(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  17187853,     635852]*)
(*NotebookOutlinePosition[  17227104,     637157]*)
(*  CellTagsIndexPosition[  17226982,     637150]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Some recent directions in technical computing", "Title",
  PageBreakAbove->False],

Cell[TextData[{
  StyleBox["Daniel Lichtblau",
    FontSize->18],
  "\nWolfram Research, Inc.\n100 Trade Centre Dr.\nChampaign IL 61820\n\
danl@wolfram.com\n\n\nSCI 2002, Orlando\n"
}], "Author"],

Cell["copyright \[Copyright]  July 2002", "Copyright"],

Cell["", "Author"],

Cell[CellGroupData[{

Cell["Abstract", "Section"],

Cell["\<\
While at one time computational software was comprised mostly of \
numerical codes, modern needs extend well beyond this (though of course \
numerical methods are still vital and actively researched). A \
present\[Hyphen]day wish list for a technical program might include a smart \
interface, the capability to perform symbolic computation, communicate with \
other programs, interact with the web, produce all sorts of graphics, serve \
the different needs of both novice and advanced users, and produce technical \
documents. Of course in addition to all this one requires that the system be \
programmable. In recent years several software systems have migrated in \
various ways toward supporting many of these needs.\
\>", "Text"],

Cell["\<\
I work on development team for the general-purpose program \
Mathematica. In this talk I will touch upon several of these trends, \
illustrating with that program. I will show some of the directions we and \
other companies and research groups are taking with such software. I hope to \
convey a sense of the excitement we have for this work and it's applicability \
in the technical world.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell["My day job", "Subsection"],

Cell[TextData[{
  "I work on development of a large program called ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and in particular I implement various aspects of its symbolic engine. \
Much of what I code is later used in ways I can hardly begin to imagine. \
Indeed, my end\[Hyphen]product is my neighbor's tool (quite literally: he has \
used ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to design glass sculpture)."
}], "Text"],

Cell["\<\
For about five years I have been working alot in an area known as \
hybrid symbolic/numeric computation. This is a fascinating world and I may \
touch upon a few of its features in this talk. It also is very much in the \
spirit of interconnection between different fields that lies at the heart of \
this conference.\
\>", "Text"],

Cell["My kids think I spend all my time at work drinking coffee.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Modern needs of technical software", "Subsection",
  PageBreakAbove->True],

Cell["\<\
Several decades ago technical computation consisted almost entirely \
of numeric computation. More recently, as computers have come in to all \
manners of business, industry, academia, government, and elsewhere, technical \
computation requirements have changed.\
\>", "Text"],

Cell["\<\
Today one requires much of a general purpose technical program.
(1) Ability to perform computations in numeric, exact, and symbolic domains. \
Within the numeric domain, the need for arbitrary precision is frequently \
encountered.
(2) Flexible user interface.
(3) Communicate with other programs.
(4) Import and export various flavors of data.
(5) Interact with the web.
(6) Algorithms that can go about their business without requiring much \
understanding from novice users.
(7) Algorithms that have the power and flexibility needed by sophisticated \
users.
(8) Ability to produce documents (technical papers, lab reports, \
presentations such as this one).
(9) General purpose graphical capabilities.
(10) Use of existing \"standard\" cross\[Hyphen]platform libraries e.g. \
LAPACK.
(11) Last but not least...a solid programming language.\
\>", "Text"],

Cell[TextData[{
  "I will demonstrate a few of these ideas. While I use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " one should bear in mind that these directions are by no means unique to \
our software but rather indicate a general trend in modern technical \
computation."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Speaking to Google from ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " via Java"
}], "Section"],

Cell["\<\
It happens that www.google.com exports a Java interface (API). Thus \
one can \"query\" google from other programs. Below is a simple demo of such. \
Note that in order to run this in actuality one must be connected to the web. \
Reminds me of a true story: A friend (okay, actually it was me) called Sears \
to ask why the ice maker on our new fridge was not working. Fellow comes out \
to take a look, says \"You need to connect it to your water line.\"\
\>", \
"Text"],

Cell[CellGroupData[{

Cell["Example: Google API", "Subsection"],

Cell["\<\
This is an example of providing access to remote servers, in this \
case Google. The package was written by Todd Gayley and may be obtained from \
him (tgayley@wolfram.com). It relies on a Java API supported by Google to \
allow programs to launch queries.\
\>", "Text"],

Cell[BoxData[
    \(<< Google`\)], "Input"],

Cell["\<\
This counts the number of URLs that link to www.wolfram.com \
according to Google.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GooglePageCount[\ "\<allinlinks:www.wolfram.com\>"\ ]\)], "Input"],

Cell[BoxData[
    \({234000, False}\)], "Output"]
}, Open  ]],

Cell["This gets the 20 first such URLs ... ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GoogleSearch["\<allinlinks:www.wolfram.com\>", 
      20, "\<URL\>"]\)], "Input"],

Cell[BoxData[
    \({"http://mathworld.wolfram.com/", "http://integrals.wolfram.com/", 
      "http://www.wolfram.com/products/mathematica/", 
      "http://www.mathsource.com/", "http://register.wolfram.com/", 
      "http://support.wolfram.com/", "http://documents.wolfram.com/", 
      "http://library.wolfram.com/", "http://functions.wolfram.com/", 
      "http://store.wolfram.com/catalog/", "http://imo.wolfram.com/", 
      "http://www.stephenwolfram.com/", 
      "http://library.wolfram.com/mathgroup/", 
      "http://scienceworld.wolfram.com/biography/", 
      "http://scienceworld.wolfram.com/", "http://polytopes.wolfram.com/", 
      "http://documents.wolfram.com/v4/", 
      "http://store.wolfram.com/catalog/apps/", 
      "http://mathworld.wolfram.com/about.html", 
      "http://site.wolfram.com/distr/unst-home.html"}\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["An ODE computation \"visualized\" courtesy of a Java applet", "Section"],

Cell["\<\
In technical computation a frequent need is to solve an ordinary \
differential equation. One may wish to plot various solution curves, inspect \
sensitivity with respect to parameters, and the like. We show a simple \
example wherein this is done with a Java GUI. This again serves to illustrate \
the usefulness of linking to stardardized programs via specific APIs.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell["Example: PlotOrbits", "Subsection"],

Cell[TextData[{
  "This is an example of providing a direct manipulation GUI function to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". The package was written by Rob Knapp and may be obtained from him \
(rknapp@wolfram.com)."
}], "Text"],

Cell[BoxData[
    \(<< PlotOrbits`\)], "Input"],

Cell[BoxData[
    \(Clear[\ a, \ w, \ x\ ]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a\  = \ 
        Parameter[\[Alpha], \ 3, {0, 10}];\)\), "\[IndentingNewLine]", 
    \(w\  = \ Parameter[\[Omega], \ 1, \ {0, 2}]; 
    PlotOrbits[\(x''\)[t]\  + \ x[t]\  \[Equal] \ a\ Cos[w\ x[t]], 
      x, {t, \(-10\), 10}, \ 
      PlotRange \[Rule] {{\(-10\), 10}, {\(-10\), 10}}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.309017 0.0309017 [
[0 .29652 -9 -9 ]
[0 .29652 9 0 ]
[.125 .29652 -12 -9 ]
[.125 .29652 12 0 ]
[.25 .29652 -6 -9 ]
[.25 .29652 6 0 ]
[.375 .29652 -12 -9 ]
[.375 .29652 12 0 ]
[.625 .29652 -9 -9 ]
[.625 .29652 9 0 ]
[.75 .29652 -3 -9 ]
[.75 .29652 3 0 ]
[.875 .29652 -9 -9 ]
[.875 .29652 9 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -24 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -12 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -24 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -18 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -6 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -18 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -12 -4.5 ]
[.4875 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30902 m
0 .31527 L
s
[(-10)] 0 .29652 0 1 Mshowa
.125 .30902 m
.125 .31527 L
s
[(-7.5)] .125 .29652 0 1 Mshowa
.25 .30902 m
.25 .31527 L
s
[(-5)] .25 .29652 0 1 Mshowa
.375 .30902 m
.375 .31527 L
s
[(-2.5)] .375 .29652 0 1 Mshowa
.625 .30902 m
.625 .31527 L
s
[(2.5)] .625 .29652 0 1 Mshowa
.75 .30902 m
.75 .31527 L
s
[(5)] .75 .29652 0 1 Mshowa
.875 .30902 m
.875 .31527 L
s
[(7.5)] .875 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(10)] 1 .29652 0 1 Mshowa
.125 Mabswid
.025 .30902 m
.025 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.075 .30902 m
.075 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.175 .30902 m
.175 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.225 .30902 m
.225 .31277 L
s
.275 .30902 m
.275 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.325 .30902 m
.325 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.425 .30902 m
.425 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.475 .30902 m
.475 .31277 L
s
.525 .30902 m
.525 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.575 .30902 m
.575 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.675 .30902 m
.675 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.725 .30902 m
.725 .31277 L
s
.775 .30902 m
.775 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.825 .30902 m
.825 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.925 .30902 m
.925 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.975 .30902 m
.975 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-7.5)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-2.5)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(2.5)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(7.5)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(10)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.207 .055 .289 r
.5 Mabswid
.67915 .34387 m
.68095 .33296 L
.68221 .32025 L
.68256 .30759 L
.682 .29492 L
.68053 .28219 L
.67815 .26937 L
.67484 .25642 L
.6706 .24335 L
.66542 .23019 L
.65929 .21703 L
.65222 .204 L
.64526 .19284 L
.63761 .18213 L
.62931 .17207 L
.6204 .16293 L
.61095 .15495 L
.60104 .14839 L
.59076 .14347 L
.58024 .14034 L
.56958 .1391 L
.55889 .13972 L
.54606 .14283 L
.53355 .14819 L
.52153 .15533 L
.5101 .16373 L
.49934 .17288 L
.4893 .18231 L
.47791 .19377 L
.46757 .20456 L
.45821 .21436 L
.44971 .22296 L
.44197 .23029 L
.43485 .23631 L
.42823 .24107 L
.42201 .2446 L
.41607 .24695 L
.41029 .24818 L
.40519 .24836 L
.40007 .24771 L
.39486 .24626 L
.38949 .24404 L
.38391 .2411 L
.37805 .23749 L
.37314 .23417 L
.36798 .23051 L
.36258 .22656 L
.3569 .22242 L
.35094 .21816 L
.34469 .21389 L
Mistroke
.33652 .20878 L
.32794 .20416 L
.32006 .20075 L
.31196 .19819 L
.30372 .19672 L
.29541 .19654 L
.28714 .19781 L
.27902 .20064 L
.27117 .20507 L
.26371 .21109 L
.25675 .21861 L
.25473 .22119 L
.25278 .2239 L
.25089 .22672 L
.24907 .22966 L
.24731 .23271 L
.24562 .23587 L
.24401 .23912 L
.23823 .25324 L
.23381 .26855 L
.23083 .28466 L
.22935 .30125 L
.22941 .31798 L
.23099 .33455 L
.23408 .35061 L
.2386 .36584 L
.24385 .37859 L
.25011 .39008 L
.25726 .40005 L
.26517 .40827 L
.27368 .41457 L
.28262 .41885 L
.29184 .42113 L
.30117 .42151 L
.31305 .41956 L
.32459 .41543 L
.3343 .41053 L
.34352 .40491 L
.3522 .39899 L
.36032 .39313 L
.36791 .38758 L
.37501 .38258 L
.38166 .37826 L
.38796 .37474 L
.39396 .3721 L
.39976 .37039 L
.40473 .3697 L
.40966 .36979 L
.41464 .37068 L
.41973 .3724 L
Mistroke
.42498 .37499 L
.43049 .37848 L
.43632 .3829 L
.44254 .38827 L
.44925 .39462 L
.45455 .39992 L
.4602 .40574 L
.4662 .41203 L
.4726 .41874 L
.47941 .42581 L
.48666 .43313 L
.49435 .44056 L
.50248 .44794 L
.51105 .45506 L
.5187 .46076 L
.52662 .46595 L
.53479 .47047 L
.54317 .47416 L
.55172 .47688 L
.56038 .47851 L
.57085 .47889 L
.58128 .47747 L
.59157 .47425 L
.60161 .46932 L
.61129 .46282 L
.62053 .45498 L
.62926 .44602 L
.6374 .43618 L
.64491 .42571 L
.6535 .41183 L
.66098 .39759 L
.66734 .38323 L
.67258 .36892 L
.67671 .35475 L
.67929 .34312 L
.68113 .33158 L
.68222 .32011 L
.68256 .30869 L
.68217 .29726 L
.68104 .28579 L
.67916 .27425 L
.67654 .26261 L
.67315 .25087 L
.6697 .24089 L
.66571 .23087 L
.66117 .22084 L
.65608 .21086 L
.65045 .20101 L
.64428 .19138 L
.63568 .17965 L
Mistroke
.62629 .16879 L
.61862 .16129 L
.61058 .15467 L
.60221 .14907 L
.59357 .14462 L
.58473 .14144 L
.57576 .13959 L
.56484 .13915 L
.55497 .1404 L
.54521 .14312 L
.53565 .14714 L
.52636 .15224 L
.51739 .1582 L
.50879 .16478 L
.49851 .17363 L
.48889 .18271 L
.47815 .19353 L
.46834 .20376 L
.4594 .21312 L
.45125 .22144 L
.44379 .22862 L
.43692 .23464 L
.43053 .23952 L
.42453 .2433 L
.41881 .246 L
.41329 .24768 L
.40788 .24837 L
.40248 .24811 L
.39581 .24658 L
.38891 .24376 L
.38415 .24124 L
.3792 .23824 L
.37402 .23478 L
.36857 .23093 L
.36284 .22676 L
.3568 .22234 L
.35044 .21781 L
.34375 .21328 L
.33675 .20892 L
.32756 .20398 L
.32146 .20129 L
.31523 .1991 L
.30889 .1975 L
.30247 .19661 L
.29603 .19651 L
.2896 .19727 L
.28113 .19974 L
.27292 .20393 L
.26509 .20983 L
.25777 .21737 L
Mistroke
.2511 .22641 L
.24516 .23677 L
.24006 .24826 L
.23588 .26065 L
.23268 .27373 L
.23087 .28436 L
.22971 .2952 L
.22921 .30615 L
.22937 .31712 L
.23018 .32803 L
.23165 .33878 L
.23376 .34928 L
.23649 .35943 L
.23982 .36913 L
.24309 .37696 L
.24676 .38431 L
.25078 .39114 L
.25515 .39739 L
.25981 .40299 L
.26579 .40881 L
.27026 .41233 L
.27488 .41528 L
.27961 .41765 L
.28444 .41946 L
.28933 .42071 L
.29329 .42131 L
.29727 .42157 L
.30125 .42151 L
.30522 .42113 L
.31042 .42021 L
.31556 .41884 L
.31832 .41792 L
.32105 .41691 L
.32376 .41579 L
.32644 .41459 L
.3267 .41446 L
.32697 .41434 L
.32723 .41421 L
.32737 .41415 L
.3275 .41408 L
.32763 .41402 L
.32777 .41395 L
.32803 .41382 L
.3283 .41369 L
.32856 .41356 L
.3312 .41222 L
.3338 .41081 L
.33636 .40934 L
.33889 .40783 L
.34339 .40499 L
Mistroke
.34777 .40207 L
.35201 .39912 L
.35611 .39619 L
.36008 .3933 L
.36656 .38856 L
.37267 .38419 L
.3773 .38103 L
.38174 .37821 L
.38602 .37575 L
.39015 .37368 L
.39417 .37202 L
.39908 .37054 L
.4039 .36976 L
.40869 .36971 L
.41351 .3704 L
.41841 .37188 L
.42346 .37416 L
.42986 .37804 L
.43492 .38178 L
.44027 .38624 L
.44498 .39052 L
.44997 .39532 L
.45525 .40063 L
.46087 .40643 L
.46684 .41269 L
.47319 .41936 L
.47996 .42637 L
.48715 .43361 L
.49571 .44184 L
.50483 .44996 L
.51275 .45638 L
.52101 .46235 L
.52958 .46769 L
.53842 .47219 L
.54748 .47567 L
.55671 .47796 L
.56748 .47896 L
.57827 .47807 L
.58712 .47587 L
.59581 .47238 L
.6043 .46769 L
.6125 .46189 L
.62038 .45512 L
.62788 .44754 L
.63715 .43651 L
.64422 .42674 L
.65071 .41658 L
.65662 .40617 L
.66192 .39562 L
.6666 .38503 L
Mistroke
.67068 .37446 L
.67415 .36394 L
.67702 .35351 L
.67928 .34316 L
.68171 .32639 L
.6825 .31394 L
.6824 .3015 L
.68144 .28904 L
.67959 .27651 L
.67685 .26386 L
.67322 .2511 L
.66869 .23822 L
.66325 .22528 L
.65689 .21239 L
.64708 .19562 L
.63935 .18443 L
.63092 .1739 L
.62182 .16428 L
.61215 .15587 L
.60197 .14893 L
.59139 .14371 L
.58054 .14041 L
.56954 .1391 L
.56059 .1395 L
.5517 .14116 L
.54292 .14397 L
.53432 .1478 L
.52594 .1525 L
.51784 .15788 L
.50885 .16473 L
.5003 .17202 L
.4922 .17951 L
.48456 .187 L
.47737 .19433 L
.47061 .20138 L
.46427 .20803 L
.45832 .21424 L
.45274 .21995 L
.44582 .22673 L
.4394 .23255 L
.43342 .23742 L
.42779 .24136 L
.42245 .24439 L
.41732 .24655 L
.41232 .24787 L
.4074 .24838 L
.40249 .24812 L
.39622 .24671 L
.39154 .24497 L
.38671 .24265 L
Mistroke
.38169 .23979 L
.37644 .23643 L
.37092 .23261 L
.3661 .22914 L
.36107 .22546 L
.3558 .22162 L
.3503 .21771 L
.34455 .2138 L
.33675 .20892 L
.33007 .20523 L
.32316 .20199 L
.31748 .19982 L
.31169 .19812 L
.30584 .19698 L
.29994 .19647 L
.29403 .19665 L
.28693 .19787 L
.27994 .20024 L
.27313 .2038 L
.2666 .20853 L
.2604 .21441 L
.2546 .22137 L
.24928 .2293 L
.2445 .23811 L
.24029 .24767 L
.23598 .2603 L
.23327 .27092 L
.23123 .28189 L
.22989 .2931 L
.22925 .30446 L
.22932 .31586 L
.2301 .3272 L
.2318 .33964 L
.23436 .35174 L
.23774 .36334 L
.24191 .37428 L
.24681 .38441 L
.25238 .39356 L
.25856 .40158 L
.26525 .40834 L
.27236 .41375 L
.27846 .41713 L
.28472 .41955 L
.2911 .42102 L
.29753 .42158 L
.30397 .42128 L
.31037 .42022 L
.31784 .41809 L
.32514 .41518 L
.33222 .41167 L
Mistroke
.33905 .40773 L
.3456 .40353 L
.35187 .39923 L
.35784 .39494 L
.36596 .389 L
.37353 .38359 L
.3806 .37891 L
.38725 .3751 L
.39358 .37224 L
.39968 .37041 L
.40565 .36966 L
.41264 .37022 L
.41979 .37243 L
.42729 .37636 L
.43535 .38212 L
.44418 .38977 L
.454 .39936 L
.46503 .4108 L
.47334 .41952 L
.48235 .42881 L
.49211 .43844 L
.50262 .44806 L
.51387 .45723 L
.52581 .46545 L
.53833 .47215 L
.5513 .47677 L
.56454 .47887 L
.57506 .47853 L
.5855 .47637 L
.59575 .47241 L
.60571 .46678 L
.61526 .45965 L
.62434 .45126 L
.63286 .44184 L
.6419 .43009 L
.65007 .41764 L
.65735 .40479 L
.6637 .39176 L
.66912 .3787 L
.67361 .3657 L
.67719 .35282 L
.67985 .34007 L
.68161 .32742 L
.68247 .31484 L
.68244 .30229 L
.68131 .28792 L
.679 .27344 L
.67552 .25881 L
.67084 .24402 L
.66495 .22911 L
Mistroke
.65785 .21422 L
.64955 .19954 L
.64008 .18542 L
.62949 .17228 L
.6179 .16065 L
.60543 .15108 L
.5923 .14408 L
.58155 .14063 L
.57064 .13914 L
.55969 .13961 L
.54884 .14195 L
.5382 .14594 L
.52786 .15134 L
.5179 .15784 L
.50839 .16511 L
.49936 .17286 L
.49084 .18081 L
.48204 .18954 L
.47385 .19799 L
.46624 .20597 L
.45918 .21336 L
.45262 .22007 L
.44651 .22606 L
.44081 .23132 L
.43472 .23642 L
.42901 .24057 L
.42359 .2438 L
.41841 .24616 L
.41338 .24766 L
.40844 .24834 L
.40777 .24837 L
Mfstroke
.025 w
.3275 .41408 Mdot
.57 .391 .227 r
.5 Mabswid
.32162 .26336 m
.32121 .26297 L
.31819 .2604 L
.31502 .25813 L
.31172 .25621 L
.30831 .25467 L
.30481 .25356 L
.30196 .25301 L
.29909 .25277 L
.29622 .25286 L
.29336 .2533 L
.29053 .25409 L
.28516 .25667 L
.28011 .26062 L
.27553 .26587 L
.27153 .27231 L
.26822 .27977 L
.26518 .29036 L
.26395 .29774 L
.26333 .30532 L
.26334 .31298 L
.26398 .32056 L
.26524 .32792 L
.26708 .33493 L
.26949 .34143 L
.27325 .34877 L
.27772 .35491 L
.28126 .35846 L
.28504 .36129 L
.289 .36336 L
.29308 .36467 L
.29723 .36524 L
.3014 .3651 L
.30554 .36428 L
.30959 .36284 L
.31351 .36084 L
.31557 .35954 L
.31758 .35811 L
.31952 .35655 L
.3214 .35488 L
.32321 .3531 L
.32339 .35292 L
.32357 .35274 L
.32374 .35255 L
.32392 .35237 L
.32394 .35235 L
.32395 .35233 L
.32397 .35231 L
.32398 .3523 L
.32399 .35229 L
Mistroke
.324 .35228 L
.32401 .35227 L
.32402 .35226 L
.32849 .34685 L
.33233 .34093 L
.33551 .33467 L
.3384 .32679 L
.34024 .31872 L
.34085 .31337 L
.341 .30801 L
.34067 .30266 L
.33989 .29732 L
.33863 .29204 L
.33692 .28683 L
.33516 .28259 L
.33309 .27845 L
.33073 .27445 L
.32808 .27063 L
.32516 .26704 L
.32199 .26371 L
.31741 .2598 L
.31248 .25661 L
.30947 .25514 L
.30639 .254 L
.30325 .25322 L
.30008 .25281 L
.2969 .25281 L
.29233 .25355 L
.28785 .25519 L
.28355 .25776 L
.27949 .26123 L
.27575 .26557 L
.2724 .2707 L
.26955 .27646 L
.26718 .2828 L
.26535 .28962 L
.26407 .29679 L
.26339 .30419 L
.2633 .31168 L
.26342 .31452 L
.26363 .31735 L
.26393 .32015 L
.26432 .32293 L
.26478 .32567 L
.2664 .33261 L
.26855 .33913 L
.27121 .34511 L
.27432 .35043 L
.27782 .35503 L
.28167 .35881 L
Mistroke
.28681 .36232 L
.29223 .36446 L
.2978 .36527 L
.30338 .36479 L
.30886 .36315 L
.31412 .36047 L
.31908 .35693 L
.32364 .35266 L
.32775 .34784 L
.33135 .34258 L
.33442 .33701 L
.33692 .33122 L
.33883 .32528 L
.34038 .31779 L
.34099 .31022 L
.341 .30873 L
.34098 .30724 L
.34092 .30575 L
.34082 .30427 L
.34069 .30278 L
.33998 .29781 L
.33886 .29288 L
.33735 .28801 L
.33545 .28323 L
.33316 .27858 L
.3305 .2741 L
.32822 .27083 L
.32575 .26772 L
.32309 .2648 L
.31925 .26125 L
.31514 .2582 L
.31212 .25641 L
.309 .25495 L
.30581 .25383 L
.30257 .2531 L
.2993 .25277 L
.29601 .25288 L
.29275 .25344 L
.28954 .25446 L
.28639 .25594 L
.2827 .25839 L
.27921 .26151 L
.27597 .26528 L
.27301 .26966 L
.27039 .2746 L
.26813 .28002 L
.26572 .28802 L
.26413 .29638 L
.26334 .30505 L
.26338 .31383 L
Mistroke
.2636 .31691 L
.26391 .31997 L
.26432 .32299 L
.26484 .32597 L
.26545 .32889 L
.26616 .33175 L
.26851 .33902 L
.27147 .34562 L
.27499 .35141 L
.27898 .35628 L
.28336 .36014 L
.28803 .36293 L
.2929 .36463 L
.29948 .36525 L
.30603 .36414 L
.31143 .36198 L
.31656 .35886 L
.32134 .35494 L
.32569 .35038 L
.32957 .34532 L
.33292 .33989 L
.33572 .33419 L
.33794 .32831 L
.33956 .3223 L
.34058 .31622 L
.341 .31011 L
.3408 .30399 L
.34021 .29915 L
.33924 .29434 L
.33789 .28959 L
.33617 .28491 L
.33408 .28034 L
.33163 .27591 L
.32875 .27155 L
.32552 .26745 L
.32196 .26368 L
.31812 .26034 L
.31402 .2575 L
.30971 .25525 L
.30656 .25406 L
.30335 .25324 L
.3001 .25281 L
.29684 .25281 L
.29359 .25325 L
.29052 .25409 L
.28751 .25536 L
.28458 .25705 L
.28175 .25915 L
.27905 .26167 L
.27549 .26592 L
Mistroke
.27229 .27091 L
.26951 .27656 L
.26719 .28277 L
.26538 .28944 L
.26412 .29646 L
.26341 .30369 L
.26328 .31102 L
.26373 .31831 L
.26439 .32338 L
.26532 .32832 L
.26653 .33309 L
.268 .33765 L
.26972 .34196 L
.27149 .34565 L
.27344 .34908 L
.27556 .35221 L
.27784 .35504 L
.28024 .35754 L
.28294 .35983 L
.28575 .36172 L
.28866 .36321 L
.29163 .3643 L
.29465 .36498 L
.29722 .36524 L
.2998 .36524 L
.30238 .36497 L
.30493 .36444 L
.30808 .36345 L
.31115 .36211 L
.31415 .36046 L
.31703 .35851 L
.31832 .35753 L
.31959 .3565 L
.32082 .35542 L
.32203 .35429 L
.32214 .35417 L
.32226 .35406 L
.32238 .35394 L
.32244 .35388 L
.3225 .35382 L
.32256 .35377 L
.32262 .35371 L
.32274 .35359 L
.32285 .35347 L
.32297 .35335 L
.32412 .35215 L
.32525 .3509 L
.32633 .34962 L
.32739 .3483 L
.32978 .34501 L
Mistroke
.33196 .34157 L
.33392 .33801 L
.33565 .33435 L
.33714 .33062 L
.33876 .32554 L
.33995 .32038 L
.34058 .31626 L
.34093 .31211 L
.341 .30796 L
.34078 .30381 L
.34029 .29967 L
.33923 .29429 L
.33769 .28897 L
.33568 .28376 L
.33322 .27869 L
.33032 .27383 L
.327 .26924 L
.32329 .26501 L
.31923 .26124 L
.31485 .25802 L
.30956 .25518 L
.30402 .25338 L
.29837 .25276 L
.29272 .25345 L
.2872 .25551 L
.28197 .25898 L
.27715 .2638 L
.27459 .2672 L
.27224 .271 L
.27012 .27517 L
.26826 .27967 L
.26668 .28445 L
.26538 .28947 L
.26458 .29347 L
.26397 .29755 L
.26355 .3017 L
.26331 .3059 L
.26327 .31011 L
.26352 .31599 L
.26415 .32179 L
.26514 .32745 L
.26648 .33289 L
.26815 .33807 L
.27015 .34292 L
.27129 .34526 L
.2725 .34749 L
.27378 .34961 L
.27513 .35161 L
.27654 .35348 L
.28045 .35773 L
Mistroke
.28468 .36106 L
.28915 .36342 L
.29378 .36482 L
.29848 .36527 L
.30319 .36483 L
.30599 .36415 L
.30876 .36319 L
.31147 .36196 L
.31411 .36048 L
.31667 .35878 L
.32084 .3554 L
.3247 .35152 L
.32759 .34805 L
.33022 .34436 L
.33259 .34049 L
.33467 .33648 L
.33647 .33237 L
.33798 .32817 L
.33945 .32281 L
.34043 .31738 L
.34094 .31192 L
.34095 .30645 L
.34048 .30099 L
.33952 .29557 L
.3375 .28843 L
.33464 .28149 L
.33098 .27486 L
.32741 .26976 L
.32336 .26508 L
.31889 .26095 L
.31404 .25751 L
.3089 .2549 L
.30355 .25328 L
.2981 .25276 L
.29265 .25346 L
.28734 .25544 L
.28228 .25872 L
.27838 .26239 L
.27481 .26687 L
.27164 .2721 L
.26891 .278 L
.26667 .28447 L
.26498 .29137 L
.26447 .29415 L
.26405 .29696 L
.26372 .29981 L
.26348 .30269 L
.26332 .30558 L
.26334 .31296 L
.26395 .32027 L
Mistroke
.26512 .32738 L
.26685 .33416 L
.2691 .3405 L
.27183 .34629 L
.27445 .35063 L
.27734 .35447 L
.28047 .35775 L
.2838 .36046 L
.28729 .36257 L
.2909 .36407 L
.29566 .36511 L
.30048 .36519 L
.30419 .36462 L
.30786 .36353 L
.31143 .36197 L
.31489 .35999 L
.3182 .35763 L
.32239 .35393 L
.32623 .34974 L
.32895 .34621 L
.33141 .34248 L
.33361 .33861 L
.33553 .33461 L
.33718 .33052 L
.33853 .32636 L
.33985 .32088 L
.34068 .31534 L
.341 .30978 L
.34082 .30422 L
.34013 .29868 L
.33894 .29318 L
.33663 .28606 L
.33347 .27916 L
.32951 .27263 L
.32582 .26781 L
.32169 .26343 L
.31718 .25963 L
.31233 .25653 L
.30723 .25428 L
.30196 .25301 L
.29662 .25283 L
.29131 .25383 L
.28617 .25607 L
.28247 .25857 L
.27897 .26176 L
.27573 .2656 L
.27278 .27005 L
.27018 .27505 L
.26794 .28055 L
.26569 .28815 L
Mistroke
.26415 .29624 L
.26336 .30462 L
.26335 .31312 L
.26411 .32151 L
.26562 .32961 L
.26799 .33761 L
.27022 .34308 L
.27283 .34807 L
.27578 .3525 L
.27902 .35632 L
.28251 .35949 L
.2862 .36198 L
.28934 .3635 L
.29256 .36455 L
.29584 .36513 L
.29913 .36526 L
.30241 .36496 L
.30567 .36424 L
.30887 .36314 L
.312 .36168 L
.31503 .3599 L
.31915 .35686 L
.323 .35333 L
.32567 .35041 L
.32815 .3473 L
.33044 .34402 L
.3331 .33956 L
.33539 .33493 L
.3373 .33017 L
.33882 .32531 L
.33995 .32039 L
.34067 .31544 L
.34081 .31395 L
.34091 .31247 L
.34097 .31099 L
.341 .3095 L
.341 .30802 L
.3404 .30045 L
.33888 .29295 L
.33698 .287 L
.3345 .28119 L
.33145 .27561 L
.32785 .27034 L
.32375 .26549 L
.3192 .26121 L
.31425 .25764 L
.30899 .25494 L
.30351 .25327 L
.29792 .25277 L
.29234 .25354 L
Mistroke
.2869 .25567 L
.28175 .25915 L
.2779 .26292 L
.27438 .2675 L
.27127 .27282 L
.2686 .27878 L
.26643 .28529 L
.26481 .29224 L
.26454 .29372 L
Mfstroke
.025 w
.3225 .35382 Mdot
.352 .48 .098 r
.5 Mabswid
.89792 .35347 m
.89928 .34802 L
.9017 .33528 L
.90316 .32213 L
.90364 .30879 L
.90313 .29545 L
.90256 .2894 L
.9018 .28342 L
.90083 .27752 L
.89967 .27172 L
.89831 .26604 L
.89676 .2605 L
.89184 .24677 L
.88576 .23442 L
.87865 .2237 L
.87067 .21482 L
.86199 .20784 L
.85278 .20275 L
.84319 .1994 L
.83338 .19752 L
.82345 .19678 L
.81349 .19678 L
.80354 .19708 L
.79362 .19727 L
.7837 .19693 L
.77371 .19571 L
.76356 .19325 L
.75313 .18925 L
.74608 .18568 L
.7388 .18127 L
.73124 .17598 L
.72334 .16977 L
.71506 .16263 L
.70634 .15458 L
.69712 .14567 L
.68476 .13342 L
.67445 .12324 L
.66355 .11279 L
.65206 .10239 L
.63998 .09242 L
.62736 .0833 L
.61425 .07546 L
.60073 .06931 L
.58875 .06558 L
.57662 .06352 L
.56443 .06314 L
.55227 .06442 L
.5402 .06718 L
.52831 .07122 L
.51664 .07624 L
Mistroke
.50068 .08437 L
.48532 .09296 L
.47054 .10123 L
.45631 .10852 L
.44255 .11437 L
.42913 .11849 L
.41593 .12073 L
.40282 .12111 L
.38968 .11977 L
.3764 .11698 L
.3653 .11388 L
.35402 .11035 L
.34252 .10672 L
.33083 .10336 L
.31896 .10065 L
.30696 .09897 L
.2949 .09867 L
.28287 .1 L
.27097 .10315 L
.2593 .10819 L
.24572 .11671 L
.2328 .12765 L
.22072 .14062 L
.20959 .15516 L
.1995 .1708 L
.19052 .18713 L
.18268 .20383 L
.17599 .22065 L
.17047 .23743 L
.16651 .25237 L
.16346 .2672 L
.16133 .28191 L
.16011 .29655 L
.15979 .31115 L
.16037 .32576 L
.16232 .34369 L
.16444 .35609 L
.16721 .36856 L
.17063 .38112 L
.1747 .39375 L
.17943 .4064 L
.18482 .41904 L
.19086 .43158 L
.19755 .44391 L
.20487 .45589 L
.21572 .47121 L
.22369 .48087 L
.23211 .48972 L
.24093 .49761 L
.2501 .5044 L
Mistroke
.25957 .50998 L
.26927 .51427 L
.28159 .51779 L
.29406 .51933 L
.30657 .51909 L
.31901 .51737 L
.33132 .51454 L
.34344 .51103 L
.35534 .50726 L
.37071 .50257 L
.38576 .49896 L
.40058 .49704 L
.41533 .49724 L
.42452 .49855 L
.43379 .50078 L
.44319 .5039 L
.45277 .50787 L
.46255 .51259 L
.47258 .51792 L
.48289 .52369 L
.49348 .52968 L
.50436 .53563 L
.51443 .54075 L
.52472 .54538 L
.5352 .5493 L
.54583 .55232 L
.55657 .55425 L
.56737 .55495 L
.58047 .55405 L
.59347 .55118 L
.60627 .54645 L
.61877 .54007 L
.63089 .53233 L
.64257 .52357 L
.65377 .51414 L
.66445 .5044 L
.67672 .49257 L
.68824 .48115 L
.69904 .47048 L
.70918 .46078 L
.71873 .45217 L
.72776 .44471 L
.73816 .43719 L
.74803 .4313 L
.75749 .42692 L
.76667 .42389 L
.77565 .422 L
.78453 .42104 L
.79335 .42077 L
.80217 .42091 L
Mistroke
.81101 .42119 L
.81987 .42131 L
.82789 .42103 L
.83586 .42016 L
.84375 .41848 L
.85148 .41584 L
.85899 .41208 L
.86618 .40713 L
.87297 .40093 L
.87928 .3935 L
.88502 .38489 L
.8901 .3752 L
.89445 .36455 L
.89801 .35311 L
.90128 .33791 L
.90291 .32521 L
.90361 .31228 L
.90337 .2993 L
.90221 .28646 L
.90014 .27395 L
.89718 .26194 L
.89248 .24832 L
.88664 .236 L
.8798 .22523 L
.87209 .2162 L
.86367 .20901 L
.85471 .20365 L
.84536 .20001 L
.83576 .19786 L
.82602 .19689 L
.81624 .19673 L
.80825 .19693 L
.80029 .19718 L
.79233 .19726 L
.78437 .19698 L
.77637 .19614 L
.76829 .19456 L
.76006 .19208 L
.75287 .18913 L
.74547 .18533 L
.73781 .18062 L
.72983 .17492 L
.72148 .16821 L
.71269 .16049 L
.70562 .1539 L
.69823 .14676 L
.6905 .13913 L
.6824 .13108 L
.67392 .12272 L
.66505 .1142 L
Mistroke
.65344 .10361 L
.64124 .09341 L
.63143 .08609 L
.62132 .07947 L
.61093 .07376 L
.60031 .06915 L
.58951 .06577 L
.57859 .06374 L
.56526 .06312 L
.55195 .06447 L
.53877 .0676 L
.5258 .07222 L
.5131 .07793 L
.50074 .08434 L
.48874 .09102 L
.4722 .10033 L
.45634 .10851 L
.44105 .11492 L
.42617 .11915 L
.41627 .1207 L
.40642 .12119 L
.39656 .12067 L
.38666 .11925 L
.37666 .11705 L
.36653 .11425 L
.35367 .11024 L
.34055 .10612 L
.33064 .10331 L
.32061 .10098 L
.31048 .09934 L
.30029 .09862 L
.2901 .09899 L
.27995 .1006 L
.26764 .10439 L
.25562 .11021 L
.24401 .11799 L
.23291 .12755 L
.22243 .13861 L
.21264 .1509 L
.20362 .1641 L
.1954 .17794 L
.1858 .19686 L
.17771 .21605 L
.17113 .23525 L
.16606 .25431 L
.16249 .27318 L
.16107 .28436 L
.16017 .2955 L
.15979 .30661 L
.15994 .31772 L
Mistroke
.16061 .32885 L
.16181 .34001 L
.16403 .35397 L
.16708 .36803 L
.16981 .37832 L
.17298 .38866 L
.1766 .39904 L
.18066 .40942 L
.18516 .41978 L
.18775 .4253 L
.19047 .4308 L
.19331 .43626 L
.19628 .44167 L
.19743 .4437 L
.19861 .44572 L
.1998 .44773 L
.1999 .4479 L
.2 .44807 L
.2001 .44824 L
.2002 .44841 L
.20142 .45041 L
.20264 .45239 L
.20389 .45436 L
.2074 .45969 L
.21103 .46491 L
.21478 .46999 L
.21866 .47492 L
.22447 .48174 L
.23051 .48813 L
.23677 .49405 L
.24321 .49943 L
.24983 .50422 L
.26108 .51074 L
.27264 .51544 L
.28159 .51778 L
.29063 .51909 L
.29969 .51943 L
.30876 .51889 L
.31778 .5176 L
.32674 .5157 L
.33777 .51274 L
.34863 .5094 L
.35931 .506 L
.36981 .50283 L
.38015 .50014 L
.39037 .49815 L
.4005 .49704 L
.4106 .49693 L
.42072 .4979 L
.4389 .50237 L
Mistroke
.45242 .50771 L
.46636 .51456 L
.48081 .52252 L
.49309 .52946 L
.50576 .53637 L
.5188 .5428 L
.53219 .54826 L
.54585 .55232 L
.55968 .55458 L
.57359 .55477 L
.58492 .55329 L
.59614 .55035 L
.60719 .54604 L
.61802 .5405 L
.62856 .53393 L
.63878 .52654 L
.65079 .51673 L
.66224 .50647 L
.67128 .49788 L
.67992 .48942 L
.68817 .48122 L
.69604 .47342 L
.70356 .4661 L
.71075 .45932 L
.71931 .45166 L
.72745 .44495 L
.73523 .43918 L
.74269 .43432 L
.7499 .43033 L
.75689 .42716 L
.76545 .42422 L
.77384 .4223 L
.78211 .42122 L
.79033 .4208 L
.79854 .42082 L
.80676 .42106 L
.815 .42128 L
.82468 .4212 L
.83433 .42038 L
.84386 .41845 L
.85317 .41511 L
.86211 .41011 L
.87055 .40333 L
.87833 .39474 L
.88529 .38441 L
.89129 .37253 L
.89621 .35931 L
.89783 .35379 L
.89926 .34812 L
.90049 .34233 L
Mistroke
.90152 .33642 L
.90235 .33043 L
.90298 .32437 L
.90362 .31132 L
.90331 .29823 L
.90206 .2853 L
.89988 .27272 L
.89681 .26067 L
.89288 .24934 L
.88817 .23889 L
.88101 .22692 L
.87282 .21695 L
.86379 .2091 L
.85507 .20383 L
.84782 .2008 L
.84039 .19873 L
.83285 .19746 L
.82525 .19685 L
.81762 .19672 L
.81 .19687 L
.79986 .19719 L
.79165 .19726 L
.78343 .19692 L
.77516 .19596 L
.7668 .19418 L
.75827 .19141 L
.74949 .1875 L
.739 .18141 L
.73006 .1751 L
.72064 .16751 L
.71066 .15863 L
.70003 .14852 L
.68867 .13731 L
.67651 .12526 L
.66408 .11329 L
.65337 .10354 L
.64216 .09413 L
.63045 .0854 L
.61831 .0777 L
.60579 .07137 L
.59298 .06671 L
.57996 .06392 L
.56685 .06309 L
.55607 .06385 L
.54535 .06583 L
.53474 .06889 L
.52429 .07284 L
.51402 .07749 L
.50397 .08261 L
.49311 .08856 L
Mistroke
.48254 .09454 L
.47226 .10029 L
.46224 .1056 L
.45247 .1103 L
.44291 .11424 L
.43353 .11733 L
.42427 .11953 L
.41509 .12081 L
.40033 .12098 L
.3855 .11903 L
.37044 .11538 L
.35505 .11068 L
.34317 .10692 L
.33108 .10343 L
.3188 .10062 L
.30638 .09893 L
.2939 .09871 L
.28146 .10027 L
.26918 .1038 L
.25948 .1081 L
.25002 .11369 L
.24086 .12049 L
.23205 .12838 L
.22364 .13723 L
.21567 .14689 L
.20483 .16222 L
.19751 .17419 L
.19083 .18652 L
.18479 .19905 L
.17941 .21168 L
.17468 .22434 L
.17061 .23696 L
.1672 .24951 L
.16443 .26198 L
.16231 .27437 L
.16037 .29229 L
.15979 .30689 L
.16011 .32149 L
.16133 .33613 L
.16346 .35084 L
.16651 .36567 L
.17047 .3806 L
.176 .39739 L
.18268 .41421 L
.19052 .43091 L
.1995 .44724 L
.20959 .46289 L
.22073 .47742 L
.23281 .49039 L
.24573 .50133 L
Mistroke
.25931 .50984 L
.27098 .51488 L
.28288 .51803 L
.29491 .51937 L
.30697 .51906 L
.31896 .51738 L
.33083 .51467 L
.34253 .51131 L
.35402 .50768 L
.36531 .50415 L
.3764 .50105 L
.38969 .49826 L
.40283 .49692 L
.41594 .4973 L
.42914 .49955 L
.44256 .50367 L
.45633 .50952 L
.47056 .51682 L
.48534 .52508 L
.50071 .53368 L
.51667 .54181 L
.52834 .54683 L
.54025 .55086 L
.55232 .55363 L
.56449 .55489 L
.57668 .55451 L
.58882 .55243 L
.60081 .5487 L
.61433 .54253 L
.62744 .53468 L
.64007 .52554 L
.65216 .51555 L
.66365 .50515 L
.67455 .49469 L
.68486 .48451 L
.69722 .47226 L
.70643 .46337 L
.71514 .45533 L
.72342 .4482 L
.7313 .44201 L
.73886 .43672 L
.74613 .43233 L
.75318 .42876 L
.76359 .42478 L
.77371 .42233 L
.78368 .4211 L
.79358 .42077 L
.80347 .42095 L
.81339 .42125 L
.82333 .42125 L
Mistroke
.83324 .42053 L
.84304 .41868 L
.85261 .41536 L
.86181 .41032 L
.87048 .4034 L
.87846 .39458 L
.88557 .38394 L
.89167 .37166 L
.89662 .358 L
.89819 .35245 L
.89957 .34676 L
.90075 .34096 L
.90173 .33504 L
.90252 .32905 L
.90309 .32299 L
.90363 .30971 L
.9032 .29642 L
.90178 .28332 L
.89942 .27061 L
.89613 .25848 L
.89199 .24713 L
.88703 .23672 L
.87924 .22449 L
.87035 .21451 L
.86267 .20831 L
.85457 .20358 L
.84615 .20025 L
.83751 .19815 L
.82875 .19706 L
.81994 .19672 L
.81112 .19684 L
.80365 .19708 L
.79618 .19725 L
.78872 .19719 L
.78573 .19706 L
Mfstroke
.025 w
.2 .44807 Mdot
.035 .914 .188 r
.5 Mabswid
.81497 .50286 m
.8177 .50288 L
.82556 .5028 L
.8334 .50241 L
.84307 .50136 L
.85266 .49948 L
.86413 .49586 L
.86928 .49365 L
.87437 .49108 L
.87939 .48814 L
.88432 .48482 L
.88915 .48113 L
.88962 .48073 L
.8901 .48034 L
.89057 .47994 L
.89105 .47954 L
.8911 .4795 L
.89114 .47946 L
.89119 .47942 L
.89121 .4794 L
.89124 .47938 L
.89126 .47936 L
.89128 .47934 L
.89131 .47932 L
.90572 .4646 L
.91869 .44658 L
.92771 .43044 L
.93556 .41297 L
.94216 .3945 L
.94745 .37531 L
.95139 .35564 L
.95394 .33566 L
.95509 .31553 L
.95484 .29535 L
.95319 .27526 L
.95015 .25537 L
.94641 .23846 L
.94166 .22194 L
.93593 .20598 L
.92926 .19075 L
.92171 .17647 L
.91332 .16336 L
.90419 .15163 L
.8944 .14147 L
.88405 .13302 L
.87324 .12634 L
.85979 .12061 L
.84601 .11715 L
.83205 .11553 L
.81802 .11515 L
Mistroke
.80398 .11535 L
.78997 .11544 L
.77129 .11429 L
.76131 .11269 L
.75123 .11019 L
.74099 .10669 L
.73055 .10211 L
.71984 .09643 L
.70882 .08968 L
.69743 .08196 L
.6873 .07465 L
.67683 .06689 L
.66602 .05888 L
.65486 .05084 L
.64335 .04305 L
.6315 .03579 L
.61935 .02937 L
.60695 .02405 L
.59434 .02007 L
.58159 .01759 L
.56876 .01669 L
.55593 .01735 L
.53758 .02078 L
.51954 .02656 L
.5019 .03381 L
.48475 .0416 L
.46809 .04902 L
.44814 .05659 L
.42869 .06156 L
.41531 .06325 L
.40199 .06347 L
.38863 .06233 L
.37519 .06008 L
.3616 .05703 L
.34783 .05362 L
.33387 .05031 L
.31975 .04763 L
.3019 .04592 L
.28402 .04682 L
.2663 .0509 L
.24898 .05831 L
.23227 .06885 L
.21637 .08197 L
.20142 .09696 L
.18754 .11307 L
.17212 .13324 L
.15836 .15311 L
.14622 .17204 L
.13653 .18811 L
.12801 .20306 L
Mistroke
.12057 .2169 L
.11413 .22971 L
.10862 .24161 L
.10397 .25272 L
.10014 .26318 L
.09693 .27359 L
.09453 .28355 L
.0929 .29321 L
.09203 .30266 L
.0919 .31204 L
.09251 .32146 L
.09387 .33103 L
.09599 .34087 L
.09891 .35111 L
.10265 .36188 L
.10727 .37333 L
.11108 .38188 L
.11539 .39091 L
.12021 .40044 L
.12557 .41054 L
.13152 .42123 L
.13807 .43254 L
.14528 .44447 L
.15316 .45697 L
.16081 .46858 L
.16904 .48049 L
.17787 .49259 L
.18731 .50468 L
.19734 .51654 L
.20795 .52793 L
.2191 .53854 L
.23319 .54985 L
.2479 .55914 L
.26309 .56602 L
.27862 .57033 L
.29433 .5721 L
.31007 .57162 L
.32573 .56939 L
.34122 .56603 L
.35958 .56149 L
.37763 .55748 L
.38976 .55556 L
.40181 .55457 L
.41384 .55469 L
.42591 .556 L
.43808 .55852 L
.45039 .56219 L
.46291 .56687 L
.47328 .57127 L
.48383 .57602 L
Mistroke
.49458 .58093 L
.50552 .5858 L
.51665 .59037 L
.52795 .59442 L
.5394 .59771 L
.55097 .60003 L
.5626 .60122 L
.57713 .60094 L
.5916 .59863 L
.6059 .59437 L
.61995 .58838 L
.63366 .58099 L
.64698 .5726 L
.65986 .56364 L
.67229 .55452 L
.68755 .5432 L
.70211 .53283 L
.71605 .52383 L
.72947 .51645 L
.74247 .51078 L
.75517 .50676 L
.76643 .50442 L
.77758 .50312 L
.78869 .50261 L
.79978 .50261 L
.81088 .50281 L
.82198 .50287 L
.83081 .50258 L
.8396 .50182 L
.84835 .50044 L
.85702 .49829 L
.86558 .49528 L
.87397 .4913 L
.88463 .4846 L
.89484 .47616 L
.90116 .4698 L
.90722 .46278 L
.91299 .45514 L
.91847 .44693 L
.92361 .43821 L
.9314 .4227 L
.93817 .4062 L
.94385 .38895 L
.94841 .37114 L
.95181 .35296 L
.95404 .33454 L
.95501 .31859 L
.95509 .30261 L
.9543 .28665 L
.95263 .27077 L
Mistroke
.95008 .25504 L
.94668 .23954 L
.94243 .22437 L
.93735 .20964 L
.93147 .19549 L
.92311 .17893 L
.91597 .16723 L
.90824 .15653 L
.89997 .14697 L
.89124 .13866 L
.8821 .13167 L
.87264 .12603 L
.85969 .12058 L
.84645 .11723 L
.83303 .11559 L
.81955 .11515 L
.80605 .11531 L
.79426 .11547 L
.78246 .11522 L
.77062 .11421 L
.75869 .11213 L
.7466 .10873 L
.73425 .10385 L
.72534 .09947 L
.71622 .09431 L
.70686 .0884 L
.69723 .08182 L
.68731 .07466 L
.67707 .06707 L
.66399 .05739 L
.6504 .04775 L
.63845 .03995 L
.62617 .03284 L
.6136 .02674 L
.60077 .02191 L
.58776 .01859 L
.57464 .0169 L
.56148 .01687 L
.54835 .01843 L
.53533 .02139 L
.52247 .02549 L
.50981 .03042 L
.49738 .03583 L
.48215 .04279 L
.46729 .04935 L
.44877 .05638 L
.43683 .05982 L
.42504 .06217 L
.41333 .06337 L
.40164 .06345 L
Mistroke
.38994 .0625 L
.37817 .06066 L
.3639 .05759 L
.34944 .05402 L
.33849 .05136 L
.32743 .04897 L
.31628 .04712 L
.30507 .04605 L
.29383 .04596 L
.28261 .04702 L
.26906 .05004 L
.25572 .05501 L
.24269 .06189 L
.23006 .07049 L
.21791 .08056 L
.20633 .09177 L
.19534 .10377 L
.18499 .11624 L
.1724 .13286 L
.16382 .14503 L
.15584 .15693 L
.14846 .16845 L
.14165 .17952 L
.13538 .19008 L
.12964 .20014 L
.12643 .20593 L
.1234 .21154 L
.12053 .21698 L
.11782 .22225 L
.11528 .22736 L
.10911 .2405 L
.10398 .2527 L
.09983 .2641 L
.09658 .27489 L
.0942 .28521 L
.09266 .29522 L
.09209 .3016 L
.09187 .30793 L
.09198 .31426 L
.09243 .32062 L
.09321 .32704 L
.09467 .33515 L
.09597 .34077 L
.09751 .34651 L
.09932 .35241 L
.1014 .35848 L
.10375 .36476 L
.10639 .37126 L
.10933 .37802 L
.11144 .38265 L
Mistroke
.11368 .3874 L
.11607 .39229 L
.11861 .39733 L
.11983 .39971 L
.12108 .40212 L
.12237 .40456 L
.12243 .40469 L
.1225 .40481 L
.12257 .40494 L
.12263 .40507 L
.12396 .40756 L
.12533 .41008 L
.12672 .41264 L
.12963 .41789 L
.13269 .42328 L
.13589 .42882 L
.13925 .43451 L
.14398 .44234 L
.149 .45043 L
.15432 .45876 L
.15994 .46729 L
.16589 .476 L
.17629 .49047 L
.18756 .50499 L
.19688 .51603 L
.20671 .52666 L
.21701 .53665 L
.22775 .54576 L
.2389 .55376 L
.25038 .56045 L
.264 .56635 L
.27789 .57018 L
.28931 .57179 L
.30076 .57215 L
.31221 .5714 L
.3236 .56977 L
.33491 .5675 L
.34611 .56484 L
.36067 .56122 L
.37503 .55798 L
.38683 .55594 L
.39855 .55474 L
.41024 .55453 L
.42194 .55544 L
.43372 .55748 L
.44561 .56065 L
.46397 .5673 L
.47923 .57392 L
.49489 .58107 L
.50743 .58661 L
Mistroke
.52021 .59173 L
.53321 .59605 L
.54639 .59924 L
.55968 .60104 L
.57301 .60122 L
.58632 .59971 L
.59951 .59651 L
.61253 .59176 L
.62529 .58566 L
.63775 .57852 L
.64987 .57064 L
.66349 .56101 L
.67659 .55132 L
.68685 .54371 L
.69679 .53653 L
.70643 .52992 L
.7158 .52398 L
.72494 .51878 L
.73386 .51436 L
.74611 .50947 L
.7581 .50604 L
.76993 .50391 L
.78166 .50285 L
.79335 .50256 L
.80504 .5027 L
.81874 .50288 L
.83008 .50262 L
.8414 .5016 L
.85262 .49949 L
.86368 .49603 L
.87449 .49102 L
.88496 .48435 L
.89499 .47601 L
.90449 .46606 L
.91336 .45463 L
.92152 .44189 L
.9289 .42804 L
.93544 .41328 L
.94109 .39782 L
.94583 .38181 L
.94961 .36541 L
.95243 .34874 L
.95426 .33189 L
.9551 .31494 L
.95495 .29798 L
.95381 .28105 L
.95168 .26425 L
.9499 .25406 L
.94775 .24397 L
.94524 .23401 L
Mistroke
.94237 .2242 L
.93916 .21458 L
.93561 .20518 L
.92988 .19204 L
.92348 .17959 L
.91773 .16994 L
.91159 .16094 L
.90507 .15266 L
.89822 .14516 L
.89106 .1385 L
.8819 .13153 L
.87242 .12591 L
.86267 .12162 L
.85273 .11857 L
.84266 .11661 L
.83251 .11556 L
.82232 .11517 L
.81213 .11521 L
.80194 .11539 L
.78729 .1154 L
.77576 .11476 L
.76416 .11323 L
.75244 .11054 L
.74052 .10651 L
.72832 .10101 L
.71575 .09402 L
.70272 .08562 L
.68915 .07601 L
.67498 .06551 L
.66017 .05462 L
.64828 .04631 L
.63601 .03845 L
.6234 .03138 L
.61048 .02543 L
.59733 .02088 L
.584 .01794 L
.56912 .01669 L
.55728 .01721 L
.5455 .01896 L
.5338 .02182 L
.52225 .02557 L
.51085 .02998 L
.49965 .03482 L
.48865 .03981 L
.47784 .04474 L
.46724 .04938 L
.45466 .05434 L
.44231 .05837 L
.43013 .06129 L
.41807 .06302 L
Mistroke
.40606 .06355 L
.39404 .06294 L
.38198 .06134 L
.36421 .05766 L
.34616 .0532 L
.33087 .04967 L
.3154 .04701 L
.29982 .04587 L
.28422 .04679 L
.26875 .05013 L
.25356 .05601 L
.23879 .06434 L
.22457 .07483 L
.21103 .08703 L
.20042 .09806 L
.19035 .10964 L
.18086 .12152 L
.17196 .13346 L
.16364 .14529 L
.1559 .15685 L
.14871 .16805 L
.13988 .18246 L
.13197 .19602 L
.12492 .2087 L
.11869 .22055 L
.11321 .23162 L
.10844 .24201 L
.10434 .25179 L
.10087 .26105 L
.09678 .27414 L
.09395 .28654 L
.09232 .2985 L
.09187 .31026 L
.09257 .32204 L
.09445 .33408 L
.09754 .3466 L
.1019 .35986 L
.1087 .37661 L
.11752 .3952 L
.1266 .41241 L
.1374 .4314 L
.15011 .4522 L
.1649 .47457 L
.17322 .4863 L
.18212 .49813 L
.19158 .50987 L
.20162 .52129 L
.21219 .53213 L
.22327 .54213 L
.23481 .551 L
Mistroke
.25185 .56119 L
.26542 .56684 L
.27924 .57044 L
.2932 .57205 L
.30719 .57185 L
.32113 .57019 L
.33496 .56749 L
.34862 .56422 L
.3621 .56088 L
.37542 .55791 L
.38859 .55571 L
.40425 .5545 L
.4199 .5552 L
.43565 .55793 L
.45164 .56262 L
.46798 .56897 L
.48477 .57644 L
.50205 .58428 L
.51727 .59061 L
.53282 .59593 L
.54861 .59965 L
.56455 .6013 L
.58052 .60058 L
.59638 .59742 L
.61201 .59197 L
.62392 .58638 L
.63557 .57985 L
.64693 .57263 L
.65797 .56499 L
.66869 .55719 L
.67907 .54947 L
.68913 .54204 L
.70427 .53136 L
.71875 .52223 L
.73001 .51618 L
.74097 .51135 L
.7517 .5077 L
.76227 .50515 L
.77273 .50357 L
.78313 .50278 L
.7935 .50256 L
.80908 .50278 L
.82117 .50287 L
.83325 .50242 L
.84527 .50101 L
.85716 .49825 L
.86884 .49386 L
.88018 .48764 L
.88898 .48126 L
.89742 .47367 L
Mistroke
.90546 .46492 L
.91303 .45509 L
.92008 .4443 L
.92657 .43267 L
.93481 .41481 L
.94005 .40091 L
.94454 .38653 L
.94826 .37181 L
.95119 .35682 L
.95332 .34165 L
.95464 .32637 L
.95516 .31103 L
.95486 .29568 L
.95375 .28038 L
.95105 .26039 L
.94697 .24072 L
.94153 .22156 L
.93608 .20637 L
.92978 .19183 L
.92267 .17815 L
.9148 .16549 L
.90624 .15405 L
.89706 .144 L
.88735 .13548 L
.8772 .12855 L
.86669 .12323 L
.85593 .11942 L
.84498 .11698 L
.83393 .11566 L
.82168 .11517 L
.80941 .11525 L
.79716 .11545 L
.78491 .11533 L
.77263 .11445 L
.76027 .11247 L
.74773 .10911 L
.73493 .10416 L
.72177 .09752 L
.70813 .08924 L
.69061 .07708 L
.67559 .06597 L
.65984 .05438 L
.64336 .04306 L
.6262 .03285 L
.60845 .02462 L
.59026 .01911 L
.57621 .01702 L
.5621 .01684 L
.54803 .01849 L
.53408 .02174 L
Mistroke
.52032 .02627 L
.5068 .03169 L
.49356 .03757 L
.48118 .04323 L
.47988 .04382 L
Mfstroke
.025 w
.1225 .40481 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0002F1000`40O003h00OogooogooFWoo003o
OoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogoo
FWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00
ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomo
oeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol0
0?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOooo
OomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo
003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogoo
ogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYo
o`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mo
oomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJ
Ool00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003o
OoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogoo
FWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00
ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomo
oeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol0
0?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOooo
OomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo
003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogoo
ogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYo
o`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mo
oomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJ
Ool00?mooomooeYoo`00ogooogooFWoo003oOolFOol70003Ool4003oOolfOol00?mooaUoo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo0?mooc=oo`00ogoo6Goo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol0ogoo<goo003oOolIOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`3oOolcOol00?moo`eoo`H000Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Moo`D0
0?moobMoo`00ogoo6Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0
ogoo:Goo003oOolIOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3o
OolYOol00?mooaMoo`<000Eoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo0?moobUoo`00
ogoo6Goo00<007ooOol017oo10002Woo00<007ooOol0ogoo:Goo003oOol^Ool00`00Oomoo`3oOolY
Ool00?moobioo`03001oogoo0?moobUoo`00ogoo;Woo00<007ooOol0ogoo:Goo003oOol^Ool00`00
Oomoo`3oOolYOol00?moobioo`<0029oo`P7Y_ioo`00ogoo;Woo00<007ooOol067oo60NVn7oo003o
Ool^Ool00`00Oomoo`0DOol:1jH>Ool:1jKbOol00?moobioo`03001oogoo011oo`H7YQeoo`H7Y^mo
o`00ogoo;Woo00<007ooOol03Woo10NV9Goo10NVkGoo003oOol^Ool00`00Oomoo`0;Ool41jHZOol5
1jKZOol00?moobioo`03001oogoo00Qoo`@7YS1oo`@7Y^Qoo`00ogoo;Woo00<007ooOol01Goo10NV
=Woo0`NViWoo003oOol^Ool00`00Oomoo`03Ool31jHkOol31jKTOol00?moobioo`<000<7YT1oo`<7
Y^9oo`00ogoo;Woo00@000NV1jH7YTAoo`<7Y^1oo`00ogoo;Goo0`NVB7oo0`NVgWoo003oOol[Ool3
1jH00`00Oomoo`19Ool31jKLOol00?moobUoo`<7YP9oo`03001oogoo04]oo`87Y]]oo`00ogoo9goo
0`NV17oo00<007ooOol0C7oo0`NVfGoo003oOolTOol41jH6Ool00`00Oomoo`1>Ool21jKHOol00?mo
ob9oo`@7YPQoo`03001oogoo051oo`87Y]Ioo`00]7oo30NVGgoo0`NV2goo00<007ooOol0DGoo0`NV
e7oo002_Ool81jH8Ool91jIDOol31jH>Ool3001COol21jKCOol00:Yoo`D7YQQoo`L7YT]oo`@7YQ1o
o`03001oogoo05Aoo`<7Y]5oo`00YWoo1@NV87oo1`NVAGoo0`NV4goo00<007ooOol0EWoo0PNVd7oo
002TOol31jHYOol51jHoOol31jHFOol00`00Oomoo`1GOol31jK>Ool00:5oo`@7YRmoo`D7YSQoo`@7
YQQoo`03001oogoo05Uoo`87Y/eoo`00Wgoo0`NV=Woo1@NV<Goo10NV6goo00<007ooOol0FWoo0PNV
c7oo002MOol31jHlOol61jHXOol61jHMOol00`00Oomoo`1KOol21jK;Ool009]oo`<7YT=oo`H7YQmo
o`P7YQmoo`03001oogoo05eoo`031jIoogoo0<Qoo`00VWoo0PNVBGoo20NV57oo20NV97oo0`00GWoo
0PNVb7oo002HOol21jIAOolI1jHYOol00`00Oomoo`0OOol<;N<dOol21jK7Ool009Moo`87YYAoo`03
001oogoo01Yoo`P]h`Eoo`P]hc9oo`87Y/Eoo`00UGoo0PNVUWoo00<007ooOol05Woo1BgS4goo1bgS
;Goo0PNVa7oo002COol31jJGOol00`00Oomoo`0COol3;N<LOol5;N</Ool21jK3Ool0099oo`87YYUo
o`03001oogoo00moo`@]hb=oo`<]hb]oo`87Y/9oo`00TGoo0PNVO7oo00<007ooOol01Goo0P001Woo
10002Woo00<007ooOol037oo12gS:Goo0bgS:Woo0PNV`7oo002?Ool31jImOol00`00Oomoo`05Ool2
0005Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool3;N<^Ool3;N<YOol21jJoOol0
08ioo`87YWmoo`03001oogoo015oo`03001oogoo00Moo`03001oogoo00Qoo`<]hc9oo`<]hbQoo`<7
Y[eoo`00SGoo0PNVPGoo00<007ooOol047oo00<007ooOol01goo1@0017oo0bgS=Woo0bgS:7oo0PNV
_7oo002<Ool21jIeOol60007Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`04Ool3;N<j
Ool2;N<XOol31jJjOol008]oo`031jIoogoo089oo`03001oogoo00aoo`@000Yoo`03001oogoo009o
o`8]hcioo`<]hbQoo`87Y[Uoo`00RWoo00<7YWooOol0Q7oo00<007ooOol02goo00<007ooOol02goo
00<007ooOol00RgS@Woo0bgS9goo0PNV^7oo0029Ool00`NVOomoo`20Ool00`00Oomoo`02Ool00`00
Oomoo`0;Ool00`00Oomoo`0;Ool00`00;N<]h`16Ool2;N<XOol21jJfOol008Qoo`031jIoogoo085o
o`H000eoo`D000Qoo`8]hdYoo`8]hbQoo`031jIoogoo0;=oo`00Qgoo00<7YWooOol0X7oo0RgS00=o
o`00Ool0BWoo0RgS:7oo0PNV/goo0026Ool00`NVOomoo`2OOol2;N<3Ool00`00Oomoo`1;Ool00bgS
Oomoo`0VOol21jJbOol008Eoo`031jIoogoo09ioo`<]h`Aoo`03001oogoo04aoo`8]hbQoo`87Y[1o
o`00Q7oo00<7YWooOol0WWoo0RgS1Woo0`00CGoo0RgS:7oo0`NV[Woo0023Ool00`NVOomoo`2MOol2
;N<8Ool00`00Oomoo`1?Ool00bgSOomoo`0WOol21jJ]Ool0089oo`031jIoogoo09aoo`8]h`Yoo`03
001oogoo051oo`03;N=oogoo02Qoo`87YZ]oo`00PGoo00<7YWooOol0Vgoo0bgS2goo00<007ooOol0
DGoo0RgS:Woo0PNVZGoo0020Ool21jH`OolA;N=JOol3;N<=Ool00`00Oomoo`1BOol2;N<ZOol31jJW
Ool007moo`87YRaoo`L]h`ioo`L]he=oo`8]h`moo`03001oogoo05Aoo`03;N=oogoo02Uoo`<7YZEo
o`00OWoo0PNV:7oo1RgS6goo1BgSC7oo0bgS47oo00<007ooOol0EGoo00<]hgooOol0:Woo0`NVXgoo
001mOol21jHWOol4;N<TOol4;N=6Ool3;N<BOol00`00Oomoo`1FOol00bgSOomoo`0[Ool31jJQOol0
07eoo`031jIoogoo02Aoo`<]hbUoo`D]hd5oo`<]haAoo`03001oogoo05Moo`03;N=oogoo02aoo`@7
YYioo`00O7oo00<7YWooOol08goo0bgS;Woo1BgS>goo0bgS5goo0`00F7oo0RgS;Woo1@NVVgoo001k
Ool00`NVOomoo`0ROol3;N<dOol4;N<fOol3;N<IOol00`00Oomoo`1IOol2;N<_Ool61jJHOol007Yo
o`87YR=oo`8]hcQoo`@]hc9oo`<]ha]oo`03001oogoo05Yoo`8]hc9oo`H7YYAoo`00NGoo0PNV8Woo
0RgS?Woo12gS;7oo0bgS7Goo00<007ooOol0Fgoo0RgS=Goo1`NVSgoo001hOol21jHROol2;N=1Ool6
;N<UOol4;N<OOol00`00Oomoo`1LOol2;N<iOolZ1jIWOol007Moo`87YR5oo`8]hdMoo`H]haeoo`D]
hb9oo`03001oogoo05eoo`8]heaoo``7YV5oo`00Mgoo00<7YWooOol07goo0RgSCGoo1RgS4goo1bgS
9Goo00<007ooOol0GWoo0RgSIWoo1@NVGGoo001fOol00`NVOomoo`0OOol2;N=AOol:;N<4Ool<;N<X
Ool00`00Oomoo`1OOol2;N=XOol51jIJOol007Eoo`031jIoogoo01moo`03;N=oogoo05Qoo`T]hc9o
o`03001oogoo065oo`03;N=oogoo06Qoo`@7YUQoo`00M7oo00<7YWooOol07goo00<]hgooOol0U7oo
0`00HWoo00<]hgooOol0Jgoo0`NVEGoo001dOol00`NVOomoo`0MOol2;N>GOol00`00Oomoo`1SOol0
0bgSOomoo`1/Ool31jICOol007=oo`031jIoogoo01eoo`8]hiQoo`03001oogoo06Aoo`03;N=oogoo
06eoo`87YU9oo`00LWoo00<7YWooOol07Goo0RgSVGoo00<007ooOol0IGoo00<]hgooOol0KGoo0`NV
D7oo001aOol00`NVOomoo`0MOol2;N>JOol00`00Oomoo`1VOol00bgSOomoo`1^Ool31jI>Ool0071o
o`87YQioo`8]hi]oo`03001oogoo06Moo`03;N=oogoo06moo`87YTeoo`00Kgoo0PNV7Woo0RgSW7oo
00<007ooOol0J7oo00<]hgooOol0Kgoo0`NVBgoo001_Ool00`NVOomoo`0MOol00bgSOomoo`2KOol0
0`00Oomoo`1YOol00bgSOomoo`1`Ool21jI:Ool006ioo`87YQioo`03;N=oogoo09aoo`03001oogoo
06Yoo`03;N=oogoo071oo`87YTUoo`00KGoo0PNV7Woo00<]hgooOol0WGoo0`007Woo3QPY?goo00<]
hgooOol0LGoo0PNVAgoo001/Ool21jHNOol00bgSOomoo`2NOol00`00Oomoo`0JOol762T8Ool762Tl
Ool00bgSOomoo`1aOol21jI6Ool006aoo`031jIoogoo01aoo`8]hj1oo`03001oogoo01Moo`@H:A=o
o`@H:C]oo`8]hg9oo`87YTEoo`00Jgoo0PNV7Goo0RgSXGoo00<007ooOol05Goo0aPY6Goo0aPY>Woo
0RgSLWoo0PNVA7oo001ZOol21jHNOol00bgSOomoo`2POol00`00Oomoo`0COol262TNOol462ThOol2
;N=bOol00`NVOomoo`12Ool006Yoo`031jIoogoo01aoo`03;N=oogoo09=oo`@000Yoo`03001oogoo
015oo`8H:B9oo`@H:CMoo`8]hg9oo`031jIoogoo045oo`00JGoo0PNV7Goo0RgSU7oo00<007ooOol0
0Woo00<007ooOol01goo00<007ooOol03goo0aPY9Goo0aPY=goo0RgSLGoo0PNV@Woo001YOol00`NV
Oomoo`0KOol2;N>JOol00`00Oomoo`07Ool00`00Oomoo`0=Ool362TYOol362TfOol2;N=aOol21jI1
Ool006Qoo`031jIoogoo01aoo`03;N=oogoo09Uoo`03001oogoo00Moo`03001oogoo00]oo`<H:Beo
o`8H:CIoo`8]hg5oo`87YT1oo`00Igoo0PNV7Goo00<]hgooOol0S7oo1P0027oo00<007ooOol01goo
1@0027oo0QPY<7oo0QPY=Woo0RgSLGoo0PNV?goo001WOol00`NVOomoo`0KOol00bgSOomoo`2GOol4
000:Ool00`00Oomoo`08Ool362TcOol00aPYOomoo`0dOol2;N=aOol21jHnOol006Ioo`031jIoogoo
01]oo`8]hiUoo`03001oogoo00]oo`03001oogoo00Moo`8H:CIoo`8H:CEoo`8]hg5oo`87YSeoo`00
IGoo0PNV7Goo00<]hgooOol0V7oo00<007ooOol02goo00<007ooOol01Woo0QPY>7oo0QPY=Goo0RgS
L7oo0PNV?Goo001UOol00`NVOomoo`0KOol00bgSOomoo`2IOol50009Ool00`00Oomoo`04Ool262Tk
Ool262TeOol2;N=`Ool21jHlOol006Aoo`87YQaoo`8]hjUoo`03001oogoo00=oo`8H:Ceoo`8H:CEo
o`8]hg1oo`87YS]oo`00I7oo00<7YWooOol06Woo0RgSZWoo00<007ooOol00Woo00<H:GooOol0?Woo
0QPY=Goo0RgSL7oo00<7YWooOol0>Goo001SOol21jHLOol00bgSOomoo`2YOol01@00Oomoogoo62T0
@Woo0QPY=Goo0RgSL7oo00<7YWooOol0>7oo001ROol21jHLOol2;N>[Ool01000OolH:APYA7oo0QPY
=Woo00<]hgooOol0KGoo0PNV>Goo001ROol00`NVOomoo`0KOol00bgSOomoo`2ZOol00`0062TH:@16
Ool262TfOol00bgSOomoo`1]Ool00`NVOomoo`0gOol0065oo`87YQaoo`8]hjaoo`8H:DUoo`0362Uo
ogoo03Aoo`8]hfeoo`87YSQoo`00H7oo0PNV7Goo00<]hgooOol0ZWoo0QPYBWoo0QPY=goo0RgSK7oo
00<7YWooOol0=Woo001POol00`NVOomoo`0KOol00bgSOomoo`2ZOol262T00`00Oomoo`19Ool262Tg
Ool2;N=[Ool21jHgOol005moo`87YQeoo`03;N=oogoo0:Uoo`8H:@03Ool007oo04]oo`8H:CMoo`8]
hf]oo`031jIoogoo03Eoo`00Ggoo00<7YWooOol06goo00<]hgooOol0ZGoo0QPY0Woo00<007ooOol0
Bgoo00<H:GooOol0=Woo0bgSJWoo00<7YWooOol0=7oo001NOol21jHMOol00bgSOomoo`2XOol00aPY
Oomoo`02Ool00`00Oomoo`1<Ool00aPYOomoo`0gOol2;N=YOol21jHeOol005ioo`031jIoogoo01]o
o`03;N=oogoo0:Qoo`0362Uoogoo00=oo`03001oogoo04aoo`8H:CUoo`<]hfQoo`031jIoogoo03=o
o`00GGoo00<7YWooOol077oo00<]hgooOol0Ygoo00<H:GooOol017oo00<007ooOol0CGoo0QPY>Woo
0RgSIgoo0PNV=7oo001LOol21jHMOol00bgSOomoo`2WOol00aPYOomoo`05Ool3001>Ool262TkOol2
;N=VOol00`NVOomoo`0bOol005aoo`031jIoogoo01aoo`03;N=oogoo0:Ioo`0362Uoogoo00Ioo`03
001oogoo04moo`0362Uoogoo03Yoo`<]hfAoo`87YS=oo`00Fgoo00<7YWooOol077oo00<]hgooOol0
YWoo0QPY27oo00<007ooOol0Cgoo0QPY?Goo0bgSHgoo00<7YWooOol0<Goo001JOol21jHNOol00bgS
Oomoo`2UOol262T9Ool00`00Oomoo`1@Ool00aPYOomoo`0mOol4;N=POol21jHbOol005Yoo`031jIo
ogoo01aoo`03;N=oogoo0:Eoo`8H:@Yoo`03001oogoo051oo`8H:D1oo`D]heioo`031jIoogoo031o
o`00FGoo0PNV7Woo00<]hgooOol0Y7oo0QPY2goo00<007ooOol0DGoo0QPY@goo1BgSFWoo0PNV<Goo
001IOol00`NVOomoo`0LOol2;N<kOol:62UPOol262T<Ool00`00Oomoo`1BOol00aPYOomoo`15Ool:
;N<6OolD;N<hOol00`NVOomoo`0_Ool005Qoo`87YQioo`03;N=oogoo03Ioo`HH:@Ioo`HH:E]oo`8H
:@eoo`03001oogoo059oo`8H:Dmoo`/]h`eoo`P]hc=oo`87YS1oo`00F7oo00<7YWooOol077oo0RgS
=Goo11PY3goo1APYEgoo0QPY3Woo00<007ooOol0Dgoo0QPYJgoo1bgS<7oo00<7YWooOol0;Woo001G
Ool21jHNOol00bgSOomoo`0bOol462TEOol362UDOol262T?Ool3001DOol00aPYOomoo`1^Ool4;N<^
Ool21jH_Ool005Moo`031jIoogoo01aoo`8]hc9oo`<H:AYoo`@H:E1oo`8H:A1oo`03001oogoo05Ao
o`8H:G9oo`<]hbaoo`87YRmoo`00EWoo00<7YWooOol07Goo00<]hgooOol0<7oo0QPY7Woo11PYCGoo
0QPY4Goo00<007ooOol0EGoo00<H:GooOol0LWoo0bgS:goo0PNV;Woo001FOol00`NVOomoo`0LOol2
;N<aOol00aPYOomoo`0QOol362U:Ool262TBOol00`00Oomoo`1EOol262UeOol3;N<YOol21jH^Ool0
05Eoo`031jIoogoo01eoo`03;N=oogoo02moo`0362Uoogoo02Aoo`8H:DQoo`8H:A=oo`03001oogoo
05Ioo`8H:GIoo`8]hbUoo`031jIoogoo02aoo`00E7oo0PNV7Woo0RgS<7oo00<H:GooOol09goo0QPY
AGoo0QPY57oo00<007ooOol0Egoo00<H:GooOol0MGoo0RgS:7oo0PNV;Goo001DOol00`NVOomoo`0M
Ool00bgSOomoo`0]Ool262T[Ool362U2Ool262TEOol00`00Oomoo`1GOol262UgOol3;N<VOol21jH]
Ool005=oo`87YQioo`8]hbioo`8H:Bioo`8H:D1oo`8H:AIoo`03001oogoo05Qoo`0362Uoogoo07Mo
o`8]hbIoo`031jIoogoo02]oo`00Dgoo00<7YWooOol07Goo00<]hgooOol0;7oo0QPY<7oo0aPY?Goo
0QPY5goo00<007ooOol0F7oo0QPYNGoo0RgS9Goo0PNV;7oo001BOol21jHOOol00bgSOomoo`0[Ool2
62TcOol262TkOol262THOol3001IOol00aPYOomoo`1hOol2;N<TOol21jH/Ool0059oo`031jIoogoo
01eoo`8]hbeoo`0362Uoogoo03=oo`8H:CUoo`8H:AUoo`03001oogoo05Uoo`0362Uoogoo07Uoo`03
;N=oogoo02=oo`031jIoogoo02Yoo`00DGoo0PNV7goo0RgS;7oo00<H:GooOol0=Goo0aPY=Woo0QPY
6Woo00<007ooOol0FWoo00<H:GooOol0NGoo00<]hgooOol08Woo0PNV:goo001@Ool21jHPOol00bgS
Oomoo`0ZOol262TiOol262TdOol262TKOol00`00Oomoo`1JOol00aPYOomoo`1iOol2;N<TOol00`NV
Oomoo`0YOol0051oo`87YQmoo`8]hbaoo`0362Uoogoo03Uoo`<H:C5oo`8H:Aaoo`03001oogoo05]o
o`0362Uoogoo07Uoo`8]hb=oo`031jIoogoo02Uoo`00Cgoo0PNV87oo0RgS:goo00<H:GooOol0?7oo
0QPY;Goo0P000QPY0P001Goo0P001Woo10002Woo00<007ooOol0Fgoo00<H:GooOol0NWoo0RgS8Woo
0PNV:Woo001?Ool21jHPOol00bgSOomoo`0YOol262ToOol262T/Ool00`0062TH:@02Ool00`00Oomo
o`03Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`1LOol00aPYOomoo`1jOol0
0bgSOomoo`0QOol00`NVOomoo`0XOol004ioo`87YR1oo`8]hb]oo`0362Uoogoo03moo`8H:B]oo`8H
:AEoo`03001oogoo00Moo`03001oogoo05aoo`0362Uoogoo07Yoo`8]hb9oo`031jIoogoo02Qoo`00
CWoo0PNV87oo0RgS:Woo00<H:GooOol0@Woo0QPY:7oo0QPY00=oo`00Ool04goo00<007ooOol01goo
1@00FWoo0QPYO7oo0RgS8Goo0PNV:Goo001>Ool00`NVOomoo`0OOol00bgSOomoo`0XOol262U5Ool2
62TOOol600000goo62TH:@03Ool00`00Oomoo`0AOol00`00Oomoo`07Ool00`00Oomoo`1MOol00aPY
Oomoo`1kOol00bgSOomoo`0POol00`NVOomoo`0WOol004eoo`87YR1oo`8]hbYoo`0362Uoogoo04Io
o`8H:B=oo`8H:@Eoo`03001oogoo00aoo`@000Yoo`03001oogoo05eoo`8H:Gaoo`8]hb5oo`031jIo
ogoo02Moo`00CGoo00<7YWooOol07goo0RgS:Goo0QPYBGoo0aPY87oo00DH:GooOomoo`0000Aoo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo05ioo`0362Uoogoo07]oo`03;N=oogoo01moo`87
YRQoo`00C7oo0PNV8Goo00<]hgooOol0:7oo00<H:GooOol0BWoo0QPY7Goo0QPY17oo00<007ooOol0
0Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol0GWoo0QPYO7oo0RgS87oo0PNV:7oo001<
Ool00`NVOomoo`0OOol2;N<YOol262U=Ool262TKOol262T6Ool4000>Ool50009Ool00`00Oomoo`1O
Ool00aPYOomoo`1kOol00bgSOomoo`0OOol00`NVOomoo`0VOol004aoo`031jIoogoo01moo`8]hbUo
o`0362Uoogoo04ioo`8H:AMoo`8H:BQoo`03001oogoo05moo`8H:Gaoo`8]hb1oo`031jIoogoo02Io
o`00Bgoo0PNV8Goo0RgS:7oo0QPYDGoo0aPY4goo0aPY:Goo00<007ooOol0Ggoo0QPYOGoo00<]hgoo
Ool07Woo0PNV9goo001;Ool00`NVOomoo`0POol00bgSOomoo`0WOol262UCOol362T?Ool362T[Ool0
0`00Oomoo`1POol00aPYOomoo`1kOol2;N<OOol21jHWOol004Yoo`87YR5oo`8]hbQoo`8H:EMoo`<H
:@Uoo`@H:Beoo`<0061oo`0362Uoogoo07aoo`03;N=oogoo01ioo`031jIoogoo02Eoo`00BWoo00<7
YWooOol087oo0RgS:7oo0QPYFWoo2QPY<7oo00<007ooOol0H7oo0QPYOGoo0RgS7goo00<7YWooOol0
9Goo0019Ool21jHROol2;N<XOol262VDOol00`00Oomoo`1QOol00aPYOomoo`1lOol00bgSOomoo`0M
Ool00`NVOomoo`0UOol004Uoo`031jIoogoo025oo`03;N=oogoo02Ioo`8H:IEoo`03001oogoo065o
o`0362Uoogoo07aoo`03;N=oogoo01eoo`87YRIoo`00BGoo00<7YWooOol08Goo00<]hgooOol09Woo
0QPY77oo2dV7KWoo00<007ooOol0HGoo0QPYOGoo0RgS7Woo0PNV9Woo0018Ool21jHSOol00bgSOomo
o`0VOol00aPYOomoo`0IOol4BHL8Ool3BHM/Ool00`00Oomoo`1QOol262UnOol00bgSOomoo`0LOol2
1jHVOol004Qoo`031jIoogoo025oo`8]hbQoo`0362Uoogoo01Moo`=9Q`eoo`=9QfYoo`03001oogoo
069oo`0362Uoogoo07aoo`8]haioo`031jIoogoo02Aoo`00Agoo0PNV8goo00<]hgooOol09Woo00<H
:GooOol05goo0TV74Goo0dV7J7oo00<007ooOol0HWoo00<H:GooOol0O7oo0RgS7Woo00<7YWooOol0
97oo0017Ool21jHSOol00bgSOomoo`0VOol00aPYOomoo`0FOol2BHLDOol2BHMWOol00`00Oomoo`1R
Ool262UnOol00bgSOomoo`0LOol21jHUOol004Moo`031jIoogoo029oo`03;N=oogoo02Ioo`0362Uo
ogoo01Eoo`99QaIoo`99QfIoo`<0069oo`8H:Gioo`8]haeoo`87YREoo`00AWoo0PNV8goo0RgS9goo
0QPY5Woo0TV767oo0TV7IGoo00<007ooOol0Hgoo00<H:GooOol0O7oo0RgS7Goo0PNV9Goo0016Ool2
1jHSOol2;N<WOol00aPYOomoo`0EOol00dV7Oomoo`0HOol2BHMTOol00`00Oomoo`1SOol262UnOol0
0bgSOomoo`0LOol00`NVOomoo`0SOol004Ioo`031jIoogoo029oo`8]hbMoo`0362Uoogoo01Aoo`03
BHMoogoo01Yoo`99Qf=oo`03001oogoo06=oo`8H:Gioo`03;N=oogoo01aoo`031jIoogoo02=oo`00
AWoo00<7YWooOol08Woo00<]hgooOol09Goo0QPY5Goo0TV77Goo0TV7HWoo00<007ooOol0Hgoo0QPY
OWoo0RgS7Goo00<7YWooOol08goo0015Ool21jHTOol00bgSOomoo`0UOol262TEOol00dV7Oomoo`0M
Ool2BHMQOol00`00Oomoo`1TOol00aPYOomoo`1lOol2;N<MOol00`NVOomoo`0SOol004Eoo`031jIo
ogoo02=oo`03;N=oogoo02Eoo`8H:AAoo`99Qb1oo`03BHMoogoo05moo`03001oogoo06Aoo`8H:Gio
o`03;N=oogoo01]oo`87YRAoo`00AGoo00<7YWooOol08Woo0RgS9goo00<H:GooOol04goo00=9Qgoo
Ool07goo0TV7H7oo00<007ooOol0I7oo0QPYOWoo00<]hgooOol06goo0PNV97oo000:Ool70003Ool4
000]Ool00`NVOomoo`08Ool00`00Oomoo`05Ool20006Ool40006Ool2;N<VOol262T;Ool40005Ool2
BHLROol00dV7Oomoo`0>Ool60005Ool20006Ool4000iOol00`00Oomoo`0iOol60005Ool20006Ool4
000DOol262TUOol4000mOol00`00Oomoo`05Ool20006Ool40004Ool00bgSOomoo`0KOol21jHAOol7
0003Ool40005Ool000eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Uoo`87YPYoo`03
001oogoo00Eoo`8000Eoo`03001oogoo009oo`03001oogoo00=oo`8]hbIoo`8H:@Yoo`03001oogoo
009oo`03001oogoo009oo`03BHMoogoo025oo`99Q`moo`03001oogoo009oo`03001oogoo00=oo`80
00Eoo`03001oogoo009oo`03001oogoo03Ioo`<003Uoo`03001oogoo009oo`03001oogoo00=oo`80
00Eoo`03001oogoo009oo`03001oogoo019oo`0362Uoogoo029oo`03001oogoo009oo`03001oogoo
03Yoo`03001oogoo00Eoo`8000Eoo`03001oogoo009oo`04001oogooOol2;N<LOol21jHDOol00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool000eoo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo02Uoo`031jIoogoo00Uoo`03001oogoo015oo`03001oogoo00=oo`03;N=oogoo02Eo
o`8H:@moo`04001oogooOol2BHLTOol2BHL?Ool00`00Oomoo`0COol00`00Oomoo`0fOol00`00Oomo
o`0jOol00`00Oomoo`0COol00`00Oomoo`0BOol00aPYOomoo`0WOol00`00Oomoo`0jOol00`00Oomo
o`0AOol01000Oomoogoo0RgS7Goo00<7YWooOol04Woo00<007ooOol00goo00<007ooOol00Woo00<0
07ooOol00Woo000=Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0YOol00`NVOomoo`0:
Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00bgSOomoo`0UOol00aPYOomoo`0>Ool01000Oomoogoo
0TV797oo0TV747oo00<007ooOol04Woo00<007ooOol0=Woo00<007ooOol0>goo00<007ooOol04Woo
00<007ooOol04Woo0QPY:7oo00<007ooOol0>goo00<007ooOol047oo00<007ooOol00Woo00<]hgoo
Ool06goo00<7YWooOol04Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00000goo
000000040006Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0XOol21jH50007Ool00`00
Oomoo`0@Ool00`00Oomoo`03Ool00bgSOomoo`0UOol00aPYOomoo`060008Ool01@00OomoogooBHL0
9Woo0TV717oo1P001Woo00<007ooOol04Goo00<007ooOol0=Woo00<007ooOol0?7oo00<007ooOol0
4Goo00<007ooOol04Woo0QPY:7oo00<007ooOol0>goo00<007ooOol047oo00<007ooOol00Woo00<]
hgooOol06goo00<7YWooOol04Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo000=
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0XOol21jH<Ool00`00Oomoo`0<Ool40006
Ool00bgSOomoo`0UOol00aPYOomoo`0:Ool40003Ool2BHLVOol2BHLAOol00`00Oomoo`0<Ool4000i
Ool00`00Oomoo`0mOol00`00Oomoo`0<Ool4000EOol262TTOol4000nOol00`00Oomoo`0<Ool40005
Ool00bgSOomoo`0KOol00`NVOomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool000eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Qoo`87YPeoo`03001oogoo00]o
o`03001oogoo00Moo`03;N=oogoo02Eoo`0362Uoogoo00Yoo`03001oogoo00Aoo`99QbMoo`99Q`ao
o`03001oogoo009oo`03001oogoo00]oo`03001oogoo03Yoo`03001oogoo03Uoo`03001oogoo009o
o`03001oogoo00]oo`03001oogoo01Ioo`8H:BAoo`03001oogoo041oo`03001oogoo00]oo`03001o
ogoo00Ioo`03;N=oogoo01]oo`031jIoogoo019oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo009oo`002goo0`001Goo00<007ooOol00Woo00<007ooOol0:7oo00<7YWooOol01goo00<007oo
Ool00Woo00<007ooOol02goo00<007ooOol01Woo0RgS9goo00<H:GooOol02Woo00<007ooOol017oo
00=9QgooOol09Woo0TV737oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol0>Woo00<007oo
Ool0>Goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol05Woo0QPY97oo00<007ooOol0>goo
00<007ooOol00Woo00<007ooOol02goo00<007ooOol01Woo00<]hgooOol06goo00<7YWooOol047oo
0`001Goo00<007ooOol00Woo00<007ooOol00Woo000=Ool00`00Oomoo`04Ool4000ZOol21jH9Ool6
000=Ool50004Ool00bgSOomoo`0UOol262T<Ool50002Ool00dV7Oomoo`0VOol2BHL=Ool4000>Ool5
000hOol00`00Oomoo`0jOol4000>Ool5000EOol00aPYOomoo`0ROol5000iOol6000=Ool50004Ool0
0bgSOomoo`0KOol00`NVOomoo`0BOol00`00Oomoo`04Ool40005Ool0049oo`87YREoo`03;N=oogoo
02Eoo`8H:A=oo`03BHMoogoo02Moo`03BHMoogoo05Yoo`03001oogoo06Ioo`0362Uoogoo07aoo`8]
haaoo`87YR=oo`00@Woo0PNV9Goo00<]hgooOol09Goo0QPY4Woo0TV7:Goo0TV7Fgoo0`00IWoo00<H
:GooOol0OGoo00<]hgooOol06Woo0PNV8goo0012Ool21jHUOol00bgSOomoo`0UOol262TBOol00dV7
Oomoo`0XOol2BHMKOol00`00Oomoo`1VOol00aPYOomoo`1mOol00bgSOomoo`0JOol21jHSOol0049o
o`87YREoo`03;N=oogoo02Eoo`8H:A9oo`03BHMoogoo02Qoo`99Qe]oo`03001oogoo06Ioo`0362Uo
ogoo07eoo`03;N=oogoo01Yoo`87YR=oo`00@Woo00<7YWooOol097oo00<]hgooOol09Goo00<H:Goo
Ool04Goo00=9QgooOol0:Goo00=9QgooOol0FGoo00<007ooOol0IWoo00<H:GooOol0OGoo00<]hgoo
Ool06Woo0PNV8goo0012Ool00`NVOomoo`0TOol00bgSOomoo`0UOol00aPYOomoo`0AOol00dV7Oomo
o`0YOol00dV7Oomoo`1IOol00`00Oomoo`1VOol00aPYOomoo`1mOol00bgSOomoo`0JOol21jHSOol0
049oo`031jIoogoo02Aoo`03;N=oogoo02Eoo`0362Uoogoo015oo`03BHMoogoo02Uoo`03BHMoogoo
05Uoo`03001oogoo06Ioo`0362Uoogoo07eoo`03;N=oogoo01Yoo`87YR=oo`00@Woo00<7YWooOol0
97oo00<]hgooOol09Goo00<H:GooOol04Goo00=9QgooOol0:Goo00=9QgooOol0FGoo00<007ooOol0
IWoo00<H:GooOol0OGoo00<]hgooOol06Woo0PNV8goo0012Ool00`NVOomoo`0TOol00bgSOomoo`0U
Ool00aPYOomoo`0AOol00dV7Oomoo`0YOol2BHMJOol00`00Oomoo`1VOol00aPYOomoo`1mOol00bgS
Oomoo`0JOol21jHSOol0049oo`031jIoogoo02Aoo`03;N=oogoo02Eoo`0362Uoogoo015oo`03BHMo
ogoo02Uoo`99QeYoo`03001oogoo06Ioo`0362Uoogoo07eoo`03;N=oogoo01]oo`031jIoogoo025o
o`003Goo=@0000<7YP000000900000<]h`0000009@0000<H:@0000004@0000=9Q`000000:P0000=9
Q`000000`@0000<H:@000000O@0000<]h`0000006`0000<7YP0000005`002Woo000=Ool00`00Oomo
o`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`NVOomoo`02Ool00`00Oomo
o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00bgSOomoo`06Ool00`00Oomoo`0;Ool00`00Oomo
o`0<Ool00`00OolH:@0;Ool00`00Oomoo`05Ool00dV7Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomo
o`0;Ool00`00Oomoo`07Ool00dV7Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomo
o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomo
o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomo
o`0;Ool01@00Oomoogoo62T02Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo00<0
07ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo00<0
07oo;N<02goo00<007ooOol037oo00@007ooOol7YPYoo`03001oogoo00]oo`03001oogoo00Qoo`00
3Goo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol01goo00<7YWooOol0
0Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol00goo00<]hgooOol01Woo00<007ooOol0
2goo00<007ooOol037oo00<007oo62T02goo00<007ooOol01Goo00=9QgooOol017oo00<007ooOol0
2goo00<007ooOol02goo00<007ooOol01Woo0TV717oo00<007ooOol02goo00<007ooOol037oo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol037oo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol037oo00<0
07ooOol02goo00D007ooOomooaPY00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00ao
o`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00ao
o`03001oobgS00]oo`03001oogoo00aoo`04001oogoo1jH:Ool00`00Oomoo`0;Ool00`00Oomoo`08
Ool000eoo`03001oogoo039oo`031jIoogoo011oo`03001oogoo015oo`03;N=oogoo02Eoo`0362Uo
ogoo00Uoo`03001oogoo00Eoo`03BHMoogoo02Uoo`99Qa9oo`03001oogoo04Eoo`03001oogoo04Eo
o`03001oogoo01ioo`0362Uoogoo02Aoo`03001oogoo04Eoo`03001oogoo00ioo`03;N=oogoo01]o
o`031jIoogoo01Ioo`03001oogoo00Qoo`003Goo00<007ooOol0<Woo00<7YWooOol047oo00<007oo
Ool04Goo00<]hgooOol09Goo00<H:GooOol02Goo00<007ooOol01Goo00=9QgooOol0:Goo0TV74Woo
00<007ooOol0AGoo00<007ooOol0AGoo00<007ooOol07Woo00<H:GooOol097oo00<007ooOol0AGoo
00<007ooOol03Woo00<]hgooOol06goo00<7YWooOol05Woo00<007ooOol027oo0012Ool00`NVOomo
o`0TOol00bgSOomoo`0UOol00aPYOomoo`0AOol00dV7Oomoo`0YOol00dV7Oomoo`1IOol00`00Oomo
o`1VOol00aPYOomoo`1mOol00bgSOomoo`0KOol00`NVOomoo`0QOol0049oo`031jIoogoo02Aoo`03
;N=oogoo02Eoo`0362Uoogoo015oo`03BHMoogoo02Uoo`03BHMoogoo05Uoo`03001oogoo06Ioo`03
62Uoogoo07eoo`03;N=oogoo01Yoo`87YR=oo`00@Woo00<7YWooOol097oo00<]hgooOol09Goo00<H
:GooOol04Goo00=9QgooOol0:7oo0TV7Fgoo00<007ooOol0IWoo00<H:GooOol0OGoo00<]hgooOol0
6Woo0PNV8goo0012Ool00`NVOomoo`0TOol00bgSOomoo`0UOol262TBOol00dV7Oomoo`0XOol2BHMK
Ool00`00Oomoo`1VOol00aPYOomoo`1mOol00bgSOomoo`0JOol21jHSOol0049oo`87YREoo`8]hbIo
o`8H:A9oo`99QbUoo`99Qe]oo`<006Ioo`0362Uoogoo07eoo`03;N=oogoo01Yoo`87YR=oo`00@Woo
0PNV9Goo0RgS9Woo0QPY4goo00=9QgooOol09goo00=9QgooOol0FWoo00<007ooOol0IWoo00<H:Goo
Ool0O7oo0RgS77oo0PNV8goo0012Ool21jHUOol2;N<WOol00aPYOomoo`0AOol00dV7Oomoo`0VOol2
BHMLOol00`00Oomoo`1VOol00aPYOomoo`1lOol2;N<LOol00`NVOomoo`0ROol004=oo`031jIoogoo
02=oo`8]hbMoo`0362Uoogoo015oo`03BHMoogoo02Ioo`99Qeaoo`03001oogoo06Ioo`0362Uoogoo
07aoo`8]haaoo`031jIoogoo029oo`00@goo0PNV9Goo00<]hgooOol09Goo00<H:GooOol04Goo0TV7
9goo00=9QgooOol0Fgoo00<007ooOol0IWoo00<H:GooOol0O7oo00<]hgooOol06goo00<7YWooOol0
8Woo0013Ool21jHUOol00bgSOomoo`0UOol00aPYOomoo`0AOol2BHLVOol2BHMMOol00`00Oomoo`1V
Ool00aPYOomoo`1lOol00bgSOomoo`0KOol00`NVOomoo`0ROol004=oo`87YREoo`03;N=oogoo02Eo
o`8H:A=oo`03BHMoogoo02Aoo`99Qeeoo`03001oogoo06Eoo`8H:Gioo`03;N=oogoo01]oo`031jIo
ogoo029oo`00@goo0PNV9Goo00<]hgooOol09Goo0QPY4goo0TV797oo0TV7GWoo00<007ooOol0IGoo
0QPYOWoo00<]hgooOol06goo00<7YWooOol08Woo0014Ool00`NVOomoo`0SOol00bgSOomoo`0UOol2
62TCOol2BHLTOol2BHMNOol00`00Oomoo`1UOol00aPYOomoo`1lOol2;N<MOol00`NVOomoo`0ROol0
04Aoo`031jIoogoo02=oo`8]hbMoo`0362Uoogoo019oo`03BHMoogoo025oo`99Qemoo`<006Eoo`03
62Uoogoo07aoo`8]haaoo`87YRAoo`00A7oo00<7YWooOol08goo0RgS9goo00<H:GooOol04Woo0TV7
8Woo00=9QgooOol0GWoo00<007ooOol0IGoo00<H:GooOol0O7oo00<]hgooOol06goo0PNV97oo0014
Ool21jHTOol2;N<WOol00aPYOomoo`0COol00dV7Oomoo`0HOol6BHL00gooBHM9Q`1POol00`00Oomo
o`1TOol262UnOol00bgSOomoo`0KOol21jHTOol004Eoo`031jIoogoo02=oo`03;N=oogoo02Eoo`8H
:AAoo`99QaQoo`U9Qf5oo`03001oogoo06Aoo`8H:Geoo`8]haeoo`87YRAoo`00AGoo00<7YWooOol0
8goo00<]hgooOol09Woo00<H:GooOol04goo0TV75Woo2TV7HGoo00<007ooOol0I7oo00<H:GooOol0
O7oo0RgS7Goo00<7YWooOol08goo0015Ool21jHTOol00bgSOomoo`0VOol00aPYOomoo`0COol2BHLE
Ool<BHMPOol00`00Oomoo`1TOol00aPYOomoo`1lOol2;N<MOol00`NVOomoo`0SOol004Ioo`031jIo
ogoo029oo`8]hbMoo`0362Uoogoo01Aoo`99Qa=oo`e9Qf1oo`03001oogoo06=oo`8H:Gioo`03;N=o
ogoo01]oo`87YREoo`00AWoo00<7YWooOol08Woo0RgS9goo00<H:GooOol05Goo0TV74Woo3TV7Ggoo
00<007ooOol0Hgoo00<H:GooOol0OGoo00<]hgooOol06goo0PNV9Goo0016Ool21jHSOol2;N<WOol2
62TFOol2BHLBOol>BHMOOol00`00Oomoo`1SOol00aPYOomoo`1mOol00bgSOomoo`0KOol21jHUOol0
04Ioo`87YRAoo`03;N=oogoo02Ioo`0362Uoogoo01Eoo`99Qa5oo`i9Qemoo`<0069oo`8H:Gioo`8]
haeoo`87YREoo`00Agoo0PNV8goo00<]hgooOol09Woo00<H:GooOol05Woo0TV747oo3TV7Ggoo00<0
07ooOol0HWoo0QPYOWoo00<]hgooOol077oo00<7YWooOol097oo0017Ool21jHSOol00bgSOomoo`0V
Ool262THOol2BHL?Ool=BHMPOol00`00Oomoo`1ROol00aPYOomoo`1mOol00bgSOomoo`0LOol00`NV
Oomoo`0TOol004Qoo`031jIoogoo025oo`03;N=oogoo02Ioo`8H:AUoo`=9Q`ioo`a9Qf1oo`03001o
ogoo069oo`0362Uoogoo07aoo`8]haeoo`87YRIoo`00B7oo0PNV8goo00<]hgooOol09Woo00<H:Goo
Ool06Goo0dV72Goo3TV7HGoo00<007ooOol0HGoo0QPYOWoo00<]hgooOol077oo0PNV9Woo0019Ool0
0`NVOomoo`0QOol00bgSOomoo`0VOol262TLOol<BHL3Ool8BHMROol00`00Oomoo`1QOol262UmOol2
;N<NOol21jHVOol004Uoo`87YR9oo`03;N=oogoo02Ioo`8H:Baoo`I9Qf=oo`03001oogoo065oo`8H
:Geoo`03;N=oogoo01eoo`87YRIoo`00BGoo0PNV8Woo00<]hgooOol09goo00<H:GooOol0Tgoo00<0
07ooOol0HGoo00<H:GooOol0O7oo00<]hgooOol07Goo00<7YWooOol09Goo001:Ool00`NVOomoo`0P
Ool00bgSOomoo`0WOol262UIOol;62T`Ool00`00Oomoo`1POol262UmOol2;N<OOol00`NVOomoo`0U
Ool004Yoo`87YR5oo`8]hbQoo`8H:EMoo`8H:@Uoo`@H:Bioo`<0061oo`8H:Geoo`03;N=oogoo01eo
o`87YRMoo`00BWoo0PNV8Woo00<]hgooOol09goo0QPYE7oo0QPY3Woo0aPY;7oo00<007ooOol0H7oo
00<H:GooOol0Ngoo0RgS7goo0PNV9goo001;Ool21jHQOol00bgSOomoo`0WOol262UBOol262TBOol3
62TZOol00`00Oomoo`1POol00aPYOomoo`1kOol00bgSOomoo`0NOol21jHWOol004]oo`87YR5oo`8]
hbUoo`8H:Dmoo`<H:AEoo`<H:BQoo`03001oogoo05moo`0362Uoogoo07]oo`8]hb1oo`031jIoogoo
02Ioo`00C7oo00<7YWooOol07goo0RgS:Goo0QPYCGoo0aPY6Goo0QPY9goo00<007ooOol0Ggoo00<H
:GooOol0Ngoo00<]hgooOol07Woo0PNV:7oo001<Ool21jHQOol00bgSOomoo`0XOol00aPYOomoo`1:
Ool262TMOol262T4Ool60005Ool20006Ool4000:Ool00`00Oomoo`1NOol262UlOol2;N<POol21jHX
Ool004eoo`031jIoogoo01moo`8]hbUoo`8H:DUoo`<H:Amoo`8H:@=oo`03001oogoo009oo`03001o
ogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo05ioo`0362Uoogoo07]o
o`03;N=oogoo01moo`87YRQoo`00CWoo00<7YWooOol07Woo0RgS:Woo00<H:GooOol0AWoo0QPY8goo
00DH:GooOomoo`0001Eoo`03001oogoo00Moo`03001oogoo05eoo`8H:Gaoo`8]hb5oo`031jIoogoo
02Moo`00CWoo00<7YWooOol07goo00<]hgooOol0:Goo00<H:GooOol0@goo0QPY9Woo00DH:GooOomo
o`0001Aoo`03001oogoo00Moo`03001oogoo05eoo`0362Uoogoo07Yoo`8]hb5oo`87YRUoo`00Cgoo
00<7YWooOol07Woo0RgS:Woo00<H:GooOol0@Woo0QPY:7oo00DH:GooOomoo`0001=oo`03001oogoo
00Moo`D005]oo`0362Uoogoo07Yoo`03;N=oogoo021oo`87YRUoo`00Cgoo00<7YWooOol07Woo0RgS
:goo00<H:GooOol0@7oo00<H:GooOol0:Goo0QPY0Woo00<007ooOol037oo10002Woo00<007ooOol0
G7oo0QPYNgoo0RgS8Woo0PNV:Goo001@Ool00`NVOomoo`0NOol00bgSOomoo`0YOol262ToOol262T/
Ool00`0062TH:@02Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`1LOol00aPYOomoo`1i
Ool2;N<SOol00`NVOomoo`0XOol0051oo`031jIoogoo01ioo`8]hb]oo`0362Uoogoo03aoo`8H:Beo
o`06001ooaPY62Uoo`003Goo00<007ooOol02goo00<007ooOol0Fgoo0QPYNgoo0RgS8Woo0PNV:Woo
001@Ool71jHJOol2;N</Ool00aPYOomoo`0jOol262T_Ool2000262T>Ool50009Ool00`00Oomoo`1K
Ool00aPYOomoo`1iOol2;N<SOol00`NVOomoo`0YOol0051oo`P7YQYoo`03;N=oogoo02Yoo`8H:CUo
o`8H:CAoo`8H:A]oo`03001oogoo05Yoo`8H:GYoo`8]hbAoo`031jIoogoo02Uoo`00Cgoo2PNV6Goo
0RgS;7oo00<H:GooOol0=Woo0QPY=Woo0QPY6Woo00<007ooOol0FWoo00<H:GooOol0N7oo0RgS97oo
0PNV:goo001>Ool<1jHHOol2;N<]Ool00aPYOomoo`0dOol00aPYOomoo`0gOol262TIOol00`00Oomo
o`1IOol262UjOol00bgSOomoo`0SOol21jH[Ool004eoo`d7YQUoo`03;N=oogoo02aoo`0362Uoogoo
035oo`8H:C]oo`8H:AQoo`<005Uoo`0362Uoogoo07Qoo`03;N=oogoo02Aoo`031jIoogoo02Yoo`00
CGoo3PNV67oo0RgS;Woo00<H:GooOol08Goo1QPY1goo0QPY?Woo0QPY5goo00<007ooOol0F7oo0QPY
NGoo00<]hgooOol097oo0PNV;7oo001=Ool>1jHIOol00bgSOomoo`0]Ool00aPYOomoo`0OOol862T5
Ool262U0Ool262TFOol00`00Oomoo`1HOol00aPYOomoo`1gOol00bgSOomoo`0UOol00`NVOomoo`0[
Ool004eoo`h7YQUoo`03;N=oogoo02eoo`8H:Amoo`XH:@9oo`8H:D=oo`8H:AEoo`03001oogoo05Mo
o`8H:GMoo`8]hbMoo`87YReoo`00CGoo3PNV6Goo0RgS;goo0QPY7Goo3QPYAGoo0QPY57oo00<007oo
Ool0Egoo00<H:GooOol0MGoo0RgS:7oo0PNV;Goo001=Ool=1jHKOol00bgSOomoo`0^Ool262TKOol=
62U8Ool262TCOol00`00Oomoo`1FOol262UfOol2;N<YOol00`NVOomoo`0/Ool004ioo``7YQ]oo`8]
hc1oo`<H:AUoo`hH:DQoo`8H:A9oo`03001oogoo05Ioo`0362Uoogoo07=oo`8]hbYoo`87YRioo`00
Cgoo2PNV7Goo00<]hgooOol0<7oo0QPY67oo3QPYBGoo0QPY4Goo00<007ooOol0EGoo00<H:GooOol0
LWoo0RgS;7oo00<7YWooOol0;Goo001@Ool81jHNOol2;N<bOol362TFOol>62U:Ool00aPYOomoo`0?
Ool00`00Oomoo`1EOol00aPYOomoo`1`Ool3;N<]Ool00`NVOomoo`0]Ool0055oo`L7YQmoo`03;N=o
ogoo039oo`<H:AAoo`hH:D]oo`0362Uoogoo00ioo`<005Aoo`0362Uoogoo06ioo`@]hbioo`87YRmo
o`00F7oo00<7YWooOol077oo0RgS=Goo11PY47oo3QPYCGoo00<H:GooOol03Goo00<007ooOol0Dgoo
0QPYK7oo1BgS<Goo00<7YWooOol0;Woo001HOol00`NVOomoo`0MOol00bgSOomoo`0eOol562T:Ool4
62T00goo62TH:@0:62U>Ool00aPYOomoo`0<Ool00`00Oomoo`1COol00aPYOomoo`1=Ool9;N<?Ool7
;N<dOol21jH`Ool005Uoo`031jIoogoo01aoo`8]hcUoo``H:@Ioo`XH:E1oo`0362Uoogoo00]oo`03
001oogoo059oo`8H:DEoo`/]h`Eooa@]hcUoo`031jIoogoo02moo`00FGoo0PNV7Woo00<]hgooOol0
BWoo21PYDWoo00<H:GooOol02Woo00<007ooOol0DGoo0QPY@Woo1BgSFgoo0PNV<Goo001JOol00`NV
Oomoo`0LOol00bgSOomoo`1;Ool662UDOol00aPYOomoo`09Ool00`00Oomoo`1AOol00aPYOomoo`0o
Ool4;N=NOol21jHaOol005Yoo`87YQioo`03;N=oogoo0:Eoo`0362Uoogoo00Qoo`03001oogoo051o
o`0362Uoogoo03ioo`<]hf1oo`87YS9oo`00Fgoo0PNV7Goo00<]hgooOol0YWoo00<H:GooOol01goo
00<007ooOol0Cgoo0QPY?Goo0bgSHgoo0PNV<Woo001KOol21jHNOol00bgSOomoo`2VOol00aPYOomo
o`06Ool00`00Oomoo`1>Ool262TlOol3;N=TOol21jHcOol005aoo`87YQeoo`03;N=oogoo0:Moo`03
62Uoogoo00Eoo`<004ioo`0362Uoogoo03Yoo`8]hfIoo`87YS=oo`00GGoo0PNV7Goo00<]hgooOol0
Ygoo00<H:GooOol017oo00<007ooOol0CGoo0QPY>Woo0RgSIgoo0PNV=7oo001MOol21jHMOol00bgS
Oomoo`2XOol00aPYOomoo`03Ool00`00Oomoo`1<Ool262TjOol2;N=XOol00`NVOomoo`0cOol005io
o`87YQeoo`L]hjAoo`0362Uoogoo009oo`03001oogoo04]oo`8H:CUoo`8]hfUoo`87YSEoo`00Ggoo
00<7YWooOol06goo22gSY7oo00DH:GooOomoo`0004eoo`0362Uoogoo03Moo`8]hfUoo`87YSIoo`00
Ggoo0PNV6goo2RgSY7oo00@H:GooOol004aoo`8H:CMoo`<]hfYoo`87YSIoo`00H7oo00<7YWooOol0
67oo32gSY7oo00<H:Goo0000Bgoo0QPY=Woo0bgSJgoo0PNV=goo001QOol00`NVOomoo`0FOol=;N>U
Ool262U:Ool262TfOol3;N=/Ool21jHgOol0065oo`87YQMoo`h]hjEoo`8H:DUoo`0362Uoogoo03Ao
o`8]hfeoo`87YSQoo`00HWoo00<7YWooOol05Goo3RgSYGoo0P0000<H:GooOol0AGoo00<H:GooOol0
=7oo0RgSKWoo00<7YWooOol0=goo001ROol21jHFOol>;N>UOol01000OomooaPYAGoo00<H:GooOol0
=7oo0RgSKWoo0PNV>Goo001SOol00`NVOomoo`0DOol>;N>UOol01000Oomoogoo0QPY@Woo00<H:Goo
Ool0<goo0RgSKgoo0PNV>Woo001TOol00`NVOomoo`0COol=;N>VOol00`00Oomoo`02Ool262U0Ool0
0aPYOomoo`0cOol2;N=`Ool21jHjOol006Aoo`87YQEoo``]hjIoo`03001oogoo00Aoo`0362Uoogoo
03aoo`0362Uoogoo03=oo`8]hg1oo`87YS]oo`00IGoo00<7YWooOol057oo2RgSYgoo00<007ooOol0
1Goo00<H:GooOol0>Woo00<H:GooOol0<goo0RgSL7oo0PNV?7oo001VOol00`NVOomoo`0DOol8;N>J
Ool4000:Ool00`00Oomoo`06Ool262ThOol262TeOol2;N=aOol00`NVOomoo`0kOol006Ioo`87YQIo
o`P]hiQoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Moo`8H:CIoo`8H:CEoo`8]hg5o
o`031jIoogoo03aoo`00Igoo00<7YWooOol06goo0RgSW7oo00<007ooOol01goo00<007ooOol02Goo
0QPY<goo0QPY=Goo0RgSLGoo0PNV?Woo001XOol00`NVOomoo`0KOol00bgSOomoo`2JOol00`00Oomo
o`07Ool50008Ool362T_Ool262TfOol2;N=bOol00`NVOomoo`0mOol006Qoo`87YQaoo`8]hi]oo`03
001oogoo00Moo`03001oogoo00aoo`8H:Baoo`<H:CIoo`8]hg9oo`031jIoogoo03ioo`00JGoo00<7
YWooOol06goo0RgSUWoo10002Woo00<007ooOol03Goo0QPY:Woo0QPY=goo0RgSLWoo00<7YWooOol0
?goo001ZOol00`NVOomoo`0KOol00bgSOomoo`2DOol00`00Oomoo`0;Ool00`00Oomoo`0?Ool262TV
Ool362TgOol2;N=bOol21jI1Ool006]oo`031jIoogoo01Yoo`8]hiEoo`03001oogoo00]oo`03001o
ogoo015oo`8H:B9oo`<H:CQoo`8]hg9oo`87YT9oo`00Jgoo00<7YWooOol06goo0RgSU7oo1@002Goo
00<007ooOol04goo0QPY7Woo0aPY>Goo00<]hgooOol0LGoo0PNV@goo001/Ool00`NVOomoo`0KOol0
0bgSOomoo`2POol00`00Oomoo`0EOol362TIOol362TjOol00bgSOomoo`1aOol21jI4Ool006aoo`87
YQeoo`03;N=oogoo09moo`03001oogoo01Moo`DH:A5oo`@H:Caoo`03;N=oogoo075oo`031jIoogoo
04Aoo`00KGoo0PNV7Goo00<]hgooOol0WWoo00<007ooOol06Woo1aPY1goo1QPY?Woo00<]hgooOol0
L7oo0PNVAgoo001]Ool21jHMOol2;N>OOol3000NOol=62U0Ool00bgSOomoo`1`Ool21jI8Ool006io
o`87YQeoo`8]hiioo`03001oogoo06Yoo`03;N=oogoo071oo`87YTUoo`00Kgoo0PNV7Goo0RgSWGoo
00<007ooOol0JGoo00<]hgooOol0L7oo0PNVBWoo001`Ool00`NVOomoo`0LOol2;N>LOol00`00Oomo
o`1XOol00bgSOomoo`1_Ool21jI<Ool0075oo`031jIoogoo01aoo`8]hi]oo`03001oogoo06Moo`03
;N=oogoo06moo`87YTeoo`00LGoo0PNV7Woo0RgSVWoo00<007ooOol0IWoo00<]hgooOol0Kgoo00<7
YWooOol0CGoo001bOol00`NVOomoo`0MOol2;N>IOol00`00Oomoo`1UOol00bgSOomoo`1^Ool21jI@
Ool007=oo`031jIoogoo01eoo`8]hiQoo`03001oogoo06Aoo`03;N=oogoo06eoo`87YU9oo`00M7oo
00<7YWooOol07Goo0RgSUgoo00<007ooOol0Hgoo00<]hgooOol0K7oo0`NVDgoo001dOol21jHOOol2
;N>FOol3001ROol00bgSOomoo`1ZOol41jIEOol007Eoo`031jIoogoo01moo`03;N=oogoo05Qoo`/]
hc1oo`03001oogoo065oo`03;N=oogoo06Uoo`@7YUMoo`00MWoo00<7YWooOol07goo00<]hgooOol0
DGoo1RgS1Woo32gS:Goo00<007ooOol0H7oo00<]hgooOol0IWoo1@NVFWoo001gOol00`NVOomoo`0O
Ool2;N=<Ool7;N<COol7;N<UOol00`00Oomoo`1OOol00bgSOomoo`1ROol71jIMOol007Moo`87YR5o
o`8]hdQoo`H]haaoo`D]hb9oo`03001oogoo05ioo`03;N=oogoo05Uoo`d7YV5oo`00N7oo00<7YWoo
Ool087oo0bgS@Goo1bgS97oo12gS7goo00<007ooOol0GGoo00<]hgooOol0>7oo:0NVJ7oo001iOol0
0`NVOomoo`0QOol2;N<nOol4;N</Ool3;N<MOol00`00Oomoo`1LOol00bgSOomoo`0dOol81jJ=Ool0
07Yoo`031jIoogoo025oo`<]hcQoo`D]hc5oo`<]ha]oo`03001oogoo05]oo`03;N=oogoo035oo`D7
YYAoo`00NWoo0PNV97oo0bgS<Woo1RgS=Woo0bgS6Goo00<007ooOol0FWoo00<]hgooOol0;Woo1PNV
Ugoo001kOol21jHUOol3;N<]Ool6;N<kOol4;N<FOol3001HOol2;N<_Ool41jJKOol007aoo`87YRIo
o`<]hbMoo`H]hd5oo`@]haAoo`03001oogoo05Moo`8]hbeoo`@7YYioo`00OGoo0PNV9goo12gS8Goo
1RgSAWoo12gS4Woo00<007ooOol0EWoo00<]hgooOol0:goo0`NVXGoo001nOol21jHXOol6;N<IOol7
;N=;Ool4;N<@Ool00`00Oomoo`1EOol00bgSOomoo`0ZOol31jJSOol007moo`87YRaoo`L]h`ioo`L]
he9oo`<]h`moo`03001oogoo05Aoo`03;N=oogoo02Uoo`<7YZEoo`00P7oo0PNV<7oo42gSFgoo0bgS
3Goo00<007ooOol0DWoo0RgS:Woo10NVYWoo0021Ool00`NVOomoo`2KOol3;N<;Ool00`00Oomoo`1A
Ool2;N<YOol41jJXOol0089oo`031jIoogoo09aoo`8]h`Yoo`03001oogoo051oo`03;N=oogoo02Qo
o`<7YZYoo`00Pgoo00<7YWooOol0WGoo0RgS27oo00<007ooOol0CWoo0RgS:Goo0`NV[7oo0024Ool0
0`NVOomoo`2MOol3;N<6Ool3001=Ool2;N<YOol21jJ^Ool008Aoo`87YZ1oo`<]h`Aoo`03001oogoo
04aoo`8]hbQoo`87Y[1oo`00QGoo0PNVXGoo0RgS0goo00<007ooOol0Bgoo0RgS9goo0`NV/Goo0026
Ool21jJROol2;N<00goo001oo`1:Ool2;N<XOol21jJcOol008Moo`87YZ=oo`8]hdYoo`8]hbMoo`87
Y[Eoo`00R7oo0PNVQGoo00<007ooOol01Goo0P001Woo10002Woo00<002gS;N<0Agoo0RgS9goo0PNV
]Woo002:Ool00`NVOomoo`22Ool00`00Oomoo`05Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`02;N=3Ool2;N<WOol21jJhOol008]oo`031jIoogoo085oo`03001oogoo015oo`03
001oogoo00Moo`04001oogooOol3;N<oOol2;N<XOol21jJiOol008aoo`87YX9oo`03001oogoo011o
o`03001oogoo00Moo`03001oogoo00=oo`<]hc]oo`<]hbMoo`87Y[]oo`00SGoo0PNVPGoo00<007oo
Ool047oo00<007ooOol01goo1@000goo12gS=Woo0bgS:7oo0PNV_7oo002>Ool21jJ0Ool00`00Oomo
o`0<Ool4000:Ool00`00Oomoo`08Ool3;N<cOol2;N<YOol00`NVOomoo`2lOol008moo`87YX1oo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`<]hbmoo`8]hbYoo`031jIoogoo0;eoo`00
TGoo0PNVNGoo00<007ooOol00Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo12gS
:Goo0bgS:Woo0PNV`7oo002BOol21jIhOol6000=Ool50009Ool00`00Oomoo`0?Ool4;N<SOol4;N<[
Ool21jK1Ool009=oo`87YYQoo`03001oogoo015oo`D]haaoo`H]hbaoo`87Y/9oo`00U7oo0`NVUWoo
00<007ooOol05Goo1RgS57oo1RgS;Woo00<7YWooOol0`Woo002EOol31jJEOol00`00Oomoo`0JOol7
;N<8Ool7;N<aOol21jK5Ool009Moo`<7YU1ooa/7YRQoo`03001oogoo01ioo`h]hcAoo`87Y/Ioo`00
VGoo0`NVB7oo1`NV6Goo1PNV8goo0`00Ggoo0PNVagoo002KOol31jI2Ool71jHROol41jHPOol00`00
Oomoo`1MOol21jK9Ool009eoo`<7YSaoo`H7YRYoo`@7YQeoo`03001oogoo05aoo`87Y/Yoo`00Wgoo
0`NV=Woo1PNV<Woo0`NV6Woo00<007ooOol0FWoo0PNVc7oo002QOol31jH`Ool61jHhOol31jHHOol0
0`00Oomoo`1IOol21jK=Ool00:=oo`@7YRUoo`D7YT1oo`<7YQEoo`03001oogoo05Moo`87Y/moo`00
YGoo1@NV8Woo1@NVAWoo0`NV4goo00<007ooOol0EWoo0PNVd7oo002XOol51jHHOol81jI=Ool31jH@
Ool00`00Oomoo`1EOol21jKAOol00:aoo`/7YPEoo`d7YU=oo`<7YPioo`<005=oo`87Y]=oo`00/Woo
4@NVFgoo0`NV37oo00<007ooOol0DWoo0PNVe7oo003oOolQOol31jH:Ool00`00Oomoo`1@Ool21jKF
Ool00?moobAoo`87YPQoo`03001oogoo04ioo`87Y]Qoo`00ogoo9Woo0PNV1Woo00<007ooOol0C7oo
0`NVfGoo003oOolXOol21jH4Ool00`00Oomoo`1;Ool21jKKOol00?moobYoo`<7YP03Ool007oo04Yo
o`87Y]eoo`00ogoo;7oo0`NVBGoo0`NVgWoo003oOol^Ool41jI4Ool31jKPOol00?moobioo`8000D7
YSmoo`<7Y^9oo`00ogoo;Woo00<007ooOol00Woo10NV>goo0`NVi7oo003oOol^Ool00`00Oomoo`06
Ool31jHfOol31jKVOol00?moobioo`03001oogoo00Qoo`@7YS5oo`<7Y^Qoo`00ogoo;Woo00<007oo
Ool02Woo1@NV:goo10NVjWoo003oOol^Ool00`00Oomoo`0<Ool61jHUOol51jK/Ool00?moobioo`03
001oogoo015oo`D7YQeoo`H7Y^moo`00ogoo;Woo00<007ooOol05Goo1`NV4goo1`NVlWoo003oOol^
Ool00`00Oomoo`0HOolJ1jKfOol00?moobioo`<00?moobUoo`00ogoo;Woo00<007ooOol0ogoo:Goo
003oOol^Ool00`00Oomoo`3oOolYOol00?moobioo`03001oogoo0?moobUoo`00ogoo;Woo00<007oo
Ool0ogoo:Goo003oOol^Ool00`00Oomoo`3oOolYOol00?mooaIoo`L000=oo`@000Yoo`03001oogoo
0?moobUoo`00ogoo6Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0
ogoo:Goo003oOolIOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3o
OolYOol00?mooaUoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Moo`D00?moobMoo`00
ogoo6Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0ogoo<goo003oOolIOol00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`3oOolcOol00?mooaUoo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo0?mooc=oo`00ogoo5goo0`001Goo00<007ooOol00Woo00<007ooOol0ogoo<goo
003oOolIOol00`00Oomoo`04Ool4003oOolfOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJ
Ool00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003o
OoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogoo
FWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00
ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomo
oeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol0
0?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOooo
OomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo
003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogoo
ogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYo
o`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mo
oomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJ
Ool00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003o
OoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogoo
FWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00
ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomo
oeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol0
0?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOooo
OomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo
003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogoo
ogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo003oOoooOomJOol00?mooomooeYo
o`00ogooogooFWoo003oOoooOomJOol00?mooomooeYoo`00ogooogooFWoo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {599, 0}} -> {-10.4684, -16.8121, 0.0520387, \
0.0842004}}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\({\[Omega] \[Rule] 1, \[Alpha] \[Rule] 6.4`}\), 
        ",", \({{\(-3.4499999999999993`\), 3.4000000000000004`}, {\(-3.55`\), 
            1.450000000000001`}, {\(-6.`\), 4.5`}, {\(-7.55`\), 
            3.1000000000000014`}}\), ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(Clear[\ a, \ w, \ x\ ]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Global optimization", "Section"],

Cell["\<\
This is an ever more important part of computation. Indeed, many \
talks at this conference discuss aspects of this very topic. I will show a \
simple example though of course \"real\" problems tend to be less simple to \
illustrate.\
\>", "Text"],

Cell[BoxData[
    \(<< NumericalMath`NMinimize`\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
f[x_] :=
x^2 - 2*x + (x^2)^(1/4) + 12*Sin[x^3] - 7*Cos[x^4]
Plot[Evaluate[f[x]], {x,0,4}];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.242451 0.0136595 [
[.2619 .22995 -3 -9 ]
[.2619 .22995 3 0 ]
[.5 .22995 -3 -9 ]
[.5 .22995 3 0 ]
[.7381 .22995 -3 -9 ]
[.7381 .22995 3 0 ]
[.97619 .22995 -3 -9 ]
[.97619 .22995 3 0 ]
[.01131 .10586 -18 -4.5 ]
[.01131 .10586 0 4.5 ]
[.01131 .37905 -12 -4.5 ]
[.01131 .37905 0 4.5 ]
[.01131 .51564 -12 -4.5 ]
[.01131 .51564 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .24245 m
.2619 .2487 L
s
[(1)] .2619 .22995 0 1 Mshowa
.5 .24245 m
.5 .2487 L
s
[(2)] .5 .22995 0 1 Mshowa
.7381 .24245 m
.7381 .2487 L
s
[(3)] .7381 .22995 0 1 Mshowa
.97619 .24245 m
.97619 .2487 L
s
[(4)] .97619 .22995 0 1 Mshowa
.125 Mabswid
.07143 .24245 m
.07143 .2462 L
s
.11905 .24245 m
.11905 .2462 L
s
.16667 .24245 m
.16667 .2462 L
s
.21429 .24245 m
.21429 .2462 L
s
.30952 .24245 m
.30952 .2462 L
s
.35714 .24245 m
.35714 .2462 L
s
.40476 .24245 m
.40476 .2462 L
s
.45238 .24245 m
.45238 .2462 L
s
.54762 .24245 m
.54762 .2462 L
s
.59524 .24245 m
.59524 .2462 L
s
.64286 .24245 m
.64286 .2462 L
s
.69048 .24245 m
.69048 .2462 L
s
.78571 .24245 m
.78571 .2462 L
s
.83333 .24245 m
.83333 .2462 L
s
.88095 .24245 m
.88095 .2462 L
s
.92857 .24245 m
.92857 .2462 L
s
.25 Mabswid
0 .24245 m
1 .24245 L
s
.02381 .10586 m
.03006 .10586 L
s
[(-10)] .01131 .10586 1 0 Mshowa
.02381 .37905 m
.03006 .37905 L
s
[(10)] .01131 .37905 1 0 Mshowa
.02381 .51564 m
.03006 .51564 L
s
[(20)] .01131 .51564 1 0 Mshowa
.125 Mabswid
.02381 .13318 m
.02756 .13318 L
s
.02381 .16049 m
.02756 .16049 L
s
.02381 .18781 m
.02756 .18781 L
s
.02381 .21513 m
.02756 .21513 L
s
.02381 .26977 m
.02756 .26977 L
s
.02381 .29709 m
.02756 .29709 L
s
.02381 .32441 m
.02756 .32441 L
s
.02381 .35173 m
.02756 .35173 L
s
.02381 .40636 m
.02756 .40636 L
s
.02381 .43368 m
.02756 .43368 L
s
.02381 .461 m
.02756 .461 L
s
.02381 .48832 m
.02756 .48832 L
s
.02381 .07854 m
.02756 .07854 L
s
.02381 .05122 m
.02756 .05122 L
s
.02381 .0239 m
.02756 .0239 L
s
.02381 .54296 m
.02756 .54296 L
s
.02381 .57028 m
.02756 .57028 L
s
.02381 .5976 m
.02756 .5976 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .14684 m
.02499 .14766 L
.02605 .14791 L
.02729 .14809 L
.02846 .14822 L
.02954 .14831 L
.03053 .14837 L
.03279 .14849 L
.03396 .14853 L
.03506 .14856 L
.03636 .14859 L
.03756 .14862 L
.04 .14865 L
.04262 .14868 L
.04759 .14872 L
.05033 .14875 L
.0529 .14877 L
.0553 .14881 L
.05791 .14885 L
.06244 .14896 L
.06506 .14905 L
.06782 .14916 L
.07277 .14941 L
.07815 .14979 L
.08405 .15032 L
.08917 .15091 L
.09467 .15169 L
.10458 .1535 L
.11475 .15599 L
.12582 .15951 L
.13538 .16333 L
.14594 .16848 L
.16572 .18115 L
.18672 .19974 L
.20607 .22254 L
.22693 .25454 L
.24697 .29376 L
.26807 .34445 L
.28803 .39868 L
.30617 .44515 L
.31101 .4552 L
.31356 .4598 L
.31626 .46406 L
.31862 .46719 L
.32122 .46993 L
.32235 .47087 L
.32358 .47169 L
.32473 .47228 L
.32579 .47266 L
.32708 .47289 L
Mistroke
.3278 .47291 L
.32845 .47285 L
.32973 .47255 L
.33093 .47201 L
.33161 .47159 L
.33233 .47105 L
.33362 .46986 L
.33501 .46822 L
.33653 .46599 L
.33908 .46118 L
.34181 .45446 L
.34674 .43802 L
.35204 .41373 L
.35694 .38508 L
.36802 .29988 L
.37841 .20266 L
.38815 .11288 L
.39254 .07864 L
.39715 .05005 L
.39957 .03884 L
.40085 .03411 L
.40222 .03001 L
.40348 .02712 L
.40462 .02528 L
.40577 .02417 L
.40685 .02384 L
.40804 .02426 L
.40936 .02568 L
.41002 .02677 L
.41073 .02823 L
.412 .03158 L
.41449 .04065 L
.41675 .05171 L
.42225 .08771 L
.42747 .12926 L
.43244 .16933 L
.4371 .20173 L
.43945 .21454 L
.44197 .2251 L
.44334 .22927 L
.44408 .23107 L
.44478 .23246 L
.44601 .2342 L
.44666 .23476 L
.44735 .23509 L
.44859 .23501 L
.44973 .23421 L
.45098 .23262 L
.45161 .23156 L
.45231 .23021 L
Mistroke
.457 .21781 L
.45918 .21153 L
.46038 .20842 L
.46152 .20587 L
.46258 .204 L
.46374 .20264 L
.46479 .20212 L
.46576 .20235 L
.46705 .20383 L
.4677 .20513 L
.46841 .20701 L
.46967 .21158 L
.47085 .21732 L
.47224 .22604 L
.4735 .23584 L
.47634 .26424 L
.48146 .33421 L
.4863 .41135 L
.49063 .47335 L
.49281 .49706 L
.49405 .50731 L
.49522 .51446 L
.49648 .51929 L
.49764 .52089 L
.49892 .51944 L
.49956 .51741 L
.50026 .51422 L
.50142 .50662 L
.50267 .49549 L
.50491 .46827 L
.5099 .3842 L
.51517 .28879 L
.51792 .2497 L
.51948 .23321 L
.52024 .22698 L
.52095 .22211 L
.52159 .21861 L
.52229 .21574 L
.52352 .21306 L
.52421 .21281 L
.52495 .21348 L
.52565 .21494 L
.52628 .21689 L
.52754 .22235 L
.52888 .2298 L
.53127 .24493 L
.53251 .25234 L
.53384 .25885 L
.53461 .26161 L
.5353 .26334 L
Mistroke
.536 .26422 L
.53666 .26419 L
.53785 .26182 L
.5391 .25579 L
.54017 .24765 L
.54135 .2355 L
.54397 .1974 L
.54643 .15146 L
.54883 .10332 L
.55139 .05688 L
.55286 .03605 L
.55356 .02832 L
.5542 .02259 L
.55484 .01825 L
.55554 .01528 L
.55681 .01472 L
.55799 .02001 L
.55909 .03003 L
.5603 .04641 L
.5616 .06965 L
.56667 .19459 L
.56905 .25397 L
.57031 .28064 L
.57164 .30379 L
.57281 .31886 L
.57409 .32956 L
.57526 .33386 L
.57636 .3335 L
.57744 .32949 L
.57857 .32214 L
.58061 .30436 L
.58168 .29461 L
.58281 .28554 L
.58405 .27853 L
.58519 .27598 L
.58641 .27848 L
.58711 .28259 L
.58776 .28829 L
.58893 .30302 L
.59019 .32497 L
.59473 .43759 L
.59604 .47065 L
.59746 .50152 L
.59811 .51297 L
.59881 .52291 L
.60006 .5341 L
.60137 .53561 L
.60261 .527 L
.60372 .51127 L
.60492 .48672 L
Mistroke
.60958 .35237 L
.61071 .3209 L
.61192 .29223 L
.61262 .27883 L
.61325 .26885 L
.61449 .25587 L
.61562 .2517 L
.61666 .25383 L
.6178 .26173 L
.61901 .27458 L
.62105 .29939 L
.62221 .31071 L
.62329 .31678 L
.62444 .31666 L
.62568 .30747 L
.62699 .28665 L
.62819 .25848 L
.63268 .11141 L
.63389 .07552 L
.63518 .04682 L
.63585 .0367 L
.63658 .02995 L
.63788 .0298 L
.6391 .04318 L
.64042 .07032 L
.64166 .10492 L
.64279 .14062 L
.64497 .20722 L
.64607 .2338 L
.64728 .25398 L
.64859 .26321 L
.64982 .26017 L
.65095 .24902 L
.65218 .23115 L
.65335 .21235 L
.65444 .1972 L
.65557 .18759 L
.65682 .188 L
.6579 .19966 L
.65888 .21989 L
.66001 .25391 L
.66108 .2946 L
.6633 .39166 L
.66453 .44217 L
.66569 .48132 L
.66635 .49794 L
.66706 .51088 L
.66832 .51945 L
.66959 .51009 L
.67078 .48772 L
Mistroke
.67334 .41702 L
.6746 .38528 L
.67575 .36531 L
.6764 .35931 L
.67709 .35749 L
.67778 .36037 L
.67854 .36866 L
.67984 .39313 L
.68106 .42256 L
.6822 .44973 L
.68345 .47144 L
.68463 .47846 L
.68571 .46987 L
.68669 .44889 L
.68777 .41223 L
.68996 .30921 L
.69111 .25145 L
.69233 .19845 L
.69296 .17634 L
.69366 .15782 L
.69488 .1412 L
.69604 .14397 L
.69727 .16316 L
.69844 .1902 L
.6995 .21561 L
.70069 .23755 L
.70181 .24573 L
.70303 .23704 L
.70435 .20735 L
.70561 .16459 L
.70698 .11338 L
.70828 .07361 L
.70949 .0544 L
.71071 .05851 L
.71182 .08387 L
.71309 .13465 L
.7143 .19494 L
.71532 .24774 L
.71641 .29652 L
.7176 .33402 L
.71869 .34957 L
.71999 .34476 L
.72117 .32421 L
.72244 .29618 L
.72311 .28359 L
.72383 .27473 L
.7251 .2761 L
.72629 .30099 L
.72739 .34377 L
.72861 .40547 L
Mistroke
.73 .47837 L
.73132 .5324 L
.73204 .55022 L
.73284 .55774 L
.73356 .55338 L
.73423 .54035 L
.73491 .51938 L
.73556 .49436 L
.73677 .44145 L
.73808 .39017 L
.73881 .36998 L
.73949 .35917 L
.74075 .36062 L
.74194 .38437 L
.74303 .41608 L
.74418 .44765 L
.74543 .46417 L
.74659 .45271 L
.74784 .40869 L
.74855 .37129 L
.74921 .33084 L
.75031 .26044 L
.75134 .20145 L
.75241 .15751 L
.75358 .13791 L
.75477 .14883 L
.75604 .18464 L
.75714 .22105 L
.7583 .24911 L
.75896 .25527 L
.75968 .25172 L
.76096 .21945 L
.76169 .18991 L
.76246 .15379 L
.76319 .12044 L
.76386 .09399 L
.76453 .07525 L
.76527 .06656 L
.76592 .07057 L
.76661 .0871 L
.76792 .14842 L
.76912 .2226 L
.7703 .29221 L
.77155 .34051 L
.7722 .35114 L
.77292 .35093 L
.77418 .32674 L
.77537 .29242 L
.77665 .26867 L
.77785 .2778 L
Mistroke
.77895 .31836 L
.78015 .38967 L
.78144 .47519 L
.78265 .53702 L
.78377 .55997 L
.78495 .5438 L
.7862 .49276 L
.78749 .4299 L
.78822 .40252 L
.78888 .38747 L
.79005 .38873 L
.79115 .41959 L
.79218 .46157 L
.79326 .50055 L
.79446 .51436 L
.79556 .48777 L
.79675 .4201 L
.79806 .323 L
.79872 .27646 L
.79945 .23565 L
.80076 .20083 L
.80205 .21748 L
.80323 .25853 L
.80396 .28296 L
.80465 .29792 L
.80593 .29148 L
.80664 .26601 L
.8073 .23121 L
.80879 .13678 L
.81 .07959 L
.81112 .06838 L
.81236 .10881 L
.81367 .19077 L
.81434 .23334 L
.81506 .2712 L
.81637 .30102 L
.81765 .2783 L
.81882 .23373 L
.82007 .20085 L
.82126 .21404 L
.82232 .26969 L
.82348 .36144 L
.82474 .45837 L
.82544 .49525 L
.82608 .51242 L
.82732 .50018 L
.82849 .45158 L
.82959 .40588 L
.83076 .39082 L
.83175 .41652 L
Mistroke
.83284 .47648 L
.83402 .54666 L
.83527 .58321 L
.83646 .55567 L
.83755 .48528 L
.83882 .38686 L
.83947 .34785 L
.84018 .32203 L
.84144 .32628 L
.84262 .36963 L
.84329 .39523 L
.844 .41098 L
.84527 .38972 L
.84598 .3483 L
.84664 .29613 L
.84736 .23361 L
.84814 .17229 L
.84944 .1182 L
.85068 .14021 L
.85188 .20501 L
.85299 .25792 L
.85419 .26655 L
.85551 .21075 L
.85618 .17009 L
.85689 .13211 L
.85817 .11124 L
.85948 .17409 L
.86066 .27698 L
.86134 .33317 L
.86206 .37745 L
.86338 .3942 L
.86464 .3494 L
.86532 .321 L
.86596 .30503 L
.86709 .32162 L
.86833 .40722 L
.86954 .51412 L
.87068 .57741 L
.8717 .57427 L
.87281 .51605 L
.87402 .43983 L
.87531 .413 L
.87641 .45233 L
.87762 .52451 L
.87894 .55854 L
.8796 .53885 L
.88033 .48971 L
.88163 .36611 L
.88281 .28128 L
.88353 .26537 L
Mistroke
.88421 .27654 L
.88493 .30699 L
.8857 .34404 L
.88639 .36383 L
.88711 .35963 L
.8884 .28129 L
.8896 .17128 L
.89089 .10353 L
.8921 .13371 L
.89321 .21348 L
.89451 .28429 L
.89525 .28555 L
.89593 .26044 L
.89718 .18492 L
.89851 .15363 L
.89966 .21647 L
.90092 .34483 L
.90206 .43438 L
.90313 .4461 L
.90377 .42236 L
.90447 .38573 L
.90574 .34879 L
.90697 .40362 L
.90811 .51157 L
.90912 .58996 L
.91023 .60077 L
.91139 .5288 L
.91248 .44646 L
.91365 .4198 L
.91473 .46813 L
.91597 .54306 L
.91714 .54212 L
.91844 .43182 L
.91962 .3095 L
.92027 .26981 L
.92097 .26232 L
.92225 .31937 L
.92345 .36587 L
.92472 .31525 L
.9258 .20815 L
.92699 .11878 L
.92771 .11502 L
.92839 .14888 L
.92967 .25494 L
.93039 .29493 L
.93105 .29987 L
.93178 .26997 L
.93255 .21654 L
.93382 .16366 L
.93501 .22641 L
Mistroke
.93632 .37424 L
.93706 .43693 L
.93774 .4576 L
.93898 .41127 L
.94015 .35572 L
.9412 .38195 L
.94234 .49349 L
.94358 .60332 L
.9449 .58572 L
.94602 .49122 L
.94725 .43345 L
.94841 .48404 L
.94946 .56111 L
.95067 .5664 L
.95183 .45668 L
.95282 .34394 L
.95387 .29546 L
.95503 .34405 L
.9561 .39838 L
.95677 .39229 L
.95747 .34292 L
.95872 .20099 L
.95941 .14585 L
.96006 .13595 L
.96078 .1714 L
.96154 .23812 L
.9622 .28811 L
.96291 .30619 L
.96421 .23165 L
.96548 .1511 L
.96665 .20232 L
.97619 .53366 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`005@3oool00`000000oooo0?oo
o`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?oo
o`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0M`3oool001D0oooo00<000000?ooo`3oool0S@3o
ool2000007T0oooo000E0?ooo`800000IP3oool00`000000oooo0?ooo`0U0?ooo`800000N@3oool0
01D0oooo00<000000?ooo`3oool0I03oool3000002H0oooo00<000000?ooo`000000N03oool001D0
oooo00<000000?ooo`3oool0I03oool00`000000oooo0000000V0?ooo`030000003oool0000001@0
oooo00<000000?ooo`3oool0H@3oool001D0oooo00<000000?ooo`3oool0H`3oool01@000000oooo
0?ooo`3oool0000002D0oooo00<000000?ooo`000000503oool00`000000oooo0?ooo`1Q0?ooo`00
5@3oool00`000000oooo0?ooo`1S0?ooo`050000003oool0oooo0?ooo`0000009@3oool00`000000
oooo0000000C0?ooo`800000H`3oool001D0oooo00<000000?ooo`3oool0H`3oool01@000000oooo
0?ooo`3oool0000002D0oooo00<000000?ooo`0000004`3oool2000006<0oooo000E0?ooo`030000
003oool0oooo06<0oooo00D000000?ooo`3oool0oooo0000000U0?ooo`030000003oool0000001<0
oooo0P00001S0?ooo`005@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool08@3oool010000000oooo0?ooo`00000C0?ooo`800000H`3oool001D0oooo
0P00001S0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08@3oool010000000oooo
0?ooo`00000C0?ooo`800000H`3oool001D0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool000004`3oool200000180
oooo00<000000?ooo`3oool0CP3oool001D0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool000004`3oool00`000000
oooo0000000A0?ooo`800000C`3oool001D0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool000004`3oool00`000000
oooo0000000A0?ooo`800000C`3oool001D0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool000004`3oool00`000000
oooo0000000A0?ooo`8000003P3oool00`000000oooo0?ooo`0n0?ooo`005@3oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool010000000oooo
0?ooo`00000C0?ooo`030000003oool000000140oooo0P00000>0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0<P3oool001D0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0200oooo00@000000?ooo`3oool000004`3oool00`000000
oooo0000000A0?ooo`8000003@3oool2000000/0oooo00<000000?ooo`3oool0<P3oool001D0oooo
0P00001R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool010000000oooo
0?ooo`00000C0?ooo`030000003oool000000140oooo0P00000=0?ooo`8000002`3oool00`000000
oooo0?ooo`0b0?ooo`005@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0803oool010000000oooo0?ooo`00000C0?ooo`030000003oool000000140
oooo0P00000=0?ooo`8000002`3oool00`000000oooo0?ooo`0b0?ooo`005@3oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool010000000oooo
0?ooo`00000C0?ooo`030000003oool000000140oooo0P00000=0?ooo`8000002`3oool00`000000
oooo0?ooo`0b0?ooo`005@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0803oool010000000oooo0?ooo`00000C0?ooo`030000003oool000000140
oooo0P00000=0?ooo`8000002`3oool00`000000oooo0?ooo`0b0?ooo`005@3oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool010000000oooo
0?ooo`00000C0?ooo`030000003oool000000140oooo0P00000=0?ooo`8000002`3oool00`000000
oooo0?ooo`0b0?ooo`005@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0803oool010000000oooo0?ooo`00000C0?ooo`030000003oool000000140
oooo0P00000=0?ooo`8000002`3oool00`000000oooo0?ooo`0b0?ooo`001`3oool4000000<0oooo
0P0000050?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0O0?ooo`040000003oool0oooo000001<0oooo00<000000?ooo`0000004@3oool2000000d0
oooo0P00000;0?ooo`030000003oool0oooo0380oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0O0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`00
0000oooo0000000A0?ooo`8000003@3oool2000000/0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0L0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00P3oool300000600oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0O0?oo
o`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0000000A0?ooo`8000003@3oool2
000000/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0L0?ooo`0000<0oooo0000
000000000P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0O
0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0000000A0?ooo`8000003@3o
ool2000000X0oooo0P00000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0703o
ool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo00D0
00000?ooo`3oool0oooo0000000B0?ooo`030000003oool000000140oooo0P00000=0?ooo`800000
2P3oool2000000`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0180oooo00070?ooo`<000000`3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0O0?ooo`050000
003oool0oooo0?ooo`0000004P3oool00`000000oooo0000000A0?ooo`8000003@3oool2000000X0
oooo0P00000:0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0B0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool01@000000oooo
0?ooo`3oool000000180oooo00<000000?ooo`0000004@3oool2000000d0oooo0P00000:0?ooo`80
00002P3oool00`000000oooo000000080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool04P3oool001D0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01h0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool000000140
oooo0P00000=0?ooo`8000002P3oool2000000X0oooo00<000000?ooo`000000203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0180oooo000E0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool00`000000oooo0000000A0?ooo`8000003@3oool2000000X0oooo
0P00000:0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0B0?ooo`005@3oool200000600oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0000
000A0?ooo`8000003@3oool2000000X0oooo0P00000:0?ooo`030000003oool0000000P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`005@3oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`0000004@3oool2000000X0oooo00<00000
0?ooo`3oool00P00000:0?ooo`8000002P3oool00`000000oooo000000080?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`005@3oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`0000003@3oool01000
0000oooo0?ooo`3oool2000000X0oooo00<000000?ooo`3oool00P00000:0?ooo`8000002P3oool0
0`000000oooo000000070?ooo`8000002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00T0oooo000E0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`00
0000oooo0000000=0?ooo`80000000@0oooo0000003oool000002P3oool2000000030?ooo`000000
000000X0oooo0P00000:0?ooo`030000003oool0000000L0oooo0P0000090?ooo`030000003oool0
oooo00D0oooo0P00000;0?ooo`005@3oool;000005L0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`00
0000oooo0000000=0?ooo`80000000@0oooo0000003oool000002P3oool2000000030?ooo`000000
000000X0oooo0P0000090?ooo`80000000<0oooo0000003oool01P3oool2000000T0oooo00<00000
0?ooo`3oool01@3oool2000000/0oooo000E0?ooo`030000003oool0oooo00P0oooo2P00001=0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00l0oooo00@000000?ooo`3oool000003@3oool2000000040?ooo`000000
oooo000000X0oooo0P0000000`3oool000000000000:0?ooo`030000003oool0000000P0oooo0P00
00000`3oool000000?ooo`060?ooo`8000002@3oool00`000000oooo0?ooo`050?ooo`<000002P3o
ool001D0oooo00<000000?ooo`3oool04P3oool6000004L0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool0
10000000oooo0?ooo`00000=0?ooo`80000000@0oooo0000003oool000002P3oool2000000030?oo
o`000000000000X0oooo00<000000?ooo`000000203oool4000000L0oooo0P0000000`3oool00000
0?ooo`060?ooo`030000003oool0oooo00D0oooo0`00000:0?ooo`005@3oool00`000000oooo0?oo
o`0H0?ooo`<00000A03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000000d0oooo
0P000000103oool000000?ooo`00000:0?ooo`80000000<0oooo0000000000002P3oool00`000000
oooo000000080?ooo`@000001`3oool2000000030?ooo`000000oooo00H0oooo00<000000?ooo`3o
ool01@3oool3000000X0oooo000E0?ooo`800000703oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00l0oooo00@000000?ooo`3oool000003@3oool2000000040?ooo`000000oooo0000
00X0oooo0P0000000`3oool000000000000:0?ooo`030000003oool0000000P0oooo100000070?oo
o`80000000<0oooo0000003oool01P3oool2000000H0oooo0`00000:0?ooo`005@3oool00`000000
oooo0?ooo`0L0?ooo`800000@03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo0000
00d0oooo0P0000001@3oool000000?ooo`3oool0000000T0oooo0P0000000`3oool000000000000:
0?ooo`030000003oool0000000P0oooo100000070?ooo`80000000<0oooo0000003oool01@3oool3
000000H0oooo0`00000:0?ooo`005@3oool00`000000oooo0?ooo`0N0?ooo`800000?P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0>0?ooo`040000003oool0oooo000000d0oooo0P0000001@3oool000000?ooo`3o
ool0000000T0oooo0P0000000`3oool000000000000:0?ooo`030000003oool0000000P0oooo1000
00070?ooo`80000000<0oooo0000003oool01@3oool3000000H0oooo0`00000:0?ooo`005@3oool0
0`000000oooo0?ooo`0P0?ooo`800000?03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0
oooo0?ooo`000000303oool2000000050?ooo`000000oooo0?ooo`0000002@3oool2000000030?oo
o`000000000000X0oooo00<000000?ooo`000000203oool4000000L0oooo0P0000000`3oool00000
0?ooo`050?ooo`<000001P3oool3000000X0oooo000E0?ooo`030000003oool0oooo0280oooo0P00
000j0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`800000
00D0oooo0000003oool0oooo000000090?ooo`80000000<0oooo0000000000002P3oool00`000000
oooo000000080?ooo`@000001`3oool2000000030?ooo`000000oooo00D0oooo0`0000060?ooo`<0
00002P3oool001D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`80000000D0oooo0000003o
ool0oooo000000090?ooo`80000000<0oooo0000000000002P3oool00`000000oooo000000080?oo
o`@000001`3oool2000000030?ooo`000000oooo00D0oooo0`0000060?ooo`<000002P3oool001D0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0
oooo00D000000?ooo`3oool0oooo0000000<0?ooo`80000000D0oooo0000003oool0oooo00000009
0?ooo`80000000<0oooo0000000000002P3oool00`000000oooo000000080?ooo`@000001`3oool2
000000030?ooo`000000oooo00D0oooo0`0000060?ooo`<000002P3oool001D0oooo0P00000W0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01`3oool2000000050?ooo`000000oooo0?ooo`0000002@3o
ool2000000040?ooo`000000oooo000000T0oooo00<000000?ooo`000000203oool4000000L0oooo
0P0000000`3oool000000?ooo`050?ooo`<000001P3oool3000000X0oooo000E0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`80000000D0oooo0000003oool0
oooo000000090?ooo`80000000@0oooo0000003oool000002@3oool00`000000oooo000000080?oo
o`@000001`3oool2000000030?ooo`000000oooo00D0oooo0`0000060?ooo`<000002P3oool001D0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0
oooo00H000000?ooo`3oool0oooo0000003oool2000000T0oooo0P0000001@3oool000000?ooo`3o
ool0000000T0oooo0P000000103oool000000?ooo`0000090?ooo`030000003oool0000000P0oooo
100000070?ooo`80000000<0oooo0000003oool01@3oool4000000D0oooo0`00000:0?ooo`005@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3o
ool01P000000oooo0?ooo`3oool000000?ooo`8000002@3oool2000000050?ooo`000000oooo0?oo
o`0000002@3oool2000000040?ooo`000000oooo000000T0oooo00<000000?ooo`000000203oool4
000000L0oooo0P0000000`3oool000000?ooo`050?ooo`@000001@3oool3000000X0oooo000E0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00@0oooo0P00000D0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool03P3oool01P000000oooo0?ooo`3oool000000?ooo`8000002@3oool2000000050?ooo`00
0000oooo0?ooo`0000002@3oool2000000040?ooo`000000oooo000000L0oooo00L000000?ooo`00
0000oooo0000003oool0000000H0oooo100000070?ooo`80000000<0oooo0000003oool01@3oool4
000000D0oooo0`00000:0?ooo`005@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
00l0oooo1000000M0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`00
0000oooo000000050?ooo`@000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00h0oooo00H000000?ooo`3oool0oooo0000003oool2000000T0oooo00@000000?ooo`0000000000
0P3oool00`000000oooo0?ooo`020?ooo`8000000`3oool2000000040?ooo`000000oooo000000L0
oooo00L000000?ooo`000000oooo0000003oool0000000H0oooo100000070?ooo`80000000<0oooo
0000003oool01@3oool4000000D0oooo0`0000020?ooo`030000003oool0oooo00D0oooo000E0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000050?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?oo
o`090000003oool0oooo0?ooo`000000oooo0000003oool0000000P0oooo00@000000?ooo`000000
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`0000020?oo
o`030000003oool0oooo00D0oooo0`000000103oool000000?ooo`0000060?ooo`@000001`3oool2
000000030?ooo`000000oooo00D0oooo100000050?ooo`<000000P3oool00`000000oooo0?ooo`05
0?ooo`005@3oool2000002d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00h0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000203oool010000000oooo0000000000020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`0000020?ooo`030000003oool0oooo00D0oooo0`000000103oool000000?ooo`000006
0?ooo`@000001`3oool2000000030?ooo`000000oooo00D0oooo100000050?ooo`L000001P3oool0
01D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00h0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000203oool010000000oooo0000000000020?ooo`030000003oool0oooo0080oooo0P0000030?oo
o`<000000P3oool00`000000oooo0?ooo`050?ooo`<0000000@0oooo0000003oool000001P3oool4
000000L0oooo0P0000000`3oool000000?ooo`050?ooo`@000001@3oool300000080oooo00<00000
0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool03`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool0000000P0oooo00@000000?ooo`00000000000P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<000000P3oool00`000000oooo0?ooo`050?oo
o`<0000000@0oooo00000000000000001P3oool4000000L0oooo0P0000000`3oool000000?ooo`05
0?ooo`@000001@3oool4000000030?ooo`000000oooo00H0oooo000E0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool02`3oool3000001h0oooo00<000000?ooo`3oool03`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`000000203oool010000000oooo
0000000000020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030000
0080oooo00<000000?ooo`3oool01@3oool3000000040?ooo`0000000000000000H0oooo0`000000
0`3oool000000?ooo`050?ooo`@000001P3oool4000000D0oooo0`0000000`3oool0000000000007
0?ooo`005@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool01@000000oooo0000003o
ool0000000L0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo0080oooo0P00
00030?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`<0000000@0oooo0000000000000000
1P3oool3000000030?ooo`000000oooo00D0oooo100000060?ooo`@000001@3oool300000080oooo
00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0100oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000070?ooo`030000
003oool0oooo008000000P3oool00`000000oooo0?ooo`070?ooo`<000000P3oool00`000000oooo
0?ooo`050?ooo`<0000000@0oooo00000000000000001P3oool01@000000oooo0000003oool00000
00H0oooo100000060?ooo`@000001@3oool3000000X0oooo000E0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0A0?ooo`8000001@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo000000070?oo
o`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool01@3oool3000000040?ooo`0000000000000000H0oooo00D00000
0?ooo`000000oooo000000060?ooo`@000001P3oool4000000D0oooo0`00000:0?ooo`005@3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo
000000070?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`070?ooo`030000
003oool000000080oooo00<000000?ooo`3oool01@3oool3000000040?ooo`0000000000000000H0
oooo00D000000?ooo`000000oooo000000060?ooo`@000001P3oool4000000D0oooo0`00000:0?oo
o`003P3ooooo000001<00000000E0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0
oooo000000080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`0000001@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00H0
00000?ooo`3oool0oooo0000003oool2000000030?ooo`000000oooo00H0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`030?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool3000000040?ooo`000000000000000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000103oool00`000000oooo0000
0003000000H0oooo100000050?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`005@3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000001`3oool00`000000oooo0?ooo`0:0?ooo`040000
003oool0oooo000000D0oooo0P0000000`3oool000000?ooo`060?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool0
0`000000oooo0?ooo`050?ooo`<0000000@0oooo00000000000000001P3oool01@000000oooo0000
003oool0000000H0oooo00@000000?ooo`00000000001P3oool4000000D0oooo0`0000020?ooo`03
0000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo00L000000?ooo`3oool0
oooo0000003oool0000000L0oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`000005
0?ooo`80000000<0oooo0000003oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`<0000000@0oooo
00000000000000001P3oool01@000000oooo0000003oool0000000H0oooo00@000000?ooo`000000
00001P3oool4000000D0oooo0`00000:0?ooo`005@3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo0P0000070?ooo`030000003oool0oooo00X0oooo0P0000000`3oool00000
0?ooo`040?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool300000004
0?ooo`0000000000000000H0oooo00D000000?ooo`000000oooo000000060?ooo`040000003oool0
0000000000H0oooo100000050?ooo`@000002@3oool001D0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`0:0?ooo`80000000<0oooo
0000003oool0103oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0`00
0000103oool000000000000000060?ooo`050000003oool000000?ooo`0000001P3oool010000000
oooo0000000000050?ooo`D000001@3oool4000000T0oooo000E0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0
oooo00D000000?ooo`000000oooo000000050?ooo`040000003oool0oooo000000L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01@3oool3000000040?ooo`0000000000000000H0oooo00D000000?ooo`000000oooo
000000050?ooo`80000000<0oooo0000000000001@3oool5000000D0oooo100000090?ooo`005@3o
ool2000003L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`050000003o
ool000000?ooo`000000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo
0`000000103oool000000000000000060?ooo`050000003oool0oooo0?ooo`0000001@3oool20000
00030?ooo`000000000000D0oooo1@0000050?ooo`@000002@3oool001D0oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`00
0000oooo000000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`0000001@3oool30000
00040?ooo`0000000000000000H0oooo00D000000?ooo`3oool0oooo000000050?ooo`80000000<0
oooo0000000000001@3oool5000000D0oooo0P0000000`3oool000000?ooo`080?ooo`005@3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`050000003oool000000?ooo`000000203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000D0oooo0`000000103oool000000000000000060?ooo`050000003oool0oooo
0?ooo`0000001@3oool2000000030?ooo`000000000000D0oooo0P0000000`3oool0000000000005
0?ooo`80000000<0oooo0000003oool0203oool001D0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo008000001P3oool01@000000oooo0000003oool0
000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`040000003oool0
0000000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000050?ooo`<0000000@0
oooo00000000000000001P3oool01@000000oooo0?ooo`3oool0000000D0oooo0P0000000`3oool0
0000000000050?ooo`80000000<0oooo0000000000001@3oool2000000030?ooo`000000oooo00P0
oooo000E0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`02000000H0oooo00D000000?ooo`000000oooo000000080?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool010000000oooo0000000000060?ooo`030000003oool0oooo
0080oooo0`0000050?ooo`<0000000@0oooo00000000000000001P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo0P000000103oool000000?ooo`0000040?ooo`80000000<0oooo000000000000
1@3oool2000000030?ooo`000000oooo00P0oooo000E0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`02000000H0oooo00D000000?ooo`000000oooo
000000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool010000000oooo
0000000000060?ooo`030000003oool0oooo0080oooo0`0000050?ooo`<000000P3oool2000000H0
oooo00D000000?ooo`3oool0oooo000000050?ooo`80000000@0oooo0000003oool00000103oool2
000000030?ooo`000000000000D0oooo0P0000000`3oool000000?ooo`080?ooo`005@3oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P0000060?oo
o`050000003oool000000?ooo`000000203oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00@0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?ooo`020?ooo`<000001@3o
ool300000080oooo0P0000060?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000<0oooo
00<000000?ooo`3oool00P3oool2000000030?ooo`000000000000D0oooo0P0000000`3oool00000
0?ooo`080?ooo`005@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00H0
00000?ooo`3oool000000?ooo`0000050?ooo`050000003oool000000?ooo`000000203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00@000000?ooo`00000000001P3oool0
0`000000oooo0?ooo`020?ooo`<000001@3oool300000080oooo0P0000060?ooo`050000003oool0
oooo0?ooo`0000001@3oool2000000<0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`00
0000000000@0oooo0`0000000`3oool000000?ooo`080?ooo`005@3oool2000003/0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0303oool01P000000oooo0?ooo`000000oooo000000D0oooo00D000000?ooo`000000
oooo000000080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool010000000
oooo0000000000050?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`8000000`3oool20000
00H0oooo00D000000?ooo`3oool0oooo000000050?ooo`8000000`3oool00`000000oooo0?ooo`02
0?ooo`80000000<0oooo000000000000103oool3000000030?ooo`000000oooo00P0oooo000E0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`000000oooo000000020?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`000000oooo000000080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool010000000oooo0000000000050?ooo`030000003o
ool0oooo00<0oooo0`0000050?ooo`030000003oool0oooo0080oooo0P0000060?ooo`050000003o
ool0oooo0?ooo`0000001@3oool2000000<0oooo00<000000?ooo`3oool00P3oool2000000030?oo
o`000000000000@0oooo0`0000000`3oool000000?ooo`080?ooo`005@3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00800000203oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`00000000001@3oool00`000000oooo0?ooo`030?ooo`<00000
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool0
oooo0P0000040?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000
oooo0?ooo`020?ooo`<0000000<0oooo0000003oool0203oool001D0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`02000000P0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`040?ooo`040000003oool00000000000D0oooo00<000000?ooo`3oool00`3oool3000000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?oo
o`800000103oool2000000<0oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?oo
o`3oool00P3oool200000080oooo00<000000?ooo`3oool01`3oool001D0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`02000000P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`040000003oool00000000000D0oooo00<000000?ooo`3oool00`3oool30000
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool00P3oool200000080oooo00<00000
0?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool01`3oool001D0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool3000000D0oooo00<000000?ooo`3oool00`3oool3000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`800000103o
ool2000000<0oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool00P3o
ool200000080oooo00<000000?ooo`3oool01`3oool001D0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool3
000000D0oooo00<000000?ooo`3oool00`3oool3000000D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`800000103oool2000000<0oooo00<0
00000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool00P3oool200000080oooo00<0
00000?ooo`3oool01`3oool001D0oooo0P00000n0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`<000001@3oool00`000000oooo0?ooo`03
0?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000000`3oool2000000@0oooo0P0000030?ooo`030000003oool0oooo0080oooo0P000002
0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo00L0oooo000E0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool200000080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool3000000D0oooo00<000000?ooo`3oool00`3oool3000000D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo0P0000030?oo
o`<000000`3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`020?oo
o`8000000P3oool00`000000oooo0?ooo`070?ooo`005@3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00h0oooo0P0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo0`0000050?ooo`03
0000003oool0oooo00<0oooo0`0000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000030?ooo`8000000`3oool3000000<0oooo00<000000?ooo`3o
ool00P3oool200000080oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3o
ool01`3oool001D0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool3000000D0oooo00<000000?ooo`3oool00`3oool3000000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo0P0000030?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000
oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`070?ooo`005@3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
000000050?ooo`030000003oool0oooo00<0oooo0`0000050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`8000000`3oool3000000<0oooo
00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool00P3oool200000080oooo
00<000000?ooo`3oool01`3oool001D0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`030?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000`3oool2000000<0oooo0`0000030?ooo`030000003oool0oooo0080oooo0P00
00020?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo00L0oooo000E
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0103oool2000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo0P000003
0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`02
0?ooo`8000000P3oool00`000000oooo0?ooo`070?ooo`005@3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000050?oo
o`030000003oool0oooo00@0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool3000000<0oooo0P0000030?ooo`<000000`3oool2000000<0oooo0P0000020?oo
o`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo00L0oooo000E0?ooo`80
0000@@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`<000000`3oool2000000<0oooo0`0000030?ooo`80
00000`3oool200000080oooo00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3o
ool01`3oool001D0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo0`0000030?ooo`8000000`3oool00`000000oooo000000030?ooo`8000000`3oool200000080
oooo0P0000030?ooo`8000000P3oool00`000000oooo0?ooo`070?ooo`005@3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`070?ooo`070000
003oool0oooo0?ooo`000000oooo000000080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000000`3oool2000000<0oooo00<000000?oo
o`0000000`3oool2000000<0oooo0P0000020?ooo`8000000`3oool200000080oooo00<000000?oo
o`3oool01`3oool001D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0200000080
oooo00<000000?ooo`3oool01`3oool01`000000oooo0?ooo`3oool000000?ooo`000000203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool3
000000<0oooo0`0000020?ooo`030000003oool0000000<0oooo0P0000030?ooo`8000000P3oool2
000000<0oooo0P0000020?ooo`030000003oool0oooo00L0oooo000E0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P0000000`3oool000000?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000000`3oool300000080oooo00<000000?oo
o`3oool00`3oool2000000<0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`8000000`3oool0
0`000000oooo0?ooo`060?ooo`001`3oool4000000<0oooo0P0000050?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P0000000`3oool000000?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`800000103oool300000080oooo00<000000?oo
o`3oool00`3oool200000080oooo00<000000?ooo`3oool00P3oool300000080oooo0P0000030?oo
o`030000003oool0oooo00H0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P0000020?oo
o`030000003oool0oooo00P0oooo00H000000?ooo`00000000000?ooo`0000080?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo
000000020?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo0080oooo
0`0000020?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00P3oool3000004<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0P0000020?ooo`030000003oool0oooo00P0oooo00H000000?ooo`00000000000?ooo`0000080?oo
o`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`800000103oool0
0`000000oooo000000020?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`030000003oool0
oooo0080oooo0`0000020?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`002@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003o
ool0oooo008000000P3oool00`000000oooo0?ooo`080?ooo`060000003oool000000000003oool0
0000203oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool20000
00@0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`8000000P3oool00`00
0000oooo0?ooo`020?ooo`<000000P3oool2000000<0oooo00<000000?ooo`3oool01P3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`0000003P3oool0
0`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0203oool01P000000oooo00000000
0000oooo000000P0oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool0oooo0080
oooo0P0000040?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3oool200000080
oooo00<000000?ooo`3oool00P3oool300000080oooo0P0000030?ooo`030000003oool0oooo00H0
oooo00070?ooo`<000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?oo
o`3oool00P0000020?ooo`030000003oool0oooo00P0oooo00H000000?ooo`00000000000?ooo`00
00080?ooo`050000003oool000000?ooo`0000001P3oool00`000000oooo000000020?ooo`800000
103oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo0P0000020?ooo`030000
003oool0oooo0080oooo0`0000020?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`002@3o
ool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo00800000
0P3oool00`000000oooo0?ooo`080?ooo`060000003oool000000000003oool00000203oool01@00
0000oooo0000003oool0000000H0oooo00<000000?ooo`0000000P3oool2000000@0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`8000000P3oool00`000000oooo0?ooo`02
0?ooo`<000000P3oool2000000<0oooo00<000000?ooo`3oool01P3oool001D0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`0000003P3oool0
0`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool0203oool01P000000oooo00000000
0000oooo000000P0oooo00D000000?ooo`000000oooo000000060?ooo`030000003oool000000080
oooo0P0000060?ooo`040000003oool0oooo000000D0oooo0P0000020?ooo`030000003oool0oooo
0080oooo0`0000020?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`005@3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000000>0?oo
o`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`080?ooo`040000003oool00000
0?ooo`800000203oool01@000000oooo0000003oool0000000H0oooo00<000000?ooo`0000000P3o
ool2000000H0oooo00@000000?ooo`3oool000001@3oool200000080oooo00<000000?ooo`3oool0
0P3oool300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`005@3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo
0000000>0?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`080?ooo`040000
003oool000000?ooo`800000203oool00`000000oooo00000002000000H0oooo00D000000?ooo`00
000000000?ooo`02000000H0oooo00@000000?ooo`3oool000001@3oool200000080oooo00<00000
0?ooo`3oool00P3oool3000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool01P3oool0
01D0oooo0P0000170?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000000>
0?ooo`080000003oool0oooo0000003oool000000?ooo`00000:0?ooo`040000003oool000000?oo
o`800000203oool00`000000oooo00000002000000H0oooo00D000000?ooo`00000000000?ooo`02
000000H0oooo00@000000?ooo`3oool000001@3oool200000080oooo00<000000?ooo`3oool00P3o
ool3000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool01P3oool001D0oooo00<00000
0?ooo`3oool0A`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`0000003P3o
ool020000000oooo0?ooo`000000oooo0000003oool000002P3oool010000000oooo0000003oool2
000000P0oooo00<000000?ooo`0000000P0000070?ooo`<0000000<0oooo0000000000001P3oool0
10000000oooo0000000000050?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`<0000000<0
oooo0000003oool0103oool00`000000oooo0?ooo`060?ooo`005@3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`080000003o
ool0oooo0000003oool000000?ooo`00000:0?ooo`040000003oool000000?ooo`800000203oool0
0`000000oooo00000002000000L0oooo0`0000000`3oool000000?ooo`060?ooo`040000003oool0
0000000000D0oooo0P0000020?ooo`030000003oool0oooo0080oooo0`0000000`3oool000000?oo
o`040?ooo`030000003oool0oooo00H0oooo000E0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0503oool01@000000oooo0?ooo`3oool0000000h0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000X0oooo00@000000?ooo`000000oooo0P0000080?ooo`030000003oool0
0000008000001`3oool3000000030?ooo`000000oooo00H0oooo00@000000?ooo`00000000001@3o
ool2000000030?ooo`000000000000@0oooo0`0000000`3oool000000?ooo`040?ooo`030000003o
ool0oooo00H0oooo000E0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool0
10000000oooo0?ooo`00000?0?ooo`080000003oool0oooo0000003oool000000?ooo`00000:0?oo
o`040000003oool000000?ooo`800000203oool00`000000oooo00000002000000L0oooo0`000000
0`3oool000000?ooo`060?ooo`040000003oool00000000000D0oooo0P0000000`3oool000000000
00040?ooo`<0000000<0oooo0000003oool0103oool00`000000oooo0?ooo`060?ooo`005@3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool000003`3o
ool020000000oooo0?ooo`000000oooo0000003oool000002P3oool010000000oooo0000003oool2
000000P0oooo00<000000?ooo`0000000P0000070?ooo`<0000000<0oooo0000003oool01P3oool0
10000000oooo0000000000050?ooo`80000000<0oooo000000000000103oool3000000030?ooo`00
0000oooo00@0oooo00<000000?ooo`3oool01P3oool001D0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0E0?ooo`040000003oool0oooo000000l0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000X0oooo00@000000?ooo`000000oooo0P0000080?ooo`030000003oool0
0000008000001`3oool3000000030?ooo`000000oooo00H0oooo100000050?ooo`80000000<0oooo
000000000000103oool3000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool01P3oool0
01D0oooo0P00001:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool000003`3oool0
1@000000oooo0?ooo`000000oooo008000002`3oool010000000oooo0000003oool2000000P0oooo
00<000000?ooo`0000000P0000070?ooo`<0000000<0oooo0000003oool01P3oool4000000D0oooo
0P0000000`3oool00000000000040?ooo`D000001@3oool00`000000oooo0?ooo`060?ooo`005@3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool00000
3`3oool01@000000oooo0?ooo`000000oooo008000002`3oool010000000oooo0000003oool20000
00P0oooo00<000000?ooo`0000000P0000070?ooo`@00000203oool4000000D0oooo0P0000000`3o
ool00000000000040?ooo`D000001@3oool00`000000oooo0?ooo`060?ooo`005@3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool000003`3oool01@00
0000oooo0?ooo`000000oooo008000002`3oool010000000oooo0000003oool2000000P0oooo00<0
00000?ooo`0000000P0000070?ooo`@00000203oool4000000D0oooo0P0000000`3oool000000000
00040?ooo`D000001@3oool00`000000oooo0?ooo`060?ooo`005@3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool09@3oool01@000000oooo0?ooo`3o
ool0000001L0oooo00@000000?ooo`3oool000003`3oool01@000000oooo0?ooo`000000oooo0080
00002`3oool010000000oooo0000003oool2000000P0oooo00<000000?ooo`0000000P0000070?oo
o`@00000203oool4000000D0oooo0P0000000`3oool00000000000040?ooo`D000001@3oool00`00
0000oooo0?ooo`060?ooo`005@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool09@3oool01@000000oooo0?ooo`3oool0000001L0oooo00@000000?oo
o`3oool000003`3oool01@000000oooo0?ooo`000000oooo008000002`3oool010000000oooo0000
003oool2000000P0oooo00<000000?ooo`0000000P0000070?ooo`@00000203oool4000000H0oooo
00@000000?ooo`00000000001@3oool4000000D0oooo00<000000?ooo`3oool01P3oool001D0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02H0oooo
00D000000?ooo`3oool0oooo0000000G0?ooo`040000003oool0oooo000000l0oooo00D000000?oo
o`3oool000000?ooo`02000000/0oooo00@000000?ooo`000000oooo0P0000080?ooo`030000003o
ool00000008000001`3oool4000000P0oooo100000060?ooo`040000003oool00000000000D0oooo
100000050?ooo`030000003oool0oooo00H0oooo000E0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0V0?ooo`050000003oool0oooo0?ooo`000000
603oool00`000000oooo0000000?0?ooo`030000003oool000000080oooo0P00000;0?ooo`040000
003oool000000?ooo`800000203oool00`000000oooo00000002000000L0oooo100000080?ooo`@0
00001P3oool010000000oooo0000000000050?ooo`@000001@3oool00`000000oooo0?ooo`060?oo
o`005@3oool2000004d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0V0?ooo`05
0000003oool0oooo0?ooo`000000603oool00`000000oooo0000000?0?ooo`030000003oool00000
0080oooo0P00000;0?ooo`050000003oool000000?ooo`0000002@3oool00`000000oooo00000002
000000L0oooo100000080?ooo`@000001P3oool010000000oooo0000000000060?ooo`<000001@3o
ool00`000000oooo0?ooo`060?ooo`005@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool09P3oool01@000000oooo0?ooo`3oool0000001P0oooo00<0
00000?ooo`000000403oool200000080oooo0P00000;0?ooo`050000003oool000000?ooo`000000
2@3oool2000000030?ooo`000000000000L0oooo100000080?ooo`@000001P3oool010000000oooo
0000000000060?ooo`<000001@3oool00`000000oooo0?ooo`060?ooo`005@3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09`3oool01@000000oooo
0?ooo`3oool0000001P0oooo00<000000?ooo`000000403oool200000080oooo0P00000;0?ooo`03
0000003oool0000000/0oooo0P0000000`3oool00000000000070?ooo`@00000203oool4000000H0
oooo00@000000?ooo`00000000001P3oool3000000D0oooo00<000000?ooo`3oool01P3oool001D0
oooo00<000000?ooo`3oool0CP3oool4000002X0oooo00D000000?ooo`3oool0oooo0000000H0?oo
o`030000003oool000000100oooo0P0000020?ooo`8000002`3oool00`000000oooo0000000;0?oo
o`80000000<0oooo0000000000001`3oool4000000P0oooo100000060?ooo`040000003oool00000
000000H0oooo0`0000050?ooo`030000003oool0oooo00H0oooo000E0?ooo`030000003oool0oooo
04l0oooo0P00000[0?ooo`050000003oool0oooo0?ooo`000000603oool00`000000oooo0000000@
0?ooo`8000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000/0oooo0P000000
0`3oool00000000000070?ooo`@00000203oool4000000H0oooo00@000000?ooo`00000000001P3o
ool3000000D0oooo00<000000?ooo`3oool01P3oool001D0oooo00<000000?ooo`3oool0O03oool0
1@000000oooo0?ooo`3oool0000001P0oooo00<000000?ooo`000000403oool2000000<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0000000;0?ooo`80000000<0oooo0000000000001`3o
ool4000000P0oooo100000060?ooo`040000003oool00000000000H0oooo0`0000060?ooo`030000
003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo07`0oooo00D000000?ooo`3oool0oooo
0000000H0?ooo`030000003oool000000100oooo0P00000?0?ooo`030000003oool0000000/0oooo
0P0000000`3oool00000000000070?ooo`@00000203oool4000000H0oooo00@000000?ooo`000000
00001P3oool3000000H0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0000000I0?ooo`030000003oool000000100oooo0P00000?0?ooo`030000
003oool0000000/0oooo0P0000000`3oool00000000000070?ooo`@00000203oool4000000H0oooo
00@000000?ooo`00000000001P3oool3000000H0oooo00<000000?ooo`3oool01@3oool001D0oooo
0P00001n0?ooo`030000003oool0000001T0oooo00<000000?ooo`000000403oool2000000l0oooo
00<000000?ooo`0000002`3oool2000000030?ooo`000000000000L0oooo100000080?ooo`@00000
1P3oool4000000H0oooo0`0000060?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003o
ool0oooo07d0oooo00<000000?ooo`0000006@3oool00`000000oooo0000000@0?ooo`8000003`3o
ool00`000000oooo0000000;0?ooo`80000000<0oooo0000000000001`3oool4000000P0oooo1000
00060?ooo`@000001P3oool3000000H0oooo00<000000?ooo`3oool01@3oool001D0oooo00<00000
0?ooo`3oool0O@3oool00`000000oooo0000000I0?ooo`030000003oool000000100oooo0P00000?
0?ooo`030000003oool0000000/0oooo0P0000000`3oool00000000000070?ooo`@00000203oool4
000000H0oooo100000060?ooo`<000001P3oool00`000000oooo0?ooo`050?ooo`005@3oool00`00
0000oooo0?ooo`1m0?ooo`030000003oool0000001T0oooo00<000000?ooo`000000403oool20000
00l0oooo00<000000?ooo`0000002`3oool2000000030?ooo`000000000000L0oooo100000080?oo
o`@000001P3oool4000000H0oooo0`0000060?ooo`030000003oool0oooo00D0oooo000E0?ooo`03
0000003oool0oooo07d0oooo00<000000?ooo`0000006@3oool00`000000oooo0000000@0?ooo`80
00003`3oool00`000000oooo0000000;0?ooo`80000000<0oooo0000000000001`3oool4000000P0
oooo100000060?ooo`@000001P3oool3000000H0oooo00<000000?ooo`3oool01@3oool000L0oooo
100000030?ooo`8000001@3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0000001T0oooo
00<000000?ooo`000000403oool2000000l0oooo0P00000<0?ooo`8000000P3oool00`000000oooo
0?ooo`050?ooo`040000003oool00000000000P0oooo100000060?ooo`80000000<0oooo0000003o
ool01@3oool3000000H0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07d0oooo00<000000?ooo`00
00006@3oool00`000000oooo0000000@0?ooo`8000003`3oool2000000`0oooo0P0000020?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`0000000000203oool4000000H0oooo0P0000000`3o
ool000000?ooo`050?ooo`<000001P3oool00`000000oooo0?ooo`050?ooo`00203oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0`00001m0?ooo`030000003oool00000
01T0oooo00<000000?ooo`000000403oool2000000l0oooo0P00000<0?ooo`8000000P3oool00`00
0000oooo0?ooo`070?ooo`800000203oool4000000H0oooo0P0000000`3oool000000?ooo`050?oo
o`<000001P3oool00`000000oooo0?ooo`050?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0>0?ooo`800000303oool20000
00`0oooo0P0000080?ooo`@000001P3oool2000000030?ooo`000000oooo00D0oooo0`0000060?oo
o`030000003oool0oooo00D0oooo000:0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo01P0oooo0P00000R0?oo
o`800000303oool2000000`0oooo0P0000080?ooo`@000001P3oool2000000030?ooo`000000oooo
00D0oooo0`0000060?ooo`030000003oool0oooo00D0oooo00070?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2I0?ooo`8000008P3oool2
000000`0oooo0P00000<0?ooo`800000203oool4000000H0oooo0P0000000`3oool000000?ooo`05
0?ooo`<000001P3oool00`000000oooo0?ooo`050?ooo`00203oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo09X0oooo00<000000?ooo`3oool0803oool2000000`0oooo0P00000<0?oo
o`800000203oool4000000H0oooo0P0000000`3oool000000?ooo`050?ooo`<000001P3oool00`00
0000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0200
oooo0P00000<0?ooo`800000303oool2000000P0oooo100000060?ooo`80000000<0oooo0000003o
ool01@3oool3000000H0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0
VP3oool00`000000oooo0?ooo`0P0?ooo`800000303oool2000000`0oooo0P0000080?ooo`@00000
1P3oool2000000030?ooo`000000oooo00D0oooo0`00000>0?ooo`005@3oool00`000000oooo0?oo
o`2m0?ooo`800000303oool2000000`0oooo0P0000080?ooo`@000001P3oool2000000030?ooo`00
0000oooo00D0oooo0`00000>0?ooo`005@3oool200000;l0oooo00<000000?ooo`3oool02P3oool2
000000`0oooo0P0000080?ooo`80000000<0oooo0000003oool01@3oool2000000030?ooo`000000
oooo00D0oooo0`00000>0?ooo`005@3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02P3oool2000000P0oooo0P0000000`3oool000000?ooo`050?oo
o`800000203oool3000000h0oooo000E0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0:0?ooo`800000203oool2000000030?ooo`000000oooo00H0
oooo00<000000?ooo`3oool01P3oool3000000h0oooo000E0?ooo`030000003oool0oooo0;h0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`800000203oool2000000030?oo
o`000000oooo00H0oooo00<000000?ooo`3oool01P3oool3000000h0oooo000E0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`800000203o
ool2000000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool01P3oool3000000h0oooo000E
0?ooo`030000003oool0oooo0=T0oooo0P0000080?ooo`8000002@3oool00`000000oooo0?ooo`06
0?ooo`<000003P3oool001D0oooo00<000000?ooo`3oool0fP3oool00`000000oooo0?ooo`060?oo
o`8000002@3oool00`000000oooo0?ooo`060?ooo`<000003P3oool001D0oooo0P00003K0?ooo`03
0000003oool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo00H0oooo0P00000?0?ooo`00
5@3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo00H0oooo0P0000090?ooo`030000
003oool0oooo00H0oooo0P00000?0?ooo`005@3oool00`000000oooo0?ooo`3J0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`060?ooo`8000003`3o
ool001D0oooo00<000000?ooo`3oool0fP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00H0oooo0P00000?0?ooo`005@3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool01P3oool2000000l0oooo000E0?ooo`030000003oool0oooo0>h0
oooo00<000000?ooo`3oool01P3oool2000000l0oooo000E0?ooo`030000003oool0oooo0>h0oooo
00<000000?ooo`3oool01P3oool2000000l0oooo000E0?ooo`030000003oool0oooo0>h0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`005@3oool200000>l0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`005@3oool00`000000oooo0?ooo`3g0?oo
o`030000003oool0oooo00h0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo
00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E
0?ooo`030000003oool0oooo0?l0oooo2@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.330384, -18.9319, \
0.015437, 0.269078}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NMinimize[f[x], {x, 0, 4}, 
      Method \[Rule] {DifferentialEvolution, 
          SearchPoints \[Rule] 50}]\)], "Input"],

Cell[BoxData[
    \({\(-16.71189354315345`\), {x \[Rule] 2.2364041708210616`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["More functionality from an optimizer", "Subsection"],

Cell["\<\
Further desired features include handling constraints, integer\
\[Hyphen]valued variables, and so forth. Such functionality is becoming ever \
more prevalent in both commercial and other software, as needs in industry \
and elsewhere increase. I show a simple example of an integer programming \
problem, shamelessly stolen from my session talk yesterday. We are given \
143267 coins in pennies, nickels, dimes, and quarters, of total value \
$12563.29, and we are to determine how many coins might be of each \
type.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      solutions = \(NMinimize[{1, {p + 5\ n + 10\ d + 25\ q == 1256329, 
                p + n + d + q == 143267, {p, n, d, q} \[Element] Integers, 
                0 \[LessEqual] p \[LessEqual] 1256329, 
                0 \[LessEqual] n \[LessEqual] 1256329\/5, 
                0 \[LessEqual] d \[LessEqual] 1256329\/10, 
                0 \[LessEqual] q \[LessEqual] 1256329\/25}}, {p, n, d, q}, 
            MaxIterations \[Rule] 500, 
            Method \[Rule] {DifferentialEvolution, 
                RandomSeed \[Rule] 
                  Random[Integer, 1000]}]\)[\([2]\)]]\)], "Input",
  FontSize->18],

Cell[BoxData[
    \({33.678999999999995`\ Second, {d \[Rule] 2606, n \[Rule] 42032, 
        p \[Rule] 60234, q \[Rule] 38395}}\)], "Output"]
}, Open  ]],

Cell["\<\
One can check that this is a valid solution to this integer \
programming problem.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Some programming examples (snooze)", "Section"],

Cell["\<\
Most modern technical computation software has some form of \
programming language to handle situations in which an \"out of the box\" \
method is not available. An old adage which I made up last week: \"When you \
can't find it, fake it, or steal it, just code it.\"\
\>", "Text"],

Cell[CellGroupData[{

Cell["Simple graphing example (skip me)", "Subsection"],

Cell["\<\
This first example throws together some simple linear algebra and \
calculus functions for the purpose of obtaining \"tube\" plots about given \
curves.\
\>", "Text"],

Cell[BoxData[{
    \(<< LinearAlgebra`Orthogonalization`\), "\n", 
    \(tubeplot[curve_List, range_List, radius_] := 
      Module[{perps, var = First[range], theta}, 
        perps = GramSchmidt[
            NullSpace[{D[curve, var]}]]; \[IndentingNewLine]ParametricPlot3D[
          Evaluate[
            curve + radius*Transpose[perps] . {Sin[theta], Cos[theta]}], 
          Evaluate[range], {theta, 0, 2*Pi}, 
          PlotPoints \[Rule] 50];]\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(curve2 = {t, Sin[t], 0};\)\), "\n", 
    \(tubeplot[curve2, {t, \(-5\), 5}, 1]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .58944 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0173544 1.01735 -0.190404 1.01735 [
[.05295 .26251 -5.37798 -9 ]
[.05295 .26251 6.62202 0 ]
[.22494 .20255 -11.2332 -9 ]
[.22494 .20255 12.7668 0 ]
[.40593 .13945 -2.9376 -9 ]
[.40593 .13945 3.0624 0 ]
[.59666 .07299 -9.23472 -9 ]
[.59666 .07299 8.76528 0 ]
[.79793 .00287 -3.23176 -9 ]
[.79793 .00287 2.76824 0 ]
[.85915 .00101 0 -6.05956 ]
[.85915 .00101 12 2.94044 ]
[.89444 .05368 0 -6.02107 ]
[.89444 .05368 12 2.97893 ]
[.92833 .10428 0 -5.98443 ]
[.92833 .10428 6 3.01557 ]
[.96092 .15292 0 -5.94952 ]
[.96092 .15292 6 3.05048 ]
[.99227 .19972 0 -5.91621 ]
[.99227 .19972 6 3.08379 ]
[.99567 .20748 0 -5.91104 ]
[.99567 .20748 12 3.08896 ]
[.9996 .24079 0 -5.89083 ]
[.9996 .24079 24 3.10917 ]
[1.0036 .27463 0 -5.87033 ]
[1.0036 .27463 6 3.12967 ]
[1.00766 .30901 0 -5.84951 ]
[1.00766 .30901 18 3.15049 ]
[1.01179 .34396 0 -5.82838 ]
[1.01179 .34396 6 3.17162 ]
[ 0 0 0 0 ]
[ 1 .58944 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01574 .28763 m
.84367 0 L
s
.05164 .27516 m
.05099 .28149 L
s
[(-5)] .05295 .26251 -0.10367 1 Mshowa
.22413 .21524 m
.22372 .22158 L
s
[(-2.5)] .22494 .20255 -0.0639 1 Mshowa
.40567 .15217 m
.40553 .15852 L
s
[(0)] .40593 .13945 -0.0208 1 Mshowa
.59699 .0857 m
.59716 .09206 L
s
[(2.5)] .59666 .07299 .02608 1 Mshowa
.79891 .01555 m
.7994 .02189 L
s
[(5)] .79793 .00287 .07725 1 Mshowa
.125 Mabswid
.08545 .26342 m
.08508 .26721 L
s
.11959 .25155 m
.11926 .25535 L
s
.15409 .23957 m
.15378 .24337 L
s
.18893 .22747 m
.18865 .23127 L
s
.25969 .20288 m
.25948 .20669 L
s
.29562 .1904 m
.29544 .19421 L
s
.33192 .17779 m
.33177 .1816 L
s
.3686 .16504 m
.36849 .16886 L
s
.44312 .13915 m
.44308 .14297 L
s
.48098 .126 m
.48097 .12982 L
s
.51924 .11271 m
.51926 .11653 L
s
.55791 .09928 m
.55797 .10309 L
s
.6365 .07197 m
.63664 .07579 L
s
.67644 .0581 m
.67661 .06191 L
s
.71682 .04407 m
.71703 .04788 L
s
.75764 .02989 m
.75789 .03369 L
s
.01817 .28679 m
.01775 .29058 L
s
.84065 .00105 m
.84098 .00485 L
s
.25 Mabswid
.84367 0 m
.98315 .20803 L
s
.84713 .00517 m
.84113 .00725 L
s
[(-2)] .85915 .00101 -1 .34657 Mshowa
.88239 .05776 m
.87637 .05979 L
s
[(-1)] .89444 .05368 -1 .33802 Mshowa
.91626 .10827 m
.91022 .11026 L
s
[(0)] .92833 .10428 -1 .32987 Mshowa
.94881 .15682 m
.94276 .15877 L
s
[(1)] .96092 .15292 -1 .32211 Mshowa
.98014 .20353 m
.97407 .20544 L
s
[(2)] .99227 .19972 -1 .31471 Mshowa
.125 Mabswid
.8543 .01586 m
.85069 .01711 L
s
.86141 .02646 m
.8578 .0277 L
s
.86846 .03698 m
.86485 .03821 L
s
.87545 .04741 m
.87184 .04864 L
s
.88927 .06802 m
.88566 .06924 L
s
.8961 .0782 m
.89248 .07941 L
s
.90287 .0883 m
.89925 .08951 L
s
.90959 .09832 m
.90597 .09952 L
s
.92287 .11813 m
.91925 .11932 L
s
.92943 .12792 m
.92581 .1291 L
s
.93594 .13763 m
.93232 .13881 L
s
.9424 .14726 m
.93877 .14844 L
s
.95517 .16631 m
.95154 .16747 L
s
.96149 .17572 m
.95785 .17688 L
s
.96775 .18506 m
.96411 .18622 L
s
.97397 .19433 m
.97033 .19548 L
s
.25 Mabswid
.98315 .20803 m
1 .35105 L
s
.98353 .21129 m
.97747 .21319 L
s
[(-1)] .99567 .20748 -1 .31356 Mshowa
.98745 .24454 m
.98138 .24642 L
s
[(-0.5)] .9996 .24079 -1 .30907 Mshowa
.99143 .27833 m
.98535 .28018 L
s
[(0)] 1.0036 .27463 -1 .30452 Mshowa
.99548 .31267 m
.98939 .31449 L
s
[(0.5)] 1.00766 .30901 -1 .29989 Mshowa
.99959 .34756 m
.99349 .34936 L
s
[(1)] 1.01179 .34396 -1 .2952 Mshowa
.125 Mabswid
.98431 .2179 m
.98067 .21904 L
s
.98509 .22453 m
.98145 .22566 L
s
.98588 .23118 m
.98223 .23231 L
s
.98666 .23785 m
.98302 .23898 L
s
.98824 .25126 m
.9846 .25238 L
s
.98904 .25799 m
.98539 .25912 L
s
.98983 .26475 m
.98618 .26587 L
s
.99063 .27153 m
.98698 .27265 L
s
.99224 .28516 m
.98859 .28626 L
s
.99304 .292 m
.98939 .29311 L
s
.99385 .29887 m
.9902 .29997 L
s
.99466 .30576 m
.99101 .30685 L
s
.99629 .3196 m
.99264 .32069 L
s
.99711 .32656 m
.99346 .32765 L
s
.99794 .33354 m
.99428 .33462 L
s
.99876 .34054 m
.9951 .34162 L
s
.25 Mabswid
.01574 .28763 m
0 .42841 L
s
0 .42841 m
.19113 .58944 L
s
.19113 .58944 m
.20006 .45392 L
s
.20006 .45392 m
.01574 .28763 L
s
.84367 0 m
.98315 .20803 L
s
.98315 .20803 m
1 .35105 L
s
1 .35105 m
.85682 .14805 L
s
.85682 .14805 m
.84367 0 L
s
.01574 .28763 m
0 .42841 L
s
0 .42841 m
.85682 .14805 L
s
.85682 .14805 m
.84367 0 L
s
.84367 0 m
.01574 .28763 L
s
.20006 .45392 m
.98315 .20803 L
s
.98315 .20803 m
1 .35105 L
s
1 .35105 m
.19113 .58944 L
s
.19113 .58944 m
.20006 .45392 L
s
0 0 m
1 0 L
1 .58944 L
0 .58944 L
closepath
clip
newpath
.5 Mabswid
.23122 .46725 m .20451 .47217 L .2034 .46243 L p .653 .527 .698 r
F P
0 g
s
.2034 .46243 m .22915 .45766 L .23122 .46725 L p .653 .527 .698 r
F P
0 g
s
.22915 .45766 m .2034 .46243 L .20196 .45277 L p .657 .552 .724 r
F P
0 g
s
.20196 .45277 m .22657 .4482 L .22915 .45766 L p .657 .552 .724 r
F P
0 g
s
.22657 .4482 m .20196 .45277 L .20021 .44335 L p .661 .576 .749 r
F P
0 g
s
.23276 .4768 m .20527 .48184 L .20451 .47217 L p .647 .502 .672 r
F P
0 g
s
.20451 .47217 m .23122 .46725 L .23276 .4768 L p .647 .502 .672 r
F P
0 g
s
.20021 .44335 m .22352 .43899 L .22657 .4482 L p .661 .576 .749 r
F P
0 g
s
.22352 .43899 m .20021 .44335 L .19817 .43429 L p .665 .601 .774 r
F P
0 g
s
.23374 .48617 m .20566 .4913 L .20527 .48184 L p .64 .474 .643 r
F P
0 g
s
.20527 .48184 m .23276 .4768 L .23374 .48617 L p .64 .474 .643 r
F P
0 g
s
.19817 .43429 m .22006 .43019 L .22352 .43899 L p .665 .601 .774 r
F P
0 g
s
.22006 .43019 m .19817 .43429 L .19588 .42575 L p .667 .627 .8 r
F P
0 g
s
.23414 .49523 m .20569 .5004 L .20566 .4913 L p .632 .444 .611 r
F P
0 g
s
.20566 .4913 m .23374 .48617 L .23414 .49523 L p .632 .444 .611 r
F P
0 g
s
.25575 .45928 m .23122 .46725 L .22915 .45766 L p .612 .501 .703 r
F P
0 g
s
.22915 .45766 m .25274 .44996 L .25575 .45928 L p .612 .501 .703 r
F P
0 g
s
.25274 .44996 m .22915 .45766 L .22657 .4482 L p .621 .53 .73 r
F P
0 g
s
.22657 .4482 m .24907 .44081 L .25274 .44996 L p .621 .53 .73 r
F P
0 g
s
.24907 .44081 m .22657 .4482 L .22352 .43899 L p .629 .558 .755 r
F P
0 g
s
.25804 .46862 m .23276 .4768 L .23122 .46725 L p .602 .471 .674 r
F P
0 g
s
.23122 .46725 m .25575 .45928 L .25804 .46862 L p .602 .471 .674 r
F P
0 g
s
.22352 .43899 m .24478 .43198 L .24907 .44081 L p .629 .558 .755 r
F P
0 g
s
.24478 .43198 m .22352 .43899 L .22006 .43019 L p .637 .586 .781 r
F P
0 g
s
.19588 .42575 m .21623 .42192 L .22006 .43019 L p .667 .627 .8 r
F P
0 g
s
.21623 .42192 m .19588 .42575 L .19337 .41786 L p .668 .655 .827 r
F P
0 g
s
.23396 .50382 m .20534 .509 L .20569 .5004 L p .621 .41 .575 r
F P
0 g
s
.20569 .5004 m .23414 .49523 L .23396 .50382 L p .621 .41 .575 r
F P
0 g
s
.25958 .47785 m .23374 .48617 L .23276 .4768 L p .59 .438 .643 r
F P
0 g
s
.23276 .4768 m .25804 .46862 L .25958 .47785 L p .59 .438 .643 r
F P
0 g
s
.22006 .43019 m .23995 .4236 L .24478 .43198 L p .637 .586 .781 r
F P
0 g
s
.23995 .4236 m .22006 .43019 L .21623 .42192 L p .643 .615 .807 r
F P
0 g
s
.26034 .48683 m .23414 .49523 L .23374 .48617 L p .576 .402 .608 r
F P
0 g
s
.23374 .48617 m .25958 .47785 L .26034 .48683 L p .576 .402 .608 r
F P
0 g
s
.19337 .41786 m .21209 .41433 L .21623 .42192 L p .668 .655 .827 r
F P
0 g
s
.21209 .41433 m .19337 .41786 L .19067 .41074 L p .668 .685 .857 r
F P
0 g
s
.21623 .42192 m .23465 .4158 L .23995 .4236 L p .643 .615 .807 r
F P
0 g
s
.23465 .4158 m .21623 .42192 L .21209 .41433 L p .65 .646 .833 r
F P
0 g
s
.23319 .51181 m .20463 .51696 L .20534 .509 L p .608 .37 .531 r
F P
0 g
s
.20534 .509 m .23396 .50382 L .23319 .51181 L p .608 .37 .531 r
F P
0 g
s
.26031 .4954 m .23396 .50382 L .23414 .49523 L p .559 .36 .567 r
F P
0 g
s
.23414 .49523 m .26034 .48683 L .26031 .4954 L p .559 .36 .567 r
F P
0 g
s
.2727 .43982 m .25274 .44996 L .24907 .44081 L p .579 .507 .738 r
F P
0 g
s
.24907 .44081 m .26814 .43108 L .2727 .43982 L p .579 .507 .738 r
F P
0 g
s
.26814 .43108 m .24907 .44081 L .24478 .43198 L p .592 .54 .765 r
F P
0 g
s
.27647 .44881 m .25575 .45928 L .25274 .44996 L p .564 .473 .71 r
F P
0 g
s
.25274 .44996 m .2727 .43982 L .27647 .44881 L p .564 .473 .71 r
F P
0 g
s
.24478 .43198 m .26284 .42271 L .26814 .43108 L p .592 .54 .765 r
F P
0 g
s
.26284 .42271 m .24478 .43198 L .23995 .4236 L p .605 .573 .791 r
F P
0 g
s
.27937 .45789 m .25804 .46862 L .25575 .45928 L p .547 .436 .679 r
F P
0 g
s
.25575 .45928 m .27647 .44881 L .27937 .45789 L p .547 .436 .679 r
F P
0 g
s
.21209 .41433 m .22895 .40869 L .23465 .4158 L p .65 .646 .833 r
F P
0 g
s
.22895 .40869 m .21209 .41433 L .2077 .40752 L p .655 .679 .861 r
F P
0 g
s
.19067 .41074 m .2077 .40752 L .21209 .41433 L p .668 .685 .857 r
F P
0 g
s
.23995 .4236 m .2569 .41486 L .26284 .42271 L p .605 .573 .791 r
F P
0 g
s
.2569 .41486 m .23995 .4236 L .23465 .4158 L p .618 .606 .817 r
F P
0 g
s
.2077 .40752 m .19067 .41074 L .18784 .40451 L p .665 .718 .888 r
F P
0 g
s
.23184 .51907 m .20355 .52416 L .20463 .51696 L p .589 .321 .478 r
F P
0 g
s
.20463 .51696 m .23319 .51181 L .23184 .51907 L p .589 .321 .478 r
F P
0 g
s
.28137 .46695 m .25958 .47785 L .25804 .46862 L p .528 .395 .643 r
F P
0 g
s
.25804 .46862 m .27937 .45789 L .28137 .46695 L p .528 .395 .643 r
F P
0 g
s
.25948 .50344 m .23319 .51181 L .23396 .50382 L p .538 .31 .517 r
F P
0 g
s
.23396 .50382 m .26031 .4954 L .25948 .50344 L p .538 .31 .517 r
F P
0 g
s
.23465 .4158 m .2504 .40763 L .2569 .41486 L p .618 .606 .817 r
F P
0 g
s
.2504 .40763 m .23465 .4158 L .22895 .40869 L p .629 .64 .842 r
F P
0 g
s
.28243 .47582 m .26034 .48683 L .25958 .47785 L p .506 .349 .603 r
F P
0 g
s
.25958 .47785 m .28137 .46695 L .28243 .47582 L p .506 .349 .603 r
F P
0 g
s
.2077 .40752 m .22295 .4024 L .22895 .40869 L p .655 .679 .861 r
F P
0 g
s
.22295 .4024 m .2077 .40752 L .20314 .40161 L p .659 .716 .891 r
F P
0 g
s
.18784 .40451 m .20314 .40161 L .2077 .40752 L p .665 .718 .888 r
F P
0 g
s
.22895 .40869 m .24344 .40114 L .2504 .40763 L p .629 .64 .842 r
F P
0 g
s
.24344 .40114 m .22895 .40869 L .22295 .4024 L p .641 .676 .868 r
F P
0 g
s
.20314 .40161 m .18784 .40451 L .1849 .39927 L p .657 .756 .923 r
F P
0 g
s
.22993 .52549 m .20214 .53047 L .20355 .52416 L p .563 .258 .408 r
F P
0 g
s
.20355 .52416 m .23184 .51907 L .22993 .52549 L p .563 .258 .408 r
F P
0 g
s
.25786 .51082 m .23184 .51907 L .23319 .51181 L p .51 .249 .455 r
F P
0 g
s
.23319 .51181 m .25948 .50344 L .25786 .51082 L p .51 .249 .455 r
F P
0 g
s
.28252 .48438 m .26031 .4954 L .26034 .48683 L p .479 .296 .554 r
F P
0 g
s
.26034 .48683 m .28243 .47582 L .28252 .48438 L p .479 .296 .554 r
F P
0 g
s
.28859 .4281 m .2727 .43982 L .26814 .43108 L p .534 .486 .749 r
F P
0 g
s
.26814 .43108 m .28339 .41976 L .28859 .4281 L p .534 .486 .749 r
F P
0 g
s
.28339 .41976 m .26814 .43108 L .26284 .42271 L p .555 .525 .777 r
F P
0 g
s
.26284 .42271 m .27738 .41187 L .28339 .41976 L p .555 .525 .777 r
F P
0 g
s
.27738 .41187 m .26284 .42271 L .2569 .41486 L p .574 .562 .803 r
F P
0 g
s
.20314 .40161 m .21674 .39703 L .22295 .4024 L p .659 .716 .891 r
F P
0 g
s
.21674 .39703 m .20314 .40161 L .19847 .39669 L p .66 .757 .922 r
F P
0 g
s
.1849 .39927 m .19847 .39669 L .20314 .40161 L p .657 .756 .923 r
F P
0 g
s
.2929 .43676 m .27647 .44881 L .2727 .43982 L p .511 .445 .718 r
F P
0 g
s
.2727 .43982 m .28859 .4281 L .2929 .43676 L p .511 .445 .718 r
F P
0 g
s
.22295 .4024 m .23614 .3955 L .24344 .40114 L p .641 .676 .868 r
F P
0 g
s
.23614 .3955 m .22295 .4024 L .21674 .39703 L p .652 .715 .894 r
F P
0 g
s
.2569 .41486 m .27065 .40453 L .27738 .41187 L p .574 .562 .803 r
F P
0 g
s
.27065 .40453 m .2569 .41486 L .2504 .40763 L p .593 .599 .828 r
F P
0 g
s
.29624 .44559 m .27937 .45789 L .27647 .44881 L p .486 .399 .683 r
F P
0 g
s
.27647 .44881 m .2929 .43676 L .29624 .44559 L p .486 .399 .683 r
F P
0 g
s
.28164 .49248 m .25948 .50344 L .26031 .4954 L p .444 .231 .494 r
F P
0 g
s
.26031 .4954 m .28252 .48438 L .28164 .49248 L p .444 .231 .494 r
F P
0 g
s
.2504 .40763 m .26331 .39788 L .27065 .40453 L p .593 .599 .828 r
F P
0 g
s
.26331 .39788 m .2504 .40763 L .24344 .40114 L p .611 .636 .852 r
F P
0 g
s
.25548 .51741 m .22993 .52549 L .23184 .51907 L p .47 .17 .373 r
F P
0 g
s
.23184 .51907 m .25786 .51082 L .25548 .51741 L p .47 .17 .373 r
F P
0 g
s
.19847 .39669 m .1849 .39927 L .18191 .39511 L p .639 .799 .959 r
F P
0 g
s
.22748 .53095 m .2004 .5358 L .20214 .53047 L p .524 .173 .314 r
F P
0 g
s
.20214 .53047 m .22993 .52549 L .22748 .53095 L p .524 .173 .314 r
F P
0 g
s
.29857 .45446 m .28137 .46695 L .27937 .45789 L p .456 .348 .643 r
F P
0 g
s
.27937 .45789 m .29624 .44559 L .29857 .45446 L p .456 .348 .643 r
F P
0 g
s
.24344 .40114 m .25547 .39201 L .26331 .39788 L p .611 .636 .852 r
F P
0 g
s
.25547 .39201 m .24344 .40114 L .23614 .3955 L p .628 .675 .875 r
F P
0 g
s
.21674 .39703 m .22859 .3908 L .23614 .3955 L p .652 .715 .894 r
F P
0 g
s
.22859 .3908 m .21674 .39703 L .21041 .39266 L p .662 .758 .921 r
F P
0 g
s
.19847 .39669 m .21041 .39266 L .21674 .39703 L p .66 .757 .922 r
F P
0 g
s
.21041 .39266 m .19847 .39669 L .19376 .39286 L p .655 .803 .954 r
F P
0 g
s
.18191 .39511 m .19376 .39286 L .19847 .39669 L p .639 .799 .959 r
F P
0 g
s
.29984 .46324 m .28243 .47582 L .28137 .46695 L p .421 .289 .594 r
F P
0 g
s
.28137 .46695 m .29857 .45446 L .29984 .46324 L p .421 .289 .594 r
F P
0 g
s
.2798 .5 m .25786 .51082 L .25948 .50344 L p .398 .149 .416 r
F P
0 g
s
.25948 .50344 m .28164 .49248 L .2798 .5 L p .398 .149 .416 r
F P
0 g
s
.23614 .3955 m .24725 .38702 L .25547 .39201 L p .628 .675 .875 r
F P
0 g
s
.24725 .38702 m .23614 .3955 L .22859 .3908 L p .646 .715 .898 r
F P
0 g
s
.25235 .5231 m .22748 .53095 L .22993 .52549 L p .412 .063 .26 r
F P
0 g
s
.22993 .52549 m .25548 .51741 L .25235 .5231 L p .412 .063 .26 r
F P
0 g
s
.19376 .39286 m .18191 .39511 L .17892 .39211 L p .601 .841 .99 r
F P
0 g
s
.22454 .53536 m .19835 .54004 L .2004 .5358 L p .461 .053 .178 r
F P
0 g
s
.2004 .5358 m .22748 .53095 L .22454 .53536 L p .461 .053 .178 r
F P
0 g
s
.21041 .39266 m .22093 .38711 L .22859 .3908 L p .662 .758 .921 r
F P
0 g
s
.22093 .38711 m .21041 .39266 L .20406 .38938 L p .67 .805 .947 r
F P
0 g
s
.19376 .39286 m .20406 .38938 L .21041 .39266 L p .655 .803 .954 r
F P
0 g
s
.30002 .47178 m .28252 .48438 L .28243 .47582 L p .378 .218 .534 r
F P
0 g
s
.28243 .47582 m .29984 .46324 L .30002 .47178 L p .378 .218 .534 r
F P
0 g
s
.29534 .4075 m .28339 .41976 L .27738 .41187 L p .519 .513 .789 r
F P
0 g
s
.27738 .41187 m .28886 .4 L .29534 .4075 L p .519 .513 .789 r
F P
0 g
s
.28886 .4 m .27738 .41187 L .27065 .40453 L p .546 .555 .815 r
F P
0 g
s
.22859 .3908 m .23877 .38298 L .24725 .38702 L p .646 .715 .898 r
F P
0 g
s
.23877 .38298 m .22859 .3908 L .22093 .38711 L p .664 .758 .92 r
F P
0 g
s
.27065 .40453 m .28162 .39312 L .28886 .4 L p .546 .555 .815 r
F P
0 g
s
.28162 .39312 m .27065 .40453 L .26331 .39788 L p .571 .595 .839 r
F P
0 g
s
.30095 .4155 m .28859 .4281 L .28339 .41976 L p .49 .468 .76 r
F P
0 g
s
.28339 .41976 m .29534 .4075 L .30095 .4155 L p .49 .468 .76 r
F P
0 g
s
.20406 .38938 m .19376 .39286 L .18909 .39018 L p .638 .852 .982 r
F P
0 g
s
.17892 .39211 m .18909 .39018 L .19376 .39286 L p .601 .841 .99 r
F P
0 g
s
.27703 .50681 m .25548 .51741 L .25786 .51082 L p .335 .042 .311 r
F P
0 g
s
.25786 .51082 m .2798 .5 L .27703 .50681 L p .335 .042 .311 r
F P
0 g
s
.26331 .39788 m .27374 .38696 L .28162 .39312 L p .571 .595 .839 r
F P
0 g
s
.27374 .38696 m .26331 .39788 L .25547 .39201 L p .595 .635 .861 r
F P
0 g
s
.30561 .42387 m .2929 .43676 L .28859 .4281 L p .458 .419 .726 r
F P
0 g
s
.28859 .4281 m .30095 .4155 L .30561 .42387 L p .458 .419 .726 r
F P
0 g
s
.25547 .39201 m .26532 .38162 L .27374 .38696 L p .595 .635 .861 r
F P
0 g
s
.26532 .38162 m .25547 .39201 L .24725 .38702 L p .618 .675 .882 r
F P
0 g
s
.29911 .47995 m .28164 .49248 L .28252 .48438 L p .323 .13 .457 r
F P
0 g
s
.28252 .48438 m .30002 .47178 L .29911 .47995 L p .323 .13 .457 r
F P
0 g
s
.30925 .43248 m .29624 .44559 L .2929 .43676 L p .422 .364 .687 r
F P
0 g
s
.2929 .43676 m .30561 .42387 L .30925 .43248 L p .422 .364 .687 r
F P
0 g
s
.24854 .5278 m .22454 .53536 L .22748 .53095 L p .321 0 .096 r
F P
0 g
s
.22748 .53095 m .25235 .5231 L .24854 .5278 L p .321 0 .096 r
F P
0 g
s
.20406 .38938 m .21326 .38449 L .22093 .38711 L p .67 .805 .947 r
F P
0 g
s
.21326 .38449 m .20406 .38938 L .19779 .38723 L p .672 .856 .97 r
F P
0 g
s
.18909 .39018 m .19779 .38723 L .20406 .38938 L p .638 .852 .982 r
F P
0 g
s
.22093 .38711 m .23018 .37997 L .23877 .38298 L p .664 .758 .92 r
F P
0 g
s
.23018 .37997 m .22093 .38711 L .21326 .38449 L p .681 .804 .94 r
F P
0 g
s
.18909 .39018 m .17892 .39211 L .17597 .39033 L p .517 .866 .99 r
F P
0 g
s
.22114 .53865 m .19604 .54312 L .19835 .54004 L p .354 0 0 r
F P
0 g
s
.19835 .54004 m .22454 .53536 L .22114 .53865 L p .354 0 0 r
F P
0 g
s
.24725 .38702 m .25652 .37718 L .26532 .38162 L p .618 .675 .882 r
F P
0 g
s
.25652 .37718 m .24725 .38702 L .23877 .38298 L p .642 .715 .901 r
F P
0 g
s
.31179 .44121 m .29857 .45446 L .29624 .44559 L p .379 .3 .64 r
F P
0 g
s
.29624 .44559 m .30925 .43248 L .31179 .44121 L p .379 .3 .64 r
F P
0 g
s
.27335 .5128 m .25235 .5231 L .25548 .51741 L p .243 0 .164 r
F P
0 g
s
.25548 .51741 m .27703 .50681 L .27335 .5128 L p .243 0 .164 r
F P
0 g
s
.19779 .38723 m .18909 .39018 L .18453 .3887 L p .593 .894 .989 r
F P
0 g
s
.17597 .39033 m .18453 .3887 L .18909 .39018 L p .517 .866 .99 r
F P
0 g
s
.29712 .48762 m .2798 .5 L .28164 .49248 L p .249 .018 .354 r
F P
0 g
s
.28164 .49248 m .29911 .47995 L .29712 .48762 L p .249 .018 .354 r
F P
0 g
s
.23877 .38298 m .24745 .37371 L .25652 .37718 L p .642 .715 .901 r
F P
0 g
s
.24745 .37371 m .23877 .38298 L .23018 .37997 L p .666 .757 .919 r
F P
0 g
s
.3132 .44991 m .29984 .46324 L .29857 .45446 L p .327 .224 .581 r
F P
0 g
s
.29857 .45446 m .31179 .44121 L .3132 .44991 L p .327 .224 .581 r
F P
0 g
s
.21326 .38449 m .2216 .37803 L .23018 .37997 L p .681 .804 .94 r
F P
0 g
s
.2216 .37803 m .21326 .38449 L .20572 .38301 L p .697 .853 .957 r
F P
0 g
s
.19779 .38723 m .20572 .38301 L .21326 .38449 L p .672 .856 .97 r
F P
0 g
s
.20572 .38301 m .19779 .38723 L .19171 .38627 L p .66 .906 .98 r
F P
0 g
s
.18453 .3887 m .19171 .38627 L .19779 .38723 L p .593 .894 .989 r
F P
0 g
s
.24409 .53142 m .22114 .53865 L .22454 .53536 L p .176 0 0 r
F P
0 g
s
.22454 .53536 m .24854 .5278 L .24409 .53142 L p .176 0 0 r
F P
0 g
s
.23018 .37997 m .23826 .37128 L .24745 .37371 L p .666 .757 .919 r
F P
0 g
s
.23826 .37128 m .23018 .37997 L .2216 .37803 L p .69 .801 .934 r
F P
0 g
s
.18453 .3887 m .17597 .39033 L .17311 .3898 L p .347 .819 .896 r
F P
0 g
s
.29801 .38748 m .28886 .4 L .28162 .39312 L p .522 .55 .825 r
F P
0 g
s
.28162 .39312 m .29045 .38094 L .29801 .38748 L p .522 .55 .825 r
F P
0 g
s
.29045 .38094 m .28162 .39312 L .27374 .38696 L p .553 .593 .848 r
F P
0 g
s
.21734 .54074 m .1935 .54498 L .19604 .54312 L p .17 0 0 r
F P
0 g
s
.19604 .54312 m .22114 .53865 L .21734 .54074 L p .17 0 0 r
F P
0 g
s
.30478 .39467 m .29534 .4075 L .28886 .4 L p .489 .504 .799 r
F P
0 g
s
.28886 .4 m .29801 .38748 L .30478 .39467 L p .489 .504 .799 r
F P
0 g
s
.26883 .51786 m .24854 .5278 L .25235 .5231 L p .108 0 0 r
F P
0 g
s
.25235 .5231 m .27335 .5128 L .26883 .51786 L p .108 0 0 r
F P
0 g
s
.31345 .45844 m .30002 .47178 L .29984 .46324 L p .263 .131 .506 r
F P
0 g
s
.29984 .46324 m .3132 .44991 L .31345 .45844 L p .263 .131 .506 r
F P
0 g
s
.27374 .38696 m .28222 .37515 L .29045 .38094 L p .553 .593 .848 r
F P
0 g
s
.28222 .37515 m .27374 .38696 L .26532 .38162 L p .582 .635 .869 r
F P
0 g
s
.29407 .49465 m .27703 .50681 L .2798 .5 L p .149 0 .213 r
F P
0 g
s
.2798 .5 m .29712 .48762 L .29407 .49465 L p .149 0 .213 r
F P
0 g
s
.31065 .40241 m .30095 .4155 L .29534 .4075 L p .452 .453 .769 r
F P
0 g
s
.29534 .4075 m .30478 .39467 L .31065 .40241 L p .452 .453 .769 r
F P
0 g
s
.19171 .38627 m .18453 .3887 L .18017 .38847 L p .491 .894 .933 r
F P
0 g
s
.17311 .3898 m .18017 .38847 L p .17802 .38933 L .347 .819 .896 r
F P
0 g
s
.18017 .38847 m .17311 .3898 L .17039 .39055 L p 0 0 0 r
F P
0 g
s
.17606 .38948 m .18017 .38847 L p .17442 .38969 L 0 0 0 r
F P
0 g
s
.17039 .39055 m .17606 .38948 L p .17442 .38969 L 0 0 0 r
F P
0 g
s
.17606 .38948 m .17229 .39174 L p .17766 .38928 L 0 0 0 r
F P
0 g
s
.18017 .38847 m .17606 .38948 L p .18235 .38759 L .297 .788 .749 r
F P
0 g
s
.18049 .38797 m .18591 .38651 L p .17976 .38837 L .297 .788 .749 r
F P
0 g
s
.17606 .38948 m .18049 .38797 L p .17976 .38837 L .297 .788 .749 r
F P
0 g
s
.18049 .38797 m .17555 .39064 L p .18137 .38751 L .338 .784 .625 r
F P
0 g
s
.18049 .38797 m .18502 .38554 L .19148 .38353 L p .519 .917 .849 r
F P
0 g
s
.18502 .38554 m .18049 .38797 L p .18137 .38751 L .338 .784 .625 r
F P
0 g
s
.18049 .38797 m .17606 .38948 L p .17766 .38928 L 0 0 0 r
F P
0 g
s
.18591 .38651 m .18017 .38847 L p .18235 .38759 L .297 .788 .749 r
F P
0 g
s
.18017 .38847 m .18453 .3887 L p .17802 .38933 L .347 .819 .896 r
F P
0 g
s
.26532 .38162 m .27346 .37021 L .28222 .37515 L p .582 .635 .869 r
F P
0 g
s
.27346 .37021 m .26532 .38162 L .25652 .37718 L p .611 .675 .887 r
F P
0 g
s
.20572 .38301 m .21318 .3772 L .2216 .37803 L p .697 .853 .957 r
F P
0 g
s
.21318 .3772 m .20572 .38301 L .19842 .38268 L p .707 .905 .966 r
F P
0 g
s
.19171 .38627 m .19842 .38268 L .20572 .38301 L p .66 .906 .98 r
F P
0 g
s
.31554 .41057 m .30561 .42387 L .30095 .4155 L p .41 .396 .733 r
F P
0 g
s
.30095 .4155 m .31065 .40241 L .31554 .41057 L p .41 .396 .733 r
F P
0 g
s
.25652 .37718 m .26428 .3662 L .27346 .37021 L p .611 .675 .887 r
F P
0 g
s
.26428 .3662 m .25652 .37718 L .24745 .37371 L p .639 .716 .903 r
F P
0 g
s
.2216 .37803 m .22911 .36992 L .23826 .37128 L p .69 .801 .934 r
F P
0 g
s
.22911 .36992 m .2216 .37803 L .21318 .3772 L p .713 .848 .946 r
F P
0 g
s
.19842 .38268 m .19171 .38627 L .18591 .38651 L p .619 .94 .954 r
F P
0 g
s
.18017 .38847 m .18591 .38651 L .19171 .38627 L p .491 .894 .933 r
F P
0 g
s
.31252 .46667 m .29911 .47995 L .30002 .47178 L p .179 .013 .405 r
F P
0 g
s
.30002 .47178 m .31345 .45844 L .31252 .46667 L p .179 .013 .405 r
F P
0 g
s
.31935 .41902 m .30925 .43248 L .30561 .42387 L p .362 .331 .689 r
F P
0 g
s
.30561 .42387 m .31554 .41057 L .31935 .41902 L p .362 .331 .689 r
F P
0 g
s
.23907 .5339 m .21734 .54074 L .22114 .53865 L p 0 0 0 r
F P
0 g
s
.22114 .53865 m .24409 .53142 L .23907 .5339 L p 0 0 0 r
F P
0 g
s
.22114 .53865 m .23907 .5339 L .23907 .5339 L 0 0 0 r
F
.1935 .54498 m .21734 .54074 L .21318 .54159 L p F P
0 g
s
.23356 .53517 m .21318 .54159 L .21733 .54074 L p .295 .789 .768 r
F P
0 g
s
.23907 .5339 m .23907 .5339 L p .23907 .5339 L 0 0 0 r
F P
0 g
s
.24745 .37371 m .25485 .36317 L .26428 .3662 L p .639 .716 .903 r
F P
0 g
s
.25485 .36317 m .24745 .37371 L .23826 .37128 L p .667 .757 .918 r
F P
0 g
s
.29001 .50093 m .27335 .5128 L .27703 .50681 L p .009 0 .017 r
F P
0 g
s
.27703 .50681 m .29407 .49465 L .29001 .50093 L p .009 0 .017 r
F P
0 g
s
.26353 .5219 m .24409 .53142 L .24854 .5278 L p 0 0 0 r
F P
0 g
s
.24854 .5278 m .26883 .51786 L .26353 .5219 L p 0 0 0 r
F P
0 g
s
.21318 .54159 m .19076 .54558 L .1935 .54498 L p 0 0 0 r
F P
0 g
s
.32204 .42764 m .31179 .44121 L .30925 .43248 L p .305 .254 .635 r
F P
0 g
s
.30925 .43248 m .31935 .41902 L .32204 .42764 L p .305 .254 .635 r
F P
0 g
s
.19842 .38268 m .20503 .37751 L .21318 .3772 L p .707 .905 .966 r
F P
0 g
s
.20503 .37751 m .19842 .38268 L .19148 .38353 L p .704 .951 .954 r
F P
0 g
s
.18591 .38651 m .19148 .38353 L .19842 .38268 L p .619 .94 .954 r
F P
0 g
s
.21318 .3772 m .22012 .36966 L .22911 .36992 L p .713 .848 .946 r
F P
0 g
s
.22012 .36966 m .21318 .3772 L .20503 .37751 L p .736 .897 .952 r
F P
0 g
s
.23826 .37128 m .2453 .36118 L .25485 .36317 L p .667 .757 .918 r
F P
0 g
s
.2453 .36118 m .23826 .37128 L .22911 .36992 L p .695 .799 .929 r
F P
0 g
s
.31043 .47447 m .29712 .48762 L .29911 .47995 L p .068 0 .269 r
F P
0 g
s
.29911 .47995 m .31252 .46667 L .31043 .47447 L p .068 0 .269 r
F P
0 g
s
.19148 .38353 m .18591 .38651 L .18049 .38797 L p .519 .917 .849 r
F P
0 g
s
.32354 .43628 m .3132 .44991 L .31179 .44121 L p .234 .16 .564 r
F P
0 g
s
.31179 .44121 m .32204 .42764 L .32354 .43628 L p .234 .16 .564 r
F P
0 g
s
.28498 .50636 m .26883 .51786 L .27335 .5128 L p 0 0 0 r
F P
0 g
s
.27335 .5128 m .29001 .50093 L .28498 .50636 L p 0 0 0 r
F P
0 g
s
.22911 .36992 m .23579 .36026 L .2453 .36118 L p .695 .799 .929 r
F P
0 g
s
.23579 .36026 m .22911 .36992 L .22012 .36966 L p .724 .842 .938 r
F P
0 g
s
.21734 .54074 m .23907 .5339 L .23356 .53517 L p .295 .789 .768 r
F P
0 g
s
.3055 .37452 m .29801 .38748 L .29045 .38094 L p .504 .547 .833 r
F P
0 g
s
.29045 .38094 m .29774 .36821 L .3055 .37452 L p .504 .547 .833 r
F P
0 g
s
.29774 .36821 m .29045 .38094 L .28222 .37515 L p .54 .592 .855 r
F P
0 g
s
.28222 .37515 m .28931 .36268 L .29774 .36821 L p .54 .592 .855 r
F P
0 g
s
.28931 .36268 m .28222 .37515 L .27346 .37021 L p .573 .635 .875 r
F P
0 g
s
.20503 .37751 m .21145 .37051 L .22012 .36966 L p .736 .897 .952 r
F P
0 g
s
.21145 .37051 m .20503 .37751 L .19731 .37895 L p .753 .944 .944 r
F P
0 g
s
.19148 .38353 m .19731 .37895 L .20503 .37751 L p .704 .951 .954 r
F P
0 g
s
.25752 .52486 m .23907 .5339 L .24409 .53142 L p 0 0 0 r
F P
0 g
s
.24409 .53142 m .26353 .5219 L .25752 .52486 L p 0 0 0 r
F P
0 g
s
.31246 .38151 m .30478 .39467 L .29801 .38748 L p .465 .497 .807 r
F P
0 g
s
.29801 .38748 m .3055 .37452 L .31246 .38151 L p .465 .497 .807 r
F P
0 g
s
.27346 .37021 m .28032 .35802 L .28931 .36268 L p .573 .635 .875 r
F P
0 g
s
.28032 .35802 m .27346 .37021 L .26428 .3662 L p .605 .676 .891 r
F P
0 g
s
.19731 .37895 m .19148 .38353 L .18502 .38554 L p .672 .973 .899 r
F P
0 g
s
.30721 .4817 m .29407 .49465 L .29712 .48762 L p 0 0 .082 r
F P
0 g
s
.29712 .48762 m .31043 .47447 L .30721 .4817 L p 0 0 .082 r
F P
0 g
s
.17606 .38948 m .17039 .39055 L .16786 .39258 L p .189 0 0 r
F P
0 g
s
.31849 .38907 m .31065 .40241 L .30478 .39467 L p .421 .442 .776 r
F P
0 g
s
.30478 .39467 m .31246 .38151 L .31849 .38907 L p .421 .442 .776 r
F P
0 g
s
.32383 .44481 m .31345 .45844 L .3132 .44991 L p .144 .042 .47 r
F P
0 g
s
.3132 .44991 m .32354 .43628 L .32383 .44481 L p .144 .042 .47 r
F P
0 g
s
.26428 .3662 m .27092 .35429 L .28032 .35802 L p .605 .676 .891 r
F P
0 g
s
.27092 .35429 m .26428 .3662 L .25485 .36317 L p .637 .717 .905 r
F P
0 g
s
.20875 .54117 m .18786 .54489 L .19076 .54558 L p .361 .824 .914 r
F P
0 g
s
.19076 .54558 m .21318 .54159 L .20875 .54117 L p .361 .824 .914 r
F P
0 g
s
.16786 .39258 m .17229 .39174 L .17606 .38948 L p .189 0 0 r
F P
0 g
s
.22012 .36966 m .22646 .36043 L .23579 .36026 L p .724 .842 .938 r
F P
0 g
s
.22646 .36043 m .22012 .36966 L .21145 .37051 L p .752 .887 .94 r
F P
0 g
s
.32352 .39709 m .31554 .41057 L .31065 .40241 L p .371 .378 .737 r
F P
0 g
s
.31065 .40241 m .31849 .38907 L .32352 .39709 L p .371 .378 .737 r
F P
0 g
s
.25485 .36317 m .26126 .35157 L .27092 .35429 L p .637 .717 .905 r
F P
0 g
s
.26126 .35157 m .25485 .36317 L .2453 .36118 L p .667 .757 .917 r
F P
0 g
s
.17229 .39174 m .17555 .39064 L .18049 .38797 L p 0 0 0 r
F P
0 g
s
.27907 .51083 m .26353 .5219 L .26883 .51786 L p 0 0 0 r
F P
0 g
s
.26883 .51786 m .28498 .50636 L .27907 .51083 L p 0 0 0 r
F P
0 g
s
.19731 .37895 m .20324 .37246 L .21145 .37051 L p .753 .944 .944 r
F P
0 g
s
.20324 .37246 m .19731 .37895 L .19014 .38151 L p .756 .982 .911 r
F P
0 g
s
.18502 .38554 m .19014 .38151 L .19731 .37895 L p .672 .973 .899 r
F P
0 g
s
.3229 .4531 m .31252 .46667 L .31345 .45844 L p .029 0 .344 r
F P
0 g
s
.31345 .45844 m .32383 .44481 L .3229 .4531 L p .029 0 .344 r
F P
0 g
s
.32746 .40544 m .31935 .41902 L .31554 .41057 L p .312 .304 .689 r
F P
0 g
s
.31554 .41057 m .32352 .39709 L .32746 .40544 L p .312 .304 .689 r
F P
0 g
s
.2453 .36118 m .25149 .34988 L .26126 .35157 L p .667 .757 .917 r
F P
0 g
s
.25149 .34988 m .2453 .36118 L .23579 .36026 L p .698 .797 .926 r
F P
0 g
s
.22765 .53522 m .20875 .54117 L .21318 .54159 L p .486 .888 .943 r
F P
0 g
s
.21318 .54159 m .23356 .53517 L .22765 .53522 L p .486 .888 .943 r
F P
0 g
s
.30289 .48824 m .29001 .50093 L .29407 .49465 L p 0 0 0 r
F P
0 g
s
.29407 .49465 m .30721 .4817 L .30289 .48824 L p 0 0 0 r
F P
0 g
s
.19014 .38151 m .18502 .38554 L .17915 .38869 L p .584 .934 .765 r
F P
0 g
s
.17915 .38869 m .17396 .39295 L p .17945 .38852 L 0 0 0 r
F P
0 g
s
.18363 .38516 m .19014 .38151 L p .18359 .38579 L .584 .934 .765 r
F P
0 g
s
.17915 .38869 m .18363 .38516 L p .18359 .38579 L .584 .934 .765 r
F P
0 g
s
.18363 .38516 m .17915 .38869 L p .17945 .38852 L 0 0 0 r
F P
0 g
s
.17915 .38869 m .18502 .38554 L p .17893 .38882 L .338 .784 .625 r
F P
0 g
s
.17555 .39064 m .17915 .38869 L p .17893 .38882 L .338 .784 .625 r
F P
0 g
s
.17915 .38869 m .17555 .39064 L .17116 .39446 L p 0 0 0 r
F P
0 g
s
.17116 .39446 m .17396 .39295 L .17915 .38869 L p 0 0 0 r
F P
0 g
s
.17789 .38983 m .18363 .38516 L p .17775 .38989 L 0 0 0 r
F P
0 g
s
.17396 .39295 m .17789 .38983 L p .17775 .38989 L 0 0 0 r
F P
0 g
s
.17789 .38983 m .17304 .39547 L p .17808 .38975 L 0 0 0 r
F P
0 g
s
.18363 .38516 m .17789 .38983 L p .18368 .38433 L .65 .936 .675 r
F P
0 g
s
.18263 .38459 m .18871 .37955 L p .18248 .38547 L .65 .936 .675 r
F P
0 g
s
.17789 .38983 m .18263 .38459 L p .18248 .38547 L .65 .936 .675 r
F P
0 g
s
.18263 .38459 m .17789 .38983 L p .17808 .38975 L 0 0 0 r
F P
0 g
s
.1775 .39053 m .18263 .38459 L p .17711 .39085 L 0 0 0 r
F P
0 g
s
.17304 .39547 m .1775 .39053 L p .17711 .39085 L 0 0 0 r
F P
0 g
s
.1775 .39053 m .17341 .39728 L p .17799 .39014 L 0 0 0 r
F P
0 g
s
.18263 .38459 m .1775 .39053 L p .18282 .38352 L .69 .91 .567 r
F P
0 g
s
.18236 .38332 m .18765 .37715 L p .18173 .38496 L .69 .91 .567 r
F P
0 g
s
.1775 .39053 m .18236 .38332 L p .18173 .38496 L .69 .91 .567 r
F P
0 g
s
.18236 .38332 m .1775 .39053 L p .17799 .39014 L 0 0 0 r
F P
0 g
s
.17814 .39025 m .18236 .38332 L p .17717 .39141 L 0 0 0 r
F P
0 g
s
.17341 .39728 m .17814 .39025 L p .17717 .39141 L 0 0 0 r
F P
0 g
s
.17814 .39025 m .17506 .39783 L p .17926 .38891 L 0 0 0 r
F P
0 g
s
.18236 .38332 m .17814 .39025 L p .18309 .38142 L .687 .847 .427 r
F P
0 g
s
.18292 .38111 m .18722 .37404 L p .18147 .3843 L .687 .847 .427 r
F P
0 g
s
.17814 .39025 m .18292 .38111 L p .18147 .3843 L .687 .847 .427 r
F P
0 g
s
.19199 .36303 m .18722 .37404 L .18292 .3811 L p .767 .892 .486 r
F P
0 g
s
.18292 .3811 m .18292 .38111 L p .18293 .3811 L .767 .892 .486 r
F P
0 g
s
.18293 .3811 m .19199 .36303 L .18292 .3811 L .767 .892 .486 r
F
.18765 .37017 m .19199 .36303 L p .18522 .37652 L F P
0 g
s
.18292 .38111 m .18765 .37017 L p .18522 .37652 L .767 .892 .486 r
F P
0 g
s
.18451 .37791 m .18765 .37018 L p .18183 .38398 L 0 0 0 r
F P
0 g
s
.17981 .38878 m .18451 .37791 L p .18183 .38398 L 0 0 0 r
F P
0 g
s
.18722 .37404 m .18236 .38332 L p .18309 .38142 L .687 .847 .427 r
F P
0 g
s
.18765 .37715 m .18263 .38459 L p .18282 .38352 L .69 .91 .567 r
F P
0 g
s
.19392 .37182 m .18871 .37955 L .18263 .38459 L p .775 .987 .746 r
F P
0 g
s
.18263 .38459 m .18765 .37715 L .19392 .37182 L p .775 .987 .746 r
F P
0 g
s
.19261 .3677 m .18765 .37715 L .18236 .38332 L p .792 .959 .636 r
F P
0 g
s
.18236 .38332 m .18722 .37404 L .19261 .3677 L p .792 .959 .636 r
F P
0 g
s
.18451 .37791 m .18261 .38611 L p .18745 .37123 L 0 0 0 r
F P
0 g
s
.18765 .37018 m .18765 .37017 L p .18765 .37018 L 0 0 0 r
F P
0 g
s
.17981 .38878 m .18765 .37018 L .18765 .37018 L 0 0 0 r
F
.18765 .37017 m .18292 .38111 L p .18456 .37751 L F P
0 g
s
.18765 .37017 m .18451 .37791 L p .19033 .36318 L .675 .765 .281 r
F P
0 g
s
.19245 .35782 m .18765 .37017 L p .19033 .36318 L .675 .765 .281 r
F P
0 g
s
.19744 .35658 m .19261 .3677 L .18722 .37404 L p .841 .975 .669 r
F P
0 g
s
.18722 .37404 m .19199 .36303 L .19744 .35658 L p .841 .975 .669 r
F P
0 g
s
.19681 .35063 m .19199 .36303 L .18765 .37017 L p .801 .91 .512 r
F P
0 g
s
.18765 .37017 m .19245 .35782 L .19681 .35063 L p .801 .91 .512 r
F P
0 g
s
.18929 .36559 m .19245 .35782 L p .18477 .37724 L .675 .765 .281 r
F P
0 g
s
.18451 .37791 m .18929 .36559 L p .18477 .37724 L .675 .765 .281 r
F P
0 g
s
.20198 .33719 m .19681 .35063 L .19245 .35782 L p .804 .911 .514 r
F P
0 g
s
.19245 .35782 m .19762 .34438 L .20198 .33719 L p .804 .911 .514 r
F P
0 g
s
.19762 .34438 m .19245 .35782 L .18929 .36559 L p .679 .768 .284 r
F P
0 g
s
.18929 .36559 m .19445 .35216 L .19762 .34438 L p .679 .768 .284 r
F P
0 g
s
.18929 .36559 m .18739 .37382 L p .1942 .35292 L 0 0 0 r
F P
0 g
s
.19445 .35216 m .18929 .36559 L p .1942 .35292 L 0 0 0 r
F P
0 g
s
.18261 .38611 m .18739 .37382 L .18929 .36559 L p 0 0 0 r
F P
0 g
s
.18929 .36559 m .18451 .37791 L p .18745 .37123 L 0 0 0 r
F P
0 g
s
.18292 .38111 m .17981 .38878 L p .18456 .37751 L 0 0 0 r
F P
0 g
s
.18292 .38111 m .17814 .39025 L p .17926 .38891 L 0 0 0 r
F P
0 g
s
.18871 .37955 m .18363 .38516 L p .18368 .38433 L .65 .936 .675 r
F P
0 g
s
.25092 .52666 m .23356 .53517 L .23907 .5339 L p .495 .906 .858 r
F P
0 g
s
.23907 .5339 m .25752 .52486 L .25092 .52666 L p .495 .906 .858 r
F P
0 g
s
.21145 .37051 m .21747 .3617 L .22646 .36043 L p .752 .887 .94 r
F P
0 g
s
.21747 .3617 m .21145 .37051 L .20324 .37246 L p .778 .932 .933 r
F P
0 g
s
.17229 .39174 m .16786 .39258 L .16555 .39585 L p .368 0 .006 r
F P
0 g
s
.33023 .41399 m .32204 .42764 L .31935 .41902 L p .24 .214 .628 r
F P
0 g
s
.31935 .41902 m .32746 .40544 L .33023 .41399 L p .24 .214 .628 r
F P
0 g
s
.20411 .53949 m .18487 .54292 L .18786 .54489 L p .522 .861 .994 r
F P
0 g
s
.18786 .54489 m .20875 .54117 L .20411 .53949 L p .522 .861 .994 r
F P
0 g
s
.23579 .36026 m .24176 .34927 L .25149 .34988 L p .698 .797 .926 r
F P
0 g
s
.24176 .34927 m .23579 .36026 L .22646 .36043 L p .73 .838 .931 r
F P
0 g
s
.17555 .39064 m .17229 .39174 L .16891 .39523 L p .173 0 0 r
F P
0 g
s
.16555 .39585 m .16891 .39523 L .17229 .39174 L p .368 0 .006 r
F P
0 g
s
.32075 .461 m .31043 .47447 L .31252 .46667 L p 0 0 .171 r
F P
0 g
s
.31252 .46667 m .3229 .4531 L .32075 .461 L p 0 0 .171 r
F P
0 g
s
.16891 .39523 m .17116 .39446 L .17555 .39064 L p .173 0 0 r
F P
0 g
s
.27238 .51427 m .25752 .52486 L .26353 .5219 L p .546 .92 .769 r
F P
0 g
s
.26353 .5219 m .27907 .51083 L .27238 .51427 L p .546 .92 .769 r
F P
0 g
s
.19014 .38151 m .19561 .37549 L .20324 .37246 L p .756 .982 .911 r
F P
0 g
s
.19561 .37549 m .19014 .38151 L .18363 .38516 L p .73 .99 .831 r
F P
0 g
s
.29754 .49398 m .28498 .50636 L .29001 .50093 L p 0 0 0 r
F P
0 g
s
.29001 .50093 m .30289 .48824 L .29754 .49398 L p 0 0 0 r
F P
0 g
s
.20324 .37246 m .20896 .36404 L .21747 .3617 L p .778 .932 .933 r
F P
0 g
s
.20896 .36404 m .20324 .37246 L .19561 .37549 L p .798 .972 .909 r
F P
0 g
s
.33179 .4226 m .32354 .43628 L .32204 .42764 L p .151 .104 .546 r
F P
0 g
s
.32204 .42764 m .33023 .41399 L .33179 .4226 L p .151 .104 .546 r
F P
0 g
s
.22646 .36043 m .23222 .34974 L .24176 .34927 L p .73 .838 .931 r
F P
0 g
s
.23222 .34974 m .22646 .36043 L .21747 .3617 L p .761 .88 .932 r
F P
0 g
s
.30402 .35518 m .29774 .36821 L .28931 .36268 L p .531 .592 .86 r
F P
0 g
s
.28931 .36268 m .29545 .3498 L .30402 .35518 L p .531 .592 .86 r
F P
0 g
s
.29545 .3498 m .28931 .36268 L .28032 .35802 L p .568 .636 .878 r
F P
0 g
s
.31191 .36136 m .3055 .37452 L .29774 .36821 L p .492 .545 .838 r
F P
0 g
s
.29774 .36821 m .30402 .35518 L .31191 .36136 L p .492 .545 .838 r
F P
0 g
s
.28032 .35802 m .28633 .34529 L .29545 .3498 L p .568 .636 .878 r
F P
0 g
s
.28633 .34529 m .28032 .35802 L .27092 .35429 L p .602 .677 .894 r
F P
0 g
s
.22144 .53403 m .20411 .53949 L .20875 .54117 L p .586 .884 .992 r
F P
0 g
s
.20875 .54117 m .22765 .53522 L .22144 .53403 L p .586 .884 .992 r
F P
0 g
s
.24381 .52729 m .22765 .53522 L .23356 .53517 L p .6 .929 .961 r
F P
0 g
s
.23356 .53517 m .25092 .52666 L .24381 .52729 L p .6 .929 .961 r
F P
0 g
s
.31898 .36824 m .31246 .38151 L .3055 .37452 L p .449 .493 .812 r
F P
0 g
s
.3055 .37452 m .31191 .36136 L .31898 .36824 L p .449 .493 .812 r
F P
0 g
s
.27092 .35429 m .27679 .34173 L .28633 .34529 L p .602 .677 .894 r
F P
0 g
s
.27679 .34173 m .27092 .35429 L .26126 .35157 L p .635 .717 .906 r
F P
0 g
s
.32512 .37571 m .31849 .38907 L .31246 .38151 L p .4 .434 .78 r
F P
0 g
s
.31246 .38151 m .31898 .36824 L .32512 .37571 L p .4 .434 .78 r
F P
0 g
s
.31742 .46839 m .30721 .4817 L .31043 .47447 L p 0 0 0 r
F P
0 g
s
.31043 .47447 m .32075 .461 L .31742 .46839 L p 0 0 0 r
F P
0 g
s
.26126 .35157 m .26699 .33917 L .27679 .34173 L p .635 .717 .906 r
F P
0 g
s
.26699 .33917 m .26126 .35157 L .25149 .34988 L p .668 .756 .917 r
F P
0 g
s
.16891 .39523 m .16555 .39585 L .16351 .40034 L p .473 .074 .203 r
F P
0 g
s
.19934 .53656 m .18181 .53969 L .18487 .54292 L p .601 .832 .987 r
F P
0 g
s
.18487 .54292 m .20411 .53949 L .19934 .53656 L p .601 .832 .987 r
F P
0 g
s
.33211 .43114 m .32383 .44481 L .32354 .43628 L p .038 0 .434 r
F P
0 g
s
.32354 .43628 m .33179 .4226 L .33211 .43114 L p .038 0 .434 r
F P
0 g
s
.17116 .39446 m .16891 .39523 L .166 .39989 L p .317 0 .114 r
F P
0 g
s
.16351 .40034 m .166 .39989 L .16891 .39523 L p .473 .074 .203 r
F P
0 g
s
.18363 .38516 m .18871 .37955 L .19561 .37549 L p .73 .99 .831 r
F P
0 g
s
.21747 .3617 m .22303 .3513 L .23222 .34974 L p .761 .88 .932 r
F P
0 g
s
.22303 .3513 m .21747 .3617 L .20896 .36404 L p .792 .921 .924 r
F P
0 g
s
.26499 .51661 m .25092 .52666 L .25752 .52486 L p .642 .963 .907 r
F P
0 g
s
.25752 .52486 m .27238 .51427 L .26499 .51661 L p .642 .963 .907 r
F P
0 g
s
.19561 .37549 m .20107 .36743 L .20896 .36404 L p .798 .972 .909 r
F P
0 g
s
.20107 .36743 m .19561 .37549 L .18871 .37955 L p .803 .998 .853 r
F P
0 g
s
.17396 .39295 m .17116 .39446 L .16742 .39941 L p .076 0 0 r
F P
0 g
s
.166 .39989 m .16742 .39941 L .17116 .39446 L p .317 0 .114 r
F P
0 g
s
.29125 .49883 m .27907 .51083 L .28498 .50636 L p .606 .921 .677 r
F P
0 g
s
.28498 .50636 m .29754 .49398 L .29125 .49883 L p .606 .921 .677 r
F P
0 g
s
.33024 .38365 m .32352 .39709 L .31849 .38907 L p .343 .366 .74 r
F P
0 g
s
.31849 .38907 m .32512 .37571 L .33024 .38365 L p .343 .366 .74 r
F P
0 g
s
.25149 .34988 m .25708 .33766 L .26699 .33917 L p .668 .756 .917 r
F P
0 g
s
.25708 .33766 m .25149 .34988 L .24176 .34927 L p .7 .795 .924 r
F P
0 g
s
.17789 .38983 m .17396 .39295 L .16955 .39824 L p 0 0 0 r
F P
0 g
s
.16742 .39941 m .16955 .39824 L .17396 .39295 L p .076 0 0 r
F P
0 g
s
.23632 .5267 m .22144 .53403 L .22765 .53522 L p .644 .895 .984 r
F P
0 g
s
.22765 .53522 m .24381 .52729 L .23632 .5267 L p .644 .895 .984 r
F P
0 g
s
.21501 .53161 m .19934 .53656 L .20411 .53949 L p .63 .841 .981 r
F P
0 g
s
.20411 .53949 m .22144 .53403 L .21501 .53161 L p .63 .841 .981 r
F P
0 g
s
.33425 .39195 m .32746 .40544 L .32352 .39709 L p .276 .285 .689 r
F P
0 g
s
.32352 .39709 m .33024 .38365 L .33425 .39195 L p .276 .285 .689 r
F P
0 g
s
.24176 .34927 m .24721 .33723 L .25708 .33766 L p .7 .795 .924 r
F P
0 g
s
.24721 .33723 m .24176 .34927 L .23222 .34974 L p .733 .835 .928 r
F P
0 g
s
.31295 .47514 m .30289 .48824 L .30721 .4817 L p 0 0 0 r
F P
0 g
s
.30721 .4817 m .31742 .46839 L .31295 .47514 L p 0 0 0 r
F P
0 g
s
.33118 .43947 m .3229 .4531 L .32383 .44481 L p 0 0 .282 r
F P
0 g
s
.32383 .44481 m .33211 .43114 L .33118 .43947 L p 0 0 .282 r
F P
0 g
s
.20896 .36404 m .21434 .35392 L .22303 .3513 L p .792 .921 .924 r
F P
0 g
s
.21434 .35392 m .20896 .36404 L .20107 .36743 L p .819 .96 .903 r
F P
0 g
s
.16955 .39824 m .17304 .39547 L .17789 .38983 L p 0 0 0 r
F P
0 g
s
.18871 .37955 m .19392 .37182 L .20107 .36743 L p .803 .998 .853 r
F P
0 g
s
.166 .39989 m .16351 .40034 L .16178 .40598 L p .535 .192 .334 r
F P
0 g
s
.19451 .53242 m .17876 .53523 L .18181 .53969 L p .638 .789 .955 r
F P
0 g
s
.18181 .53969 m .19934 .53656 L .19451 .53242 L p .638 .789 .955 r
F P
0 g
s
.25704 .51781 m .24381 .52729 L .25092 .52666 L p .681 .942 .962 r
F P
0 g
s
.25092 .52666 m .26499 .51661 L .25704 .51781 L p .681 .942 .962 r
F P
0 g
s
.16742 .39941 m .166 .39989 L .16359 .40565 L p .407 .067 .274 r
F P
0 g
s
.16178 .40598 m .16359 .40565 L .166 .39989 L p .535 .192 .334 r
F P
0 g
s
.2841 .50269 m .27238 .51427 L .27907 .51083 L p .696 .982 .839 r
F P
0 g
s
.27907 .51083 m .29125 .49883 L .2841 .50269 L p .696 .982 .839 r
F P
0 g
s
.33708 .40047 m .33023 .41399 L .32746 .40544 L p .193 .186 .621 r
F P
0 g
s
.32746 .40544 m .33425 .39195 L .33708 .40047 L p .193 .186 .621 r
F P
0 g
s
.16955 .39824 m .16742 .39941 L .16437 .40539 L p .213 0 .166 r
F P
0 g
s
.16359 .40565 m .16437 .40539 L .16742 .39941 L p .407 .067 .274 r
F P
0 g
s
.23222 .34974 m .23755 .33788 L .24721 .33723 L p .733 .835 .928 r
F P
0 g
s
.23755 .33788 m .23222 .34974 L .22303 .3513 L p .766 .874 .926 r
F P
0 g
s
.17304 .39547 m .16955 .39824 L .16601 .40449 L p 0 0 .016 r
F P
0 g
s
.16437 .40539 m .16601 .40449 L .16955 .39824 L p .213 0 .166 r
F P
0 g
s
.329 .44745 m .32075 .461 L .3229 .4531 L p 0 0 .079 r
F P
0 g
s
.3229 .4531 m .33118 .43947 L .329 .44745 L p 0 0 .079 r
F P
0 g
s
.20107 .36743 m .20629 .35756 L .21434 .35392 L p .819 .96 .903 r
F P
0 g
s
.20629 .35756 m .20107 .36743 L .19392 .37182 L p .837 .99 .859 r
F P
0 g
s
.3074 .48113 m .29754 .49398 L .30289 .48824 L p .644 .897 .568 r
F P
0 g
s
.30289 .48824 m .31295 .47514 L .3074 .48113 L p .644 .897 .568 r
F P
0 g
s
.30974 .34212 m .30402 .35518 L .29545 .3498 L p .527 .592 .863 r
F P
0 g
s
.29545 .3498 m .30109 .33677 L .30974 .34212 L p .527 .592 .863 r
F P
0 g
s
.30109 .33677 m .29545 .3498 L .28633 .34529 L p .565 .636 .88 r
F P
0 g
s
.22856 .52491 m .21501 .53161 L .22144 .53403 L p .657 .844 .972 r
F P
0 g
s
.22144 .53403 m .23632 .5267 L .22856 .52491 L p .657 .844 .972 r
F P
0 g
s
.28633 .34529 m .29188 .33231 L .30109 .33677 L p .565 .636 .88 r
F P
0 g
s
.29188 .33231 m .28633 .34529 L .27679 .34173 L p .6 .678 .895 r
F P
0 g
s
.2085 .52799 m .19451 .53242 L .19934 .53656 L p .647 .792 .951 r
F P
0 g
s
.19934 .53656 m .21501 .53161 L .2085 .52799 L p .647 .792 .951 r
F P
0 g
s
.31769 .34827 m .31191 .36136 L .30402 .35518 L p .486 .544 .841 r
F P
0 g
s
.30402 .35518 m .30974 .34212 L .31769 .34827 L p .486 .544 .841 r
F P
0 g
s
.33868 .40908 m .33179 .4226 L .33023 .41399 L p .09 .063 .53 r
F P
0 g
s
.33023 .41399 m .33708 .40047 L .33868 .40908 L p .09 .063 .53 r
F P
0 g
s
.27679 .34173 m .28226 .32879 L .29188 .33231 L p .6 .678 .895 r
F P
0 g
s
.28226 .32879 m .27679 .34173 L .26699 .33917 L p .635 .717 .907 r
F P
0 g
s
.22303 .3513 m .22824 .3396 L .23755 .33788 L p .766 .874 .926 r
F P
0 g
s
.22824 .3396 m .22303 .3513 L .21434 .35392 L p .798 .914 .918 r
F P
0 g
s
.32483 .35513 m .31898 .36824 L .31191 .36136 L p .44 .491 .815 r
F P
0 g
s
.31191 .36136 m .31769 .34827 L .32483 .35513 L p .44 .491 .815 r
F P
0 g
s
.1775 .39053 m .17304 .39547 L .16915 .40199 L p 0 0 0 r
F P
0 g
s
.16601 .40449 m .16915 .40199 L .17304 .39547 L p 0 0 .016 r
F P
0 g
s
.26699 .33917 m .27237 .32629 L .28226 .32879 L p .635 .717 .907 r
F P
0 g
s
.27237 .32629 m .26699 .33917 L .25708 .33766 L p .668 .756 .916 r
F P
0 g
s
.27622 .5055 m .26499 .51661 L .27238 .51427 L p .728 .976 .922 r
F P
0 g
s
.27238 .51427 m .2841 .50269 L .27622 .5055 L p .728 .976 .922 r
F P
0 g
s
.24866 .51784 m .23632 .5267 L .24381 .52729 L p .687 .896 .973 r
F P
0 g
s
.24381 .52729 m .25704 .51781 L .24866 .51784 L p .687 .896 .973 r
F P
0 g
s
.16359 .40565 m .16178 .40598 L .16039 .41267 L p .574 .277 .426 r
F P
0 g
s
.33104 .36258 m .32512 .37571 L .31898 .36824 L p .389 .43 .782 r
F P
0 g
s
.31898 .36824 m .32483 .35513 L .33104 .36258 L p .389 .43 .782 r
F P
0 g
s
.18971 .52713 m .17575 .52963 L .17876 .53523 L p .654 .746 .917 r
F P
0 g
s
.17876 .53523 m .19451 .53242 L .18971 .52713 L p .654 .746 .917 r
F P
0 g
s
.16437 .40539 m .16359 .40565 L .16174 .41243 L p .462 .172 .385 r
F P
0 g
s
.16039 .41267 m .16174 .41243 L .16359 .40565 L p .574 .277 .426 r
F P
0 g
s
.16601 .40449 m .16437 .40539 L .16209 .41231 L p .307 .027 .315 r
F P
0 g
s
.16174 .41243 m .16209 .41231 L .16437 .40539 L p .462 .172 .385 r
F P
0 g
s
.3256 .45496 m .31742 .46839 L .32075 .461 L p 0 0 0 r
F P
0 g
s
.32075 .461 m .329 .44745 L .3256 .45496 L p 0 0 0 r
F P
0 g
s
.25708 .33766 m .26238 .32483 L .27237 .32629 L p .668 .756 .916 r
F P
0 g
s
.26238 .32483 m .25708 .33766 L .24721 .33723 L p .701 .795 .923 r
F P
0 g
s
.19392 .37182 m .199 .36218 L .20629 .35756 L p .837 .99 .859 r
F P
0 g
s
.199 .36218 m .19392 .37182 L .18765 .37715 L p .835 .998 .776 r
F P
0 g
s
.16915 .40199 m .16601 .40449 L .16338 .4116 L p .115 0 .217 r
F P
0 g
s
.16209 .41231 m .16338 .4116 L .16601 .40449 L p .307 .027 .315 r
F P
0 g
s
.33902 .41763 m .33211 .43114 L .33179 .4226 L p 0 0 .405 r
F P
0 g
s
.33179 .4226 m .33868 .40908 L .33902 .41763 L p 0 0 .405 r
F P
0 g
s
.30086 .48627 m .29125 .49883 L .29754 .49398 L p .738 .981 .753 r
F P
0 g
s
.29754 .49398 m .3074 .48113 L .30086 .48627 L p .738 .981 .753 r
F P
0 g
s
.21434 .35392 m .21943 .34238 L .22824 .3396 L p .798 .914 .918 r
F P
0 g
s
.21943 .34238 m .21434 .35392 L .20629 .35756 L p .829 .951 .898 r
F P
0 g
s
.33621 .37052 m .33024 .38365 L .32512 .37571 L p .328 .359 .741 r
F P
0 g
s
.32512 .37571 m .33104 .36258 L .33621 .37052 L p .328 .359 .741 r
F P
0 g
s
.22068 .52194 m .2085 .52799 L .21501 .53161 L p .656 .793 .947 r
F P
0 g
s
.21501 .53161 m .22856 .52491 L .22068 .52194 L p .656 .793 .947 r
F P
0 g
s
.20199 .52322 m .18971 .52713 L .19451 .53242 L p .652 .745 .918 r
F P
0 g
s
.19451 .53242 m .2085 .52799 L .20199 .52322 L p .652 .745 .918 r
F P
0 g
s
.24721 .33723 m .25243 .32446 L .26238 .32483 L p .701 .795 .923 r
F P
0 g
s
.25243 .32446 m .24721 .33723 L .23755 .33788 L p .734 .833 .926 r
F P
0 g
s
.16915 .40199 m .17341 .39728 L .1775 .39053 L p 0 0 0 r
F P
0 g
s
.17341 .39728 m .16915 .40199 L .1663 .40928 L p 0 0 .084 r
F P
0 g
s
.16338 .4116 m .1663 .40928 L .16915 .40199 L p .115 0 .217 r
F P
0 g
s
.26773 .5072 m .25704 .51781 L .26499 .51661 L p .729 .938 .955 r
F P
0 g
s
.26499 .51661 m .27622 .5055 L .26773 .5072 L p .729 .938 .955 r
F P
0 g
s
.34027 .37881 m .33425 .39195 L .33024 .38365 L p .256 .274 .688 r
F P
0 g
s
.33024 .38365 m .33621 .37052 L .34027 .37881 L p .256 .274 .688 r
F P
0 g
s
.23998 .51668 m .22856 .52491 L .23632 .5267 L p .678 .843 .962 r
F P
0 g
s
.23632 .5267 m .24866 .51784 L .23998 .51668 L p .678 .843 .962 r
F P
0 g
s
.16174 .41243 m .16039 .41267 L .15936 .42031 L p .6 .339 .493 r
F P
0 g
s
.32103 .46186 m .31295 .47514 L .31742 .46839 L p .64 .833 .427 r
F P
0 g
s
.31742 .46839 m .3256 .45496 L .32103 .46186 L p .64 .833 .427 r
F P
0 g
s
.16209 .41231 m .16174 .41243 L .16049 .42012 L p .495 .245 .464 r
F P
0 g
s
.15936 .42031 m .16049 .42012 L .16174 .41243 L p .6 .339 .493 r
F P
0 g
s
.18503 .52077 m .17284 .52295 L .17575 .52963 L p .662 .708 .882 r
F P
0 g
s
.17575 .52963 m .18971 .52713 L .18503 .52077 L p .662 .708 .882 r
F P
0 g
s
.16338 .4116 m .16209 .41231 L .16061 .42007 L p .373 .138 .423 r
F P
0 g
s
.16049 .42012 m .16061 .42007 L .16209 .41231 L p .495 .245 .464 r
F P
0 g
s
.33809 .426 m .33118 .43947 L .33211 .43114 L p 0 0 .234 r
F P
0 g
s
.33211 .43114 m .33902 .41763 L .33809 .426 L p 0 0 .234 r
F P
0 g
s
.18765 .37715 m .19261 .3677 L .199 .36218 L p .835 .998 .776 r
F P
0 g
s
.20629 .35756 m .21128 .34618 L .21943 .34238 L p .829 .951 .898 r
F P
0 g
s
.21128 .34618 m .20629 .35756 L .199 .36218 L p .853 .982 .859 r
F P
0 g
s
.23755 .33788 m .24269 .32516 L .25243 .32446 L p .734 .833 .926 r
F P
0 g
s
.24269 .32516 m .23755 .33788 L .22824 .3396 L p .768 .872 .924 r
F P
0 g
s
.1663 .40928 m .16338 .4116 L .16174 .41945 L p .223 .009 .363 r
F P
0 g
s
.16061 .42007 m .16174 .41945 L .16338 .4116 L p .373 .138 .423 r
F P
0 g
s
.29344 .49046 m .2841 .50269 L .29125 .49883 L p .773 .996 .865 r
F P
0 g
s
.29125 .49883 m .30086 .48627 L .29344 .49046 L p .773 .996 .865 r
F P
0 g
s
.21281 .51783 m .20199 .52322 L .2085 .52799 L p .649 .745 .919 r
F P
0 g
s
.2085 .52799 m .22068 .52194 L .21281 .51783 L p .649 .745 .919 r
F P
0 g
s
.34314 .38734 m .33708 .40047 L .33425 .39195 L p .167 .17 .617 r
F P
0 g
s
.33425 .39195 m .34027 .37881 L .34314 .38734 L p .167 .17 .617 r
F P
0 g
s
.19561 .51739 m .18503 .52077 L .18971 .52713 L p .651 .704 .886 r
F P
0 g
s
.18971 .52713 m .20199 .52322 L .19561 .51739 L p .651 .704 .886 r
F P
0 g
s
.17814 .39025 m .17341 .39728 L .17042 .40473 L p 0 0 0 r
F P
0 g
s
.1663 .40928 m .17042 .40473 L .17341 .39728 L p 0 0 .084 r
F P
0 g
s
.17042 .40473 m .1663 .40928 L .16454 .41723 L p .036 0 .276 r
F P
0 g
s
.16174 .41945 m .16454 .41723 L .1663 .40928 L p .223 .009 .363 r
F P
0 g
s
.22824 .3396 m .23331 .32694 L .24269 .32516 L p .768 .872 .924 r
F P
0 g
s
.23331 .32694 m .22824 .3396 L .21943 .34238 L p .801 .91 .915 r
F P
0 g
s
.25877 .50775 m .24866 .51784 L .25704 .51781 L p .714 .89 .961 r
F P
0 g
s
.25704 .51781 m .26773 .5072 L .25877 .50775 L p .714 .89 .961 r
F P
0 g
s
.31526 .32936 m .30974 .34212 L .30109 .33677 L p .527 .592 .863 r
F P
0 g
s
.30109 .33677 m .30658 .32394 L .31526 .32936 L p .527 .592 .863 r
F P
0 g
s
.30658 .32394 m .30109 .33677 L .29188 .33231 L p .564 .636 .881 r
F P
0 g
s
.23114 .51436 m .22068 .52194 L .22856 .52491 L p .664 .792 .943 r
F P
0 g
s
.22856 .52491 m .23998 .51668 L .23114 .51436 L p .664 .792 .943 r
F P
0 g
s
.29188 .33231 m .29734 .31941 L .30658 .32394 L p .564 .636 .881 r
F P
0 g
s
.29734 .31941 m .29188 .33231 L .28226 .32879 L p .6 .678 .895 r
F P
0 g
s
.33589 .43404 m .329 .44745 L .33118 .43947 L p 0 0 .012 r
F P
0 g
s
.33118 .43947 m .33809 .426 L .33589 .43404 L p 0 0 .012 r
F P
0 g
s
.32325 .33558 m .31769 .34827 L .30974 .34212 L p .485 .544 .841 r
F P
0 g
s
.30974 .34212 m .31526 .32936 L .32325 .33558 L p .485 .544 .841 r
F P
0 g
s
.16049 .42012 m .15936 .42031 L .15872 .42877 L p .617 .386 .544 r
F P
0 g
s
.31536 .46804 m .3074 .48113 L .31295 .47514 L p .753 .953 .641 r
F P
0 g
s
.31295 .47514 m .32103 .46186 L .31536 .46804 L p .753 .953 .641 r
F P
0 g
s
.28226 .32879 m .28768 .31582 L .29734 .31941 L p .6 .678 .895 r
F P
0 g
s
.28768 .31582 m .28226 .32879 L .27237 .32629 L p .635 .717 .907 r
F P
0 g
s
.16061 .42007 m .16049 .42012 L .15985 .42858 L p .525 .309 .528 r
F P
0 g
s
.15872 .42877 m .15985 .42858 L .16049 .42012 L p .617 .386 .544 r
F P
0 g
s
.18054 .51344 m .17009 .51532 L .17284 .52295 L p .665 .674 .849 r
F P
0 g
s
.17284 .52295 m .18503 .52077 L .18054 .51344 L p .665 .674 .849 r
F P
0 g
s
.16174 .41945 m .16061 .42007 L .15998 .42854 L p .423 .224 .504 r
F P
0 g
s
.15985 .42858 m .15998 .42854 L .16061 .42007 L p .525 .309 .528 r
F P
0 g
s
.199 .36218 m .20391 .35093 L .21128 .34618 L p .853 .982 .859 r
F P
0 g
s
.20391 .35093 m .199 .36218 L .19261 .3677 L p .863 .996 .788 r
F P
0 g
s
.16454 .41723 m .16174 .41945 L .1611 .42792 L p .302 .126 .468 r
F P
0 g
s
.15998 .42854 m .1611 .42792 L .16174 .41945 L p .423 .224 .504 r
F P
0 g
s
.33042 .3425 m .32483 .35513 L .31769 .34827 L p .44 .49 .815 r
F P
0 g
s
.31769 .34827 m .32325 .33558 L .33042 .3425 L p .44 .49 .815 r
F P
0 g
s
.34477 .39596 m .33868 .40908 L .33708 .40047 L p .056 .04 .52 r
F P
0 g
s
.33708 .40047 m .34314 .38734 L .34477 .39596 L p .056 .04 .52 r
F P
0 g
s
.27237 .32629 m .27777 .31325 L .28768 .31582 L p .635 .717 .907 r
F P
0 g
s
.27777 .31325 m .27237 .32629 L .26238 .32483 L p .668 .756 .916 r
F P
0 g
s
.28524 .49363 m .27622 .5055 L .2841 .50269 L p .773 .971 .921 r
F P
0 g
s
.2841 .50269 m .29344 .49046 L .28524 .49363 L p .773 .971 .921 r
F P
0 g
s
.20507 .51265 m .19561 .51739 L .20199 .52322 L p .64 .702 .891 r
F P
0 g
s
.20199 .52322 m .21281 .51783 L .20507 .51265 L p .64 .702 .891 r
F P
0 g
s
.18947 .51058 m .18054 .51344 L .18503 .52077 L p .647 .667 .855 r
F P
0 g
s
.18503 .52077 m .19561 .51739 L .18947 .51058 L p .647 .667 .855 r
F P
0 g
s
.33665 .35001 m .33104 .36258 L .32483 .35513 L p .388 .43 .783 r
F P
0 g
s
.32483 .35513 m .33042 .3425 L .33665 .35001 L p .388 .43 .783 r
F P
0 g
s
.17042 .40473 m .17506 .39783 L .17814 .39025 L p 0 0 0 r
F P
0 g
s
.17506 .39783 m .17042 .40473 L .16859 .41276 L p 0 0 .176 r
F P
0 g
s
.16454 .41723 m .16859 .41276 L .17042 .40473 L p .036 0 .276 r
F P
0 g
s
.21943 .34238 m .22444 .32978 L .23331 .32694 L p .801 .91 .915 r
F P
0 g
s
.22444 .32978 m .21943 .34238 L .21128 .34618 L p .833 .947 .895 r
F P
0 g
s
.16859 .41276 m .16454 .41723 L .16391 .4257 L p .154 .008 .417 r
F P
0 g
s
.1611 .42792 m .16391 .4257 L .16454 .41723 L p .302 .126 .468 r
F P
0 g
s
.26238 .32483 m .26774 .31173 L .27777 .31325 L p .668 .756 .916 r
F P
0 g
s
.26774 .31173 m .26238 .32483 L .25243 .32446 L p .701 .795 .923 r
F P
0 g
s
.22231 .51091 m .21281 .51783 L .22068 .52194 L p .647 .745 .921 r
F P
0 g
s
.22068 .52194 m .23114 .51436 L .22231 .51091 L p .647 .745 .921 r
F P
0 g
s
.24949 .50714 m .23998 .51668 L .24866 .51784 L p .693 .84 .953 r
F P
0 g
s
.24866 .51784 m .25877 .50775 L .24949 .50714 L p .693 .84 .953 r
F P
0 g
s
.15985 .42858 m .15872 .42877 L .15848 .43792 L p .628 .424 .587 r
F P
0 g
s
.33246 .44162 m .3256 .45496 L .329 .44745 L p 0 0 0 r
F P
0 g
s
.329 .44745 m .33589 .43404 L .33246 .44162 L p 0 0 0 r
F P
0 g
s
.17632 .50528 m .16754 .50687 L .17009 .51532 L p .665 .644 .819 r
F P
0 g
s
.17009 .51532 m .18054 .51344 L .17632 .50528 L p .665 .644 .819 r
F P
0 g
s
.15998 .42854 m .15985 .42858 L .15984 .43769 L p .555 .365 .579 r
F P
0 g
s
.15848 .43792 m .15984 .43769 L .15985 .42858 L p .628 .424 .587 r
F P
0 g
s
.1611 .42792 m .15998 .42854 L .16019 .43757 L p .463 .295 .566 r
F P
0 g
s
.15984 .43769 m .16019 .43757 L .15998 .42854 L p .555 .365 .579 r
F P
0 g
s
.34185 .358 m .33621 .37052 L .33104 .36258 L p .327 .358 .741 r
F P
0 g
s
.33104 .36258 m .33665 .35001 L .34185 .358 L p .327 .358 .741 r
F P
0 g
s
.19261 .3677 m .19744 .35658 L .20391 .35093 L p .863 .996 .788 r
F P
0 g
s
.30868 .47339 m .30086 .48627 L .3074 .48113 L p .804 .998 .787 r
F P
0 g
s
.3074 .48113 m .31536 .46804 L .30868 .47339 L p .804 .998 .787 r
F P
0 g
s
.34512 .40454 m .33902 .41763 L .33868 .40908 L p 0 0 .387 r
F P
0 g
s
.33868 .40908 m .34477 .39596 L .34512 .40454 L p 0 0 .387 r
F P
0 g
s
.16391 .4257 m .1611 .42792 L .16149 .43686 L p .362 .218 .547 r
F P
0 g
s
.16019 .43757 m .16149 .43686 L .1611 .42792 L p .463 .295 .566 r
F P
0 g
s
.25243 .32446 m .25776 .31129 L .26774 .31173 L p .701 .795 .923 r
F P
0 g
s
.25776 .31129 m .25243 .32446 L .24269 .32516 L p .735 .833 .925 r
F P
0 g
s
.27642 .49571 m .26773 .5072 L .27622 .5055 L p .755 .929 .945 r
F P
0 g
s
.27622 .5055 m .28524 .49363 L .27642 .49571 L p .755 .929 .945 r
F P
0 g
s
.19761 .50648 m .18947 .51058 L .19561 .51739 L p .628 .662 .863 r
F P
0 g
s
.19561 .51739 m .20507 .51265 L .19761 .50648 L p .628 .662 .863 r
F P
0 g
s
.18368 .50291 m .17632 .50528 L .18054 .51344 L p .642 .633 .826 r
F P
0 g
s
.18054 .51344 m .18947 .51058 L .18368 .50291 L p .642 .633 .826 r
F P
0 g
s
.21128 .34618 m .21623 .33363 L .22444 .32978 L p .833 .947 .895 r
F P
0 g
s
.21623 .33363 m .21128 .34618 L .20391 .35093 L p .86 .977 .858 r
F P
0 g
s
.16391 .4257 m .16796 .42124 L .16859 .41276 L p .154 .008 .417 r
F P
0 g
s
.16796 .42124 m .16391 .4257 L .16442 .43455 L p .244 .131 .52 r
F P
0 g
s
.16149 .43686 m .16442 .43455 L .16391 .4257 L p .362 .218 .547 r
F P
0 g
s
.34592 .36635 m .34027 .37881 L .33621 .37052 L p .254 .273 .688 r
F P
0 g
s
.33621 .37052 m .34185 .358 L .34592 .36635 L p .254 .273 .688 r
F P
0 g
s
.16859 .41276 m .1732 .40593 L .17506 .39783 L p 0 0 .176 r
F P
0 g
s
.1732 .40593 m .16859 .41276 L .16796 .42124 L p 0 0 .354 r
F P
0 g
s
.21363 .50637 m .20507 .51265 L .21281 .51783 L p .629 .701 .897 r
F P
0 g
s
.21281 .51783 m .22231 .51091 L .21363 .50637 L p .629 .701 .897 r
F P
0 g
s
.15984 .43769 m .15848 .43792 L .15864 .44759 L p .636 .456 .623 r
F P
0 g
s
.17245 .49642 m .16523 .49772 L .16754 .50687 L p .664 .616 .791 r
F P
0 g
s
.16754 .50687 m .17632 .50528 L .17245 .49642 L p .664 .616 .791 r
F P
0 g
s
.16019 .43757 m .15984 .43769 L .16047 .44727 L p .574 .409 .62 r
F P
0 g
s
.15864 .44759 m .16047 .44727 L .15984 .43769 L p .636 .456 .623 r
F P
0 g
s
.24005 .50538 m .23114 .51436 L .23998 .51668 L p .669 .791 .939 r
F P
0 g
s
.23998 .51668 m .24949 .50714 L .24005 .50538 L p .669 .791 .939 r
F P
0 g
s
.16149 .43686 m .16019 .43757 L .16126 .44701 L p .495 .352 .616 r
F P
0 g
s
.16047 .44727 m .16126 .44701 L .16019 .43757 L p .574 .409 .62 r
F P
0 g
s
.24269 .32516 m .24799 .31193 L .25776 .31129 L p .735 .833 .925 r
F P
0 g
s
.24799 .31193 m .24269 .32516 L .23331 .32694 L p .768 .872 .924 r
F P
0 g
s
.16442 .43455 m .16149 .43686 L .16291 .44612 L p .409 .293 .609 r
F P
0 g
s
.16126 .44701 m .16291 .44612 L .16149 .43686 L p .495 .352 .616 r
F P
0 g
s
.32783 .44862 m .32103 .46186 L .3256 .45496 L p .724 .884 .488 r
F P
0 g
s
.3256 .45496 m .33246 .44162 L .32783 .44862 L p .724 .884 .488 r
F P
0 g
s
.3442 .41293 m .33809 .426 L .33902 .41763 L p 0 0 .207 r
F P
0 g
s
.33902 .41763 m .34512 .40454 L .3442 .41293 L p 0 0 .207 r
F P
0 g
s
.19056 .49942 m .18368 .50291 L .18947 .51058 L p .617 .625 .836 r
F P
0 g
s
.18947 .51058 m .19761 .50648 L .19056 .49942 L p .617 .625 .836 r
F P
0 g
s
.17833 .49451 m .17245 .49642 L .17632 .50528 L p .635 .602 .798 r
F P
0 g
s
.17632 .50528 m .18368 .50291 L .17833 .49451 L p .635 .602 .798 r
F P
0 g
s
.30108 .47781 m .29344 .49046 L .30086 .48627 L p .812 .992 .872 r
F P
0 g
s
.30086 .48627 m .30868 .47339 L .30108 .47781 L p .812 .992 .872 r
F P
0 g
s
.17506 .39783 m .17981 .38878 L .18292 .38111 L p 0 0 0 r
F P
0 g
s
.17981 .38878 m .17506 .39783 L .1732 .40593 L p 0 0 .082 r
F P
0 g
s
.2671 .49667 m .25877 .50775 L .26773 .5072 L p .73 .883 .951 r
F P
0 g
s
.26773 .5072 m .27642 .49571 L .2671 .49667 L p .73 .883 .951 r
F P
0 g
s
.16047 .44727 m .15864 .44759 L .15921 .45762 L p .643 .485 .655 r
F P
0 g
s
.169 .48701 m .16321 .48805 L .16523 .49772 L p .661 .59 .764 r
F P
0 g
s
.16523 .49772 m .17245 .49642 L .169 .48701 L p .661 .59 .764 r
F P
0 g
s
.34881 .37492 m .34314 .38734 L .34027 .37881 L p .165 .169 .617 r
F P
0 g
s
.34027 .37881 m .34592 .36635 L .34881 .37492 L p .165 .169 .617 r
F P
0 g
s
.16126 .44701 m .16047 .44727 L .16173 .45717 L p .588 .446 .656 r
F P
0 g
s
.15921 .45762 m .16173 .45717 L .16047 .44727 L p .643 .485 .655 r
F P
0 g
s
.20526 .50084 m .19761 .50648 L .20507 .51265 L p .611 .659 .872 r
F P
0 g
s
.20507 .51265 m .21363 .50637 L .20526 .50084 L p .611 .659 .872 r
F P
0 g
s
.16291 .44612 m .16126 .44701 L .16317 .45669 L p .521 .401 .658 r
F P
0 g
s
.16173 .45717 m .16317 .45669 L .16126 .44701 L p .588 .446 .656 r
F P
0 g
s
.16442 .43455 m .16856 .43003 L .16796 .42124 L p .244 .131 .52 r
F P
0 g
s
.16856 .43003 m .16442 .43455 L .16608 .44364 L p .313 .228 .597 r
F P
0 g
s
.16291 .44612 m .16608 .44364 L .16442 .43455 L p .409 .293 .609 r
F P
0 g
s
.20391 .35093 m .2088 .33844 L .21623 .33363 L p .86 .977 .858 r
F P
0 g
s
.2088 .33844 m .20391 .35093 L .19744 .35658 L p .874 .994 .793 r
F P
0 g
s
.23331 .32694 m .23859 .31366 L .24799 .31193 L p .768 .872 .924 r
F P
0 g
s
.23859 .31366 m .23331 .32694 L .22444 .32978 L p .802 .91 .915 r
F P
0 g
s
.32091 .31729 m .31526 .32936 L .30658 .32394 L p .53 .592 .861 r
F P
0 g
s
.30658 .32394 m .31226 .31169 L .32091 .31729 L p .53 .592 .861 r
F P
0 g
s
.31226 .31169 m .30658 .32394 L .29734 .31941 L p .567 .636 .879 r
F P
0 g
s
.23061 .50248 m .22231 .51091 L .23114 .51436 L p .645 .745 .922 r
F P
0 g
s
.23114 .51436 m .24005 .50538 L .23061 .50248 L p .645 .745 .922 r
F P
0 g
s
.16796 .42124 m .17258 .41442 L .1732 .40593 L p 0 0 .354 r
F P
0 g
s
.17258 .41442 m .16796 .42124 L .16856 .43003 L p .121 .042 .485 r
F P
0 g
s
.29734 .31941 m .30304 .30696 L .31226 .31169 L p .567 .636 .879 r
F P
0 g
s
.30304 .30696 m .29734 .31941 L .28768 .31582 L p .602 .677 .894 r
F P
0 g
s
.17353 .48553 m .169 .48701 L .17245 .49642 L p .628 .571 .771 r
F P
0 g
s
.17245 .49642 m .17833 .49451 L .17353 .48553 L p .628 .571 .771 r
F P
0 g
s
.16608 .44364 m .16291 .44612 L .16533 .45554 L p .447 .355 .658 r
F P
0 g
s
.16317 .45669 m .16533 .45554 L .16291 .44612 L p .521 .401 .658 r
F P
0 g
s
.18403 .4916 m .17833 .49451 L .18368 .50291 L p .604 .589 .809 r
F P
0 g
s
.18368 .50291 m .19056 .49942 L .18403 .4916 L p .604 .589 .809 r
F P
0 g
s
.32888 .32367 m .32325 .33558 L .31526 .32936 L p .49 .545 .839 r
F P
0 g
s
.31526 .32936 m .32091 .31729 L .32888 .32367 L p .49 .545 .839 r
F P
0 g
s
.16173 .45717 m .15921 .45762 L .16017 .46782 L p .649 .513 .684 r
F P
0 g
s
.16603 .47721 m .16151 .47803 L .16321 .48805 L p .658 .564 .738 r
F P
0 g
s
.16321 .48805 m .169 .48701 L .16603 .47721 L p .658 .564 .738 r
F P
0 g
s
.28768 .31582 m .29342 .30318 L .30304 .30696 L p .602 .677 .894 r
F P
0 g
s
.29342 .30318 m .28768 .31582 L .27777 .31325 L p .635 .717 .907 r
F P
0 g
s
.16317 .45669 m .16173 .45717 L .16359 .46721 L p .6 .48 .687 r
F P
0 g
s
.16017 .46782 m .16359 .46721 L .16173 .45717 L p .649 .513 .684 r
F P
0 g
s
.16359 .46721 m .16017 .46782 L .16151 .47803 L p .653 .539 .711 r
F P
0 g
s
.16533 .45554 m .16317 .45669 L .16588 .46646 L p .542 .444 .693 r
F P
0 g
s
.16359 .46721 m .16588 .46646 L .16317 .45669 L p .6 .48 .687 r
F P
0 g
s
.16151 .47803 m .16603 .47721 L .16359 .46721 L p .653 .539 .711 r
F P
0 g
s
.33603 .33075 m .33042 .3425 L .32325 .33558 L p .446 .492 .813 r
F P
0 g
s
.32325 .33558 m .32888 .32367 L .33603 .33075 L p .446 .492 .813 r
F P
0 g
s
.16935 .47613 m .16603 .47721 L .169 .48701 L p .62 .542 .744 r
F P
0 g
s
.169 .48701 m .17353 .48553 L .16935 .47613 L p .62 .542 .744 r
F P
0 g
s
.34199 .42101 m .33589 .43404 L .33809 .426 L p 0 0 0 r
F P
0 g
s
.33809 .426 m .3442 .41293 L .34199 .42101 L p 0 0 0 r
F P
0 g
s
.19733 .49439 m .19056 .49942 L .19761 .50648 L p .592 .619 .848 r
F P
0 g
s
.19761 .50648 m .20526 .50084 L .19733 .49439 L p .592 .619 .848 r
F P
0 g
s
.32209 .45491 m .31536 .46804 L .32103 .46186 L p .808 .974 .677 r
F P
0 g
s
.32103 .46186 m .32783 .44862 L .32209 .45491 L p .808 .974 .677 r
F P
0 g
s
.16588 .46646 m .16359 .46721 L .16603 .47721 L p .611 .511 .717 r
F P
0 g
s
.17815 .48315 m .17353 .48553 L .17833 .49451 L p .591 .554 .782 r
F P
0 g
s
.17833 .49451 m .18403 .4916 L .17815 .48315 L p .591 .554 .782 r
F P
0 g
s
.27777 .31325 m .28353 .30041 L .29342 .30318 L p .635 .717 .907 r
F P
0 g
s
.28353 .30041 m .27777 .31325 L .26774 .31173 L p .668 .756 .916 r
F P
0 g
s
.16603 .47721 m .16935 .47613 L .16588 .46646 L p .611 .511 .717 r
F P
0 g
s
.35045 .38357 m .34477 .39596 L .34314 .38734 L p .053 .038 .52 r
F P
0 g
s
.34314 .38734 m .34881 .37492 L .35045 .38357 L p .053 .038 .52 r
F P
0 g
s
.2927 .48123 m .28524 .49363 L .29344 .49046 L p .796 .961 .917 r
F P
0 g
s
.29344 .49046 m .30108 .47781 L .2927 .48123 L p .796 .961 .917 r
F P
0 g
s
.16533 .45554 m .16885 .45281 L .16608 .44364 L p .447 .355 .658 r
F P
0 g
s
.16885 .45281 m .16533 .45554 L .16872 .46496 L p .479 .408 .699 r
F P
0 g
s
.16588 .46646 m .16872 .46496 L .16533 .45554 L p .542 .444 .693 r
F P
0 g
s
.1732 .40593 m .17792 .39693 L .17981 .38878 L p 0 0 .082 r
F P
0 g
s
.17792 .39693 m .1732 .40593 L .17258 .41442 L p 0 0 .291 r
F P
0 g
s
.16608 .44364 m .17037 .43898 L .16856 .43003 L p .313 .228 .597 r
F P
0 g
s
.17037 .43898 m .16608 .44364 L .16885 .45281 L p .369 .307 .657 r
F P
0 g
s
.25746 .49648 m .24949 .50714 L .25877 .50775 L p .702 .836 .947 r
F P
0 g
s
.25877 .50775 m .2671 .49667 L .25746 .49648 L p .702 .836 .947 r
F P
0 g
s
.16872 .46496 m .16588 .46646 L .16935 .47613 L p .56 .483 .725 r
F P
0 g
s
.34224 .3384 m .33665 .35001 L .33042 .3425 L p .397 .433 .781 r
F P
0 g
s
.33042 .3425 m .33603 .33075 L .34224 .3384 L p .397 .433 .781 r
F P
0 g
s
.17302 .47422 m .16935 .47613 L .17353 .48553 L p .576 .519 .754 r
F P
0 g
s
.17353 .48553 m .17815 .48315 L .17302 .47422 L p .576 .519 .754 r
F P
0 g
s
.22133 .4985 m .21363 .50637 L .22231 .51091 L p .621 .701 .902 r
F P
0 g
s
.22231 .51091 m .23061 .50248 L .22133 .4985 L p .621 .701 .902 r
F P
0 g
s
.22444 .32978 m .22969 .31645 L .23859 .31366 L p .802 .91 .915 r
F P
0 g
s
.22969 .31645 m .22444 .32978 L .21623 .33363 L p .833 .946 .895 r
F P
0 g
s
.16935 .47613 m .17302 .47422 L .16872 .46496 L p .56 .483 .725 r
F P
0 g
s
.18999 .48714 m .18403 .4916 L .19056 .49942 L p .573 .58 .822 r
F P
0 g
s
.19056 .49942 m .19733 .49439 L .18999 .48714 L p .573 .58 .822 r
F P
0 g
s
.16856 .43003 m .17323 .42317 L .17258 .41442 L p .121 .042 .485 r
F P
0 g
s
.17323 .42317 m .16856 .43003 L .17037 .43898 L p .216 .164 .58 r
F P
0 g
s
.19744 .35658 m .2023 .34414 L .2088 .33844 L p .874 .994 .793 r
F P
0 g
s
.2023 .34414 m .19744 .35658 L .19199 .36303 L p .862 .979 .683 r
F P
0 g
s
.26774 .31173 m .27353 .2987 L .28353 .30041 L p .668 .756 .916 r
F P
0 g
s
.27353 .2987 m .26774 .31173 L .25776 .31129 L p .701 .795 .924 r
F P
0 g
s
.16872 .46496 m .17271 .4619 L .16885 .45281 L p .479 .408 .699 r
F P
0 g
s
.17271 .4619 m .16872 .46496 L .17302 .47422 L p .506 .456 .735 r
F P
0 g
s
.18337 .47922 m .17815 .48315 L .18403 .4916 L p .552 .54 .795 r
F P
0 g
s
.18403 .4916 m .18999 .48714 L .18337 .47922 L p .552 .54 .795 r
F P
0 g
s
.34743 .34651 m .34185 .358 L .33665 .35001 L p .339 .364 .74 r
F P
0 g
s
.33665 .35001 m .34224 .3384 L .34743 .34651 L p .339 .364 .74 r
F P
0 g
s
.17302 .47422 m .17757 .47075 L .17271 .4619 L p .506 .456 .735 r
F P
0 g
s
.17757 .47075 m .17302 .47422 L .17815 .48315 L p .531 .499 .766 r
F P
0 g
s
.16885 .45281 m .17337 .44794 L .17037 .43898 L p .369 .307 .657 r
F P
0 g
s
.17337 .44794 m .16885 .45281 L .17271 .4619 L p .414 .374 .704 r
F P
0 g
s
.17815 .48315 m .18337 .47922 L .17757 .47075 L p .531 .499 .766 r
F P
0 g
s
.21237 .4935 m .20526 .50084 L .21363 .50637 L p .596 .658 .881 r
F P
0 g
s
.21363 .50637 m .22133 .4985 L .21237 .4935 L p .596 .658 .881 r
F P
0 g
s
.33854 .42863 m .33246 .44162 L .33589 .43404 L p 0 0 0 r
F P
0 g
s
.33589 .43404 m .34199 .42101 L .33854 .42863 L p 0 0 0 r
F P
0 g
s
.35082 .39218 m .34512 .40454 L .34477 .39596 L p 0 0 .386 r
F P
0 g
s
.34477 .39596 m .35045 .38357 L .35082 .39218 L p 0 0 .386 r
F P
0 g
s
.24764 .49515 m .24005 .50538 L .24949 .50714 L p .673 .79 .936 r
F P
0 g
s
.24949 .50714 m .25746 .49648 L .24764 .49515 L p .673 .79 .936 r
F P
0 g
s
.25776 .31129 m .26358 .29807 L .27353 .2987 L p .701 .795 .924 r
F P
0 g
s
.26358 .29807 m .25776 .31129 L .24799 .31193 L p .733 .834 .927 r
F P
0 g
s
.31531 .46039 m .30868 .47339 L .31536 .46804 L p .836 .999 .801 r
F P
0 g
s
.31536 .46804 m .32209 .45491 L .31531 .46039 L p .836 .999 .801 r
F P
0 g
s
.28366 .48359 m .27642 .49571 L .28524 .49363 L p .77 .921 .937 r
F P
0 g
s
.28524 .49363 m .2927 .48123 L .28366 .48359 L p .77 .921 .937 r
F P
0 g
s
.17258 .41442 m .17731 .40544 L .17792 .39693 L p 0 0 .291 r
F P
0 g
s
.17731 .40544 m .17258 .41442 L .17323 .42317 L p .01 0 .448 r
F P
0 g
s
.18451 .37791 m .17981 .38878 L .17792 .39693 L p 0 0 .013 r
F P
0 g
s
.21623 .33363 m .22145 .32027 L .22969 .31645 L p .833 .946 .895 r
F P
0 g
s
.22145 .32027 m .21623 .33363 L .2088 .33844 L p .861 .977 .858 r
F P
0 g
s
.17037 .43898 m .17513 .43201 L .17323 .42317 L p .216 .164 .58 r
F P
0 g
s
.17513 .43201 m .17037 .43898 L .17337 .44794 L p .292 .261 .652 r
F P
0 g
s
.17271 .4619 m .17752 .45675 L .17337 .44794 L p .414 .374 .704 r
F P
0 g
s
.17752 .45675 m .17271 .4619 L .17757 .47075 L p .453 .431 .744 r
F P
0 g
s
.20389 .48757 m .19733 .49439 L .20526 .50084 L p .571 .616 .858 r
F P
0 g
s
.20526 .50084 m .21237 .4935 L .20389 .48757 L p .571 .616 .858 r
F P
0 g
s
.3515 .35496 m .34592 .36635 L .34185 .358 L p .27 .281 .688 r
F P
0 g
s
.34185 .358 m .34743 .34651 L .3515 .35496 L p .27 .281 .688 r
F P
0 g
s
.19199 .36303 m .19681 .35063 L .2023 .34414 L p .862 .979 .683 r
F P
0 g
s
.17757 .47075 m .18274 .46526 L .17752 .45675 L p .453 .431 .744 r
F P
0 g
s
.18274 .46526 m .17757 .47075 L .18337 .47922 L p .487 .482 .778 r
F P
0 g
s
.19604 .48081 m .18999 .48714 L .19733 .49439 L p .545 .573 .834 r
F P
0 g
s
.19733 .49439 m .20389 .48757 L .19604 .48081 L p .545 .573 .834 r
F P
0 g
s
.24799 .31193 m .25383 .29853 L .26358 .29807 L p .733 .834 .927 r
F P
0 g
s
.25383 .29853 m .24799 .31193 L .23859 .31366 L p .766 .874 .926 r
F P
0 g
s
.23783 .49268 m .23061 .50248 L .24005 .50538 L p .644 .745 .923 r
F P
0 g
s
.24005 .50538 m .24764 .49515 L .23783 .49268 L p .644 .745 .923 r
F P
0 g
s
.18337 .47922 m .18895 .47333 L .18274 .46526 L p .487 .482 .778 r
F P
0 g
s
.18895 .47333 m .18337 .47922 L .18999 .48714 L p .517 .529 .807 r
F P
0 g
s
.18999 .48714 m .19604 .48081 L .18895 .47333 L p .517 .529 .807 r
F P
0 g
s
.17337 .44794 m .17827 .44082 L .17513 .43201 L p .292 .261 .652 r
F P
0 g
s
.17827 .44082 m .17337 .44794 L .17752 .45675 L p .353 .342 .707 r
F P
0 g
s
.3499 .40059 m .3442 .41293 L .34512 .40454 L p 0 0 .204 r
F P
0 g
s
.34512 .40454 m .35082 .39218 L .3499 .40059 L p 0 0 .204 r
F P
0 g
s
.27413 .48483 m .2671 .49667 L .27642 .49571 L p .739 .877 .944 r
F P
0 g
s
.27642 .49571 m .28366 .48359 L .27413 .48483 L p .739 .877 .944 r
F P
0 g
s
.33388 .43567 m .32783 .44862 L .33246 .44162 L p .762 .905 .515 r
F P
0 g
s
.33246 .44162 m .33854 .42863 L .33388 .43567 L p .762 .905 .515 r
F P
0 g
s
.17323 .42317 m .17799 .41417 L .17731 .40544 L p .01 0 .448 r
F P
0 g
s
.17799 .41417 m .17323 .42317 L .17513 .43201 L p .131 .107 .562 r
F P
0 g
s
.35438 .36361 m .34881 .37492 L .34592 .36635 L p .185 .181 .62 r
F P
0 g
s
.34592 .36635 m .3515 .35496 L .35438 .36361 L p .185 .181 .62 r
F P
0 g
s
.30761 .46496 m .30108 .47781 L .30868 .47339 L p .83 .986 .873 r
F P
0 g
s
.30868 .47339 m .31531 .46039 L .30761 .46496 L p .83 .986 .873 r
F P
0 g
s
.17792 .39693 m .18261 .38611 L .18451 .37791 L p 0 0 .013 r
F P
0 g
s
.18261 .38611 m .17792 .39693 L .17731 .40544 L p 0 0 .241 r
F P
0 g
s
.2088 .33844 m .21401 .32504 L .22145 .32027 L p .861 .977 .858 r
F P
0 g
s
.21401 .32504 m .2088 .33844 L .2023 .34414 L p .875 .993 .793 r
F P
0 g
s
.32692 .3063 m .32091 .31729 L .31226 .31169 L p .537 .592 .857 r
F P
0 g
s
.31226 .31169 m .31837 .3004 L .32692 .3063 L p .537 .592 .857 r
F P
0 g
s
.31837 .3004 m .31226 .31169 L .30304 .30696 L p .572 .635 .876 r
F P
0 g
s
.22818 .48912 m .22133 .4985 L .23061 .50248 L p .615 .702 .907 r
F P
0 g
s
.23061 .50248 m .23783 .49268 L .22818 .48912 L p .615 .702 .907 r
F P
0 g
s
.30304 .30696 m .30927 .29535 L .31837 .3004 L p .572 .635 .876 r
F P
0 g
s
.30927 .29535 m .30304 .30696 L .29342 .30318 L p .604 .677 .892 r
F P
0 g
s
.33478 .31297 m .32888 .32367 L .32091 .31729 L p .501 .546 .835 r
F P
0 g
s
.32091 .31729 m .32692 .3063 L .33478 .31297 L p .501 .546 .835 r
F P
0 g
s
.23859 .31366 m .24445 .30009 L .25383 .29853 L p .766 .874 .926 r
F P
0 g
s
.24445 .30009 m .23859 .31366 L .22969 .31645 L p .799 .913 .917 r
F P
0 g
s
.17752 .45675 m .1826 .44942 L .17827 .44082 L p .353 .342 .707 r
F P
0 g
s
.1826 .44942 m .17752 .45675 L .18274 .46526 L p .404 .409 .751 r
F P
0 g
s
.29342 .30318 m .29976 .29124 L .30927 .29535 L p .604 .677 .892 r
F P
0 g
s
.29976 .29124 m .29342 .30318 L .28353 .30041 L p .636 .717 .906 r
F P
0 g
s
.34184 .3203 m .33603 .33075 L .32888 .32367 L p .46 .496 .809 r
F P
0 g
s
.32888 .32367 m .33478 .31297 L .34184 .3203 L p .46 .496 .809 r
F P
0 g
s
.21887 .48454 m .21237 .4935 L .22133 .4985 L p .585 .659 .888 r
F P
0 g
s
.22133 .4985 m .22818 .48912 L .21887 .48454 L p .585 .659 .888 r
F P
0 g
s
.26425 .48493 m .25746 .49648 L .2671 .49667 L p .708 .832 .942 r
F P
0 g
s
.2671 .49667 m .27413 .48483 L .26425 .48493 L p .708 .832 .942 r
F P
0 g
s
.28353 .30041 m .28999 .28814 L .29976 .29124 L p .636 .717 .906 r
F P
0 g
s
.28999 .28814 m .28353 .30041 L .27353 .2987 L p .668 .756 .917 r
F P
0 g
s
.17513 .43201 m .17995 .42295 L .17799 .41417 L p .131 .107 .562 r
F P
0 g
s
.17995 .42295 m .17513 .43201 L .17827 .44082 L p .226 .222 .645 r
F P
0 g
s
.34797 .32818 m .34224 .3384 L .33603 .33075 L p .415 .439 .777 r
F P
0 g
s
.33603 .33075 m .34184 .3203 L .34797 .32818 L p .415 .439 .777 r
F P
0 g
s
.35602 .37232 m .35045 .38357 L .34881 .37492 L p .08 .056 .527 r
F P
0 g
s
.34881 .37492 m .35438 .36361 L .35602 .37232 L p .08 .056 .527 r
F P
0 g
s
.18274 .46526 m .18804 .45768 L .1826 .44942 L p .404 .409 .751 r
F P
0 g
s
.18804 .45768 m .18274 .46526 L .18895 .47333 L p .448 .468 .788 r
F P
0 g
s
.3477 .40868 m .34199 .42101 L .3442 .41293 L p 0 0 0 r
F P
0 g
s
.3442 .41293 m .3499 .40059 L .3477 .40868 L p 0 0 0 r
F P
0 g
s
.29911 .46853 m .2927 .48123 L .30108 .47781 L p .807 .954 .913 r
F P
0 g
s
.30108 .47781 m .30761 .46496 L .29911 .46853 L p .807 .954 .913 r
F P
0 g
s
.21005 .479 m .20389 .48757 L .21237 .4935 L p .554 .615 .868 r
F P
0 g
s
.21237 .4935 m .21887 .48454 L .21005 .479 L p .554 .615 .868 r
F P
0 g
s
.3281 .44201 m .32209 .45491 L .32783 .44862 L p .831 .981 .692 r
F P
0 g
s
.32783 .44862 m .33388 .43567 L .3281 .44201 L p .831 .981 .692 r
F P
0 g
s
.18895 .47333 m .1945 .46545 L .18804 .45768 L p .448 .468 .788 r
F P
0 g
s
.1945 .46545 m .18895 .47333 L .19604 .48081 L p .487 .521 .818 r
F P
0 g
s
.17731 .40544 m .18201 .39464 L .18261 .38611 L p 0 0 .241 r
F P
0 g
s
.18201 .39464 m .17731 .40544 L .17799 .41417 L p 0 0 .417 r
F P
0 g
s
.2023 .34414 m .20748 .33072 L .21401 .32504 L p .875 .993 .793 r
F P
0 g
s
.20748 .33072 m .2023 .34414 L .19681 .35063 L p .864 .98 .684 r
F P
0 g
s
.20188 .4726 m .19604 .48081 L .20389 .48757 L p .522 .569 .844 r
F P
0 g
s
.20389 .48757 m .21005 .479 L .20188 .4726 L p .522 .569 .844 r
F P
0 g
s
.22969 .31645 m .23558 .30272 L .24445 .30009 L p .799 .913 .917 r
F P
0 g
s
.23558 .30272 m .22969 .31645 L .22145 .32027 L p .83 .95 .897 r
F P
0 g
s
.19604 .48081 m .20188 .4726 L .1945 .46545 L p .487 .521 .818 r
F P
0 g
s
.27353 .2987 m .28012 .28609 L .28999 .28814 L p .668 .756 .917 r
F P
0 g
s
.28012 .28609 m .27353 .2987 L .26358 .29807 L p .699 .796 .925 r
F P
0 g
s
.35309 .33648 m .34743 .34651 L .34224 .3384 L p .363 .374 .738 r
F P
0 g
s
.34224 .3384 m .34797 .32818 L .35309 .33648 L p .363 .374 .738 r
F P
0 g
s
.25421 .48389 m .24764 .49515 L .25746 .49648 L p .676 .789 .934 r
F P
0 g
s
.25746 .49648 m .26425 .48493 L .25421 .48389 L p .676 .789 .934 r
F P
0 g
s
.17827 .44082 m .18318 .43166 L .17995 .42295 L p .226 .222 .645 r
F P
0 g
s
.18318 .43166 m .17827 .44082 L .1826 .44942 L p .302 .315 .708 r
F P
0 g
s
.3564 .38096 m .35082 .39218 L .35045 .38357 L p 0 0 .399 r
F P
0 g
s
.35045 .38357 m .35602 .37232 L .3564 .38096 L p 0 0 .399 r
F P
0 g
s
.26358 .29807 m .27028 .28512 L .28012 .28609 L p .699 .796 .925 r
F P
0 g
s
.27028 .28512 m .26358 .29807 L .25383 .29853 L p .73 .837 .93 r
F P
0 g
s
.35711 .34509 m .3515 .35496 L .34743 .34651 L p .301 .298 .689 r
F P
0 g
s
.34743 .34651 m .35309 .33648 L .35711 .34509 L p .301 .298 .689 r
F P
0 g
s
.34425 .41631 m .33854 .42863 L .34199 .42101 L p 0 0 0 r
F P
0 g
s
.34199 .42101 m .3477 .40868 L .34425 .41631 L p 0 0 0 r
F P
0 g
s
.28995 .47105 m .28366 .48359 L .2927 .48123 L p .777 .914 .932 r
F P
0 g
s
.2927 .48123 m .29911 .46853 L .28995 .47105 L p .777 .914 .932 r
F P
0 g
s
.17799 .41417 m .18271 .40336 L .18201 .39464 L p 0 0 .417 r
F P
0 g
s
.18271 .40336 m .17799 .41417 L .17995 .42295 L p .067 .066 .546 r
F P
0 g
s
.32127 .44754 m .31531 .46039 L .32209 .45491 L p .849 .998 .806 r
F P
0 g
s
.32209 .45491 m .3281 .44201 L .32127 .44754 L p .849 .998 .806 r
F P
0 g
s
.24416 .48172 m .23783 .49268 L .24764 .49515 L p .643 .746 .924 r
F P
0 g
s
.24764 .49515 m .25421 .48389 L .24416 .48172 L p .643 .746 .924 r
F P
0 g
s
.1826 .44942 m .18762 .44013 L .18318 .43166 L p .302 .315 .708 r
F P
0 g
s
.18762 .44013 m .1826 .44942 L .18804 .45768 L p .364 .392 .756 r
F P
0 g
s
.22145 .32027 m .22736 .30639 L .23558 .30272 L p .83 .95 .897 r
F P
0 g
s
.22736 .30639 m .22145 .32027 L .21401 .32504 L p .855 .981 .859 r
F P
0 g
s
.19681 .35063 m .20198 .33719 L .20748 .33072 L p .864 .98 .684 r
F P
0 g
s
.25383 .29853 m .26065 .28527 L .27028 .28512 L p .73 .837 .93 r
F P
0 g
s
.26065 .28527 m .25383 .29853 L .24445 .30009 L p .762 .878 .93 r
F P
0 g
s
.35996 .35385 m .35438 .36361 L .3515 .35496 L p .226 .206 .625 r
F P
0 g
s
.3515 .35496 m .35711 .34509 L .35996 .35385 L p .226 .206 .625 r
F P
0 g
s
.23429 .47845 m .22818 .48912 L .23783 .49268 L p .611 .703 .91 r
F P
0 g
s
.23783 .49268 m .24416 .48172 L .23429 .47845 L p .611 .703 .91 r
F P
0 g
s
.18739 .37382 m .18261 .38611 L .18201 .39464 L p 0 0 .213 r
F P
0 g
s
.18804 .45768 m .19319 .44822 L .18762 .44013 L p .364 .392 .756 r
F P
0 g
s
.19319 .44822 m .18804 .45768 L .1945 .46545 L p .417 .458 .795 r
F P
0 g
s
.33335 .2968 m .32692 .3063 L .31837 .3004 L p .549 .593 .85 r
F P
0 g
s
.31837 .3004 m .32505 .29046 L .33335 .2968 L p .549 .593 .85 r
F P
0 g
s
.32505 .29046 m .31837 .3004 L .30927 .29535 L p .58 .635 .87 r
F P
0 g
s
.34099 .30388 m .33478 .31297 L .32692 .3063 L p .517 .549 .828 r
F P
0 g
s
.32692 .3063 m .33335 .2968 L .34099 .30388 L p .517 .549 .828 r
F P
0 g
s
.35549 .38938 m .3499 .40059 L .35082 .39218 L p 0 0 .225 r
F P
0 g
s
.35082 .39218 m .3564 .38096 L .35549 .38938 L p 0 0 .225 r
F P
0 g
s
.30927 .29535 m .31621 .28496 L .32505 .29046 L p .58 .635 .87 r
F P
0 g
s
.31621 .28496 m .30927 .29535 L .29976 .29124 L p .609 .676 .888 r
F P
0 g
s
.28028 .47245 m .27413 .48483 L .28366 .48359 L p .745 .872 .939 r
F P
0 g
s
.28366 .48359 m .28995 .47105 L .28028 .47245 L p .745 .872 .939 r
F P
0 g
s
.34784 .31157 m .34184 .3203 L .33478 .31297 L p .482 .501 .801 r
F P
0 g
s
.33478 .31297 m .34099 .30388 L .34784 .31157 L p .482 .501 .801 r
F P
0 g
s
.17995 .42295 m .18472 .41212 L .18271 .40336 L p .067 .066 .546 r
F P
0 g
s
.18472 .41212 m .17995 .42295 L .18318 .43166 L p .177 .194 .639 r
F P
0 g
s
.22475 .47414 m .21887 .48454 L .22818 .48912 L p .577 .659 .893 r
F P
0 g
s
.22818 .48912 m .23429 .47845 L .22475 .47414 L p .577 .659 .893 r
F P
0 g
s
.1945 .46545 m .19981 .45579 L .19319 .44822 L p .417 .458 .795 r
F P
0 g
s
.19981 .45579 m .1945 .46545 L .20188 .4726 L p .463 .515 .826 r
F P
0 g
s
.33959 .42334 m .33388 .43567 L .33854 .42863 L p .765 .907 .518 r
F P
0 g
s
.33854 .42863 m .34425 .41631 L .33959 .42334 L p .765 .907 .518 r
F P
0 g
s
.29976 .29124 m .30697 .28036 L .31621 .28496 L p .609 .676 .888 r
F P
0 g
s
.30697 .28036 m .29976 .29124 L .28999 .28814 L p .638 .716 .904 r
F P
0 g
s
.31351 .45217 m .30761 .46496 L .31531 .46039 L p .838 .982 .873 r
F P
0 g
s
.31531 .46039 m .32127 .44754 L .31351 .45217 L p .838 .982 .873 r
F P
0 g
s
.35379 .31978 m .34797 .32818 L .34184 .3203 L p .443 .449 .771 r
F P
0 g
s
.34184 .3203 m .34784 .31157 L .35379 .31978 L p .443 .449 .771 r
F P
0 g
s
.21401 .32504 m .21993 .31105 L .22736 .30639 L p .855 .981 .859 r
F P
0 g
s
.21993 .31105 m .21401 .32504 L .20748 .33072 L p .866 .996 .79 r
F P
0 g
s
.61246 .34011 m .58411 .34039 L .58437 .33 L p .704 .566 .696 r
F P
0 g
s
.58437 .33 m .61194 .32973 L .61246 .34011 L p .704 .566 .696 r
F P
0 g
s
.55789 .3284 m .58437 .33 L .58411 .34039 L p .724 .582 .696 r
F P
0 g
s
.61194 .32973 m .58437 .33 L .58472 .31963 L p .704 .587 .721 r
F P
0 g
s
.58437 .33 m .55789 .3284 L .55892 .31806 L p .723 .602 .722 r
F P
0 g
s
.55892 .31806 m .58472 .31963 L .58437 .33 L p .723 .602 .722 r
F P
0 g
s
.21573 .46887 m .21005 .479 L .21887 .48454 L p .542 .614 .874 r
F P
0 g
s
.21887 .48454 m .22475 .47414 L .21573 .46887 L p .542 .614 .874 r
F P
0 g
s
.20188 .4726 m .20737 .46271 L .19981 .45579 L p .463 .515 .826 r
F P
0 g
s
.20737 .46271 m .20188 .4726 L .21005 .479 L p .504 .567 .852 r
F P
0 g
s
.64185 .33715 m .61246 .34011 L .61194 .32973 L p .677 .545 .696 r
F P
0 g
s
.61194 .32973 m .64036 .32686 L .64185 .33715 L p .677 .545 .696 r
F P
0 g
s
.64036 .32686 m .61194 .32973 L .61138 .31937 L p .68 .568 .722 r
F P
0 g
s
.58472 .31963 m .61138 .31937 L .61194 .32973 L p .704 .587 .721 r
F P
0 g
s
.61293 .35035 m .58394 .35063 L .58411 .34039 L p .703 .543 .668 r
F P
0 g
s
.58411 .34039 m .61246 .34011 L .61293 .35035 L p .703 .543 .668 r
F P
0 g
s
.55705 .33875 m .58411 .34039 L .58394 .35063 L p .725 .561 .669 r
F P
0 g
s
.58411 .34039 m .55705 .33875 L .55789 .3284 L p .724 .582 .696 r
F P
0 g
s
.21005 .479 m .21573 .46887 L .20737 .46271 L p .504 .567 .852 r
F P
0 g
s
.61138 .31937 m .58472 .31963 L .58516 .30944 L p .704 .608 .747 r
F P
0 g
s
.58472 .31963 m .55892 .31806 L .56012 .3079 L p .72 .622 .747 r
F P
0 g
s
.56012 .3079 m .58516 .30944 L .58472 .31963 L p .72 .622 .747 r
F P
0 g
s
.64311 .34732 m .61293 .35035 L .61246 .34011 L p .674 .52 .669 r
F P
0 g
s
.61246 .34011 m .64185 .33715 L .64311 .34732 L p .674 .52 .669 r
F P
0 g
s
.61138 .31937 m .63866 .31661 L .64036 .32686 L p .68 .568 .722 r
F P
0 g
s
.63866 .31661 m .61138 .31937 L .61079 .30919 L p .682 .591 .748 r
F P
0 g
s
.58516 .30944 m .61079 .30919 L .61138 .31937 L p .704 .608 .747 r
F P
0 g
s
.24445 .30009 m .25137 .28652 L .26065 .28527 L p .762 .878 .93 r
F P
0 g
s
.25137 .28652 m .24445 .30009 L .23558 .30272 L p .793 .919 .922 r
F P
0 g
s
.36159 .36264 m .35602 .37232 L .35438 .36361 L p .133 .091 .541 r
F P
0 g
s
.35438 .36361 m .35996 .35385 L .36159 .36264 L p .133 .091 .541 r
F P
0 g
s
.28999 .28814 m .29748 .27677 L .30697 .28036 L p .638 .716 .904 r
F P
0 g
s
.29748 .27677 m .28999 .28814 L .28012 .28609 L p .667 .757 .917 r
F P
0 g
s
.53241 .32553 m .55789 .3284 L .55705 .33875 L p .739 .595 .697 r
F P
0 g
s
.55789 .3284 m .53241 .32553 L .5339 .31524 L p .736 .614 .723 r
F P
0 g
s
.5339 .31524 m .55892 .31806 L .55789 .3284 L p .736 .614 .723 r
F P
0 g
s
.61334 .36029 m .58387 .36058 L .58394 .35063 L p .701 .519 .639 r
F P
0 g
s
.58394 .35063 m .61293 .35035 L .61334 .36029 L p .701 .519 .639 r
F P
0 g
s
.55642 .34898 m .58394 .35063 L .58387 .36058 L p .724 .539 .639 r
F P
0 g
s
.58394 .35063 m .55642 .34898 L .55705 .33875 L p .725 .561 .669 r
F P
0 g
s
.35876 .32835 m .35309 .33648 L .34797 .32818 L p .398 .39 .734 r
F P
0 g
s
.34797 .32818 m .35379 .31978 L .35876 .32835 L p .398 .39 .734 r
F P
0 g
s
.27026 .47273 m .26425 .48493 L .27413 .48483 L p .711 .83 .938 r
F P
0 g
s
.27413 .48483 m .28028 .47245 L .27026 .47273 L p .711 .83 .938 r
F P
0 g
s
.18201 .39464 m .18679 .38237 L .18739 .37382 L p 0 0 .213 r
F P
0 g
s
.18679 .38237 m .18201 .39464 L .18271 .40336 L p 0 0 .399 r
F P
0 g
s
.61079 .30919 m .58516 .30944 L .58568 .29957 L p .702 .629 .772 r
F P
0 g
s
.58516 .30944 m .56012 .3079 L .56148 .29808 L p .716 .641 .773 r
F P
0 g
s
.56148 .29808 m .58568 .29957 L .58516 .30944 L p .716 .641 .773 r
F P
0 g
s
.53117 .33586 m .55705 .33875 L .55642 .34898 L p .74 .575 .669 r
F P
0 g
s
.55705 .33875 m .53117 .33586 L .53241 .32553 L p .739 .595 .697 r
F P
0 g
s
.64411 .35722 m .61334 .36029 L .61293 .35035 L p .669 .494 .64 r
F P
0 g
s
.61293 .35035 m .64311 .34732 L .64411 .35722 L p .669 .494 .64 r
F P
0 g
s
.55892 .31806 m .5339 .31524 L .53562 .30513 L p .732 .633 .748 r
F P
0 g
s
.53562 .30513 m .56012 .3079 L .55892 .31806 L p .732 .633 .748 r
F P
0 g
s
.18318 .43166 m .188 .42078 L .18472 .41212 L p .177 .194 .639 r
F P
0 g
s
.188 .42078 m .18318 .43166 L .18762 .44013 L p .265 .296 .707 r
F P
0 g
s
.61079 .30919 m .63677 .30654 L .63866 .31661 L p .682 .591 .748 r
F P
0 g
s
.63677 .30654 m .61079 .30919 L .61017 .29934 L p .683 .614 .773 r
F P
0 g
s
.58568 .29957 m .61017 .29934 L .61079 .30919 L p .702 .629 .772 r
F P
0 g
s
.35331 .39745 m .3477 .40868 L .3499 .40059 L p 0 0 .001 r
F P
0 g
s
.3499 .40059 m .35549 .38938 L .35331 .39745 L p 0 0 .001 r
F P
0 g
s
.67112 .33085 m .64185 .33715 L .64036 .32686 L p .643 .521 .699 r
F P
0 g
s
.64036 .32686 m .66855 .32076 L .67112 .33085 L p .643 .521 .699 r
F P
0 g
s
.66855 .32076 m .64036 .32686 L .63866 .31661 L p .649 .547 .725 r
F P
0 g
s
.58387 .36058 m .55599 .35891 L .55642 .34898 L p .724 .539 .639 r
F P
0 g
s
.53021 .34606 m .55642 .34898 L .55599 .35891 L p .741 .553 .639 r
F P
0 g
s
.55642 .34898 m .53021 .34606 L .53117 .33586 L p .74 .575 .669 r
F P
0 g
s
.63866 .31661 m .66558 .31076 L .66855 .32076 L p .649 .547 .725 r
F P
0 g
s
.66558 .31076 m .63866 .31661 L .63677 .30654 L p .654 .572 .751 r
F P
0 g
s
.56012 .3079 m .53562 .30513 L .53754 .29536 L p .726 .651 .774 r
F P
0 g
s
.53754 .29536 m .56148 .29808 L .56012 .3079 L p .726 .651 .774 r
F P
0 g
s
.67325 .34086 m .64311 .34732 L .64185 .33715 L p .637 .494 .671 r
F P
0 g
s
.64185 .33715 m .67112 .33085 L .67325 .34086 L p .637 .494 .671 r
F P
0 g
s
.28012 .28609 m .28787 .27422 L .29748 .27677 L p .667 .757 .917 r
F P
0 g
s
.28787 .27422 m .28012 .28609 L .27028 .28512 L p .696 .798 .928 r
F P
0 g
s
.3338 .42967 m .3281 .44201 L .33388 .43567 L p .833 .981 .693 r
F P
0 g
s
.33388 .43567 m .33959 .42334 L .3338 .42967 L p .833 .981 .693 r
F P
0 g
s
.61369 .36979 m .58391 .37008 L .58387 .36058 L p .697 .492 .607 r
F P
0 g
s
.58387 .36058 m .61334 .36029 L .61369 .36979 L p .697 .492 .607 r
F P
0 g
s
.55599 .35891 m .58387 .36058 L .58391 .37008 L p .723 .513 .606 r
F P
0 g
s
.30494 .4558 m .29911 .46853 L .30761 .46496 L p .812 .95 .91 r
F P
0 g
s
.30761 .46496 m .31351 .45217 L .30494 .4558 L p .812 .95 .91 r
F P
0 g
s
.36266 .33718 m .35711 .34509 L .35309 .33648 L p .347 .322 .689 r
F P
0 g
s
.35309 .33648 m .35876 .32835 L .36266 .33718 L p .347 .322 .689 r
F P
0 g
s
.64484 .36669 m .61369 .36979 L .61334 .36029 L p .663 .465 .607 r
F P
0 g
s
.61334 .36029 m .64411 .35722 L .64484 .36669 L p .663 .465 .607 r
F P
0 g
s
.50781 .3219 m .53241 .32553 L .53117 .33586 L p .748 .604 .697 r
F P
0 g
s
.53241 .32553 m .50781 .3219 L .50959 .31163 L p .744 .622 .724 r
F P
0 g
s
.50959 .31163 m .5339 .31524 L .53241 .32553 L p .744 .622 .724 r
F P
0 g
s
.61017 .29934 m .58568 .29957 L .58628 .29019 L p .699 .651 .799 r
F P
0 g
s
.58568 .29957 m .56148 .29808 L .56297 .28875 L p .711 .661 .799 r
F P
0 g
s
.56297 .28875 m .58628 .29019 L .58568 .29957 L p .711 .661 .799 r
F P
0 g
s
.20748 .33072 m .21343 .31662 L .21993 .31105 L p .866 .996 .79 r
F P
0 g
s
.21343 .31662 m .20748 .33072 L .20198 .33719 L p .848 .976 .673 r
F P
0 g
s
.61017 .29934 m .63472 .29683 L .63677 .30654 L p .683 .614 .773 r
F P
0 g
s
.63472 .29683 m .61017 .29934 L .60954 .28997 L p .682 .638 .799 r
F P
0 g
s
.58628 .29019 m .60954 .28997 L .61017 .29934 L p .699 .651 .799 r
F P
0 g
s
.23558 .30272 m .2426 .28888 L .25137 .28652 L p .793 .919 .922 r
F P
0 g
s
.2426 .28888 m .23558 .30272 L .22736 .30639 L p .822 .958 .902 r
F P
0 g
s
.5339 .31524 m .50959 .31163 L .51163 .30155 L p .739 .64 .749 r
F P
0 g
s
.51163 .30155 m .53562 .30513 L .5339 .31524 L p .739 .64 .749 r
F P
0 g
s
.63677 .30654 m .66225 .30098 L .66558 .31076 L p .654 .572 .751 r
F P
0 g
s
.66225 .30098 m .63677 .30654 L .63472 .29683 L p .658 .598 .776 r
F P
0 g
s
.26007 .47186 m .25421 .48389 L .26425 .48493 L p .677 .788 .933 r
F P
0 g
s
.26425 .48493 m .27026 .47273 L .26007 .47186 L p .677 .788 .933 r
F P
0 g
s
.50632 .33221 m .53117 .33586 L .53021 .34606 L p .751 .584 .67 r
F P
0 g
s
.53117 .33586 m .50632 .33221 L .50781 .3219 L p .748 .604 .697 r
F P
0 g
s
.36196 .37132 m .3564 .38096 L .35602 .37232 L p .015 0 .425 r
F P
0 g
s
.35602 .37232 m .36159 .36264 L .36196 .37132 L p .015 0 .425 r
F P
0 g
s
.6749 .35065 m .64411 .35722 L .64311 .34732 L p .629 .465 .641 r
F P
0 g
s
.64311 .34732 m .67325 .34086 L .6749 .35065 L p .629 .465 .641 r
F P
0 g
s
.18762 .44013 m .1925 .42918 L .188 .42078 L p .265 .296 .707 r
F P
0 g
s
.1925 .42918 m .18762 .44013 L .19319 .44822 L p .336 .38 .759 r
F P
0 g
s
.58391 .37008 m .55578 .36841 L .55599 .35891 L p .723 .513 .606 r
F P
0 g
s
.52953 .35598 m .55599 .35891 L .55578 .36841 L p .741 .529 .606 r
F P
0 g
s
.55599 .35891 m .52953 .35598 L .53021 .34606 L p .741 .553 .639 r
F P
0 g
s
.56148 .29808 m .53754 .29536 L .53964 .28608 L p .719 .669 .8 r
F P
0 g
s
.53964 .28608 m .56297 .28875 L .56148 .29808 L p .719 .669 .8 r
F P
0 g
s
.18271 .40336 m .18751 .39111 L .18679 .38237 L p 0 0 .399 r
F P
0 g
s
.18751 .39111 m .18271 .40336 L .18472 .41212 L p .032 .043 .536 r
F P
0 g
s
.53562 .30513 m .51163 .30155 L .51389 .29181 L p .733 .657 .775 r
F P
0 g
s
.51389 .29181 m .53754 .29536 L .53562 .30513 L p .733 .657 .775 r
F P
0 g
s
.50514 .34239 m .53021 .34606 L .52953 .35598 L p .753 .563 .64 r
F P
0 g
s
.53021 .34606 m .50514 .34239 L .50632 .33221 L p .751 .584 .67 r
F P
0 g
s
.27028 .28512 m .2783 .27277 L .28787 .27422 L p .696 .798 .928 r
F P
0 g
s
.2783 .27277 m .27028 .28512 L .26065 .28527 L p .725 .841 .936 r
F P
0 g
s
.63472 .29683 m .65861 .29159 L .66225 .30098 L p .658 .598 .776 r
F P
0 g
s
.65861 .29159 m .63472 .29683 L .63255 .28761 L p .662 .625 .802 r
F P
0 g
s
.60954 .28997 m .63255 .28761 L .63472 .29683 L p .682 .638 .799 r
F P
0 g
s
.34733 .29674 m .34099 .30388 L .33335 .2968 L p .538 .553 .818 r
F P
0 g
s
.33335 .2968 m .34012 .28913 L .34733 .29674 L p .538 .553 .818 r
F P
0 g
s
.34012 .28913 m .33335 .2968 L .32505 .29046 L p .565 .595 .842 r
F P
0 g
s
.34988 .40504 m .34425 .41631 L .3477 .40868 L p 0 0 0 r
F P
0 g
s
.3477 .40868 m .35331 .39745 L .34988 .40504 L p 0 0 0 r
F P
0 g
s
.24988 .46986 m .24416 .48172 L .25421 .48389 L p .643 .746 .924 r
F P
0 g
s
.25421 .48389 m .26007 .47186 L .24988 .46986 L p .643 .746 .924 r
F P
0 g
s
.61397 .37869 m .58404 .37898 L .58391 .37008 L p .692 .462 .57 r
F P
0 g
s
.58391 .37008 m .61369 .36979 L .61397 .37869 L p .692 .462 .57 r
F P
0 g
s
.55578 .36841 m .58391 .37008 L .58404 .37898 L p .719 .484 .569 r
F P
0 g
s
.36542 .34611 m .35996 .35385 L .35711 .34509 L p .285 .241 .632 r
F P
0 g
s
.35711 .34509 m .36266 .33718 L .36542 .34611 L p .285 .241 .632 r
F P
0 g
s
.67605 .36006 m .64484 .36669 L .64411 .35722 L p .619 .432 .608 r
F P
0 g
s
.64411 .35722 m .6749 .35065 L .67605 .36006 L p .619 .432 .608 r
F P
0 g
s
.35378 .30492 m .34784 .31157 L .34099 .30388 L p .509 .51 .792 r
F P
0 g
s
.34099 .30388 m .34733 .29674 L .35378 .30492 L p .509 .51 .792 r
F P
0 g
s
.32505 .29046 m .33229 .28222 L .34012 .28913 L p .565 .595 .842 r
F P
0 g
s
.33229 .28222 m .32505 .29046 L .31621 .28496 L p .591 .635 .863 r
F P
0 g
s
.19319 .44822 m .19816 .43719 L .1925 .42918 L p .336 .38 .759 r
F P
0 g
s
.19816 .43719 m .19319 .44822 L .19981 .45579 L p .396 .45 .799 r
F P
0 g
s
.64529 .37559 m .61397 .37869 L .61369 .36979 L p .655 .433 .57 r
F P
0 g
s
.61369 .36979 m .64484 .36669 L .64529 .37559 L p .655 .433 .57 r
F P
0 g
s
.60954 .28997 m .58628 .29019 L .58693 .28143 L p .693 .674 .826 r
F P
0 g
s
.58628 .29019 m .56297 .28875 L .56457 .28004 L p .703 .682 .827 r
F P
0 g
s
.56457 .28004 m .58693 .28143 L .58628 .29019 L p .703 .682 .827 r
F P
0 g
s
.63255 .28761 m .60954 .28997 L .6089 .28122 L p .68 .664 .827 r
F P
0 g
s
.58693 .28143 m .6089 .28122 L .60954 .28997 L p .693 .674 .826 r
F P
0 g
s
.48411 .31791 m .50781 .3219 L .50632 .33221 L p .753 .609 .698 r
F P
0 g
s
.50781 .3219 m .48411 .31791 L .48602 .30764 L p .749 .627 .724 r
F P
0 g
s
.48602 .30764 m .50959 .31163 L .50781 .3219 L p .749 .627 .724 r
F P
0 g
s
.29571 .45837 m .28995 .47105 L .29911 .46853 L p .781 .911 .929 r
F P
0 g
s
.29911 .46853 m .30494 .4558 L .29571 .45837 L p .781 .911 .929 r
F P
0 g
s
.50959 .31163 m .48602 .30764 L .48821 .29757 L p .743 .644 .75 r
F P
0 g
s
.48821 .29757 m .51163 .30155 L .50959 .31163 L p .743 .644 .75 r
F P
0 g
s
.35939 .31354 m .35379 .31978 L .34784 .31157 L p .478 .463 .762 r
F P
0 g
s
.34784 .31157 m .35378 .30492 L .35939 .31354 L p .478 .463 .762 r
F P
0 g
s
.31621 .28496 m .32394 .27609 L .33229 .28222 L p .591 .635 .863 r
F P
0 g
s
.32394 .27609 m .31621 .28496 L .30697 .28036 L p .616 .675 .883 r
F P
0 g
s
.4825 .32821 m .50632 .33221 L .50514 .34239 L p .757 .59 .67 r
F P
0 g
s
.50632 .33221 m .4825 .32821 L .48411 .31791 L p .753 .609 .698 r
F P
0 g
s
.53754 .29536 m .51389 .29181 L .51636 .28257 L p .725 .675 .801 r
F P
0 g
s
.51636 .28257 m .53964 .28608 L .53754 .29536 L p .725 .675 .801 r
F P
0 g
s
.55578 .36841 m .52914 .36547 L .52953 .35598 L p .741 .529 .606 r
F P
0 g
s
.5043 .3523 m .52953 .35598 L .52914 .36547 L p .753 .539 .606 r
F P
0 g
s
.52953 .35598 m .5043 .3523 L .50514 .34239 L p .753 .563 .64 r
F P
0 g
s
.32696 .43517 m .32127 .44754 L .3281 .44201 L p .85 .998 .806 r
F P
0 g
s
.3281 .44201 m .3338 .42967 L .32696 .43517 L p .85 .998 .806 r
F P
0 g
s
.58404 .37898 m .5558 .37731 L .55578 .36841 L p .719 .484 .569 r
F P
0 g
s
.52914 .36547 m .55578 .36841 L .5558 .37731 L p .739 .5 .568 r
F P
0 g
s
.69828 .32117 m .67112 .33085 L .66855 .32076 L p .603 .496 .704 r
F P
0 g
s
.66855 .32076 m .69468 .31141 L .69828 .32117 L p .603 .496 .704 r
F P
0 g
s
.69468 .31141 m .66855 .32076 L .66558 .31076 L p .613 .525 .731 r
F P
0 g
s
.22736 .30639 m .23447 .29229 L .2426 .28888 L p .822 .958 .902 r
F P
0 g
s
.23447 .29229 m .22736 .30639 L .21993 .31105 L p .842 .988 .859 r
F P
0 g
s
.23986 .46675 m .23429 .47845 L .24416 .48172 L p .608 .704 .912 r
F P
0 g
s
.24416 .48172 m .24988 .46986 L .23986 .46675 L p .608 .704 .912 r
F P
0 g
s
.56297 .28875 m .53964 .28608 L .54188 .27743 L p .71 .688 .828 r
F P
0 g
s
.54188 .27743 m .56457 .28004 L .56297 .28875 L p .71 .688 .828 r
F P
0 g
s
.66558 .31076 m .6905 .30179 L .69468 .31141 L p .613 .525 .731 r
F P
0 g
s
.6905 .30179 m .66558 .31076 L .66225 .30098 L p .622 .554 .757 r
F P
0 g
s
.20198 .33719 m .20794 .32302 L .21343 .31662 L p .848 .976 .673 r
F P
0 g
s
.20794 .32302 m .20198 .33719 L .19762 .34438 L p .777 .898 .494 r
F P
0 g
s
.19981 .45579 m .20488 .44465 L .19816 .43719 L p .396 .45 .799 r
F P
0 g
s
.20488 .44465 m .19981 .45579 L .20737 .46271 L p .447 .511 .831 r
F P
0 g
s
.36107 .37974 m .35549 .38938 L .3564 .38096 L p 0 0 .267 r
F P
0 g
s
.3564 .38096 m .36196 .37132 L .36107 .37974 L p 0 0 .267 r
F P
0 g
s
.51163 .30155 m .48821 .29757 L .49063 .28784 L p .737 .661 .776 r
F P
0 g
s
.49063 .28784 m .51389 .29181 L .51163 .30155 L p .737 .661 .776 r
F P
0 g
s
.70124 .33093 m .67325 .34086 L .67112 .33085 L p .592 .465 .676 r
F P
0 g
s
.67112 .33085 m .69828 .32117 L .70124 .33093 L p .592 .465 .676 r
F P
0 g
s
.48121 .3384 m .50514 .34239 L .5043 .3523 L p .759 .569 .64 r
F P
0 g
s
.50514 .34239 m .48121 .3384 L .4825 .32821 L p .757 .59 .67 r
F P
0 g
s
.18739 .37382 m .19255 .3604 L .19445 .35216 L p 0 0 0 r
F P
0 g
s
.19255 .3604 m .18739 .37382 L .18679 .38237 L p 0 0 .21 r
F P
0 g
s
.18472 .41212 m .18954 .39988 L .18751 .39111 L p .032 .043 .536 r
F P
0 g
s
.18954 .39988 m .18472 .41212 L .188 .42078 L p .15 .178 .635 r
F P
0 g
s
.36407 .32247 m .35876 .32835 L .35379 .31978 L p .443 .411 .728 r
F P
0 g
s
.35379 .31978 m .35939 .31354 L .36407 .32247 L p .443 .411 .728 r
F P
0 g
s
.30697 .28036 m .31521 .27087 L .32394 .27609 L p .616 .675 .883 r
F P
0 g
s
.31521 .27087 m .30697 .28036 L .29748 .27677 L p .641 .715 .902 r
F P
0 g
s
.26065 .28527 m .26892 .27244 L .2783 .27277 L p .725 .841 .936 r
F P
0 g
s
.26892 .27244 m .26065 .28527 L .25137 .28652 L p .754 .885 .938 r
F P
0 g
s
.63255 .28761 m .65473 .28273 L .65861 .29159 L p .662 .625 .802 r
F P
0 g
s
.65473 .28273 m .63255 .28761 L .63028 .27903 L p .664 .653 .829 r
F P
0 g
s
.6089 .28122 m .63028 .27903 L .63255 .28761 L p .68 .664 .827 r
F P
0 g
s
.66225 .30098 m .6858 .29247 L .6905 .30179 L p .622 .554 .757 r
F P
0 g
s
.6858 .29247 m .66225 .30098 L .65861 .29159 L p .631 .583 .782 r
F P
0 g
s
.23019 .4626 m .22475 .47414 L .23429 .47845 L p .572 .66 .897 r
F P
0 g
s
.23429 .47845 m .23986 .46675 L .23019 .4626 L p .572 .66 .897 r
F P
0 g
s
.20737 .46271 m .21255 .45146 L .20488 .44465 L p .447 .511 .831 r
F P
0 g
s
.21255 .45146 m .20737 .46271 L .21573 .46887 L p .493 .565 .857 r
F P
0 g
s
.67669 .36895 m .64529 .37559 L .64484 .36669 L p .606 .396 .569 r
F P
0 g
s
.64484 .36669 m .67605 .36006 L .67669 .36895 L p .606 .396 .569 r
F P
0 g
s
.367 .355 m .36159 .36264 L .35996 .35385 L p .208 .141 .558 r
F P
0 g
s
.35996 .35385 m .36542 .34611 L .367 .355 L p .208 .141 .558 r
F P
0 g
s
.22104 .45747 m .21573 .46887 L .22475 .47414 L p .534 .614 .879 r
F P
0 g
s
.22475 .47414 m .23019 .4626 L .22104 .45747 L p .534 .614 .879 r
F P
0 g
s
.21573 .46887 m .22104 .45747 L .21255 .45146 L p .493 .565 .857 r
F P
0 g
s
.61417 .38686 m .58427 .38715 L .58404 .37898 L p .684 .425 .525 r
F P
0 g
s
.58404 .37898 m .61397 .37869 L .61417 .38686 L p .684 .425 .525 r
F P
0 g
s
.5558 .37731 m .58404 .37898 L .58427 .38715 L p .714 .449 .524 r
F P
0 g
s
.70352 .34055 m .6749 .35065 L .67325 .34086 L p .579 .431 .644 r
F P
0 g
s
.67325 .34086 m .70124 .33093 L .70352 .34055 L p .579 .431 .644 r
F P
0 g
s
.64545 .38378 m .61417 .38686 L .61397 .37869 L p .644 .394 .525 r
F P
0 g
s
.61397 .37869 m .64529 .37559 L .64545 .38378 L p .644 .394 .525 r
F P
0 g
s
.53964 .28608 m .51636 .28257 L .51898 .27397 L p .714 .693 .828 r
F P
0 g
s
.51898 .27397 m .54188 .27743 L .53964 .28608 L p .714 .693 .828 r
F P
0 g
s
.28596 .45984 m .28028 .47245 L .28995 .47105 L p .747 .87 .937 r
F P
0 g
s
.28995 .47105 m .29571 .45837 L .28596 .45984 L p .747 .87 .937 r
F P
0 g
s
.4615 .31395 m .48411 .31791 L .4825 .32821 L p .755 .611 .698 r
F P
0 g
s
.48411 .31791 m .4615 .31395 L .46341 .30366 L p .751 .628 .724 r
F P
0 g
s
.46341 .30366 m .48602 .30764 L .48411 .31791 L p .751 .628 .724 r
F P
0 g
s
.6089 .28122 m .58693 .28143 L .58765 .27344 L p .686 .698 .856 r
F P
0 g
s
.58693 .28143 m .56457 .28004 L .56626 .2721 L p .692 .704 .856 r
F P
0 g
s
.56626 .2721 m .58765 .27344 L .58693 .28143 L p .692 .704 .856 r
F P
0 g
s
.5558 .37731 m .52906 .37437 L .52914 .36547 L p .739 .5 .568 r
F P
0 g
s
.50379 .36179 m .52914 .36547 L .52906 .37437 L p .752 .511 .567 r
F P
0 g
s
.52914 .36547 m .50379 .36179 L .5043 .3523 L p .753 .539 .606 r
F P
0 g
s
.34524 .41201 m .33959 .42334 L .34425 .41631 L p .736 .891 .497 r
F P
0 g
s
.34425 .41631 m .34988 .40504 L .34524 .41201 L p .736 .891 .497 r
F P
0 g
s
.51389 .29181 m .49063 .28784 L .49326 .27862 L p .728 .678 .802 r
F P
0 g
s
.49326 .27862 m .51636 .28257 L .51389 .29181 L p .728 .678 .802 r
F P
0 g
s
.63028 .27903 m .6089 .28122 L .60826 .27325 L p .677 .691 .856 r
F P
0 g
s
.58765 .27344 m .60826 .27325 L .6089 .28122 L p .686 .698 .856 r
F P
0 g
s
.65861 .29159 m .68066 .28359 L .6858 .29247 L p .631 .583 .782 r
F P
0 g
s
.68066 .28359 m .65861 .29159 L .65473 .28273 L p .638 .613 .808 r
F P
0 g
s
.48602 .30764 m .46341 .30366 L .46559 .29357 L p .745 .646 .75 r
F P
0 g
s
.46559 .29357 m .48821 .29757 L .48602 .30764 L p .745 .646 .75 r
F P
0 g
s
.36774 .33157 m .36266 .33718 L .35876 .32835 L p .402 .352 .687 r
F P
0 g
s
.35876 .32835 m .36407 .32247 L .36774 .33157 L p .402 .352 .687 r
F P
0 g
s
.48027 .34831 m .5043 .3523 L .50379 .36179 L p .76 .545 .606 r
F P
0 g
s
.5043 .3523 m .48027 .34831 L .48121 .3384 L p .759 .569 .64 r
F P
0 g
s
.29748 .27677 m .30623 .26662 L .31521 .27087 L p .641 .715 .902 r
F P
0 g
s
.30623 .26662 m .29748 .27677 L .28787 .27422 L p .666 .757 .918 r
F P
0 g
s
.45988 .32427 m .4825 .32821 L .48121 .3384 L p .759 .592 .67 r
F P
0 g
s
.4825 .32821 m .45988 .32427 L .4615 .31395 L p .755 .611 .698 r
F P
0 g
s
.58427 .38715 m .55604 .38548 L .5558 .37731 L p .714 .449 .524 r
F P
0 g
s
.52906 .37437 m .5558 .37731 L .55604 .38548 L p .735 .466 .522 r
F P
0 g
s
.31918 .43976 m .31351 .45217 L .32127 .44754 L p .839 .981 .873 r
F P
0 g
s
.32127 .44754 m .32696 .43517 L .31918 .43976 L p .839 .981 .873 r
F P
0 g
s
.56457 .28004 m .54188 .27743 L .54424 .26956 L p .697 .709 .857 r
F P
0 g
s
.54424 .26956 m .56626 .2721 L .56457 .28004 L p .697 .709 .857 r
F P
0 g
s
.188 .42078 m .19286 .40854 L .18954 .39988 L p .15 .178 .635 r
F P
0 g
s
.19286 .40854 m .188 .42078 L .1925 .42918 L p .244 .286 .707 r
F P
0 g
s
.48821 .29757 m .46559 .29357 L .46799 .28383 L p .738 .662 .776 r
F P
0 g
s
.46799 .28383 m .49063 .28784 L .48821 .29757 L p .738 .662 .776 r
F P
0 g
s
.21993 .31105 m .22713 .29673 L .23447 .29229 L p .842 .988 .859 r
F P
0 g
s
.22713 .29673 m .21993 .31105 L .21343 .31662 L p .843 .998 .781 r
F P
0 g
s
.35893 .38777 m .35331 .39745 L .35549 .38938 L p 0 0 .058 r
F P
0 g
s
.35549 .38938 m .36107 .37974 L .35893 .38777 L p 0 0 .058 r
F P
0 g
s
.45857 .33447 m .48121 .3384 L .48027 .34831 L p .761 .571 .64 r
F P
0 g
s
.48121 .3384 m .45857 .33447 L .45988 .32427 L p .759 .592 .67 r
F P
0 g
s
.70508 .34986 m .67605 .36006 L .6749 .35065 L p .564 .394 .608 r
F P
0 g
s
.6749 .35065 m .70352 .34055 L .70508 .34986 L p .564 .394 .608 r
F P
0 g
s
.25137 .28652 m .25989 .27325 L .26892 .27244 L p .754 .885 .938 r
F P
0 g
s
.25989 .27325 m .25137 .28652 L .2426 .28888 L p .782 .929 .931 r
F P
0 g
s
.19762 .34438 m .20359 .33016 L .20794 .32302 L p .777 .898 .494 r
F P
0 g
s
.20359 .33016 m .19762 .34438 L .19445 .35216 L p 0 0 0 r
F P
0 g
s
.63028 .27903 m .65065 .27453 L .65473 .28273 L p .664 .653 .829 r
F P
0 g
s
.65065 .27453 m .63028 .27903 L .62795 .27122 L p .665 .684 .858 r
F P
0 g
s
.60826 .27325 m .62795 .27122 L .63028 .27903 L p .677 .691 .856 r
F P
0 g
s
.35922 .30042 m .35378 .30492 L .34733 .29674 L p .543 .521 .781 r
F P
0 g
s
.34733 .29674 m .35343 .29167 L .35922 .30042 L p .543 .521 .781 r
F P
0 g
s
.35343 .29167 m .34733 .29674 L .34012 .28913 L p .565 .56 .807 r
F P
0 g
s
.18679 .38237 m .19196 .36898 L .19255 .3604 L p 0 0 .21 r
F P
0 g
s
.19196 .36898 m .18679 .38237 L .18751 .39111 L p 0 0 .398 r
F P
0 g
s
.34012 .28913 m .34696 .28343 L .35343 .29167 L p .565 .56 .807 r
F P
0 g
s
.34696 .28343 m .34012 .28913 L .33229 .28222 L p .586 .598 .832 r
F P
0 g
s
.36737 .36372 m .36196 .37132 L .36159 .36264 L p .111 .017 .458 r
F P
0 g
s
.36159 .36264 m .367 .355 L .36737 .36372 L p .111 .017 .458 r
F P
0 g
s
.67678 .37717 m .64545 .38378 L .64529 .37559 L p .591 .352 .523 r
F P
0 g
s
.64529 .37559 m .67669 .36895 L .67678 .37717 L p .591 .352 .523 r
F P
0 g
s
.36425 .30954 m .35939 .31354 L .35378 .30492 L p .519 .479 .752 r
F P
0 g
s
.35378 .30492 m .35922 .30042 L .36425 .30954 L p .519 .479 .752 r
F P
0 g
s
.65473 .28273 m .67514 .27528 L .68066 .28359 L p .638 .613 .808 r
F P
0 g
s
.67514 .27528 m .65473 .28273 L .65065 .27453 L p .646 .644 .834 r
F P
0 g
s
.27586 .46017 m .27026 .47273 L .28028 .47245 L p .712 .829 .937 r
F P
0 g
s
.28028 .47245 m .28596 .45984 L .27586 .46017 L p .712 .829 .937 r
F P
0 g
s
.51636 .28257 m .49326 .27862 L .49605 .27003 L p .717 .696 .829 r
F P
0 g
s
.49605 .27003 m .51898 .27397 L .51636 .28257 L p .717 .696 .829 r
F P
0 g
s
.37034 .34071 m .36542 .34611 L .36266 .33718 L p .354 .283 .637 r
F P
0 g
s
.36266 .33718 m .36774 .33157 L .37034 .34071 L p .354 .283 .637 r
F P
0 g
s
.28787 .27422 m .29714 .26341 L .30623 .26662 L p .666 .757 .918 r
F P
0 g
s
.29714 .26341 m .28787 .27422 L .2783 .27277 L p .691 .801 .933 r
F P
0 g
s
.33229 .28222 m .33992 .27583 L .34696 .28343 L p .586 .598 .832 r
F P
0 g
s
.33992 .27583 m .33229 .28222 L .32394 .27609 L p .606 .636 .855 r
F P
0 g
s
.52906 .37437 m .50364 .37069 L .50379 .36179 L p .752 .511 .567 r
F P
0 g
s
.47968 .3578 m .50379 .36179 L .50364 .37069 L p .759 .517 .567 r
F P
0 g
s
.50379 .36179 m .47968 .3578 L .48027 .34831 L p .76 .545 .606 r
F P
0 g
s
.54188 .27743 m .51898 .27397 L .52173 .26615 L p .7 .712 .858 r
F P
0 g
s
.52173 .26615 m .54424 .26956 L .54188 .27743 L p .7 .712 .858 r
F P
0 g
s
.44032 .31038 m .4615 .31395 L .45988 .32427 L p .753 .609 .698 r
F P
0 g
s
.4615 .31395 m .44032 .31038 L .4421 .30006 L p .749 .627 .724 r
F P
0 g
s
.4421 .30006 m .46341 .30366 L .4615 .31395 L p .749 .627 .724 r
F P
0 g
s
.49063 .28784 m .46799 .28383 L .47059 .27458 L p .729 .679 .802 r
F P
0 g
s
.47059 .27458 m .49326 .27862 L .49063 .28784 L p .729 .679 .802 r
F P
0 g
s
.55604 .38548 m .52929 .38255 L .52906 .37437 L p .735 .466 .522 r
F P
0 g
s
.50364 .37069 m .52906 .37437 L .52929 .38255 L p .749 .477 .521 r
F P
0 g
s
.6143 .39416 m .5846 .39445 L .58427 .38715 L p .672 .381 .471 r
F P
0 g
s
.58427 .38715 m .61417 .38686 L .6143 .39416 L p .672 .381 .471 r
F P
0 g
s
.55604 .38548 m .58427 .38715 L .5846 .39445 L p .704 .406 .468 r
F P
0 g
s
.46341 .30366 m .4421 .30006 L .4441 .28992 L p .744 .644 .75 r
F P
0 g
s
.4441 .28992 m .46559 .29357 L .46341 .30366 L p .744 .644 .75 r
F P
0 g
s
.36843 .31889 m .36407 .32247 L .35939 .31354 L p .493 .435 .72 r
F P
0 g
s
.35939 .31354 m .36425 .30954 L .36843 .31889 L p .493 .435 .72 r
F P
0 g
s
.4576 .3444 m .48027 .34831 L .47968 .3578 L p .762 .547 .606 r
F P
0 g
s
.48027 .34831 m .4576 .3444 L .45857 .33447 L p .761 .571 .64 r
F P
0 g
s
.43881 .32074 m .45988 .32427 L .45857 .33447 L p .757 .59 .67 r
F P
0 g
s
.45988 .32427 m .43881 .32074 L .44032 .31038 L p .753 .609 .698 r
F P
0 g
s
.64531 .39111 m .6143 .39416 L .61417 .38686 L p .628 .346 .471 r
F P
0 g
s
.61417 .38686 m .64545 .38378 L .64531 .39111 L p .628 .346 .471 r
F P
0 g
s
.1925 .42918 m .19741 .41693 L .19286 .40854 L p .244 .286 .707 r
F P
0 g
s
.19741 .41693 m .1925 .42918 L .19816 .43719 L p .321 .373 .761 r
F P
0 g
s
.33948 .41825 m .3338 .42967 L .33959 .42334 L p .815 .977 .682 r
F P
0 g
s
.33959 .42334 m .34524 .41201 L .33948 .41825 L p .815 .977 .682 r
F P
0 g
s
.60826 .27325 m .58765 .27344 L .5884 .26634 L p .673 .725 .888 r
F P
0 g
s
.58765 .27344 m .56626 .2721 L .56802 .26506 L p .677 .728 .888 r
F P
0 g
s
.56802 .26506 m .5884 .26634 L .58765 .27344 L p .677 .728 .888 r
F P
0 g
s
.62795 .27122 m .60826 .27325 L .60764 .26616 L p .669 .721 .888 r
F P
0 g
s
.5884 .26634 m .60764 .26616 L .60826 .27325 L p .673 .725 .888 r
F P
0 g
s
.32394 .27609 m .33241 .26897 L .33992 .27583 L p .606 .636 .855 r
F P
0 g
s
.33241 .26897 m .32394 .27609 L .31521 .27087 L p .625 .675 .877 r
F P
0 g
s
.70589 .35872 m .67669 .36895 L .67605 .36006 L p .546 .351 .567 r
F P
0 g
s
.67605 .36006 m .70508 .34986 L .70589 .35872 L p .546 .351 .567 r
F P
0 g
s
.31059 .44335 m .30494 .4558 L .31351 .45217 L p .813 .949 .91 r
F P
0 g
s
.31351 .45217 m .31918 .43976 L .31059 .44335 L p .813 .949 .91 r
F P
0 g
s
.46559 .29357 m .4441 .28992 L .44631 .28013 L p .737 .661 .776 r
F P
0 g
s
.44631 .28013 m .46799 .28383 L .46559 .29357 L p .737 .661 .776 r
F P
0 g
s
.26558 .45935 m .26007 .47186 L .27026 .47273 L p .678 .788 .932 r
F P
0 g
s
.27026 .47273 m .27586 .46017 L .26558 .45935 L p .678 .788 .932 r
F P
0 g
s
.43758 .33097 m .45857 .33447 L .4576 .3444 L p .759 .569 .64 r
F P
0 g
s
.45857 .33447 m .43758 .33097 L .43881 .32074 L p .757 .59 .67 r
F P
0 g
s
.5846 .39445 m .5565 .39279 L .55604 .38548 L p .704 .406 .468 r
F P
0 g
s
.52929 .38255 m .55604 .38548 L .5565 .39279 L p .726 .423 .466 r
F P
0 g
s
.71723 .29949 m .69468 .31141 L .6905 .30179 L p .575 .506 .74 r
F P
0 g
s
.6905 .30179 m .71206 .29033 L .71723 .29949 L p .575 .506 .74 r
F P
0 g
s
.71206 .29033 m .6905 .30179 L .6858 .29247 L p .589 .538 .766 r
F P
0 g
s
.37171 .32832 m .36774 .33157 L .36407 .32247 L p .463 .385 .683 r
F P
0 g
s
.36407 .32247 m .36843 .31889 L .37171 .32832 L p .463 .385 .683 r
F P
0 g
s
.56626 .2721 m .54424 .26956 L .54666 .26259 L p .679 .73 .889 r
F P
0 g
s
.54666 .26259 m .56802 .26506 L .56626 .2721 L p .679 .73 .889 r
F P
0 g
s
.72168 .30887 m .69828 .32117 L .69468 .31141 L p .559 .471 .712 r
F P
0 g
s
.69468 .31141 m .71723 .29949 L .72168 .30887 L p .559 .471 .712 r
F P
0 g
s
.2426 .28888 m .25134 .27518 L .25989 .27325 L p .782 .929 .931 r
F P
0 g
s
.25134 .27518 m .2426 .28888 L .23447 .29229 L p .804 .969 .908 r
F P
0 g
s
.21343 .31662 m .22069 .30211 L .22713 .29673 L p .843 .998 .781 r
F P
0 g
s
.22069 .30211 m .21343 .31662 L .20794 .32302 L p .806 .964 .647 r
F P
0 g
s
.37182 .34973 m .367 .355 L .36542 .34611 L p .296 .2 .574 r
F P
0 g
s
.36542 .34611 m .37034 .34071 L .37182 .34973 L p .296 .2 .574 r
F P
0 g
s
.65065 .27453 m .66935 .26768 L .67514 .27528 L p .646 .644 .834 r
F P
0 g
s
.66935 .26768 m .65065 .27453 L .64645 .26712 L p .652 .678 .862 r
F P
0 g
s
.62795 .27122 m .64645 .26712 L .65065 .27453 L p .665 .684 .858 r
F P
0 g
s
.6858 .29247 m .70625 .28155 L .71206 .29033 L p .589 .538 .766 r
F P
0 g
s
.70625 .28155 m .6858 .29247 L .68066 .28359 L p .602 .571 .792 r
F P
0 g
s
.35555 .39527 m .34988 .40504 L .35331 .39745 L p 0 0 0 r
F P
0 g
s
.35331 .39745 m .35893 .38777 L .35555 .39527 L p 0 0 0 r
F P
0 g
s
.18751 .39111 m .19269 .37775 L .19196 .36898 L p 0 0 .398 r
F P
0 g
s
.19269 .37775 m .18751 .39111 L .18954 .39988 L p .029 .041 .535 r
F P
0 g
s
.2783 .27277 m .28808 .26131 L .29714 .26341 L p .691 .801 .933 r
F P
0 g
s
.28808 .26131 m .2783 .27277 L .26892 .27244 L p .716 .846 .944 r
F P
0 g
s
.19445 .35216 m .20044 .33791 L .20359 .33016 L p 0 0 0 r
F P
0 g
s
.20044 .33791 m .19445 .35216 L .19255 .3604 L p 0 0 .003 r
F P
0 g
s
.19816 .43719 m .20313 .42493 L .19741 .41693 L p .321 .373 .761 r
F P
0 g
s
.20313 .42493 m .19816 .43719 L .20488 .44465 L p .385 .447 .802 r
F P
0 g
s
.49326 .27862 m .47059 .27458 L .47335 .26597 L p .717 .696 .829 r
F P
0 g
s
.47335 .26597 m .49605 .27003 L .49326 .27862 L p .717 .696 .829 r
F P
0 g
s
.64645 .26712 m .62795 .27122 L .6256 .26431 L p .664 .718 .889 r
F P
0 g
s
.60764 .26616 m .6256 .26431 L .62795 .27122 L p .669 .721 .888 r
F P
0 g
s
.36651 .37213 m .36107 .37974 L .36196 .37132 L p 0 0 .323 r
F P
0 g
s
.36196 .37132 m .36737 .36372 L .36651 .37213 L p 0 0 .323 r
F P
0 g
s
.51898 .27397 m .49605 .27003 L .49896 .26222 L p .702 .714 .858 r
F P
0 g
s
.49896 .26222 m .52173 .26615 L .51898 .27397 L p .702 .714 .858 r
F P
0 g
s
.42106 .30753 m .44032 .31038 L .43881 .32074 L p .748 .604 .697 r
F P
0 g
s
.44032 .31038 m .42106 .30753 L .42254 .29715 L p .744 .622 .724 r
F P
0 g
s
.42254 .29715 m .4421 .30006 L .44032 .31038 L p .744 .622 .724 r
F P
0 g
s
.31521 .27087 m .32455 .26298 L .33241 .26897 L p .625 .675 .877 r
F P
0 g
s
.32455 .26298 m .31521 .27087 L .30623 .26662 L p .645 .715 .899 r
F P
0 g
s
.36794 .30739 m .36425 .30954 L .35922 .30042 L p .563 .499 .741 r
F P
0 g
s
.35922 .30042 m .36379 .29776 L .36794 .30739 L p .563 .499 .741 r
F P
0 g
s
.36379 .29776 m .35922 .30042 L .35343 .29167 L p .58 .535 .769 r
F P
0 g
s
.35343 .29167 m .359 .28842 L .36379 .29776 L p .58 .535 .769 r
F P
0 g
s
.359 .28842 m .35343 .29167 L .34696 .28343 L p .595 .57 .795 r
F P
0 g
s
.72533 .31834 m .70124 .33093 L .69828 .32117 L p .543 .435 .681 r
F P
0 g
s
.69828 .32117 m .72168 .30887 L .72533 .31834 L p .543 .435 .681 r
F P
0 g
s
.67634 .38459 m .64531 .39111 L .64545 .38378 L p .569 .298 .466 r
F P
0 g
s
.64545 .38378 m .67678 .37717 L .67634 .38459 L p .569 .298 .466 r
F P
0 g
s
.50364 .37069 m .47947 .36672 L .47968 .3578 L p .759 .517 .567 r
F P
0 g
s
.45699 .3539 m .47968 .3578 L .47947 .36672 L p .762 .519 .567 r
F P
0 g
s
.47968 .3578 m .45699 .3539 L .4576 .3444 L p .762 .547 .606 r
F P
0 g
s
.52929 .38255 m .50384 .37889 L .50364 .37069 L p .749 .477 .521 r
F P
0 g
s
.47947 .36672 m .50364 .37069 L .50384 .37889 L p .756 .484 .52 r
F P
0 g
s
.4421 .30006 m .42254 .29715 L .42421 .28695 L p .739 .64 .749 r
F P
0 g
s
.42421 .28695 m .4441 .28992 L .4421 .30006 L p .739 .64 .749 r
F P
0 g
s
.46799 .28383 m .44631 .28013 L .4487 .27082 L p .728 .678 .802 r
F P
0 g
s
.4487 .27082 m .47059 .27458 L .46799 .28383 L p .728 .678 .802 r
F P
0 g
s
.41979 .31793 m .43881 .32074 L .43758 .33097 L p .751 .584 .67 r
F P
0 g
s
.43881 .32074 m .41979 .31793 L .42106 .30753 L p .748 .604 .697 r
F P
0 g
s
.68066 .28359 m .69987 .27327 L .70625 .28155 L p .602 .571 .792 r
F P
0 g
s
.69987 .27327 m .68066 .28359 L .67514 .27528 L p .615 .604 .817 r
F P
0 g
s
.25531 .4574 m .24988 .46986 L .26007 .47186 L p .643 .746 .924 r
F P
0 g
s
.26007 .47186 m .26558 .45935 L .25531 .4574 L p .643 .746 .924 r
F P
0 g
s
.37138 .31717 m .36843 .31889 L .36425 .30954 L p .545 .461 .711 r
F P
0 g
s
.36425 .30954 m .36794 .30739 L .37138 .31717 L p .545 .461 .711 r
F P
0 g
s
.34696 .28343 m .35364 .27952 L .359 .28842 L p .595 .57 .795 r
F P
0 g
s
.35364 .27952 m .34696 .28343 L .33992 .27583 L p .61 .604 .821 r
F P
0 g
s
.43666 .34092 m .4576 .3444 L .45699 .3539 L p .76 .545 .606 r
F P
0 g
s
.4576 .3444 m .43666 .34092 L .43758 .33097 L p .759 .569 .64 r
F P
0 g
s
.54424 .26956 m .52173 .26615 L .52455 .25923 L p .68 .731 .889 r
F P
0 g
s
.52455 .25923 m .54666 .26259 L .54424 .26956 L p .68 .731 .889 r
F P
0 g
s
.37403 .3377 m .37034 .34071 L .36774 .33157 L p .428 .328 .64 r
F P
0 g
s
.36774 .33157 m .37171 .32832 L .37403 .3377 L p .428 .328 .64 r
F P
0 g
s
.5565 .39279 m .52983 .38988 L .52929 .38255 L p .726 .423 .466 r
F P
0 g
s
.50384 .37889 m .52929 .38255 L .52983 .38988 L p .741 .435 .463 r
F P
0 g
s
.20488 .44465 m .20991 .43238 L .20313 .42493 L p .385 .447 .802 r
F P
0 g
s
.20991 .43238 m .20488 .44465 L .21255 .45146 L p .439 .509 .834 r
F P
0 g
s
.4441 .28992 m .42421 .28695 L .42603 .27708 L p .733 .657 .775 r
F P
0 g
s
.42603 .27708 m .44631 .28013 L .4441 .28992 L p .733 .657 .775 r
F P
0 g
s
.41874 .3282 m .43758 .33097 L .43666 .34092 L p .753 .563 .639 r
F P
0 g
s
.43758 .33097 m .41874 .3282 L .41979 .31793 L p .751 .584 .67 r
F P
0 g
s
.72812 .32774 m .70352 .34055 L .70124 .33093 L p .524 .395 .647 r
F P
0 g
s
.70124 .33093 m .72533 .31834 L .72812 .32774 L p .524 .395 .647 r
F P
0 g
s
.70593 .367 m .67678 .37717 L .67669 .36895 L p .523 .299 .516 r
F P
0 g
s
.67669 .36895 m .70589 .35872 L .70593 .367 L p .523 .299 .516 r
F P
0 g
s
.30133 .44588 m .29571 .45837 L .30494 .4558 L p .781 .911 .929 r
F P
0 g
s
.30494 .4558 m .31059 .44335 L .30133 .44588 L p .781 .911 .929 r
F P
0 g
s
.33267 .42366 m .32696 .43517 L .3338 .42967 L p .84 .999 .803 r
F P
0 g
s
.3338 .42967 m .33948 .41825 L .33267 .42366 L p .84 .999 .803 r
F P
0 g
s
.37407 .32695 m .37171 .32832 L .36843 .31889 L p .524 .42 .678 r
F P
0 g
s
.36843 .31889 m .37138 .31717 L .37407 .32695 L p .524 .42 .678 r
F P
0 g
s
.2452 .45434 m .23986 .46675 L .24988 .46986 L p .607 .704 .913 r
F P
0 g
s
.24988 .46986 m .25531 .4574 L .2452 .45434 L p .607 .704 .913 r
F P
0 g
s
.33992 .27583 m .3478 .27119 L .35364 .27952 L p .61 .604 .821 r
F P
0 g
s
.3478 .27119 m .33992 .27583 L .33241 .26897 L p .624 .639 .846 r
F P
0 g
s
.61434 .40048 m .58501 .40076 L .5846 .39445 L p .653 .322 .4 r
F P
0 g
s
.5846 .39445 m .6143 .39416 L .61434 .40048 L p .653 .322 .4 r
F P
0 g
s
.5565 .39279 m .5846 .39445 L .58501 .40076 L p .688 .349 .397 r
F P
0 g
s
.37086 .30628 m .36794 .30739 L .36379 .29776 L p .608 .522 .732 r
F P
0 g
s
.36379 .29776 m .36785 .29621 L .37086 .30628 L p .608 .522 .732 r
F P
0 g
s
.36785 .29621 m .36379 .29776 L .359 .28842 L p .618 .553 .759 r
F P
0 g
s
.64488 .39749 m .61434 .40048 L .6143 .39416 L p .605 .284 .399 r
F P
0 g
s
.6143 .39416 m .64531 .39111 L .64488 .39749 L p .605 .284 .399 r
F P
0 g
s
.40432 .30563 m .42106 .30753 L .41979 .31793 L p .739 .595 .697 r
F P
0 g
s
.42106 .30753 m .40432 .30563 L .40532 .29519 L p .736 .614 .723 r
F P
0 g
s
.40532 .29519 m .42254 .29715 L .42106 .30753 L p .736 .614 .723 r
F P
0 g
s
.67514 .27528 m .69304 .26562 L .69987 .27327 L p .615 .604 .817 r
F P
0 g
s
.69304 .26562 m .67514 .27528 L .66935 .26768 L p .627 .638 .842 r
F P
0 g
s
.30623 .26662 m .31645 .25794 L .32455 .26298 L p .645 .715 .899 r
F P
0 g
s
.31645 .25794 m .30623 .26662 L .29714 .26341 L p .665 .757 .919 r
F P
0 g
s
.37334 .31642 m .37138 .31717 L .36794 .30739 L p .597 .49 .704 r
F P
0 g
s
.36794 .30739 m .37086 .30628 L .37334 .31642 L p .597 .49 .704 r
F P
0 g
s
.21255 .45146 m .21765 .43915 L .20991 .43238 L p .439 .509 .834 r
F P
0 g
s
.21765 .43915 m .21255 .45146 L .22104 .45747 L p .487 .564 .86 r
F P
0 g
s
.37217 .3585 m .36737 .36372 L .367 .355 L p .222 .098 .492 r
F P
0 g
s
.367 .355 m .37182 .34973 L .37217 .3585 L p .222 .098 .492 r
F P
0 g
s
.60764 .26616 m .5884 .26634 L .58919 .26025 L p .654 .754 .923 r
F P
0 g
s
.5884 .26634 m .56802 .26506 L .56981 .25903 L p .653 .753 .923 r
F P
0 g
s
.56981 .25903 m .58919 .26025 L .5884 .26634 L p .653 .753 .923 r
F P
0 g
s
.359 .28842 m .36436 .28637 L .36785 .29621 L p .618 .553 .759 r
F P
0 g
s
.36436 .28637 m .359 .28842 L .35364 .27952 L p .627 .583 .785 r
F P
0 g
s
.42254 .29715 m .40532 .29519 L .40644 .28492 L p .732 .633 .749 r
F P
0 g
s
.40644 .28492 m .42421 .28695 L .42254 .29715 L p .732 .633 .749 r
F P
0 g
s
.18954 .39988 m .19474 .38656 L .19269 .37775 L p .029 .041 .535 r
F P
0 g
s
.19474 .38656 m .18954 .39988 L .19286 .40854 L p .148 .177 .635 r
F P
0 g
s
.26892 .27244 m .2792 .26035 L .28808 .26131 L p .716 .846 .944 r
F P
0 g
s
.2792 .26035 m .26892 .27244 L .25989 .27325 L p .74 .893 .948 r
F P
0 g
s
.40344 .31609 m .41979 .31793 L .41874 .3282 L p .741 .575 .669 r
F P
0 g
s
.41979 .31793 m .40344 .31609 L .40432 .30563 L p .739 .595 .697 r
F P
0 g
s
.6256 .26431 m .60764 .26616 L .60704 .26009 L p .656 .755 .923 r
F P
0 g
s
.58919 .26025 m .60704 .26009 L .60764 .26616 L p .654 .754 .923 r
F P
0 g
s
.23545 .45023 m .23019 .4626 L .23986 .46675 L p .569 .66 .899 r
F P
0 g
s
.23986 .46675 m .2452 .45434 L .23545 .45023 L p .569 .66 .899 r
F P
0 g
s
.23447 .29229 m .24342 .27822 L .25134 .27518 L p .804 .969 .908 r
F P
0 g
s
.24342 .27822 m .23447 .29229 L .22713 .29673 L p .813 .996 .856 r
F P
0 g
s
.47059 .27458 m .4487 .27082 L .45121 .26216 L p .717 .696 .829 r
F P
0 g
s
.45121 .26216 m .47335 .26597 L .47059 .27458 L p .717 .696 .829 r
F P
0 g
s
.49605 .27003 m .47335 .26597 L .47621 .25814 L p .702 .714 .858 r
F P
0 g
s
.47621 .25814 m .49896 .26222 L .49605 .27003 L p .702 .714 .858 r
F P
0 g
s
.64645 .26712 m .66336 .2609 L .66935 .26768 L p .652 .678 .862 r
F P
0 g
s
.66336 .2609 m .64645 .26712 L .64217 .26063 L p .657 .716 .891 r
F P
0 g
s
.6256 .26431 m .64217 .26063 L .64645 .26712 L p .664 .718 .889 r
F P
0 g
s
.22104 .45747 m .22621 .44514 L .21765 .43915 L p .487 .564 .86 r
F P
0 g
s
.22621 .44514 m .22104 .45747 L .23019 .4626 L p .53 .614 .881 r
F P
0 g
s
.23019 .4626 m .23545 .45023 L .22621 .44514 L p .53 .614 .881 r
F P
0 g
s
.20794 .32302 m .21527 .30837 L .22069 .30211 L p .806 .964 .647 r
F P
0 g
s
.21527 .30837 m .20794 .32302 L .20359 .33016 L p .71 .861 .445 r
F P
0 g
s
.37599 .31585 m .37334 .31642 L .37086 .30628 L p .642 .52 .699 r
F P
0 g
s
.37086 .30628 m .37455 .30547 L .37599 .31585 L p .642 .52 .699 r
F P
0 g
s
.37455 .30547 m .37086 .30628 L .36785 .29621 L p .648 .546 .726 r
F P
0 g
s
.44631 .28013 m .42603 .27708 L .42798 .2677 L p .725 .675 .801 r
F P
0 g
s
.42798 .2677 m .4487 .27082 L .44631 .28013 L p .725 .675 .801 r
F P
0 g
s
.37527 .32649 m .37407 .32695 L .37138 .31717 L p .583 .457 .673 r
F P
0 g
s
.37138 .31717 m .37334 .31642 L .37527 .32649 L p .583 .457 .673 r
F P
0 g
s
.58501 .40076 m .55717 .39912 L .5565 .39279 L p .688 .349 .397 r
F P
0 g
s
.52983 .38988 m .5565 .39279 L .55717 .39912 L p .712 .367 .392 r
F P
0 g
s
.36785 .29621 m .37278 .29512 L .37455 .30547 L p .648 .546 .726 r
F P
0 g
s
.37278 .29512 m .36785 .29621 L .36436 .28637 L p .653 .573 .752 r
F P
0 g
s
.19255 .3604 m .19855 .34615 L .20044 .33791 L p 0 0 .003 r
F P
0 g
s
.19855 .34615 m .19255 .3604 L .19196 .36898 L p 0 0 .233 r
F P
0 g
s
.47947 .36672 m .45673 .36282 L .45699 .3539 L p .762 .519 .567 r
F P
0 g
s
.43605 .35043 m .45699 .3539 L .45673 .36282 L p .759 .517 .567 r
F P
0 g
s
.45699 .3539 m .43605 .35043 L .43666 .34092 L p .76 .545 .606 r
F P
0 g
s
.35098 .40212 m .34524 .41201 L .34988 .40504 L p .667 .851 .447 r
F P
0 g
s
.34988 .40504 m .35555 .39527 L .35098 .40212 L p .667 .851 .447 r
F P
0 g
s
.36443 .38008 m .35893 .38777 L .36107 .37974 L p 0 0 .14 r
F P
0 g
s
.36107 .37974 m .36651 .37213 L .36443 .38008 L p 0 0 .14 r
F P
0 g
s
.50384 .37889 m .47964 .37492 L .47947 .36672 L p .756 .484 .52 r
F P
0 g
s
.45673 .36282 m .47947 .36672 L .47964 .37492 L p .759 .486 .52 r
F P
0 g
s
.41794 .33818 m .43666 .34092 L .43605 .35043 L p .753 .539 .606 r
F P
0 g
s
.43666 .34092 m .41794 .33818 L .41874 .3282 L p .753 .563 .639 r
F P
0 g
s
.56802 .26506 m .54666 .26259 L .54912 .25663 L p .652 .752 .923 r
F P
0 g
s
.54912 .25663 m .56981 .25903 L .56802 .26506 L p .652 .752 .923 r
F P
0 g
s
.52173 .26615 m .49896 .26222 L .50194 .25531 L p .681 .732 .889 r
F P
0 g
s
.50194 .25531 m .52455 .25923 L .52173 .26615 L p .681 .732 .889 r
F P
0 g
s
.37534 .34687 m .37182 .34973 L .37034 .34071 L p .386 .262 .586 r
F P
0 g
s
.37034 .34071 m .37403 .3377 L .37534 .34687 L p .386 .262 .586 r
F P
0 g
s
.37596 .33657 m .37403 .3377 L .37171 .32832 L p .5 .374 .64 r
F P
0 g
s
.37171 .32832 m .37407 .32695 L .37596 .33657 L p .5 .374 .64 r
F P
0 g
s
.35364 .27952 m .36045 .2769 L .36436 .28637 L p .627 .583 .785 r
F P
0 g
s
.36045 .2769 m .35364 .27952 L .3478 .27119 L p .636 .614 .811 r
F P
0 g
s
.33241 .26897 m .34156 .26357 L .3478 .27119 L p .624 .639 .846 r
F P
0 g
s
.34156 .26357 m .33241 .26897 L .32455 .26298 L p .637 .676 .87 r
F P
0 g
s
.39074 .30478 m .40432 .30563 L .40344 .31609 L p .725 .583 .696 r
F P
0 g
s
.40432 .30563 m .39074 .30478 L .39105 .29429 L p .723 .603 .722 r
F P
0 g
s
.39105 .29429 m .40532 .29519 L .40432 .30563 L p .723 .603 .722 r
F P
0 g
s
.42421 .28695 m .40644 .28492 L .40764 .27497 L p .726 .651 .774 r
F P
0 g
s
.40764 .27497 m .42603 .27708 L .42421 .28695 L p .726 .651 .774 r
F P
0 g
s
.4027 .3264 m .41874 .3282 L .41794 .33818 L p .742 .553 .639 r
F P
0 g
s
.41874 .3282 m .4027 .3264 L .40344 .31609 L p .741 .575 .669 r
F P
0 g
s
.73001 .33694 m .70508 .34986 L .70352 .34055 L p .502 .351 .608 r
F P
0 g
s
.70352 .34055 m .72812 .32774 L .73001 .33694 L p .502 .351 .608 r
F P
0 g
s
.37708 .32611 m .37527 .32649 L .37334 .31642 L p .636 .492 .67 r
F P
0 g
s
.37334 .31642 m .37599 .31585 L .37708 .32611 L p .636 .492 .67 r
F P
0 g
s
.38131 .31534 m .37599 .31585 L .37455 .30547 L p .678 .545 .696 r
F P
0 g
s
.37455 .30547 m .38083 .30485 L .38131 .31534 L p .678 .545 .696 r
F P
0 g
s
.38083 .30485 m .37455 .30547 L .37278 .29512 L p .68 .569 .723 r
F P
0 g
s
.39044 .31528 m .40344 .31609 L .4027 .3264 L p .726 .562 .668 r
F P
0 g
s
.40344 .31609 m .39044 .31528 L .39074 .30478 L p .725 .583 .696 r
F P
0 g
s
.64217 .26063 m .6256 .26431 L .62326 .25842 L p .658 .756 .923 r
F P
0 g
s
.60704 .26009 m .62326 .25842 L .6256 .26431 L p .656 .755 .923 r
F P
0 g
s
.40532 .29519 m .39105 .29429 L .39137 .28397 L p .72 .622 .748 r
F P
0 g
s
.39137 .28397 m .40644 .28492 L .40532 .29519 L p .72 .622 .748 r
F P
0 g
s
.36436 .28637 m .37071 .28495 L .37278 .29512 L p .653 .573 .752 r
F P
0 g
s
.37071 .28495 m .36436 .28637 L .36045 .2769 L p .657 .599 .778 r
F P
0 g
s
.37278 .29512 m .38021 .29437 L .38083 .30485 L p .68 .569 .723 r
F P
0 g
s
.38021 .29437 m .37278 .29512 L .37071 .28495 L p .682 .592 .748 r
F P
0 g
s
.52983 .38988 m .5044 .38623 L .50384 .37889 L p .741 .435 .463 r
F P
0 g
s
.47964 .37492 m .50384 .37889 L .5044 .38623 L p .75 .441 .462 r
F P
0 g
s
.38164 .32567 m .37708 .32611 L .37599 .31585 L p .675 .521 .668 r
F P
0 g
s
.37599 .31585 m .38131 .31534 L .38164 .32567 L p .675 .521 .668 r
F P
0 g
s
.39044 .31528 m .38131 .31534 L .38083 .30485 L p .705 .566 .695 r
F P
0 g
s
.38083 .30485 m .39074 .30478 L .39044 .31528 L p .705 .566 .695 r
F P
0 g
s
.39074 .30478 m .38083 .30485 L .38021 .29437 L p .705 .588 .722 r
F P
0 g
s
.38021 .29437 m .39105 .29429 L .39074 .30478 L p .705 .588 .722 r
F P
0 g
s
.29155 .44729 m .28596 .45984 L .29571 .45837 L p .747 .87 .936 r
F P
0 g
s
.29571 .45837 m .30133 .44588 L .29155 .44729 L p .747 .87 .936 r
F P
0 g
s
.67537 .39109 m .64488 .39749 L .64531 .39111 L p .539 .229 .391 r
F P
0 g
s
.64531 .39111 m .67634 .38459 L .67537 .39109 L p .539 .229 .391 r
F P
0 g
s
.39015 .32562 m .38164 .32567 L .38131 .31534 L p .704 .544 .668 r
F P
0 g
s
.38131 .31534 m .39044 .31528 L .39015 .32562 L p .704 .544 .668 r
F P
0 g
s
.66935 .26768 m .68586 .25873 L .69304 .26562 L p .627 .638 .842 r
F P
0 g
s
.68586 .25873 m .66935 .26768 L .66336 .2609 L p .639 .675 .868 r
F P
0 g
s
.4027 .3264 m .39015 .32562 L .39044 .31528 L p .726 .562 .668 r
F P
0 g
s
.39105 .29429 m .38021 .29437 L .37946 .28406 L p .704 .609 .747 r
F P
0 g
s
.37071 .28495 m .37946 .28406 L .38021 .29437 L p .682 .592 .748 r
F P
0 g
s
.3766 .33632 m .37596 .33657 L .37407 .32695 L p .568 .419 .639 r
F P
0 g
s
.37407 .32695 m .37527 .32649 L .3766 .33632 L p .568 .419 .639 r
F P
0 g
s
.37946 .28406 m .39137 .28397 L .39105 .29429 L p .704 .609 .747 r
F P
0 g
s
.29714 .26341 m .30825 .25394 L .31645 .25794 L p .665 .757 .919 r
F P
0 g
s
.30825 .25394 m .29714 .26341 L .28808 .26131 L p .684 .803 .938 r
F P
0 g
s
.37781 .33607 m .3766 .33632 L .37527 .32649 L p .629 .462 .638 r
F P
0 g
s
.37527 .32649 m .37708 .32611 L .37781 .33607 L p .629 .462 .638 r
F P
0 g
s
.41794 .33818 m .40211 .33641 L .4027 .3264 L p .742 .553 .639 r
F P
0 g
s
.39015 .32562 m .4027 .3264 L .40211 .33641 L p .725 .539 .639 r
F P
0 g
s
.37946 .28406 m .37071 .28495 L .36837 .27512 L p .683 .615 .774 r
F P
0 g
s
.36045 .2769 m .36837 .27512 L .37071 .28495 L p .657 .599 .778 r
F P
0 g
s
.40644 .28492 m .39137 .28397 L .39169 .27397 L p .716 .642 .773 r
F P
0 g
s
.39169 .27397 m .40764 .27497 L .40644 .28492 L p .716 .642 .773 r
F P
0 g
s
.19286 .40854 m .19808 .39527 L .19474 .38656 L p .148 .177 .635 r
F P
0 g
s
.19808 .39527 m .19286 .40854 L .19741 .41693 L p .243 .285 .707 r
F P
0 g
s
.32492 .42812 m .31918 .43976 L .32696 .43517 L p .833 .985 .873 r
F P
0 g
s
.32696 .43517 m .33267 .42366 L .32492 .42812 L p .833 .985 .873 r
F P
0 g
s
.54666 .26259 m .52455 .25923 L .5274 .25332 L p .651 .752 .923 r
F P
0 g
s
.5274 .25332 m .54912 .25663 L .54666 .26259 L p .651 .752 .923 r
F P
0 g
s
.38182 .3357 m .37781 .33607 L .37708 .32611 L p .67 .494 .638 r
F P
0 g
s
.37708 .32611 m .38164 .32567 L .38182 .3357 L p .67 .494 .638 r
F P
0 g
s
.3478 .27119 m .35617 .26796 L .36045 .2769 L p .636 .614 .811 r
F P
0 g
s
.35617 .26796 m .3478 .27119 L .34156 .26357 L p .644 .646 .837 r
F P
0 g
s
.7052 .37456 m .67634 .38459 L .67678 .37717 L p .493 .236 .453 r
F P
0 g
s
.67678 .37717 m .70593 .367 L .7052 .37456 L p .493 .236 .453 r
F P
0 g
s
.42603 .27708 m .40764 .27497 L .40892 .26551 L p .719 .669 .8 r
F P
0 g
s
.40892 .26551 m .42798 .2677 L .42603 .27708 L p .719 .669 .8 r
F P
0 g
s
.55717 .39912 m .53066 .39624 L .52983 .38988 L p .712 .367 .392 r
F P
0 g
s
.5044 .38623 m .52983 .38988 L .53066 .39624 L p .728 .379 .388 r
F P
0 g
s
.43605 .35043 m .41739 .34772 L .41794 .33818 L p .753 .539 .606 r
F P
0 g
s
.40211 .33641 m .41794 .33818 L .41739 .34772 L p .741 .529 .606 r
F P
0 g
s
.36837 .27512 m .36045 .2769 L .35617 .26796 L p .661 .626 .804 r
F P
0 g
s
.4487 .27082 m .42798 .2677 L .43004 .25896 L p .714 .693 .828 r
F P
0 g
s
.43004 .25896 m .45121 .26216 L .4487 .27082 L p .714 .693 .828 r
F P
0 g
s
.38989 .33565 m .38182 .3357 L .38164 .32567 L p .702 .519 .638 r
F P
0 g
s
.38164 .32567 m .39015 .32562 L .38989 .33565 L p .702 .519 .638 r
F P
0 g
s
.40211 .33641 m .38989 .33565 L .39015 .32562 L p .725 .539 .639 r
F P
0 g
s
.37135 .36688 m .36651 .37213 L .36737 .36372 L p .128 0 .381 r
F P
0 g
s
.36737 .36372 m .37217 .3585 L .37135 .36688 L p .128 0 .381 r
F P
0 g
s
.39137 .28397 m .37946 .28406 L .37858 .27408 L p .702 .63 .773 r
F P
0 g
s
.36837 .27512 m .37858 .27408 L .37946 .28406 L p .683 .615 .774 r
F P
0 g
s
.47335 .26597 m .45121 .26216 L .45383 .25427 L p .702 .714 .858 r
F P
0 g
s
.45383 .25427 m .47621 .25814 L .47335 .26597 L p .702 .714 .858 r
F P
0 g
s
.37858 .27408 m .39169 .27397 L .39137 .28397 L p .702 .63 .773 r
F P
0 g
s
.25989 .27325 m .27064 .26055 L .2792 .26035 L p .74 .893 .948 r
F P
0 g
s
.27064 .26055 m .25989 .27325 L .25134 .27518 L p .76 .94 .942 r
F P
0 g
s
.37701 .34589 m .37534 .34687 L .37403 .3377 L p .471 .32 .595 r
F P
0 g
s
.37403 .3377 m .37596 .33657 L .37701 .34589 L p .471 .32 .595 r
F P
0 g
s
.32455 .26298 m .33502 .25678 L .34156 .26357 L p .637 .676 .87 r
F P
0 g
s
.33502 .25678 m .32455 .26298 L .31645 .25794 L p .65 .715 .895 r
F P
0 g
s
.45673 .36282 m .43577 .35936 L .43605 .35043 L p .759 .517 .567 r
F P
0 g
s
.41739 .34772 m .43605 .35043 L .43577 .35936 L p .752 .511 .567 r
F P
0 g
s
.73097 .34578 m .70589 .35872 L .70508 .34986 L p .475 .299 .562 r
F P
0 g
s
.70508 .34986 m .73001 .33694 L .73097 .34578 L p .475 .299 .562 r
F P
0 g
s
.47964 .37492 m .45685 .37103 L .45673 .36282 L p .759 .486 .52 r
F P
0 g
s
.43577 .35936 m .45673 .36282 L .45685 .37103 L p .757 .484 .52 r
F P
0 g
s
.49896 .26222 m .47621 .25814 L .47915 .25121 L p .681 .733 .889 r
F P
0 g
s
.47915 .25121 m .50194 .25531 L .49896 .26222 L p .681 .733 .889 r
F P
0 g
s
.22713 .29673 m .23627 .28232 L .24342 .27822 L p .813 .996 .856 r
F P
0 g
s
.23627 .28232 m .22713 .29673 L .22069 .30211 L p .793 .992 .758 r
F P
0 g
s
.37563 .35569 m .37217 .3585 L .37182 .34973 L p .335 .182 .52 r
F P
0 g
s
.37182 .34973 m .37534 .34687 L .37563 .35569 L p .335 .182 .52 r
F P
0 g
s
.61431 .4057 m .58552 .40597 L .58501 .40076 L p .623 .243 .304 r
F P
0 g
s
.58501 .40076 m .61434 .40048 L .61431 .4057 L p .623 .243 .304 r
F P
0 g
s
.55717 .39912 m .58501 .40076 L .58552 .40597 L p .66 .272 .298 r
F P
0 g
s
.64217 .26063 m .65727 .25506 L .66336 .2609 L p .657 .716 .891 r
F P
0 g
s
.65727 .25506 m .64217 .26063 L .6379 .25516 L p .66 .757 .922 r
F P
0 g
s
.62326 .25842 m .6379 .25516 L .64217 .26063 L p .658 .756 .923 r
F P
0 g
s
.19196 .36898 m .19797 .35476 L .19855 .34615 L p 0 0 .233 r
F P
0 g
s
.19797 .35476 m .19196 .36898 L .19269 .37775 L p 0 0 .412 r
F P
0 g
s
.37732 .34577 m .37701 .34589 L .37596 .33657 L p .547 .375 .6 r
F P
0 g
s
.37596 .33657 m .3766 .33632 L .37732 .34577 L p .547 .375 .6 r
F P
0 g
s
.20359 .33016 m .21096 .3154 L .21527 .30837 L p .71 .861 .445 r
F P
0 g
s
.21096 .3154 m .20359 .33016 L .20044 .33791 L p 0 0 0 r
F P
0 g
s
.41739 .34772 m .40168 .34596 L .40211 .33641 L p .741 .529 .606 r
F P
0 g
s
.38989 .33565 m .40211 .33641 L .40168 .34596 L p .724 .513 .606 r
F P
0 g
s
.37858 .27408 m .36837 .27512 L .36581 .26578 L p .682 .639 .8 r
F P
0 g
s
.35617 .26796 m .36581 .26578 L .36837 .27512 L p .661 .626 .804 r
F P
0 g
s
.64415 .40278 m .61431 .4057 L .61434 .40048 L p .569 .2 .302 r
F P
0 g
s
.61434 .40048 m .64488 .39749 L .64415 .40278 L p .569 .2 .302 r
F P
0 g
s
.37816 .3456 m .37732 .34577 L .3766 .33632 L p .62 .43 .603 r
F P
0 g
s
.3766 .33632 m .37781 .33607 L .37816 .3456 L p .62 .43 .603 r
F P
0 g
s
.28142 .44756 m .27586 .46017 L .28596 .45984 L p .713 .829 .937 r
F P
0 g
s
.28596 .45984 m .29155 .44729 L .28142 .44756 L p .713 .829 .937 r
F P
0 g
s
.40764 .27497 m .39169 .27397 L .392 .26444 L p .711 .662 .8 r
F P
0 g
s
.392 .26444 m .40892 .26551 L .40764 .27497 L p .711 .662 .8 r
F P
0 g
s
.3453 .40821 m .33948 .41825 L .34524 .41201 L p .771 .961 .654 r
F P
0 g
s
.34524 .41201 m .35098 .40212 L .3453 .40821 L p .771 .961 .654 r
F P
0 g
s
.38184 .34526 m .37816 .3456 L .37781 .33607 L p .665 .465 .604 r
F P
0 g
s
.37781 .33607 m .38182 .3357 L .38184 .34526 L p .665 .465 .604 r
F P
0 g
s
.36115 .38745 m .35555 .39527 L .35893 .38777 L p 0 0 0 r
F P
0 g
s
.35893 .38777 m .36443 .38008 L .36115 .38745 L p 0 0 0 r
F P
0 g
s
.5044 .38623 m .48018 .38227 L .47964 .37492 L p .75 .441 .462 r
F P
0 g
s
.45685 .37103 m .47964 .37492 L .48018 .38227 L p .753 .444 .461 r
F P
0 g
s
.60704 .26009 m .58919 .26025 L .58999 .25528 L p .621 .785 .96 r
F P
0 g
s
.58919 .26025 m .56981 .25903 L .57161 .25412 L p .614 .778 .96 r
F P
0 g
s
.57161 .25412 m .58999 .25528 L .58919 .26025 L p .614 .778 .96 r
F P
0 g
s
.38964 .34522 m .38184 .34526 L .38182 .3357 L p .698 .492 .605 r
F P
0 g
s
.38182 .3357 m .38989 .33565 L .38964 .34522 L p .698 .492 .605 r
F P
0 g
s
.62326 .25842 m .60704 .26009 L .60648 .25514 L p .631 .792 .96 r
F P
0 g
s
.58999 .25528 m .60648 .25514 L .60704 .26009 L p .621 .785 .96 r
F P
0 g
s
.66336 .2609 m .67843 .25269 L .68586 .25873 L p .639 .675 .868 r
F P
0 g
s
.67843 .25269 m .66336 .2609 L .65727 .25506 L p .651 .714 .894 r
F P
0 g
s
.40168 .34596 m .38964 .34522 L .38989 .33565 L p .724 .513 .606 r
F P
0 g
s
.19741 .41693 m .20266 .40372 L .19808 .39527 L p .243 .285 .707 r
F P
0 g
s
.20266 .40372 m .19741 .41693 L .20313 .42493 L p .319 .373 .761 r
F P
0 g
s
.34156 .26357 m .35159 .25969 L .35617 .26796 L p .644 .646 .837 r
F P
0 g
s
.35159 .25969 m .34156 .26357 L .33502 .25678 L p .651 .68 .864 r
F P
0 g
s
.73584 .28597 m .71723 .29949 L .71206 .29033 L p .537 .489 .75 r
F P
0 g
s
.71206 .29033 m .72995 .27726 L .73584 .28597 L p .537 .489 .75 r
F P
0 g
s
.72995 .27726 m .71206 .29033 L .70625 .28155 L p .556 .526 .777 r
F P
0 g
s
.70625 .28155 m .72333 .26899 L .72995 .27726 L p .556 .526 .777 r
F P
0 g
s
.72333 .26899 m .70625 .28155 L .69987 .27327 L p .575 .562 .802 r
F P
0 g
s
.39169 .27397 m .37858 .27408 L .3776 .26457 L p .699 .651 .799 r
F P
0 g
s
.36581 .26578 m .3776 .26457 L .37858 .27408 L p .682 .639 .8 r
F P
0 g
s
.36581 .26578 m .35617 .26796 L .35159 .25969 L p .663 .654 .831 r
F P
0 g
s
.3776 .26457 m .392 .26444 L .39169 .27397 L p .699 .651 .799 r
F P
0 g
s
.52455 .25923 m .50194 .25531 L .50496 .24942 L p .651 .751 .923 r
F P
0 g
s
.50496 .24942 m .5274 .25332 L .52455 .25923 L p .651 .751 .923 r
F P
0 g
s
.42798 .2677 m .40892 .26551 L .41026 .25667 L p .71 .689 .828 r
F P
0 g
s
.41026 .25667 m .43004 .25896 L .42798 .2677 L p .71 .689 .828 r
F P
0 g
s
.58552 .40597 m .55806 .40436 L .55717 .39912 L p .66 .272 .298 r
F P
0 g
s
.53066 .39624 m .55717 .39912 L .55806 .40436 L p .686 .29 .292 r
F P
0 g
s
.43577 .35936 m .41711 .35666 L .41739 .34772 L p .752 .511 .567 r
F P
0 g
s
.40168 .34596 m .41739 .34772 L .41711 .35666 L p .739 .5 .567 r
F P
0 g
s
.28808 .26131 m .30007 .25106 L .30825 .25394 L p .684 .803 .938 r
F P
0 g
s
.30007 .25106 m .28808 .26131 L .2792 .26035 L p .702 .851 .954 r
F P
0 g
s
.56981 .25903 m .54912 .25663 L .55158 .25179 L p .61 .774 .959 r
F P
0 g
s
.55158 .25179 m .57161 .25412 L .56981 .25903 L p .61 .774 .959 r
F P
0 g
s
.7409 .29498 m .72168 .30887 L .71723 .29949 L p .516 .45 .721 r
F P
0 g
s
.71723 .29949 m .73584 .28597 L .7409 .29498 L p .516 .45 .721 r
F P
0 g
s
.69987 .27327 m .71607 .26129 L .72333 .26899 L p .575 .562 .802 r
F P
0 g
s
.71607 .26129 m .69987 .27327 L .69304 .26562 L p .593 .598 .827 r
F P
0 g
s
.53066 .39624 m .50531 .39261 L .5044 .38623 L p .728 .379 .388 r
F P
0 g
s
.48018 .38227 m .5044 .38623 L .50531 .39261 L p .737 .386 .386 r
F P
0 g
s
.31637 .43157 m .31059 .44335 L .31918 .43976 L p .809 .952 .912 r
F P
0 g
s
.31918 .43976 m .32492 .42812 L .31637 .43157 L p .809 .952 .912 r
F P
0 g
s
.6379 .25516 m .62326 .25842 L .62097 .25364 L p .643 .799 .957 r
F P
0 g
s
.60648 .25514 m .62097 .25364 L .62326 .25842 L p .631 .792 .96 r
F P
0 g
s
.45121 .26216 m .43004 .25896 L .43217 .25098 L p .7 .712 .858 r
F P
0 g
s
.43217 .25098 m .45383 .25427 L .45121 .26216 L p .7 .712 .858 r
F P
0 g
s
.37722 .35477 m .37563 .35569 L .37534 .34687 L p .435 .257 .54 r
F P
0 g
s
.37534 .34687 m .37701 .34589 L .37722 .35477 L p .435 .257 .54 r
F P
0 g
s
.31645 .25794 m .32828 .25092 L .33502 .25678 L p .65 .715 .895 r
F P
0 g
s
.32828 .25092 m .31645 .25794 L .30825 .25394 L p .663 .757 .921 r
F P
0 g
s
.27111 .44668 m .26558 .45935 L .27586 .46017 L p .678 .787 .932 r
F P
0 g
s
.27586 .46017 m .28142 .44756 L .27111 .44668 L p .678 .787 .932 r
F P
0 g
s
.45685 .37103 m .43583 .36757 L .43577 .35936 L p .757 .484 .52 r
F P
0 g
s
.41711 .35666 m .43577 .35936 L .43583 .36757 L p .749 .477 .521 r
F P
0 g
s
.67387 .39657 m .64415 .40278 L .64488 .39749 L p .494 .136 .288 r
F P
0 g
s
.64488 .39749 m .67537 .39109 L .67387 .39657 L p .494 .136 .288 r
F P
0 g
s
.3776 .26457 m .36581 .26578 L .36304 .25708 L p .68 .665 .828 r
F P
0 g
s
.35159 .25969 m .36304 .25708 L .36581 .26578 L p .663 .654 .831 r
F P
0 g
s
.36939 .37472 m .36443 .38008 L .36651 .37213 L p .004 0 .231 r
F P
0 g
s
.36651 .37213 m .37135 .36688 L .36939 .37472 L p .004 0 .231 r
F P
0 g
s
.41711 .35666 m .40142 .35491 L .40168 .34596 L p .739 .5 .567 r
F P
0 g
s
.38964 .34522 m .40168 .34596 L .40142 .35491 L p .72 .484 .567 r
F P
0 g
s
.74504 .30417 m .72533 .31834 L .72168 .30887 L p .492 .407 .688 r
F P
0 g
s
.72168 .30887 m .7409 .29498 L .74504 .30417 L p .492 .407 .688 r
F P
0 g
s
.37741 .35469 m .37722 .35477 L .37701 .34589 L p .518 .32 .552 r
F P
0 g
s
.37701 .34589 m .37732 .34577 L .37741 .35469 L p .518 .32 .552 r
F P
0 g
s
.69304 .26562 m .70829 .25428 L .71607 .26129 L p .593 .598 .827 r
F P
0 g
s
.70829 .25428 m .69304 .26562 L .68586 .25873 L p .611 .635 .85 r
F P
0 g
s
.25134 .27518 m .26253 .26193 L .27064 .26055 L p .76 .94 .942 r
F P
0 g
s
.26253 .26193 m .25134 .27518 L .24342 .27822 L p .77 .979 .913 r
F P
0 g
s
.47621 .25814 m .45383 .25427 L .4565 .24728 L p .681 .732 .889 r
F P
0 g
s
.4565 .24728 m .47915 .25121 L .47621 .25814 L p .681 .732 .889 r
F P
0 g
s
.37813 .35455 m .37741 .35469 L .37732 .34577 L p .611 .394 .563 r
F P
0 g
s
.37732 .34577 m .37816 .3456 L .37813 .35455 L p .611 .394 .563 r
F P
0 g
s
.40892 .26551 m .392 .26444 L .3923 .25554 L p .703 .682 .827 r
F P
0 g
s
.3923 .25554 m .41026 .25667 L .40892 .26551 L p .703 .682 .827 r
F P
0 g
s
.20313 .42493 m .2084 .41178 L .20266 .40372 L p .319 .373 .761 r
F P
0 g
s
.2084 .41178 m .20313 .42493 L .20991 .43238 L p .383 .446 .802 r
F P
0 g
s
.73096 .35413 m .70593 .367 L .70589 .35872 L p .441 .236 .504 r
F P
0 g
s
.70589 .35872 m .73097 .34578 L .73096 .35413 L p .441 .236 .504 r
F P
0 g
s
.7037 .38127 m .67537 .39109 L .67634 .38459 L p .451 .154 .369 r
F P
0 g
s
.67634 .38459 m .7052 .37456 L .7037 .38127 L p .451 .154 .369 r
F P
0 g
s
.3817 .35422 m .37813 .35455 L .37816 .3456 L p .657 .431 .566 r
F P
0 g
s
.37816 .3456 m .38184 .34526 L .3817 .35422 L p .657 .431 .566 r
F P
0 g
s
.37488 .36403 m .37135 .36688 L .37217 .3585 L p .268 .081 .432 r
F P
0 g
s
.37217 .3585 m .37563 .35569 L .37488 .36403 L p .268 .081 .432 r
F P
0 g
s
.38943 .35418 m .3817 .35422 L .38184 .34526 L p .693 .461 .567 r
F P
0 g
s
.38184 .34526 m .38964 .34522 L .38943 .35418 L p .693 .461 .567 r
F P
0 g
s
.40142 .35491 m .38943 .35418 L .38964 .34522 L p .72 .484 .567 r
F P
0 g
s
.19269 .37775 m .1987 .36358 L .19797 .35476 L p 0 0 .412 r
F P
0 g
s
.1987 .36358 m .19269 .37775 L .19474 .38656 L p .057 .059 .543 r
F P
0 g
s
.54912 .25663 m .5274 .25332 L .53025 .24853 L p .607 .77 .958 r
F P
0 g
s
.53025 .24853 m .55158 .25179 L .54912 .25663 L p .607 .77 .958 r
F P
0 g
s
.48018 .38227 m .45734 .37838 L .45685 .37103 L p .753 .444 .461 r
F P
0 g
s
.43583 .36757 m .45685 .37103 L .45734 .37838 L p .75 .442 .462 r
F P
0 g
s
.55806 .40436 m .53178 .40151 L .53066 .39624 L p .686 .29 .292 r
F P
0 g
s
.50531 .39261 m .53066 .39624 L .53178 .40151 L p .702 .302 .285 r
F P
0 g
s
.392 .26444 m .3776 .26457 L .37652 .25568 L p .693 .674 .827 r
F P
0 g
s
.36304 .25708 m .37652 .25568 L .3776 .26457 L p .68 .665 .828 r
F P
0 g
s
.22069 .30211 m .22999 .28743 L .23627 .28232 L p .793 .992 .758 r
F P
0 g
s
.22999 .28743 m .22069 .30211 L .21527 .30837 L p .722 .928 .591 r
F P
0 g
s
.37652 .25568 m .3923 .25554 L .392 .26444 L p .693 .674 .827 r
F P
0 g
s
.33502 .25678 m .34678 .25221 L .35159 .25969 L p .651 .68 .864 r
F P
0 g
s
.34678 .25221 m .33502 .25678 L .32828 .25092 L p .657 .716 .892 r
F P
0 g
s
.36304 .25708 m .35159 .25969 L .34678 .25221 L p .664 .685 .86 r
F P
0 g
s
.20044 .33791 m .20784 .32309 L .21096 .3154 L p 0 0 0 r
F P
0 g
s
.20784 .32309 m .20044 .33791 L .19855 .34615 L p 0 0 .063 r
F P
0 g
s
.50194 .25531 m .47915 .25121 L .48211 .24529 L p .651 .751 .923 r
F P
0 g
s
.48211 .24529 m .50496 .24942 L .50194 .25531 L p .651 .751 .923 r
F P
0 g
s
.26079 .44467 m .25531 .4574 L .26558 .45935 L p .643 .746 .924 r
F P
0 g
s
.26558 .45935 m .27111 .44668 L .26079 .44467 L p .643 .746 .924 r
F P
0 g
s
.33859 .41341 m .33267 .42366 L .33948 .41825 L p .815 .999 .792 r
F P
0 g
s
.33948 .41825 m .3453 .40821 L .33859 .41341 L p .815 .999 .792 r
F P
0 g
s
.65727 .25506 m .67087 .24762 L .67843 .25269 L p .651 .714 .894 r
F P
0 g
s
.67087 .24762 m .65727 .25506 L .65117 .25025 L p .662 .758 .921 r
F P
0 g
s
.6379 .25516 m .65117 .25025 L .65727 .25506 L p .66 .757 .922 r
F P
0 g
s
.35673 .39411 m .35098 .40212 L .35555 .39527 L p 0 0 0 r
F P
0 g
s
.35555 .39527 m .36115 .38745 L .35673 .39411 L p 0 0 0 r
F P
0 g
s
.43004 .25896 m .41026 .25667 L .41163 .24861 L p .697 .709 .857 r
F P
0 g
s
.41163 .24861 m .43217 .25098 L .43004 .25896 L p .697 .709 .857 r
F P
0 g
s
.65117 .25025 m .6379 .25516 L .6337 .25081 L p .658 .804 .953 r
F P
0 g
s
.62097 .25364 m .6337 .25081 L .6379 .25516 L p .643 .799 .957 r
F P
0 g
s
.20991 .43238 m .21522 .41929 L .2084 .41178 L p .383 .446 .802 r
F P
0 g
s
.21522 .41929 m .20991 .43238 L .21765 .43915 L p .438 .509 .834 r
F P
0 g
s
.74821 .31337 m .72812 .32774 L .72533 .31834 L p .465 .36 .651 r
F P
0 g
s
.72533 .31834 m .74504 .30417 L .74821 .31337 L p .465 .36 .651 r
F P
0 g
s
.43583 .36757 m .4171 .36487 L .41711 .35666 L p .749 .477 .521 r
F P
0 g
s
.40142 .35491 m .41711 .35666 L .4171 .36487 L p .735 .466 .522 r
F P
0 g
s
.68586 .25873 m .70011 .24807 L .70829 .25428 L p .611 .635 .85 r
F P
0 g
s
.70011 .24807 m .68586 .25873 L .67843 .25269 L p .628 .673 .874 r
F P
0 g
s
.50531 .39261 m .48109 .38866 L .48018 .38227 L p .737 .386 .386 r
F P
0 g
s
.45734 .37838 m .48018 .38227 L .48109 .38866 L p .74 .388 .385 r
F P
0 g
s
.2792 .26035 m .29205 .24933 L .30007 .25106 L p .702 .851 .954 r
F P
0 g
s
.29205 .24933 m .2792 .26035 L .27064 .26055 L p .716 .901 .962 r
F P
0 g
s
.30714 .43394 m .30133 .44588 L .31059 .44335 L p .779 .913 .931 r
F P
0 g
s
.31059 .44335 m .31637 .43157 L .30714 .43394 L p .779 .913 .931 r
F P
0 g
s
.61419 .40974 m .5861 .41 L .58552 .40597 L p .57 .13 .165 r
F P
0 g
s
.58552 .40597 m .61431 .4057 L .61419 .40974 L p .57 .13 .165 r
F P
0 g
s
.55806 .40436 m .58552 .40597 L .5861 .41 L p .61 .16 .157 r
F P
0 g
s
.37656 .36305 m .37488 .36403 L .37563 .35569 L p .389 .179 .47 r
F P
0 g
s
.37563 .35569 m .37722 .35477 L .37656 .36305 L p .389 .179 .47 r
F P
0 g
s
.25065 .44154 m .2452 .45434 L .25531 .4574 L p .606 .704 .913 r
F P
0 g
s
.25531 .4574 m .26079 .44467 L .25065 .44154 L p .606 .704 .913 r
F P
0 g
s
.30825 .25394 m .32144 .24609 L .32828 .25092 L p .663 .757 .921 r
F P
0 g
s
.32144 .24609 m .30825 .25394 L .30007 .25106 L p .673 .803 .945 r
F P
0 g
s
.64314 .40691 m .61419 .40974 L .61431 .4057 L p .51 .081 .163 r
F P
0 g
s
.61431 .4057 m .64415 .40278 L .64314 .40691 L p .51 .081 .163 r
F P
0 g
s
.21765 .43915 m .22299 .42614 L .21522 .41929 L p .438 .509 .834 r
F P
0 g
s
.22299 .42614 m .21765 .43915 L .22621 .44514 L p .486 .564 .86 r
F P
0 g
s
.45383 .25427 m .43217 .25098 L .43434 .24391 L p .68 .731 .889 r
F P
0 g
s
.43434 .24391 m .4565 .24728 L .45383 .25427 L p .68 .731 .889 r
F P
0 g
s
.37652 .25568 m .36304 .25708 L .36013 .24915 L p .676 .692 .857 r
F P
0 g
s
.34678 .25221 m .36013 .24915 L .36304 .25708 L p .664 .685 .86 r
F P
0 g
s
.5274 .25332 m .50496 .24942 L .50796 .24465 L p .606 .768 .958 r
F P
0 g
s
.50796 .24465 m .53025 .24853 L .5274 .25332 L p .606 .768 .958 r
F P
0 g
s
.60648 .25514 m .58999 .25528 L .59081 .25152 L p .562 .811 .992 r
F P
0 g
s
.58999 .25528 m .57161 .25412 L .57339 .25041 L p .548 .798 .991 r
F P
0 g
s
.57339 .25041 m .59081 .25152 L .58999 .25528 L p .548 .798 .991 r
F P
0 g
s
.4171 .36487 m .40133 .36312 L .40142 .35491 L p .735 .466 .522 r
F P
0 g
s
.38943 .35418 m .40142 .35491 L .40133 .36312 L p .714 .449 .522 r
F P
0 g
s
.62097 .25364 m .60648 .25514 L .60595 .25139 L p .583 .827 .991 r
F P
0 g
s
.59081 .25152 m .60595 .25139 L .60648 .25514 L p .562 .811 .992 r
F P
0 g
s
.37687 .36293 m .37656 .36305 L .37722 .35477 L p .478 .252 .492 r
F P
0 g
s
.37722 .35477 m .37741 .35469 L .37687 .36293 L p .478 .252 .492 r
F P
0 g
s
.37771 .36276 m .37687 .36293 L .37741 .35469 L p .596 .35 .514 r
F P
0 g
s
.37741 .35469 m .37813 .35455 L .37771 .36276 L p .596 .35 .514 r
F P
0 g
s
.41026 .25667 m .3923 .25554 L .39259 .2474 L p .692 .704 .857 r
F P
0 g
s
.39259 .2474 m .41163 .24861 L .41026 .25667 L p .692 .704 .857 r
F P
0 g
s
.24086 .43736 m .23545 .45023 L .2452 .45434 L p .569 .66 .899 r
F P
0 g
s
.2452 .45434 m .25065 .44154 L .24086 .43736 L p .569 .66 .899 r
F P
0 g
s
.3814 .36242 m .37771 .36276 L .37813 .35455 L p .645 .391 .519 r
F P
0 g
s
.37813 .35455 m .3817 .35422 L .3814 .36242 L p .645 .391 .519 r
F P
0 g
s
.45734 .37838 m .43623 .37493 L .43583 .36757 L p .75 .442 .462 r
F P
0 g
s
.4171 .36487 m .43583 .36757 L .43623 .37493 L p .742 .435 .463 r
F P
0 g
s
.22621 .44514 m .23159 .4322 L .22299 .42614 L p .486 .564 .86 r
F P
0 g
s
.23159 .4322 m .22621 .44514 L .23545 .45023 L p .529 .614 .881 r
F P
0 g
s
.19474 .38656 m .20076 .37246 L .1987 .36358 L p .057 .059 .543 r
F P
0 g
s
.20076 .37246 m .19474 .38656 L .19808 .39527 L p .169 .189 .638 r
F P
0 g
s
.23545 .45023 m .24086 .43736 L .23159 .4322 L p .529 .614 .881 r
F P
0 g
s
.53178 .40151 m .50655 .39791 L .50531 .39261 L p .702 .302 .285 r
F P
0 g
s
.48109 .38866 m .50531 .39261 L .50655 .39791 L p .711 .308 .281 r
F P
0 g
s
.38924 .36238 m .3814 .36242 L .3817 .35422 L p .685 .424 .522 r
F P
0 g
s
.3817 .35422 m .38943 .35418 L .38924 .36238 L p .685 .424 .522 r
F P
0 g
s
.5861 .41 m .55913 .40842 L .55806 .40436 L p .61 .16 .157 r
F P
0 g
s
.53178 .40151 m .55806 .40436 L .55913 .40842 L p .636 .178 .147 r
F P
0 g
s
.40133 .36312 m .38924 .36238 L .38943 .35418 L p .714 .449 .522 r
F P
0 g
s
.36629 .3819 m .36115 .38745 L .36443 .38008 L p 0 0 .029 r
F P
0 g
s
.36443 .38008 m .36939 .37472 L .36629 .3819 L p 0 0 .029 r
F P
0 g
s
.24342 .27822 m .25502 .26445 L .26253 .26193 L p .77 .979 .913 r
F P
0 g
s
.25502 .26445 m .24342 .27822 L .23627 .28232 L p .754 .995 .842 r
F P
0 g
s
.73 .36185 m .7052 .37456 L .70593 .367 L p .397 .157 .429 r
F P
0 g
s
.70593 .367 m .73096 .35413 L .73 .36185 L p .397 .157 .429 r
F P
0 g
s
.57161 .25412 m .55158 .25179 L .554 .24815 L p .54 .788 .99 r
F P
0 g
s
.554 .24815 m .57339 .25041 L .57161 .25412 L p .54 .788 .99 r
F P
0 g
s
.3731 .37173 m .36939 .37472 L .37135 .36688 L p .18 0 .315 r
F P
0 g
s
.37135 .36688 m .37488 .36403 L .3731 .37173 L p .18 0 .315 r
F P
0 g
s
.3923 .25554 m .37652 .25568 L .37537 .24756 L p .686 .699 .856 r
F P
0 g
s
.36013 .24915 m .37537 .24756 L .37652 .25568 L p .676 .692 .857 r
F P
0 g
s
.75035 .32246 m .73001 .33694 L .72812 .32774 L p .434 .306 .607 r
F P
0 g
s
.72812 .32774 m .74821 .31337 L .75035 .32246 L p .434 .306 .607 r
F P
0 g
s
.67843 .25269 m .69165 .24275 L .70011 .24807 L p .628 .673 .874 r
F P
0 g
s
.69165 .24275 m .67843 .25269 L .67087 .24762 L p .646 .714 .897 r
F P
0 g
s
.37537 .24756 m .39259 .2474 L .3923 .25554 L p .686 .699 .856 r
F P
0 g
s
.47915 .25121 m .4565 .24728 L .45919 .24131 L p .651 .751 .923 r
F P
0 g
s
.45919 .24131 m .48211 .24529 L .47915 .25121 L p .651 .751 .923 r
F P
0 g
s
.6337 .25081 m .62097 .25364 L .61877 .25007 L p .612 .843 .987 r
F P
0 g
s
.60595 .25139 m .61877 .25007 L .62097 .25364 L p .583 .827 .991 r
F P
0 g
s
.36013 .24915 m .34678 .25221 L .34181 .24564 L p .663 .719 .89 r
F P
0 g
s
.32828 .25092 m .34181 .24564 L .34678 .25221 L p .657 .716 .892 r
F P
0 g
s
.34181 .24564 m .32828 .25092 L .32144 .24609 L p .66 .757 .922 r
F P
0 g
s
.21527 .30837 m .2247 .29346 L .22999 .28743 L p .722 .928 .591 r
F P
0 g
s
.2247 .29346 m .21527 .30837 L .21096 .3154 L p 0 0 0 r
F P
0 g
s
.19855 .34615 m .20598 .33131 L .20784 .32309 L p 0 0 .063 r
F P
0 g
s
.20598 .33131 m .19855 .34615 L .19797 .35476 L p 0 0 .277 r
F P
0 g
s
.70146 .38702 m .67387 .39657 L .67537 .39109 L p .389 .043 .253 r
F P
0 g
s
.67537 .39109 m .7037 .38127 L .70146 .38702 L p .389 .043 .253 r
F P
0 g
s
.67186 .40092 m .64314 .40691 L .64415 .40278 L p .421 .004 .14 r
F P
0 g
s
.64415 .40278 m .67387 .39657 L .67186 .40092 L p .421 .004 .14 r
F P
0 g
s
.33095 .41766 m .32492 .42812 L .33267 .42366 L p .818 .99 .873 r
F P
0 g
s
.33267 .42366 m .33859 .41341 L .33095 .41766 L p .818 .99 .873 r
F P
0 g
s
.48109 .38866 m .45819 .38477 L .45734 .37838 L p .74 .388 .385 r
F P
0 g
s
.43623 .37493 m .45734 .37838 L .45819 .38477 L p .737 .386 .386 r
F P
0 g
s
.29739 .43519 m .29155 .44729 L .30133 .44588 L p .745 .872 .938 r
F P
0 g
s
.30133 .44588 m .30714 .43394 L .29739 .43519 L p .745 .872 .938 r
F P
0 g
s
.65117 .25025 m .6633 .24358 L .67087 .24762 L p .662 .758 .921 r
F P
0 g
s
.6633 .24358 m .65117 .25025 L .64516 .24655 L p .671 .806 .948 r
F P
0 g
s
.6337 .25081 m .64516 .24655 L .65117 .25025 L p .658 .804 .953 r
F P
0 g
s
.43217 .25098 m .41163 .24861 L .41302 .24143 L p .679 .73 .889 r
F P
0 g
s
.41302 .24143 m .43434 .24391 L .43217 .25098 L p .679 .73 .889 r
F P
0 g
s
.35122 .39995 m .3453 .40821 L .35098 .40212 L p .683 .919 .597 r
F P
0 g
s
.35098 .40212 m .35673 .39411 L .35122 .39995 L p .683 .919 .597 r
F P
0 g
s
.43623 .37493 m .41736 .37221 L .4171 .36487 L p .742 .435 .463 r
F P
0 g
s
.40133 .36312 m .4171 .36487 L .41736 .37221 L p .727 .423 .465 r
F P
0 g
s
.55158 .25179 m .53025 .24853 L .53304 .24494 L p .535 .782 .989 r
F P
0 g
s
.53304 .24494 m .554 .24815 L .55158 .25179 L p .535 .782 .989 r
F P
0 g
s
.50496 .24942 m .48211 .24529 L .48505 .2405 L p .605 .768 .958 r
F P
0 g
s
.48505 .2405 m .50796 .24465 L .50496 .24942 L p .605 .768 .958 r
F P
0 g
s
.27064 .26055 m .2843 .2488 L .29205 .24933 L p .716 .901 .962 r
F P
0 g
s
.2843 .2488 m .27064 .26055 L .26253 .26193 L p .72 .948 .953 r
F P
0 g
s
.55913 .40842 m .53318 .40561 L .53178 .40151 L p .636 .178 .147 r
F P
0 g
s
.50655 .39791 m .53178 .40151 L .53318 .40561 L p .653 .188 .137 r
F P
0 g
s
.37505 .37061 m .3731 .37173 L .37488 .36403 L p .331 .083 .378 r
F P
0 g
s
.37488 .36403 m .37656 .36305 L .37505 .37061 L p .331 .083 .378 r
F P
0 g
s
.30007 .25106 m .31461 .24238 L .32144 .24609 L p .673 .803 .945 r
F P
0 g
s
.31461 .24238 m .30007 .25106 L .29205 .24933 L p .68 .853 .965 r
F P
0 g
s
.19808 .39527 m .2041 .38127 L .20076 .37246 L p .169 .189 .638 r
F P
0 g
s
.2041 .38127 m .19808 .39527 L .20266 .40372 L p .259 .293 .707 r
F P
0 g
s
.64516 .24655 m .6337 .25081 L .62963 .24765 L p .644 .854 .98 r
F P
0 g
s
.61877 .25007 m .62963 .24765 L .6337 .25081 L p .612 .843 .987 r
F P
0 g
s
.37537 .24756 m .36013 .24915 L .3571 .24213 L p .669 .722 .889 r
F P
0 g
s
.34181 .24564 m .3571 .24213 L .36013 .24915 L p .663 .719 .89 r
F P
0 g
s
.50655 .39791 m .48236 .39397 L .48109 .38866 L p .711 .308 .281 r
F P
0 g
s
.45819 .38477 m .48109 .38866 L .48236 .39397 L p .714 .31 .28 r
F P
0 g
s
.75142 .33128 m .73097 .34578 L .73001 .33694 L p .395 .242 .553 r
F P
0 g
s
.73001 .33694 m .75035 .32246 L .75142 .33128 L p .395 .242 .553 r
F P
0 g
s
.41736 .37221 m .40141 .37045 L .40133 .36312 L p .727 .423 .465 r
F P
0 g
s
.38924 .36238 m .40133 .36312 L .40141 .37045 L p .704 .405 .466 r
F P
0 g
s
.67087 .24762 m .68305 .23841 L .69165 .24275 L p .646 .714 .897 r
F P
0 g
s
.68305 .23841 m .67087 .24762 L .6633 .24358 L p .664 .758 .92 r
F P
0 g
s
.37569 .37037 m .37505 .37061 L .37656 .36305 L p .449 .185 .42 r
F P
0 g
s
.37656 .36305 m .37687 .36293 L .37569 .37037 L p .449 .185 .42 r
F P
0 g
s
.37691 .37012 m .37569 .37037 L .37687 .36293 L p .572 .291 .452 r
F P
0 g
s
.37687 .36293 m .37771 .36276 L .37691 .37012 L p .572 .291 .452 r
F P
0 g
s
.41163 .24861 m .39259 .2474 L .39286 .24016 L p .677 .728 .889 r
F P
0 g
s
.39286 .24016 m .41302 .24143 L .41163 .24861 L p .677 .728 .889 r
F P
0 g
s
.4565 .24728 m .43434 .24391 L .43652 .23785 L p .651 .752 .923 r
F P
0 g
s
.43652 .23785 m .45919 .24131 L .4565 .24728 L p .651 .752 .923 r
F P
0 g
s
.38095 .36975 m .37691 .37012 L .37771 .36276 L p .629 .341 .462 r
F P
0 g
s
.37771 .36276 m .3814 .36242 L .38095 .36975 L p .629 .341 .462 r
F P
0 g
s
.38908 .3697 m .38095 .36975 L .3814 .36242 L p .673 .378 .466 r
F P
0 g
s
.3814 .36242 m .38924 .36238 L .38908 .3697 L p .673 .378 .466 r
F P
0 g
s
.40141 .37045 m .38908 .3697 L .38924 .36238 L p .704 .405 .466 r
F P
0 g
s
.74468 .26322 m .72995 .27726 L .72333 .26899 L p .528 .517 .787 r
F P
0 g
s
.72333 .26899 m .73752 .25538 L .74468 .26322 L p .528 .517 .787 r
F P
0 g
s
.73752 .25538 m .72333 .26899 L .71607 .26129 L p .552 .557 .812 r
F P
0 g
s
.28729 .43528 m .28142 .44756 L .29155 .44729 L p .711 .83 .938 r
F P
0 g
s
.29155 .44729 m .29739 .43519 L .28729 .43528 L p .711 .83 .938 r
F P
0 g
s
.36212 .3883 m .35673 .39411 L .36115 .38745 L p 0 0 0 r
F P
0 g
s
.36115 .38745 m .36629 .3819 L .36212 .3883 L p 0 0 0 r
F P
0 g
s
.71607 .26129 m .72966 .24817 L .73752 .25538 L p .552 .557 .812 r
F P
0 g
s
.72966 .24817 m .71607 .26129 L .70829 .25428 L p .575 .595 .836 r
F P
0 g
s
.45819 .38477 m .43695 .3813 L .43623 .37493 L p .737 .386 .386 r
F P
0 g
s
.41736 .37221 m .43623 .37493 L .43695 .3813 L p .728 .379 .388 r
F P
0 g
s
.23627 .28232 m .24822 .2681 L .25502 .26445 L p .754 .995 .842 r
F P
0 g
s
.24822 .2681 m .23627 .28232 L .22999 .28743 L p .692 .957 .705 r
F P
0 g
s
.39259 .2474 m .37537 .24756 L .37415 .24033 L p .673 .725 .888 r
F P
0 g
s
.3571 .24213 m .37415 .24033 L .37537 .24756 L p .669 .722 .889 r
F P
0 g
s
.37031 .37869 m .36629 .3819 L .36939 .37472 L p .061 0 .154 r
F P
0 g
s
.36939 .37472 m .3731 .37173 L .37031 .37869 L p .061 0 .154 r
F P
0 g
s
.61399 .41251 m .58675 .41276 L .5861 .41 L p .472 0 0 r
F P
0 g
s
.5861 .41 m .61419 .40974 L .61399 .41251 L p .472 0 0 r
F P
0 g
s
.55913 .40842 m .5861 .41 L .58675 .41276 L p .514 0 0 r
F P
0 g
s
.37415 .24033 m .39286 .24016 L .39259 .2474 L p .673 .725 .888 r
F P
0 g
s
.75106 .27156 m .73584 .28597 L .72995 .27726 L p .503 .476 .76 r
F P
0 g
s
.72995 .27726 m .74468 .26322 L .75106 .27156 L p .503 .476 .76 r
F P
0 g
s
.72808 .36881 m .7037 .38127 L .7052 .37456 L p .335 .054 .329 r
F P
0 g
s
.7052 .37456 m .73 .36185 L .72808 .36881 L p .335 .054 .329 r
F P
0 g
s
.53025 .24853 m .50796 .24465 L .51089 .24107 L p .532 .778 .988 r
F P
0 g
s
.51089 .24107 m .53304 .24494 L .53025 .24853 L p .532 .778 .988 r
F P
0 g
s
.64187 .40979 m .61399 .41251 L .61419 .40974 L p .405 0 0 r
F P
0 g
s
.61419 .40974 m .64314 .40691 L .64187 .40979 L p .405 0 0 r
F P
0 g
s
.19797 .35476 m .20541 .33994 L .20598 .33131 L p 0 0 .277 r
F P
0 g
s
.20541 .33994 m .19797 .35476 L .1987 .36358 L p 0 0 .439 r
F P
0 g
s
.32144 .24609 m .33675 .2401 L .34181 .24564 L p .66 .757 .922 r
F P
0 g
s
.33675 .2401 m .32144 .24609 L .31461 .24238 L p .66 .802 .951 r
F P
0 g
s
.3571 .24213 m .34181 .24564 L .33675 .2401 L p .658 .756 .923 r
F P
0 g
s
.70829 .25428 m .72125 .24169 L .72966 .24817 L p .575 .595 .836 r
F P
0 g
s
.72125 .24169 m .70829 .25428 L .70011 .24807 L p .597 .634 .858 r
F P
0 g
s
.32251 .42085 m .31637 .43157 L .32492 .42812 L p .8 .959 .916 r
F P
0 g
s
.32492 .42812 m .33095 .41766 L .32251 .42085 L p .8 .959 .916 r
F P
0 g
s
.20266 .40372 m .20867 .38984 L .2041 .38127 L p .259 .293 .707 r
F P
0 g
s
.20867 .38984 m .20266 .40372 L .2084 .41178 L p .332 .378 .76 r
F P
0 g
s
.60595 .25139 m .59081 .25152 L .59161 .24903 L p .451 .815 .995 r
F P
0 g
s
.59081 .25152 m .57339 .25041 L .57511 .24798 L p .429 .794 .995 r
F P
0 g
s
.57511 .24798 m .59161 .24903 L .59081 .25152 L p .429 .794 .995 r
F P
0 g
s
.21096 .3154 m .2205 .30032 L .2247 .29346 L p 0 0 0 r
F P
0 g
s
.2205 .30032 m .21096 .3154 L .20784 .32309 L p 0 0 0 r
F P
0 g
s
.61877 .25007 m .60595 .25139 L .60548 .24891 L p .488 .843 .994 r
F P
0 g
s
.59161 .24903 m .60548 .24891 L .60595 .25139 L p .451 .815 .995 r
F P
0 g
s
.53318 .40561 m .50812 .40203 L .50655 .39791 L p .653 .188 .137 r
F P
0 g
s
.48236 .39397 m .50655 .39791 L .50812 .40203 L p .662 .194 .131 r
F P
0 g
s
.48211 .24529 m .45919 .24131 L .46185 .23646 L p .606 .768 .958 r
F P
0 g
s
.46185 .23646 m .48505 .2405 L .48211 .24529 L p .606 .768 .958 r
F P
0 g
s
.75653 .28027 m .7409 .29498 L .73584 .28597 L p .475 .432 .729 r
F P
0 g
s
.73584 .28597 m .75106 .27156 L .75653 .28027 L p .475 .432 .729 r
F P
0 g
s
.58675 .41276 m .56039 .41122 L .55913 .40842 L p .514 0 0 r
F P
0 g
s
.53318 .40561 m .55913 .40842 L .56039 .41122 L p .54 .008 0 r
F P
0 g
s
.34471 .40486 m .33859 .41341 L .3453 .40821 L p .761 .989 .767 r
F P
0 g
s
.3453 .40821 m .35122 .39995 L .34471 .40486 L p .761 .989 .767 r
F P
0 g
s
.57339 .25041 m .554 .24815 L .55634 .24578 L p .417 .778 .995 r
F P
0 g
s
.55634 .24578 m .57511 .24798 L .57339 .25041 L p .417 .778 .995 r
F P
0 g
s
.64516 .24655 m .65583 .24066 L .6633 .24358 L p .671 .806 .948 r
F P
0 g
s
.65583 .24066 m .64516 .24655 L .63933 .24404 L p .674 .859 .97 r
F P
0 g
s
.62963 .24765 m .63933 .24404 L .64516 .24655 L p .644 .854 .98 r
F P
0 g
s
.43434 .24391 m .41302 .24143 L .4144 .23528 L p .652 .752 .923 r
F P
0 g
s
.4144 .23528 m .43652 .23785 L .43434 .24391 L p .652 .752 .923 r
F P
0 g
s
.70011 .24807 m .71241 .23604 L .72125 .24169 L p .597 .634 .858 r
F P
0 g
s
.71241 .23604 m .70011 .24807 L .69165 .24275 L p .62 .673 .879 r
F P
0 g
s
.62963 .24765 m .61877 .25007 L .61668 .24776 L p .542 .873 .992 r
F P
0 g
s
.60548 .24891 m .61668 .24776 L .61877 .25007 L p .488 .843 .994 r
F P
0 g
s
.27701 .43421 m .27111 .44668 L .28142 .44756 L p .677 .788 .933 r
F P
0 g
s
.28142 .44756 m .28729 .43528 L .27701 .43421 L p .677 .788 .933 r
F P
0 g
s
.48236 .39397 m .4594 .39008 L .45819 .38477 L p .714 .31 .28 r
F P
0 g
s
.43695 .3813 m .45819 .38477 L .4594 .39008 L p .711 .308 .281 r
F P
0 g
s
.6985 .39172 m .67186 .40092 L .67387 .39657 L p .293 0 .085 r
F P
0 g
s
.67387 .39657 m .70146 .38702 L .6985 .39172 L p .293 0 .085 r
F P
0 g
s
.43695 .3813 m .41789 .37857 L .41736 .37221 L p .728 .379 .388 r
F P
0 g
s
.40141 .37045 m .41736 .37221 L .41789 .37857 L p .712 .367 .391 r
F P
0 g
s
.26253 .26193 m .27696 .24949 L .2843 .2488 L p .72 .948 .953 r
F P
0 g
s
.27696 .24949 m .26253 .26193 L .25502 .26445 L p .702 .978 .909 r
F P
0 g
s
.75139 .3397 m .73096 .35413 L .73097 .34578 L p .347 .163 .484 r
F P
0 g
s
.73097 .34578 m .75142 .33128 L .75139 .3397 L p .347 .163 .484 r
F P
0 g
s
.6633 .24358 m .67444 .23512 L .68305 .23841 L p .664 .758 .92 r
F P
0 g
s
.67444 .23512 m .6633 .24358 L .65583 .24066 L p .682 .806 .942 r
F P
0 g
s
.37269 .37733 m .37031 .37869 L .3731 .37173 L p .252 0 .255 r
F P
0 g
s
.3731 .37173 m .37505 .37061 L .37269 .37733 L p .252 0 .255 r
F P
0 g
s
.29205 .24933 m .3079 .23985 L .31461 .24238 L p .68 .853 .965 r
F P
0 g
s
.3079 .23985 m .29205 .24933 L .2843 .2488 L p .677 .904 .976 r
F P
0 g
s
.66938 .40406 m .64187 .40979 L .64314 .40691 L p .299 0 0 r
F P
0 g
s
.64314 .40691 m .67186 .40092 L .66938 .40406 L p .299 0 0 r
F P
0 g
s
.76102 .28921 m .74504 .30417 L .7409 .29498 L p .444 .383 .694 r
F P
0 g
s
.7409 .29498 m .75653 .28027 L .76102 .28921 L p .444 .383 .694 r
F P
0 g
s
.2084 .41178 m .21441 .39804 L .20867 .38984 L p .332 .378 .76 r
F P
0 g
s
.21441 .39804 m .2084 .41178 L .21522 .41929 L p .393 .449 .8 r
F P
0 g
s
.37415 .24033 m .3571 .24213 L .35401 .23612 L p .656 .755 .923 r
F P
0 g
s
.33675 .2401 m .35401 .23612 L .3571 .24213 L p .658 .756 .923 r
F P
0 g
s
.50796 .24465 m .48505 .2405 L .48792 .23691 L p .531 .777 .988 r
F P
0 g
s
.48792 .23691 m .51089 .24107 L .50796 .24465 L p .531 .777 .988 r
F P
0 g
s
.37391 .37687 m .37269 .37733 L .37505 .37061 L p .407 .098 .325 r
F P
0 g
s
.37505 .37061 m .37569 .37037 L .37391 .37687 L p .407 .098 .325 r
F P
0 g
s
.554 .24815 m .53304 .24494 L .53573 .24262 L p .41 .768 .995 r
F P
0 g
s
.53573 .24262 m .55634 .24578 L .554 .24815 L p .41 .768 .995 r
F P
0 g
s
.41789 .37857 m .40166 .37678 L .40141 .37045 L p .712 .367 .391 r
F P
0 g
s
.38908 .3697 m .40141 .37045 L .40166 .37678 L p .688 .347 .393 r
F P
0 g
s
.37574 .37649 m .37391 .37687 L .37569 .37037 L p .535 .214 .37 r
F P
0 g
s
.37569 .37037 m .37691 .37012 L .37574 .37649 L p .535 .214 .37 r
F P
0 g
s
.56039 .41122 m .53483 .40845 L .53318 .40561 L p .54 .008 0 r
F P
0 g
s
.50812 .40203 m .53318 .40561 L .53483 .40845 L p .555 .017 0 r
F P
0 g
s
.69165 .24275 m .70327 .23132 L .71241 .23604 L p .62 .673 .879 r
F P
0 g
s
.70327 .23132 m .69165 .24275 L .68305 .23841 L p .642 .714 .9 r
F P
0 g
s
.41302 .24143 m .39286 .24016 L .39311 .23393 L p .653 .753 .923 r
F P
0 g
s
.39311 .23393 m .4144 .23528 L .41302 .24143 L p .653 .753 .923 r
F P
0 g
s
.38035 .37606 m .37574 .37649 L .37691 .37012 L p .604 .275 .387 r
F P
0 g
s
.37691 .37012 m .38095 .36975 L .38035 .37606 L p .604 .275 .387 r
F P
0 g
s
.63933 .24404 m .62963 .24765 L .62576 .24574 L p .606 .898 .987 r
F P
0 g
s
.61668 .24776 m .62576 .24574 L .62963 .24765 L p .542 .873 .992 r
F P
0 g
s
.26672 .432 m .26079 .44467 L .27111 .44668 L p .643 .746 .924 r
F P
0 g
s
.27111 .44668 m .27701 .43421 L .26672 .432 L p .643 .746 .924 r
F P
0 g
s
.1987 .36358 m .20614 .34884 L .20541 .33994 L p 0 0 .439 r
F P
0 g
s
.20614 .34884 m .1987 .36358 L .20076 .37246 L p .114 .096 .557 r
F P
0 g
s
.3134 .42294 m .30714 .43394 L .31637 .43157 L p .772 .919 .936 r
F P
0 g
s
.31637 .43157 m .32251 .42085 L .3134 .42294 L p .772 .919 .936 r
F P
0 g
s
.35692 .39381 m .35122 .39995 L .35673 .39411 L p .526 .824 .493 r
F P
0 g
s
.35673 .39411 m .36212 .3883 L .35692 .39381 L p .526 .824 .493 r
F P
0 g
s
.38897 .37601 m .38035 .37606 L .38095 .36975 L p .653 .318 .393 r
F P
0 g
s
.38095 .36975 m .38908 .3697 L .38897 .37601 L p .653 .318 .393 r
F P
0 g
s
.40166 .37678 m .38897 .37601 L .38908 .3697 L p .688 .347 .393 r
F P
0 g
s
.45919 .24131 m .43652 .23785 L .43866 .23292 L p .607 .77 .958 r
F P
0 g
s
.43866 .23292 m .46185 .23646 L .45919 .24131 L p .607 .77 .958 r
F P
0 g
s
.50812 .40203 m .48398 .39811 L .48236 .39397 L p .662 .194 .131 r
F P
0 g
s
.4594 .39008 m .48236 .39397 L .48398 .39811 L p .665 .196 .129 r
F P
0 g
s
.22999 .28743 m .24226 .27282 L .24822 .2681 L p .692 .957 .705 r
F P
0 g
s
.24226 .27282 m .22999 .28743 L .2247 .29346 L p .562 .835 .487 r
F P
0 g
s
.36654 .38477 m .36212 .3883 L .36629 .3819 L p 0 0 0 r
F P
0 g
s
.36629 .3819 m .37031 .37869 L .36654 .38477 L p 0 0 0 r
F P
0 g
s
.21522 .41929 m .22122 .40571 L .21441 .39804 L p .393 .449 .8 r
F P
0 g
s
.22122 .40571 m .21522 .41929 L .22299 .42614 L p .445 .511 .832 r
F P
0 g
s
.39286 .24016 m .37415 .24033 L .3729 .23412 L p .654 .754 .923 r
F P
0 g
s
.35401 .23612 m .3729 .23412 L .37415 .24033 L p .656 .755 .923 r
F P
0 g
s
.3729 .23412 m .39311 .23393 L .39286 .24016 L p .654 .754 .923 r
F P
0 g
s
.4594 .39008 m .438 .3866 L .43695 .3813 L p .711 .308 .281 r
F P
0 g
s
.41789 .37857 m .43695 .3813 L .438 .3866 L p .702 .301 .285 r
F P
0 g
s
.20784 .32309 m .21747 .3079 L .2205 .30032 L p 0 0 0 r
F P
0 g
s
.21747 .3079 m .20784 .32309 L .20598 .33131 L p 0 0 .149 r
F P
0 g
s
.76445 .29826 m .74821 .31337 L .74504 .30417 L p .409 .328 .653 r
F P
0 g
s
.74504 .30417 m .76102 .28921 L .76445 .29826 L p .409 .328 .653 r
F P
0 g
s
.72524 .37489 m .70146 .38702 L .7037 .38127 L p .247 0 .189 r
F P
0 g
s
.7037 .38127 m .72808 .36881 L .72524 .37489 L p .247 0 .189 r
F P
0 g
s
.31461 .24238 m .3317 .23568 L .33675 .2401 L p .66 .802 .951 r
F P
0 g
s
.3317 .23568 m .31461 .24238 L .3079 .23985 L p .65 .85 .977 r
F P
0 g
s
.35401 .23612 m .33675 .2401 L .3317 .23568 L p .645 .798 .956 r
F P
0 g
s
.2566 .42868 m .25065 .44154 L .26079 .44467 L p .608 .704 .912 r
F P
0 g
s
.26079 .44467 m .26672 .432 L .2566 .42868 L p .608 .704 .912 r
F P
0 g
s
.3373 .40876 m .33095 .41766 L .33859 .41341 L p .787 .995 .869 r
F P
0 g
s
.33859 .41341 m .34471 .40486 L .3373 .40876 L p .787 .995 .869 r
F P
0 g
s
.22299 .42614 m .22899 .41272 L .22122 .40571 L p .445 .511 .832 r
F P
0 g
s
.22899 .41272 m .22299 .42614 L .23159 .4322 L p .491 .565 .858 r
F P
0 g
s
.53304 .24494 m .51089 .24107 L .51371 .23878 L p .406 .763 .994 r
F P
0 g
s
.51371 .23878 m .53573 .24262 L .53304 .24494 L p .406 .763 .994 r
F P
0 g
s
.24683 .42431 m .24086 .43736 L .25065 .44154 L p .571 .66 .897 r
F P
0 g
s
.25065 .44154 m .2566 .42868 L .24683 .42431 L p .571 .66 .897 r
F P
0 g
s
.61372 .41396 m .58746 .4142 L .58675 .41276 L p .293 0 0 r
F P
0 g
s
.58675 .41276 m .61399 .41251 L .61372 .41396 L p .293 0 0 r
F P
0 g
s
.56039 .41122 m .58675 .41276 L .58746 .4142 L p .334 0 0 r
F P
0 g
s
.68305 .23841 m .69398 .2276 L .70327 .23132 L p .642 .714 .9 r
F P
0 g
s
.69398 .2276 m .68305 .23841 L .67444 .23512 L p .666 .758 .919 r
F P
0 g
s
.23159 .4322 m .23757 .41896 L .22899 .41272 L p .491 .565 .858 r
F P
0 g
s
.23757 .41896 m .23159 .4322 L .24086 .43736 L p .533 .614 .88 r
F P
0 g
s
.75027 .34758 m .73 .36185 L .73096 .35413 L p .283 .064 .394 r
F P
0 g
s
.73096 .35413 m .75139 .3397 L .75027 .34758 L p .283 .064 .394 r
F P
0 g
s
.64034 .41137 m .61372 .41396 L .61399 .41251 L p .219 0 0 r
F P
0 g
s
.61399 .41251 m .64187 .40979 L .64034 .41137 L p .219 0 0 r
F P
0 g
s
.65583 .24066 m .66595 .23295 L .67444 .23512 L p .682 .806 .942 r
F P
0 g
s
.66595 .23295 m .65583 .24066 L .6486 .2389 L p .697 .858 .959 r
F P
0 g
s
.63933 .24404 m .6486 .2389 L .65583 .24066 L p .674 .859 .97 r
F P
0 g
s
.24086 .43736 m .24683 .42431 L .23757 .41896 L p .533 .614 .88 r
F P
0 g
s
.48505 .2405 m .46185 .23646 L .46444 .23282 L p .532 .778 .988 r
F P
0 g
s
.46444 .23282 m .48792 .23691 L .48505 .2405 L p .532 .778 .988 r
F P
0 g
s
.25502 .26445 m .27015 .25139 L .27696 .24949 L p .702 .978 .909 r
F P
0 g
s
.27015 .25139 m .25502 .26445 L .24822 .2681 L p .638 .96 .799 r
F P
0 g
s
.6486 .2389 m .63933 .24404 L .63378 .24275 L p .664 .911 .978 r
F P
0 g
s
.62576 .24574 m .63378 .24275 L .63933 .24404 L p .606 .898 .987 r
F P
0 g
s
.53483 .40845 m .50999 .40491 L .50812 .40203 L p .555 .017 0 r
F P
0 g
s
.48398 .39811 m .50812 .40203 L .50999 .40491 L p .562 .021 0 r
F P
0 g
s
.43652 .23785 m .4144 .23528 L .41575 .23025 L p .61 .774 .959 r
F P
0 g
s
.41575 .23025 m .43866 .23292 L .43652 .23785 L p .61 .774 .959 r
F P
0 g
s
.60548 .24891 m .59161 .24903 L .5924 .24787 L p .25 .746 .908 r
F P
0 g
s
.59161 .24903 m .57511 .24798 L .57677 .24687 L p .219 .717 .913 r
F P
0 g
s
.57677 .24687 m .5924 .24787 L .59161 .24903 L p .219 .717 .913 r
F P
0 g
s
.61668 .24776 m .60548 .24891 L .60507 .24777 L p .307 .789 .909 r
F P
0 g
s
.60507 .24777 m .60548 .24891 L p .59856 .24836 L .25 .746 .908 r
F P
0 g
s
.61476 .24678 m .61668 .24776 L p .61036 .24777 L .307 .789 .909 r
F P
0 g
s
.60507 .24777 m .61476 .24678 L p .61036 .24777 L .307 .789 .909 r
F P
0 g
s
.61476 .24678 m .61303 .24714 L p .61892 .24585 L .156 .691 .694 r
F P
0 g
s
.62216 .24513 m .61476 .24678 L p .61892 .24585 L .156 .691 .694 r
F P
0 g
s
.60507 .24777 m .60473 .24798 L p .61113 .24722 L 0 0 0 r
F P
0 g
s
.61113 .24722 m .61471 .24679 L .60507 .24777 L 0 0 0 r
F
.61471 .24678 m .60507 .24777 L p .61471 .24679 L F P
0 g
s
.60473 .24798 m .61303 .24714 L .61476 .24678 L p 0 0 0 r
F P
0 g
s
.61888 .24584 m .62216 .24513 L p .61669 .24634 L .156 .691 .694 r
F P
0 g
s
.62576 .24574 m .61668 .24776 L .61476 .24678 L p .398 .846 .919 r
F P
0 g
s
.61476 .24678 m .62216 .24513 L .62576 .24574 L p .398 .846 .919 r
F P
0 g
s
.61888 .24584 m .61599 .24788 L p .62111 .24535 L 0 0 0 r
F P
0 g
s
.6286 .24273 m .62216 .24513 L .61888 .24584 L p .332 .81 .76 r
F P
0 g
s
.62388 .24398 m .6286 .24273 L p .62252 .24468 L .332 .81 .76 r
F P
0 g
s
.61888 .24584 m .62388 .24398 L p .62252 .24468 L .332 .81 .76 r
F P
0 g
s
.63527 .23901 m .6286 .24273 L .62388 .24398 L p .513 .913 .829 r
F P
0 g
s
.62939 .24089 m .63527 .23901 L p .62833 .24204 L .513 .913 .829 r
F P
0 g
s
.62388 .24398 m .62939 .24089 L p .62833 .24204 L .513 .913 .829 r
F P
0 g
s
.62388 .24398 m .61969 .24649 L p .62555 .24311 L 0 0 0 r
F P
0 g
s
.62939 .24089 m .62388 .24398 L p .62555 .24311 L 0 0 0 r
F P
0 g
s
.62418 .24397 m .62939 .24089 L p .62326 .24443 L 0 0 0 r
F P
0 g
s
.61969 .24649 m .62418 .24397 L p .62326 .24443 L 0 0 0 r
F P
0 g
s
.63378 .24275 m .62576 .24574 L .62216 .24513 L p .513 .905 .936 r
F P
0 g
s
.62216 .24513 m .6286 .24273 L .63378 .24275 L p .513 .905 .936 r
F P
0 g
s
.62418 .24397 m .61973 .24821 L p .62544 .24335 L 0 0 0 r
F P
0 g
s
.62939 .24089 m .62418 .24397 L p .63077 .23942 L .533 .899 .701 r
F P
0 g
s
.62997 .23949 m .63589 .23587 L p .62899 .24064 L .533 .899 .701 r
F P
0 g
s
.62418 .24397 m .62997 .23949 L p .62899 .24064 L .533 .899 .701 r
F P
0 g
s
.62997 .23949 m .62418 .24397 L p .62544 .24335 L 0 0 0 r
F P
0 g
s
.6249 .24419 m .62997 .23949 L p .62386 .24469 L 0 0 0 r
F P
0 g
s
.61973 .24821 m .6249 .24419 L p .62386 .24469 L 0 0 0 r
F P
0 g
s
.6249 .24419 m .62078 .24991 L p .62626 .24355 L 0 0 0 r
F P
0 g
s
.62997 .23949 m .6249 .24419 L p .63121 .23802 L .545 .857 .557 r
F P
0 g
s
.63128 .23771 m .63673 .23262 L p .62993 .23927 L .545 .857 .557 r
F P
0 g
s
.6249 .24419 m .63128 .23771 L p .62993 .23927 L .545 .857 .557 r
F P
0 g
s
.63673 .23262 m .62997 .23949 L p .63121 .23802 L .545 .857 .557 r
F P
0 g
s
.64311 .22855 m .63589 .23587 L .62997 .23949 L p .675 .968 .771 r
F P
0 g
s
.62997 .23949 m .63673 .23262 L .64311 .22855 L p .675 .968 .771 r
F P
0 g
s
.64401 .22336 m .63673 .23262 L .63128 .23771 L p .678 .933 .638 r
F P
0 g
s
.63831 .22875 m .64401 .22336 L p .63638 .23196 L .678 .933 .638 r
F P
0 g
s
.63128 .23771 m .63831 .22875 L p .63638 .23196 L .678 .933 .638 r
F P
0 g
s
.63831 .22875 m .63128 .23771 L p .6329 .23582 L 0 0 0 r
F P
0 g
s
.63368 .23504 m .63831 .22875 L p .63153 .23762 L 0 0 0 r
F P
0 g
s
.62684 .24375 m .63368 .23504 L p .63153 .23762 L 0 0 0 r
F P
0 g
s
.63589 .23587 m .62939 .24089 L p .63077 .23942 L .533 .899 .701 r
F P
0 g
s
.6286 .24273 m .63527 .23901 L .6417 .23835 L p .621 .944 .947 r
F P
0 g
s
.64257 .23338 m .63527 .23901 L .62939 .24089 L p .65 .969 .873 r
F P
0 g
s
.62939 .24089 m .63589 .23587 L .64257 .23338 L p .65 .969 .873 r
F P
0 g
s
.63368 .23504 m .6302 .24212 L p .63617 .23205 L 0 0 0 r
F P
0 g
s
.63831 .22875 m .63368 .23504 L p .64055 .22503 L .638 .851 .466 r
F P
0 g
s
.64091 .22405 m .64566 .21759 L p .63778 .22907 L .638 .851 .466 r
F P
0 g
s
.63368 .23504 m .64091 .22405 L p .63778 .22907 L .638 .851 .466 r
F P
0 g
s
.64566 .21759 m .63831 .22875 L p .64055 .22503 L .638 .851 .466 r
F P
0 g
s
.6515 .212 m .64401 .22336 L .63831 .22875 L p .755 .967 .683 r
F P
0 g
s
.63831 .22875 m .64566 .21759 L .6515 .212 L p .755 .967 .683 r
F P
0 g
s
.65324 .20461 m .64566 .21759 L .64091 .22405 L p .701 .888 .508 r
F P
0 g
s
.64091 .22405 m .64091 .22405 L p .64091 .22405 L .701 .888 .508 r
F P
0 g
s
.64091 .22405 m .65324 .20461 L .64091 .22405 L .701 .888 .508 r
F
.64843 .21117 m .65324 .20461 L p .64353 .21992 L F P
0 g
s
.64091 .22405 m .64843 .21117 L p .64353 .21992 L .701 .888 .508 r
F P
0 g
s
.66118 .1902 m .65324 .20461 L .64843 .21116 L p .728 .902 .526 r
F P
0 g
s
.64843 .21117 m .65634 .19679 L .66118 .1902 L p .728 .902 .526 r
F P
0 g
s
.64482 .21847 m .65271 .20412 L .65634 .19679 L p 0 0 0 r
F P
0 g
s
.64843 .21117 m .64482 .21847 L p .65382 .20153 L 0 0 0 r
F P
0 g
s
.65634 .19679 m .64843 .21117 L p .65382 .20153 L 0 0 0 r
F P
0 g
s
.63735 .23127 m .64482 .21847 L .64843 .21117 L p 0 0 0 r
F P
0 g
s
.64843 .21117 m .64843 .21117 L p .64843 .21117 L 0 0 0 r
F P
0 g
s
.63735 .23127 m .64843 .21117 L .64843 .21117 L 0 0 0 r
F
.64091 .22405 m .63735 .23127 L p .64444 .2184 L F P
0 g
s
.64843 .21117 m .64091 .22405 L p .64444 .2184 L 0 0 0 r
F P
0 g
s
.64091 .22405 m .63368 .23504 L p .63617 .23205 L 0 0 0 r
F P
0 g
s
.63128 .23771 m .62684 .24375 L p .6329 .23582 L 0 0 0 r
F P
0 g
s
.63128 .23771 m .6249 .24419 L p .62626 .24355 L 0 0 0 r
F P
0 g
s
.62388 .24398 m .61888 .24584 L p .62111 .24535 L 0 0 0 r
F P
0 g
s
.61308 .24713 m .61888 .24584 L .61669 .24634 L .156 .691 .694 r
F
.61303 .24714 m .61307 .24713 L p .61308 .24713 L F P
0 g
s
.61307 .24713 m .61888 .24584 L p .61308 .24713 L .156 .691 .694 r
F P
0 g
s
.61476 .24678 m .61471 .24678 L p .61471 .24679 L 0 0 0 r
F P
0 g
s
.5924 .24787 m .60507 .24777 L p .59856 .24836 L .25 .746 .908 r
F P
0 g
s
.36954 .38308 m .36654 .38477 L .37031 .37869 L p .141 0 .083 r
F P
0 g
s
.37031 .37869 m .37269 .37733 L .36954 .38308 L p .141 0 .083 r
F P
0 g
s
.20076 .37246 m .20818 .35784 L .20614 .34884 L p .114 .096 .557 r
F P
0 g
s
.20818 .35784 m .20076 .37246 L .2041 .38127 L p .213 .215 .643 r
F P
0 g
s
.2843 .2488 m .30141 .23855 L .3079 .23985 L p .677 .904 .976 r
F P
0 g
s
.30141 .23855 m .2843 .2488 L .27696 .24949 L p .652 .944 .96 r
F P
0 g
s
.438 .3866 m .41869 .38383 L .41789 .37857 L p .702 .301 .285 r
F P
0 g
s
.40166 .37678 m .41789 .37857 L .41869 .38383 L p .686 .289 .289 r
F P
0 g
s
.30378 .42389 m .29739 .43519 L .30714 .43394 L p .741 .875 .942 r
F P
0 g
s
.30714 .43394 m .3134 .42294 L .30378 .42389 L p .741 .875 .942 r
F P
0 g
s
.58746 .4142 m .56181 .4127 L .56039 .41122 L p .334 0 0 r
F P
0 g
s
.53483 .40845 m .56039 .41122 L .56181 .4127 L p .355 0 0 r
F P
0 g
s
.48398 .39811 m .46094 .39422 L .4594 .39008 L p .665 .196 .129 r
F P
0 g
s
.438 .3866 m .4594 .39008 L .46094 .39422 L p .662 .194 .131 r
F P
0 g
s
.76676 .30726 m .75035 .32246 L .74821 .31337 L p .366 .263 .603 r
F P
0 g
s
.74821 .31337 m .76445 .29826 L .76676 .30726 L p .366 .263 .603 r
F P
0 g
s
.69486 .39527 m .66938 .40406 L .67186 .40092 L p .141 0 0 r
F P
0 g
s
.67186 .40092 m .6985 .39172 L .69486 .39527 L p .141 0 0 r
F P
0 g
s
.57511 .24798 m .55634 .24578 L .55856 .24474 L p .204 .698 .919 r
F P
0 g
s
.55856 .24474 m .57677 .24687 L .57511 .24798 L p .204 .698 .919 r
F P
0 g
s
.37153 .38234 m .36954 .38308 L .37269 .37733 L p .337 0 .192 r
F P
0 g
s
.37269 .37733 m .37391 .37687 L .37153 .38234 L p .337 0 .192 r
F P
0 g
s
.3729 .23412 m .35401 .23612 L .35091 .23123 L p .632 .791 .959 r
F P
0 g
s
.3317 .23568 m .35091 .23123 L .35401 .23612 L p .645 .798 .956 r
F P
0 g
s
.35077 .39833 m .34471 .40486 L .35122 .39995 L p .658 .949 .713 r
F P
0 g
s
.35122 .39995 m .35692 .39381 L .35077 .39833 L p .658 .949 .713 r
F P
0 g
s
.37421 .38178 m .37153 .38234 L .37391 .37687 L p .481 .109 .257 r
F P
0 g
s
.37391 .37687 m .37574 .37649 L .37421 .38178 L p .481 .109 .257 r
F P
0 g
s
.66645 .40593 m .64034 .41137 L .64187 .40979 L p .098 0 0 r
F P
0 g
s
.64187 .40979 m .66938 .40406 L .66645 .40593 L p .098 0 0 r
F P
0 g
s
.41869 .38383 m .40209 .38201 L .40166 .37678 L p .686 .289 .289 r
F P
0 g
s
.38897 .37601 m .40166 .37678 L .40209 .38201 L p .66 .268 .293 r
F P
0 g
s
.2247 .29346 m .23723 .27853 L .24226 .27282 L p .562 .835 .487 r
F P
0 g
s
.23723 .27853 m .2247 .29346 L .2205 .30032 L p 0 0 0 r
F P
0 g
s
.20598 .33131 m .21565 .31609 L .21747 .3079 L p 0 0 .149 r
F P
0 g
s
.21565 .31609 m .20598 .33131 L .20541 .33994 L p 0 0 .336 r
F P
0 g
s
.37962 .38127 m .37421 .38178 L .37574 .37649 L p .565 .187 .284 r
F P
0 g
s
.37574 .37649 m .38035 .37606 L .37962 .38127 L p .565 .187 .284 r
F P
0 g
s
.4144 .23528 m .39311 .23393 L .39333 .22883 L p .615 .778 .959 r
F P
0 g
s
.39333 .22883 m .41575 .23025 L .4144 .23528 L p .615 .778 .959 r
F P
0 g
s
.36186 .38988 m .35692 .39381 L .36212 .3883 L p 0 0 0 r
F P
0 g
s
.36212 .3883 m .36654 .38477 L .36186 .38988 L p 0 0 0 r
F P
0 g
s
.51089 .24107 m .48792 .23691 L .49067 .23459 L p .405 .761 .994 r
F P
0 g
s
.49067 .23459 m .51371 .23878 L .51089 .24107 L p .405 .761 .994 r
F P
0 g
s
.67444 .23512 m .68468 .22493 L .69398 .2276 L p .666 .758 .919 r
F P
0 g
s
.68468 .22493 m .67444 .23512 L .66595 .23295 L p .689 .804 .936 r
F P
0 g
s
.38889 .38121 m .37962 .38127 L .38035 .37606 L p .621 .236 .293 r
F P
0 g
s
.38035 .37606 m .38897 .37601 L .38889 .38121 L p .621 .236 .293 r
F P
0 g
s
.40209 .38201 m .38889 .38121 L .38897 .37601 L p .66 .268 .293 r
F P
0 g
s
.55634 .24578 m .53573 .24262 L .53828 .24162 L p .196 .687 .923 r
F P
0 g
s
.53828 .24162 m .55856 .24474 L .55634 .24578 L p .196 .687 .923 r
F P
0 g
s
.3291 .41158 m .32251 .42085 L .33095 .41766 L p .781 .968 .92 r
F P
0 g
s
.33095 .41766 m .3373 .40876 L .3291 .41158 L p .781 .968 .92 r
F P
0 g
s
.46185 .23646 m .43866 .23292 L .44075 .22919 L p .535 .782 .989 r
F P
0 g
s
.44075 .22919 m .46444 .23282 L .46185 .23646 L p .535 .782 .989 r
F P
0 g
s
.56181 .4127 m .53671 .40998 L .53483 .40845 L p .355 0 0 r
F P
0 g
s
.50999 .40491 m .53483 .40845 L .53671 .40998 L p .366 0 0 r
F P
0 g
s
.39311 .23393 m .3729 .23412 L .37162 .22904 L p .622 .784 .959 r
F P
0 g
s
.35091 .23123 m .37162 .22904 L .3729 .23412 L p .632 .791 .959 r
F P
0 g
s
.2041 .38127 m .21149 .36679 L .20818 .35784 L p .213 .215 .643 r
F P
0 g
s
.21149 .36679 m .2041 .38127 L .20867 .38984 L p .292 .31 .708 r
F P
0 g
s
.3079 .23985 m .32672 .23245 L .3317 .23568 L p .65 .85 .977 r
F P
0 g
s
.32672 .23245 m .3079 .23985 L .30141 .23855 L p .621 .895 .987 r
F P
0 g
s
.37162 .22904 m .39333 .22883 L .39311 .23393 L p .622 .784 .959 r
F P
0 g
s
.50999 .40491 m .48591 .40101 L .48398 .39811 L p .562 .021 0 r
F P
0 g
s
.46094 .39422 m .48398 .39811 L .48591 .40101 L p .565 .022 0 r
F P
0 g
s
.7215 .38 m .6985 .39172 L .70146 .38702 L p .117 0 0 r
F P
0 g
s
.70146 .38702 m .72524 .37489 L .7215 .38 L p .117 0 0 r
F P
0 g
s
.29381 .42367 m .28729 .43528 L .29739 .43519 L p .709 .832 .941 r
F P
0 g
s
.29739 .43519 m .30378 .42389 L .29381 .42367 L p .709 .832 .941 r
F P
0 g
s
.74952 .24108 m .73752 .25538 L .72966 .24817 L p .534 .553 .821 r
F P
0 g
s
.72966 .24817 m .74129 .23422 L .74952 .24108 L p .534 .553 .821 r
F P
0 g
s
.74129 .23422 m .72966 .24817 L .72125 .24169 L p .561 .594 .844 r
F P
0 g
s
.35091 .23123 m .3317 .23568 L .32672 .23245 L p .617 .84 .985 r
F P
0 g
s
.46094 .39422 m .43936 .39071 L .438 .3866 L p .662 .194 .131 r
F P
0 g
s
.41869 .38383 m .438 .3866 L .43936 .39071 L p .653 .188 .136 r
F P
0 g
s
.75705 .24859 m .74468 .26322 L .73752 .25538 L p .506 .511 .796 r
F P
0 g
s
.73752 .25538 m .74952 .24108 L .75705 .24859 L p .506 .511 .796 r
F P
0 g
s
.72125 .24169 m .73246 .22814 L .74129 .23422 L p .561 .594 .844 r
F P
0 g
s
.73246 .22814 m .72125 .24169 L .71241 .23604 L p .587 .634 .864 r
F P
0 g
s
.74805 .35478 m .72808 .36881 L .73 .36185 L p .195 0 .27 r
F P
0 g
s
.73 .36185 m .75027 .34758 L .74805 .35478 L p .195 0 .27 r
F P
0 g
s
.6486 .2389 m .65772 .23192 L .66595 .23295 L p .697 .858 .959 r
F P
0 g
s
.65772 .23192 m .6486 .2389 L .6417 .23835 L p .706 .912 .966 r
F P
0 g
s
.63378 .24275 m .6417 .23835 L .6486 .2389 L p .664 .911 .978 r
F P
0 g
s
.76791 .31607 m .75142 .33128 L .75035 .32246 L p .314 .185 .541 r
F P
0 g
s
.75035 .32246 m .76676 .30726 L .76791 .31607 L p .314 .185 .541 r
F P
0 g
s
.76374 .25665 m .75106 .27156 L .74468 .26322 L p .475 .466 .768 r
F P
0 g
s
.74468 .26322 m .75705 .24859 L .76374 .25665 L p .475 .466 .768 r
F P
0 g
s
.24822 .2681 m .26399 .25449 L .27015 .25139 L p .638 .96 .799 r
F P
0 g
s
.26399 .25449 m .24822 .2681 L .24226 .27282 L p .504 .854 .596 r
F P
0 g
s
.71241 .23604 m .72319 .22292 L .73246 .22814 L p .587 .634 .864 r
F P
0 g
s
.72319 .22292 m .71241 .23604 L .70327 .23132 L p .613 .674 .884 r
F P
0 g
s
.6417 .23835 m .63378 .24275 L .6286 .24273 L p .621 .944 .947 r
F P
0 g
s
.36562 .38777 m .36186 .38988 L .36654 .38477 L p 0 0 0 r
F P
0 g
s
.36654 .38477 m .36954 .38308 L .36562 .38777 L p 0 0 0 r
F P
0 g
s
.27696 .24949 m .29525 .23851 L .30141 .23855 L p .652 .944 .96 r
F P
0 g
s
.29525 .23851 m .27696 .24949 L .27015 .25139 L p .582 .944 .883 r
F P
0 g
s
.53573 .24262 m .51371 .23878 L .51638 .2378 L p .193 .681 .926 r
F P
0 g
s
.51638 .2378 m .53828 .24162 L .53573 .24262 L p .193 .681 .926 r
F P
0 g
s
.48792 .23691 m .46444 .23282 L .46692 .23045 L p .406 .763 .994 r
F P
0 g
s
.46692 .23045 m .49067 .23459 L .48792 .23691 L p .406 .763 .994 r
F P
0 g
s
.20867 .38984 m .21603 .37556 L .21149 .36679 L p .292 .31 .708 r
F P
0 g
s
.21603 .37556 m .20867 .38984 L .21441 .39804 L p .357 .389 .757 r
F P
0 g
s
.66595 .23295 m .67552 .22338 L .68468 .22493 L p .689 .804 .936 r
F P
0 g
s
.67552 .22338 m .66595 .23295 L .65772 .23192 L p .712 .855 .95 r
F P
0 g
s
.61337 .41406 m .58822 .41429 L .58746 .4142 L p .014 0 0 r
F P
0 g
s
.58746 .4142 m .61372 .41396 L .61337 .41406 L p .014 0 0 r
F P
0 g
s
.56181 .4127 m .58746 .4142 L .58822 .41429 L p .05 0 0 r
F P
0 g
s
.43866 .23292 m .41575 .23025 L .41705 .22642 L p .54 .788 .99 r
F P
0 g
s
.41705 .22642 m .44075 .22919 L .43866 .23292 L p .54 .788 .99 r
F P
0 g
s
.28365 .42228 m .27701 .43421 L .28729 .43528 L p .676 .789 .934 r
F P
0 g
s
.28729 .43528 m .29381 .42367 L .28365 .42228 L p .676 .789 .934 r
F P
0 g
s
.20541 .33994 m .21509 .32475 L .21565 .31609 L p 0 0 .336 r
F P
0 g
s
.21509 .32475 m .20541 .33994 L .20614 .34884 L p .092 .02 .474 r
F P
0 g
s
.76949 .26514 m .75653 .28027 L .75106 .27156 L p .441 .417 .737 r
F P
0 g
s
.75106 .27156 m .76374 .25665 L .76949 .26514 L p .441 .417 .737 r
F P
0 g
s
.63859 .41161 m .61337 .41406 L .61372 .41396 L p 0 0 0 r
F P
0 g
s
.61372 .41396 m .64034 .41137 L .63859 .41161 L p 0 0 0 r
F P
0 g
s
.70327 .23132 m .71361 .21864 L .72319 .22292 L p .613 .674 .884 r
F P
0 g
s
.71361 .21864 m .70327 .23132 L .69398 .2276 L p .64 .715 .902 r
F P
0 g
s
.43936 .39071 m .41974 .3879 L .41869 .38383 L p .653 .188 .136 r
F P
0 g
s
.40209 .38201 m .41869 .38383 L .41974 .3879 L p .636 .176 .143 r
F P
0 g
s
.53671 .40998 m .51212 .40648 L .50999 .40491 L p .366 0 0 r
F P
0 g
s
.48591 .40101 m .50999 .40491 L .51212 .40648 L p .371 0 0 r
F P
0 g
s
.34378 .40178 m .3373 .40876 L .34471 .40486 L p .726 .99 .853 r
F P
0 g
s
.34471 .40486 m .35077 .39833 L .34378 .40178 L p .726 .99 .853 r
F P
0 g
s
.2205 .30032 m .23324 .28517 L .23723 .27853 L p 0 0 0 r
F P
0 g
s
.23324 .28517 m .2205 .30032 L .21747 .3079 L p 0 0 .04 r
F P
0 g
s
.32026 .41326 m .3134 .42294 L .32251 .42085 L p .76 .926 .943 r
F P
0 g
s
.32251 .42085 m .3291 .41158 L .32026 .41326 L p .76 .926 .943 r
F P
0 g
s
.60507 .24777 m .5924 .24787 L .59316 .24807 L p .042 0 0 r
F P
0 g
s
.5924 .24787 m .57677 .24687 L .57831 .24712 L p .081 0 0 r
F P
0 g
s
.57831 .24712 m .59316 .24807 L .5924 .24787 L p .081 0 0 r
F P
0 g
s
.48591 .40101 m .4628 .39711 L .46094 .39422 L p .565 .022 0 r
F P
0 g
s
.43936 .39071 m .46094 .39422 L .4628 .39711 L p .562 .021 0 r
F P
0 g
s
.59316 .24807 m .60473 .24798 L .60507 .24777 L p .042 0 0 r
F P
0 g
s
.36859 .38668 m .36562 .38777 L .36954 .38308 L p .224 0 0 r
F P
0 g
s
.36954 .38308 m .37153 .38234 L .36859 .38668 L p .224 0 0 r
F P
0 g
s
.6906 .3976 m .66645 .40593 L .66938 .40406 L p 0 0 0 r
F P
0 g
s
.66938 .40406 m .69486 .39527 L .6906 .3976 L p 0 0 0 r
F P
0 g
s
.66938 .40406 m .6906 .3976 L .69059 .39761 L 0 0 0 r
F
.68578 .39868 m .66313 .4065 L .66645 .40593 L p .326 .809 .778 r
F P
0 g
s
.66645 .40593 m .66645 .40593 L p .66646 .40593 L .326 .809 .778 r
F P
0 g
s
.66646 .40593 m .68578 .39868 L .66645 .40593 L .326 .809 .778 r
F
.6906 .3976 m .6906 .3976 L p .69059 .39761 L 0 0 0 r
F P
0 g
s
.35632 .39392 m .35077 .39833 L .35692 .39381 L p .477 .846 .606 r
F P
0 g
s
.35692 .39381 m .36186 .38988 L .35632 .39392 L p .477 .846 .606 r
F P
0 g
s
.58822 .41429 m .56336 .41283 L .56181 .4127 L p .05 0 0 r
F P
0 g
s
.53671 .40998 m .56181 .4127 L .56336 .41283 L p 0 .519 .712 r
F P
0 g
s
.37162 .22904 m .35091 .23123 L .34784 .22755 L p .587 .826 .99 r
F P
0 g
s
.32672 .23245 m .34784 .22755 L .35091 .23123 L p .617 .84 .985 r
F P
0 g
s
.37235 .38588 m .36859 .38668 L .37153 .38234 L p .396 0 .094 r
F P
0 g
s
.37153 .38234 m .37421 .38178 L .37235 .38588 L p .396 0 .094 r
F P
0 g
s
.57677 .24687 m .55856 .24474 L .56063 .24505 L p .098 0 0 r
F P
0 g
s
.56063 .24505 m .57831 .24712 L .57677 .24687 L p .098 0 0 r
F P
0 g
s
.41974 .3879 m .40268 .38604 L .40209 .38201 L p .636 .176 .143 r
F P
0 g
s
.38889 .38121 m .40209 .38201 L .40268 .38604 L p .608 .154 .149 r
F P
0 g
s
.76788 .32455 m .75139 .3397 L .75142 .33128 L p .247 .088 .459 r
F P
0 g
s
.75142 .33128 m .76791 .31607 L .76788 .32455 L p .247 .088 .459 r
F P
0 g
s
.37875 .38527 m .37235 .38588 L .37421 .38178 L p .499 .06 .135 r
F P
0 g
s
.37421 .38178 m .37962 .38127 L .37875 .38527 L p .499 .06 .135 r
F P
0 g
s
.21441 .39804 m .22172 .38397 L .21603 .37556 L p .357 .389 .757 r
F P
0 g
s
.22172 .38397 m .21441 .39804 L .22122 .40571 L p .412 .456 .796 r
F P
0 g
s
.27348 .41974 m .26672 .432 L .27701 .43421 L p .643 .746 .924 r
F P
0 g
s
.27701 .43421 m .28365 .42228 L .27348 .41974 L p .643 .746 .924 r
F P
0 g
s
.77421 .27391 m .76102 .28921 L .75653 .28027 L p .403 .363 .699 r
F P
0 g
s
.75653 .28027 m .76949 .26514 L .77421 .27391 L p .403 .363 .699 r
F P
0 g
s
.41575 .23025 m .39333 .22883 L .39352 .22493 L p .55 .798 .991 r
F P
0 g
s
.39352 .22493 m .41705 .22642 L .41575 .23025 L p .55 .798 .991 r
F P
0 g
s
.69398 .2276 m .70388 .21538 L .71361 .21864 L p .64 .715 .902 r
F P
0 g
s
.70388 .21538 m .69398 .2276 L .68468 .22493 L p .666 .757 .918 r
F P
0 g
s
.66313 .4065 m .63859 .41161 L .64034 .41137 L p .17 .704 .72 r
F P
0 g
s
.64034 .41137 m .66645 .40593 L .66313 .4065 L p .17 .704 .72 r
F P
0 g
s
.38885 .3852 m .37875 .38527 L .37962 .38127 L p .565 .119 .149 r
F P
0 g
s
.37962 .38127 m .38889 .38121 L .38885 .3852 L p .565 .119 .149 r
F P
0 g
s
.40268 .38604 m .38885 .3852 L .38889 .38121 L p .608 .154 .149 r
F P
0 g
s
.51371 .23878 m .49067 .23459 L .49326 .2336 L p .193 .679 .927 r
F P
0 g
s
.49326 .2336 m .51638 .2378 L .51371 .23878 L p .193 .679 .927 r
F P
0 g
s
.30141 .23855 m .32189 .23049 L .32672 .23245 L p .621 .895 .987 r
F P
0 g
s
.32189 .23049 m .30141 .23855 L .29525 .23851 L p .551 .914 .955 r
F P
0 g
s
.74477 .36119 m .72524 .37489 L .72808 .36881 L p .072 0 .096 r
F P
0 g
s
.72808 .36881 m .74805 .35478 L .74477 .36119 L p .072 0 .096 r
F P
0 g
s
.6417 .23835 m .64988 .23206 L .65772 .23192 L p .706 .912 .966 r
F P
0 g
s
.64988 .23206 m .6417 .23835 L .63527 .23901 L p .697 .958 .948 r
F P
0 g
s
.71692 .38403 m .69486 .39527 L .6985 .39172 L p 0 0 0 r
F P
0 g
s
.6985 .39172 m .7215 .38 L .71692 .38403 L p 0 0 0 r
F P
0 g
s
.46444 .23282 m .44075 .22919 L .44273 .22674 L p .41 .768 .995 r
F P
0 g
s
.44273 .22674 m .46692 .23045 L .46444 .23282 L p .41 .768 .995 r
F P
0 g
s
.39333 .22883 m .37162 .22904 L .37034 .22516 L p .565 .811 .991 r
F P
0 g
s
.34784 .22755 m .37034 .22516 L .37162 .22904 L p .587 .826 .99 r
F P
0 g
s
.37034 .22516 m .39352 .22493 L .39333 .22883 L p .565 .811 .991 r
F P
0 g
s
.55856 .24474 m .53828 .24162 L .54063 .24198 L p 0 .484 .7 r
F P
0 g
s
.54063 .24198 m .56063 .24505 L .55856 .24474 L p 0 .484 .7 r
F P
0 g
s
.34784 .22755 m .32672 .23245 L .32189 .23049 L p .558 .873 .994 r
F P
0 g
s
.24226 .27282 m .25857 .25873 L .26399 .25449 L p .504 .854 .596 r
F P
0 g
s
.25857 .25873 m .24226 .27282 L .23723 .27853 L p 0 0 0 r
F P
0 g
s
.22122 .40571 m .22846 .3919 L .22172 .38397 L p .412 .456 .796 r
F P
0 g
s
.22846 .3919 m .22122 .40571 L .22899 .41272 L p .459 .514 .827 r
F P
0 g
s
.56336 .41283 m .53879 .41017 L .53671 .40998 L p 0 .519 .712 r
F P
0 g
s
.51212 .40648 m .53671 .40998 L .53879 .41017 L p 0 .511 .724 r
F P
0 g
s
.26347 .41609 m .2566 .42868 L .26672 .432 L p .61 .703 .91 r
F P
0 g
s
.26672 .432 m .27348 .41974 L .26347 .41609 L p .61 .703 .91 r
F P
0 g
s
.51212 .40648 m .48813 .40259 L .48591 .40101 L p .371 0 0 r
F P
0 g
s
.4628 .39711 m .48591 .40101 L .48813 .40259 L p .373 0 0 r
F P
0 g
s
.20614 .34884 m .21581 .33373 L .21509 .32475 L p .092 .02 .474 r
F P
0 g
s
.21581 .33373 m .20614 .34884 L .20818 .35784 L p .194 .148 .575 r
F P
0 g
s
.65772 .23192 m .66664 .22295 L .67552 .22338 L p .712 .855 .95 r
F P
0 g
s
.66664 .22295 m .65772 .23192 L .64988 .23206 L p .733 .907 .955 r
F P
0 g
s
.4628 .39711 m .44102 .39357 L .43936 .39071 L p .562 .021 0 r
F P
0 g
s
.41974 .3879 m .43936 .39071 L .44102 .39357 L p .554 .016 0 r
F P
0 g
s
.31091 .41377 m .30378 .42389 L .3134 .42294 L p .733 .881 .949 r
F P
0 g
s
.3134 .42294 m .32026 .41326 L .31091 .41377 L p .733 .881 .949 r
F P
0 g
s
.77781 .28284 m .76445 .29826 L .76102 .28921 L p .358 .3 .654 r
F P
0 g
s
.76102 .28921 m .77421 .27391 L .77781 .28284 L p .358 .3 .654 r
F P
0 g
s
.36099 .39131 m .35632 .39392 L .36186 .38988 L p 0 0 0 r
F P
0 g
s
.36186 .38988 m .36562 .38777 L .36099 .39131 L p 0 0 0 r
F P
0 g
s
.27015 .25139 m .28953 .23975 L .29525 .23851 L p .582 .944 .883 r
F P
0 g
s
.28953 .23975 m .27015 .25139 L .26399 .25449 L p .438 .856 .704 r
F P
0 g
s
.68468 .22493 m .69414 .21318 L .70388 .21538 L p .666 .757 .918 r
F P
0 g
s
.69414 .21318 m .68468 .22493 L .67552 .22338 L p .694 .803 .932 r
F P
0 g
s
.33604 .4041 m .3291 .41158 L .3373 .40876 L p .745 .975 .924 r
F P
0 g
s
.3373 .40876 m .34378 .40178 L .33604 .4041 L p .745 .975 .924 r
F P
0 g
s
.22899 .41272 m .23615 .39919 L .22846 .3919 L p .459 .514 .827 r
F P
0 g
s
.23615 .39919 m .22899 .41272 L .23757 .41896 L p .501 .566 .854 r
F P
0 g
s
.25381 .41139 m .24683 .42431 L .2566 .42868 L p .576 .659 .894 r
F P
0 g
s
.2566 .42868 m .26347 .41609 L .25381 .41139 L p .576 .659 .894 r
F P
0 g
s
.21747 .3079 m .23035 .2926 L .23324 .28517 L p 0 0 .04 r
F P
0 g
s
.23035 .2926 m .21747 .3079 L .21565 .31609 L p 0 0 .245 r
F P
0 g
s
.23757 .41896 m .24465 .40573 L .23615 .39919 L p .501 .566 .854 r
F P
0 g
s
.24465 .40573 m .23757 .41896 L .24683 .42431 L p .54 .614 .876 r
F P
0 g
s
.24683 .42431 m .25381 .41139 L .24465 .40573 L p .54 .614 .876 r
F P
0 g
s
.53828 .24162 m .51638 .2378 L .51883 .23817 L p 0 .48 .709 r
F P
0 g
s
.51883 .23817 m .54063 .24198 L .53828 .24162 L p 0 .48 .709 r
F P
0 g
s
.76665 .33257 m .75027 .34758 L .75139 .3397 L p .159 0 .349 r
F P
0 g
s
.75139 .3397 m .76788 .32455 L .76665 .33257 L p .159 0 .349 r
F P
0 g
s
.49067 .23459 m .46692 .23045 L .46925 .22941 L p .194 .681 .926 r
F P
0 g
s
.46925 .22941 m .49326 .2336 L .49067 .23459 L p .194 .681 .926 r
F P
0 g
s
.44075 .22919 m .41705 .22642 L .41828 .22388 L p .418 .779 .995 r
F P
0 g
s
.41828 .22388 m .44273 .22674 L .44075 .22919 L p .418 .779 .995 r
F P
0 g
s
.35002 .39683 m .34378 .40178 L .35077 .39833 L p .611 .952 .809 r
F P
0 g
s
.35077 .39833 m .35632 .39392 L .35002 .39683 L p .611 .952 .809 r
F P
0 g
s
.44102 .39357 m .42103 .39071 L .41974 .3879 L p .554 .016 0 r
F P
0 g
s
.40268 .38604 m .41974 .3879 L .42103 .39071 L p .538 .005 0 r
F P
0 g
s
.36514 .38979 m .36099 .39131 L .36562 .38777 L p .051 0 0 r
F P
0 g
s
.36562 .38777 m .36859 .38668 L .36514 .38979 L p .051 0 0 r
F P
0 g
s
.61295 .41278 m .58902 .413 L .58822 .41429 L p .273 .757 .923 r
F P
0 g
s
.58822 .41429 m .61337 .41406 L .61295 .41278 L p .273 .757 .923 r
F P
0 g
s
.56336 .41283 m .58822 .41429 L .58902 .413 L p .245 .731 .926 r
F P
0 g
s
.53879 .41017 m .5145 .40671 L .51212 .40648 L p 0 .511 .724 r
F P
0 g
s
.48813 .40259 m .51212 .40648 L .5145 .40671 L p 0 .507 .732 r
F P
0 g
s
.63663 .41048 m .61295 .41278 L .61337 .41406 L p .325 .796 .923 r
F P
0 g
s
.61337 .41406 m .63859 .41161 L .63663 .41048 L p .325 .796 .923 r
F P
0 g
s
.20818 .35784 m .2178 .34289 L .21581 .33373 L p .194 .148 .575 r
F P
0 g
s
.2178 .34289 m .20818 .35784 L .21149 .36679 L p .275 .25 .65 r
F P
0 g
s
.46495 .39868 m .4628 .39711 L p .48573 .40207 L .373 0 0 r
F P
0 g
s
.44102 .39357 m .4628 .39711 L .46495 .39868 L p .371 0 0 r
F P
0 g
s
.44294 .39511 m .44102 .39357 L p .45934 .39748 L .371 0 0 r
F P
0 g
s
.46495 .39868 m .44294 .39511 L p .45934 .39748 L .371 0 0 r
F P
0 g
s
.42103 .39071 m .44102 .39357 L .44294 .39511 L p .365 0 0 r
F P
0 g
s
.42254 .3922 m .42103 .39071 L p .43571 .39366 L .365 0 0 r
F P
0 g
s
.44294 .39511 m .42254 .3922 L p .43571 .39366 L .365 0 0 r
F P
0 g
s
.40343 .38879 m .42103 .39071 L .42254 .3922 L p .352 0 0 r
F P
0 g
s
.40433 .39021 m .40343 .38879 L p .41501 .39086 L .352 0 0 r
F P
0 g
s
.42254 .3922 m .40433 .39021 L p .41501 .39086 L .352 0 0 r
F P
0 g
s
.38885 .38791 m .40343 .38879 L .40433 .39021 L p .325 0 0 r
F P
0 g
s
.40433 .39021 m .38889 .38929 L .38885 .38791 L p .325 0 0 r
F P
0 g
s
.40433 .39021 m .40537 .39027 L p .3953 .38967 L 0 .543 .708 r
F P
0 g
s
.38889 .38929 m .40433 .39021 L p .3953 .38967 L 0 .543 .708 r
F P
0 g
s
.42254 .3922 m .42426 .39233 L p .41104 .39092 L 0 .522 .716 r
F P
0 g
s
.40433 .39021 m .42254 .3922 L p .41104 .39092 L 0 .522 .716 r
F P
0 g
s
.44294 .39511 m .44509 .3953 L p .42812 .39297 L 0 .512 .725 r
F P
0 g
s
.42254 .3922 m .44294 .39511 L p .42812 .39297 L 0 .512 .725 r
F P
0 g
s
.46495 .39868 m .46736 .39891 L p .44547 .39551 L 0 .507 .732 r
F P
0 g
s
.44294 .39511 m .46495 .39868 L p .44547 .39551 L 0 .507 .732 r
F P
0 g
s
.48813 .40259 m .46495 .39868 L p .48573 .40207 L .373 0 0 r
F P
0 g
s
.66645 .40593 m .6906 .3976 L .68578 .39868 L p .326 .809 .778 r
F P
0 g
s
.37034 .22516 m .34784 .22755 L .34486 .22515 L p .5 .844 .996 r
F P
0 g
s
.32189 .23049 m .34486 .22515 L .34784 .22755 L p .558 .873 .994 r
F P
0 g
s
.60473 .24798 m .59316 .24807 L .59387 .24965 L p .315 0 0 r
F P
0 g
s
.59316 .24807 m .57831 .24712 L .57973 .24874 L p .358 0 0 r
F P
0 g
s
.57973 .24874 m .59387 .24965 L .59316 .24807 L p .358 0 0 r
F P
0 g
s
.37017 .38872 m .36514 .38979 L .36859 .38668 L p .257 0 0 r
F P
0 g
s
.36859 .38668 m .37235 .38588 L .37017 .38872 L p .257 0 0 r
F P
0 g
s
.61303 .24714 m .60473 .24798 L .60446 .24957 L p .24 0 0 r
F P
0 g
s
.59387 .24965 m .60446 .24957 L .60473 .24798 L p .315 0 0 r
F P
0 g
s
.30121 .41309 m .29381 .42367 L .30378 .42389 L p .704 .835 .945 r
F P
0 g
s
.30378 .42389 m .31091 .41377 L .30121 .41309 L p .704 .835 .945 r
F P
0 g
s
.78024 .29178 m .76676 .30726 L .76445 .29826 L p .305 .225 .598 r
F P
0 g
s
.76445 .29826 m .77781 .28284 L .78024 .29178 L p .305 .225 .598 r
F P
0 g
s
.67552 .22338 m .68456 .21209 L .69414 .21318 L p .694 .803 .932 r
F P
0 g
s
.68456 .21209 m .67552 .22338 L .66664 .22295 L p .722 .85 .943 r
F P
0 g
s
.58902 .413 m .56504 .41159 L .56336 .41283 L p .245 .731 .926 r
F P
0 g
s
.53879 .41017 m .56336 .41283 L .56504 .41159 L p .231 .714 .931 r
F P
0 g
s
.42103 .39071 m .40343 .38879 L .40268 .38604 L p .538 .005 0 r
F P
0 g
s
.38885 .3852 m .40268 .38604 L .40343 .38879 L p .509 0 0 r
F P
0 g
s
.74048 .3667 m .7215 .38 L .72524 .37489 L p 0 0 0 r
F P
0 g
s
.72524 .37489 m .74477 .36119 L .74048 .3667 L p 0 0 0 r
F P
0 g
s
.63527 .23901 m .64257 .23338 L .64988 .23206 L p .697 .958 .948 r
F P
0 g
s
.64988 .23206 m .65819 .22368 L .66664 .22295 L p .733 .907 .955 r
F P
0 g
s
.65819 .22368 m .64988 .23206 L .64257 .23338 L p .744 .956 .942 r
F P
0 g
s
.37777 .38799 m .37017 .38872 L .37235 .38588 L p .385 0 0 r
F P
0 g
s
.37235 .38588 m .37875 .38527 L .37777 .38799 L p .385 0 0 r
F P
0 g
s
.61888 .24584 m .61303 .24714 L .61151 .24886 L p .112 0 0 r
F P
0 g
s
.60446 .24957 m .61151 .24886 L .61303 .24714 L p .24 0 0 r
F P
0 g
s
.57831 .24712 m .56063 .24505 L .5625 .24672 L p .381 0 0 r
F P
0 g
s
.5625 .24672 m .57973 .24874 L .57831 .24712 L p .381 0 0 r
F P
0 g
s
.41705 .22642 m .39352 .22493 L .39368 .22233 L p .433 .794 .996 r
F P
0 g
s
.39368 .22233 m .41828 .22388 L .41705 .22642 L p .433 .794 .996 r
F P
0 g
s
.29525 .23851 m .3173 .22983 L .32189 .23049 L p .551 .914 .955 r
F P
0 g
s
.3173 .22983 m .29525 .23851 L .28953 .23975 L p .407 .859 .826 r
F P
0 g
s
.23723 .27853 m .25401 .26406 L .25857 .25873 L p 0 0 0 r
F P
0 g
s
.25401 .26406 m .23723 .27853 L .23324 .28517 L p 0 0 0 r
F P
0 g
s
.38885 .38791 m .37777 .38799 L .37875 .38527 L p .462 0 0 r
F P
0 g
s
.37875 .38527 m .38885 .3852 L .38885 .38791 L p .462 0 0 r
F P
0 g
s
.40343 .38879 m .38885 .38791 L .38885 .3852 L p .509 0 0 r
F P
0 g
s
.71158 .38692 m .6906 .3976 L .69486 .39527 L p 0 0 0 r
F P
0 g
s
.69486 .39527 m .71692 .38403 L .71158 .38692 L p 0 0 0 r
F P
0 g
s
.65946 .40572 m .63663 .41048 L .63859 .41161 L p .405 .847 .931 r
F P
0 g
s
.63859 .41161 m .66313 .4065 L .65946 .40572 L p .405 .847 .931 r
F P
0 g
s
.32768 .40523 m .32026 .41326 L .3291 .41158 L p .738 .935 .952 r
F P
0 g
s
.3291 .41158 m .33604 .4041 L .32768 .40523 L p .738 .935 .952 r
F P
0 g
s
.75151 .21971 m .74129 .23422 L .73246 .22814 L p .551 .593 .849 r
F P
0 g
s
.73246 .22814 m .74242 .21388 L .75151 .21971 L p .551 .593 .849 r
F P
0 g
s
.74242 .21388 m .73246 .22814 L .72319 .22292 L p .58 .634 .869 r
F P
0 g
s
.76 .22632 m .74952 .24108 L .74129 .23422 L p .521 .551 .827 r
F P
0 g
s
.74129 .23422 m .75151 .21971 L .76 .22632 L p .521 .551 .827 r
F P
0 g
s
.51638 .2378 m .49326 .2336 L .49564 .23396 L p 0 .479 .711 r
F P
0 g
s
.49564 .23396 m .51883 .23817 L .51638 .2378 L p 0 .479 .711 r
F P
0 g
s
.21565 .31609 m .22862 .30073 L .23035 .2926 L p 0 0 .245 r
F P
0 g
s
.22862 .30073 m .21565 .31609 L .21509 .32475 L p .112 0 .397 r
F P
0 g
s
.61151 .24886 m .61599 .24788 L .61888 .24584 L p .112 0 0 r
F P
0 g
s
.39352 .22493 m .37034 .22516 L .36908 .22257 L p .459 .816 .996 r
F P
0 g
s
.34486 .22515 m .36908 .22257 L .37034 .22516 L p .5 .844 .996 r
F P
0 g
s
.34486 .22515 m .32189 .23049 L .3173 .22983 L p .435 .861 .94 r
F P
0 g
s
.46692 .23045 m .44273 .22674 L .44459 .22563 L p .197 .687 .924 r
F P
0 g
s
.44459 .22563 m .46925 .22941 L .46692 .23045 L p .197 .687 .924 r
F P
0 g
s
.72319 .22292 m .73288 .20895 L .74242 .21388 L p .58 .634 .869 r
F P
0 g
s
.73288 .20895 m .72319 .22292 L .71361 .21864 L p .609 .674 .887 r
F P
0 g
s
.36908 .22257 m .39368 .22233 L .39352 .22493 L p .459 .816 .996 r
F P
0 g
s
.76776 .23363 m .75705 .24859 L .74952 .24108 L p .489 .507 .803 r
F P
0 g
s
.74952 .24108 m .76 .22632 L .76776 .23363 L p .489 .507 .803 r
F P
0 g
s
.56063 .24505 m .54063 .24198 L .54276 .24369 L p .392 0 0 r
F P
0 g
s
.54276 .24369 m .5625 .24672 L .56063 .24505 L p .392 0 0 r
F P
0 g
s
.21149 .36679 m .22104 .35206 L .2178 .34289 L p .275 .25 .65 r
F P
0 g
s
.22104 .35206 m .21149 .36679 L .21603 .37556 L p .34 .334 .707 r
F P
0 g
s
.35573 .39364 m .35002 .39683 L .35632 .39392 L p .421 .85 .716 r
F P
0 g
s
.35632 .39392 m .36099 .39131 L .35573 .39364 L p .421 .85 .716 r
F P
0 g
s
.26399 .25449 m .28435 .24225 L .28953 .23975 L p .438 .856 .704 r
F P
0 g
s
.28435 .24225 m .26399 .25449 L .25857 .25873 L p 0 0 0 r
F P
0 g
s
.5145 .40671 m .49061 .40284 L .48813 .40259 L p 0 .507 .732 r
F P
0 g
s
.46495 .39868 m .48813 .40259 L .49061 .40284 L p 0 .506 .734 r
F P
0 g
s
.56504 .41159 m .54104 .40899 L .53879 .41017 L p .231 .714 .931 r
F P
0 g
s
.5145 .40671 m .53879 .41017 L .54104 .40899 L p .224 .704 .935 r
F P
0 g
s
.76424 .33998 m .74805 .35478 L .75027 .34758 L p .041 0 .197 r
F P
0 g
s
.75027 .34758 m .76665 .33257 L .76424 .33998 L p .041 0 .197 r
F P
0 g
s
.29133 .41122 m .28365 .42228 L .29381 .42367 L p .674 .79 .936 r
F P
0 g
s
.29381 .42367 m .30121 .41309 L .29133 .41122 L p .674 .79 .936 r
F P
0 g
s
.71361 .21864 m .72302 .20497 L .73288 .20895 L p .609 .674 .887 r
F P
0 g
s
.72302 .20497 m .71361 .21864 L .70388 .21538 L p .638 .715 .903 r
F P
0 g
s
.61599 .24788 m .61969 .24649 L .62388 .24398 L p 0 0 0 r
F P
0 g
s
.77466 .24151 m .76374 .25665 L .75705 .24859 L p .454 .46 .775 r
F P
0 g
s
.75705 .24859 m .76776 .23363 L .77466 .24151 L p .454 .46 .775 r
F P
0 g
s
.34305 .39853 m .33604 .4041 L .34378 .40178 L p .678 .97 .918 r
F P
0 g
s
.34378 .40178 m .35002 .39683 L .34305 .39853 L p .678 .97 .918 r
F P
0 g
s
.78146 .30059 m .76791 .31607 L .76676 .30726 L p .238 .133 .526 r
F P
0 g
s
.76676 .30726 m .78024 .29178 L .78146 .30059 L p .238 .133 .526 r
F P
0 g
s
.66664 .22295 m .67527 .21212 L .68456 .21209 L p .722 .85 .943 r
F P
0 g
s
.67527 .21212 m .66664 .22295 L .65819 .22368 L p .749 .9 .946 r
F P
0 g
s
.70388 .21538 m .71301 .20201 L .72302 .20497 L p .638 .715 .903 r
F P
0 g
s
.71301 .20201 m .70388 .21538 L .69414 .21318 L p .667 .757 .918 r
F P
0 g
s
.36122 .39163 m .35573 .39364 L .36099 .39131 L p 0 0 0 r
F P
0 g
s
.36099 .39131 m .36514 .38979 L .36122 .39163 L p 0 0 0 r
F P
0 g
s
.21603 .37556 m .22546 .36109 L .22104 .35206 L p .34 .334 .707 r
F P
0 g
s
.22546 .36109 m .21603 .37556 L .22172 .38397 L p .394 .404 .752 r
F P
0 g
s
.54063 .24198 m .51883 .23817 L .52104 .2399 L p .398 0 0 r
F P
0 g
s
.52104 .2399 m .54276 .24369 L .54063 .24198 L p .398 0 0 r
F P
0 g
s
.44273 .22674 m .41828 .22388 L .41942 .22268 L p .207 .7 .921 r
F P
0 g
s
.41942 .22268 m .44459 .22563 L .44273 .22674 L p .207 .7 .921 r
F P
0 g
s
.49326 .2336 m .46925 .22941 L .47139 .22972 L p 0 .48 .709 r
F P
0 g
s
.47139 .22972 m .49564 .23396 L .49326 .2336 L p 0 .48 .709 r
F P
0 g
s
.78059 .24985 m .76949 .26514 L .76374 .25665 L p .415 .407 .742 r
F P
0 g
s
.76374 .25665 m .77466 .24151 L .78059 .24985 L p .415 .407 .742 r
F P
0 g
s
.64257 .23338 m .65031 .22555 L .65819 .22368 L p .744 .956 .942 r
F P
0 g
s
.65031 .22555 m .64257 .23338 L .63589 .23587 L p .733 .987 .891 r
F P
0 g
s
.28144 .4082 m .27348 .41974 L .28365 .42228 L p .644 .746 .923 r
F P
0 g
s
.28365 .42228 m .29133 .41122 L .28144 .4082 L p .644 .746 .923 r
F P
0 g
s
.31885 .40515 m .31091 .41377 L .32026 .41326 L p .719 .887 .958 r
F P
0 g
s
.32026 .41326 m .32768 .40523 L .31885 .40515 L p .719 .887 .958 r
F P
0 g
s
.21509 .32475 m .22808 .30942 L .22862 .30073 L p .112 0 .397 r
F P
0 g
s
.22808 .30942 m .21509 .32475 L .21581 .33373 L p .211 .105 .508 r
F P
0 g
s
.61247 .41014 m .58984 .41034 L .58902 .413 L p .466 .817 .997 r
F P
0 g
s
.58902 .413 m .61295 .41278 L .61247 .41014 L p .466 .817 .997 r
F P
0 g
s
.56504 .41159 m .58902 .413 L .58984 .41034 L p .447 .798 .998 r
F P
0 g
s
.23324 .28517 m .25037 .27041 L .25401 .26406 L p 0 0 0 r
F P
0 g
s
.25037 .27041 m .23324 .28517 L .23035 .2926 L p .051 0 .172 r
F P
0 g
s
.54104 .40899 m .51708 .40558 L .5145 .40671 L p .224 .704 .935 r
F P
0 g
s
.49061 .40284 m .5145 .40671 L .51708 .40558 L p .221 .698 .937 r
F P
0 g
s
.73523 .37121 m .71692 .38403 L .7215 .38 L p 0 0 0 r
F P
0 g
s
.7215 .38 m .74048 .3667 L .73524 .3712 L p 0 0 0 r
F P
0 g
s
.7215 .38 m .73524 .3712 L .73521 .37122 L 0 0 0 r
F
.72911 .37463 m .71158 .38692 L .71691 .38404 L p .498 .885 .709 r
F P
0 g
s
.71691 .38404 m .71692 .38403 L p .71694 .38402 L .498 .885 .709 r
F P
0 g
s
.71694 .38402 m .72911 .37463 L .71691 .38404 L .498 .885 .709 r
F
.73524 .3712 m .73523 .37121 L p .73521 .37122 L 0 0 0 r
F P
0 g
s
.6345 .408 m .61247 .41014 L .61295 .41278 L p .498 .84 .997 r
F P
0 g
s
.61295 .41278 m .63663 .41048 L .6345 .408 L p .498 .84 .997 r
F P
0 g
s
.68048 .39846 m .65946 .40572 L .66313 .4065 L p .505 .898 .945 r
F P
0 g
s
.66313 .4065 m .68578 .39868 L .68048 .39846 L p .505 .898 .945 r
F P
0 g
s
.36772 .39024 m .36122 .39163 L .36514 .38979 L p .041 0 0 r
F P
0 g
s
.36514 .38979 m .37017 .38872 L .36772 .39024 L p .041 0 0 r
F P
0 g
s
.49061 .40284 m .46736 .39891 L .46495 .39868 L p 0 .506 .734 r
F P
0 g
s
.36908 .22257 m .34486 .22515 L .342 .22408 L p .335 .802 .925 r
F P
0 g
s
.3173 .22983 m .342 .22408 L .34486 .22515 L p .435 .861 .94 r
F P
0 g
s
.60446 .24957 m .59387 .24965 L .59452 .25259 L p .487 0 0 r
F P
0 g
s
.59387 .24965 m .57973 .24874 L .58098 .25172 L p .53 .014 0 r
F P
0 g
s
.58098 .25172 m .59452 .25259 L .59387 .24965 L p .53 .014 0 r
F P
0 g
s
.61151 .24886 m .60446 .24957 L .60427 .25252 L p .419 0 0 r
F P
0 g
s
.59452 .25259 m .60427 .25252 L .60446 .24957 L p .487 0 0 r
F P
0 g
s
.28953 .23975 m .31303 .23049 L .3173 .22983 L p .407 .859 .826 r
F P
0 g
s
.31303 .23049 m .28953 .23975 L .28435 .24225 L p 0 0 0 r
F P
0 g
s
.69414 .21318 m .703 .20013 L .71301 .20201 L p .667 .757 .918 r
F P
0 g
s
.703 .20013 m .69414 .21318 L .68456 .21209 L p .697 .801 .93 r
F P
0 g
s
.22172 .38397 m .23101 .36983 L .22546 .36109 L p .394 .404 .752 r
F P
0 g
s
.23101 .36983 m .22172 .38397 L .22846 .3919 L p .44 .465 .789 r
F P
0 g
s
.58984 .41034 m .56679 .40899 L .56504 .41159 L p .447 .798 .998 r
F P
0 g
s
.54104 .40899 m .56504 .41159 L .56679 .40899 L p .436 .785 .997 r
F P
0 g
s
.37668 .38938 m .36772 .39024 L .37017 .38872 L p .188 0 0 r
F P
0 g
s
.37017 .38872 m .37777 .38799 L .37668 .38938 L p .188 0 0 r
F P
0 g
s
.70555 .3886 m .68578 .39868 L .6906 .3976 L p .491 .903 .841 r
F P
0 g
s
.6906 .3976 m .71158 .38692 L .70555 .3886 L p .491 .903 .841 r
F P
0 g
s
.61599 .24788 m .61151 .24886 L .61025 .25192 L p .31 0 0 r
F P
0 g
s
.60427 .25252 m .61025 .25192 L .61151 .24886 L p .419 0 0 r
F P
0 g
s
.2717 .40407 m .26347 .41609 L .27348 .41974 L p .614 .702 .908 r
F P
0 g
s
.27348 .41974 m .28144 .4082 L .2717 .40407 L p .614 .702 .908 r
F P
0 g
s
.78546 .25852 m .77421 .27391 L .76949 .26514 L p .371 .347 .703 r
F P
0 g
s
.76949 .26514 m .78059 .24985 L .78546 .25852 L p .371 .347 .703 r
F P
0 g
s
.57973 .24874 m .5625 .24672 L .56414 .24974 L p .557 .031 0 r
F P
0 g
s
.56414 .24974 m .58098 .25172 L .57973 .24874 L p .557 .031 0 r
F P
0 g
s
.78142 .30913 m .76788 .32455 L .76791 .31607 L p .153 .018 .431 r
F P
0 g
s
.76791 .31607 m .78146 .30059 L .78142 .30913 L p .153 .018 .431 r
F P
0 g
s
.41828 .22388 m .39368 .22233 L .3938 .22106 L p .227 .721 .918 r
F P
0 g
s
.39383 .22107 m .41828 .22388 L .3938 .22106 L .227 .721 .918 r
F
.3938 .22106 m .41942 .22268 L .41828 .22388 L p F P
0 g
s
.39388 .22118 m .42044 .22286 L .41942 .22269 L p .069 0 0 r
F P
0 g
s
.41942 .22269 m .41942 .22268 L p .41939 .22268 L .069 0 0 r
F P
0 g
s
.39388 .22118 m .41942 .22269 L .41939 .22268 L .069 0 0 r
F
.3938 .22106 m .3938 .22106 L p .39383 .22107 L .227 .721 .918 r
F P
0 g
s
.65819 .22368 m .66643 .21329 L .67527 .21212 L p .749 .9 .946 r
F P
0 g
s
.66643 .21329 m .65819 .22368 L .65031 .22555 L p .771 .949 .934 r
F P
0 g
s
.76068 .34667 m .74477 .36119 L .74805 .35478 L p 0 0 0 r
F P
0 g
s
.74805 .35478 m .76424 .33998 L .76068 .34667 L p 0 0 0 r
F P
0 g
s
.38889 .38929 m .37668 .38938 L .37777 .38799 L p .276 0 0 r
F P
0 g
s
.37777 .38799 m .38885 .38791 L .38889 .38929 L p .276 0 0 r
F P
0 g
s
.34991 .39471 m .34305 .39853 L .35002 .39683 L p .563 .936 .893 r
F P
0 g
s
.35002 .39683 m .35573 .39364 L .34991 .39471 L p .563 .936 .893 r
F P
0 g
s
.25857 .25873 m .27978 .246 L .28435 .24225 L p 0 0 0 r
F P
0 g
s
.27978 .246 m .25857 .25873 L .25401 .26406 L p 0 0 0 r
F P
0 g
s
.6555 .40362 m .6345 .408 L .63663 .41048 L p .543 .866 .995 r
F P
0 g
s
.63663 .41048 m .65946 .40572 L .6555 .40362 L p .543 .866 .995 r
F P
0 g
s
.61969 .24649 m .61599 .24788 L .61354 .25121 L p .134 0 0 r
F P
0 g
s
.61025 .25192 m .61354 .25121 L .61599 .24788 L p .31 0 0 r
F P
0 g
s
.51883 .23817 m .49564 .23396 L .49778 .23568 L p .399 0 0 r
F P
0 g
s
.49778 .23568 m .52104 .2399 L .51883 .23817 L p .399 0 0 r
F P
0 g
s
.33552 .399 m .32768 .40523 L .33604 .4041 L p .699 .941 .961 r
F P
0 g
s
.33604 .4041 m .34305 .39853 L .33552 .399 L p .699 .941 .961 r
F P
0 g
s
.342 .22408 m .3173 .22983 L .31303 .23049 L p .221 .741 .754 r
F P
0 g
s
.22846 .3919 m .23759 .37811 L .23101 .36983 L p .44 .465 .789 r
F P
0 g
s
.23759 .37811 m .22846 .3919 L .23615 .39919 L p .48 .519 .82 r
F P
0 g
s
.39368 .22233 m .36908 .22257 L .36785 .22132 L p .267 .754 .918 r
F P
0 g
s
.342 .22408 m .36785 .22132 L .36908 .22257 L p .335 .802 .925 r
F P
0 g
s
.46925 .22941 m .44459 .22563 L .44628 .22587 L p 0 .485 .701 r
F P
0 g
s
.44628 .22587 m .47139 .22972 L .46925 .22941 L p 0 .485 .701 r
F P
0 g
s
.26229 .3989 m .25381 .41139 L .26347 .41609 L p .583 .659 .89 r
F P
0 g
s
.26347 .41609 m .2717 .40407 L .26229 .3989 L p .583 .659 .89 r
F P
0 g
s
.36785 .22132 m .3938 .22106 L .39368 .22233 L p .267 .754 .918 r
F P
0 g
s
.5625 .24672 m .54276 .24369 L .54462 .24675 L p .572 .041 0 r
F P
0 g
s
.54462 .24675 m .56414 .24974 L .5625 .24672 L p .572 .041 0 r
F P
0 g
s
.30968 .40385 m .30121 .41309 L .31091 .41377 L p .696 .838 .951 r
F P
0 g
s
.31091 .41377 m .31885 .40515 L .30968 .40385 L p .696 .838 .951 r
F P
0 g
s
.62418 .24397 m .61969 .24649 L .61612 .25023 L p 0 0 0 r
F P
0 g
s
.61354 .25121 m .61612 .25023 L .61969 .24649 L p .134 0 0 r
F P
0 g
s
.51708 .40558 m .49332 .40172 L .49061 .40284 L p .221 .698 .937 r
F P
0 g
s
.46736 .39891 m .49061 .40284 L .49332 .40172 L p .221 .696 .938 r
F P
0 g
s
.21581 .33373 m .22876 .31851 L .22808 .30942 L p .211 .105 .508 r
F P
0 g
s
.22876 .31851 m .21581 .33373 L .2178 .34289 L p .288 .209 .591 r
F P
0 g
s
.23615 .39919 m .24508 .38581 L .23759 .37811 L p .48 .519 .82 r
F P
0 g
s
.24508 .38581 m .23615 .39919 L .24465 .40573 L p .517 .568 .846 r
F P
0 g
s
.56679 .40899 m .54342 .40645 L .54104 .40899 L p .436 .785 .997 r
F P
0 g
s
.51708 .40558 m .54104 .40899 L .54342 .40645 L p .43 .777 .997 r
F P
0 g
s
.46736 .39891 m .44509 .3953 L .44294 .39511 L p 0 .507 .732 r
F P
0 g
s
.25336 .39278 m .24465 .40573 L .25381 .41139 L p .551 .615 .869 r
F P
0 g
s
.25381 .41139 m .26229 .3989 L .25336 .39278 L p .551 .615 .869 r
F P
0 g
s
.68456 .21209 m .69314 .19935 L .703 .20013 L p .697 .801 .93 r
F P
0 g
s
.69314 .19935 m .68456 .21209 L .67527 .21212 L p .727 .847 .937 r
F P
0 g
s
.24465 .40573 m .25336 .39278 L .24508 .38581 L p .517 .568 .846 r
F P
0 g
s
.78918 .26737 m .77781 .28284 L .77421 .27391 L p .319 .278 .654 r
F P
0 g
s
.77421 .27391 m .78546 .25852 L .78918 .26737 L p .319 .278 .654 r
F P
0 g
s
.63589 .23587 m .64311 .22855 L .65031 .22555 L p .733 .987 .891 r
F P
0 g
s
.23035 .2926 m .24773 .27766 L .25037 .27041 L p .051 0 .172 r
F P
0 g
s
.24773 .27766 m .23035 .2926 L .22862 .30073 L p .174 0 .333 r
F P
0 g
s
.3569 .39215 m .34991 .39471 L .35573 .39364 L p .397 .854 .838 r
F P
0 g
s
.35573 .39364 m .36122 .39163 L .3569 .39215 L p .397 .854 .838 r
F P
0 g
s
.71692 .38403 m .73523 .37121 L .72911 .37463 L p .498 .885 .709 r
F P
0 g
s
.61612 .25023 m .61973 .24821 L .62418 .24397 L p 0 0 0 r
F P
0 g
s
.54276 .24369 m .52104 .2399 L .52297 .24297 L p .58 .045 0 r
F P
0 g
s
.52297 .24297 m .54462 .24675 L .54276 .24369 L p .58 .045 0 r
F P
0 g
s
.78013 .31725 m .76665 .33257 L .76788 .32455 L p .041 0 .3 r
F P
0 g
s
.76788 .32455 m .78142 .30913 L .78013 .31725 L p .041 0 .3 r
F P
0 g
s
.49564 .23396 m .47139 .22972 L .4733 .23141 L p .398 0 0 r
F P
0 g
s
.4733 .23141 m .49778 .23568 L .49564 .23396 L p .398 0 0 r
F P
0 g
s
.44459 .22563 m .41942 .22268 L .42044 .22286 L p .094 0 0 r
F P
0 g
s
.42044 .22286 m .44628 .22587 L .44459 .22563 L p .094 0 0 r
F P
0 g
s
.65031 .22555 m .65819 .21558 L .66643 .21329 L p .771 .949 .934 r
F P
0 g
s
.65819 .21558 m .65031 .22555 L .64311 .22855 L p .78 .987 .896 r
F P
0 g
s
.44509 .3953 m .42426 .39233 L .42254 .3922 L p 0 .512 .725 r
F P
0 g
s
.61193 .40616 m .59066 .40635 L .58984 .41034 L p .571 .809 .989 r
F P
0 g
s
.58984 .41034 m .61247 .41014 L .61193 .40616 L p .571 .809 .989 r
F P
0 g
s
.56679 .40899 m .58984 .41034 L .59066 .40635 L p .56 .798 .988 r
F P
0 g
s
.67479 .39695 m .6555 .40362 L .65946 .40572 L p .597 .888 .991 r
F P
0 g
s
.65946 .40572 m .68048 .39846 L .67479 .39695 L p .597 .888 .991 r
F P
0 g
s
.54342 .40645 m .51982 .40308 L .51708 .40558 L p .43 .777 .997 r
F P
0 g
s
.49332 .40172 m .51708 .40558 L .51982 .40308 L p .427 .772 .997 r
F P
0 g
s
.63224 .40419 m .61193 .40616 L .61247 .41014 L p .587 .821 .988 r
F P
0 g
s
.61247 .41014 m .6345 .408 L .63224 .40419 L p .587 .821 .988 r
F P
0 g
s
.30034 .40135 m .29133 .41122 L .30121 .41309 L p .671 .791 .938 r
F P
0 g
s
.30121 .41309 m .30968 .40385 L .30034 .40135 L p .671 .791 .938 r
F P
0 g
s
.36503 .39041 m .3569 .39215 L .36122 .39163 L p .223 .744 .771 r
F P
0 g
s
.36122 .39163 m .36772 .39024 L .36503 .39041 L p .223 .744 .771 r
F P
0 g
s
.2178 .34289 m .23065 .32786 L .22876 .31851 L p .288 .209 .591 r
F P
0 g
s
.23065 .32786 m .2178 .34289 L .22104 .35206 L p .348 .294 .654 r
F P
0 g
s
.75602 .35252 m .74048 .3667 L .74477 .36119 L p 0 0 0 r
F P
0 g
s
.74477 .36119 m .76068 .34667 L .75602 .35252 L p 0 0 0 r
F P
0 g
s
.67527 .21212 m .6836 .19969 L .69314 .19935 L p .727 .847 .937 r
F P
0 g
s
.6836 .19969 m .67527 .21212 L .66643 .21329 L p .758 .894 .939 r
F P
0 g
s
.32756 .39821 m .31885 .40515 L .32768 .40523 L p .696 .893 .969 r
F P
0 g
s
.32768 .40523 m .33552 .399 L .32756 .39821 L p .696 .893 .969 r
F P
0 g
s
.28435 .24225 m .30914 .23249 L .31303 .23049 L p 0 0 0 r
F P
0 g
s
.30914 .23249 m .28435 .24225 L .27978 .246 L p .047 0 0 r
F P
0 g
s
.49332 .40172 m .46999 .39778 L .46736 .39891 L p .221 .696 .938 r
F P
0 g
s
.44509 .3953 m .46736 .39891 L .46999 .39778 L p .222 .698 .937 r
F P
0 g
s
.31303 .23049 m .33933 .22438 L .342 .22408 L p .221 .741 .754 r
F P
0 g
s
.36785 .22132 m .342 .22408 L .33933 .22438 L p 0 0 0 r
F P
0 g
s
.69893 .38905 m .68048 .39846 L .68578 .39868 L p .601 .933 .956 r
F P
0 g
s
.68578 .39868 m .70555 .3886 L .69893 .38905 L p .601 .933 .956 r
F P
0 g
s
.60427 .25252 m .59452 .25259 L .59511 .25685 L p .58 .148 .185 r
F P
0 g
s
.59452 .25259 m .58098 .25172 L .58206 .25601 L p .62 .178 .177 r
F P
0 g
s
.58206 .25601 m .59511 .25685 L .59452 .25259 L p .62 .178 .177 r
F P
0 g
s
.61025 .25192 m .60427 .25252 L .60416 .25679 L p .52 .1 .184 r
F P
0 g
s
.59511 .25685 m .60416 .25679 L .60427 .25252 L p .58 .148 .185 r
F P
0 g
s
.34363 .39448 m .33552 .399 L .34305 .39853 L p .634 .934 .966 r
F P
0 g
s
.34305 .39853 m .34991 .39471 L .34363 .39448 L p .634 .934 .966 r
F P
0 g
s
.25401 .26406 m .27593 .25092 L .27978 .246 L p 0 0 0 r
F P
0 g
s
.27593 .25092 m .25401 .26406 L .25037 .27041 L p .142 0 .105 r
F P
0 g
s
.7917 .27628 m .78024 .29178 L .77781 .28284 L p .255 .194 .593 r
F P
0 g
s
.77781 .28284 m .78918 .26737 L .7917 .27628 L p .255 .194 .593 r
F P
0 g
s
.76083 .20489 m .75151 .21971 L .74242 .21388 L p .545 .593 .853 r
F P
0 g
s
.74242 .21388 m .75158 .19921 L .76083 .20489 L p .545 .593 .853 r
F P
0 g
s
.75158 .19921 m .74242 .21388 L .73288 .20895 L p .576 .634 .872 r
F P
0 g
s
.59066 .40635 m .56861 .40505 L .56679 .40899 L p .56 .798 .988 r
F P
0 g
s
.54342 .40645 m .56679 .40899 L .56861 .40505 L p .553 .791 .987 r
F P
0 g
s
.73288 .20895 m .74186 .19442 L .75158 .19921 L p .576 .634 .872 r
F P
0 g
s
.74186 .19442 m .73288 .20895 L .72302 .20497 L p .607 .675 .889 r
F P
0 g
s
.76947 .21139 m .76 .22632 L .75151 .21971 L p .513 .55 .832 r
F P
0 g
s
.75151 .21971 m .76083 .20489 L .76947 .21139 L p .513 .55 .832 r
F P
0 g
s
.61354 .25121 m .61025 .25192 L .60926 .25629 L p .43 .023 .163 r
F P
0 g
s
.60416 .25679 m .60926 .25629 L .61025 .25192 L p .52 .1 .184 r
F P
0 g
s
.37551 .38939 m .36503 .39041 L .36772 .39024 L p .089 .647 .725 r
F P
0 g
s
.36772 .39024 m .37668 .38938 L .37551 .38939 L p .089 .647 .725 r
F P
0 g
s
.42426 .39233 m .40537 .39027 L .40433 .39021 L p 0 .522 .716 r
F P
0 g
s
.58098 .25172 m .56414 .24974 L .56553 .25408 L p .647 .196 .166 r
F P
0 g
s
.56553 .25408 m .58206 .25601 L .58098 .25172 L p .647 .196 .166 r
F P
0 g
s
.41942 .22268 m .3938 .22106 L .39388 .22118 L p .069 0 0 r
F P
0 g
s
.61612 .25023 m .61354 .25121 L .61157 .25579 L p .284 0 .101 r
F P
0 g
s
.60926 .25629 m .61157 .25579 L .61354 .25121 L p .43 .023 .163 r
F P
0 g
s
.65132 .40021 m .63224 .40419 L .6345 .408 L p .61 .833 .985 r
F P
0 g
s
.6345 .408 m .6555 .40362 L .65132 .40021 L p .61 .833 .985 r
F P
0 g
s
.72302 .20497 m .73183 .1906 L .74186 .19442 L p .607 .675 .889 r
F P
0 g
s
.73183 .1906 m .72302 .20497 L .71301 .20201 L p .637 .716 .904 r
F P
0 g
s
.77737 .21859 m .76776 .23363 L .76 .22632 L p .478 .505 .807 r
F P
0 g
s
.76 .22632 m .76947 .21139 L .77737 .21859 L p .478 .505 .807 r
F P
0 g
s
.37668 .38938 m .38889 .38929 L .38898 .38929 L p .005 .582 .707 r
F P
0 g
s
.38898 .38929 m .37551 .38939 L .37668 .38938 L p .005 .582 .707 r
F P
0 g
s
.33933 .22438 m .31303 .23049 L .30914 .23249 L p .042 0 0 r
F P
0 g
s
.40537 .39027 m .38898 .38929 L .38889 .38929 L p 0 .543 .708 r
F P
0 g
s
.52104 .2399 m .49778 .23568 L .49964 .23874 L p .583 .047 0 r
F P
0 g
s
.49964 .23874 m .52297 .24297 L .52104 .2399 L p .583 .047 0 r
F P
0 g
s
.22862 .30073 m .24614 .28571 L .24773 .27766 L p .174 0 .333 r
F P
0 g
s
.24614 .28571 m .22862 .30073 L .22808 .30942 L p .264 .091 .45 r
F P
0 g
s
.61973 .24821 m .61612 .25023 L .61323 .25516 L p .09 0 0 r
F P
0 g
s
.61157 .25579 m .61323 .25516 L .61612 .25023 L p .284 0 .101 r
F P
0 g
s
.47139 .22972 m .44628 .22587 L .44779 .2275 L p .391 0 0 r
F P
0 g
s
.44779 .2275 m .4733 .23141 L .47139 .22972 L p .391 0 0 r
F P
0 g
s
.3938 .22106 m .36785 .22132 L .36669 .22145 L p .018 0 0 r
F P
0 g
s
.33933 .22438 m .36669 .22145 L .36785 .22132 L p 0 0 0 r
F P
0 g
s
.29097 .39769 m .28144 .4082 L .29133 .41122 L p .645 .745 .922 r
F P
0 g
s
.29133 .41122 m .30034 .40135 L .29097 .39769 L p .645 .745 .922 r
F P
0 g
s
.22104 .35206 m .23372 .33731 L .23065 .32786 L p .348 .294 .654 r
F P
0 g
s
.23372 .33731 m .22104 .35206 L .22546 .36109 L p .398 .364 .704 r
F P
0 g
s
.56414 .24974 m .54462 .24675 L .54618 .25111 L p .665 .207 .157 r
F P
0 g
s
.54618 .25111 m .56553 .25408 L .56414 .24974 L p .665 .207 .157 r
F P
0 g
s
.36669 .22145 m .39388 .22118 L .3938 .22106 L p .018 0 0 r
F P
0 g
s
.71301 .20201 m .72165 .18781 L .73183 .1906 L p .637 .716 .904 r
F P
0 g
s
.72165 .18781 m .71301 .20201 L .703 .20013 L p .667 .757 .917 r
F P
0 g
s
.56861 .40505 m .5459 .40258 L .54342 .40645 L p .553 .791 .987 r
F P
0 g
s
.51982 .40308 m .54342 .40645 L .5459 .40258 L p .549 .785 .986 r
F P
0 g
s
.78441 .22638 m .77466 .24151 L .76776 .23363 L p .441 .456 .779 r
F P
0 g
s
.76776 .23363 m .77737 .21859 L .78441 .22638 L p .441 .456 .779 r
F P
0 g
s
.51982 .40308 m .49619 .39924 L .49332 .40172 L p .427 .772 .997 r
F P
0 g
s
.46999 .39778 m .49332 .40172 L .49619 .39924 L p .426 .77 .996 r
F P
0 g
s
.7776 .32483 m .76424 .33998 L .76665 .33257 L p 0 0 .12 r
F P
0 g
s
.76665 .33257 m .78013 .31725 L .7776 .32483 L p 0 0 .12 r
F P
0 g
s
.46999 .39778 m .44746 .39412 L .44509 .3953 L p .222 .698 .937 r
F P
0 g
s
.42426 .39233 m .44509 .3953 L .44746 .39412 L p .225 .704 .935 r
F P
0 g
s
.66643 .21329 m .67452 .20115 L .6836 .19969 L p .758 .894 .939 r
F P
0 g
s
.67452 .20115 m .66643 .21329 L .65819 .21558 L p .786 .941 .928 r
F P
0 g
s
.64311 .22855 m .65067 .21895 L .65819 .21558 L p .78 .987 .896 r
F P
0 g
s
.65067 .21895 m .64311 .22855 L .63673 .23262 L p .758 .994 .806 r
F P
0 g
s
.35223 .39133 m .34363 .39448 L .34991 .39471 L p .54 .906 .962 r
F P
0 g
s
.34991 .39471 m .3569 .39215 L .35223 .39133 L p .54 .906 .962 r
F P
0 g
s
.72221 .37691 m .70555 .3886 L .71158 .38692 L p .621 .959 .883 r
F P
0 g
s
.71158 .38692 m .72911 .37463 L .72221 .37691 L p .621 .959 .883 r
F P
0 g
s
.6249 .24419 m .61973 .24821 L .61611 .25354 L p 0 0 0 r
F P
0 g
s
.61323 .25516 m .61611 .25354 L .61973 .24821 L p .09 0 0 r
F P
0 g
s
.79296 .2851 m .78146 .30059 L .78024 .29178 L p .176 .091 .513 r
F P
0 g
s
.78024 .29178 m .7917 .27628 L .79296 .2851 L p .176 .091 .513 r
F P
0 g
s
.31929 .39617 m .30968 .40385 L .31885 .40515 L p .683 .841 .959 r
F P
0 g
s
.31885 .40515 m .32756 .39821 L .31929 .39617 L p .683 .841 .959 r
F P
0 g
s
.75033 .35743 m .73523 .37121 L .74048 .3667 L p .503 .842 .562 r
F P
0 g
s
.74048 .3667 m .75602 .35252 L .75033 .35743 L p .503 .842 .562 r
F P
0 g
s
.28175 .39292 m .2717 .40407 L .28144 .4082 L p .619 .701 .904 r
F P
0 g
s
.28144 .4082 m .29097 .39769 L .28175 .39292 L p .619 .701 .904 r
F P
0 g
s
.703 .20013 m .71147 .18609 L .72165 .18781 L p .667 .757 .917 r
F P
0 g
s
.71147 .18609 m .703 .20013 L .69314 .19935 L p .699 .8 .928 r
F P
0 g
s
.22546 .36109 m .23792 .3467 L .23372 .33731 L p .398 .364 .704 r
F P
0 g
s
.23792 .3467 m .22546 .36109 L .23101 .36983 L p .44 .424 .745 r
F P
0 g
s
.79046 .23465 m .78059 .24985 L .77466 .24151 L p .398 .4 .745 r
F P
0 g
s
.77466 .24151 m .78441 .22638 L .79046 .23465 L p .398 .4 .745 r
F P
0 g
s
.54462 .24675 m .52297 .24297 L .52457 .24735 L p .674 .213 .15 r
F P
0 g
s
.52457 .24735 m .54618 .25111 L .54462 .24675 L p .674 .213 .15 r
F P
0 g
s
.49778 .23568 m .4733 .23141 L .47494 .23444 L p .58 .045 0 r
F P
0 g
s
.47494 .23444 m .49964 .23874 L .49778 .23568 L p .58 .045 0 r
F P
0 g
s
.33698 .39295 m .32756 .39821 L .33552 .399 L p .66 .894 .981 r
F P
0 g
s
.33552 .399 m .34363 .39448 L .33698 .39295 L p .66 .894 .981 r
F P
0 g
s
.66878 .39415 m .65132 .40021 L .6555 .40362 L p .635 .843 .98 r
F P
0 g
s
.6555 .40362 m .67479 .39695 L .66878 .39415 L p .635 .843 .98 r
F P
0 g
s
.25037 .27041 m .27284 .25695 L .27593 .25092 L p .142 0 .105 r
F P
0 g
s
.27284 .25695 m .25037 .27041 L .24773 .27766 L p .258 0 .276 r
F P
0 g
s
.44628 .22587 m .42044 .22286 L .42133 .22441 L p .377 0 0 r
F P
0 g
s
.42133 .22441 m .44779 .2275 L .44628 .22587 L p .377 0 0 r
F P
0 g
s
.61134 .40091 m .59149 .40108 L .59066 .40635 L p .626 .78 .955 r
F P
0 g
s
.59066 .40635 m .61193 .40616 L .61134 .40091 L p .626 .78 .955 r
F P
0 g
s
.56861 .40505 m .59066 .40635 L .59149 .40108 L p .622 .776 .955 r
F P
0 g
s
.27978 .246 m .30571 .23579 L .30914 .23249 L p .047 0 0 r
F P
0 g
s
.30571 .23579 m .27978 .246 L .27593 .25092 L p .223 0 .019 r
F P
0 g
s
.62988 .39911 m .61134 .40091 L .61193 .40616 L p .632 .785 .955 r
F P
0 g
s
.61193 .40616 m .63224 .40419 L .62988 .39911 L p .632 .785 .955 r
F P
0 g
s
.44746 .39412 m .42614 .39108 L .42426 .39233 L p .225 .704 .935 r
F P
0 g
s
.40537 .39027 m .42426 .39233 L .42614 .39108 L p .234 .715 .933 r
F P
0 g
s
.69182 .38823 m .67479 .39695 L .68048 .39846 L p .647 .9 .983 r
F P
0 g
s
.68048 .39846 m .69893 .38905 L .69182 .38823 L p .647 .9 .983 r
F P
0 g
s
.5459 .40258 m .52268 .39926 L .51982 .40308 L p .549 .785 .986 r
F P
0 g
s
.49619 .39924 m .51982 .40308 L .52268 .39926 L p .547 .782 .986 r
F P
0 g
s
.36215 .3892 m .35223 .39133 L .3569 .39215 L p .435 .858 .948 r
F P
0 g
s
.3569 .39215 m .36503 .39041 L .36215 .3892 L p .435 .858 .948 r
F P
0 g
s
.22808 .30942 m .24564 .29442 L .24614 .28571 L p .264 .091 .45 r
F P
0 g
s
.24564 .29442 m .22808 .30942 L .22876 .31851 L p .332 .192 .536 r
F P
0 g
s
.60416 .25679 m .59511 .25685 L .59561 .26237 L p .63 .258 .32 r
F P
0 g
s
.59511 .25685 m .58206 .25601 L .58293 .26156 L p .668 .286 .314 r
F P
0 g
s
.58293 .26156 m .59561 .26237 L .59511 .25685 L p .668 .286 .314 r
F P
0 g
s
.60926 .25629 m .60416 .25679 L .60413 .26232 L p .577 .216 .319 r
F P
0 g
s
.59561 .26237 m .60413 .26232 L .60416 .25679 L p .63 .258 .32 r
F P
0 g
s
.49619 .39924 m .4728 .39528 L .46999 .39778 L p .426 .77 .996 r
F P
0 g
s
.44746 .39412 m .46999 .39778 L .4728 .39528 L p .427 .772 .997 r
F P
0 g
s
.27284 .38712 m .26229 .3989 L .2717 .40407 L p .593 .659 .883 r
F P
0 g
s
.2717 .40407 m .28175 .39292 L .27284 .38712 L p .593 .659 .883 r
F P
0 g
s
.23101 .36983 m .24318 .35585 L .23792 .3467 L p .44 .424 .745 r
F P
0 g
s
.24318 .35585 m .23101 .36983 L .23759 .37811 L p .476 .478 .78 r
F P
0 g
s
.36669 .22145 m .33933 .22438 L .33689 .22604 L p .199 0 0 r
F P
0 g
s
.30914 .23249 m .33689 .22604 L .33933 .22438 L p .042 0 0 r
F P
0 g
s
.59149 .40108 m .57046 .39984 L .56861 .40505 L p .622 .776 .955 r
F P
0 g
s
.5459 .40258 m .56861 .40505 L .57046 .39984 L p .62 .773 .954 r
F P
0 g
s
.61157 .25579 m .60926 .25629 L .60856 .26189 L p .504 .154 .307 r
F P
0 g
s
.60413 .26232 m .60856 .26189 L .60926 .25629 L p .577 .216 .319 r
F P
0 g
s
.58206 .25601 m .56553 .25408 L .56664 .25966 L p .694 .305 .308 r
F P
0 g
s
.56664 .25966 m .58293 .26156 L .58206 .25601 L p .694 .305 .308 r
F P
0 g
s
.65819 .21558 m .66606 .20372 L .67452 .20115 L p .786 .941 .928 r
F P
0 g
s
.66606 .20372 m .65819 .21558 L .65067 .21895 L p .805 .982 .895 r
F P
0 g
s
.69314 .19935 m .70145 .18548 L .71147 .18609 L p .699 .8 .928 r
F P
0 g
s
.70145 .18548 m .69314 .19935 L .6836 .19969 L p .731 .844 .934 r
F P
0 g
s
.61611 .25354 m .62078 .24991 L .6249 .24419 L p 0 0 0 r
F P
0 g
s
.79543 .24327 m .78546 .25852 L .78059 .24985 L p .35 .337 .705 r
F P
0 g
s
.78059 .24985 m .79046 .23465 L .79543 .24327 L p .35 .337 .705 r
F P
0 g
s
.61323 .25516 m .61157 .25579 L .61012 .26156 L p .377 .043 .265 r
F P
0 g
s
.60856 .26189 m .61012 .26156 L .61157 .25579 L p .504 .154 .307 r
F P
0 g
s
.37428 .38802 m .36215 .3892 L .36503 .39041 L p .346 .805 .936 r
F P
0 g
s
.36503 .39041 m .37551 .38939 L .37428 .38802 L p .346 .805 .936 r
F P
0 g
s
.64699 .39553 m .62988 .39911 L .63224 .40419 L p .64 .789 .953 r
F P
0 g
s
.63224 .40419 m .65132 .40021 L .64699 .39553 L p .64 .789 .953 r
F P
0 g
s
.42614 .39108 m .40652 .38894 L .40537 .39027 L p .234 .715 .933 r
F P
0 g
s
.38898 .38929 m .40537 .39027 L .40652 .38894 L p .251 .734 .93 r
F P
0 g
s
.77387 .33174 m .76068 .34667 L .76424 .33998 L p 0 0 0 r
F P
0 g
s
.76424 .33998 m .7776 .32483 L .77387 .33174 L p 0 0 0 r
F P
0 g
s
.26438 .38039 m .25336 .39278 L .26229 .3989 L p .566 .616 .861 r
F P
0 g
s
.26229 .3989 m .27284 .38712 L .26438 .38039 L p .566 .616 .861 r
F P
0 g
s
.23759 .37811 m .24942 .36462 L .24318 .35585 L p .476 .478 .78 r
F P
0 g
s
.24942 .36462 m .23759 .37811 L .24508 .38581 L p .509 .527 .81 r
F P
0 g
s
.79293 .29368 m .78142 .30913 L .78146 .30059 L p .075 0 .405 r
F P
0 g
s
.78146 .30059 m .79296 .2851 L .79293 .29368 L p .075 0 .405 r
F P
0 g
s
.61611 .25354 m .61323 .25516 L .61107 .2612 L p .223 0 .197 r
F P
0 g
s
.61012 .26156 m .61107 .2612 L .61323 .25516 L p .377 .043 .265 r
F P
0 g
s
.31087 .39291 m .30034 .40135 L .30968 .40385 L p .666 .792 .942 r
F P
0 g
s
.30968 .40385 m .31929 .39617 L .31087 .39291 L p .666 .792 .942 r
F P
0 g
s
.63673 .23262 m .64401 .22336 L .65067 .21895 L p .758 .994 .806 r
F P
0 g
s
.42044 .22286 m .39388 .22118 L .39392 .22268 L p .348 0 0 r
F P
0 g
s
.39392 .22268 m .42133 .22441 L .42044 .22286 L p .348 0 0 r
F P
0 g
s
.33689 .22604 m .30914 .23249 L .30571 .23579 L p .255 0 0 r
F P
0 g
s
.52297 .24297 m .49964 .23874 L .50117 .24311 L p .677 .215 .148 r
F P
0 g
s
.50117 .24311 m .52457 .24735 L .52297 .24297 L p .677 .215 .148 r
F P
0 g
s
.25653 .37285 m .24508 .38581 L .25336 .39278 L p .538 .572 .837 r
F P
0 g
s
.25336 .39278 m .26438 .38039 L .25653 .37285 L p .538 .572 .837 r
F P
0 g
s
.24508 .38581 m .25653 .37285 L .24942 .36462 L p .509 .527 .81 r
F P
0 g
s
.3891 .3879 m .37428 .38802 L .37551 .38939 L p .286 .763 .93 r
F P
0 g
s
.37551 .38939 m .38898 .38929 L .3891 .3879 L p .286 .763 .93 r
F P
0 g
s
.40652 .38894 m .3891 .3879 L .38898 .38929 L p .251 .734 .93 r
F P
0 g
s
.56553 .25408 m .54618 .25111 L .54741 .25672 L p .711 .317 .301 r
F P
0 g
s
.54741 .25672 m .56664 .25966 L .56553 .25408 L p .711 .317 .301 r
F P
0 g
s
.4733 .23141 m .44779 .2275 L .44907 .23048 L p .571 .04 0 r
F P
0 g
s
.44907 .23048 m .47494 .23444 L .4733 .23141 L p .571 .04 0 r
F P
0 g
s
.57046 .39984 m .54843 .39743 L .5459 .40258 L p .62 .773 .954 r
F P
0 g
s
.52268 .39926 m .5459 .40258 L .54843 .39743 L p .618 .772 .954 r
F P
0 g
s
.71465 .37799 m .69893 .38905 L .70555 .3886 L p .674 .948 .957 r
F P
0 g
s
.70555 .3886 m .72221 .37691 L .71465 .37799 L p .674 .948 .957 r
F P
0 g
s
.39388 .22118 m .36669 .22145 L .36561 .22297 L p .294 0 0 r
F P
0 g
s
.33689 .22604 m .36561 .22297 L .36669 .22145 L p .199 0 0 r
F P
0 g
s
.62078 .24991 m .61611 .25354 L .6134 .25988 L p .042 0 .104 r
F P
0 g
s
.61107 .2612 m .6134 .25988 L .61611 .25354 L p .223 0 .197 r
F P
0 g
s
.52268 .39926 m .4992 .39543 L .49619 .39924 L p .547 .782 .986 r
F P
0 g
s
.4728 .39528 m .49619 .39924 L .4992 .39543 L p .546 .782 .986 r
F P
0 g
s
.36561 .22297 m .39392 .22268 L .39388 .22118 L p .294 0 0 r
F P
0 g
s
.34731 .38917 m .33698 .39295 L .34363 .39448 L p .611 .885 .99 r
F P
0 g
s
.34363 .39448 m .35223 .39133 L .34731 .38917 L p .611 .885 .99 r
F P
0 g
s
.22876 .31851 m .24624 .30364 L .24564 .29442 L p .332 .192 .536 r
F P
0 g
s
.24624 .30364 m .22876 .31851 L .23065 .32786 L p .384 .273 .603 r
F P
0 g
s
.74369 .36131 m .72911 .37463 L .73523 .37121 L p .64 .958 .781 r
F P
0 g
s
.73523 .37121 m .75033 .35743 L .74369 .36131 L p .64 .958 .781 r
F P
0 g
s
.4728 .39528 m .44999 .39158 L .44746 .39412 L p .427 .772 .997 r
F P
0 g
s
.42614 .39108 m .44746 .39412 L .44999 .39158 L p .43 .777 .997 r
F P
0 g
s
.6836 .19969 m .69176 .18599 L .70145 .18548 L p .731 .844 .934 r
F P
0 g
s
.69176 .18599 m .6836 .19969 L .67452 .20115 L p .763 .89 .935 r
F P
0 g
s
.79923 .2521 m .78918 .26737 L .78546 .25852 L p .292 .263 .654 r
F P
0 g
s
.78546 .25852 m .79543 .24327 L .79923 .2521 L p .292 .263 .654 r
F P
0 g
s
.33009 .39014 m .31929 .39617 L .32756 .39821 L p .664 .843 .968 r
F P
0 g
s
.32756 .39821 m .33698 .39295 L .33009 .39014 L p .664 .843 .968 r
F P
0 g
s
.24773 .27766 m .2706 .26401 L .27284 .25695 L p .258 0 .276 r
F P
0 g
s
.2706 .26401 m .24773 .27766 L .24614 .28571 L p .339 .1 .398 r
F P
0 g
s
.66258 .39011 m .64699 .39553 L .65132 .40021 L p .649 .792 .951 r
F P
0 g
s
.65132 .40021 m .66878 .39415 L .66258 .39011 L p .649 .792 .951 r
F P
0 g
s
.54618 .25111 m .52457 .24735 L .52582 .25297 L p .72 .324 .297 r
F P
0 g
s
.52582 .25297 m .54741 .25672 L .54618 .25111 L p .72 .324 .297 r
F P
0 g
s
.65067 .21895 m .65834 .20735 L .66606 .20372 L p .805 .982 .895 r
F P
0 g
s
.65834 .20735 m .65067 .21895 L .64401 .22336 L p .802 1 .822 r
F P
0 g
s
.30242 .38847 m .29097 .39769 L .30034 .40135 L p .647 .745 .921 r
F P
0 g
s
.30034 .40135 m .31087 .39291 L .30242 .38847 L p .647 .745 .921 r
F P
0 g
s
.68435 .38616 m .66878 .39415 L .67479 .39695 L p .659 .847 .972 r
F P
0 g
s
.67479 .39695 m .69182 .38823 L .68435 .38616 L p .659 .847 .972 r
F P
0 g
s
.27593 .25092 m .3028 .24036 L .30571 .23579 L p .223 0 .019 r
F P
0 g
s
.3028 .24036 m .27593 .25092 L .27284 .25695 L p .339 0 .211 r
F P
0 g
s
.61072 .39446 m .5923 .39462 L .59149 .40108 L p .658 .749 .917 r
F P
0 g
s
.59149 .40108 m .61134 .40091 L .61072 .39446 L p .658 .749 .917 r
F P
0 g
s
.57046 .39984 m .59149 .40108 L .5923 .39462 L p .659 .75 .917 r
F P
0 g
s
.62746 .39283 m .61072 .39446 L .61134 .40091 L p .656 .747 .917 r
F P
0 g
s
.61134 .40091 m .62988 .39911 L .62746 .39283 L p .656 .747 .917 r
F P
0 g
s
.49964 .23874 m .47494 .23444 L .47629 .23879 L p .674 .213 .15 r
F P
0 g
s
.47629 .23879 m .50117 .24311 L .49964 .23874 L p .674 .213 .15 r
F P
0 g
s
.79161 .30189 m .78013 .31725 L .78142 .30913 L p 0 0 .256 r
F P
0 g
s
.78142 .30913 m .79293 .29368 L .79161 .30189 L p 0 0 .256 r
F P
0 g
s
.54843 .39743 m .52561 .39416 L .52268 .39926 L p .618 .772 .954 r
F P
0 g
s
.4992 .39543 m .52268 .39926 L .52561 .39416 L p .617 .77 .954 r
F P
0 g
s
.44779 .2275 m .42133 .22441 L .42208 .22734 L p .554 .028 0 r
F P
0 g
s
.42208 .22734 m .44907 .23048 L .44779 .2275 L p .554 .028 0 r
F P
0 g
s
.60413 .26232 m .59561 .26237 L .59603 .26908 L p .659 .335 .414 r
F P
0 g
s
.59561 .26237 m .58293 .26156 L .58359 .26828 L p .694 .362 .41 r
F P
0 g
s
.58359 .26828 m .59603 .26908 L .59561 .26237 L p .694 .362 .41 r
F P
0 g
s
.62078 .24991 m .62684 .24375 L .63128 .23771 L p 0 0 0 r
F P
0 g
s
.62684 .24375 m .62078 .24991 L .61769 .25655 L p 0 0 0 r
F P
0 g
s
.6134 .25988 m .61769 .25655 L .62078 .24991 L p .042 0 .104 r
F P
0 g
s
.35911 .38663 m .34731 .38917 L .35223 .39133 L p .555 .865 .996 r
F P
0 g
s
.35223 .39133 m .36215 .3892 L .35911 .38663 L p .555 .865 .996 r
F P
0 g
s
.60856 .26189 m .60413 .26232 L .60419 .26903 L p .612 .298 .414 r
F P
0 g
s
.59603 .26908 m .60419 .26903 L .60413 .26232 L p .659 .335 .414 r
F P
0 g
s
.76898 .33785 m .75602 .35252 L .76068 .34667 L p 0 0 0 r
F P
0 g
s
.76068 .34667 m .77387 .33174 L .76898 .33785 L p 0 0 0 r
F P
0 g
s
.76963 .19011 m .76083 .20489 L .75158 .19921 L p .542 .593 .855 r
F P
0 g
s
.75158 .19921 m .76029 .18444 L .76963 .19011 L p .542 .593 .855 r
F P
0 g
s
.76029 .18444 m .75158 .19921 L .74186 .19442 L p .574 .635 .873 r
F P
0 g
s
.44999 .39158 m .42816 .38846 L .42614 .39108 L p .43 .777 .997 r
F P
0 g
s
.40652 .38894 m .42614 .39108 L .42816 .38846 L p .437 .785 .997 r
F P
0 g
s
.74186 .19442 m .75049 .17967 L .76029 .18444 L p .574 .635 .873 r
F P
0 g
s
.75049 .17967 m .74186 .19442 L .73183 .1906 L p .605 .675 .89 r
F P
0 g
s
.5923 .39462 m .5723 .39343 L .57046 .39984 L p .659 .75 .917 r
F P
0 g
s
.54843 .39743 m .57046 .39984 L .5723 .39343 L p .66 .751 .917 r
F P
0 g
s
.61012 .26156 m .60856 .26189 L .60816 .26865 L p .551 .248 .407 r
F P
0 g
s
.60419 .26903 m .60816 .26865 L .60856 .26189 L p .612 .298 .414 r
F P
0 g
s
.23065 .32786 m .24793 .31323 L .24624 .30364 L p .384 .273 .603 r
F P
0 g
s
.24793 .31323 m .23065 .32786 L .23372 .33731 L p .427 .34 .656 r
F P
0 g
s
.4992 .39543 m .47574 .39146 L .4728 .39528 L p .546 .782 .986 r
F P
0 g
s
.44999 .39158 m .4728 .39528 L .47574 .39146 L p .547 .782 .986 r
F P
0 g
s
.77836 .19659 m .76947 .21139 L .76083 .20489 L p .509 .55 .833 r
F P
0 g
s
.76083 .20489 m .76963 .19011 L .77836 .19659 L p .509 .55 .833 r
F P
0 g
s
.61107 .2612 m .61012 .26156 L .60921 .26844 L p .434 .149 .379 r
F P
0 g
s
.60816 .26865 m .60921 .26844 L .61012 .26156 L p .551 .248 .407 r
F P
0 g
s
.58293 .26156 m .56664 .25966 L .56745 .2664 L p .718 .38 .406 r
F P
0 g
s
.56745 .2664 m .58359 .26828 L .58293 .26156 L p .718 .38 .406 r
F P
0 g
s
.6134 .25988 m .61107 .2612 L .60969 .26825 L p .313 .046 .338 r
F P
0 g
s
.60921 .26844 m .60969 .26825 L .61107 .2612 L p .434 .149 .379 r
F P
0 g
s
.73183 .1906 m .74037 .17588 L .75049 .17967 L p .605 .675 .89 r
F P
0 g
s
.74037 .17588 m .73183 .1906 L .72165 .18781 L p .636 .716 .905 r
F P
0 g
s
.67452 .20115 m .68254 .18762 L .69176 .18599 L p .763 .89 .935 r
F P
0 g
s
.68254 .18762 m .67452 .20115 L .66606 .20372 L p .793 .936 .924 r
F P
0 g
s
.64257 .38966 m .62746 .39283 L .62988 .39911 L p .654 .746 .918 r
F P
0 g
s
.62988 .39911 m .64699 .39553 L .64257 .38966 L p .654 .746 .918 r
F P
0 g
s
.36561 .22297 m .33689 .22604 L .33472 .22905 L p .39 0 0 r
F P
0 g
s
.30571 .23579 m .33472 .22905 L .33689 .22604 L p .255 0 0 r
F P
0 g
s
.80181 .261 m .7917 .27628 L .78918 .26737 L p .222 .173 .589 r
F P
0 g
s
.78918 .26737 m .79923 .2521 L .80181 .261 L p .222 .173 .589 r
F P
0 g
s
.78634 .20379 m .77737 .21859 L .76947 .21139 L p .473 .504 .809 r
F P
0 g
s
.76947 .21139 m .77836 .19659 L .78634 .20379 L p .473 .504 .809 r
F P
0 g
s
.373 .38526 m .35911 .38663 L .36215 .3892 L p .506 .841 .998 r
F P
0 g
s
.36215 .3892 m .37428 .38802 L .373 .38526 L p .506 .841 .998 r
F P
0 g
s
.29409 .38293 m .28175 .39292 L .29097 .39769 L p .627 .701 .899 r
F P
0 g
s
.29097 .39769 m .30242 .38847 L .29409 .38293 L p .627 .701 .899 r
F P
0 g
s
.33472 .22905 m .30571 .23579 L .3028 .24036 L p .391 0 .11 r
F P
0 g
s
.70654 .37785 m .69182 .38823 L .69893 .38905 L p .685 .902 .973 r
F P
0 g
s
.69893 .38905 m .71465 .37799 L .70654 .37785 L p .685 .902 .973 r
F P
0 g
s
.61769 .25655 m .6134 .25988 L .61164 .26714 L p .171 0 .28 r
F P
0 g
s
.60969 .26825 m .61164 .26714 L .6134 .25988 L p .313 .046 .338 r
F P
0 g
s
.52457 .24735 m .50117 .24311 L .50235 .24873 L p .723 .326 .296 r
F P
0 g
s
.50235 .24873 m .52582 .25297 L .52457 .24735 L p .723 .326 .296 r
F P
0 g
s
.42816 .38846 m .40777 .38623 L .40652 .38894 L p .437 .785 .997 r
F P
0 g
s
.3891 .3879 m .40652 .38894 L .40777 .38623 L p .45 .799 .998 r
F P
0 g
s
.72165 .18781 m .7301 .17311 L .74037 .17588 L p .636 .716 .905 r
F P
0 g
s
.7301 .17311 m .72165 .18781 L .71147 .18609 L p .668 .757 .917 r
F P
0 g
s
.56664 .25966 m .54741 .25672 L .54828 .26348 L p .734 .393 .402 r
F P
0 g
s
.54828 .26348 m .56745 .2664 L .56664 .25966 L p .734 .393 .402 r
F P
0 g
s
.73622 .36408 m .72221 .37691 L .72911 .37463 L p .705 .98 .903 r
F P
0 g
s
.72911 .37463 m .74369 .36131 L .73622 .36408 L p .705 .98 .903 r
F P
0 g
s
.42133 .22441 m .39392 .22268 L .39392 .22556 L p .524 .004 0 r
F P
0 g
s
.39392 .22556 m .42208 .22734 L .42133 .22441 L p .524 .004 0 r
F P
0 g
s
.32306 .38608 m .31087 .39291 L .31929 .39617 L p .659 .792 .946 r
F P
0 g
s
.31929 .39617 m .33009 .39014 L .32306 .38608 L p .659 .792 .946 r
F P
0 g
s
.5723 .39343 m .55096 .39109 L .54843 .39743 L p .66 .751 .917 r
F P
0 g
s
.52561 .39416 m .54843 .39743 L .55096 .39109 L p .66 .751 .917 r
F P
0 g
s
.24614 .28571 m .26923 .27197 L .2706 .26401 L p .339 .1 .398 r
F P
0 g
s
.26923 .27197 m .24614 .28571 L .24564 .29442 L p .397 .196 .487 r
F P
0 g
s
.34221 .38569 m .33009 .39014 L .33698 .39295 L p .64 .839 .977 r
F P
0 g
s
.33698 .39295 m .34731 .38917 L .34221 .38569 L p .64 .839 .977 r
F P
0 g
s
.38926 .38513 m .373 .38526 L .37428 .38802 L p .471 .817 .998 r
F P
0 g
s
.37428 .38802 m .3891 .3879 L .38926 .38513 L p .471 .817 .998 r
F P
0 g
s
.40777 .38623 m .38926 .38513 L .3891 .3879 L p .45 .799 .998 r
F P
0 g
s
.47494 .23444 m .44907 .23048 L .45011 .23479 L p .664 .206 .156 r
F P
0 g
s
.45011 .23479 m .47629 .23879 L .47494 .23444 L p .664 .206 .156 r
F P
0 g
s
.23372 .33731 m .2507 .32301 L .24793 .31323 L p .427 .34 .656 r
F P
0 g
s
.2507 .32301 m .23372 .33731 L .23792 .3467 L p .462 .398 .699 r
F P
0 g
s
.52561 .39416 m .50228 .39035 L .4992 .39543 L p .617 .77 .954 r
F P
0 g
s
.47574 .39146 m .4992 .39543 L .50228 .39035 L p .617 .77 .953 r
F P
0 g
s
.79345 .21158 m .78441 .22638 L .77737 .21859 L p .434 .454 .781 r
F P
0 g
s
.77737 .21859 m .78634 .20379 L .79345 .21158 L p .434 .454 .781 r
F P
0 g
s
.64401 .22336 m .6515 .212 L .65834 .20735 L p .802 1 .822 r
F P
0 g
s
.39392 .22268 m .36561 .22297 L .36462 .22586 L p .473 0 0 r
F P
0 g
s
.33472 .22905 m .36462 .22586 L .36561 .22297 L p .39 0 0 r
F P
0 g
s
.36462 .22586 m .39392 .22556 L .39392 .22268 L p .473 0 0 r
F P
0 g
s
.47574 .39146 m .45264 .3877 L .44999 .39158 L p .547 .782 .986 r
F P
0 g
s
.42816 .38846 m .44999 .39158 L .45264 .3877 L p .549 .785 .986 r
F P
0 g
s
.71147 .18609 m .71984 .17143 L .7301 .17311 L p .668 .757 .917 r
F P
0 g
s
.71984 .17143 m .71147 .18609 L .70145 .18548 L p .699 .799 .927 r
F P
0 g
s
.78901 .30959 m .7776 .32483 L .78013 .31725 L p 0 0 .054 r
F P
0 g
s
.78013 .31725 m .79161 .30189 L .78901 .30959 L p 0 0 .054 r
F P
0 g
s
.65627 .38488 m .64257 .38966 L .64699 .39553 L p .651 .745 .918 r
F P
0 g
s
.64699 .39553 m .66258 .39011 L .65627 .38488 L p .651 .745 .918 r
F P
0 g
s
.28604 .37638 m .27284 .38712 L .28175 .39292 L p .607 .659 .875 r
F P
0 g
s
.28175 .39292 m .29409 .38293 L .28604 .37638 L p .607 .659 .875 r
F P
0 g
s
.67663 .38286 m .66258 .39011 L .66878 .39415 L p .657 .794 .948 r
F P
0 g
s
.66878 .39415 m .68435 .38616 L .67663 .38286 L p .657 .794 .948 r
F P
0 g
s
.27284 .25695 m .30045 .24613 L .3028 .24036 L p .339 0 .211 r
F P
0 g
s
.30045 .24613 m .27284 .25695 L .2706 .26401 L p .414 .114 .344 r
F P
0 g
s
.66606 .20372 m .67394 .19034 L .68254 .18762 L p .793 .936 .924 r
F P
0 g
s
.67394 .19034 m .66606 .20372 L .65834 .20735 L p .818 .976 .894 r
F P
0 g
s
.61007 .38691 m .59307 .38705 L .5923 .39462 L p .676 .719 .881 r
F P
0 g
s
.5923 .39462 m .61072 .39446 L .61007 .38691 L p .676 .719 .881 r
F P
0 g
s
.5723 .39343 m .5923 .39462 L .59307 .38705 L p .682 .724 .882 r
F P
0 g
s
.54741 .25672 m .52582 .25297 L .5267 .25974 L p .743 .399 .4 r
F P
0 g
s
.5267 .25974 m .54828 .26348 L .54741 .25672 L p .743 .399 .4 r
F P
0 g
s
.62502 .38545 m .61007 .38691 L .61072 .39446 L p .669 .713 .882 r
F P
0 g
s
.61072 .39446 m .62746 .39283 L .62502 .38545 L p .669 .713 .882 r
F P
0 g
s
.8031 .26983 m .79296 .2851 L .7917 .27628 L p .133 .062 .503 r
F P
0 g
s
.7917 .27628 m .80181 .261 L .8031 .26983 L p .133 .062 .503 r
F P
0 g
s
.61769 .25655 m .6235 .25064 L .62684 .24375 L p 0 0 0 r
F P
0 g
s
.6235 .25064 m .61769 .25655 L .61567 .26401 L p .011 0 .205 r
F P
0 g
s
.61164 .26714 m .61567 .26401 L .61769 .25655 L p .171 0 .28 r
F P
0 g
s
.763 .34307 m .75033 .35743 L .75602 .35252 L p .638 .923 .646 r
F P
0 g
s
.75602 .35252 m .76898 .33785 L .763 .34307 L p .638 .923 .646 r
F P
0 g
s
.63368 .23504 m .62684 .24375 L .6235 .25064 L p 0 0 0 r
F P
0 g
s
.23792 .3467 m .25449 .33281 L .2507 .32301 L p .462 .398 .699 r
F P
0 g
s
.25449 .33281 m .23792 .3467 L .24318 .35585 L p .492 .448 .736 r
F P
0 g
s
.79956 .21985 m .79046 .23465 L .78441 .22638 L p .39 .397 .747 r
F P
0 g
s
.78441 .22638 m .79345 .21158 L .79956 .21985 L p .39 .397 .747 r
F P
0 g
s
.60419 .26903 m .59603 .26908 L .59635 .27686 L p .677 .392 .483 r
F P
0 g
s
.59603 .26908 m .58359 .26828 L .58402 .27607 L p .708 .417 .481 r
F P
0 g
s
.58402 .27607 m .59635 .27686 L .59603 .26908 L p .708 .417 .481 r
F P
0 g
s
.60816 .26865 m .60419 .26903 L .60434 .27681 L p .634 .359 .483 r
F P
0 g
s
.59635 .27686 m .60434 .27681 L .60419 .26903 L p .677 .392 .483 r
F P
0 g
s
.55096 .39109 m .52856 .38786 L .52561 .39416 L p .66 .751 .917 r
F P
0 g
s
.50228 .39035 m .52561 .39416 L .52856 .38786 L p .66 .752 .918 r
F P
0 g
s
.50117 .24311 m .47629 .23879 L .47732 .24438 L p .72 .324 .297 r
F P
0 g
s
.47732 .24438 m .50235 .24873 L .50117 .24311 L p .72 .324 .297 r
F P
0 g
s
.60921 .26844 m .60816 .26865 L .60808 .27646 L p .583 .318 .48 r
F P
0 g
s
.60434 .27681 m .60808 .27646 L .60816 .26865 L p .634 .359 .483 r
F P
0 g
s
.59307 .38705 m .57411 .38592 L .5723 .39343 L p .682 .724 .882 r
F P
0 g
s
.55096 .39109 m .5723 .39343 L .57411 .38592 L p .685 .727 .882 r
F P
0 g
s
.60969 .26825 m .60921 .26844 L .60888 .2763 L p .467 .224 .461 r
F P
0 g
s
.60808 .27646 m .60888 .2763 L .60921 .26844 L p .583 .318 .48 r
F P
0 g
s
.58359 .26828 m .56745 .2664 L .56794 .2742 L p .731 .435 .478 r
F P
0 g
s
.56794 .2742 m .58402 .27607 L .58359 .26828 L p .731 .435 .478 r
F P
0 g
s
.2784 .36892 m .26438 .38039 L .27284 .38712 L p .586 .618 .851 r
F P
0 g
s
.27284 .38712 m .28604 .37638 L .2784 .36892 L p .586 .618 .851 r
F P
0 g
s
.61164 .26714 m .60969 .26825 L .60911 .2762 L p .377 .151 .44 r
F P
0 g
s
.60888 .2763 m .60911 .2762 L .60969 .26825 L p .467 .224 .461 r
F P
0 g
s
.35597 .38272 m .34221 .38569 L .34731 .38917 L p .614 .831 .983 r
F P
0 g
s
.34731 .38917 m .35911 .38663 L .35597 .38272 L p .614 .831 .983 r
F P
0 g
s
.70145 .18548 m .70974 .17085 L .71984 .17143 L p .699 .799 .927 r
F P
0 g
s
.70974 .17085 m .70145 .18548 L .69176 .18599 L p .732 .843 .933 r
F P
0 g
s
.63815 .38269 m .62502 .38545 L .62746 .39283 L p .659 .708 .883 r
F P
0 g
s
.62746 .39283 m .64257 .38966 L .63815 .38269 L p .659 .708 .883 r
F P
0 g
s
.44907 .23048 m .42208 .22734 L .42267 .23159 L p .646 .193 .163 r
F P
0 g
s
.42267 .23159 m .45011 .23479 L .44907 .23048 L p .646 .193 .163 r
F P
0 g
s
.31601 .38083 m .30242 .38847 L .31087 .39291 L p .649 .745 .92 r
F P
0 g
s
.31087 .39291 m .32306 .38608 L .31601 .38083 L p .649 .745 .92 r
F P
0 g
s
.24564 .29442 m .26877 .2807 L .26923 .27197 L p .397 .196 .487 r
F P
0 g
s
.26877 .2807 m .24564 .29442 L .24624 .30364 L p .44 .272 .556 r
F P
0 g
s
.24318 .35585 m .25925 .34247 L .25449 .33281 L p .492 .448 .736 r
F P
0 g
s
.25925 .34247 m .24318 .35585 L .24942 .36462 L p .518 .494 .769 r
F P
0 g
s
.50228 .39035 m .47876 .38636 L .47574 .39146 L p .617 .77 .953 r
F P
0 g
s
.45264 .3877 m .47574 .39146 L .47876 .38636 L p .617 .77 .954 r
F P
0 g
s
.45264 .3877 m .4303 .3845 L .42816 .38846 L p .549 .785 .986 r
F P
0 g
s
.40777 .38623 m .42816 .38846 L .4303 .3845 L p .554 .791 .987 r
F P
0 g
s
.69802 .37648 m .68435 .38616 L .69182 .38823 L p .678 .847 .964 r
F P
0 g
s
.69182 .38823 m .70654 .37785 L .69802 .37648 L p .678 .847 .964 r
F P
0 g
s
.61567 .26401 m .61164 .26714 L .61087 .2752 L p .263 .06 .405 r
F P
0 g
s
.60911 .2762 m .61087 .2752 L .61164 .26714 L p .377 .151 .44 r
F P
0 g
s
.27131 .36068 m .25653 .37285 L .26438 .38039 L p .565 .578 .825 r
F P
0 g
s
.26438 .38039 m .2784 .36892 L .27131 .36068 L p .565 .578 .825 r
F P
0 g
s
.72803 .3657 m .71465 .37799 L .72221 .37691 L p .719 .949 .953 r
F P
0 g
s
.72221 .37691 m .73622 .36408 L .72803 .3657 L p .719 .949 .953 r
F P
0 g
s
.24942 .36462 m .26489 .35182 L .25925 .34247 L p .518 .494 .769 r
F P
0 g
s
.26489 .35182 m .24942 .36462 L .25653 .37285 L p .543 .537 .798 r
F P
0 g
s
.56745 .2664 m .54828 .26348 L .54878 .27129 L p .746 .447 .476 r
F P
0 g
s
.54878 .27129 m .56794 .2742 L .56745 .2664 L p .746 .447 .476 r
F P
0 g
s
.36462 .22586 m .33472 .22905 L .33286 .23339 L p .5 .07 .154 r
F P
0 g
s
.3028 .24036 m .33286 .23339 L .33472 .22905 L p .391 0 .11 r
F P
0 g
s
.25653 .37285 m .27131 .36068 L .26489 .35182 L p .543 .537 .798 r
F P
0 g
s
.80459 .22848 m .79543 .24327 L .79046 .23465 L p .339 .333 .706 r
F P
0 g
s
.79046 .23465 m .79956 .21985 L .80459 .22848 L p .339 .333 .706 r
F P
0 g
s
.57411 .38592 m .55347 .38364 L .55096 .39109 L p .685 .727 .882 r
F P
0 g
s
.52856 .38786 m .55096 .39109 L .55347 .38364 L p .688 .73 .883 r
F P
0 g
s
.33701 .38094 m .32306 .38608 L .33009 .39014 L p .65 .791 .95 r
F P
0 g
s
.33009 .39014 m .34221 .38569 L .33701 .38094 L p .65 .791 .95 r
F P
0 g
s
.52582 .25297 m .50235 .24873 L .50317 .2555 L p .746 .402 .399 r
F P
0 g
s
.50317 .2555 m .5267 .25974 L .52582 .25297 L p .746 .402 .399 r
F P
0 g
s
.33286 .23339 m .3028 .24036 L .30045 .24613 L p .473 .112 .27 r
F P
0 g
s
.37169 .38116 m .35597 .38272 L .35911 .38663 L p .59 .82 .987 r
F P
0 g
s
.35911 .38663 m .373 .38526 L .37169 .38116 L p .59 .82 .987 r
F P
0 g
s
.65834 .20735 m .66611 .19411 L .67394 .19034 L p .818 .976 .894 r
F P
0 g
s
.66611 .19411 m .65834 .20735 L .6515 .212 L p .824 .999 .828 r
F P
0 g
s
.78517 .31665 m .77387 .33174 L .7776 .32483 L p 0 0 0 r
F P
0 g
s
.7776 .32483 m .78901 .30959 L .78517 .31665 L p 0 0 0 r
F P
0 g
s
.4303 .3845 m .40911 .38218 L .40777 .38623 L p .554 .791 .987 r
F P
0 g
s
.38926 .38513 m .40777 .38623 L .40911 .38218 L p .561 .798 .988 r
F P
0 g
s
.80309 .27845 m .79293 .29368 L .79296 .2851 L p .02 0 .385 r
F P
0 g
s
.79296 .2851 m .8031 .26983 L .80309 .27845 L p .02 0 .385 r
F P
0 g
s
.52856 .38786 m .50539 .38407 L .50228 .39035 L p .66 .752 .918 r
F P
0 g
s
.47876 .38636 m .50228 .39035 L .50539 .38407 L p .661 .752 .918 r
F P
0 g
s
.69176 .18599 m .69996 .1714 L .70974 .17085 L p .732 .843 .933 r
F P
0 g
s
.69996 .1714 m .69176 .18599 L .68254 .18762 L p .765 .888 .933 r
F P
0 g
s
.42208 .22734 m .39392 .22556 L .39387 .22978 L p .617 .171 .169 r
F P
0 g
s
.39387 .22978 m .42267 .23159 L .42208 .22734 L p .617 .171 .169 r
F P
0 g
s
.6688 .37839 m .65627 .38488 L .66258 .39011 L p .649 .745 .919 r
F P
0 g
s
.66258 .39011 m .67663 .38286 L .6688 .37839 L p .649 .745 .919 r
F P
0 g
s
.64998 .37854 m .63815 .38269 L .64257 .38966 L p .649 .703 .886 r
F P
0 g
s
.64257 .38966 m .65627 .38488 L .64998 .37854 L p .649 .703 .886 r
F P
0 g
s
.47629 .23879 m .45011 .23479 L .45089 .24036 L p .71 .317 .301 r
F P
0 g
s
.45089 .24036 m .47732 .24438 L .47629 .23879 L p .71 .317 .301 r
F P
0 g
s
.60941 .37838 m .5938 .37851 L .59307 .38705 L p .688 .692 .848 r
F P
0 g
s
.59307 .38705 m .61007 .38691 L .60941 .37838 L p .688 .692 .848 r
F P
0 g
s
.57411 .38592 m .59307 .38705 L .5938 .37851 L p .696 .699 .849 r
F P
0 g
s
.38946 .38101 m .37169 .38116 L .373 .38526 L p .572 .808 .988 r
F P
0 g
s
.373 .38526 m .38926 .38513 L .38946 .38101 L p .572 .808 .988 r
F P
0 g
s
.61567 .26401 m .62133 .25828 L .6235 .25064 L p .011 0 .205 r
F P
0 g
s
.62133 .25828 m .61567 .26401 L .61478 .27218 L p .136 0 .36 r
F P
0 g
s
.61087 .2752 m .61478 .27218 L .61567 .26401 L p .263 .06 .405 r
F P
0 g
s
.2706 .26401 m .29873 .253 L .30045 .24613 L p .414 .114 .344 r
F P
0 g
s
.29873 .253 m .2706 .26401 L .26923 .27197 L p .466 .209 .44 r
F P
0 g
s
.62261 .3771 m .60941 .37838 L .61007 .38691 L p .676 .683 .849 r
F P
0 g
s
.61007 .38691 m .62502 .38545 L .62261 .3771 L p .676 .683 .849 r
F P
0 g
s
.75604 .3473 m .74369 .36131 L .75033 .35743 L p .725 .988 .818 r
F P
0 g
s
.75033 .35743 m .763 .34307 L .75604 .3473 L p .725 .988 .818 r
F P
0 g
s
.40911 .38218 m .38946 .38101 L .38926 .38513 L p .561 .798 .988 r
F P
0 g
s
.6235 .25064 m .6302 .24212 L .63368 .23504 L p 0 0 0 r
F P
0 g
s
.6302 .24212 m .6235 .25064 L .62133 .25828 L p 0 0 .127 r
F P
0 g
s
.54828 .26348 m .5267 .25974 L .52718 .26756 L p .755 .454 .475 r
F P
0 g
s
.52718 .26756 m .54878 .27129 L .54828 .26348 L p .755 .454 .475 r
F P
0 g
s
.60434 .27681 m .59635 .27686 L .59656 .28558 L p .688 .437 .537 r
F P
0 g
s
.59635 .27686 m .58402 .27607 L .58421 .28479 L p .717 .46 .536 r
F P
0 g
s
.58421 .28479 m .59656 .28558 L .59635 .27686 L p .717 .46 .536 r
F P
0 g
s
.47876 .38636 m .45538 .38254 L .45264 .3877 L p .617 .77 .954 r
F P
0 g
s
.4303 .3845 m .45264 .3877 L .45538 .38254 L p .618 .771 .954 r
F P
0 g
s
.60808 .27646 m .60434 .27681 L .60458 .28553 L p .649 .406 .537 r
F P
0 g
s
.59656 .28558 m .60458 .28553 L .60434 .27681 L p .688 .437 .537 r
F P
0 g
s
.30906 .37448 m .29409 .38293 L .30242 .38847 L p .636 .702 .893 r
F P
0 g
s
.30242 .38847 m .31601 .38083 L .30906 .37448 L p .636 .702 .893 r
F P
0 g
s
.24624 .30364 m .26924 .29006 L .26877 .2807 L p .44 .272 .556 r
F P
0 g
s
.26924 .29006 m .24624 .30364 L .24793 .31323 L p .474 .334 .61 r
F P
0 g
s
.39392 .22556 m .36462 .22586 L .36375 .23009 L p .571 .133 .169 r
F P
0 g
s
.33286 .23339 m .36375 .23009 L .36462 .22586 L p .5 .07 .154 r
F P
0 g
s
.60888 .2763 m .60808 .27646 L .60832 .28518 L p .602 .369 .536 r
F P
0 g
s
.60458 .28553 m .60832 .28518 L .60808 .27646 L p .649 .406 .537 r
F P
0 g
s
.5938 .37851 m .57586 .37743 L .57411 .38592 L p .696 .699 .849 r
F P
0 g
s
.55347 .38364 m .57411 .38592 L .57586 .37743 L p .702 .705 .85 r
F P
0 g
s
.36375 .23009 m .39387 .22978 L .39392 .22556 L p .571 .133 .169 r
F P
0 g
s
.60911 .2762 m .60888 .2763 L .60912 .28503 L p .501 .291 .527 r
F P
0 g
s
.60832 .28518 m .60912 .28503 L .60888 .2763 L p .602 .369 .536 r
F P
0 g
s
.61087 .2752 m .60911 .2762 L .60936 .28493 L p .425 .234 .515 r
F P
0 g
s
.60912 .28503 m .60936 .28493 L .60911 .2762 L p .501 .291 .527 r
F P
0 g
s
.55347 .38364 m .53147 .38047 L .52856 .38786 L p .688 .73 .883 r
F P
0 g
s
.50539 .38407 m .52856 .38786 L .53147 .38047 L p .689 .732 .883 r
F P
0 g
s
.80845 .23732 m .79923 .2521 L .79543 .24327 L p .279 .256 .654 r
F P
0 g
s
.79543 .24327 m .80459 .22848 L .80845 .23732 L p .279 .256 .654 r
F P
0 g
s
.58402 .27607 m .56794 .2742 L .5681 .28293 L p .738 .477 .534 r
F P
0 g
s
.5681 .28293 m .58421 .28479 L .58402 .27607 L p .738 .477 .534 r
F P
0 g
s
.6338 .37474 m .62261 .3771 L .62502 .38545 L p .661 .673 .851 r
F P
0 g
s
.62502 .38545 m .63815 .38269 L .6338 .37474 L p .661 .673 .851 r
F P
0 g
s
.68923 .3739 m .67663 .38286 L .68435 .38616 L p .664 .794 .944 r
F P
0 g
s
.68435 .38616 m .69802 .37648 L .68923 .3739 L p .664 .794 .944 r
F P
0 g
s
.50235 .24873 m .47732 .24438 L .47801 .25115 L p .743 .399 .4 r
F P
0 g
s
.47801 .25115 m .50317 .2555 L .50235 .24873 L p .743 .399 .4 r
F P
0 g
s
.61478 .27218 m .61087 .2752 L .61112 .28393 L p .331 .163 .497 r
F P
0 g
s
.60936 .28493 m .61112 .28393 L .61087 .2752 L p .425 .234 .515 r
F P
0 g
s
.35278 .37752 m .33701 .38094 L .34221 .38569 L p .641 .788 .952 r
F P
0 g
s
.34221 .38569 m .35597 .38272 L .35278 .37752 L p .641 .788 .952 r
F P
0 g
s
.71925 .36613 m .70654 .37785 L .71465 .37799 L p .71 .899 .964 r
F P
0 g
s
.71465 .37799 m .72803 .3657 L .71925 .36613 L p .71 .899 .964 r
F P
0 g
s
.68254 .18762 m .69067 .17306 L .69996 .1714 L p .765 .888 .933 r
F P
0 g
s
.69067 .17306 m .68254 .18762 L .67394 .19034 L p .796 .933 .922 r
F P
0 g
s
.77824 .17575 m .76963 .19011 L .76029 .18444 L p .543 .593 .854 r
F P
0 g
s
.76029 .18444 m .76888 .16998 L .77824 .17575 L p .543 .593 .854 r
F P
0 g
s
.76888 .16998 m .76029 .18444 L .75049 .17967 L p .575 .635 .873 r
F P
0 g
s
.56794 .2742 m .54878 .27129 L .5489 .28003 L p .752 .489 .533 r
F P
0 g
s
.5489 .28003 m .5681 .28293 L .56794 .2742 L p .752 .489 .533 r
F P
0 g
s
.75049 .17967 m .75907 .1651 L .76888 .16998 L p .575 .635 .873 r
F P
0 g
s
.75907 .1651 m .75049 .17967 L .74037 .17588 L p .606 .675 .89 r
F P
0 g
s
.50539 .38407 m .48182 .38005 L .47876 .38636 L p .661 .752 .918 r
F P
0 g
s
.45538 .38254 m .47876 .38636 L .48182 .38005 L p .66 .752 .918 r
F P
0 g
s
.57586 .37743 m .55589 .37522 L .55347 .38364 L p .702 .705 .85 r
F P
0 g
s
.53147 .38047 m .55347 .38364 L .55589 .37522 L p .706 .709 .851 r
F P
0 g
s
.45011 .23479 m .42267 .23159 L .42308 .23713 L p .693 .303 .305 r
F P
0 g
s
.42308 .23713 m .45089 .24036 L .45011 .23479 L p .693 .303 .305 r
F P
0 g
s
.3318 .375 m .31601 .38083 L .32306 .38608 L p .651 .746 .919 r
F P
0 g
s
.32306 .38608 m .33701 .38094 L .3318 .375 L p .651 .746 .919 r
F P
0 g
s
.6515 .212 m .65917 .1989 L .66611 .19411 L p .824 .999 .828 r
F P
0 g
s
.65917 .1989 m .6515 .212 L .64566 .21759 L p .794 .981 .706 r
F P
0 g
s
.78698 .18233 m .77836 .19659 L .76963 .19011 L p .509 .55 .833 r
F P
0 g
s
.76963 .19011 m .77824 .17575 L .78698 .18233 L p .509 .55 .833 r
F P
0 g
s
.45538 .38254 m .43251 .37926 L .4303 .3845 L p .618 .771 .954 r
F P
0 g
s
.40911 .38218 m .4303 .3845 L .43251 .37926 L p .62 .773 .954 r
F P
0 g
s
.80176 .28672 m .79161 .30189 L .79293 .29368 L p 0 0 .224 r
F P
0 g
s
.79293 .29368 m .80309 .27845 L .80176 .28672 L p 0 0 .224 r
F P
0 g
s
.74037 .17588 m .74894 .16119 L .75907 .1651 L p .606 .675 .89 r
F P
0 g
s
.74894 .16119 m .74037 .17588 L .7301 .17311 L p .636 .716 .905 r
F P
0 g
s
.30235 .36713 m .28604 .37638 L .29409 .38293 L p .623 .662 .867 r
F P
0 g
s
.29409 .38293 m .30906 .37448 L .30235 .36713 L p .623 .662 .867 r
F P
0 g
s
.24793 .31323 m .27062 .29989 L .26924 .29006 L p .474 .334 .61 r
F P
0 g
s
.27062 .29989 m .24793 .31323 L .2507 .32301 L p .502 .387 .655 r
F P
0 g
s
.5267 .25974 m .50317 .2555 L .50359 .26333 L p .758 .456 .474 r
F P
0 g
s
.50359 .26333 m .52718 .26756 L .5267 .25974 L p .758 .456 .474 r
F P
0 g
s
.78014 .32295 m .76898 .33785 L .77387 .33174 L p .595 .839 .47 r
F P
0 g
s
.77387 .33174 m .78517 .31665 L .78014 .32295 L p .595 .839 .47 r
F P
0 g
s
.661 .37281 m .64998 .37854 L .65627 .38488 L p .638 .7 .891 r
F P
0 g
s
.65627 .38488 m .6688 .37839 L .661 .37281 L p .638 .7 .891 r
F P
0 g
s
.6438 .37121 m .6338 .37474 L .63815 .38269 L p .644 .665 .856 r
F P
0 g
s
.63815 .38269 m .64998 .37854 L .6438 .37121 L p .644 .665 .856 r
F P
0 g
s
.30045 .24613 m .33134 .23898 L .33286 .23339 L p .473 .112 .27 r
F P
0 g
s
.33134 .23898 m .30045 .24613 L .29873 .253 L p .525 .214 .382 r
F P
0 g
s
.60874 .36902 m .59447 .36914 L .5938 .37851 L p .695 .667 .818 r
F P
0 g
s
.5938 .37851 m .60941 .37838 L .60874 .36902 L p .695 .667 .818 r
F P
0 g
s
.57586 .37743 m .5938 .37851 L .59447 .36914 L p .707 .677 .819 r
F P
0 g
s
.62026 .3679 m .60874 .36902 L .60941 .37838 L p .68 .655 .819 r
F P
0 g
s
.60941 .37838 m .62261 .3771 L .62026 .3679 L p .68 .655 .819 r
F P
0 g
s
.36375 .23009 m .33286 .23339 L .33134 .23898 L p .563 .194 .299 r
F P
0 g
s
.79498 .18962 m .78634 .20379 L .77836 .19659 L p .474 .504 .809 r
F P
0 g
s
.77836 .19659 m .78698 .18233 L .79498 .18962 L p .474 .504 .809 r
F P
0 g
s
.61478 .27218 m .62036 .26653 L .62133 .25828 L p .136 0 .36 r
F P
0 g
s
.62036 .26653 m .61478 .27218 L .61503 .28091 L p .229 .088 .472 r
F P
0 g
s
.61112 .28393 m .61503 .28091 L .61478 .27218 L p .331 .163 .497 r
F P
0 g
s
.53147 .38047 m .50848 .37669 L .50539 .38407 L p .689 .732 .883 r
F P
0 g
s
.48182 .38005 m .50539 .38407 L .50848 .37669 L p .689 .732 .883 r
F P
0 g
s
.81106 .24624 m .80181 .261 L .79923 .2521 L p .205 .163 .587 r
F P
0 g
s
.79923 .2521 m .80845 .23732 L .81106 .24624 L p .205 .163 .587 r
F P
0 g
s
.60458 .28553 m .59656 .28558 L .59667 .2951 L p .695 .473 .581 r
F P
0 g
s
.59656 .28558 m .58421 .28479 L .58416 .29431 L p .722 .495 .58 r
F P
0 g
s
.58416 .29431 m .59667 .2951 L .59656 .28558 L p .722 .495 .58 r
F P
0 g
s
.60832 .28518 m .60458 .28553 L .60489 .29505 L p .659 .444 .581 r
F P
0 g
s
.59667 .2951 m .60489 .29505 L .60458 .28553 L p .695 .473 .581 r
F P
0 g
s
.26923 .27197 m .29765 .26088 L .29873 .253 L p .466 .209 .44 r
F P
0 g
s
.29765 .26088 m .26923 .27197 L .26877 .2807 L p .503 .282 .511 r
F P
0 g
s
.7301 .17311 m .73866 .15832 L .74894 .16119 L p .636 .716 .905 r
F P
0 g
s
.73866 .15832 m .7301 .17311 L .71984 .17143 L p .668 .757 .917 r
F P
0 g
s
.7482 .35045 m .73622 .36408 L .74369 .36131 L p .753 .983 .909 r
F P
0 g
s
.74369 .36131 m .75604 .3473 L .7482 .35045 L p .753 .983 .909 r
F P
0 g
s
.62133 .25828 m .62793 .24989 L .6302 .24212 L p 0 0 .127 r
F P
0 g
s
.62793 .24989 m .62133 .25828 L .62036 .26653 L p .013 0 .311 r
F P
0 g
s
.60912 .28503 m .60832 .28518 L .60888 .29468 L p .614 .41 .581 r
F P
0 g
s
.60489 .29505 m .60888 .29468 L .60832 .28518 L p .659 .444 .581 r
F P
0 g
s
.37038 .37578 m .35278 .37752 L .35597 .38272 L p .633 .784 .954 r
F P
0 g
s
.35597 .38272 m .37169 .38116 L .37038 .37578 L p .633 .784 .954 r
F P
0 g
s
.60936 .28493 m .60912 .28503 L .60994 .29446 L p .536 .352 .579 r
F P
0 g
s
.60888 .29468 m .60994 .29446 L .60912 .28503 L p .614 .41 .581 r
F P
0 g
s
.59447 .36914 m .5775 .36811 L .57586 .37743 L p .707 .677 .819 r
F P
0 g
s
.55589 .37522 m .57586 .37743 L .5775 .36811 L p .715 .685 .82 r
F P
0 g
s
.61112 .28393 m .60936 .28493 L .61042 .29428 L p .462 .3 .574 r
F P
0 g
s
.60994 .29446 m .61042 .29428 L .60936 .28493 L p .536 .352 .579 r
F P
0 g
s
.54878 .27129 m .52718 .26756 L .52725 .2763 L p .76 .495 .532 r
F P
0 g
s
.52725 .2763 m .5489 .28003 L .54878 .27129 L p .76 .495 .532 r
F P
0 g
s
.58421 .28479 m .5681 .28293 L .56792 .29244 L p .742 .511 .58 r
F P
0 g
s
.56792 .29244 m .58416 .29431 L .58421 .28479 L p .742 .511 .58 r
F P
0 g
s
.6296 .36593 m .62026 .3679 L .62261 .3771 L p .66 .642 .821 r
F P
0 g
s
.62261 .3771 m .6338 .37474 L .6296 .36593 L p .66 .642 .821 r
F P
0 g
s
.43251 .37926 m .4105 .37685 L .40911 .38218 L p .62 .773 .954 r
F P
0 g
s
.38946 .38101 m .40911 .38218 L .4105 .37685 L p .623 .776 .954 r
F P
0 g
s
.47732 .24438 m .45089 .24036 L .45139 .2471 L p .734 .392 .402 r
F P
0 g
s
.45139 .2471 m .47801 .25115 L .47732 .24438 L p .734 .392 .402 r
F P
0 g
s
.42267 .23159 m .39387 .22978 L .39379 .23529 L p .665 .282 .309 r
F P
0 g
s
.39379 .23529 m .42308 .23713 L .42267 .23159 L p .665 .282 .309 r
F P
0 g
s
.55589 .37522 m .5343 .37209 L .53147 .38047 L p .706 .709 .851 r
F P
0 g
s
.50848 .37669 m .53147 .38047 L .5343 .37209 L p .708 .712 .851 r
F P
0 g
s
.8021 .1975 m .79345 .21158 L .78634 .20379 L p .435 .454 .78 r
F P
0 g
s
.78634 .20379 m .79498 .18962 L .8021 .1975 L p .435 .454 .78 r
F P
0 g
s
.68032 .37015 m .6688 .37839 L .67663 .38286 L p .647 .745 .92 r
F P
0 g
s
.67663 .38286 m .68923 .3739 L .68032 .37015 L p .647 .745 .92 r
F P
0 g
s
.61503 .28091 m .61112 .28393 L .61238 .29317 L p .383 .245 .566 r
F P
0 g
s
.61042 .29428 m .61238 .29317 L .61112 .28393 L p .462 .3 .574 r
F P
0 g
s
.29597 .3589 m .2784 .36892 L .28604 .37638 L p .61 .624 .84 r
F P
0 g
s
.28604 .37638 m .30235 .36713 L .29597 .3589 L p .61 .624 .84 r
F P
0 g
s
.2507 .32301 m .27291 .31001 L .27062 .29989 L p .502 .387 .655 r
F P
0 g
s
.27291 .31001 m .2507 .32301 L .25449 .33281 L p .525 .433 .693 r
F P
0 g
s
.67394 .19034 m .68201 .17582 L .69067 .17306 L p .796 .933 .922 r
F P
0 g
s
.68201 .17582 m .67394 .19034 L .66611 .19411 L p .823 .974 .893 r
F P
0 g
s
.48182 .38005 m .45816 .37618 L .45538 .38254 L p .66 .752 .918 r
F P
0 g
s
.43251 .37926 m .45538 .38254 L .45816 .37618 L p .66 .751 .917 r
F P
0 g
s
.38969 .37561 m .37038 .37578 L .37169 .38116 L p .627 .78 .955 r
F P
0 g
s
.37169 .38116 m .38946 .38101 L .38969 .37561 L p .627 .78 .955 r
F P
0 g
s
.71984 .17143 m .72839 .15653 L .73866 .15832 L p .668 .757 .917 r
F P
0 g
s
.72839 .15653 m .71984 .17143 L .70974 .17085 L p .699 .799 .927 r
F P
0 g
s
.4105 .37685 m .38969 .37561 L .38946 .38101 L p .623 .776 .954 r
F P
0 g
s
.71004 .36535 m .69802 .37648 L .70654 .37785 L p .691 .845 .956 r
F P
0 g
s
.70654 .37785 m .71925 .36613 L .71004 .36535 L p .691 .845 .956 r
F P
0 g
s
.5681 .28293 m .5489 .28003 L .54863 .28953 L p .755 .522 .579 r
F P
0 g
s
.54863 .28953 m .56792 .29244 L .5681 .28293 L p .755 .522 .579 r
F P
0 g
s
.39387 .22978 m .36375 .23009 L .36301 .23561 L p .624 .247 .309 r
F P
0 g
s
.33134 .23898 m .36301 .23561 L .36375 .23009 L p .563 .194 .299 r
F P
0 g
s
.5775 .36811 m .5582 .36597 L .55589 .37522 L p .715 .685 .82 r
F P
0 g
s
.5343 .37209 m .55589 .37522 L .5582 .36597 L p .72 .69 .821 r
F P
0 g
s
.50317 .2555 m .47801 .25115 L .47835 .25897 L p .755 .454 .475 r
F P
0 g
s
.47835 .25897 m .50359 .26333 L .50317 .2555 L p .755 .454 .475 r
F P
0 g
s
.36301 .23561 m .39379 .23529 L .39387 .22978 L p .624 .247 .309 r
F P
0 g
s
.32667 .36795 m .30906 .37448 L .31601 .38083 L p .648 .704 .888 r
F P
0 g
s
.31601 .38083 m .3318 .375 L .32667 .36795 L p .648 .704 .888 r
F P
0 g
s
.6302 .24212 m .63735 .23127 L .64091 .22405 L p 0 0 0 r
F P
0 g
s
.63735 .23127 m .6302 .24212 L .62793 .24989 L p 0 0 .06 r
F P
0 g
s
.63785 .36301 m .6296 .36593 L .6338 .37474 L p .637 .631 .828 r
F P
0 g
s
.6338 .37474 m .6438 .37121 L .63785 .36301 L p .637 .631 .828 r
F P
0 g
s
.65336 .36621 m .6438 .37121 L .64998 .37854 L p .626 .66 .863 r
F P
0 g
s
.64998 .37854 m .661 .37281 L .65336 .36621 L p .626 .66 .863 r
F P
0 g
s
.60807 .359 m .59507 .3591 L .59447 .36914 L p .7 .643 .79 r
F P
0 g
s
.59447 .36914 m .60874 .36902 L .60807 .359 L p .7 .643 .79 r
F P
0 g
s
.5775 .36811 m .59447 .36914 L .59507 .3591 L p .714 .655 .79 r
F P
0 g
s
.64566 .21759 m .65324 .20461 L .65917 .1989 L p .794 .981 .706 r
F P
0 g
s
.61802 .35803 m .60807 .359 L .60874 .36902 L p .681 .629 .79 r
F P
0 g
s
.60874 .36902 m .62026 .3679 L .61802 .35803 L p .681 .629 .79 r
F P
0 g
s
.3496 .37112 m .3318 .375 L .33701 .38094 L p .654 .746 .918 r
F P
0 g
s
.33701 .38094 m .35278 .37752 L .3496 .37112 L p .654 .746 .918 r
F P
0 g
s
.29006 .34994 m .27131 .36068 L .2784 .36892 L p .595 .587 .813 r
F P
0 g
s
.2784 .36892 m .29597 .3589 L .29006 .34994 L p .595 .587 .813 r
F P
0 g
s
.25449 .33281 m .27605 .32026 L .27291 .31001 L p .525 .433 .693 r
F P
0 g
s
.27605 .32026 m .25449 .33281 L .25925 .34247 L p .545 .475 .727 r
F P
0 g
s
.79913 .29449 m .78901 .30959 L .79161 .30189 L p 0 0 .008 r
F P
0 g
s
.79161 .30189 m .80176 .28672 L .79913 .29449 L p 0 0 .008 r
F P
0 g
s
.80824 .20585 m .79956 .21985 L .79345 .21158 L p .391 .398 .747 r
F P
0 g
s
.79345 .21158 m .8021 .1975 L .80824 .20585 L p .391 .398 .747 r
F P
0 g
s
.60489 .29505 m .59667 .2951 L .59667 .30526 L p .7 .503 .618 r
F P
0 g
s
.59667 .2951 m .58416 .29431 L .58386 .30445 L p .725 .524 .618 r
F P
0 g
s
.58386 .30445 m .59667 .30526 L .59667 .2951 L p .725 .524 .618 r
F P
0 g
s
.60888 .29468 m .60489 .29505 L .60528 .30521 L p .666 .477 .619 r
F P
0 g
s
.59667 .30526 m .60528 .30521 L .60489 .29505 L p .7 .503 .618 r
F P
0 g
s
.50848 .37669 m .48485 .37265 L .48182 .38005 L p .689 .732 .883 r
F P
0 g
s
.45816 .37618 m .48182 .38005 L .48485 .37265 L p .689 .732 .883 r
F P
0 g
s
.77399 .32838 m .763 .34307 L .76898 .33785 L p .718 .961 .693 r
F P
0 g
s
.76898 .33785 m .78014 .32295 L .77399 .32838 L p .718 .961 .693 r
F P
0 g
s
.81238 .2551 m .8031 .26983 L .80181 .261 L p .113 .048 .497 r
F P
0 g
s
.80181 .261 m .81106 .24624 L .81238 .2551 L p .113 .048 .497 r
F P
0 g
s
.60994 .29446 m .60888 .29468 L .60975 .30478 L p .623 .444 .62 r
F P
0 g
s
.60528 .30521 m .60975 .30478 L .60888 .29468 L p .666 .477 .619 r
F P
0 g
s
.52718 .26756 m .50359 .26333 L .50362 .27207 L p .763 .497 .532 r
F P
0 g
s
.50362 .27207 m .52725 .2763 L .52718 .26756 L p .763 .497 .532 r
F P
0 g
s
.59507 .3591 m .57902 .35812 L .5775 .36811 L p .714 .655 .79 r
F P
0 g
s
.5582 .36597 m .5775 .36811 L .57902 .35812 L p .724 .665 .791 r
F P
0 g
s
.61042 .29428 m .60994 .29446 L .61132 .30446 L p .559 .399 .621 r
F P
0 g
s
.60975 .30478 m .61132 .30446 L .60994 .29446 L p .623 .444 .62 r
F P
0 g
s
.61503 .28091 m .62063 .27527 L .62036 .26653 L p .229 .088 .472 r
F P
0 g
s
.62063 .27527 m .61503 .28091 L .61644 .29006 L p .3 .188 .555 r
F P
0 g
s
.61238 .29317 m .61644 .29006 L .61503 .28091 L p .383 .245 .566 r
F P
0 g
s
.58416 .29431 m .56792 .29244 L .56741 .30257 L p .743 .539 .618 r
F P
0 g
s
.56741 .30257 m .58386 .30445 L .58416 .29431 L p .743 .539 .618 r
F P
0 g
s
.70974 .17085 m .71829 .15585 L .72839 .15653 L p .699 .799 .927 r
F P
0 g
s
.71829 .15585 m .70974 .17085 L .69996 .1714 L p .732 .843 .933 r
F P
0 g
s
.61238 .29317 m .61042 .29428 L .61229 .30409 L p .492 .355 .622 r
F P
0 g
s
.61132 .30446 m .61229 .30409 L .61042 .29428 L p .559 .399 .621 r
F P
0 g
s
.62562 .35642 m .61802 .35803 L .62026 .3679 L p .657 .613 .793 r
F P
0 g
s
.62026 .3679 m .6296 .36593 L .62562 .35642 L p .657 .613 .793 r
F P
0 g
s
.26877 .2807 m .29725 .26963 L .29765 .26088 L p .503 .282 .511 r
F P
0 g
s
.29725 .26963 m .26877 .2807 L .26924 .29006 L p .53 .34 .568 r
F P
0 g
s
.2847 .3404 m .26489 .35182 L .27131 .36068 L p .58 .55 .786 r
F P
0 g
s
.27131 .36068 m .29006 .34994 L .2847 .3404 L p .58 .55 .786 r
F P
0 g
s
.25925 .34247 m .28001 .33045 L .27605 .32026 L p .545 .475 .727 r
F P
0 g
s
.28001 .33045 m .25925 .34247 L .26489 .35182 L p .563 .513 .757 r
F P
0 g
s
.45089 .24036 m .42308 .23713 L .42331 .24386 L p .717 .379 .405 r
F P
0 g
s
.42331 .24386 m .45139 .2471 L .45089 .24036 L p .717 .379 .405 r
F P
0 g
s
.73961 .35248 m .72803 .3657 L .73622 .36408 L p .747 .944 .947 r
F P
0 g
s
.73622 .36408 m .7482 .35045 L .73961 .35248 L p .747 .944 .947 r
F P
0 g
s
.5343 .37209 m .51148 .36833 L .50848 .37669 L p .708 .712 .851 r
F P
0 g
s
.48485 .37265 m .50848 .37669 L .51148 .36833 L p .709 .713 .851 r
F P
0 g
s
.26489 .35182 m .2847 .3404 L .28001 .33045 L p .563 .513 .757 r
F P
0 g
s
.45816 .37618 m .43476 .37281 L .43251 .37926 L p .66 .751 .917 r
F P
0 g
s
.4105 .37685 m .43251 .37926 L .43476 .37281 L p .66 .751 .917 r
F P
0 g
s
.62036 .26653 m .62692 .25822 L .62793 .24989 L p .013 0 .311 r
F P
0 g
s
.62692 .25822 m .62036 .26653 L .62063 .27527 L p .132 .017 .444 r
F P
0 g
s
.29873 .253 m .3302 .24574 L .33134 .23898 L p .525 .214 .382 r
F P
0 g
s
.3302 .24574 m .29873 .253 L .29765 .26088 L p .559 .289 .463 r
F P
0 g
s
.5489 .28003 m .52725 .2763 L .52691 .28581 L p .762 .528 .579 r
F P
0 g
s
.52691 .28581 m .54863 .28953 L .5489 .28003 L p .762 .528 .579 r
F P
0 g
s
.67145 .36529 m .661 .37281 L .6688 .37839 L p .629 .699 .896 r
F P
0 g
s
.6688 .37839 m .68032 .37015 L .67145 .36529 L p .629 .699 .896 r
F P
0 g
s
.61644 .29006 m .61238 .29317 L .61464 .30279 L p .424 .311 .621 r
F P
0 g
s
.61229 .30409 m .61464 .30279 L .61238 .29317 L p .492 .355 .622 r
F P
0 g
s
.5582 .36597 m .537 .36288 L .5343 .37209 L p .72 .69 .821 r
F P
0 g
s
.51148 .36833 m .5343 .37209 L .537 .36288 L p .723 .693 .821 r
F P
0 g
s
.66611 .19411 m .67412 .17963 L .68201 .17582 L p .823 .974 .893 r
F P
0 g
s
.67412 .17963 m .66611 .19411 L .65917 .1989 L p .833 .998 .831 r
F P
0 g
s
.36301 .23561 m .33134 .23898 L .3302 .24574 L p .601 .282 .4 r
F P
0 g
s
.60743 .34847 m .59559 .34856 L .59507 .3591 L p .703 .621 .762 r
F P
0 g
s
.59507 .3591 m .60807 .359 L .60743 .34847 L p .703 .621 .762 r
F P
0 g
s
.57902 .35812 m .59507 .3591 L .59559 .34856 L p .719 .635 .763 r
F P
0 g
s
.56792 .29244 m .54863 .28953 L .54798 .29965 L p .755 .55 .618 r
F P
0 g
s
.54798 .29965 m .56741 .30257 L .56792 .29244 L p .755 .55 .618 r
F P
0 g
s
.61593 .34765 m .60743 .34847 L .60807 .359 L p .681 .604 .763 r
F P
0 g
s
.60807 .359 m .61802 .35803 L .61593 .34765 L p .681 .604 .763 r
F P
0 g
s
.57902 .35812 m .56034 .35603 L .5582 .36597 L p .724 .665 .791 r
F P
0 g
s
.537 .36288 m .5582 .36597 L .56034 .35603 L p .73 .671 .792 r
F P
0 g
s
.63223 .35407 m .62562 .35642 L .6296 .36593 L p .629 .599 .8 r
F P
0 g
s
.6296 .36593 m .63785 .36301 L .63223 .35407 L p .629 .599 .8 r
F P
0 g
s
.70054 .36337 m .68923 .3739 L .69802 .37648 L p .669 .793 .941 r
F P
0 g
s
.69802 .37648 m .71004 .36535 L .70054 .36337 L p .669 .793 .941 r
F P
0 g
s
.60528 .30521 m .59667 .30526 L .59656 .31587 L p .703 .53 .651 r
F P
0 g
s
.59667 .30526 m .58386 .30445 L .58333 .31504 L p .726 .549 .651 r
F P
0 g
s
.58333 .31504 m .59656 .31587 L .59667 .30526 L p .726 .549 .651 r
F P
0 g
s
.81328 .21454 m .80459 .22848 L .79956 .21985 L p .34 .333 .705 r
F P
0 g
s
.79956 .21985 m .80824 .20585 L .81328 .21454 L p .34 .333 .705 r
F P
0 g
s
.60975 .30478 m .60528 .30521 L .60573 .31581 L p .672 .505 .652 r
F P
0 g
s
.59656 .31587 m .60573 .31581 L .60528 .30521 L p .703 .53 .651 r
F P
0 g
s
.64601 .35871 m .63785 .36301 L .6438 .37121 L p .614 .623 .836 r
F P
0 g
s
.6438 .37121 m .65336 .36621 L .64601 .35871 L p .614 .623 .836 r
F P
0 g
s
.36909 .36918 m .3496 .37112 L .35278 .37752 L p .656 .748 .917 r
F P
0 g
s
.35278 .37752 m .37038 .37578 L .36909 .36918 L p .656 .748 .917 r
F P
0 g
s
.47801 .25115 m .45139 .2471 L .45161 .25492 L p .746 .447 .476 r
F P
0 g
s
.45161 .25492 m .47835 .25897 L .47801 .25115 L p .746 .447 .476 r
F P
0 g
s
.61132 .30446 m .60975 .30478 L .61091 .31532 L p .631 .476 .653 r
F P
0 g
s
.60573 .31581 m .61091 .31532 L .60975 .30478 L p .672 .505 .652 r
F P
0 g
s
.59559 .34856 m .58039 .34763 L .57902 .35812 L p .719 .635 .763 r
F P
0 g
s
.56034 .35603 m .57902 .35812 L .58039 .34763 L p .73 .645 .764 r
F P
0 g
s
.32172 .35992 m .30235 .36713 L .30906 .37448 L p .642 .667 .859 r
F P
0 g
s
.30906 .37448 m .32667 .36795 L .32172 .35992 L p .642 .667 .859 r
F P
0 g
s
.62193 .34638 m .61593 .34765 L .61802 .35803 L p .654 .586 .766 r
F P
0 g
s
.61802 .35803 m .62562 .35642 L .62193 .34638 L p .654 .586 .766 r
F P
0 g
s
.61229 .30409 m .61132 .30446 L .61325 .31483 L p .576 .439 .657 r
F P
0 g
s
.61091 .31532 m .61325 .31483 L .61132 .30446 L p .631 .476 .653 r
F P
0 g
s
.58386 .30445 m .56741 .30257 L .56657 .31313 L p .743 .564 .651 r
F P
0 g
s
.56657 .31313 m .58333 .31504 L .58386 .30445 L p .743 .564 .651 r
F P
0 g
s
.69996 .1714 m .70852 .15629 L .71829 .15585 L p .732 .843 .933 r
F P
0 g
s
.70852 .15629 m .69996 .1714 L .69067 .17306 L p .765 .889 .933 r
F P
0 g
s
.43476 .37281 m .41193 .37031 L .4105 .37685 L p .66 .751 .917 r
F P
0 g
s
.38969 .37561 m .4105 .37685 L .41193 .37031 L p .659 .75 .917 r
F P
0 g
s
.61464 .30279 m .61229 .30409 L .61494 .31421 L p .517 .402 .661 r
F P
0 g
s
.61325 .31483 m .61494 .31421 L .61229 .30409 L p .576 .439 .657 r
F P
0 g
s
.48485 .37265 m .46092 .36872 L .45816 .37618 L p .689 .732 .883 r
F P
0 g
s
.43476 .37281 m .45816 .37618 L .46092 .36872 L p .688 .73 .883 r
F P
0 g
s
.42308 .23713 m .39379 .23529 L .39366 .242 L p .692 .359 .407 r
F P
0 g
s
.39366 .242 m .42331 .24386 L .42308 .23713 L p .692 .359 .407 r
F P
0 g
s
.62793 .24989 m .63503 .23913 L .63735 .23127 L p 0 0 .06 r
F P
0 g
s
.63503 .23913 m .62793 .24989 L .62692 .25822 L p 0 0 .266 r
F P
0 g
s
.50359 .26333 m .47835 .25897 L .47832 .26773 L p .76 .495 .532 r
F P
0 g
s
.47832 .26773 m .50362 .27207 L .50359 .26333 L p .76 .495 .532 r
F P
0 g
s
.60682 .33764 m .59601 .33772 L .59559 .34856 L p .705 .599 .736 r
F P
0 g
s
.59559 .34856 m .60743 .34847 L .60682 .33764 L p .705 .599 .736 r
F P
0 g
s
.58039 .34763 m .59559 .34856 L .59601 .33772 L p .723 .614 .736 r
F P
0 g
s
.61402 .33695 m .60682 .33764 L .60743 .34847 L p .68 .58 .736 r
F P
0 g
s
.60743 .34847 m .61593 .34765 L .61402 .33695 L p .68 .58 .736 r
F P
0 g
s
.60573 .31581 m .59656 .31587 L .59634 .32676 L p .704 .554 .681 r
F P
0 g
s
.59656 .31587 m .58333 .31504 L .58256 .3259 L p .726 .572 .681 r
F P
0 g
s
.58256 .3259 m .59634 .32676 L .59656 .31587 L p .726 .572 .681 r
F P
0 g
s
.81239 .26374 m .80309 .27845 L .8031 .26983 L p 0 0 .376 r
F P
0 g
s
.8031 .26983 m .81238 .2551 L .81239 .26374 L p 0 0 .376 r
F P
0 g
s
.61091 .31532 m .60573 .31581 L .60625 .32669 L p .676 .531 .681 r
F P
0 g
s
.59634 .32676 m .60625 .32669 L .60573 .31581 L p .704 .554 .681 r
F P
0 g
s
.79523 .30165 m .78517 .31665 L .78901 .30959 L p 0 0 0 r
F P
0 g
s
.78901 .30959 m .79913 .29449 L .79523 .30164 L p 0 0 0 r
F P
0 g
s
.78901 .30959 m .79523 .30164 L .79523 .30165 L 0 0 0 r
F
.79012 .30805 m .78014 .32295 L .78517 .31665 L p .659 .879 .514 r
F P
0 g
s
.78517 .31665 m .78517 .31665 L p .78517 .31665 L .659 .879 .514 r
F P
0 g
s
.78517 .31665 m .79012 .30805 L .78517 .31665 L .659 .879 .514 r
F
.79523 .30164 m .79523 .30165 L p .79523 .30165 L 0 0 0 r
F P
0 g
s
.61644 .29006 m .62213 .28435 L .62063 .27527 L p .3 .188 .555 r
F P
0 g
s
.62213 .28435 m .61644 .29006 L .61897 .29948 L p .355 .269 .618 r
F P
0 g
s
.61464 .30279 m .61897 .29948 L .61644 .29006 L p .424 .311 .621 r
F P
0 g
s
.26924 .29006 m .29753 .27911 L .29725 .26963 L p .53 .34 .568 r
F P
0 g
s
.29753 .27911 m .26924 .29006 L .27062 .29989 L p .552 .388 .614 r
F P
0 g
s
.38995 .36899 m .36909 .36918 L .37038 .37578 L p .658 .749 .917 r
F P
0 g
s
.37038 .37578 m .38969 .37561 L .38995 .36899 L p .658 .749 .917 r
F P
0 g
s
.41193 .37031 m .38995 .36899 L .38969 .37561 L p .659 .75 .917 r
F P
0 g
s
.52725 .2763 m .50362 .27207 L .50324 .2816 L p .765 .53 .579 r
F P
0 g
s
.50324 .2816 m .52691 .28581 L .52725 .2763 L p .765 .53 .579 r
F P
0 g
s
.62704 .34455 m .62193 .34638 L .62562 .35642 L p .621 .568 .773 r
F P
0 g
s
.62562 .35642 m .63223 .35407 L .62704 .34455 L p .621 .568 .773 r
F P
0 g
s
.34648 .36362 m .32667 .36795 L .3318 .375 L p .659 .709 .884 r
F P
0 g
s
.3318 .375 m .3496 .37112 L .34648 .36362 L p .659 .709 .884 r
F P
0 g
s
.66277 .3594 m .65336 .36621 L .661 .37281 L p .611 .657 .871 r
F P
0 g
s
.661 .37281 m .67145 .36529 L .66277 .3594 L p .611 .657 .871 r
F P
0 g
s
.61897 .29948 m .61464 .30279 L .61786 .3126 L p .458 .368 .666 r
F P
0 g
s
.61494 .31421 m .61786 .3126 L .61464 .30279 L p .517 .402 .661 r
F P
0 g
s
.61325 .31483 m .61091 .31532 L .61234 .3261 L p .638 .505 .684 r
F P
0 g
s
.60625 .32669 m .61234 .3261 L .61091 .31532 L p .676 .531 .681 r
F P
0 g
s
.76683 .33284 m .75604 .3473 L .763 .34307 L p .772 .997 .835 r
F P
0 g
s
.763 .34307 m .77399 .32838 L .76683 .33284 L p .772 .997 .835 r
F P
0 g
s
.54863 .28953 m .52691 .28581 L .52617 .29593 L p .762 .556 .618 r
F P
0 g
s
.52617 .29593 m .54798 .29965 L .54863 .28953 L p .762 .556 .618 r
F P
0 g
s
.51148 .36833 m .48781 .36426 L .48485 .37265 L p .709 .713 .851 r
F P
0 g
s
.46092 .36872 m .48485 .37265 L .48781 .36426 L p .708 .712 .851 r
F P
0 g
s
.56741 .30257 m .54798 .29965 L .54695 .3102 L p .754 .574 .652 r
F P
0 g
s
.54695 .3102 m .56657 .31313 L .56741 .30257 L p .754 .574 .652 r
F P
0 g
s
.6186 .33597 m .61402 .33695 L .61593 .34765 L p .649 .559 .739 r
F P
0 g
s
.61593 .34765 m .62193 .34638 L .6186 .33597 L p .649 .559 .739 r
F P
0 g
s
.59601 .33772 m .58157 .33683 L .58039 .34763 L p .723 .614 .736 r
F P
0 g
s
.56228 .3456 m .58039 .34763 L .58157 .33683 L p .735 .626 .737 r
F P
0 g
s
.58039 .34763 m .56228 .3456 L .56034 .35603 L p .73 .645 .764 r
F P
0 g
s
.39379 .23529 m .36301 .23561 L .36242 .24232 L p .655 .328 .406 r
F P
0 g
s
.3302 .24574 m .36242 .24232 L .36301 .23561 L p .601 .282 .4 r
F P
0 g
s
.53952 .35299 m .56034 .35603 L .56228 .3456 L p .738 .653 .765 r
F P
0 g
s
.56034 .35603 m .53952 .35299 L .537 .36288 L p .73 .671 .792 r
F P
0 g
s
.58333 .31504 m .56657 .31313 L .56542 .32396 L p .742 .586 .682 r
F P
0 g
s
.56542 .32396 m .58256 .3259 L .58333 .31504 L p .742 .586 .682 r
F P
0 g
s
.60625 .32669 m .59634 .32676 L .59601 .33772 L p .705 .577 .709 r
F P
0 g
s
.59601 .33772 m .60682 .33764 L .60625 .32669 L p .705 .577 .709 r
F P
0 g
s
.58157 .33683 m .59601 .33772 L .59634 .32676 L p .725 .594 .709 r
F P
0 g
s
.63908 .35043 m .63223 .35407 L .63785 .36301 L p .601 .587 .81 r
F P
0 g
s
.63785 .36301 m .64601 .35871 L .63908 .35043 L p .601 .587 .81 r
F P
0 g
s
.59634 .32676 m .58256 .3259 L .58157 .33683 L p .725 .594 .709 r
F P
0 g
s
.61234 .3261 m .60625 .32669 L .60682 .33764 L p .678 .556 .709 r
F P
0 g
s
.60682 .33764 m .61402 .33695 L .61234 .3261 L p .678 .556 .709 r
F P
0 g
s
.51435 .35913 m .537 .36288 L .53952 .35299 L p .734 .675 .793 r
F P
0 g
s
.537 .36288 m .51435 .35913 L .51148 .36833 L p .723 .693 .821 r
F P
0 g
s
.61494 .31421 m .61325 .31483 L .61569 .3254 L p .59 .474 .689 r
F P
0 g
s
.61234 .3261 m .61569 .3254 L .61325 .31483 L p .638 .505 .684 r
F P
0 g
s
.48781 .36426 m .51148 .36833 L .51435 .35913 L p .724 .694 .821 r
F P
0 g
s
.36242 .24232 m .39366 .242 L .39379 .23529 L p .655 .328 .406 r
F P
0 g
s
.73041 .35333 m .71925 .36613 L .72803 .3657 L p .726 .893 .956 r
F P
0 g
s
.72803 .3657 m .73961 .35248 L .73041 .35333 L p .726 .893 .956 r
F P
0 g
s
.62063 .27527 m .6272 .26698 L .62692 .25822 L p .132 .017 .444 r
F P
0 g
s
.6272 .26698 m .62063 .27527 L .62213 .28435 L p .222 .136 .541 r
F P
0 g
s
.81716 .22343 m .80845 .23732 L .80459 .22848 L p .28 .257 .654 r
F P
0 g
s
.80459 .22848 m .81328 .21454 L .81716 .22343 L p .28 .257 .654 r
F P
0 g
s
.61569 .3254 m .61234 .3261 L .61402 .33695 L p .644 .532 .712 r
F P
0 g
s
.61786 .3126 m .61494 .31421 L .61832 .32444 L p .538 .444 .696 r
F P
0 g
s
.61569 .3254 m .61832 .32444 L .61494 .31421 L p .59 .474 .689 r
F P
0 g
s
.61402 .33695 m .6186 .33597 L .61569 .3254 L p .644 .532 .712 r
F P
0 g
s
.56399 .33484 m .58157 .33683 L .58256 .3259 L p .739 .606 .71 r
F P
0 g
s
.58157 .33683 m .56399 .33484 L .56228 .3456 L p .735 .626 .737 r
F P
0 g
s
.58256 .3259 m .56542 .32396 L .56399 .33484 L p .739 .606 .71 r
F P
0 g
s
.69092 .36023 m .68032 .37015 L .68923 .3739 L p .646 .745 .921 r
F P
0 g
s
.68923 .3739 m .70054 .36337 L .69092 .36023 L p .646 .745 .921 r
F P
0 g
s
.62238 .33461 m .6186 .33597 L .62193 .34638 L p .612 .537 .746 r
F P
0 g
s
.62193 .34638 m .62704 .34455 L .62238 .33461 L p .612 .537 .746 r
F P
0 g
s
.65917 .1989 m .66714 .18445 L .67412 .17963 L p .833 .998 .831 r
F P
0 g
s
.66714 .18445 m .65917 .1989 L .65324 .20461 L p .81 .985 .715 r
F P
0 g
s
.29765 .26088 m .32945 .25357 L .3302 .24574 L p .559 .289 .463 r
F P
0 g
s
.32945 .25357 m .29765 .26088 L .29725 .26963 L p .583 .347 .525 r
F P
0 g
s
.31702 .35103 m .29597 .3589 L .30235 .36713 L p .635 .632 .83 r
F P
0 g
s
.30235 .36713 m .32172 .35992 L .31702 .35103 L p .635 .632 .83 r
F P
0 g
s
.61832 .32444 m .61569 .3254 L .6186 .33597 L p .602 .506 .718 r
F P
0 g
s
.45139 .2471 m .42331 .24386 L .42336 .25166 L p .731 .434 .477 r
F P
0 g
s
.42336 .25166 m .45161 .25492 L .45139 .2471 L p .731 .434 .477 r
F P
0 g
s
.69067 .17306 m .69923 .15786 L .70852 .15629 L p .765 .889 .933 r
F P
0 g
s
.69923 .15786 m .69067 .17306 L .68201 .17582 L p .796 .934 .922 r
F P
0 g
s
.6186 .33597 m .62238 .33461 L .61832 .32444 L p .602 .506 .718 r
F P
0 g
s
.46092 .36872 m .437 .36526 L .43476 .37281 L p .688 .73 .883 r
F P
0 g
s
.41193 .37031 m .43476 .37281 L .437 .36526 L p .685 .728 .882 r
F P
0 g
s
.78688 .16225 m .77824 .17575 L .76888 .16998 L p .546 .593 .852 r
F P
0 g
s
.76888 .16998 m .7776 .15624 L .78688 .16225 L p .546 .593 .852 r
F P
0 g
s
.7776 .15624 m .76888 .16998 L .75907 .1651 L p .577 .634 .872 r
F P
0 g
s
.56657 .31313 m .54695 .3102 L .54556 .32101 L p .752 .595 .682 r
F P
0 g
s
.54556 .32101 m .56542 .32396 L .56657 .31313 L p .752 .595 .682 r
F P
0 g
s
.54181 .34259 m .56228 .3456 L .56399 .33484 L p .744 .634 .738 r
F P
0 g
s
.56228 .3456 m .54181 .34259 L .53952 .35299 L p .738 .653 .765 r
F P
0 g
s
.6327 .34152 m .62704 .34455 L .63223 .35407 L p .587 .552 .783 r
F P
0 g
s
.63223 .35407 m .63908 .35043 L .6327 .34152 L p .587 .552 .783 r
F P
0 g
s
.75907 .1651 m .76787 .15112 L .7776 .15624 L p .577 .634 .872 r
F P
0 g
s
.76787 .15112 m .75907 .1651 L .74894 .16119 L p .607 .675 .889 r
F P
0 g
s
.79555 .16905 m .78698 .18233 L .77824 .17575 L p .514 .551 .831 r
F P
0 g
s
.77824 .17575 m .78688 .16225 L .79555 .16905 L p .514 .551 .831 r
F P
0 g
s
.65443 .35257 m .64601 .35871 L .65336 .36621 L p .593 .618 .846 r
F P
0 g
s
.65336 .36621 m .66277 .3594 L .65443 .35257 L p .593 .618 .846 r
F P
0 g
s
.61786 .3126 m .6226 .30901 L .61897 .29948 L p .458 .368 .666 r
F P
0 g
s
.6226 .30901 m .61786 .3126 L .62199 .32244 L p .486 .417 .703 r
F P
0 g
s
.61832 .32444 m .62199 .32244 L .61786 .3126 L p .538 .444 .696 r
F P
0 g
s
.62199 .32244 m .61832 .32444 L .62238 .33461 L p .556 .482 .727 r
F P
0 g
s
.27062 .29989 m .2985 .28915 L .29753 .27911 L p .552 .388 .614 r
F P
0 g
s
.2985 .28915 m .27062 .29989 L .27291 .31001 L p .569 .43 .653 r
F P
0 g
s
.54798 .29965 m .52617 .29593 L .52504 .30648 L p .761 .579 .652 r
F P
0 g
s
.52504 .30648 m .54695 .3102 L .54798 .29965 L p .761 .579 .652 r
F P
0 g
s
.74894 .16119 m .75783 .14696 L .76787 .15112 L p .607 .675 .889 r
F P
0 g
s
.75783 .14696 m .74894 .16119 L .73866 .15832 L p .637 .715 .904 r
F P
0 g
s
.36242 .24232 m .3302 .24574 L .32945 .25357 L p .626 .346 .474 r
F P
0 g
s
.61897 .29948 m .62485 .29362 L .62213 .28435 L p .355 .269 .618 r
F P
0 g
s
.62485 .29362 m .61897 .29948 L .6226 .30901 L p .4 .335 .669 r
F P
0 g
s
.56542 .32396 m .54556 .32101 L .54384 .33186 L p .748 .615 .711 r
F P
0 g
s
.54384 .33186 m .56399 .33484 L .56542 .32396 L p .748 .615 .711 r
F P
0 g
s
.56399 .33484 m .54384 .33186 L .54181 .34259 L p .744 .634 .738 r
F P
0 g
s
.62697 .33214 m .62238 .33461 L .62704 .34455 L p .572 .518 .756 r
F P
0 g
s
.62704 .34455 m .6327 .34152 L .62697 .33214 L p .572 .518 .756 r
F P
0 g
s
.51704 .34924 m .53952 .35299 L .54181 .34259 L p .742 .657 .766 r
F P
0 g
s
.53952 .35299 m .51704 .34924 L .51435 .35913 L p .734 .675 .793 r
F P
0 g
s
.47835 .25897 m .45161 .25492 L .45152 .26368 L p .752 .488 .533 r
F P
0 g
s
.45152 .26368 m .47832 .26773 L .47835 .25897 L p .752 .488 .533 r
F P
0 g
s
.62238 .33461 m .62697 .33214 L .62199 .32244 L p .556 .482 .727 r
F P
0 g
s
.52691 .28581 m .50324 .2816 L .50247 .29173 L p .765 .558 .618 r
F P
0 g
s
.50247 .29173 m .52617 .29593 L .52691 .28581 L p .765 .558 .618 r
F P
0 g
s
.80349 .17653 m .79498 .18962 L .78698 .18233 L p .48 .505 .806 r
F P
0 g
s
.78698 .18233 m .79555 .16905 L .80349 .17653 L p .48 .505 .806 r
F P
0 g
s
.36784 .36148 m .34648 .36362 L .3496 .37112 L p .668 .714 .882 r
F P
0 g
s
.3496 .37112 m .36909 .36918 L .36784 .36148 L p .668 .714 .882 r
F P
0 g
s
.50362 .27207 m .47832 .26773 L .47793 .27726 L p .762 .528 .579 r
F P
0 g
s
.47793 .27726 m .50324 .2816 L .50362 .27207 L p .762 .528 .579 r
F P
0 g
s
.48781 .36426 m .46363 .36027 L .46092 .36872 L p .708 .712 .851 r
F P
0 g
s
.437 .36526 m .46092 .36872 L .46363 .36027 L p .706 .71 .851 r
F P
0 g
s
.62692 .25822 m .634 .24752 L .63503 .23913 L p 0 0 .266 r
F P
0 g
s
.634 .24752 m .62692 .25822 L .6272 .26698 L p .05 0 .418 r
F P
0 g
s
.49065 .35504 m .51435 .35913 L .51704 .34924 L p .735 .676 .793 r
F P
0 g
s
.51435 .35913 m .49065 .35504 L .48781 .36426 L p .724 .694 .821 r
F P
0 g
s
.81107 .27204 m .80176 .28672 L .80309 .27845 L p 0 0 .208 r
F P
0 g
s
.80309 .27845 m .81239 .26374 L .81107 .27204 L p 0 0 .208 r
F P
0 g
s
.64482 .21847 m .63735 .23127 L .63503 .23913 L p 0 0 .013 r
F P
0 g
s
.31267 .34144 m .29006 .34994 L .29597 .3589 L p .626 .599 .803 r
F P
0 g
s
.29597 .3589 m .31702 .35103 L .31267 .34144 L p .626 .599 .803 r
F P
0 g
s
.73866 .15832 m .74765 .14383 L .75783 .14696 L p .637 .715 .904 r
F P
0 g
s
.74765 .14383 m .73866 .15832 L .72839 .15653 L p .667 .757 .917 r
F P
0 g
s
.46363 .36027 m .48781 .36426 L .49065 .35504 L p .723 .693 .821 r
F P
0 g
s
.437 .36526 m .41337 .36266 L .41193 .37031 L p .685 .728 .882 r
F P
0 g
s
.38995 .36899 m .41193 .37031 L .41337 .36266 L p .681 .724 .882 r
F P
0 g
s
.78517 .31665 m .79523 .30165 L .79012 .30805 L p .659 .879 .514 r
F P
0 g
s
.64658 .34493 m .63908 .35043 L .64601 .35871 L p .574 .579 .82 r
F P
0 g
s
.64601 .35871 m .65443 .35257 L .64658 .34493 L p .574 .579 .82 r
F P
0 g
s
.62199 .32244 m .62726 .31848 L .6226 .30901 L p .486 .417 .703 r
F P
0 g
s
.62726 .31848 m .62199 .32244 L .62697 .33214 L p .511 .461 .737 r
F P
0 g
s
.68135 .35597 m .67145 .36529 L .68032 .37015 L p .622 .7 .9 r
F P
0 g
s
.68032 .37015 m .69092 .36023 L .68135 .35597 L p .622 .7 .9 r
F P
0 g
s
.34347 .35514 m .32172 .35992 L .32667 .36795 L p .66 .675 .853 r
F P
0 g
s
.32667 .36795 m .34648 .36362 L .34347 .35514 L p .66 .675 .853 r
F P
0 g
s
.81979 .23239 m .81106 .24624 L .80845 .23732 L p .207 .164 .587 r
F P
0 g
s
.80845 .23732 m .81716 .22343 L .81979 .23239 L p .207 .164 .587 r
F P
0 g
s
.72075 .353 m .71004 .36535 L .71925 .36613 L p .7 .842 .951 r
F P
0 g
s
.71925 .36613 m .73041 .35333 L .72075 .353 L p .7 .842 .951 r
F P
0 g
s
.42331 .24386 m .39366 .242 L .39349 .2498 L p .707 .415 .479 r
F P
0 g
s
.39349 .2498 m .42336 .25166 L .42331 .24386 L p .707 .415 .479 r
F P
0 g
s
.75876 .33626 m .7482 .35045 L .75604 .3473 L p .779 .98 .909 r
F P
0 g
s
.75604 .3473 m .76683 .33284 L .75876 .33626 L p .779 .98 .909 r
F P
0 g
s
.54695 .3102 m .52504 .30648 L .52353 .31728 L p .758 .601 .683 r
F P
0 g
s
.52353 .31728 m .54556 .32101 L .54695 .3102 L p .758 .601 .683 r
F P
0 g
s
.62213 .28435 m .62878 .27601 L .6272 .26698 L p .222 .136 .541 r
F P
0 g
s
.62878 .27601 m .62213 .28435 L .62485 .29362 L p .292 .23 .614 r
F P
0 g
s
.27291 .31001 m .30014 .29957 L .2985 .28915 L p .569 .43 .653 r
F P
0 g
s
.30014 .29957 m .27291 .31001 L .27605 .32026 L p .584 .468 .687 r
F P
0 g
s
.51949 .33885 m .54181 .34259 L .54384 .33186 L p .749 .639 .739 r
F P
0 g
s
.54181 .34259 m .51949 .33885 L .51704 .34924 L p .742 .657 .766 r
F P
0 g
s
.81056 .18459 m .8021 .1975 L .79498 .18962 L p .443 .456 .778 r
F P
0 g
s
.79498 .18962 m .80349 .17653 L .81056 .18459 L p .443 .456 .778 r
F P
0 g
s
.39024 .36128 m .36784 .36148 L .36909 .36918 L p .676 .719 .882 r
F P
0 g
s
.36909 .36918 m .38995 .36899 L .39024 .36128 L p .676 .719 .882 r
F P
0 g
s
.63935 .3366 m .6327 .34152 L .63908 .35043 L p .554 .541 .794 r
F P
0 g
s
.63908 .35043 m .64658 .34493 L .63935 .3366 L p .554 .541 .794 r
F P
0 g
s
.62697 .33214 m .63288 .32773 L .62726 .31848 L p .511 .461 .737 r
F P
0 g
s
.63288 .32773 m .62697 .33214 L .6327 .34152 L p .534 .502 .766 r
F P
0 g
s
.41337 .36266 m .39024 .36128 L .38995 .36899 L p .681 .724 .882 r
F P
0 g
s
.68201 .17582 m .69057 .16054 L .69923 .15786 L p .796 .934 .922 r
F P
0 g
s
.69057 .16054 m .68201 .17582 L .67412 .17963 L p .822 .974 .893 r
F P
0 g
s
.54556 .32101 m .52353 .31728 L .52167 .32814 L p .754 .62 .711 r
F P
0 g
s
.52167 .32814 m .54384 .33186 L .54556 .32101 L p .754 .62 .711 r
F P
0 g
s
.54384 .33186 m .52167 .32814 L .51949 .33885 L p .749 .639 .739 r
F P
0 g
s
.6226 .30901 m .62874 .30292 L .62485 .29362 L p .4 .335 .669 r
F P
0 g
s
.62874 .30292 m .6226 .30901 L .62726 .31848 L p .438 .393 .71 r
F P
0 g
s
.29725 .26963 m .32911 .26233 L .32945 .25357 L p .583 .347 .525 r
F P
0 g
s
.32911 .26233 m .29725 .26963 L .29753 .27911 L p .6 .394 .574 r
F P
0 g
s
.6327 .34152 m .63935 .3366 L .63288 .32773 L p .534 .502 .766 r
F P
0 g
s
.30874 .33132 m .2847 .3404 L .29006 .34994 L p .617 .567 .775 r
F P
0 g
s
.29006 .34994 m .31267 .34144 L .30874 .33132 L p .617 .567 .775 r
F P
0 g
s
.39366 .242 m .36242 .24232 L .36199 .25012 L p .673 .387 .478 r
F P
0 g
s
.32945 .25357 m .36199 .25012 L .36242 .24232 L p .626 .346 .474 r
F P
0 g
s
.65324 .20461 m .66118 .1902 L .66714 .18445 L p .81 .985 .715 r
F P
0 g
s
.72839 .15653 m .73747 .14178 L .74765 .14383 L p .667 .757 .917 r
F P
0 g
s
.73747 .14178 m .72839 .15653 L .71829 .15585 L p .698 .8 .928 r
F P
0 g
s
.52617 .29593 m .50247 .29173 L .50131 .30229 L p .763 .581 .652 r
F P
0 g
s
.50131 .30229 m .52504 .30648 L .52617 .29593 L p .763 .581 .652 r
F P
0 g
s
.36199 .25012 m .39349 .2498 L .39366 .242 L p .673 .387 .478 r
F P
0 g
s
.27605 .32026 m .30242 .3102 L .30014 .29957 L p .584 .468 .687 r
F P
0 g
s
.30242 .3102 m .27605 .32026 L .28001 .33045 L p .596 .502 .718 r
F P
0 g
s
.49331 .34514 m .51704 .34924 L .51949 .33885 L p .743 .658 .766 r
F P
0 g
s
.51704 .34924 m .49331 .34514 L .49065 .35504 L p .735 .676 .793 r
F P
0 g
s
.45161 .25492 m .42336 .25166 L .42322 .26043 L p .738 .476 .534 r
F P
0 g
s
.42322 .26043 m .45152 .26368 L .45161 .25492 L p .738 .476 .534 r
F P
0 g
s
.30531 .32085 m .28001 .33045 L .2847 .3404 L p .607 .535 .747 r
F P
0 g
s
.2847 .3404 m .30874 .33132 L .30531 .32085 L p .607 .535 .747 r
F P
0 g
s
.67199 .35065 m .66277 .3594 L .67145 .36529 L p .599 .657 .878 r
F P
0 g
s
.67145 .36529 m .68135 .35597 L .67199 .35065 L p .599 .657 .878 r
F P
0 g
s
.46363 .36027 m .43921 .35673 L .437 .36526 L p .706 .71 .851 r
F P
0 g
s
.41337 .36266 m .437 .36526 L .43921 .35673 L p .702 .705 .85 r
F P
0 g
s
.28001 .33045 m .30531 .32085 L .30242 .3102 L p .596 .502 .718 r
F P
0 g
s
.50324 .2816 m .47793 .27726 L .47718 .28742 L p .762 .556 .618 r
F P
0 g
s
.47718 .28742 m .50247 .29173 L .50324 .2816 L p .762 .556 .618 r
F P
0 g
s
.81666 .19309 m .80824 .20585 L .8021 .1975 L p .401 .401 .745 r
F P
0 g
s
.8021 .1975 m .81056 .18459 L .81666 .19309 L p .401 .401 .745 r
F P
0 g
s
.47832 .26773 m .45152 .26368 L .45115 .27324 L p .755 .522 .579 r
F P
0 g
s
.45115 .27324 m .47793 .27726 L .47832 .26773 L p .755 .522 .579 r
F P
0 g
s
.46622 .35099 m .49065 .35504 L .49331 .34514 L p .734 .675 .793 r
F P
0 g
s
.49065 .35504 m .46622 .35099 L .46363 .36027 L p .723 .693 .821 r
F P
0 g
s
.62726 .31848 m .63375 .31209 L .62874 .30292 L p .438 .393 .71 r
F P
0 g
s
.63375 .31209 m .62726 .31848 L .63288 .32773 L p .471 .443 .746 r
F P
0 g
s
.36199 .25012 m .32945 .25357 L .32911 .26233 L p .642 .396 .531 r
F P
0 g
s
.43921 .35673 m .46363 .36027 L .46622 .35099 L p .72 .69 .821 r
F P
0 g
s
.52504 .30648 m .50131 .30229 L .49978 .31311 L p .76 .602 .683 r
F P
0 g
s
.49978 .31311 m .52353 .31728 L .52504 .30648 L p .76 .602 .683 r
F P
0 g
s
.7108 .35148 m .70054 .36337 L .71004 .36535 L p .672 .792 .938 r
F P
0 g
s
.71004 .36535 m .72075 .353 L .7108 .35148 L p .672 .792 .938 r
F P
0 g
s
.6272 .26698 m .6343 .25629 L .634 .24752 L p .05 0 .418 r
F P
0 g
s
.6343 .25629 m .6272 .26698 L .62878 .27601 L p .158 .093 .528 r
F P
0 g
s
.62485 .29362 m .63162 .28517 L .62878 .27601 L p .292 .23 .614 r
F P
0 g
s
.63162 .28517 m .62485 .29362 L .62874 .30292 L p .349 .308 .67 r
F P
0 g
s
.49575 .33472 m .51949 .33885 L .52167 .32814 L p .75 .64 .739 r
F P
0 g
s
.51949 .33885 m .49575 .33472 L .49331 .34514 L p .743 .658 .766 r
F P
0 g
s
.34064 .34582 m .31702 .35103 L .32172 .35992 L p .658 .643 .824 r
F P
0 g
s
.32172 .35992 m .34347 .35514 L .34064 .34582 L p .658 .643 .824 r
F P
0 g
s
.82114 .24128 m .81238 .2551 L .81106 .24624 L p .115 .049 .498 r
F P
0 g
s
.81106 .24624 m .81979 .23239 L .82114 .24128 L p .115 .049 .498 r
F P
0 g
s
.36665 .3528 m .34347 .35514 L .34648 .36362 L p .675 .683 .85 r
F P
0 g
s
.34648 .36362 m .36784 .36148 L .36665 .3528 L p .675 .683 .85 r
F P
0 g
s
.80843 .27984 m .79913 .29449 L .80176 .28672 L p 0 0 0 r
F P
0 g
s
.80176 .28672 m .81107 .27204 L .80843 .27984 L p 0 0 0 r
F P
0 g
s
.71829 .15585 m .72745 .14085 L .73747 .14178 L p .698 .8 .928 r
F P
0 g
s
.72745 .14085 m .71829 .15585 L .70852 .15629 L p .73 .845 .935 r
F P
0 g
s
.63503 .23913 m .64247 .22639 L .64482 .21847 L p 0 0 .013 r
F P
0 g
s
.64247 .22639 m .63503 .23913 L .634 .24752 L p 0 0 .233 r
F P
0 g
s
.663 .34438 m .65443 .35257 L .66277 .3594 L p .575 .615 .855 r
F P
0 g
s
.66277 .3594 m .67199 .35065 L .663 .34438 L p .575 .615 .855 r
F P
0 g
s
.74991 .33856 m .73961 .35248 L .7482 .35045 L p .762 .938 .941 r
F P
0 g
s
.7482 .35045 m .75876 .33626 L .74991 .33856 L p .762 .938 .941 r
F P
0 g
s
.78387 .31361 m .77399 .32838 L .78014 .32295 L p .76 .977 .717 r
F P
0 g
s
.78014 .32295 m .79012 .30805 L .78387 .31361 L p .76 .977 .717 r
F P
0 g
s
.52353 .31728 m .49978 .31311 L .49792 .32398 L p .755 .622 .712 r
F P
0 g
s
.49792 .32398 m .52167 .32814 L .52353 .31728 L p .755 .622 .712 r
F P
0 g
s
.52167 .32814 m .49792 .32398 L .49575 .33472 L p .75 .64 .739 r
F P
0 g
s
.43921 .35673 m .41479 .35404 L .41337 .36266 L p .702 .705 .85 r
F P
0 g
s
.39024 .36128 m .41337 .36266 L .41479 .35404 L p .696 .7 .849 r
F P
0 g
s
.29753 .27911 m .3292 .27188 L .32911 .26233 L p .6 .394 .574 r
F P
0 g
s
.3292 .27188 m .29753 .27911 L .2985 .28915 L p .614 .434 .615 r
F P
0 g
s
.63288 .32773 m .63979 .32097 L .63375 .31209 L p .471 .443 .746 r
F P
0 g
s
.63979 .32097 m .63288 .32773 L .63935 .3366 L p .5 .489 .777 r
F P
0 g
s
.67412 .17963 m .68268 .16428 L .69057 .16054 L p .822 .974 .893 r
F P
0 g
s
.68268 .16428 m .67412 .17963 L .66714 .18445 L p .832 .998 .83 r
F P
0 g
s
.42336 .25166 m .39349 .2498 L .39329 .25857 L p .716 .458 .534 r
F P
0 g
s
.39329 .25857 m .42322 .26043 L .42336 .25166 L p .716 .458 .534 r
F P
0 g
s
.82168 .20191 m .81328 .21454 L .80824 .20585 L p .353 .339 .704 r
F P
0 g
s
.80824 .20585 m .81666 .19309 L .82168 .20191 L p .353 .339 .704 r
F P
0 g
s
.50247 .29173 m .47718 .28742 L .47608 .29801 L p .761 .579 .652 r
F P
0 g
s
.47608 .29801 m .50131 .30229 L .50247 .29173 L p .761 .579 .652 r
F P
0 g
s
.65454 .33726 m .64658 .34493 L .65443 .35257 L p .551 .574 .831 r
F P
0 g
s
.65443 .35257 m .663 .34438 L .65454 .33726 L p .551 .574 .831 r
F P
0 g
s
.46866 .34103 m .49331 .34514 L .49575 .33472 L p .742 .657 .766 r
F P
0 g
s
.49331 .34514 m .46866 .34103 L .46622 .35099 L p .734 .675 .793 r
F P
0 g
s
.63935 .3366 m .64676 .32941 L .63979 .32097 L p .5 .489 .777 r
F P
0 g
s
.64676 .32941 m .63935 .3366 L .64658 .34493 L p .526 .533 .805 r
F P
0 g
s
.39055 .35258 m .36665 .3528 L .36784 .36148 L p .688 .692 .849 r
F P
0 g
s
.36784 .36148 m .39024 .36128 L .39055 .35258 L p .688 .692 .849 r
F P
0 g
s
.64658 .34493 m .65454 .33726 L .64676 .32941 L p .526 .533 .805 r
F P
0 g
s
.41479 .35404 m .39055 .35258 L .39024 .36128 L p .696 .7 .849 r
F P
0 g
s
.39349 .2498 m .36199 .25012 L .36172 .25889 L p .685 .432 .534 r
F P
0 g
s
.32911 .26233 m .36172 .25889 L .36199 .25012 L p .642 .396 .531 r
F P
0 g
s
.47793 .27726 m .45115 .27324 L .45048 .28342 L p .755 .549 .618 r
F P
0 g
s
.45048 .28342 m .47718 .28742 L .47793 .27726 L p .755 .549 .618 r
F P
0 g
s
.45152 .26368 m .42322 .26043 L .42289 .27 L p .742 .51 .579 r
F P
0 g
s
.42289 .27 m .45115 .27324 L .45152 .26368 L p .742 .51 .579 r
F P
0 g
s
.70073 .34878 m .69092 .36023 L .70054 .36337 L p .644 .745 .922 r
F P
0 g
s
.70054 .36337 m .7108 .35148 L .70073 .34878 L p .644 .745 .922 r
F P
0 g
s
.62874 .30292 m .63569 .29431 L .63162 .28517 L p .349 .308 .67 r
F P
0 g
s
.63569 .29431 m .62874 .30292 L .63375 .31209 L p .396 .373 .716 r
F P
0 g
s
.46622 .35099 m .44134 .34737 L .43921 .35673 L p .72 .69 .821 r
F P
0 g
s
.41479 .35404 m .43921 .35673 L .44134 .34737 L p .715 .685 .82 r
F P
0 g
s
.36172 .25889 m .39329 .25857 L .39349 .2498 L p .685 .432 .534 r
F P
0 g
s
.33802 .33582 m .31267 .34144 L .31702 .35103 L p .656 .614 .795 r
F P
0 g
s
.31702 .35103 m .34064 .34582 L .33802 .33582 L p .656 .614 .795 r
F P
0 g
s
.44134 .34737 m .46622 .35099 L .46866 .34103 L p .73 .671 .792 r
F P
0 g
s
.70852 .15629 m .71777 .14106 L .72745 .14085 L p .73 .845 .935 r
F P
0 g
s
.71777 .14106 m .70852 .15629 L .69923 .15786 L p .762 .891 .935 r
F P
0 g
s
.50131 .30229 m .47608 .29801 L .47465 .30887 L p .758 .601 .683 r
F P
0 g
s
.47465 .30887 m .49978 .31311 L .50131 .30229 L p .758 .601 .683 r
F P
0 g
s
.47091 .33057 m .49575 .33472 L .49792 .32398 L p .748 .639 .739 r
F P
0 g
s
.49575 .33472 m .47091 .33057 L .46866 .34103 L p .742 .657 .766 r
F P
0 g
s
.62878 .27601 m .63592 .26531 L .6343 .25629 L p .158 .093 .528 r
F P
0 g
s
.63592 .26531 m .62878 .27601 L .63162 .28517 L p .241 .2 .609 r
F P
0 g
s
.2985 .28915 m .3297 .28206 L .3292 .27188 L p .614 .434 .615 r
F P
0 g
s
.3297 .28206 m .2985 .28915 L .30014 .29957 L p .625 .469 .651 r
F P
0 g
s
.36172 .25889 m .32911 .26233 L .3292 .27188 L p .654 .437 .577 r
F P
0 g
s
.82117 .24994 m .81239 .26374 L .81238 .2551 L p 0 0 .377 r
F P
0 g
s
.81238 .2551 m .82114 .24128 L .82117 .24994 L p 0 0 .377 r
F P
0 g
s
.36555 .3433 m .34064 .34582 L .34347 .35514 L p .679 .656 .82 r
F P
0 g
s
.34347 .35514 m .36665 .3528 L .36555 .3433 L p .679 .656 .82 r
F P
0 g
s
.49978 .31311 m .47465 .30887 L .47292 .31978 L p .754 .62 .711 r
F P
0 g
s
.47292 .31978 m .49792 .32398 L .49978 .31311 L p .754 .62 .711 r
F P
0 g
s
.74044 .33971 m .73041 .35333 L .73961 .35248 L p .735 .889 .95 r
F P
0 g
s
.73961 .35248 m .74991 .33856 L .74044 .33971 L p .735 .889 .95 r
F P
0 g
s
.49792 .32398 m .47292 .31978 L .47091 .33057 L p .748 .639 .739 r
F P
0 g
s
.82554 .2109 m .81716 .22343 L .81328 .21454 L p .296 .265 .654 r
F P
0 g
s
.81328 .21454 m .82168 .20191 L .82554 .2109 L p .296 .265 .654 r
F P
0 g
s
.80451 .28703 m .79523 .30165 L .79913 .29449 L p 0 0 0 r
F P
0 g
s
.79913 .29449 m .80843 .27984 L .80451 .28703 L p 0 0 0 r
F P
0 g
s
.634 .24752 m .64145 .23482 L .64247 .22639 L p 0 0 .233 r
F P
0 g
s
.64145 .23482 m .634 .24752 L .6343 .25629 L p 0 0 .398 r
F P
0 g
s
.77659 .31821 m .76683 .33284 L .77399 .32838 L p .796 .999 .842 r
F P
0 g
s
.77399 .32838 m .78387 .31361 L .77659 .31821 L p .796 .999 .842 r
F P
0 g
s
.6907 .34497 m .68135 .35597 L .69092 .36023 L p .617 .7 .904 r
F P
0 g
s
.69092 .36023 m .70073 .34878 L .6907 .34497 L p .617 .7 .904 r
F P
0 g
s
.79568 .15008 m .78688 .16225 L .7776 .15624 L p .553 .593 .848 r
F P
0 g
s
.7776 .15624 m .78661 .1437 L .79568 .15008 L p .553 .593 .848 r
F P
0 g
s
.78661 .1437 m .7776 .15624 L .76787 .15112 L p .582 .634 .868 r
F P
0 g
s
.33567 .32532 m .30874 .33132 L .31267 .34144 L p .652 .586 .768 r
F P
0 g
s
.31267 .34144 m .33802 .33582 L .33567 .32532 L p .652 .586 .768 r
F P
0 g
s
.63375 .31209 m .64092 .30326 L .63569 .29431 L p .396 .373 .716 r
F P
0 g
s
.64092 .30326 m .63375 .31209 L .63979 .32097 L p .436 .43 .753 r
F P
0 g
s
.44134 .34737 m .41618 .34458 L .41479 .35404 L p .715 .685 .82 r
F P
0 g
s
.39055 .35258 m .41479 .35404 L .41618 .34458 L p .707 .677 .819 r
F P
0 g
s
.47718 .28742 m .45048 .28342 L .44953 .29406 L p .754 .574 .652 r
F P
0 g
s
.44953 .29406 m .47608 .29801 L .47718 .28742 L p .754 .574 .652 r
F P
0 g
s
.66714 .18445 m .67571 .16904 L .68268 .16428 L p .832 .998 .83 r
F P
0 g
s
.67571 .16904 m .66714 .18445 L .66118 .1902 L p .808 .984 .714 r
F P
0 g
s
.42322 .26043 m .39329 .25857 L .39305 .26816 L p .722 .493 .579 r
F P
0 g
s
.39305 .26816 m .42289 .27 L .42322 .26043 L p .722 .493 .579 r
F P
0 g
s
.80417 .15723 m .79555 .16905 L .78688 .16225 L p .523 .552 .826 r
F P
0 g
s
.78688 .16225 m .79568 .15008 L .80417 .15723 L p .523 .552 .826 r
F P
0 g
s
.76787 .15112 m .77709 .13817 L .78661 .1437 L p .582 .634 .868 r
F P
0 g
s
.77709 .13817 m .76787 .15112 L .75783 .14696 L p .61 .674 .887 r
F P
0 g
s
.44335 .33733 m .46866 .34103 L .47091 .33057 L p .738 .653 .765 r
F P
0 g
s
.46866 .34103 m .44335 .33733 L .44134 .34737 L p .73 .671 .792 r
F P
0 g
s
.30014 .29957 m .33062 .29268 L .3297 .28206 L p .625 .469 .651 r
F P
0 g
s
.33062 .29268 m .30014 .29957 L .30242 .3102 L p .633 .5 .683 r
F P
0 g
s
.45115 .27324 m .42289 .27 L .42238 .28022 L p .743 .539 .618 r
F P
0 g
s
.42238 .28022 m .45048 .28342 L .45115 .27324 L p .743 .539 .618 r
F P
0 g
s
.41618 .34458 m .44134 .34737 L .44335 .33733 L p .724 .665 .791 r
F P
0 g
s
.69923 .15786 m .70857 .1424 L .71777 .14106 L p .762 .891 .935 r
F P
0 g
s
.70857 .1424 m .69923 .15786 L .69057 .16054 L p .792 .937 .925 r
F P
0 g
s
.81193 .16503 m .80349 .17653 L .79555 .16905 L p .491 .508 .802 r
F P
0 g
s
.79555 .16905 m .80417 .15723 L .81193 .16503 L p .491 .508 .802 r
F P
0 g
s
.39087 .34306 m .36555 .3433 L .36665 .3528 L p .695 .667 .819 r
F P
0 g
s
.36665 .3528 m .39055 .35258 L .39087 .34306 L p .695 .667 .819 r
F P
0 g
s
.75783 .14696 m .76728 .1336 L .77709 .13817 L p .61 .674 .887 r
F P
0 g
s
.76728 .1336 m .75783 .14696 L .74765 .14383 L p .638 .715 .903 r
F P
0 g
s
.41618 .34458 m .39087 .34306 L .39055 .35258 L p .707 .677 .819 r
F P
0 g
s
.33363 .3145 m .30531 .32085 L .30874 .33132 L p .647 .558 .741 r
F P
0 g
s
.30874 .33132 m .33567 .32532 L .33363 .3145 L p .647 .558 .741 r
F P
0 g
s
.65271 .20412 m .64482 .21847 L .64247 .22639 L p 0 0 0 r
F P
0 g
s
.39329 .25857 m .36172 .25889 L .36162 .26847 L p .693 .469 .579 r
F P
0 g
s
.3292 .27188 m .36162 .26847 L .36172 .25889 L p .654 .437 .577 r
F P
0 g
s
.30242 .3102 m .33194 .30356 L .33062 .29268 L p .633 .5 .683 r
F P
0 g
s
.33194 .30356 m .30242 .3102 L .30531 .32085 L p .641 .53 .712 r
F P
0 g
s
.68091 .34009 m .67199 .35065 L .68135 .35597 L p .59 .657 .884 r
F P
0 g
s
.68135 .35597 m .6907 .34497 L .68091 .34009 L p .59 .657 .884 r
F P
0 g
s
.36162 .26847 m .39305 .26816 L .39329 .25857 L p .693 .469 .579 r
F P
0 g
s
.63979 .32097 m .64723 .31187 L .64092 .30326 L p .436 .43 .753 r
F P
0 g
s
.64723 .31187 m .63979 .32097 L .64676 .32941 L p .472 .48 .786 r
F P
0 g
s
.47608 .29801 m .44953 .29406 L .44832 .30496 L p .752 .595 .682 r
F P
0 g
s
.44832 .30496 m .47465 .30887 L .47608 .29801 L p .752 .595 .682 r
F P
0 g
s
.30531 .32085 m .33363 .3145 L .33194 .30356 L p .641 .53 .712 r
F P
0 g
s
.63162 .28517 m .63885 .27441 L .63592 .26531 L p .241 .2 .609 r
F P
0 g
s
.63885 .27441 m .63162 .28517 L .63569 .29431 L p .308 .286 .671 r
F P
0 g
s
.36162 .26847 m .3292 .27188 L .3297 .28206 L p .662 .471 .616 r
F P
0 g
s
.4452 .32679 m .47091 .33057 L .47292 .31978 L p .744 .634 .738 r
F P
0 g
s
.47091 .33057 m .4452 .32679 L .44335 .33733 L p .738 .653 .765 r
F P
0 g
s
.36456 .33312 m .33802 .33582 L .34064 .34582 L p .68 .629 .791 r
F P
0 g
s
.34064 .34582 m .36555 .3433 L .36456 .33312 L p .68 .629 .791 r
F P
0 g
s
.81886 .17336 m .81056 .18459 L .80349 .17653 L p .457 .46 .774 r
F P
0 g
s
.80349 .17653 m .81193 .16503 L .81886 .17336 L p .457 .46 .774 r
F P
0 g
s
.7305 .33967 m .72075 .353 L .73041 .35333 L p .705 .839 .947 r
F P
0 g
s
.73041 .35333 m .74044 .33971 L .7305 .33967 L p .705 .839 .947 r
F P
0 g
s
.74765 .14383 m .75732 .13005 L .76728 .1336 L p .638 .715 .903 r
F P
0 g
s
.75732 .13005 m .74765 .14383 L .73747 .14178 L p .667 .757 .918 r
F P
0 g
s
.82818 .21993 m .81979 .23239 L .81716 .22343 L p .226 .176 .59 r
F P
0 g
s
.81716 .22343 m .82554 .2109 L .82818 .21993 L p .226 .176 .59 r
F P
0 g
s
.47465 .30887 m .44832 .30496 L .44687 .31594 L p .748 .615 .711 r
F P
0 g
s
.44687 .31594 m .47292 .31978 L .47465 .30887 L p .748 .615 .711 r
F P
0 g
s
.47292 .31978 m .44687 .31594 L .4452 .32679 L p .744 .634 .738 r
F P
0 g
s
.6715 .33423 m .663 .34438 L .67199 .35065 L p .562 .614 .862 r
F P
0 g
s
.67199 .35065 m .68091 .34009 L .6715 .33423 L p .562 .614 .862 r
F P
0 g
s
.64676 .32941 m .65452 .32 L .64723 .31187 L p .472 .48 .786 r
F P
0 g
s
.65452 .32 m .64676 .32941 L .65454 .33726 L p .504 .527 .814 r
F P
0 g
s
.81987 .25823 m .81107 .27204 L .81239 .26374 L p 0 0 .21 r
F P
0 g
s
.81239 .26374 m .82117 .24994 L .81987 .25823 L p 0 0 .21 r
F P
0 g
s
.44335 .33733 m .4175 .33445 L .41618 .34458 L p .724 .665 .791 r
F P
0 g
s
.39087 .34306 m .41618 .34458 L .4175 .33445 L p .714 .656 .791 r
F P
0 g
s
.45048 .28342 m .42238 .28022 L .4217 .2909 L p .743 .563 .651 r
F P
0 g
s
.4217 .2909 m .44953 .29406 L .45048 .28342 L p .743 .563 .651 r
F P
0 g
s
.4175 .33445 m .44335 .33733 L .4452 .32679 L p .73 .645 .764 r
F P
0 g
s
.42289 .27 m .39305 .26816 L .39279 .2784 L p .725 .523 .617 r
F P
0 g
s
.39279 .2784 m .42238 .28022 L .42289 .27 L p .725 .523 .617 r
F P
0 g
s
.66266 .32749 m .65454 .33726 L .663 .34438 L p .534 .571 .839 r
F P
0 g
s
.663 .34438 m .6715 .33423 L .66266 .32749 L p .534 .571 .839 r
F P
0 g
s
.65454 .33726 m .66266 .32749 L .65452 .32 L p .504 .527 .814 r
F P
0 g
s
.6343 .25629 m .64176 .24362 L .64145 .23482 L p 0 0 .398 r
F P
0 g
s
.64176 .24362 m .6343 .25629 L .63592 .26531 L p .113 .063 .517 r
F P
0 g
s
.76838 .32177 m .75876 .33626 L .76683 .33284 L p .792 .976 .908 r
F P
0 g
s
.76683 .33284 m .77659 .31821 L .76838 .32177 L p .792 .976 .908 r
F P
0 g
s
.79937 .29348 m .79012 .30805 L .79523 .30165 L p .687 .895 .532 r
F P
0 g
s
.79523 .30165 m .80451 .28703 L .79937 .29348 L p .687 .895 .532 r
F P
0 g
s
.82484 .1821 m .81666 .19309 L .81056 .18459 L p .419 .408 .741 r
F P
0 g
s
.81056 .18459 m .81886 .17336 L .82484 .1821 L p .419 .408 .741 r
F P
0 g
s
.66118 .1902 m .66975 .17474 L .67571 .16904 L p .808 .984 .714 r
F P
0 g
s
.66975 .17474 m .66118 .1902 L .65634 .19679 L p .725 .901 .524 r
F P
0 g
s
.3912 .33287 m .36456 .33312 L .36555 .3433 L p .7 .644 .79 r
F P
0 g
s
.36555 .3433 m .39087 .34306 L .3912 .33287 L p .7 .644 .79 r
F P
0 g
s
.3297 .28206 m .3617 .27871 L .36162 .26847 L p .662 .471 .616 r
F P
0 g
s
.3617 .27871 m .3297 .28206 L .33062 .29268 L p .668 .502 .65 r
F P
0 g
s
.69057 .16054 m .69999 .14486 L .70857 .1424 L p .792 .937 .925 r
F P
0 g
s
.69999 .14486 m .69057 .16054 L .68268 .16428 L p .816 .977 .894 r
F P
0 g
s
.73747 .14178 m .74737 .12758 L .75732 .13005 L p .667 .757 .918 r
F P
0 g
s
.74737 .12758 m .73747 .14178 L .72745 .14085 L p .696 .801 .93 r
F P
0 g
s
.4175 .33445 m .3912 .33287 L .39087 .34306 L p .714 .656 .791 r
F P
0 g
s
.36368 .32245 m .33567 .32532 L .33802 .33582 L p .68 .604 .764 r
F P
0 g
s
.33802 .33582 m .36456 .33312 L .36368 .32245 L p .68 .604 .764 r
F P
0 g
s
.39305 .26816 m .36162 .26847 L .3617 .27871 L p .698 .501 .617 r
F P
0 g
s
.63569 .29431 m .64303 .28344 L .63885 .27441 L p .308 .286 .671 r
F P
0 g
s
.64303 .28344 m .63569 .29431 L .64092 .30326 L p .363 .358 .72 r
F P
0 g
s
.3617 .27871 m .39279 .2784 L .39305 .26816 L p .698 .501 .617 r
F P
0 g
s
.44953 .29406 m .4217 .2909 L .42085 .30186 L p .741 .586 .682 r
F P
0 g
s
.42085 .30186 m .44832 .30496 L .44953 .29406 L p .741 .586 .682 r
F P
0 g
s
.41873 .32383 m .4452 .32679 L .44687 .31594 L p .735 .626 .737 r
F P
0 g
s
.4452 .32679 m .41873 .32383 L .4175 .33445 L p .73 .645 .764 r
F P
0 g
s
.72027 .33845 m .7108 .35148 L .72075 .353 L p .674 .791 .937 r
F P
0 g
s
.72075 .353 m .7305 .33967 L .72027 .33845 L p .674 .791 .937 r
F P
0 g
s
.64247 .22639 m .65037 .21208 L .65271 .20412 L p 0 0 0 r
F P
0 g
s
.65037 .21208 m .64247 .22639 L .64145 .23482 L p 0 0 .216 r
F P
0 g
s
.3912 .33287 m .4175 .33445 L .41873 .32383 L p .719 .635 .763 r
F P
0 g
s
.44832 .30496 m .42085 .30186 L .41986 .3129 L p .739 .606 .71 r
F P
0 g
s
.41986 .3129 m .44687 .31594 L .44832 .30496 L p .739 .606 .71 r
F P
0 g
s
.44687 .31594 m .41986 .3129 L .41873 .32383 L p .735 .626 .737 r
F P
0 g
s
.42238 .28022 m .39279 .2784 L .3925 .28911 L p .726 .549 .651 r
F P
0 g
s
.3925 .28911 m .4217 .2909 L .42238 .28022 L p .726 .549 .651 r
F P
0 g
s
.33062 .29268 m .36195 .28942 L .3617 .27871 L p .668 .502 .65 r
F P
0 g
s
.36195 .28942 m .33062 .29268 L .33194 .30356 L p .673 .529 .681 r
F P
0 g
s
.82954 .22885 m .82114 .24128 L .81979 .23239 L p .14 .066 .504 r
F P
0 g
s
.81979 .23239 m .82818 .21993 L .82954 .22885 L p .14 .066 .504 r
F P
0 g
s
.36295 .31148 m .33363 .3145 L .33567 .32532 L p .679 .58 .737 r
F P
0 g
s
.33567 .32532 m .36368 .32245 L .36295 .31148 L p .679 .58 .737 r
F P
0 g
s
.82977 .19111 m .82168 .20191 L .81666 .19309 L p .375 .349 .702 r
F P
0 g
s
.81666 .19309 m .82484 .1821 L .82977 .19111 L p .375 .349 .702 r
F P
0 g
s
.72745 .14085 m .73759 .12624 L .74737 .12758 L p .696 .801 .93 r
F P
0 g
s
.73759 .12624 m .72745 .14085 L .71777 .14106 L p .726 .847 .938 r
F P
0 g
s
.39153 .32218 m .36368 .32245 L .36456 .33312 L p .702 .621 .763 r
F P
0 g
s
.36456 .33312 m .3912 .33287 L .39153 .32218 L p .702 .621 .763 r
F P
0 g
s
.33194 .30356 m .36237 .30041 L .36195 .28942 L p .673 .529 .681 r
F P
0 g
s
.36237 .30041 m .33194 .30356 L .33363 .3145 L p .677 .555 .71 r
F P
0 g
s
.33363 .3145 m .36295 .31148 L .36237 .30041 L p .677 .555 .71 r
F P
0 g
s
.41873 .32383 m .39153 .32218 L .3912 .33287 L p .719 .635 .763 r
F P
0 g
s
.39279 .2784 m .3617 .27871 L .36195 .28942 L p .702 .528 .65 r
F P
0 g
s
.81725 .26603 m .80843 .27984 L .81107 .27204 L p 0 0 0 r
F P
0 g
s
.81107 .27204 m .81987 .25823 L .81725 .26603 L p 0 0 0 r
F P
0 g
s
.63592 .26531 m .64342 .25263 L .64176 .24362 L p .113 .063 .517 r
F P
0 g
s
.64342 .25263 m .63592 .26531 L .63885 .27441 L p .206 .179 .605 r
F P
0 g
s
.64092 .30326 m .64841 .29226 L .64303 .28344 L p .363 .358 .72 r
F P
0 g
s
.64841 .29226 m .64092 .30326 L .64723 .31187 L p .41 .42 .759 r
F P
0 g
s
.36195 .28942 m .3925 .28911 L .39279 .2784 L p .702 .528 .65 r
F P
0 g
s
.75939 .32423 m .74991 .33856 L .75876 .33626 L p .77 .934 .937 r
F P
0 g
s
.75876 .33626 m .76838 .32177 L .75939 .32423 L p .77 .934 .937 r
F P
0 g
s
.39153 .32218 m .41873 .32383 L .41986 .3129 L p .722 .614 .736 r
F P
0 g
s
.4217 .2909 m .3925 .28911 L .39219 .30011 L p .726 .572 .681 r
F P
0 g
s
.39219 .30011 m .42085 .30186 L .4217 .2909 L p .726 .572 .681 r
F P
0 g
s
.7099 .33606 m .70073 .34878 L .7108 .35148 L p .644 .745 .923 r
F P
0 g
s
.7108 .35148 m .72027 .33845 L .7099 .33606 L p .644 .745 .923 r
F P
0 g
s
.79308 .29907 m .78387 .31361 L .79012 .30805 L p .777 .983 .726 r
F P
0 g
s
.79012 .30805 m .79937 .29348 L .79308 .29907 L p .777 .983 .726 r
F P
0 g
s
.68268 .16428 m .69218 .14841 L .69999 .14486 L p .816 .977 .894 r
F P
0 g
s
.69218 .14841 m .68268 .16428 L .67571 .16904 L p .821 1 .827 r
F P
0 g
s
.39186 .3112 m .41986 .3129 L .42085 .30186 L p .725 .594 .709 r
F P
0 g
s
.41986 .3129 m .39186 .3112 L .39153 .32218 L p .722 .614 .736 r
F P
0 g
s
.42085 .30186 m .39219 .30011 L .39186 .3112 L p .725 .594 .709 r
F P
0 g
s
.65634 .19679 m .66493 .18129 L .66975 .17474 L p .725 .901 .524 r
F P
0 g
s
.66493 .18129 m .65634 .19679 L .65271 .20412 L p 0 0 0 r
F P
0 g
s
.39186 .3112 m .36295 .31148 L .36368 .32245 L p .704 .599 .736 r
F P
0 g
s
.36368 .32245 m .39153 .32218 L .39186 .3112 L p .704 .599 .736 r
F P
0 g
s
.3925 .28911 m .36195 .28942 L .36237 .30041 L p .703 .553 .68 r
F P
0 g
s
.36237 .30041 m .39219 .30011 L .3925 .28911 L p .703 .553 .68 r
F P
0 g
s
.64723 .31187 m .6549 .3007 L .64841 .29226 L p .41 .42 .759 r
F P
0 g
s
.6549 .3007 m .64723 .31187 L .65452 .32 L p .451 .474 .792 r
F P
0 g
s
.83357 .20024 m .82554 .2109 L .82168 .20191 L p .324 .28 .654 r
F P
0 g
s
.82168 .20191 m .82977 .19111 L .83357 .20024 L p .324 .28 .654 r
F P
0 g
s
.6996 .33254 m .6907 .34497 L .70073 .34878 L p .614 .701 .906 r
F P
0 g
s
.70073 .34878 m .7099 .33606 L .6996 .33254 L p .614 .701 .906 r
F P
0 g
s
.39219 .30011 m .36237 .30041 L .36295 .31148 L p .704 .576 .709 r
F P
0 g
s
.36295 .31148 m .39186 .3112 L .39219 .30011 L p .704 .576 .709 r
F P
0 g
s
.81273 .14733 m .80417 .15723 L .79568 .15008 L p .536 .554 .82 r
F P
0 g
s
.79568 .15008 m .80461 .13969 L .81273 .14733 L p .536 .554 .82 r
F P
0 g
s
.80461 .13969 m .79568 .15008 L .78661 .1437 L p .563 .594 .842 r
F P
0 g
s
.78661 .1437 m .79593 .13277 L .80461 .13969 L p .563 .594 .842 r
F P
0 g
s
.79593 .13277 m .78661 .1437 L .77709 .13817 L p .589 .634 .863 r
F P
0 g
s
.71777 .14106 m .72813 .12604 L .73759 .12624 L p .726 .847 .938 r
F P
0 g
s
.72813 .12604 m .71777 .14106 L .70857 .1424 L p .756 .895 .94 r
F P
0 g
s
.64145 .23482 m .64935 .22053 L .65037 .21208 L p 0 0 .216 r
F P
0 g
s
.64935 .22053 m .64145 .23482 L .64176 .24362 L p 0 0 .388 r
F P
0 g
s
.82959 .23751 m .82117 .24994 L .82114 .24128 L p .028 0 .388 r
F P
0 g
s
.82114 .24128 m .82954 .22885 L .82959 .23751 L p .028 0 .388 r
F P
0 g
s
.82016 .15557 m .81193 .16503 L .80417 .15723 L p .508 .512 .795 r
F P
0 g
s
.80417 .15723 m .81273 .14733 L .82016 .15557 L p .508 .512 .795 r
F P
0 g
s
.77709 .13817 m .78684 .12669 L .79593 .13277 L p .589 .634 .863 r
F P
0 g
s
.78684 .12669 m .77709 .13817 L .76728 .1336 L p .614 .674 .883 r
F P
0 g
s
.63885 .27441 m .6464 .26171 L .64342 .25263 L p .206 .179 .605 r
F P
0 g
s
.6464 .26171 m .63885 .27441 L .64303 .28344 L p .281 .271 .671 r
F P
0 g
s
.65452 .32 m .66239 .30862 L .6549 .3007 L p .451 .474 .792 r
F P
0 g
s
.66239 .30862 m .65452 .32 L .66266 .32749 L p .487 .524 .821 r
F P
0 g
s
.74976 .32554 m .74044 .33971 L .74991 .33856 L p .74 .886 .946 r
F P
0 g
s
.74991 .33856 m .75939 .32423 L .74976 .32554 L p .74 .886 .946 r
F P
0 g
s
.68952 .32795 m .68091 .34009 L .6907 .34497 L p .583 .657 .888 r
F P
0 g
s
.6907 .34497 m .6996 .33254 L .68952 .32795 L p .583 .657 .888 r
F P
0 g
s
.8268 .1643 m .81886 .17336 L .81193 .16503 L p .478 .467 .767 r
F P
0 g
s
.81193 .16503 m .82016 .15557 L .8268 .1643 L p .478 .467 .767 r
F P
0 g
s
.76728 .1336 m .77746 .12153 L .78684 .12669 L p .614 .674 .883 r
F P
0 g
s
.77746 .12153 m .76728 .1336 L .75732 .13005 L p .64 .715 .901 r
F P
0 g
s
.81335 .2732 m .80451 .28703 L .80843 .27984 L p 0 0 0 r
F P
0 g
s
.80843 .27984 m .81725 .26603 L .81335 .2732 L p 0 0 0 r
F P
0 g
s
.66266 .32749 m .67076 .31589 L .66239 .30862 L p .487 .524 .821 r
F P
0 g
s
.67076 .31589 m .66266 .32749 L .6715 .33423 L p .521 .57 .846 r
F P
0 g
s
.67985 .32237 m .6715 .33423 L .68091 .34009 L p .553 .614 .868 r
F P
0 g
s
.68091 .34009 m .68952 .32795 L .67985 .32237 L p .553 .614 .868 r
F P
0 g
s
.6715 .33423 m .67985 .32237 L .67076 .31589 L p .521 .57 .846 r
F P
0 g
s
.78574 .30371 m .77659 .31821 L .78387 .31361 L p .806 .999 .845 r
F P
0 g
s
.78387 .31361 m .79308 .29907 L .78574 .30371 L p .806 .999 .845 r
F P
0 g
s
.67571 .16904 m .68528 .15301 L .69218 .14841 L p .821 1 .827 r
F P
0 g
s
.68528 .15301 m .67571 .16904 L .66975 .17474 L p .788 .979 .703 r
F P
0 g
s
.83618 .20936 m .82818 .21993 L .82554 .2109 L p .262 .198 .594 r
F P
0 g
s
.82554 .2109 m .83357 .20024 L .83618 .20936 L p .262 .198 .594 r
F P
0 g
s
.65271 .20412 m .66131 .18861 L .66493 .18129 L p 0 0 0 r
F P
0 g
s
.66131 .18861 m .65271 .20412 L .65037 .21208 L p 0 0 0 r
F P
0 g
s
.70857 .1424 m .71914 .127 L .72813 .12604 L p .756 .895 .94 r
F P
0 g
s
.71914 .127 m .70857 .1424 L .69999 .14486 L p .783 .943 .929 r
F P
0 g
s
.83254 .17336 m .82484 .1821 L .81886 .17336 L p .445 .419 .735 r
F P
0 g
s
.81886 .17336 m .8268 .1643 L .83254 .17336 L p .445 .419 .735 r
F P
0 g
s
.75732 .13005 m .76795 .11738 L .77746 .12153 L p .64 .715 .901 r
F P
0 g
s
.76795 .11738 m .75732 .13005 L .74737 .12758 L p .666 .757 .918 r
F P
0 g
s
.64303 .28344 m .65067 .2707 L .6464 .26171 L p .281 .271 .671 r
F P
0 g
s
.65067 .2707 m .64303 .28344 L .64841 .29226 L p .341 .348 .722 r
F P
0 g
s
.64176 .24362 m .64968 .22935 L .64935 .22053 L p 0 0 .388 r
F P
0 g
s
.64968 .22935 m .64176 .24362 L .64342 .25263 L p .091 .049 .512 r
F P
0 g
s
.73965 .32566 m .7305 .33967 L .74044 .33971 L p .708 .837 .944 r
F P
0 g
s
.74044 .33971 m .74976 .32554 L .73965 .32566 L p .708 .837 .944 r
F P
0 g
s
.82833 .24578 m .81987 .25823 L .82117 .24994 L p 0 0 .229 r
F P
0 g
s
.82117 .24994 m .82959 .23751 L .82833 .24578 L p 0 0 .229 r
F P
0 g
s
.83728 .18263 m .82977 .19111 L .82484 .1821 L p .408 .364 .698 r
F P
0 g
s
.82484 .1821 m .83254 .17336 L .83728 .18263 L p .408 .364 .698 r
F P
0 g
s
.74737 .12758 m .75844 .11431 L .76795 .11738 L p .666 .757 .918 r
F P
0 g
s
.75844 .11431 m .74737 .12758 L .73759 .12624 L p .693 .803 .933 r
F P
0 g
s
.80823 .2796 m .79937 .29348 L .80451 .28703 L p .684 .893 .53 r
F P
0 g
s
.80451 .28703 m .81335 .2732 L .80823 .2796 L p .684 .893 .53 r
F P
0 g
s
.77748 .30731 m .76838 .32177 L .77659 .31821 L p .798 .974 .908 r
F P
0 g
s
.77659 .31821 m .78574 .30371 L .77748 .30731 L p .798 .974 .908 r
F P
0 g
s
.83754 .21832 m .82954 .22885 L .82818 .21993 L p .185 .096 .514 r
F P
0 g
s
.82818 .21993 m .83618 .20936 L .83754 .21832 L p .185 .096 .514 r
F P
0 g
s
.64841 .29226 m .65615 .27945 L .65067 .2707 L p .341 .348 .722 r
F P
0 g
s
.65615 .27945 m .64841 .29226 L .6549 .3007 L p .393 .413 .763 r
F P
0 g
s
.66975 .17474 m .67939 .15857 L .68528 .15301 L p .788 .979 .703 r
F P
0 g
s
.67939 .15857 m .66975 .17474 L .66493 .18129 L p .691 .883 .502 r
F P
0 g
s
.72924 .32461 m .72027 .33845 L .7305 .33967 L p .675 .791 .936 r
F P
0 g
s
.7305 .33967 m .73965 .32566 L .72924 .32461 L p .675 .791 .936 r
F P
0 g
s
.69999 .14486 m .71076 .12911 L .71914 .127 L p .783 .943 .929 r
F P
0 g
s
.71076 .12911 m .69999 .14486 L .69218 .14841 L p .801 .983 .896 r
F P
0 g
s
.65037 .21208 m .65898 .19656 L .66131 .18861 L p 0 0 0 r
F P
0 g
s
.65898 .19656 m .65037 .21208 L .64935 .22053 L p 0 0 .219 r
F P
0 g
s
.64342 .25263 m .65137 .23838 L .64968 .22935 L p .091 .049 .512 r
F P
0 g
s
.65137 .23838 m .64342 .25263 L .6464 .26171 L p .189 .169 .603 r
F P
0 g
s
.82092 .1397 m .81273 .14733 L .80461 .13969 L p .555 .557 .811 r
F P
0 g
s
.80461 .13969 m .81344 .13143 L .82092 .1397 L p .555 .557 .811 r
F P
0 g
s
.81344 .13143 m .80461 .13969 L .79593 .13277 L p .577 .595 .835 r
F P
0 g
s
.82778 .14852 m .82016 .15557 L .81273 .14733 L p .531 .518 .786 r
F P
0 g
s
.81273 .14733 m .82092 .1397 L .82778 .14852 L p .531 .518 .786 r
F P
0 g
s
.84094 .19196 m .83357 .20024 L .82977 .19111 L p .364 .302 .653 r
F P
0 g
s
.82977 .19111 m .83728 .18263 L .84094 .19196 L p .364 .302 .653 r
F P
0 g
s
.79593 .13277 m .80545 .12382 L .81344 .13143 L p .577 .595 .835 r
F P
0 g
s
.80545 .12382 m .79593 .13277 L .78684 .12669 L p .599 .634 .857 r
F P
0 g
s
.73759 .12624 m .7491 .11236 L .75844 .11431 L p .693 .803 .933 r
F P
0 g
s
.7491 .11236 m .73759 .12624 L .72813 .12604 L p .72 .851 .944 r
F P
0 g
s
.82577 .25352 m .81725 .26603 L .81987 .25823 L p 0 0 .015 r
F P
0 g
s
.81987 .25823 m .82833 .24578 L .82577 .25352 L p 0 0 .015 r
F P
0 g
s
.6549 .3007 m .66275 .28781 L .65615 .27945 L p .393 .413 .763 r
F P
0 g
s
.66275 .28781 m .6549 .3007 L .66239 .30862 L p .437 .47 .796 r
F P
0 g
s
.7187 .32238 m .7099 .33606 L .72027 .33845 L p .643 .745 .923 r
F P
0 g
s
.72027 .33845 m .72924 .32461 L .7187 .32238 L p .643 .745 .923 r
F P
0 g
s
.83392 .15774 m .8268 .1643 L .82016 .15557 L p .506 .477 .758 r
F P
0 g
s
.82016 .15557 m .82778 .14852 L .83392 .15774 L p .506 .477 .758 r
F P
0 g
s
.78684 .12669 m .79708 .11701 L .80545 .12382 L p .599 .634 .857 r
F P
0 g
s
.79708 .11701 m .78684 .12669 L .77746 .12153 L p .621 .673 .879 r
F P
0 g
s
.76841 .3098 m .75939 .32423 L .76838 .32177 L p .773 .931 .936 r
F P
0 g
s
.76838 .32177 m .77748 .30731 L .76841 .3098 L p .773 .931 .936 r
F P
0 g
s
.80196 .28515 m .79308 .29907 L .79937 .29348 L p .775 .982 .725 r
F P
0 g
s
.79937 .29348 m .80823 .2796 L .80196 .28515 L p .775 .982 .725 r
F P
0 g
s
.83763 .22698 m .82959 .23751 L .82954 .22885 L p .086 0 .408 r
F P
0 g
s
.82954 .22885 m .83754 .21832 L .83763 .22698 L p .086 0 .408 r
F P
0 g
s
.83923 .16723 m .83254 .17336 L .8268 .1643 L p .479 .433 .728 r
F P
0 g
s
.8268 .1643 m .83392 .15774 L .83923 .16723 L p .479 .433 .728 r
F P
0 g
s
.66239 .30862 m .67037 .29563 L .66275 .28781 L p .437 .47 .796 r
F P
0 g
s
.67037 .29563 m .66239 .30862 L .67076 .31589 L p .477 .522 .825 r
F P
0 g
s
.70821 .31902 m .6996 .33254 L .7099 .33606 L p .612 .701 .908 r
F P
0 g
s
.7099 .33606 m .7187 .32238 L .70821 .31902 L p .612 .701 .908 r
F P
0 g
s
.69218 .14841 m .70315 .13234 L .71076 .12911 L p .801 .983 .896 r
F P
0 g
s
.70315 .13234 m .69218 .14841 L .68528 .15301 L p .796 .999 .82 r
F P
0 g
s
.66493 .18129 m .67462 .16502 L .67939 .15857 L p .691 .883 .502 r
F P
0 g
s
.67462 .16502 m .66493 .18129 L .66131 .18861 L p 0 0 0 r
F P
0 g
s
.77746 .12153 m .78846 .11108 L .79708 .11701 L p .621 .673 .879 r
F P
0 g
s
.78846 .11108 m .77746 .12153 L .76795 .11738 L p .643 .714 .899 r
F P
0 g
s
.6464 .26171 m .65439 .24747 L .65137 .23838 L p .189 .169 .603 r
F P
0 g
s
.65439 .24747 m .6464 .26171 L .65067 .2707 L p .267 .265 .67 r
F P
0 g
s
.84348 .20121 m .83618 .20936 L .83357 .20024 L p .312 .228 .598 r
F P
0 g
s
.83357 .20024 m .84094 .19196 L .84348 .20121 L p .312 .228 .598 r
F P
0 g
s
.64935 .22053 m .65798 .20503 L .65898 .19656 L p 0 0 .219 r
F P
0 g
s
.65798 .20503 m .64935 .22053 L .64968 .22935 L p 0 0 .389 r
F P
0 g
s
.72813 .12604 m .74007 .11159 L .7491 .11236 L p .72 .851 .944 r
F P
0 g
s
.74007 .11159 m .72813 .12604 L .71914 .127 L p .746 .901 .947 r
F P
0 g
s
.67076 .31589 m .67888 .30278 L .67037 .29563 L p .477 .522 .825 r
F P
0 g
s
.67888 .30278 m .67076 .31589 L .67985 .32237 L p .513 .569 .85 r
F P
0 g
s
.69796 .31458 m .68952 .32795 L .6996 .33254 L p .58 .658 .891 r
F P
0 g
s
.6996 .33254 m .70821 .31902 L .69796 .31458 L p .58 .658 .891 r
F P
0 g
s
.67985 .32237 m .68813 .30913 L .67888 .30278 L p .513 .569 .85 r
F P
0 g
s
.68813 .30913 m .67985 .32237 L .68952 .32795 L p .547 .614 .871 r
F P
0 g
s
.68952 .32795 m .69796 .31458 L .68813 .30913 L p .547 .614 .871 r
F P
0 g
s
.84364 .17683 m .83728 .18263 L .83254 .17336 L p .448 .384 .693 r
F P
0 g
s
.83254 .17336 m .83923 .16723 L .84364 .17683 L p .448 .384 .693 r
F P
0 g
s
.82194 .2606 m .81335 .2732 L .81725 .26603 L p 0 0 0 r
F P
0 g
s
.81725 .26603 m .82577 .25352 L .82194 .2606 L p 0 0 0 r
F P
0 g
s
.75871 .31115 m .74976 .32554 L .75939 .32423 L p .742 .884 .945 r
F P
0 g
s
.75939 .32423 m .76841 .3098 L .75871 .31115 L p .742 .884 .945 r
F P
0 g
s
.76795 .11738 m .77971 .10615 L .78846 .11108 L p .643 .714 .899 r
F P
0 g
s
.77971 .10615 m .76795 .11738 L .75844 .11431 L p .665 .758 .919 r
F P
0 g
s
.83429 .14389 m .82778 .14852 L .82092 .1397 L p .559 .527 .776 r
F P
0 g
s
.82092 .1397 m .82833 .13442 L .83429 .14389 L p .559 .527 .776 r
F P
0 g
s
.82833 .13442 m .82092 .1397 L .81344 .13143 L p .578 .563 .801 r
F P
0 g
s
.81344 .13143 m .82185 .1254 L .82833 .13442 L p .578 .563 .801 r
F P
0 g
s
.82185 .1254 m .81344 .13143 L .80545 .12382 L p .595 .599 .826 r
F P
0 g
s
.79463 .28972 m .78574 .30371 L .79308 .29907 L p .805 .999 .845 r
F P
0 g
s
.79308 .29907 m .80196 .28515 L .79463 .28972 L p .805 .999 .845 r
F P
0 g
s
.65067 .2707 m .6587 .25647 L .65439 .24747 L p .267 .265 .67 r
F P
0 g
s
.6587 .25647 m .65067 .2707 L .65615 .27945 L p .331 .343 .723 r
F P
0 g
s
.83963 .1537 m .83392 .15774 L .82778 .14852 L p .54 .49 .749 r
F P
0 g
s
.82778 .14852 m .83429 .14389 L .83963 .1537 L p .54 .49 .749 r
F P
0 g
s
.83644 .23519 m .82833 .24578 L .82959 .23751 L p 0 0 .261 r
F P
0 g
s
.82959 .23751 m .83763 .22698 L .83644 .23519 L p 0 0 .261 r
F P
0 g
s
.84707 .18641 m .84094 .19196 L .83728 .18263 L p .413 .329 .651 r
F P
0 g
s
.83728 .18263 m .84364 .17683 L .84707 .18641 L p .413 .329 .651 r
F P
0 g
s
.84483 .21022 m .83754 .21832 L .83618 .20936 L p .247 .138 .527 r
F P
0 g
s
.83618 .20936 m .84348 .20121 L .84483 .21022 L p .247 .138 .527 r
F P
0 g
s
.68528 .15301 m .69641 .13665 L .70315 .13234 L p .796 .999 .82 r
F P
0 g
s
.69641 .13665 m .68528 .15301 L .67939 .15857 L p .743 .963 .678 r
F P
0 g
s
.71914 .127 m .73148 .11199 L .74007 .11159 L p .746 .901 .947 r
F P
0 g
s
.73148 .11199 m .71914 .127 L .71076 .12911 L p .767 .95 .936 r
F P
0 g
s
.80545 .12382 m .81495 .11699 L .82185 .1254 L p .595 .599 .826 r
F P
0 g
s
.81495 .11699 m .80545 .12382 L .79708 .11701 L p .613 .636 .85 r
F P
0 g
s
.66131 .18861 m .67106 .17225 L .67462 .16502 L p 0 0 0 r
F P
0 g
s
.67106 .17225 m .66131 .18861 L .65898 .19656 L p 0 0 .021 r
F P
0 g
s
.84428 .16367 m .83923 .16723 L .83392 .15774 L p .519 .45 .719 r
F P
0 g
s
.83392 .15774 m .83963 .1537 L .84428 .16367 L p .519 .45 .719 r
F P
0 g
s
.64968 .22935 m .65833 .21387 L .65798 .20503 L p 0 0 .389 r
F P
0 g
s
.65833 .21387 m .64968 .22935 L .65137 .23838 L p .094 .051 .513 r
F P
0 g
s
.75844 .11431 m .77098 .10229 L .77971 .10615 L p .665 .758 .919 r
F P
0 g
s
.77098 .10229 m .75844 .11431 L .7491 .11236 L p .688 .804 .937 r
F P
0 g
s
.74851 .31131 m .73965 .32566 L .74976 .32554 L p .709 .836 .943 r
F P
0 g
s
.74976 .32554 m .75871 .31115 L .74851 .31131 L p .709 .836 .943 r
F P
0 g
s
.79708 .11701 m .80772 .10932 L .81495 .11699 L p .613 .636 .85 r
F P
0 g
s
.80772 .10932 m .79708 .11701 L .78846 .11108 L p .63 .674 .873 r
F P
0 g
s
.84816 .17366 m .84364 .17683 L .83923 .16723 L p .495 .407 .686 r
F P
0 g
s
.83923 .16723 m .84428 .16367 L .84816 .17366 L p .495 .407 .686 r
F P
0 g
s
.65615 .27945 m .66424 .26523 L .6587 .25647 L p .331 .343 .723 r
F P
0 g
s
.66424 .26523 m .65615 .27945 L .66275 .28781 L p .384 .41 .764 r
F P
0 g
s
.81689 .26689 m .80823 .2796 L .81335 .2732 L p .651 .874 .508 r
F P
0 g
s
.81335 .2732 m .82194 .2606 L .81689 .26689 L p .651 .874 .508 r
F P
0 g
s
.84946 .1958 m .84348 .20121 L .84094 .19196 L p .371 .264 .601 r
F P
0 g
s
.84094 .19196 m .84707 .18641 L .84946 .1958 L p .371 .264 .601 r
F P
0 g
s
.84373 .15159 m .83963 .1537 L .83429 .14389 L p .578 .506 .739 r
F P
0 g
s
.83429 .14389 m .8395 .14121 L .84373 .15159 L p .578 .506 .739 r
F P
0 g
s
.8395 .14121 m .83429 .14389 L .82833 .13442 L p .592 .54 .765 r
F P
0 g
s
.82833 .13442 m .83481 .13107 L .8395 .14121 L p .592 .54 .765 r
F P
0 g
s
.83481 .13107 m .82833 .13442 L .82185 .1254 L p .605 .573 .791 r
F P
0 g
s
.78638 .29325 m .77748 .30731 L .78574 .30371 L p .797 .974 .908 r
F P
0 g
s
.78574 .30371 m .79463 .28972 L .78638 .29325 L p .797 .974 .908 r
F P
0 g
s
.73801 .31028 m .72924 .32461 L .73965 .32566 L p .676 .79 .935 r
F P
0 g
s
.73965 .32566 m .74851 .31131 L .73801 .31028 L p .676 .79 .935 r
F P
0 g
s
.84743 .16204 m .84428 .16367 L .83963 .1537 L p .562 .472 .71 r
F P
0 g
s
.83963 .1537 m .84373 .15159 L .84743 .16204 L p .562 .472 .71 r
F P
0 g
s
.84497 .21885 m .83763 .22698 L .83754 .21832 L p .163 .024 .432 r
F P
0 g
s
.83754 .21832 m .84483 .21022 L .84497 .21885 L p .163 .024 .432 r
F P
0 g
s
.83398 .24282 m .82577 .25352 L .82833 .24578 L p 0 0 .062 r
F P
0 g
s
.82833 .24578 m .83644 .23519 L .83398 .24282 L p 0 0 .062 r
F P
0 g
s
.82185 .1254 m .82974 .12131 L .83481 .13107 L p .605 .573 .791 r
F P
0 g
s
.82974 .12131 m .82185 .1254 L .81495 .11699 L p .617 .606 .817 r
F P
0 g
s
.78846 .11108 m .80029 .1025 L .80772 .10932 L p .63 .674 .873 r
F P
0 g
s
.80029 .1025 m .78846 .11108 L .77971 .10615 L p .647 .714 .897 r
F P
0 g
s
.7491 .11236 m .7624 .09957 L .77098 .10229 L p .688 .804 .937 r
F P
0 g
s
.7624 .09957 m .7491 .11236 L .74007 .11159 L p .71 .855 .951 r
F P
0 g
s
.71076 .12911 m .7235 .11359 L .73148 .11199 L p .767 .95 .936 r
F P
0 g
s
.7235 .11359 m .71076 .12911 L .70315 .13234 L p .774 .987 .896 r
F P
0 g
s
.67939 .15857 m .69067 .14197 L .69641 .13665 L p .743 .963 .678 r
F P
0 g
s
.69067 .14197 m .67939 .15857 L .67462 .16502 L p .621 .841 .455 r
F P
0 g
s
.65137 .23838 m .66004 .22293 L .65833 .21387 L p .094 .051 .513 r
F P
0 g
s
.66004 .22293 m .65137 .23838 L .65439 .24747 L p .191 .17 .603 r
F P
0 g
s
.66275 .28781 m .67092 .27359 L .66424 .26523 L p .384 .41 .764 r
F P
0 g
s
.67092 .27359 m .66275 .28781 L .67037 .29563 L p .431 .469 .798 r
F P
0 g
s
.8512 .18351 m .84707 .18641 L .84364 .17683 L p .468 .359 .648 r
F P
0 g
s
.84364 .17683 m .84816 .17366 L .8512 .18351 L p .468 .359 .648 r
F P
0 g
s
.65898 .19656 m .66877 .18016 L .67106 .17225 L p 0 0 .021 r
F P
0 g
s
.66877 .18016 m .65898 .19656 L .65798 .20503 L p 0 0 .238 r
F P
0 g
s
.85056 .17241 m .84816 .17366 L .84428 .16367 L p .544 .434 .679 r
F P
0 g
s
.84428 .16367 m .84743 .16204 L .85056 .17241 L p .544 .434 .679 r
F P
0 g
s
.84707 .15044 m .84373 .15159 L .8395 .14121 L p .617 .528 .73 r
F P
0 g
s
.8395 .14121 m .84419 .1396 L .84707 .15044 L p .617 .528 .73 r
F P
0 g
s
.84419 .1396 m .8395 .14121 L .83481 .13107 L p .626 .557 .757 r
F P
0 g
s
.84964 .16129 m .84743 .16204 L .84373 .15159 L p .607 .497 .702 r
F P
0 g
s
.84373 .15159 m .84707 .15044 L .84964 .16129 L p .607 .497 .702 r
F P
0 g
s
.81495 .11699 m .82436 .1121 L .82974 .12131 L p .617 .606 .817 r
F P
0 g
s
.82436 .1121 m .81495 .11699 L .80772 .10932 L p .629 .64 .842 r
F P
0 g
s
.72738 .30808 m .7187 .32238 L .72924 .32461 L p .643 .745 .923 r
F P
0 g
s
.72924 .32461 m .73801 .31028 L .72738 .30808 L p .643 .745 .923 r
F P
0 g
s
.83481 .13107 m .84104 .12892 L .84419 .1396 L p .626 .557 .757 r
F P
0 g
s
.84104 .12892 m .83481 .13107 L .82974 .12131 L p .634 .586 .783 r
F P
0 g
s
.85304 .16063 m .84964 .16129 L .84707 .15044 L p .649 .524 .697 r
F P
0 g
s
.84707 .15044 m .85162 .14955 L .85304 .16063 L p .649 .524 .697 r
F P
0 g
s
.85162 .14955 m .84707 .15044 L .84419 .1396 L p .654 .551 .725 r
F P
0 g
s
.85187 .17197 m .85056 .17241 L .84743 .16204 L p .596 .465 .672 r
F P
0 g
s
.84743 .16204 m .84964 .16129 L .85187 .17197 L p .596 .465 .672 r
F P
0 g
s
.67037 .29563 m .67861 .28141 L .67092 .27359 L p .431 .469 .798 r
F P
0 g
s
.67861 .28141 m .67037 .29563 L .67888 .30278 L p .472 .521 .827 r
F P
0 g
s
.84419 .1396 m .85011 .13843 L .85162 .14955 L p .654 .551 .725 r
F P
0 g
s
.85011 .13843 m .84419 .1396 L .84104 .12892 L p .659 .577 .752 r
F P
0 g
s
.85077 .20487 m .84483 .21022 L .84348 .20121 L p .319 .187 .538 r
F P
0 g
s
.84348 .20121 m .84946 .1958 L .85077 .20487 L p .319 .187 .538 r
F P
0 g
s
.8107 .27229 m .80196 .28515 L .80823 .2796 L p .754 .975 .714 r
F P
0 g
s
.80823 .2796 m .81689 .26689 L .8107 .27229 L p .754 .975 .714 r
F P
0 g
s
.77971 .10615 m .79276 .09665 L .80029 .1025 L p .647 .714 .897 r
F P
0 g
s
.79276 .09665 m .77971 .10615 L .77098 .10229 L p .664 .758 .92 r
F P
0 g
s
.85435 .1715 m .85187 .17197 L .84964 .16129 L p .643 .496 .668 r
F P
0 g
s
.84964 .16129 m .85304 .16063 L .85435 .1715 L p .643 .496 .668 r
F P
0 g
s
.77732 .29566 m .76841 .3098 L .77748 .30731 L p .773 .932 .936 r
F P
0 g
s
.77748 .30731 m .78638 .29325 L .77732 .29566 L p .773 .932 .936 r
F P
0 g
s
.85306 .18254 m .8512 .18351 L .84816 .17366 L p .524 .393 .644 r
F P
0 g
s
.84816 .17366 m .85056 .17241 L .85306 .18254 L p .524 .393 .644 r
F P
0 g
s
.71681 .30474 m .70821 .31902 L .7187 .32238 L p .611 .702 .909 r
F P
0 g
s
.7187 .32238 m .72738 .30808 L .71681 .30474 L p .611 .702 .909 r
F P
0 g
s
.82974 .12131 m .83767 .11856 L .84104 .12892 L p .634 .586 .783 r
F P
0 g
s
.83767 .11856 m .82974 .12131 L .82436 .1121 L p .641 .616 .809 r
F P
0 g
s
.84104 .12892 m .84853 .12742 L .85011 .13843 L p .659 .577 .752 r
F P
0 g
s
.85336 .19307 m .84946 .1958 L .84707 .18641 L p .435 .304 .603 r
F P
0 g
s
.84707 .18641 m .8512 .18351 L .85336 .19307 L p .435 .304 .603 r
F P
0 g
s
.84853 .12742 m .84104 .12892 L .83767 .11856 L p .662 .603 .778 r
F P
0 g
s
.67888 .30278 m .6872 .28856 L .67861 .28141 L p .472 .521 .827 r
F P
0 g
s
.6872 .28856 m .67888 .30278 L .68813 .30913 L p .509 .569 .852 r
F P
0 g
s
.74007 .11159 m .75411 .09803 L .7624 .09957 L p .71 .855 .951 r
F P
0 g
s
.75411 .09803 m .74007 .11159 L .73148 .11199 L p .729 .907 .957 r
F P
0 g
s
.80772 .10932 m .81875 .10356 L .82436 .1121 L p .629 .64 .842 r
F P
0 g
s
.81875 .10356 m .80772 .10932 L .80029 .1025 L p .641 .676 .868 r
F P
0 g
s
.65439 .24747 m .66309 .23208 L .66004 .22293 L p .191 .17 .603 r
F P
0 g
s
.66309 .23208 m .65439 .24747 L .6587 .25647 L p .269 .265 .671 r
F P
0 g
s
.85372 .18232 m .85306 .18254 L .85056 .17241 L p .583 .43 .639 r
F P
0 g
s
.85056 .17241 m .85187 .17197 L .85372 .18232 L p .583 .43 .639 r
F P
0 g
s
.70647 .30032 m .69796 .31458 L .70821 .31902 L p .578 .658 .892 r
F P
0 g
s
.70821 .31902 m .71681 .30474 L .70647 .30032 L p .578 .658 .892 r
F P
0 g
s
.84389 .22696 m .83644 .23519 L .83763 .22698 L p .054 0 .303 r
F P
0 g
s
.83763 .22698 m .84497 .21885 L .84389 .22696 L p .054 0 .303 r
F P
0 g
s
.68813 .30913 m .69654 .2949 L .6872 .28856 L p .509 .569 .852 r
F P
0 g
s
.69654 .2949 m .68813 .30913 L .69796 .31458 L p .544 .614 .873 r
F P
0 g
s
.70315 .13234 m .71623 .11635 L .7235 .11359 L p .774 .987 .896 r
F P
0 g
s
.71623 .11635 m .70315 .13234 L .69641 .13665 L p .747 .991 .804 r
F P
0 g
s
.83028 .24974 m .82194 .2606 L .82577 .25352 L p 0 0 0 r
F P
0 g
s
.82577 .25352 m .83398 .24282 L .83028 .24974 L p 0 0 0 r
F P
0 g
s
.85553 .18199 m .85372 .18232 L .85187 .17197 L p .636 .466 .636 r
F P
0 g
s
.85187 .17197 m .85435 .1715 L .85553 .18199 L p .636 .466 .636 r
F P
0 g
s
.69796 .31458 m .70647 .30032 L .69654 .2949 L p .544 .614 .873 r
F P
0 g
s
.83767 .11856 m .84691 .1167 L .84853 .12742 L p .662 .603 .778 r
F P
0 g
s
.67462 .16502 m .68603 .14823 L .69067 .14197 L p .621 .841 .455 r
F P
0 g
s
.68603 .14823 m .67462 .16502 L .67106 .17225 L p 0 0 0 r
F P
0 g
s
.65798 .20503 m .6678 .18862 L .66877 .18016 L p 0 0 .238 r
F P
0 g
s
.6678 .18862 m .65798 .20503 L .65833 .21387 L p .003 0 .401 r
F P
0 g
s
.84691 .1167 m .83767 .11856 L .83414 .10869 L p .665 .629 .804 r
F P
0 g
s
.82436 .1121 m .83414 .10869 L .83767 .11856 L p .641 .616 .809 r
F P
0 g
s
.83414 .10869 m .82436 .1121 L .81875 .10356 L p .648 .647 .835 r
F P
0 g
s
.8549 .19227 m .85336 .19307 L .8512 .18351 L p .499 .345 .603 r
F P
0 g
s
.8512 .18351 m .85306 .18254 L .8549 .19227 L p .499 .345 .603 r
F P
0 g
s
.77098 .10229 m .78526 .09186 L .79276 .09665 L p .664 .758 .92 r
F P
0 g
s
.78526 .09186 m .77098 .10229 L .7624 .09957 L p .68 .805 .942 r
F P
0 g
s
.76761 .29692 m .75871 .31115 L .76841 .3098 L p .742 .884 .945 r
F P
0 g
s
.76841 .3098 m .77732 .29566 L .76761 .29692 L p .742 .884 .945 r
F P
0 g
s
.85098 .21346 m .84497 .21885 L .84483 .21022 L p .254 .09 .457 r
F P
0 g
s
.84483 .21022 m .85077 .20487 L .85098 .21346 L p .254 .09 .457 r
F P
0 g
s
.85515 .19218 m .8549 .19227 L .85306 .18254 L p .566 .39 .601 r
F P
0 g
s
.85306 .18254 m .85372 .18232 L .85515 .19218 L p .566 .39 .601 r
F P
0 g
s
.85656 .19193 m .85515 .19218 L .85372 .18232 L p .628 .433 .599 r
F P
0 g
s
.85372 .18232 m .85553 .18199 L .85656 .19193 L p .628 .433 .599 r
F P
0 g
s
.80029 .1025 m .813 .09584 L .81875 .10356 L p .641 .676 .868 r
F P
0 g
s
.813 .09584 m .80029 .1025 L .79276 .09665 L p .652 .715 .894 r
F P
0 g
s
.83414 .10869 m .84527 .10644 L .84691 .1167 L p .665 .629 .804 r
F P
0 g
s
.8546 .2022 m .85077 .20487 L .84946 .1958 L p .396 .239 .548 r
F P
0 g
s
.84946 .1958 m .85336 .19307 L .8546 .2022 L p .396 .239 .548 r
F P
0 g
s
.80347 .27669 m .79463 .28972 L .80196 .28515 L p .793 .999 .842 r
F P
0 g
s
.80196 .28515 m .8107 .27229 L .80347 .27669 L p .793 .999 .842 r
F P
0 g
s
.6587 .25647 m .66743 .24115 L .66309 .23208 L p .269 .265 .671 r
F P
0 g
s
.66743 .24115 m .6587 .25647 L .66424 .26523 L p .332 .344 .723 r
F P
0 g
s
.73148 .11199 m .74624 .09771 L .75411 .09803 L p .729 .907 .957 r
F P
0 g
s
.74624 .09771 m .73148 .11199 L .7235 .11359 L p .738 .956 .944 r
F P
0 g
s
.84527 .10644 m .83414 .10869 L .8305 .09946 L p .667 .657 .831 r
F P
0 g
s
.81875 .10356 m .8305 .09946 L .83414 .10869 L p .648 .647 .835 r
F P
0 g
s
.8305 .09946 m .81875 .10356 L .813 .09584 L p .654 .681 .863 r
F P
0 g
s
.8416 .23442 m .83398 .24282 L .83644 .23519 L p 0 0 .125 r
F P
0 g
s
.83644 .23519 m .84389 .22696 L .8416 .23442 L p 0 0 .125 r
F P
0 g
s
.69641 .13665 m .70982 .12024 L .71623 .11635 L p .747 .991 .804 r
F P
0 g
s
.70982 .12024 m .69641 .13665 L .69067 .14197 L p .66 .925 .631 r
F P
0 g
s
.82539 .25582 m .81689 .26689 L .82194 .2606 L p .58 .83 .462 r
F P
0 g
s
.82194 .2606 m .83028 .24974 L .82539 .25582 L p .58 .83 .462 r
F P
0 g
s
.85603 .20146 m .8546 .2022 L .85336 .19307 L p .469 .289 .554 r
F P
0 g
s
.85336 .19307 m .8549 .19227 L .85603 .20146 L p .469 .289 .554 r
F P
0 g
s
.65833 .21387 m .66818 .19749 L .6678 .18862 L p .003 0 .401 r
F P
0 g
s
.66818 .19749 m .65833 .21387 L .66004 .22293 L p .12 .068 .519 r
F P
0 g
s
.75742 .29698 m .74851 .31131 L .75871 .31115 L p .709 .837 .943 r
F P
0 g
s
.75871 .31115 m .76761 .29692 L .75742 .29698 L p .709 .837 .943 r
F P
0 g
s
.67106 .17225 m .68257 .15533 L .68603 .14823 L p 0 0 0 r
F P
0 g
s
.68257 .15533 m .67106 .17225 L .66877 .18016 L p 0 0 .07 r
F P
0 g
s
.85615 .20141 m .85603 .20146 L .8549 .19227 L p .544 .342 .557 r
F P
0 g
s
.8549 .19227 m .85515 .19218 L .85615 .20141 L p .544 .342 .557 r
F P
0 g
s
.85743 .20119 m .85615 .20141 L .85515 .19218 L p .617 .394 .557 r
F P
0 g
s
.85515 .19218 m .85656 .19193 L .85743 .20119 L p .617 .394 .557 r
F P
0 g
s
.8305 .09946 m .84364 .09678 L .84527 .10644 L p .667 .657 .831 r
F P
0 g
s
.66424 .26523 m .67299 .24998 L .66743 .24115 L p .332 .344 .723 r
F P
0 g
s
.67299 .24998 m .66424 .26523 L .67092 .27359 L p .385 .411 .764 r
F P
0 g
s
.7624 .09957 m .77789 .08822 L .78526 .09186 L p .68 .805 .942 r
F P
0 g
s
.77789 .08822 m .7624 .09957 L .75411 .09803 L p .694 .857 .96 r
F P
0 g
s
.79276 .09665 m .8072 .08907 L .813 .09584 L p .652 .715 .894 r
F P
0 g
s
.8072 .08907 m .79276 .09665 L .78526 .09186 L p .662 .758 .921 r
F P
0 g
s
.85007 .22144 m .84389 .22696 L .84497 .21885 L p .167 0 .347 r
F P
0 g
s
.84497 .21885 m .85098 .21346 L .85007 .22144 L p .167 0 .347 r
F P
0 g
s
.8549 .21074 m .85098 .21346 L .85077 .20487 L p .347 .159 .478 r
F P
0 g
s
.85077 .20487 m .8546 .2022 L .8549 .21074 L p .347 .159 .478 r
F P
0 g
s
.79531 .28003 m .78638 .29325 L .79463 .28972 L p .79 .976 .908 r
F P
0 g
s
.79463 .28972 m .80347 .27669 L .79531 .28003 L p .79 .976 .908 r
F P
0 g
s
.84364 .09678 m .8305 .09946 L .82679 .09101 L p .667 .687 .86 r
F P
0 g
s
.813 .09584 m .82679 .09101 L .8305 .09946 L p .654 .681 .863 r
F P
0 g
s
.74691 .29585 m .73801 .31028 L .74851 .31131 L p .676 .79 .935 r
F P
0 g
s
.74851 .31131 m .75742 .29698 L .74691 .29585 L p .676 .79 .935 r
F P
0 g
s
.82679 .09101 m .813 .09584 L .8072 .08907 L p .658 .717 .892 r
F P
0 g
s
.7235 .11359 m .73892 .09862 L .74624 .09771 L p .738 .956 .944 r
F P
0 g
s
.73892 .09862 m .7235 .11359 L .71623 .11635 L p .724 .986 .892 r
F P
0 g
s
.67092 .27359 m .67969 .25843 L .67299 .24998 L p .385 .411 .764 r
F P
0 g
s
.67969 .25843 m .67092 .27359 L .67861 .28141 L p .431 .469 .798 r
F P
0 g
s
.85644 .20994 m .8549 .21074 L .8546 .2022 L p .432 .222 .493 r
F P
0 g
s
.8546 .2022 m .85603 .20146 L .85644 .20994 L p .432 .222 .493 r
F P
0 g
s
.66004 .22293 m .6699 .20661 L .66818 .19749 L p .12 .068 .519 r
F P
0 g
s
.6699 .20661 m .66004 .22293 L .66309 .23208 L p .212 .182 .606 r
F P
0 g
s
.83812 .2411 m .83028 .24974 L .83398 .24282 L p 0 0 0 r
F P
0 g
s
.83398 .24282 m .8416 .23442 L .83812 .2411 L p 0 0 0 r
F P
0 g
s
.81938 .26097 m .8107 .27229 L .81689 .26689 L p .708 .957 .688 r
F P
0 g
s
.81689 .26689 m .82539 .25582 L .81938 .26097 L p .708 .957 .688 r
F P
0 g
s
.69067 .14197 m .70436 .12521 L .70982 .12024 L p .66 .925 .631 r
F P
0 g
s
.70436 .12521 m .69067 .14197 L .68603 .14823 L p 0 0 0 r
F P
0 g
s
.8567 .20985 m .85644 .20994 L .85603 .20146 L p .512 .282 .502 r
F P
0 g
s
.85603 .20146 m .85615 .20141 L .8567 .20985 L p .512 .282 .502 r
F P
0 g
s
.82679 .09101 m .84204 .08788 L .84364 .09678 L p .667 .687 .86 r
F P
0 g
s
.85811 .2096 m .8567 .20985 L .85615 .20141 L p .601 .348 .505 r
F P
0 g
s
.85615 .20141 m .85743 .20119 L .85811 .2096 L p .601 .348 .505 r
F P
0 g
s
.73627 .29355 m .72738 .30808 L .73801 .31028 L p .643 .745 .923 r
F P
0 g
s
.73801 .31028 m .74691 .29585 L .73627 .29355 L p .643 .745 .923 r
F P
0 g
s
.66877 .18016 m .68036 .16315 L .68257 .15533 L p 0 0 .07 r
F P
0 g
s
.68036 .16315 m .66877 .18016 L .6678 .18862 L p 0 0 .273 r
F P
0 g
s
.67861 .28141 m .68741 .26634 L .67969 .25843 L p .431 .469 .798 r
F P
0 g
s
.68741 .26634 m .67861 .28141 L .6872 .28856 L p .472 .521 .827 r
F P
0 g
s
.78526 .09186 m .80143 .08334 L .8072 .08907 L p .662 .758 .921 r
F P
0 g
s
.80143 .08334 m .78526 .09186 L .77789 .08822 L p .67 .805 .948 r
F P
0 g
s
.75411 .09803 m .77078 .08578 L .77789 .08822 L p .694 .857 .96 r
F P
0 g
s
.77078 .08578 m .75411 .09803 L .74624 .09771 L p .701 .91 .968 r
F P
0 g
s
.78635 .28224 m .77732 .29566 L .78638 .29325 L p .769 .934 .938 r
F P
0 g
s
.78638 .29325 m .79531 .28003 L .78635 .28224 L p .769 .934 .938 r
F P
0 g
s
.85424 .21856 m .85007 .22144 L .85098 .21346 L p .282 .057 .385 r
F P
0 g
s
.85098 .21346 m .8549 .21074 L .85424 .21856 L p .282 .057 .385 r
F P
0 g
s
.72568 .2901 m .71681 .30474 L .72738 .30808 L p .611 .702 .909 r
F P
0 g
s
.72738 .30808 m .73627 .29355 L .72568 .2901 L p .611 .702 .909 r
F P
0 g
s
.84805 .22868 m .8416 .23442 L .84389 .22696 L p .05 0 .195 r
F P
0 g
s
.84389 .22696 m .85007 .22144 L .84805 .22868 L p .05 0 .195 r
F P
0 g
s
.6872 .28856 m .69603 .27358 L .68741 .26634 L p .472 .521 .827 r
F P
0 g
s
.69603 .27358 m .6872 .28856 L .69654 .2949 L p .51 .569 .851 r
F P
0 g
s
.84204 .08788 m .82679 .09101 L .82309 .08348 L p .664 .72 .89 r
F P
0 g
s
.8072 .08907 m .82309 .08348 L .82679 .09101 L p .658 .717 .892 r
F P
0 g
s
.82309 .08348 m .8072 .08907 L .80143 .08334 L p .66 .757 .922 r
F P
0 g
s
.71533 .28557 m .70647 .30032 L .71681 .30474 L p .578 .658 .892 r
F P
0 g
s
.71681 .30474 m .72568 .2901 L .71533 .28557 L p .578 .658 .892 r
F P
0 g
s
.69654 .2949 m .70538 .28003 L .69603 .27358 L p .51 .569 .851 r
F P
0 g
s
.70538 .28003 m .69654 .2949 L .70647 .30032 L p .545 .614 .873 r
F P
0 g
s
.70647 .30032 m .71533 .28557 L .70538 .28003 L p .545 .614 .873 r
F P
0 g
s
.66309 .23208 m .67295 .21585 L .6699 .20661 L p .212 .182 .606 r
F P
0 g
s
.67295 .21585 m .66309 .23208 L .66743 .24115 L p .285 .274 .671 r
F P
0 g
s
.71623 .11635 m .73227 .10076 L .73892 .09862 L p .724 .986 .892 r
F P
0 g
s
.73227 .10076 m .71623 .11635 L .70982 .12024 L p .66 .963 .769 r
F P
0 g
s
.85612 .2176 m .85424 .21856 L .8549 .21074 L p .386 .139 .414 r
F P
0 g
s
.8549 .21074 m .85644 .20994 L .85612 .2176 L p .386 .139 .414 r
F P
0 g
s
.81235 .2651 m .80347 .27669 L .8107 .27229 L p .766 .997 .833 r
F P
0 g
s
.8107 .27229 m .81938 .26097 L .81235 .2651 L p .766 .997 .833 r
F P
0 g
s
.83351 .24689 m .82539 .25582 L .83028 .24974 L p 0 0 0 r
F P
0 g
s
.83028 .24974 m .83812 .2411 L .83351 .24689 L p 0 0 0 r
F P
0 g
s
.85678 .21738 m .85612 .2176 L .85644 .20994 L p .485 .218 .433 r
F P
0 g
s
.85644 .20994 m .8567 .20985 L .85678 .21738 L p .485 .218 .433 r
F P
0 g
s
.82309 .08348 m .8405 .07989 L .84204 .08788 L p .664 .72 .89 r
F P
0 g
s
.85861 .21704 m .85678 .21738 L .8567 .20985 L p .577 .288 .44 r
F P
0 g
s
.8567 .20985 m .85811 .2096 L .85861 .21704 L p .577 .288 .44 r
F P
0 g
s
.68603 .14823 m .69995 .13119 L .70436 .12521 L p 0 0 0 r
F P
0 g
s
.69995 .13119 m .68603 .14823 L .68257 .15533 L p 0 0 0 r
F P
0 g
s
.6678 .18862 m .67945 .17158 L .68036 .16315 L p 0 0 .273 r
F P
0 g
s
.67945 .17158 m .6678 .18862 L .66818 .19749 L p .064 0 .422 r
F P
0 g
s
.77675 .28326 m .76761 .29692 L .77732 .29566 L p .739 .886 .947 r
F P
0 g
s
.77732 .29566 m .78635 .28224 L .77675 .28326 L p .739 .886 .947 r
F P
0 g
s
.77789 .08822 m .79578 .07876 L .80143 .08334 L p .67 .805 .948 r
F P
0 g
s
.79578 .07876 m .77789 .08822 L .77078 .08578 L p .671 .856 .97 r
F P
0 g
s
.74624 .09771 m .76404 .08461 L .77078 .08578 L p .701 .91 .968 r
F P
0 g
s
.76404 .08461 m .74624 .09771 L .73892 .09862 L p .69 .955 .951 r
F P
0 g
s
.85263 .22552 m .84805 .22868 L .85007 .22144 L p .193 0 .259 r
F P
0 g
s
.85007 .22144 m .85424 .21856 L .85263 .22552 L p .193 0 .259 r
F P
0 g
s
.66743 .24115 m .67729 .22504 L .67295 .21585 L p .285 .274 .671 r
F P
0 g
s
.67729 .22504 m .66743 .24115 L .67299 .24998 L p .345 .35 .721 r
F P
0 g
s
.84494 .23504 m .83812 .2411 L .8416 .23442 L p 0 0 0 r
F P
0 g
s
.8416 .23442 m .84805 .22868 L .84494 .23504 L p 0 0 0 r
F P
0 g
s
.8405 .07989 m .82309 .08348 L .81944 .07699 L p .658 .756 .922 r
F P
0 g
s
.80143 .08334 m .81944 .07699 L .82309 .08348 L p .66 .757 .922 r
F P
0 g
s
.81944 .07699 m .80143 .08334 L .79578 .07876 L p .657 .801 .952 r
F P
0 g
s
.76665 .28309 m .75742 .29698 L .76761 .29692 L p .707 .838 .944 r
F P
0 g
s
.76761 .29692 m .77675 .28326 L .76665 .28309 L p .707 .838 .944 r
F P
0 g
s
.70982 .12024 m .72641 .10411 L .73227 .10076 L p .66 .963 .769 r
F P
0 g
s
.72641 .10411 m .70982 .12024 L .70436 .12521 L p .522 .846 .551 r
F P
0 g
s
.80441 .26811 m .79531 .28003 L .80347 .27669 L p .775 .98 .91 r
F P
0 g
s
.80347 .27669 m .81235 .2651 L .80441 .26811 L p .775 .98 .91 r
F P
0 g
s
.85507 .22429 m .85263 .22552 L .85424 .21856 L p .323 .033 .308 r
F P
0 g
s
.85424 .21856 m .85612 .2176 L .85507 .22429 L p .323 .033 .308 r
F P
0 g
s
.66818 .19749 m .67985 .18047 L .67945 .17158 L p .064 0 .422 r
F P
0 g
s
.67985 .18047 m .66818 .19749 L .6699 .20661 L p .169 .1 .53 r
F P
0 g
s
.82783 .25168 m .81938 .26097 L .82539 .25582 L p .625 .916 .64 r
F P
0 g
s
.82539 .25582 m .83351 .24689 L .82783 .25168 L p .625 .916 .64 r
F P
0 g
s
.67299 .24998 m .68283 .23402 L .67729 .22504 L p .345 .35 .721 r
F P
0 g
s
.68283 .23402 m .67299 .24998 L .67969 .25843 L p .395 .414 .762 r
F P
0 g
s
.68257 .15533 m .69669 .13807 L .69995 .13119 L p 0 0 0 r
F P
0 g
s
.69669 .13807 m .68257 .15533 L .68036 .16315 L p 0 0 .137 r
F P
0 g
s
.85639 .22385 m .85507 .22429 L .85612 .2176 L p .443 .132 .341 r
F P
0 g
s
.85612 .2176 m .85678 .21738 L .85639 .22385 L p .443 .132 .341 r
F P
0 g
s
.8589 .22339 m .85639 .22385 L .85678 .21738 L p .541 .209 .355 r
F P
0 g
s
.85678 .21738 m .85861 .21704 L .8589 .22339 L p .541 .209 .355 r
F P
0 g
s
.81944 .07699 m .83904 .07293 L .8405 .07989 L p .658 .756 .922 r
F P
0 g
s
.77078 .08578 m .79036 .07541 L .79578 .07876 L p .671 .856 .97 r
F P
0 g
s
.79036 .07541 m .77078 .08578 L .76404 .08461 L p .659 .906 .98 r
F P
0 g
s
.75624 .28172 m .74691 .29585 L .75742 .29698 L p .675 .791 .936 r
F P
0 g
s
.75742 .29698 m .76665 .28309 L .75624 .28172 L p .675 .791 .936 r
F P
0 g
s
.73892 .09862 m .75779 .08471 L .76404 .08461 L p .69 .955 .951 r
F P
0 g
s
.75779 .08471 m .73892 .09862 L .73227 .10076 L p .639 .965 .877 r
F P
0 g
s
.85008 .23152 m .84494 .23504 L .84805 .22868 L p .07 0 .082 r
F P
0 g
s
.84805 .22868 m .85263 .22552 L .85008 .23152 L p .07 0 .082 r
F P
0 g
s
.67969 .25843 m .6895 .24264 L .68283 .23402 L p .395 .414 .762 r
F P
0 g
s
.6895 .24264 m .67969 .25843 L .68741 .26634 L p .439 .471 .796 r
F P
0 g
s
.84079 .24043 m .83351 .24689 L .83812 .2411 L p 0 0 0 r
F P
0 g
s
.83812 .2411 m .84494 .23504 L .84079 .24043 L p 0 0 0 r
F P
0 g
s
.83904 .07293 m .81944 .07699 L .81591 .07165 L p .643 .795 .955 r
F P
0 g
s
.79578 .07876 m .81591 .07165 L .81944 .07699 L p .657 .801 .952 r
F P
0 g
s
.79568 .26997 m .78635 .28224 L .79531 .28003 L p .76 .939 .942 r
F P
0 g
s
.79531 .28003 m .80441 .26811 L .79568 .26997 L p .76 .939 .942 r
F P
0 g
s
.7457 .27916 m .73627 .29355 L .74691 .29585 L p .643 .745 .923 r
F P
0 g
s
.74691 .29585 m .75624 .28172 L .7457 .27916 L p .643 .745 .923 r
F P
0 g
s
.81591 .07165 m .79578 .07876 L .79036 .07541 L p .643 .849 .979 r
F P
0 g
s
.6699 .20661 m .68158 .18968 L .67985 .18047 L p .169 .1 .53 r
F P
0 g
s
.68158 .18968 m .6699 .20661 L .67295 .21585 L p .25 .204 .609 r
F P
0 g
s
.70436 .12521 m .72143 .10861 L .72641 .10411 L p .522 .846 .551 r
F P
0 g
s
.72143 .10861 m .70436 .12521 L .69995 .13119 L p 0 0 0 r
F P
0 g
s
.68741 .26634 m .69718 .25075 L .6895 .24264 L p .439 .471 .796 r
F P
0 g
s
.69718 .25075 m .68741 .26634 L .69603 .27358 L p .478 .522 .824 r
F P
0 g
s
.82117 .25538 m .81235 .2651 L .81938 .26097 L p .716 .986 .816 r
F P
0 g
s
.81938 .26097 m .82783 .25168 L .82117 .25538 L p .716 .986 .816 r
F P
0 g
s
.85329 .22991 m .85008 .23152 L .85263 .22552 L p .232 0 .16 r
F P
0 g
s
.85263 .22552 m .85507 .22429 L .85329 .22991 L p .232 0 .16 r
F P
0 g
s
.68036 .16315 m .69462 .14576 L .69669 .13807 L p 0 0 .137 r
F P
0 g
s
.69462 .14576 m .68036 .16315 L .67945 .17158 L p .033 0 .316 r
F P
0 g
s
.73519 .27545 m .72568 .2901 L .73627 .29355 L p .612 .701 .908 r
F P
0 g
s
.73627 .29355 m .7457 .27916 L .73519 .27545 L p .612 .701 .908 r
F P
0 g
s
.69603 .27358 m .70574 .25821 L .69718 .25075 L p .478 .522 .824 r
F P
0 g
s
.70574 .25821 m .69603 .27358 L .70538 .28003 L p .514 .569 .849 r
F P
0 g
s
.85554 .22917 m .85329 .22991 L .85507 .22429 L p .376 .012 .214 r
F P
0 g
s
.85507 .22429 m .85639 .22385 L .85554 .22917 L p .376 .012 .214 r
F P
0 g
s
.72492 .27067 m .71533 .28557 L .72568 .2901 L p .58 .658 .89 r
F P
0 g
s
.72568 .2901 m .73519 .27545 L .72492 .27067 L p .58 .658 .89 r
F P
0 g
s
.85899 .22852 m .85554 .22917 L .85639 .22385 L p .485 .101 .236 r
F P
0 g
s
.85639 .22385 m .8589 .22339 L .85899 .22852 L p .485 .101 .236 r
F P
0 g
s
.70538 .28003 m .71504 .26489 L .70574 .25821 L p .514 .569 .849 r
F P
0 g
s
.71504 .26489 m .70538 .28003 L .71533 .28557 L p .548 .614 .871 r
F P
0 g
s
.81591 .07165 m .83768 .06713 L .83904 .07293 L p .643 .795 .955 r
F P
0 g
s
.71533 .28557 m .72492 .27067 L .71504 .26489 L p .548 .614 .871 r
F P
0 g
s
.73227 .10076 m .75212 .08612 L .75779 .08471 L p .639 .965 .877 r
F P
0 g
s
.75212 .08612 m .73227 .10076 L .72641 .10411 L p .518 .894 .707 r
F P
0 g
s
.76404 .08461 m .78524 .07336 L .79036 .07541 L p .659 .906 .98 r
F P
0 g
s
.78524 .07336 m .76404 .08461 L .75779 .08471 L p .616 .939 .953 r
F P
0 g
s
.78632 .27062 m .77675 .28326 L .78635 .28224 L p .734 .889 .951 r
F P
0 g
s
.78635 .28224 m .79568 .26997 L .78632 .27062 L p .734 .889 .951 r
F P
0 g
s
.67295 .21585 m .6846 .19905 L .68158 .18968 L p .25 .204 .609 r
F P
0 g
s
.6846 .19905 m .67295 .21585 L .67729 .22504 L p .315 .289 .67 r
F P
0 g
s
.83565 .24474 m .82783 .25168 L .83351 .24689 L p .491 .837 .562 r
F P
0 g
s
.83351 .24689 m .84079 .24043 L .83565 .24474 L p .491 .837 .562 r
F P
0 g
s
.84663 .23644 m .84079 .24043 L .84494 .23504 L p 0 0 0 r
F P
0 g
s
.84494 .23504 m .85008 .23152 L .84663 .23644 L p 0 0 0 r
F P
0 g
s
.83768 .06713 m .81591 .07165 L .81255 .06755 L p .614 .836 .985 r
F P
0 g
s
.79036 .07541 m .81255 .06755 L .81591 .07165 L p .643 .849 .979 r
F P
0 g
s
.69995 .13119 m .71743 .1142 L .72143 .10861 L p 0 0 0 r
F P
0 g
s
.71743 .1142 m .69995 .13119 L .69669 .13807 L p 0 0 0 r
F P
0 g
s
.81363 .25793 m .80441 .26811 L .81235 .2651 L p .747 .983 .909 r
F P
0 g
s
.81235 .2651 m .82117 .25538 L .81363 .25793 L p .747 .983 .909 r
F P
0 g
s
.81255 .06755 m .79036 .07541 L .78524 .07336 L p .607 .891 .989 r
F P
0 g
s
.67945 .17158 m .69379 .15414 L .69462 .14576 L p .033 0 .316 r
F P
0 g
s
.69379 .15414 m .67945 .17158 L .67985 .18047 L p .147 .027 .447 r
F P
0 g
s
.77647 .27005 m .76665 .28309 L .77675 .28326 L p .704 .839 .947 r
F P
0 g
s
.77675 .28326 m .78632 .27062 L .77647 .27005 L p .704 .839 .947 r
F P
0 g
s
.85081 .23436 m .84663 .23644 L .85008 .23152 L p .098 0 0 r
F P
0 g
s
.85008 .23152 m .85329 .22991 L .85081 .23436 L p .098 0 0 r
F P
0 g
s
.67729 .22504 m .68888 .20842 L .6846 .19905 L p .315 .289 .67 r
F P
0 g
s
.68888 .20842 m .67729 .22504 L .68283 .23402 L p .369 .36 .719 r
F P
0 g
s
.85422 .23323 m .85081 .23436 L .85329 .22991 L p .271 0 .03 r
F P
0 g
s
.85329 .22991 m .85554 .22917 L .85422 .23323 L p .271 0 .03 r
F P
0 g
s
.72641 .10411 m .74714 .08881 L .75212 .08612 L p .518 .894 .707 r
F P
0 g
s
.74714 .08881 m .72641 .10411 L .72143 .10861 L p 0 0 0 r
F P
0 g
s
.75779 .08471 m .78051 .07265 L .78524 .07336 L p .616 .939 .953 r
F P
0 g
s
.78051 .07265 m .75779 .08471 L .75212 .08612 L p .512 .914 .846 r
F P
0 g
s
.85887 .23235 m .85422 .23323 L .85554 .22917 L p .397 0 .066 r
F P
0 g
s
.85554 .22917 m .85899 .22852 L .85887 .23235 L p .397 0 .066 r
F P
0 g
s
.82961 .2479 m .82117 .25538 L .82783 .25168 L p .631 .955 .781 r
F P
0 g
s
.82783 .25168 m .83565 .24474 L .82961 .2479 L p .631 .955 .781 r
F P
0 g
s
.81255 .06755 m .83645 .06258 L .83768 .06713 L p .614 .836 .985 r
F P
0 g
s
.84233 .24019 m .83565 .24474 L .84079 .24043 L p 0 0 0 r
F P
0 g
s
.84079 .24043 m .84663 .23644 L .84233 .24019 L p 0 0 0 r
F P
0 g
s
.7663 .26827 m .75624 .28172 L .76665 .28309 L p .674 .791 .937 r
F P
0 g
s
.76665 .28309 m .77647 .27005 L .7663 .26827 L p .674 .791 .937 r
F P
0 g
s
.68283 .23402 m .69434 .21764 L .68888 .20842 L p .369 .36 .719 r
F P
0 g
s
.69434 .21764 m .68283 .23402 L .6895 .24264 L p .414 .421 .758 r
F P
0 g
s
.80534 .25928 m .79568 .26997 L .80441 .26811 L p .743 .944 .948 r
F P
0 g
s
.80441 .26811 m .81363 .25793 L .80534 .25928 L p .743 .944 .948 r
F P
0 g
s
.67985 .18047 m .69423 .16305 L .69379 .15414 L p .147 .027 .447 r
F P
0 g
s
.69423 .16305 m .67985 .18047 L .68158 .18968 L p .235 .143 .542 r
F P
0 g
s
.69669 .13807 m .71449 .1208 L .71743 .1142 L p 0 0 0 r
F P
0 g
s
.71449 .1208 m .69669 .13807 L .69462 .14576 L p .033 0 .21 r
F P
0 g
s
.78524 .07336 m .80941 .06479 L .81255 .06755 L p .607 .891 .989 r
F P
0 g
s
.80941 .06479 m .78524 .07336 L .78051 .07265 L p .525 .904 .951 r
F P
0 g
s
.83645 .06258 m .81255 .06755 L .80941 .06479 L p .555 .867 .995 r
F P
0 g
s
.75599 .26529 m .7457 .27916 L .75624 .28172 L p .644 .745 .923 r
F P
0 g
s
.75624 .28172 m .7663 .26827 L .75599 .26529 L p .644 .745 .923 r
F P
0 g
s
.6895 .24264 m .7009 .22654 L .69434 .21764 L p .414 .421 .758 r
F P
0 g
s
.7009 .22654 m .6895 .24264 L .69718 .25075 L p .454 .475 .791 r
F P
0 g
s
.84766 .23755 m .84233 .24019 L .84663 .23644 L p 0 0 0 r
F P
0 g
s
.84663 .23644 m .85081 .23436 L .84766 .23755 L p 0 0 0 r
F P
0 g
s
.74571 .26118 m .73519 .27545 L .7457 .27916 L p .614 .701 .906 r
F P
0 g
s
.7457 .27916 m .75599 .26529 L .74571 .26118 L p .614 .701 .906 r
F P
0 g
s
.72143 .10861 m .74294 .09275 L .74714 .08881 L p 0 0 0 r
F P
0 g
s
.74294 .09275 m .72143 .10861 L .71743 .1142 L p 0 0 0 r
F P
0 g
s
.82275 .24984 m .81363 .25793 L .82117 .25538 L p .698 .978 .904 r
F P
0 g
s
.82117 .25538 m .82961 .2479 L .82275 .24984 L p .698 .978 .904 r
F P
0 g
s
.69718 .25075 m .70845 .23496 L .7009 .22654 L p .454 .475 .791 r
F P
0 g
s
.70845 .23496 m .69718 .25075 L .70574 .25821 L p .49 .524 .819 r
F P
0 g
s
.79642 .25939 m .78632 .27062 L .79568 .26997 L p .724 .894 .957 r
F P
0 g
s
.79568 .26997 m .80534 .25928 L .79642 .25939 L p .724 .894 .957 r
F P
0 g
s
.68158 .18968 m .69593 .17237 L .69423 .16305 L p .235 .143 .542 r
F P
0 g
s
.69593 .17237 m .68158 .18968 L .6846 .19905 L p .303 .236 .614 r
F P
0 g
s
.85247 .23597 m .84766 .23755 L .85081 .23436 L p .107 0 0 r
F P
0 g
s
.85081 .23436 m .85422 .23323 L .85247 .23597 L p .107 0 0 r
F P
0 g
s
.75212 .08612 m .77625 .0733 L .78051 .07265 L p .512 .914 .846 r
F P
0 g
s
.77625 .0733 m .75212 .08612 L .74714 .08881 L p 0 0 0 r
F P
0 g
s
.83724 .24271 m .82961 .2479 L .83565 .24474 L p .495 .887 .72 r
F P
0 g
s
.83565 .24474 m .84233 .24019 L .83724 .24271 L p .495 .887 .72 r
F P
0 g
s
.73565 .25599 m .72492 .27067 L .73519 .27545 L p .584 .657 .887 r
F P
0 g
s
.73519 .27545 m .74571 .26118 L .73565 .25599 L p .584 .657 .887 r
F P
0 g
s
.70574 .25821 m .71686 .24277 L .70845 .23496 L p .49 .524 .819 r
F P
0 g
s
.71686 .24277 m .70574 .25821 L .71504 .26489 L p .523 .57 .844 r
F P
0 g
s
.85853 .23481 m .85247 .23597 L .85422 .23323 L p .253 0 0 r
F P
0 g
s
.85422 .23323 m .85887 .23235 L .85853 .23481 L p .253 0 0 r
F P
0 g
s
.69462 .14576 m .71265 .12831 L .71449 .1208 L p .033 0 .21 r
F P
0 g
s
.71265 .12831 m .69462 .14576 L .69379 .15414 L p .154 0 .362 r
F P
0 g
s
.72597 .24982 m .71504 .26489 L .72492 .27067 L p .554 .614 .867 r
F P
0 g
s
.72492 .27067 m .73565 .25599 L .72597 .24982 L p .554 .614 .867 r
F P
0 g
s
.71504 .26489 m .72597 .24982 L .71686 .24277 L p .523 .57 .844 r
F P
0 g
s
.80941 .06479 m .83537 .05938 L .83645 .06258 L p .555 .867 .995 r
F P
0 g
s
.78703 .25826 m .77647 .27005 L .78632 .27062 L p .699 .842 .952 r
F P
0 g
s
.78632 .27062 m .79642 .25939 L .78703 .25826 L p .699 .842 .952 r
F P
0 g
s
.6846 .19905 m .69888 .18192 L .69593 .17237 L p .303 .236 .614 r
F P
0 g
s
.69888 .18192 m .6846 .19905 L .68888 .20842 L p .357 .311 .669 r
F P
0 g
s
.78051 .07265 m .80656 .0634 L .80941 .06479 L p .525 .904 .951 r
F P
0 g
s
.80656 .0634 m .78051 .07265 L .77625 .0733 L p .362 .833 .807 r
F P
0 g
s
.81518 .25053 m .80534 .25928 L .81363 .25793 L p .715 .948 .954 r
F P
0 g
s
.81363 .25793 m .82275 .24984 L .81518 .25053 L p .715 .948 .954 r
F P
0 g
s
.83537 .05938 m .80941 .06479 L .80656 .0634 L p .436 .858 .95 r
F P
0 g
s
.8439 .23942 m .83724 .24271 L .84233 .24019 L p 0 0 0 r
F P
0 g
s
.84233 .24019 m .84766 .23755 L .8439 .23942 L p 0 0 0 r
F P
0 g
s
.71743 .1142 m .73959 .09788 L .74294 .09275 L p 0 0 0 r
F P
0 g
s
.73959 .09788 m .71743 .1142 L .71449 .1208 L p .061 0 .1 r
F P
0 g
s
.69379 .15414 m .71196 .1366 L .71265 .12831 L p .154 0 .362 r
F P
0 g
s
.71196 .1366 m .69379 .15414 L .69423 .16305 L p .244 .096 .472 r
F P
0 g
s
.83143 .24393 m .82275 .24984 L .82961 .2479 L p .616 .957 .888 r
F P
0 g
s
.82961 .2479 m .83724 .24271 L .83143 .24393 L p .616 .957 .888 r
F P
0 g
s
.74714 .08881 m .77254 .07532 L .77625 .0733 L p 0 0 0 r
F P
0 g
s
.77254 .07532 m .74714 .08881 L .74294 .09275 L p 0 0 0 r
F P
0 g
s
.77733 .25589 m .7663 .26827 L .77647 .27005 L p .672 .792 .939 r
F P
0 g
s
.77647 .27005 m .78703 .25826 L .77733 .25589 L p .672 .792 .939 r
F P
0 g
s
.8503 .23731 m .8439 .23942 L .84766 .23755 L p 0 0 0 r
F P
0 g
s
.84766 .23755 m .85247 .23597 L .8503 .23731 L p 0 0 0 r
F P
0 g
s
.68888 .20842 m .70303 .19155 L .69888 .18192 L p .357 .311 .669 r
F P
0 g
s
.70303 .19155 m .68888 .20842 L .69434 .21764 L p .403 .375 .714 r
F P
0 g
s
.85799 .23584 m .8503 .23731 L .85247 .23597 L p .031 0 0 r
F P
0 g
s
.85247 .23597 m .85853 .23481 L .85799 .23584 L p .031 0 0 r
F P
0 g
s
.85247 .23597 m .85799 .23584 L .85797 .23584 L .031 0 0 r
F
.85725 .23541 m .84774 .23723 L .85028 .23731 L p .231 .75 .796 r
F P
0 g
s
.85028 .23731 m .8503 .23731 L p .85033 .2373 L .231 .75 .796 r
F P
0 g
s
.85033 .2373 m .85725 .23541 L .85028 .23731 L .231 .75 .796 r
F
.85799 .23584 m .85799 .23584 L p .85797 .23584 L .031 0 0 r
F P
0 g
s
.80656 .0634 m .83446 .05758 L .83537 .05938 L p .436 .858 .95 r
F P
0 g
s
.80704 .24993 m .79642 .25939 L .80534 .25928 L p .707 .898 .965 r
F P
0 g
s
.80534 .25928 m .81518 .25053 L .80704 .24993 L p .707 .898 .965 r
F P
0 g
s
.76748 .25233 m .75599 .26529 L .7663 .26827 L p .645 .745 .922 r
F P
0 g
s
.7663 .26827 m .77733 .25589 L .76748 .25233 L p .645 .745 .922 r
F P
0 g
s
.69434 .21764 m .70831 .20109 L .70303 .19155 L p .403 .375 .714 r
F P
0 g
s
.70831 .20109 m .69434 .21764 L .7009 .22654 L p .442 .431 .752 r
F P
0 g
s
.69423 .16305 m .71244 .14554 L .71196 .1366 L p .244 .096 .472 r
F P
0 g
s
.71244 .14554 m .69423 .16305 L .69593 .17237 L p .312 .194 .554 r
F P
0 g
s
.71449 .1208 m .73715 .10414 L .73959 .09788 L p .061 0 .1 r
F P
0 g
s
.73715 .10414 m .71449 .1208 L .71265 .12831 L p .188 0 .276 r
F P
0 g
s
.83956 .23993 m .83143 .24393 L .83724 .24271 L p .497 .907 .858 r
F P
0 g
s
.83724 .24271 m .8439 .23942 L .83956 .23993 L p .497 .907 .858 r
F P
0 g
s
.77625 .0733 m .80403 .06343 L .80656 .0634 L p .362 .833 .807 r
F P
0 g
s
.80403 .06343 m .77625 .0733 L .77254 .07532 L p 0 0 0 r
F P
0 g
s
.825 .24384 m .81518 .25053 L .82275 .24984 L p .669 .946 .959 r
F P
0 g
s
.82275 .24984 m .83143 .24393 L .825 .24384 L p .669 .946 .959 r
F P
0 g
s
.83446 .05758 m .80656 .0634 L .80403 .06343 L p .229 .748 .781 r
F P
0 g
s
.75765 .24762 m .74571 .26118 L .75599 .26529 L p .618 .7 .903 r
F P
0 g
s
.75599 .26529 m .76748 .25233 L .75765 .24762 L p .618 .7 .903 r
F P
0 g
s
.7009 .22654 m .71463 .21037 L .70831 .20109 L p .442 .431 .752 r
F P
0 g
s
.71463 .21037 m .7009 .22654 L .70845 .23496 L p .476 .482 .784 r
F P
0 g
s
.74294 .09275 m .76944 .07868 L .77254 .07532 L p 0 0 0 r
F P
0 g
s
.76944 .07868 m .74294 .09275 L .73959 .09788 L p .096 0 0 r
F P
0 g
s
.79844 .24805 m .78703 .25826 L .79642 .25939 L p .69 .845 .957 r
F P
0 g
s
.79642 .25939 m .80704 .24993 L .79844 .24805 L p .69 .845 .957 r
F P
0 g
s
.74801 .24185 m .73565 .25599 L .74571 .26118 L p .591 .657 .883 r
F P
0 g
s
.74571 .26118 m .75765 .24762 L .74801 .24185 L p .591 .657 .883 r
F P
0 g
s
.70845 .23496 m .7219 .21924 L .71463 .21037 L p .476 .482 .784 r
F P
0 g
s
.7219 .21924 m .70845 .23496 L .71686 .24277 L p .507 .528 .812 r
F P
0 g
s
.84774 .23723 m .83956 .23993 L .8439 .23942 L p .355 .829 .82 r
F P
0 g
s
.8439 .23942 m .8503 .23731 L .84774 .23723 L p .355 .829 .82 r
F P
0 g
s
.73874 .23512 m .72597 .24982 L .73565 .25599 L p .564 .614 .861 r
F P
0 g
s
.73565 .25599 m .74801 .24185 L .73874 .23512 L p .564 .614 .861 r
F P
0 g
s
.71686 .24277 m .72998 .22754 L .7219 .21924 L p .507 .528 .812 r
F P
0 g
s
.72998 .22754 m .71686 .24277 L .72597 .24982 L p .536 .572 .838 r
F P
0 g
s
.69593 .17237 m .71409 .15499 L .71244 .14554 L p .312 .194 .554 r
F P
0 g
s
.71409 .15499 m .69593 .17237 L .69888 .18192 L p .366 .273 .617 r
F P
0 g
s
.72597 .24982 m .73874 .23512 L .72998 .22754 L p .536 .572 .838 r
F P
0 g
s
.8503 .23731 m .85799 .23584 L .85725 .23541 L p .231 .75 .796 r
F P
0 g
s
.71265 .12831 m .73568 .11142 L .73715 .10414 L p .188 0 .276 r
F P
0 g
s
.73568 .11142 m .71265 .12831 L .71196 .1366 L p .279 .066 .402 r
F P
0 g
s
.80403 .06343 m .83373 .05724 L .83446 .05758 L p .229 .748 .781 r
F P
0 g
s
.83473 .23905 m .825 .24384 L .83143 .24393 L p .601 .93 .961 r
F P
0 g
s
.83143 .24393 m .83956 .23993 L .83473 .23905 L p .601 .93 .961 r
F P
0 g
s
.81806 .24241 m .80704 .24993 L .81518 .25053 L p .682 .9 .974 r
F P
0 g
s
.81518 .25053 m .825 .24384 L .81806 .24241 L p .682 .9 .974 r
F P
0 g
s
.78954 .24492 m .77733 .25589 L .78703 .25826 L p .668 .793 .941 r
F P
0 g
s
.78703 .25826 m .79844 .24805 L .78954 .24492 L p .668 .793 .941 r
F P
0 g
s
.77254 .07532 m .80188 .0649 L .80403 .06343 L p 0 0 0 r
F P
0 g
s
.80188 .0649 m .77254 .07532 L .76944 .07868 L p .103 0 0 r
F P
0 g
s
.69888 .18192 m .71689 .16477 L .71409 .15499 L p .366 .273 .617 r
F P
0 g
s
.71689 .16477 m .69888 .18192 L .70303 .19155 L p .409 .339 .667 r
F P
0 g
s
.73959 .09788 m .76701 .08335 L .76944 .07868 L p .096 0 0 r
F P
0 g
s
.76701 .08335 m .73959 .09788 L .73715 .10414 L p .234 0 .18 r
F P
0 g
s
.83373 .05724 m .80403 .06343 L .80188 .0649 L p .032 0 0 r
F P
0 g
s
.84483 .23572 m .83473 .23905 L .83956 .23993 L p .516 .897 .958 r
F P
0 g
s
.83956 .23993 m .84774 .23723 L .84483 .23572 L p .516 .897 .958 r
F P
0 g
s
.78049 .24059 m .76748 .25233 L .77733 .25589 L p .646 .745 .921 r
F P
0 g
s
.77733 .25589 m .78954 .24492 L .78049 .24059 L p .646 .745 .921 r
F P
0 g
s
.71196 .1366 m .7352 .11961 L .73568 .11142 L p .279 .066 .402 r
F P
0 g
s
.7352 .11961 m .71196 .1366 L .71244 .14554 L p .345 .169 .493 r
F P
0 g
s
.70303 .19155 m .72079 .17473 L .71689 .16477 L p .409 .339 .667 r
F P
0 g
s
.72079 .17473 m .70303 .19155 L .70831 .20109 L p .445 .395 .708 r
F P
0 g
s
.81071 .23967 m .79844 .24805 L .80704 .24993 L p .676 .846 .964 r
F P
0 g
s
.80704 .24993 m .81806 .24241 L .81071 .23967 L p .676 .846 .964 r
F P
0 g
s
.85632 .23351 m .84483 .23572 L .84774 .23723 L p .435 .854 .956 r
F P
0 g
s
.84774 .23723 m .85725 .23541 L .85632 .23351 L p .435 .854 .956 r
F P
0 g
s
.82947 .23678 m .81806 .24241 L .825 .24384 L p .644 .896 .984 r
F P
0 g
s
.825 .24384 m .83473 .23905 L .82947 .23678 L p .644 .896 .984 r
F P
0 g
s
.77144 .23511 m .75765 .24762 L .76748 .25233 L p .623 .7 .9 r
F P
0 g
s
.76748 .25233 m .78049 .24059 L .77144 .23511 L p .623 .7 .9 r
F P
0 g
s
.80188 .0649 m .8332 .05837 L .83373 .05724 L p .032 0 0 r
F P
0 g
s
.70831 .20109 m .72573 .18469 L .72079 .17473 L p .445 .395 .708 r
F P
0 g
s
.72573 .18469 m .70831 .20109 L .71463 .21037 L p .477 .445 .744 r
F P
0 g
s
.76944 .07868 m .80014 .06779 L .80188 .0649 L p .103 0 0 r
F P
0 g
s
.80014 .06779 m .76944 .07868 L .76701 .08335 L p .268 0 .048 r
F P
0 g
s
.73715 .10414 m .7653 .08926 L .76701 .08335 L p .234 0 .18 r
F P
0 g
s
.7653 .08926 m .73715 .10414 L .73568 .11142 L p .328 .047 .326 r
F P
0 g
s
.76255 .22859 m .74801 .24185 L .75765 .24762 L p .601 .657 .877 r
F P
0 g
s
.75765 .24762 m .77144 .23511 L .76255 .22859 L p .601 .657 .877 r
F P
0 g
s
.71244 .14554 m .73573 .12858 L .7352 .11961 L p .345 .169 .493 r
F P
0 g
s
.73573 .12858 m .71244 .14554 L .71409 .15499 L p .395 .249 .563 r
F P
0 g
s
.71463 .21037 m .73163 .19448 L .72573 .18469 L p .477 .445 .744 r
F P
0 g
s
.73163 .19448 m .71463 .21037 L .7219 .21924 L p .505 .491 .775 r
F P
0 g
s
.8332 .05837 m .80188 .0649 L .80014 .06779 L p .252 0 0 r
F P
0 g
s
.80307 .23564 m .78954 .24492 L .79844 .24805 L p .663 .793 .944 r
F P
0 g
s
.79844 .24805 m .81071 .23967 L .80307 .23564 L p .663 .793 .944 r
F P
0 g
s
.75398 .22113 m .73874 .23512 L .74801 .24185 L p .578 .616 .854 r
F P
0 g
s
.74801 .24185 m .76255 .22859 L .75398 .22113 L p .578 .616 .854 r
F P
0 g
s
.84162 .23277 m .82947 .23678 L .83473 .23905 L p .598 .882 .992 r
F P
0 g
s
.83473 .23905 m .84483 .23572 L .84162 .23277 L p .598 .882 .992 r
F P
0 g
s
.7219 .21924 m .73838 .20392 L .73163 .19448 L p .505 .491 .775 r
F P
0 g
s
.73838 .20392 m .7219 .21924 L .72998 .22754 L p .531 .534 .803 r
F P
0 g
s
.74588 .21286 m .72998 .22754 L .73874 .23512 L p .555 .575 .829 r
F P
0 g
s
.73874 .23512 m .75398 .22113 L .74588 .21286 L p .555 .575 .829 r
F P
0 g
s
.72998 .22754 m .74588 .21286 L .73838 .20392 L p .531 .534 .803 r
F P
0 g
s
.82388 .23316 m .81071 .23967 L .81806 .24241 L p .657 .845 .972 r
F P
0 g
s
.81806 .24241 m .82947 .23678 L .82388 .23316 L p .657 .845 .972 r
F P
0 g
s
.71409 .15499 m .73728 .13817 L .73573 .12858 L p .395 .249 .563 r
F P
0 g
s
.73728 .13817 m .71409 .15499 L .71689 .16477 L p .434 .315 .618 r
F P
0 g
s
.85521 .23015 m .84162 .23277 L .84483 .23572 L p .552 .86 .997 r
F P
0 g
s
.84483 .23572 m .85632 .23351 L .85521 .23015 L p .552 .86 .997 r
F P
0 g
s
.73568 .11142 m .76434 .09631 L .7653 .08926 L p .328 .047 .326 r
F P
0 g
s
.76434 .09631 m .73568 .11142 L .7352 .11961 L p .393 .155 .43 r
F P
0 g
s
.79529 .2304 m .78049 .24059 L .78954 .24492 L p .647 .745 .92 r
F P
0 g
s
.78954 .24492 m .80307 .23564 L .79529 .2304 L p .647 .745 .92 r
F P
0 g
s
.76701 .08335 m .79885 .07207 L .80014 .06779 L p .268 0 .048 r
F P
0 g
s
.79885 .07207 m .76701 .08335 L .7653 .08926 L p .374 .02 .23 r
F P
0 g
s
.80014 .06779 m .83287 .06097 L .8332 .05837 L p .252 0 0 r
F P
0 g
s
.71689 .16477 m .73981 .14822 L .73728 .13817 L p .434 .315 .618 r
F P
0 g
s
.73981 .14822 m .71689 .16477 L .72079 .17473 L p .467 .37 .662 r
F P
0 g
s
.83287 .06097 m .80014 .06779 L .79885 .07207 L p .394 0 .084 r
F P
0 g
s
.83816 .22843 m .82388 .23316 L .82947 .23678 L p .634 .838 .979 r
F P
0 g
s
.82947 .23678 m .84162 .23277 L .83816 .22843 L p .634 .838 .979 r
F P
0 g
s
.81804 .22823 m .80307 .23564 L .81071 .23967 L p .656 .793 .947 r
F P
0 g
s
.81071 .23967 m .82388 .23316 L .81804 .22823 L p .656 .793 .947 r
F P
0 g
s
.78749 .22401 m .77144 .23511 L .78049 .24059 L p .63 .7 .895 r
F P
0 g
s
.78049 .24059 m .79529 .2304 L .78749 .22401 L p .63 .7 .895 r
F P
0 g
s
.7352 .11961 m .76416 .10439 L .76434 .09631 L p .393 .155 .43 r
F P
0 g
s
.76416 .10439 m .7352 .11961 L .73573 .12858 L p .44 .238 .508 r
F P
0 g
s
.72079 .17473 m .74329 .15857 L .73981 .14822 L p .467 .37 .662 r
F P
0 g
s
.74329 .15857 m .72079 .17473 L .72573 .18469 L p .494 .419 .701 r
F P
0 g
s
.7798 .2166 m .76255 .22859 L .77144 .23511 L p .613 .658 .87 r
F P
0 g
s
.77144 .23511 m .78749 .22401 L .7798 .2166 L p .613 .658 .87 r
F P
0 g
s
.85394 .22538 m .83816 .22843 L .84162 .23277 L p .611 .827 .983 r
F P
0 g
s
.84162 .23277 m .85521 .23015 L .85394 .22538 L p .611 .827 .983 r
F P
0 g
s
.7653 .08926 m .79803 .07768 L .79885 .07207 L p .374 .02 .23 r
F P
0 g
s
.79803 .07768 m .7653 .08926 L .76434 .09631 L p .443 .141 .356 r
F P
0 g
s
.72573 .18469 m .74767 .16902 L .74329 .15857 L p .494 .419 .701 r
F P
0 g
s
.74767 .16902 m .72573 .18469 L .73163 .19448 L p .518 .463 .734 r
F P
0 g
s
.81205 .22206 m .79529 .2304 L .80307 .23564 L p .649 .745 .919 r
F P
0 g
s
.80307 .23564 m .81804 .22823 L .81205 .22206 L p .649 .745 .919 r
F P
0 g
s
.77237 .20828 m .75398 .22113 L .76255 .22859 L p .596 .619 .845 r
F P
0 g
s
.76255 .22859 m .7798 .2166 L .77237 .20828 L p .596 .619 .845 r
F P
0 g
s
.79885 .07207 m .83277 .06501 L .83287 .06097 L p .394 0 .084 r
F P
0 g
s
.8345 .22277 m .81804 .22823 L .82388 .23316 L p .648 .79 .95 r
F P
0 g
s
.82388 .23316 m .83816 .22843 L .8345 .22277 L p .648 .79 .95 r
F P
0 g
s
.73163 .19448 m .75286 .17939 L .74767 .16902 L p .518 .463 .734 r
F P
0 g
s
.75286 .17939 m .73163 .19448 L .73838 .20392 L p .539 .503 .764 r
F P
0 g
s
.73573 .12858 m .76476 .11338 L .76416 .10439 L p .44 .238 .508 r
F P
0 g
s
.76476 .11338 m .73573 .12858 L .73728 .13817 L p .475 .303 .568 r
F P
0 g
s
.76532 .1992 m .74588 .21286 L .75398 .22113 L p .578 .58 .819 r
F P
0 g
s
.75398 .22113 m .77237 .20828 L .76532 .1992 L p .578 .58 .819 r
F P
0 g
s
.83277 .06501 m .79885 .07207 L .79803 .07768 L p .48 .106 .252 r
F P
0 g
s
.73838 .20392 m .75878 .18952 L .75286 .17939 L p .539 .503 .764 r
F P
0 g
s
.75878 .18952 m .73838 .20392 L .74588 .21286 L p .559 .542 .792 r
F P
0 g
s
.74588 .21286 m .76532 .1992 L .75878 .18952 L p .559 .542 .792 r
F P
0 g
s
.80602 .21476 m .78749 .22401 L .79529 .2304 L p .64 .702 .891 r
F P
0 g
s
.79529 .2304 m .81205 .22206 L .80602 .21476 L p .64 .702 .891 r
F P
0 g
s
.76434 .09631 m .79771 .08454 L .79803 .07768 L p .443 .141 .356 r
F P
0 g
s
.79771 .08454 m .76434 .09631 L .76416 .10439 L p .489 .23 .447 r
F P
0 g
s
.85253 .21926 m .8345 .22277 L .83816 .22843 L p .64 .787 .952 r
F P
0 g
s
.83816 .22843 m .85394 .22538 L .85253 .21926 L p .64 .787 .952 r
F P
0 g
s
.73728 .13817 m .76614 .12312 L .76476 .11338 L p .475 .303 .568 r
F P
0 g
s
.76614 .12312 m .73728 .13817 L .73981 .14822 L p .503 .358 .617 r
F P
0 g
s
.83071 .21585 m .81205 .22206 L .81804 .22823 L p .652 .746 .919 r
F P
0 g
s
.81804 .22823 m .8345 .22277 L .83071 .21585 L p .652 .746 .919 r
F P
0 g
s
.79803 .07768 m .83288 .07044 L .83277 .06501 L p .48 .106 .252 r
F P
0 g
s
.80005 .20645 m .7798 .2166 L .78749 .22401 L p .629 .662 .863 r
F P
0 g
s
.78749 .22401 m .80602 .21476 L .80005 .20645 L p .629 .662 .863 r
F P
0 g
s
.83288 .07044 m .79803 .07768 L .79771 .08454 L p .533 .211 .369 r
F P
0 g
s
.73981 .14822 m .76828 .13344 L .76614 .12312 L p .503 .358 .617 r
F P
0 g
s
.76828 .13344 m .73981 .14822 L .74329 .15857 L p .526 .405 .657 r
F P
0 g
s
.76416 .10439 m .79789 .09253 L .79771 .08454 L p .489 .23 .447 r
F P
0 g
s
.79789 .09253 m .76416 .10439 L .76476 .11338 L p .523 .298 .516 r
F P
0 g
s
.79425 .19726 m .77237 .20828 L .7798 .2166 L p .617 .625 .836 r
F P
0 g
s
.7798 .2166 m .80005 .20645 L .79425 .19726 L p .617 .625 .836 r
F P
0 g
s
.851 .21189 m .83071 .21585 L .8345 .22277 L p .654 .747 .918 r
F P
0 g
s
.8345 .22277 m .85253 .21926 L .851 .21189 L p .654 .747 .918 r
F P
0 g
s
.74329 .15857 m .77115 .14417 L .76828 .13344 L p .526 .405 .657 r
F P
0 g
s
.77115 .14417 m .74329 .15857 L .74767 .16902 L p .545 .446 .693 r
F P
0 g
s
.82686 .2078 m .80602 .21476 L .81205 .22206 L p .65 .705 .887 r
F P
0 g
s
.81205 .22206 m .83071 .21585 L .82686 .2078 L p .65 .705 .887 r
F P
0 g
s
.78872 .18736 m .76532 .1992 L .77237 .20828 L p .604 .589 .809 r
F P
0 g
s
.77237 .20828 m .79425 .19726 L .78872 .18736 L p .604 .589 .809 r
F P
0 g
s
.74767 .16902 m .77469 .15512 L .77115 .14417 L p .545 .446 .693 r
F P
0 g
s
.77469 .15512 m .74767 .16902 L .75286 .17939 L p .562 .484 .725 r
F P
0 g
s
.79771 .08454 m .83322 .07718 L .83288 .07044 L p .533 .211 .369 r
F P
0 g
s
.83322 .07718 m .79771 .08454 L .79789 .09253 L p .567 .289 .454 r
F P
0 g
s
.78356 .17691 m .75878 .18952 L .76532 .1992 L p .591 .555 .782 r
F P
0 g
s
.76532 .1992 m .78872 .18736 L .78356 .17691 L p .591 .555 .782 r
F P
0 g
s
.76476 .11338 m .79857 .10154 L .79789 .09253 L p .523 .298 .516 r
F P
0 g
s
.79857 .10154 m .76476 .11338 L .76614 .12312 L p .547 .354 .57 r
F P
0 g
s
.75286 .17939 m .77885 .1661 L .77469 .15512 L p .562 .484 .725 r
F P
0 g
s
.77885 .1661 m .75286 .17939 L .75878 .18952 L p .577 .52 .754 r
F P
0 g
s
.75878 .18952 m .78356 .17691 L .77885 .1661 L p .577 .52 .754 r
F P
0 g
s
.823 .19875 m .80005 .20645 L .80602 .21476 L p .646 .668 .857 r
F P
0 g
s
.80602 .21476 m .82686 .2078 L .823 .19875 L p .646 .668 .857 r
F P
0 g
s
.84938 .20338 m .82686 .2078 L .83071 .21585 L p .66 .71 .885 r
F P
0 g
s
.83071 .21585 m .851 .21189 L .84938 .20338 L p .66 .71 .885 r
F P
0 g
s
.76614 .12312 m .79974 .1114 L .79857 .10154 L p .547 .354 .57 r
F P
0 g
s
.79974 .1114 m .76614 .12312 L .76828 .13344 L p .567 .4 .614 r
F P
0 g
s
.79789 .09253 m .83377 .08512 L .83322 .07718 L p .567 .289 .454 r
F P
0 g
s
.83377 .08512 m .79789 .09253 L .79857 .10154 L p .591 .349 .518 r
F P
0 g
s
.8192 .18885 m .79425 .19726 L .80005 .20645 L p .64 .634 .829 r
F P
0 g
s
.80005 .20645 m .823 .19875 L .8192 .18885 L p .64 .634 .829 r
F P
0 g
s
.76828 .13344 m .80139 .12195 L .79974 .1114 L p .567 .4 .614 r
F P
0 g
s
.80139 .12195 m .76828 .13344 L .77115 .14417 L p .582 .439 .652 r
F P
0 g
s
.8477 .19388 m .823 .19875 L .82686 .2078 L p .663 .677 .854 r
F P
0 g
s
.82686 .2078 m .84938 .20338 L .8477 .19388 L p .663 .677 .854 r
F P
0 g
s
.81554 .17827 m .78872 .18736 L .79425 .19726 L p .633 .602 .801 r
F P
0 g
s
.79425 .19726 m .8192 .18885 L .81554 .17827 L p .633 .602 .801 r
F P
0 g
s
.77115 .14417 m .80349 .133 L .80139 .12195 L p .582 .439 .652 r
F P
0 g
s
.80349 .133 m .77115 .14417 L .77469 .15512 L p .595 .475 .686 r
F P
0 g
s
.79857 .10154 m .83454 .09414 L .83377 .08512 L p .591 .349 .518 r
F P
0 g
s
.83454 .09414 m .79857 .10154 L .79974 .1114 L p .609 .397 .569 r
F P
0 g
s
.81208 .1672 m .78356 .17691 L .78872 .18736 L p .625 .571 .773 r
F P
0 g
s
.78872 .18736 m .81554 .17827 L .81208 .1672 L p .625 .571 .773 r
F P
0 g
s
.77469 .15512 m .806 .14436 L .80349 .133 L p .595 .475 .686 r
F P
0 g
s
.806 .14436 m .77469 .15512 L .77885 .1661 L p .607 .508 .717 r
F P
0 g
s
.80888 .15582 m .77885 .1661 L .78356 .17691 L p .616 .54 .746 r
F P
0 g
s
.78356 .17691 m .81208 .1672 L .80888 .15582 L p .616 .54 .746 r
F P
0 g
s
.77885 .1661 m .80888 .15582 L .806 .14436 L p .607 .508 .717 r
F P
0 g
s
.84599 .18355 m .8192 .18885 L .823 .19875 L p .662 .647 .824 r
F P
0 g
s
.823 .19875 m .8477 .19388 L .84599 .18355 L p .662 .647 .824 r
F P
0 g
s
.79974 .1114 m .83549 .10407 L .83454 .09414 L p .609 .397 .569 r
F P
0 g
s
.83549 .10407 m .79974 .1114 L .80139 .12195 L p .622 .438 .612 r
F P
0 g
s
.84426 .17256 m .81554 .17827 L .8192 .18885 L p .66 .618 .796 r
F P
0 g
s
.8192 .18885 m .84599 .18355 L .84426 .17256 L p .66 .618 .796 r
F P
0 g
s
.80139 .12195 m .83663 .11476 L .83549 .10407 L p .622 .438 .612 r
F P
0 g
s
.83663 .11476 m .80139 .12195 L .80349 .133 L p .632 .473 .649 r
F P
0 g
s
.84257 .1611 m .81208 .1672 L .81554 .17827 L p .657 .59 .768 r
F P
0 g
s
.81554 .17827 m .84426 .17256 L .84257 .1611 L p .657 .59 .768 r
F P
0 g
s
.80349 .133 m .83794 .126 L .83663 .11476 L p .632 .473 .649 r
F P
0 g
s
.83794 .126 m .80349 .133 L .806 .14436 L p .641 .505 .682 r
F P
0 g
s
.84093 .14938 m .80888 .15582 L .81208 .1672 L p .653 .562 .74 r
F P
0 g
s
.81208 .1672 m .84257 .1611 L .84093 .14938 L p .653 .562 .74 r
F P
0 g
s
.806 .14436 m .83938 .13761 L .83794 .126 L p .641 .505 .682 r
F P
0 g
s
.83938 .13761 m .806 .14436 L .80888 .15582 L p .647 .534 .712 r
F P
0 g
s
.80888 .15582 m .84093 .14938 L .83938 .13761 L p .647 .534 .712 r
F P
0 g
s
.25 Mabswid
.84367 0 m
.98315 .20803 L
s
.98315 .20803 m
1 .35105 L
s
1 .35105 m
.85682 .14805 L
s
.85682 .14805 m
.84367 0 L
s
.01574 .28763 m
0 .42841 L
s
0 .42841 m
.85682 .14805 L
s
.85682 .14805 m
.84367 0 L
s
.84367 0 m
.01574 .28763 L
s
.01574 .28763 m
.84367 0 L
s
.05164 .27516 m
.05099 .28149 L
s
[(-5)] .05295 .26251 -0.10367 1 Mshowa
.22413 .21524 m
.22372 .22158 L
s
[(-2.5)] .22494 .20255 -0.0639 1 Mshowa
.40567 .15217 m
.40553 .15852 L
s
[(0)] .40593 .13945 -0.0208 1 Mshowa
.59699 .0857 m
.59716 .09206 L
s
[(2.5)] .59666 .07299 .02608 1 Mshowa
.79891 .01555 m
.7994 .02189 L
s
[(5)] .79793 .00287 .07725 1 Mshowa
.125 Mabswid
.08545 .26342 m
.08508 .26721 L
s
.11959 .25155 m
.11926 .25535 L
s
.15409 .23957 m
.15378 .24337 L
s
.18893 .22747 m
.18865 .23127 L
s
.25969 .20288 m
.25948 .20669 L
s
.29562 .1904 m
.29544 .19421 L
s
.33192 .17779 m
.33177 .1816 L
s
.3686 .16504 m
.36849 .16886 L
s
.44312 .13915 m
.44308 .14297 L
s
.48098 .126 m
.48097 .12982 L
s
.51924 .11271 m
.51926 .11653 L
s
.55791 .09928 m
.55797 .10309 L
s
.6365 .07197 m
.63664 .07579 L
s
.67644 .0581 m
.67661 .06191 L
s
.71682 .04407 m
.71703 .04788 L
s
.75764 .02989 m
.75789 .03369 L
s
.01817 .28679 m
.01775 .29058 L
s
.84065 .00105 m
.84098 .00485 L
s
.25 Mabswid
.98315 .20803 m
1 .35105 L
s
.98353 .21129 m
.97747 .21319 L
s
[(-1)] .99567 .20748 -1 .31356 Mshowa
.98745 .24454 m
.98138 .24642 L
s
[(-0.5)] .9996 .24079 -1 .30907 Mshowa
.99143 .27833 m
.98535 .28018 L
s
[(0)] 1.0036 .27463 -1 .30452 Mshowa
.99548 .31267 m
.98939 .31449 L
s
[(0.5)] 1.00766 .30901 -1 .29989 Mshowa
.99959 .34756 m
.99349 .34936 L
s
[(1)] 1.01179 .34396 -1 .2952 Mshowa
.125 Mabswid
.98431 .2179 m
.98067 .21904 L
s
.98509 .22453 m
.98145 .22566 L
s
.98588 .23118 m
.98223 .23231 L
s
.98666 .23785 m
.98302 .23898 L
s
.98824 .25126 m
.9846 .25238 L
s
.98904 .25799 m
.98539 .25912 L
s
.98983 .26475 m
.98618 .26587 L
s
.99063 .27153 m
.98698 .27265 L
s
.99224 .28516 m
.98859 .28626 L
s
.99304 .292 m
.98939 .29311 L
s
.99385 .29887 m
.9902 .29997 L
s
.99466 .30576 m
.99101 .30685 L
s
.99629 .3196 m
.99264 .32069 L
s
.99711 .32656 m
.99346 .32765 L
s
.99794 .33354 m
.99428 .33462 L
s
.99876 .34054 m
.9951 .34162 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 169.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000ZB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00c`3oool3000004h0oooo003B
0?ooo`030000003oool0oooo04/0oooo003B0?ooo`030000003oool0oooo04/0oooo003?0?ooo`<0
00005`3oool4000003<0oooo003?0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
=03oool00<l0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0c0?ooo`00c`3oool4
00000100oooo100000040?ooo`030000003oool0oooo0380oooo003L0?ooo`8000003P3oool00`00
0000oooo0?ooo`0a0?ooo`00f@3oool3000000030?ooo`000000000000X0oooo00@000000?ooo`3o
ool00000<`3oool00=H0oooo0`0000040?ooo`8000002`3oool2000003@0oooo003C0?ooo`<00000
1`3oool00`000000oooo000000100?ooo`00d03oool3000000X0oooo00@000000?ooo`0000000000
?`3oool00<h0oooo0P0000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000?`3o
ool00</0oooo0`00000@0?ooo`040000003oool0oooo000003h0oooo00380?ooo`<000004`3oool0
0`000000oooo0?ooo`02000003d0oooo00350?ooo`<000005P3oool01@000000oooo0?ooo`3oool0
000003d0oooo00320?ooo`<000000P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0080oooo0P00000k0?ooo`00_`3oool3000001`0oooo00<000000?ooo`3oool00P3oool2000000d0
oooo1000000Z0?ooo`00_03oool3000001l0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo02T0oooo002D0?ooo`@000000`3oool00`000000oooo0?oo
o`020?ooo`<000005P3oool400000240oooo00<000000?ooo`3oool0103oool2000000d0oooo00<0
00000?ooo`3oool0:@3oool009@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@
0?ooo`<000009@3oool00`000000oooo0?ooo`040?ooo`8000001@3oool4000000@0oooo00<00000
0?ooo`3oool0:@3oool009D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?oo
o`800000:03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0:@3oool009H0oooo00<000000?ooo`3oool01`3oool3000000h0oooo0`00000S0?ooo`D0
00000`3oool00`000000oooo0?ooo`040?ooo`<000002@3oool3000002/0oooo002G0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool3000000030?ooo`000000oooo01h0oooo
1P0000000`10000000000000000200000080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo02T0oooo002D0?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool0203oool300000280oooo200000000`1T01D000000000000200000080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0d0?ooo`00U@3oool2000000T0oooo1000
00040?ooo`<000008`3oool:0000000307XK@00000000000008000000P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo03@0oooo002U0?ooo`<000008`3oool50000000304@030000000
000000H000000P28=Uh200000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0c
0?ooo`00XP3oool300000080oooo00<000000?ooo`3oool07`3oool300000080A00<1P00000508Pf
GP<0000000@0Z<7/0000003oool000002`3oool00`000000oooo0?ooo`0b0?ooo`00W`3oool30000
02D0oooo0P0000000`0H000000000000000400000004074TF`000000R3IN08PfGPD000000P2ABG@3
000000030?ooo`000000oooo00T0oooo0P00000d0?ooo`00W03oool3000002H0oooo0P0000000`0H
0000000000000003000000<0LBAK100000050959M0<0000000@0ZKSS0000003oool00000303oool0
0`000000oooo0?ooo`0a0?ooo`00VP3oool2000000030?ooo`000000oooo02D0oooo1`000002074T
F`<0000000@0OCYb0000002ABG@0TDUd1@00000209MIQ0<0000000<0oooo0000003oool02`3oool2
00000380oooo002G0?ooo`<000000`3oool00`000000oooo0?ooo`0R0?ooo`H0000000<0D`aC0000
001a95/00P00000307djLP@000001@2GFH@3000000040:Z_g0000000oooo000000d0oooo00<00000
0?ooo`3oool01P3oool2000002P0oooo002D0?ooo`<00000:P3oool500000080D`aC0`00000207dj
LP<000000P25C8@00`000000UeV409MIQ00400000080VfFA0`0000020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000W0?ooo`00T@3oool30000
02`0oooo00@0000000l06@00000000000P1C35<20000000306@WKP000000OCYb008000001025C8@4
000000H0VfFA00<000000:ZXe00000000P3oool00`000000oooo0?ooo`0;0?ooo`8000001@3oool0
10000000oooo0?ooo`00000W0?ooo`00SP3oool3000000030?ooo`000000oooo02X0oooo0P000000
100?01T0000005<<D`1C35<200000080I2M^0`00000408E<Q080000000<0S5ZA0000002KII401@2K
II4300000080ZZSD00<000000?ooo`0000003`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000002L0oooo002;0?ooo`<00000;`3oool3000000040300AP000000000000000080I2M^
0P0000000`1`?880000008E<Q00208E<Q08000000`2<FY400`000000VfFA09]UT@0400000080Wg2L
100000000`3oool000000?ooo`0>0?ooo`8000000`3oool010000000oooo0?ooo`00000W0?ooo`00
J@3oool2000001d0oooo0`00000a0?ooo`<000000P0`04H00`000000I2M^06@WKP02000000<0L3b2
00@0000008E<Q00000000000102<FY44000000L0Wg2L00D000000:ZQc@000000oooo0000000>0?oo
o`030000003oool0000000<0oooo00@000000?ooo`3oool000009`3oool006P0oooo00@000000?oo
o`3oool000006@3oool400000380oooo0`0000000`0`04H0000000000003000000@0L3b20`000003
08aJT@<0000000<0TFJM0000002OL9`01P2OL9`5000000030?ooo`000000oooo0100oooo00@00000
0?ooo`3oool0oooo0P00000X0?ooo`00J03oool010000000oooo0?ooo`00000F0?ooo`<00000=@3o
ool200000080<01600@0000004L@IP1746H00000101`?8820000000307U=T@000000S5ZA00<00000
102AIYd00`000000Wg2L09m`W00500000080XGVV00D000000:VJa`000000oooo0000000@0?ooo`80
0000;@3oool006P0oooo00@000000?ooo`3oool000004`3oool3000003L0oooo1@00000204L@IP80
00000P1`?88200000080NDfA0`000006095VW@@000001`2QNJH00`000000ZI[70:VJa`0200000180
oooo00<000000?ooo`3oool0:P3oool006P0oooo00@000000?ooo`3oool000004@3oool2000003X0
oooo00<0000000P0=@0000000P1746H20000000405P[OP000000000000000080NDfA0P0000000`20
Fid00000095VW@03095VW@<0000000<0U72V0000002QNJH01P2QNJH7000001<0oooo00<000000?oo
o`3oool0:@3oool006P0oooo00@000000?ooo`3oool000003P3oool3000000030?ooo`000000oooo
03P0oooo00H0000000P0=@000000000004L@IP00000305P[OP030000001iCI40NDfA008000001020
Fid010000000TFJM00000000000509A`YP030000002QNJH0XGVV00@000000P2TPJh2000000030:RC
`000000000000180oooo0P00000[0?ooo`00J@3oool2000000`0oooo0`00000m0?ooo`<0000000<0
9`1L0000000000000P1H:gh00`000000ICn@00000002000000D0P5^M0`00000609A`YP@000001P2T
PJh01P000000X8k10:RC`0000000oooo000001<0oooo00<000000?ooo`3oool0:03oool007@0oooo
0`00000o0?ooo`<000000P0W05`010000000F2]n05P[OP00000206DoT00300000020Fid0P5^M00<0
P5^M0P0000000`26IjP0000009A`YP0309A`YP<0000000<0V7V_0000002TPJh01@2TPJh600000003
0?ooo`000000oooo0180oooo0P0000060?ooo`@000007`3oool00740oooo100000100?ooo`<00000
0P0W05`40000000406DoT00000000000000000<0P5^M0P00000308IWZ0030000002DL:H000000080
00001@2HNJl00`000000Y86^0000000300000080YHRf00H0000009f7^P00000000000?ooo`00000D
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool07P3oool006h0oooo0`0000130?oo
o`<0000000D09`1L000000000000?QQh0000000206DoT0040000001_D9h0Ke2N06m@WP<000001026
IjP3000000L0V7V_0`0000070:F8]P80000000<0Yhfi0000000000005@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01h0oooo001[0?ooo`<00000AP3oool400000080?QQh10000004
06m@WP0300000026IjP0QVNX0080QVNX0P0000000`2;L[40000009Qi[`0409Qi[`<0000000<0Vh:g
0000002UR;H01@2UR;H7000001@0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0N
0?ooo`00J03oool3000004P0oooo0P0000001`080500000003hHN00n67P0000004laS@000000101_
D9h20000000307MNZ@000000QVNX00800000102;L[400`000000V7V_00000002000000@0Vh:g00<0
00000:F8]P2UR;H0100000020:N?_@@0000000<0oooo0000003oool0503oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01h0oooo001U0?ooo`<000000P3oool00`000000oooo0?ooo`15
0?ooo`D0000000<0?QQh0000001?<Hd00P00000306m@WP040000001gGZT0MejY07MNZ@8000001@2;
L[43000000D0Vh:g1@0000030:N?_@@0000000D0Vgnc000000000000oooo0000000E0?ooo`800000
0`3oool300000200oooo001S0?ooo`800000C@3oool30000000502D6LP000000000004laS@000000
0P1MAId3000000<0MejY0P00000408]b/@8000000P2?NkT00`000000Vh:g0000000300000080WHZn
00<000000:N?_@2WSkd00`0000000`2WSkd000000000000400000080oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0oooo001P0?ooo`<00000CP3o
ool01P000000000A0000000000009@Ib00000080Cc6=00@0000005e5W@1MAId000000`1gGZT20000
0080OV^c00@0000008]b/@0000000000102?NkT2000000H0WHZn1`0000020:RGa0@000000`3oool0
0`000000oooo0?ooo`0C0?ooo`800000903oool005d0oooo1000001?0?ooo`070000000001400000
0000000U1W80000003`TRP0200000080GDFM0P00000207MNZ@030000001nJk<0OV^c0080OV^c0P00
000408mk^@80000000<0ThG10000002MR[h00P2MR[h6000000L0Z9O40`0000040?ooo`030000003o
ool0oooo0180oooo0P00000T0?ooo`00FP3oool3000005<0oooo0`0000001@0U1W80000003`TRP0l
98X000000080GDFM00<0000006QFZP1XEZX00P00000307i[/`80000000<0Q7Jk0000002?NkT00P2?
NkT010000000ThG109>5`@2CQL470000000309nBa@000000Z9O400D0Z9O41@0000040?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool08@3oool003H0oooo100000030?ooo`030000003o
ool0oooo0080oooo0`00000B0?ooo`<00000E@3oool500000080?2B:0P0000000`1MAId0000006QF
ZP0206QFZP050000001nJk<0OV^c07i[/`0000000`24M[/01@000000Sg^i000000000000ThG100<0
000000<0ThG10000000000001P2OT/D00`000000Z9O40000000300000080Z9k;0`0000050?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0803oool003H0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`@00000EP3oool2000000030000A@00000000000080?2B:
00@0000004dlW@00000000000`1XEZX00`000000LFFe00000002000000D0Q7Jk1000000209>5`@<0
00001P2OT/D3000000H0Z9k;100000050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0803oool003L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`<00000
FP3oool500000080?2B:00<0000004dlW@0000000P1XEZX200000080LFFe00<0000008Af^`24M[/0
0`24M[/3000000<0ThG10P00000309N>b0030000002OT/D0000000<000000P2RV/d010000000Z9k;
0:RNb`2XW//7000000D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0O0?ooo`00
<03oool4000000@0oooo00<000000?ooo`3oool01`3oool3000000T0oooo0`00001L0?ooo`<00000
00<0401/0000000[6HL00P0000000`1=?9d0000005]?Z`02000000<0LFFe00@0000007Ya_P000000
Q7Jk0`00000308V0``<00000102GS/P3000000D0XY[=1@0000030:VUdP@000001P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0000000H0oooo1000000F0?ooo`00>@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00H0oooo0`00001O0?ooo`@000000P0[6HL01P000000CCbM
04dlW@000000Fdn[000000<0LFFe00<0000007Ya_P0000001000000408V0``030000002GS/P0Uhk8
0080Uhk80P0000000`2JU/l000000::Jc@030::Jc@80000000<0Xj;D0000002YYM801P2YYM830000
00L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01L0oooo000f0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool30000
0080oooo00<000000?ooo`3oool0G03oool50000000302/IQ`000000?cBK0080000000D0Fdn[0000
001WGkH00000075U]@0300000080NW6n00<0000008V0``29P<<00P29P<<20000000308n:bP000000
Uhk800800000102JU/l010000000XY[=0000000000040:>Re0040000002YYM80ZJGB0:VUdPH00000
203oool00`000000oooo0?ooo`0B0?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`@00000
403oool003L0oooo0P0000090?ooo`H00000I03oool400000080:aV700<0000003ldV`0000000P1K
Cj/5000000<0NW6n00@00000085maP000000RH330P00000408n:bP030000002JU/l0VYK?00@0VYK?
0P0000050:>Re0D000000`2Y[MX3000000P0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool004<0oooo0`00
001U0?ooo`<0000000D0001V01hAQ0000000000003ldV`0500000080Ienf00D0000007Ya_P1jLKh0
NW6n00000003085maP030000002?R/X0Sh[:00<0Sh[:00<0000009>Dd@0000000`2JU/l200000004
09fOeP000000Xj;D0:>Re0<000000P2UZm/00`000000ZJgJ0:V]fP06000000T0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03`3oool00400oooo0`0000000`3oool000000?ooo`1U0?ooo`070000000003P000000000
000N4H@0000003ldV`0500000080Ienf00D00000075^`0000000NW6n00000003085maP0300000027
R<d000000080Sh[:0P00000209>Dd@040000002JU/l00000000000@0WIoF0P0000040:F[f`@00000
0`2X]N83000000X0oooo00<000000?ooo`3oool04@3oool3000000<0oooo100000040?ooo`030000
003oool0oooo00l0oooo000m0?ooo`<00000JP3oool40000000301hAQ00000000000008000000P1@
BJ/010000000Ienf06MO]P000003075^`00300000021OLH0PGg6008000000P27R<d00`000000Sh[:
0000000509>Dd@030000002MWmH0WIoF0080WIoF0P000000102QZM`000000:F[f`2UZm/200000080
Y[CS00<000000:RehP2X]N801@00000:0?ooo`030000003oool0oooo00l0oooo0`0000000`3oool0
00000?ooo`030?ooo`8000001@3oool00`000000oooo0?ooo`0?0?ooo`00>P3oool3000006d0oooo
00<000000000>00000000`0000001P0f;Y/000000519Z`1@BJ/0000005iL^08000000`1aK/001000
0000NG_800000000000508N8c@030000002CU=40TiCA0080TiCA0P0000000`2HW]P0000009fOeP02
000000@0XJWL0P0000030:Jdh`@000000`2W_n/2000000/0oooo00<000000?ooo`3oool02`3oool3
000000<0oooo0P0000090?ooo`<000004@3oool003L0oooo1000001]0?ooo`L0000000<0=RjK0000
000000000P1@BJ/00`000000GUbh00000003075^`0040000001iNlP0NG_8000000D0QhS=00@00000
08jCe0000000TiCA0P00000409RNf0030000002QZM`0XJWL0080XJWL0P0000000`2S/n@000000:Jd
h`0200000080Y[k[00<000000:Noj`2W_n/01000000<0?ooo`030000003oool0oooo00H0oooo1000
00070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool003@0oooo0`000003
0?ooo`030000003oool0oooo01l0oooo5P00000c0?ooo`H0000000<0001S0000000000000P0f;Y/0
2P000000B4J[000000000000GUbh0000001YJl800000075^`000000207Ukb00300000021Qll00000
00<0QhS=00D0000008jCe02>Tm@0SY?D0000000409RNf080000000<0W:SN0000002QZM`00P000002
0:>ci0<000000`2V_^/400000080XlWc0P00000=0?ooo`030000003oool0oooo0080oooo0`00000<
0?ooo`030000003oool0oooo01X0oooo000a0?ooo`<000008P3ooolS000002T0oooo0`0000030?oo
o`@0000000@060f30000000f;Y/000000P18AZ/010000000GUbh05iL^000000206U[`P050000001i
NlP0NG_807Ukb00000000P21Qll00`000000QhS=0000000308jCe0040000002CWMX0000009RNf080
0000102LZ=h2000000030:>ci000000000000080Y[k[00@000000:Jnj`00000000000P2Ub_<00`00
0000XlWc00000004000000`0oooo00<000000?ooo`0000000P00000>0?ooo`800000703oool002h0
oooo1000000O0?ooobl000007`3oool3000000D0oooo00L0000000000`000000000001P=P`000000
<2^J0080000000<0B4J[0000001HFKP00P00000206U[`P050000001dNLX0000007Ukb00000001021
Qll01@000000SY?D08jCe02>Tm@0000000<0TigJ00<0000009bXgP2LZ=h00P2LZ=h200000080XK?U
00<000000:Jnj`2V_^/00P2V_^/200000080YL[c100000000`2Ldo/0000000000002000000/0oooo
0`00000B0?ooo`030000003oool0oooo00T0oooo0P0000040?ooo`030000003oool0oooo0080oooo
0`0000030?ooo`00;03oool2000000<0oooo00<000000?ooo`3oool06`3oool<000000@0T35<00<0
000009loC`2O?dl01@2O?dl00`000000ZTQ?0:Y8C`020:Y8C``000000P2Y=2L<000001H0oooo0`00
00080?ooo`80000000H0001S01L<P`0000000000030[VP00000204Q6Z`030000001HFKP0000000<0
JF_200D0000007AibP000000NG_8000000030867c`0500000029T]H0000008jCe00000000P2CWMX2
0000000309VXh0000000W:SN008000000P2Q/nD2000000030:Fnj`000000Y[k[008000000P2Wbo82
00000080X]Kj0`0000000`2=g?l00000000000090?ooo`<000000`3oool00`000000oooo0?ooo`0>
0?ooo`8000002P3oool010000000oooo0?ooo`00000;0?ooo`4000000@3oool10?ooo`003`3oool3
000001L0oooo0`00000P0?ooo`T000000P1i74D010000000T35<090aC02@<D`H000000<0/De>00<0
00000;EAC@0000000`0000000`2Y=2L000000000000=000000d0oooo0`00000:0?ooo`@0000000D0
5`b30000000`:iX0<2^J04A3Z`0200000080F5Vh00@0IFW30000001YJl8000000`1dNLX01@000000
PHO?0867c`21Qll0000000<0RI;F0P0000000`2CWMX0000009VXh00309VXh08000000P2Q/nD01000
0000YKk[0:Fnj`2U_^/3000000040:O;lP00000000000:SHn0<0000000<0VN7m0000000000000`00
00060?ooo`<000001P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`3oool000002`3oool100000040oooo0@3oool00180oooo00<000000?ooo`3oool04@3o
ool300000240oooo1`00000207TLAAT000000`2aFfP010000000]f5W0;MQI`2gHFL700000080]E5=
1@0000000`2/=RH000000000000=000000D0oooo0`00000<0?ooo`030000000000l0000000800000
00H05`b30000000`:iX0000004A3Z`00000205QI^0050000001UJL<0000006U[`P0000000P1dNLX0
1@000000OHKA00000021Qll0000000<0RI;F00@00000092Mg02@WM`00000102IZ>000`000000Wk?V
09nciP03000000030:Fnj`000000000000<0ZL_a100000000`2TiO/0000000000003000000D0oooo
1000000:0?ooo`030000003oool0oooo00d0oooo0P0000040?ooo`@000000P3oool010000000oooo
0?ooo`0000080?ooo`<000000`3oool00180oooo00<000000?ooo`3oool03P3oool300000080oooo
00<000000?ooo`3oool07P3oool20000000303T010000000EP0f00D0000000<0QSIQ000000000000
1@0000040:1HN@030000002/HgX0[6=j00D0[6=j00<000000;AZNP2dJWX00P2dJWX7000000<0]f5W
00@000000;]TIP2kI6H0^fAV7000000;0?ooo`H0000000D0001U0000000G38<00000030[VP020000
000504A3Z`1DF;T0000005QI^00000000P1UJL<01@000000M7W:07AibP1dNLX000000080OHKA0P00
000208VBeP050000002@WM`0T9gL0000002GZ>800P000000102IZ>00000009nciP2O/nH200000080
YKk[0P0000020:W;l@@000000P2^i_T4000000@0oooo0`00000?0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo
00<0oooo00090?ooo`@000000P3oool3000000h0oooo0`00000T0?ooo`L0000000<0JAeH00000000
00000`00000208m9MP030000002PF7T0X5Qi00H0X5Qi00@000000:aSNP2/HgX0[6=j2@0000030;AZ
NP040000002kKgX0^fmj0;]_NPL000000`2kI6H010000000_VIV0;iVIP2nIVHW0000000701`@Q000
00000000030[VP000000A4>[0000000205AH^@080000001UJL<0IFW30000001`N</0000007AibP00
000207f6d@0300000025TMP0QI7H008000000`2@WM`010000000UjSR09NXhP2GZ>820000000309nc
iP000000YKk[0080YKk[00<000000:_;l02[bo001@0000000`2^i_T000000000000300000080oooo
0`00000C0?ooo`030000003oool0oooo00/0oooo0P00000:0?ooo`040000003oool0oooo000000P0
oooo00<000000?ooo`3oool00`3oool000l0oooo00<000000?ooo`3oool02`3oool3000002H0oooo
1@00000206TMF0<00000102?BGH?000000@0[fj800<000000;MeR02gMHP00P2gMHP7000000<0^fmj
00@000000;ibN@2nLWT0_W9i1`0000030;iVIP040000002nIVH0_VIV0;iVIPX000000P2Z=2P00`00
0000YC8Z0:Db:P0A0000000501`@Q0000000<2^J030[VP14@j/00P0000000`1DF;T0000000000002
06EY``040000001`N</0L7S;000000<0OHKA00P0000008FAf025TMP0000008fMg@000000T9gL0000
00<0UjSR00<0000009jci`2N/nL00P0000020:Fnj`070000002[bo00Zl_`0:_;l0000000/=Sd0000
00020;CUm`80000000<0/_[W0000000000000`00000F0?ooo`030000003oool0oooo00`0oooo0P00
000:0?ooo`8000002@3oool400000080oooo000?0?ooo`030000003oool0oooo00P0oooo0`000002
0?ooo`030000003oool0oooo02<0oooo1000000206TMF080000000<0McE`0000002?BGH010000002
09EHQP030000002TIHL0Y6F700H0Y6F700<000000:m^R02_KXP01@2_KXP00`000000]gF80;MeR005
0;MeR0040000002lNHP0_7V80;aiR0L000000`2nLWT010000000`GAi0<5dN@31M7T700000080_VIV
0`0000000`2nIVH000000000000A0000000303T0<P0000000P0d00<000000P0L48@01@000000<2^J
00000014@j/000000080E5Ri00@00000069Y``00000000000P1`N</01@000000NXGB0000001mQ]40
000000<0QI7H00<0000008fMg@2=WMd00P00000209NXhP040000002N/nL0W[?W00000080YKk/0`00
00020:_;l0040000002`f?@000000;CUm`80000000<0]o;d0000000000000P00000J0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool06@3oool000l0oooo100000040?ooo`<00000:@3o
ool3000000030480AP000000JAeH008000000P1g=G03000000H0UER600<000000:AUQ`2TIHL00P2T
IHLH000000<0_7V800@000000<1lR030O8P0`7b81`0000030<5dN@0300000032M7T0`WAi00L00000
0P2nIVH00`000000^fAV0;]TIP05000000080;5>CP000000ZdU@0:]9D0000000XD9A0000002C=e45
0000000500`0J`00000071240000000d;IX00P0000001014@j/0E5Ni000000000002069Y``050000
001`N</0L7S;071hb`0000000P1jQM8200000080QI7H00@0000008fMg@2=WMd000000P2EZ><20000
00<0W[?W00@000000:Fnk02U_^`000000P2/b_0;000001d0oooo00<000000?ooo`3oool02P3oool2
000000D0oooo0P00000D0?ooo`00503oool3000002/0oooo00<0000002@06P0000000P1204H20000
000607LeL0000000000000000020B88000001@2EF8H7000000@0YfnC00<000000;5hU02aN9@01@2a
N9@00`000000^7jD0;QnU0050;QnU0040000002mPY@0_H:D0;f2U0L000000`30O8P010000000`Wj8
0<9nR032OXP700000080`WAi00@000000<5dN@31M7T0`GAi1@0000020;]TIP030000002gHFL0]f5W
00X0000000D08P1L0000000Q1740000002PGQ`020000000603@]VP000000A4>[0000001DEkT00000
0`1RJL<0101^N<`00000071hb`00000307Z5dP80Pi7I0P00000308fMg@080000002EZ><0UJSS0000
002M/nL0000009jci`0000020:Fnk00:0000002/b_00[<[`0:c:l0000000/]Oc0000002ii?@00000
0;kalPD000007P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000004`3oool00180oooo0P0000020?ooo`030000003oool0oooo02L0oooo10000000
0`1204H0000005HII@03000000@0P4R200<0000009EHQP0000000`00000209UTTP030000002WKi<0
YfnC0080YfnC4@0000030;QnU0030000002mPY@0_H:D00@0_H:D00@000000<65U031QI@0`HFD2@00
00000`32OXP000000<=oR0020<=oR0H000000P31M7T00`000000_W9i0;ibN@0A000000070244L@00
0000:1N70000000d;IX0000004M5Z`020000000505AG^@1RJ<<00000069Y``0000000P1^N<`01@00
0000NXGB07Z5dP1jQM8000000080Pi7I00D0000008bMgP000000SIgM0000000309FXh`030000002M
/nL0WK?W00D000000P2/b_000`000000/]Oc000000020;WTm080000000@0a_[X0000000000000000
7`3oool00`000000oooo0?ooo`090?ooo`800000103oool010000000oooo0?ooo`00000C0?ooo`00
3`3oool3000002d0oooo0`0000020480AP040000001F6FD00000000000D0P4R20`00000409UTTPL0
0000102YN9d00`000000/X2M0;:0W@050;:0W@030000002iQId0^HFM0080^HFM1`0000030;f2U003
00000031QI@0`HFD00@0`HFD0`0000000`33Qi@000000000000500000080`gn800@000000<9nR032
OXP0`Wj81@0000020;ibN@050000002kKgX0^fmj0;]_NP0000000P2eJW/010000000[FAk0000002R
Fg/20000000303XFN000000000000080000000/0?C>K000000000000AdF[0000001DEkT00000069X
``000000HVW30000000206ihc00507R5d`000000000007Z5dP0000000P23TMT00`000000S9gN08bM
gP0200000080UJSS00@0000009fci`2M/nL000000P2T_^`00`000000[<[_0:c:k`08000000040<Kj
j0000000000000000240oooo00<000000?ooo`3oool0203oool2000000@0oooo00@000000?ooo`3o
ool000004`3oool000`0oooo0`00000_0?ooo`L0000000<0IC9l00000020B8800P20B88300000003
08MGT@000000VFBB00@000000P2MKid00`000000ZGRM0:UhW@060:UhW@030000002bP9d0/X2M00D0
/X2M00<000000;V5W@2iQId01@2iQId010000000_XVN0;j9WP2nRIh;000000H0`hND00@000000<>7
U033Qi@0`hND1P0000020<9nR00300000030OHP0`7f800P0000000@0]FYk0000002]I7/0[FAk0`00
0000100j5WP0000003PRRP00000203dcV`0400000017AJ/0000005MI^08000000P1RJ<<010000000
KWS<06ihc000000307R5d`80000000<0Pi7I0000002<WMh00P2<WMh00`000000U:SS000000020000
0080WK?W00@000000:Bnk02T_^`000000P2/b^l00`000000]=Kb000000020;_Sl`0400000032l?40
00000<Kjj08000008`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000004`3oool000T0oooo0`0000000`3oool000000?ooo`0_0?ooo`80000000@0
3@0/0000001F6FD000000P1U<W`010000000P4R200000000000308MGT@<000001P2MKid00`000000
ZGRM0:UhW@020:UhWAP000000`2nRIh;000000<0`hND00<000000<>7U033Qi@00`33Qi@010000000
`hND0<>7U033Qi@500000080`7f800H000000;ajR02lNXP0_7Z80000002gMHT;0000000303dcV`00
0000CTV[0080000000T0EeVh0000001RJ<<0HVS30000001^N<`0000006ihc00000000P1hQM<01000
0000PY7I08:Af@00000308bMgP040000002DZ><0U:SS00000080W;?X0`0000001@2T_^`000000:c:
k`2/b^l000000080]=Kb00<000000;_Sl`0000001@00000T0?ooo`030000003oool0oooo00L0oooo
0`0000030?ooo`040000003oool0oooo000001<0oooo00060?ooo`<00000103oool00`000000oooo
0?ooo`0]0?ooo`80000000@03@0/00000000000000000P1U<W`300000080QeNA0`0000000`2=Hid0
000009e_W@0409e_W@L00000102[P:H00`000000/hNV0;>7YP050;>7YP030000002iS:H0^HbV00D0
^HbV00@000000;j@YP2nT:H0_Y2V1`0000030<6<WP0400000033SYh0`hjN0<>>WPL000000P33Qi@0
0`000000`hND0<>7U0030<>7U00300000031QI@0`HFD00D0000000D0_7Z80000002gMHT0]gF90000
00020;1_R@040:IWR@000000000004``SP80000000D0BSZM000000000000CTV[0000000205MI^004
06AY``000000HVS300000080KWS<00D0000007R5d`1hQM<0N8GC0000000208:Af@0508^Mg`000000
000008bMgP0000000P2DZ><010000000W;?X09bcj00000020:Bnk0/0000000@0b_WX0000003;omL0
00009@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo0P00000D0?ooo`00
103oool2000003H0oooo1@00000206DbO080000000<0L4F>00000027Ei400P00000408eSW@030000
002MKid0000000<000000P2ON:H00`000000Zh2V0:^0YP060:^0YP030000002cQjH0/hNV00D0/hNV
00<000000;V<YP2iS:H0102iS:H00`000000_Y2V0;j@YP0300000080_Y2V00@000000<6BYP31TZH0
`I:V1`0000030<>>WP0400000033SYh0`hjN0<>>WPH000000P33Qi@00`000000`HFD0<65U0020<65
U0030000002mPY@0_H:D00T0000000<0HSj@0000000000000P1:>Yd01P000000CTV[000000000000
EeVh00000080I6W300P0000006ihc01^N<`0000007R5d`000000N8GC00000080PY7I00@0000008^M
g`2;WMl0RigO0P0000000`2DZ><0000009bcj00209bcj0040000002T_^`0Y;k/00000080[<[_00D0
00000;CFl@000000_N;b000000020<C_l0040000003:nNP00000000002L0oooo00<000000?ooo`3o
ool01P3oool2000001X0oooo00040?ooo`800000=P3oool20000000302`0E@000000000000800000
0`1`AHh2000000D0SF>M0`00000609mhYP030000002[P:H0Zh2V0080Zh2V600000030;j@YP030000
0031TZH0`I:V00@0`I:V00@000000<:DYP32U:H0`YBV1@0000040<>>WP0400000033SYh0`hjN0<>>
WPD000000P31QI@01@000000_H:D0;f2U02mPY@000000080^7jD00P000000;5iU02aNI@0000007I<
TP1R?Y00000005Y4WP80000000@0FDj[000000000000G5^h0P00000206AY``0406mhb`000000KWS<
00000080N8GC0P00000208:Af@040000002;WMl0RigO00000080TjST0P00000209bcj0040000002T
_^`0Y;k/00000080[<[_00L000000;CFl@2de_4000000;gRlP000000a>o`00D00000:03oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01P0oooo00040?ooo`030000003oool0000003@0
oooo0P000000100/05D0000004<GL`0000030715SP<00000102=Hid200000003095^Y`000000WgRV
00@0WgRV1`0000040:b7[P030000002cSJh0/hf^00D0/hf^00@000000;VB[P2iTZh0^I:^10000004
0;fF[PL000000`31TZH00`000000`YBV0<:DYP040<:DYP0300000033U:H000000080000000<0`hjN
00000033SYh01033SYh00`000000`HbN0<6<WP0B00000080FDj[00@0000005aK^01LFkP000000P1T
JL<010000000KgS;06mhb`00000207R5d`0300000022TMX0PY7J008000000`2;WMl01@000000TjST
09>Xi0000000W;?X00<000000P2T_^`01@000000[<[_0:c:k`000000]=Ka00T00000:@3oool00`00
0000oooo0?ooo`050?ooo`8000006P3oool000@0oooo00@000000?ooo`3oool00000<P3oool40000
000304<GL`00000000000080L4F>00H0000007UEW01iEI`0NEFL0000002=Hid2000000<0TFjW00<0
000009mhYP0000000`0000020:9o[P030000002/Qjh0[8N^00H0[8N^00<000000;>=[P2cSJh01@2c
SJh4000000<0^I:^00<000000;fF[P2mUZh01@2mUZh010000000`9R^0<2H[P30V:h700000080`YBV
00<000000<>DYP33U:H00`33U:H500000080`hjN00<000000<6<WP31S9h00P31S9h01@000000_XVN
0;j9WP2nRIh000000080^HJN00<000000;>0WP2cP9h01000000206IEZ`80000000L0IEng00000000
0000J6_20000001TJL<000000080KgS;00@0NXGC0000001hQM<000000`22TMX0102;WMl0000008^M
g`00000209>Xi0060000002L/nP0W;?X09bcj0000000Y;k/200000001@2mh_4000000<G^k`000000
c?WX00<00000:P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0P000004
0?ooo`030000003oool0oooo0080oooo0`0000070?ooo`00103oool01@000000oooo0?ooo`3oool0
00000340oooo00H000000000?P000000@aMc0000001D<HT3000000<0NEFL0`000004095^Y`<00000
1`2ROjh010000000[8N^0:b7[P2/QjhG000000<0_IJ^00<000000<2H[P30V:h01@30V:h010000000
`YV^0<:I[P32VJh6000000<0`iBV00@000000<:DYP32U:H0`YBV2P0000001@2nRIh000000;V6WP2i
QYh000000080/h2N00@0000008mVWP00000000000P1VEJ/010000000IEng06EO]`00000306Q[`P04
0000001_N</0KgS;00000080NXGC00D0000008:AfP22TMX0PY7J0000000208^Mg`8000000P2CZ>@0
10000000W;?X09bcj00000020:Bnk0040000002]b^l0[L[_00000080]MKa00H000000;gRl@000000
aNk_0000003<nNP3000002`0oooo00<000000?ooo`3oool00`3oool2000000@0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0?ooo`040?ooo`000`3oool00`000000oooo0?ooo`030?oo
o`800000;P3oool00`000000000n0000000200000080E36900@0000007UEW01iEI`0NEFL0P000000
0`20HjL00000095^Y`0400000080UGN_00@000000:9o[P2ROjh0XWn^200000040:f>]@030000002d
TkD0]9>e00<000000P2dTkD00`000000^IRe0;VH]@040;VH]@040000002mVkD0_I^e0;fK]@L00000
0`30V:h00`000000`YV^0<:I[P040<:I[P0400000032VZh0`YZ^0<:J[PH000000`32U:H00`000000
`I:V0<6BYP020<6BYP030000002nT:H0_Y2V00X0000000h0MEjZ000000000000000006EO]`000000
Kfk00000001XJl80000007=ibP000000KgS;00000080NXGC00L0Pi7I000000000000PY7J0000002;
WMl000000080TjST0`00000209bcj0040000002T_^`0Y;k/00000080[L[_00<000000;GFl@000000
0P2mh_400`000000aNk_00000003000002d0oooo00<000000?ooo`3oool00`3oool2000000@0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`040?ooo`000`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo02X0oooo0`0000001P0L06D0000005@aR@1D<HT000000695
VP<000000`20HjL2000000D0UGN_1@0000040:B7]P030000002]S[D0[Hje00D0[Hje0`0000050;BC
]@030000002iV;D0^IRe00@0^IRe00<000000;fK]@2mVkD0102mVkD010000000_iff0;nM]P2oWKH7
000000<0`YV^00<000000<:J[P32VZh01032VZh00`000000`YV^0<:I[P0600000080`I:V00D00000
0;j@YP2nT:H0_Y2V000000020;V<YP030000002cQjH0/hNV0080000000<0Q6JY07ENZP0000000P1`
I;D20000000406m^`0000000J6_200000080LgW:00@0000007Z5d`1jQM<000000`23TMT200000003
08^Mg`000000TjST0080TjST00<0000009bcj00000001@000000102]b^l000000;GFl@2ee_460000
00030<kof0000000000002h0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool01P3oool3000000L0oooo00030?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0:@3oool20000000501`0I@000000000005@aR@0000000P1RAIX0
10000000P6>W081SY`20HjL3000000@0UGN_0P0000000`2HP;L000000:B7]P050:B7]Q`000000`2m
VkD00`000000_iff0;nM]P040;nM]P0400000031W[H0`Ijf0<6N]PL000000P32VZh00`000000`YV^
0<:I[P030<:I[P0400000030V:h0`9R^0<2H[PD0000000D0_Y2V0000002iS:H0^HbV000000020;>7
YP080000002QNJL000000000001lJ[<00000071T]@00000306m^`0080000001cNLX0LgW:0000001l
Q]80000007Z5d`00000208>Af@040000002<WMh0S9gN000000<0TjST00L0000009bcj02L/nP0W;?X
0000002T_^`000000080[L[_1P0000000`35k^l000000<cij00300000300oooo00@000000?ooo`3o
ool0oooo0`0000030?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01`3oool0
00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?ooo`80000000<0701U0000
000f6X800P0000020695VP8000000P20HjL01P000000QVja08I^/@26K[40000009Eg[`800000102H
P;L00`000000Y8Nf00000003000000030:F>_@000000000000800000102]U;`00`000000]9Vl0;BI
_0050;BI_0030000002hWK`0^9fl00@0^9fl00@000000;bP_02lX;`0_:2l1`0000030;nM]P030000
0031W[H0`Ijf00@0`Ijf00@000000<6O]P31WkH0`Inf1P0000020<:I[P0300000030V:h0`9R^00<0
`9R^00<000000;fF[P2mUZh02`00000207aZ/`090000001hLKh0000006m^`0000000N7[90000001c
NLX000000080O8KB00D0000008>Af@23TMT0Pi7I0000000208bMgP<0000000D0TjST0000002L/nP0
W;?X000000020:Bnk0030000002]b^l000000080]MKa00D000000;gRl@2mh_4000000<G^k`040000
0380oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`000`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo02H0oooo0`00000203HJPP050000001RAIX000000000001]EjL00`000003
08I^/@<000001@2HP;L3000000<0YHjm100000060:fD_0040000002dVK`0]9Vl0;BI_0P000000`2h
WK`00`000000_:2l0;bP_0040;bP_0040000002nX[`0_Z:l0;jR_0L000000`31W[H00`000000`Inf
0<6O]P030<6O]P0400000031W[H0`Ijf0<6N]PD000000P30V:h00`000000_IJ^0;fF[P020;fF[P04
0000002iTZh0^I:^00000080]8f^0P0000000`2GNK00RG6b07aZ/`0200000080N76n00D0000007Qj
b@1hN/T0N7[90000000207b6dP0500000025TMP0000008>Af@0000000P2<WMh010000000U:ST09BX
i02DZ>@200000080W;?X00<000000:Bnk00000000P2]b^l01@000000]MKa0;GFl@000000_N;a00@0
000000<0booG000000000000<P3oool010000000oooo0?ooo`3oool2000000@0oooo0P0000090?oo
o`@000001P3oool000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0T0?ooo`<0
00000P0f6X83000000<0KENW00@0000008I^/@26K[40QVja0P0000000`2;NKX0000009R0]`0309R0
]`80000000<0VhRo0000002US[d00`0000020:F>_@`00000102cW/<010000000^:;30;RR``2hX/<7
000000<0_:2l00<000000;jR_02nX[`0102nX[`010000000_j>m0;nS_@2oXkd700000080`Inf00<0
00000<6N]P31W[H00`31W[H00`000000_iff0;nM]P09000000060;VB[P000000]8f^0;B=[P000000
[HN^0`000002089f_00:07Qa_P000000Ogg60000001hN/T000000866d0000000O8KB00000080QI7H
0P00000208bMgP040000002DZ>@0U:ST00000080W;?X3P000000103:nNP0000000000000000d0?oo
o`050000003oool0oooo0?ooo`0000006@3oool000<0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0S0?ooo`070000000005H0000003HJPP000000BCFG0000000206eGY`80000000@0
MVFb0000000000000000102;NKX010000000V82g00000000000209^8_`<0000000<0YHjm00000000
00000P0000000`2VU/@000000:jJ``050:jJ``030000002cW/<0/ik300@0/ik300<000000;RR``2h
X/<01@2hX/<010000000^ZG30;ZU``2jYL<700000080_Z:l00<000000;nS_@2oXkd01@2oXkd01000
0000_j>m0;nS_@2oXkd600000080`Ijf00<000000;nM]P2oWKH00P2oWKH00`000000_I^e0;fK]@02
0;fK]@030000002iV;D0000000L0000000@0SW^j00000000000000000`1oOLH01@000000PHK@0866
d021Q]0000000080QI7H00<0000008fMgP2=WMh00`00000209BXi0040000002L/nP0W;?X00000080
Y;k/00H000000:c:k`2/b^l000000;GFl@0000020;gRlP0300000035knl0000000<00000=P3oool0
10000000oooo00000000000I0?ooo`000`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0240oooo1@0000000`19=IL0000005U;Y`02000000<0MVFb00<0000008]i^P2;NKX0102;NKX2
0000000509^8_`00000000000000002KR;l00`0000050:JFa0040000002^V/<0[Y[30:jJ``h00000
0`2hX/<00`000000^ZG30;ZU``050;ZU``040000002lYl<0_:O30;bW``H000000`2oXkd00`000000
_j>m0;nS_@040;nS_@040000002oXkd0_j>m0;nS_@D000000P2oWKH00`000000_I^e0;fK]@020;fK
]@040000002iV;D0^IRe00000080]9>e00H000000:f>]@2TR;H0VX6g08ik^P00000208R0a00;0000
001oOLH0000008J8cP000000PHK@00000028T]H0000008FAf00000000P2=WMh00`000000UJSS09FX
h`030000000509bcj0000000Y;k/0:Bnk00000000P2/b^l01`000000]MKa0;GFl@000000_N;b0000
0035knl00`0000000`2gm[4000000?ooo`0e0?ooo`040000003oool0oooo000000@0oooo1000000A
0?ooo`000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01l0oooo00D000000000
400000005`Ei0000000204TeU`030000001IBjL0000000<0MVFb00<0000007eb_00000000`2;NKX9
0000000309fAaP000000YYK400@0YYK41@0000030:jQbP030000002cY<X0/jC:00@0/jC:00@00000
0;JWbP2fYlX0]ZO:3P0000030;bW``040000002mZ<@0_JS40;fXa0L000000P2oXkd00`000000_j>m
0;nS_@040;nS_@030000002nX[`0_Z:l00T0000000@0^IRe0000002dTkD0]9>e1@0000001@2BQ<40
000008R0a028P<@0000000<0QXS>00@0000008RBeP28T]H0R9;F0P00000208fMgP040000002EZ><0
UJSS00000080WK?W0P0000020:Bnk0060000002/b^l0[<[_0000002ee_4000000P2mh_8300000003
0<Goe@000000000003P0oooo0`0000060?ooo`030000003oool0oooo0100oooo00020?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool07P3oool400000004034UT`000000000005U;Y`80
00000P1fIK801@000000OG:l07eb_0000000RgVj00@0000000<0T8?10000000000001P2MTLH00`00
0000YYK400000002000000030:NMb`000000[Z7:00H0[Z7:00<000000;>TbP2cY<X00`2cY<X00`00
0000]ZO:0;JWbP040;JWbP030000002iZ/X0^J[:00@0^J[:00@000000;Z[bP2jZlX0^Z_:1@000005
0;fXa0040000002nZ<@0_ZS40;jXa0H000000P2oXkd00`000000_Z:l0;jR_0030;jR_0030000002l
X;`0_:2l0080_:2l00<000000;VM_000000010000000402^U;`000000000002LRKh0TXC100000028
P<@0000008f:b`000000QXS>0000002=T]@0000008RBeP00000208nMg0<0000000D0UJSS0000002M
/nL0WK?W000000020:Bnk0/0000000@0ao[X0000000000000000>P3oool3000000D0oooo00<00000
0?ooo`3oool0403oool00080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?oo
o`80000000D00016000000000000<BFC0000000205U;Y`040000001UGK@00000000000<0OG:l0`00
00020923`@80000000<0U8c90000002MTLH0102MTLH3000000D0Yig;00@000000:jQbP2^XLX0[Z7:
500000030;VZbP030000002jZlX0^Z_:00@0^Z_:00<000000;^/b`0000000P0000000`2mZ<@00000
0;jXa0050;jXa0040000002mZ<@0_JS40;fXa0D000000P2nX[`00`000000_:2l0;bP_0020;bP_005
0000002iWK`0^Ifl0;VM_00000000P2dVK`01@000000[YBl0:jD_02VSkd0W8Vn00<000000`2=R//0
1@000000SI;D08fBe02=T]@0000000<0SigL00<0000009NXhP2GZ>800P00000209fci`040000002T
_^`0Y;k/00000080[<[_00L000000;CFlP2de_8000000;cSl`000000`o3`00@00000>`3oool30000
00D0oooo00<000000?ooo`3oool0403oool00080oooo00<000000?ooo`3oool0403oool2000001`0
oooo100000000`0a9I<0000004HoYP0200000080IEfd00<0000007eb_00000000`0000001024O/@0
000000000000000309B<b@030000002MTLH0WI7600<000000P2PVLd00`000000Yig;0:NMb`070000
00<0[JOA00<000000;6Zd@2aZ]400`2aZ]400`000000]:gA0;B]d@040;B]d@040000002g[m40]joA
0;N_d@L000000P2jZlX00`000000^jc;0;^/b`030;^/b`D000000`2nZ<@00`000000_JS40;fXa003
0;fXa0030000002lYl<0_:O301<0000000h0WY750000002FSLP0000008f:b`000000TYCA0000002=
T]@0000009>MfP000000SigL00000080UjSR00<0000009fci`2M/nL00`0000020:Bnk0090000002/
b^l0[<[_0000002de_8000000;cSl`000000`o3`00@00000?@3oool2000000D0oooo00<000000?oo
o`3oool0403oool00080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0I0?ooo`80
000000H0001`0000000a9I<0000004HoYP00000206EM]0D000000`24O/@00`000000U8c909B<b@04
09B<b@800000102PVLd4000000@0Z:CB00<000000:fWd@2]Ym400`2]Ym400`000000/J[A0;6Zd@07
000000<0]:gA00<000000;N_d@2g[m40102g[m4010000000^;3B0;R`dP2h/=86000000<0^jc;00@0
00000;b]b`2l[L/0_:g;1P0000020;fXa0030000002lYl<0_:O300<0_:O300<000000;ZU``2jYL<0
0P2jYL<01@000000^:;30;RR``2hX/<000000080/ik300P000000:jJ``2^V/<000000:NFa02NTLD0
000009J=b08000000`2BU=4010000000TigJ09>MfP2CWMX200000080UjSR00@0000009fci`2M/nL0
00000P2T_^`3000000040:c:k`000000]=Kb0;CFlPD0000000<0^OcA0000003oool0?03oool30000
00<0oooo0`00000B0?ooo`000P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01L0
oooo00<0[LA80000000000000`0000000`16?jH000000000000300000003071/_P000000Q7k400<0
Q7k400<0000008^9c00000000`2DS<T20000000309RFd0000000X9W=00<000000P2RXM@00`000000
Z:CB0:RTdP0<000000<0/;7I00@000000;:cf@2b/mT0/[?I1`0000020;N_d@030000002h/=80^;3B
00@0^;3B00@000000;VadP2i/M80^K7B1`0000030;b]b`030000002k[</0^jc;00/000000P2jYL<0
1@000000^:;30;RR``2hX/<000000080/ik300<000000:jJ``2^V/<01@00000209VFc`<0000000@0
UikH0000002CWMX000000P2IZ>030000000309fci`000000Y;k/0080Y;k/00<000000:c:l02/b_00
1@0000000`2olO8000000<3kj002000003/0oooo100000070?ooo`030000003oool0oooo0100oooo
00020?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05P3oool00`000000000k0000
00050000000705ME]00000000000071/_P000000NG[70000000208Ana0050000002;RL`0RhW<0000
002DS<T00P00000309RFd0800000102RXM@4000000@0Z:cJ00<000000:b^f@2/[]T00P2/[]T00`00
0000/;7I0;2af@030;2af@030000002b/mT0/[?I00@0/[?I00@000000;>df@2c]=T0/kCI2P000006
0;VadP040000002i/M80^K7B0;VadPH000000P2k[</00`000000^Z_:0;Z[bP030;Z[bP030000002i
Z/X0^J[:00d0000000@0Z9c;0000002QVL`0XIW<0`00000409NNf0050000002IZ>00VJSP09VXh000
00000P2O/nH200000080Y;k/00@000000:c:l02/b_0000000P2ceo<01@000000^NCd000000000000
`?_X00800000>@3oool3000001h0oooo00020?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool05@3oool40000000303HgY000000000000080EeFd00P00000071/_P1`K;h0000007Uja`00
0000Q7k4000000@0RhW<00@0000009RFd02HU]00V9K@0P000000102LWmL000000::Qe02RXM@20000
00030:BZf`000000Z:cJ00@0Z:cJ5P0000030;>df@030000002d]MT0];GI00<0];GI00<000000;Ff
f@0000000`0000000`2i/M8000000;VadP050;VadP040000002i/M80^K7B0;VadPD000000P2jZlX0
0`000000^J[:0;VZbP030;VZbP050000002fYlX0]ZO:0;JWbP0000000P2cY<X01P000000[Z7:0:jQ
bP2^XLX000000:RLb`<000000P2MWmH020000000UikH000000000000W:SN0000002IZ>0000000P2O
/nH00`000000YKk[0:Fnj`03000000060:c:l0000000/mOc0;?Gl`000000^NCd1@00000g0?ooo`<0
00008@3oool00080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`<00000
00D0001Y000000000000=SNT0000000205ME]0040000001TIl000000000000<0NG[700@0000008^9
c02;RL`0RhW<0P000000102@Tm<0000009RFd000000409bOe`800000102TZ]/00`000000Z:cJ0000
0002000000030:RehP000000ZkKQ00@0ZkKQ00<000000:fhh@2]^>400P2]^>400`000000[[WQ0:ji
h@030:jih@040000002_^^40[k[Q0:njh@H000000`2d]MT00`000000]KKI0;Fff@030;Fff@D00000
0P2i/M800`000000^K7B0;VadP040;VadP030000002h/=80^;3B00D000000P2iZ/X00`000000]ZO:
0;JWbP020;JWbP060000002cY<X0/jC:0;>TbP000000[Z7:100000020:>Qd`040000002MWmH00000
000000@0W:SN0P0000000`2O/nH000000:Fnj`020:Fnj`030000002[bo00Zl_`00T00000=@3oool4
000002@0oooo00020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03P3oool30000
00030?ooo`000000000000<0000000L0=SNT0000001GEK@0EeFd0000001TIl00000000<0NG[700D0
000008:6c`000000RhW<00000004092Cd`040000002LWmL0W9oG09bOe`80000000@0WjWM0000002T
Z]/0Y:[K100000020:RehQL000000P2_^^4010000000/;[R0;2jhP2`^^87000000<0]KKI00@00000
0;Fff@2e]]T0]KKI1P0000020;VadP030000002h/=80^;3B00<0^;3B00<000000;N_d@2g[m403@00
00001P2^Ym4000000:RTdP2XY=8000000:>Qd`8000000P2PZ=`010000000W:SN0000000000020:6b
i@8000000P2U_^/01@000000Zl_`0:_;l0000000/=Sd0080000000<0]NKf0000002hl_<00P00000c
0?ooo`<00000:03oool00080oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?oo
o`<000000`3oool50000000303HgY0000000BTne008000000P1TIl00101`MlT0000007Uja`000003
08:6c`040000002@Tm<0T9?C092Cd`80000000@0UYkI0000002LWmL000000`2OZMd3000000<0YKCS
0`0000030:Nnj`030000002W_nX0YkoZ0080YkoZ00<000000:RojP2X_nX00P2X_nX00`000000Z;oZ
0:RojP030:RojP040000002X`>X0Z<3Z0:S0jPH000000`2`^^8010000000/;_R0;2khP2`^n860000
00<0]KKI00@000000;Fff@2e]]T0]KKI2`0000020;N_d@030000002d[M40]:gA0080]:gA00D00000
0;6Zd@2aZ]40/J[A000000020:jWd@030000002XY=800000008000000P2TZ]/00`000000X:SL0000
0002000000030:6bi@00000000000080YKk[0`000000102[bo0000000;3Hm00000020;GVmP040000
002hl_<0000000000340oooo0`00000[0?ooo`0000<0oooo0000003oool06`3oool00`000000oooo
0?ooo`060?ooo`<000001P3oool30000000600h?R`0[<:<000000000001:CkD000000P1TIl001000
0000L7O9071gb@00000308:6c`0500000029T]H00000092Cd`000000102FW]T20000000309nYg@00
000000000080X[?T00@000000:Fdh`00000000000P2V_^/00`000000Ykk[0000000G000000@0Z<3Z
1P0000030;2khP040000002`^n80/;_R0;2khPH000000`2e]]T00`000000];GI0;Bef@030;Bef@03
0000002c]=T0/kCI010000000P2Y[=T00`000000Y:[K00000002000000<0Xk?T0P0000020:Fnj`80
00000P2Ybo49000002h0oooo1000000^0?ooo`0000<0oooo0000003oool0703oool00`000000oooo
0?ooo`020?ooo`<000002@3oool20000000:00L:R0000000:c2S0000001:CkD0000005]S`@000000
I6O000000080L7O900@0NXCA00000022Q/l000000`29T]H010000000UYkI09JNf@2FW]T200000080
VjSO00<000000::ci02R/n@00P2R/n@300000080Y[k[0`0000020:C9la<000000P2NaO@010000000
W/Gd09k5m02NaO@3000000@0Z<3[1P0000030;2khP040000002`^n80/;_R0;2khPH000000P2d]MT0
0`000000/kCI0;>df@030;>df@030000002b/]T0/[;I0080/[;I00D000000;2af@2`/MT0/;7I0000
00030:f^f@030000002Y[=T00000008000000`2V/n8300000080Y[k[0`0000001P2Ybo4000000000
002]f?H000000:oVn@@00000;@3oool300000380oooo00000`3oool000000?ooo`0M0?ooo`@00000
2`3oool01`000000000f000000072XP0000002/`X`12Bk@00P00000205]S`@040000001`MlT0L7O9
00000080NXCA00T0000008VBeP29T]H0RI;F0000002@WM`0000009JNf@0000000`2KZ=l010000000
X;?V0000002R/n@200000080Y[k[0`0000000`2Vb_<00000000000020000000309gDn`0000000000
00d000000`2=b_`600000080W/Gd00@0000009g5m02MaO@0WLGd0`0000040:W0j`H000000`2`^n80
10000000/;[R0;2jhP2`^^8;00000080/[;I00H000000;2af@2`/MT0/;7I0000002][]T400000080
Z;GR00<000000:JchP2V/n800`0000000`2V_^/00000000000020:S;lP<0000000<0[MSf00000000
00001000000Z0?ooo`@00000=@3oool000030?ooo`000000oooo01/0oooo1@0000090?ooo`H00000
00D01`Z80000000[<:<0@T^d0000000205]S`@050000001YM</00000071gb@0000000P1jQ=401024
TMP0000008VBeP000003092Mg08000000P2KZ=l010000000X;?V0:2ciP2P/nH2000000030:Jnj`00
000000000080Z<[b0P0000020:?FnP<0000000<0S]gn0000000000002`00000306o8o`<00000102<
b?`600000080WLGd00@0000009g5l`2MaO<0WLGc100000030:S0j`H000000`2`^^800`000000[k[Q
0:njh@030:njh@030000002^^N40[[WQ00P000000`2[]^400`000000Z;GR0000000300000080Y[k[
0P0000020:S;lP8000000P2Xf?P7000002P0oooo0`00000i0?ooo`0000<0oooo0000003oool0603o
ool3000000D0oooo00<000000?ooo`3oool01P3oool70000000702D]XP000000@T^d05AP`P000000
Ff?10000000206Udb`040000001jQ=40NXCA00000080Q97H00D00000092Mg02@WM`0T9gL00000002
09NXhP<0000000<0X;?V0000000000000P2U_^/200000080Z<[b00<000000:WGm`00000020000006
0?ooo`<000000`3oool00`00QKL0000000000002000000<0K/Ko0`00000408c8o0H000000`2MaO<0
10000000WLGd09g5m02MaO@3000000<0Z<3Z2`0000030:jih@030000002]^>40000000P000000`2W
_^/3000000040:K:l`000000000000000080Z=Sh1`00000W0?ooo`<00000?03oool000030?ooo`00
0000oooo01D0oooo0`0000090?ooo`030000003oool0oooo00@0oooo1@0000001P0006H000000000
000U;J800000049;]080E63200/0000006Udb`1YM</0000007F3d`000000NXCA00000024TMP00000
08fMgP0200000005092Mg0000000UjSR09NXhP0000000P2N/nL200000080YKk[00<000000:[:l@2Z
b_401@0000000`2Xi?/000000:;_m`03000000@0oooo1000000<0?ooo`@000000`0h/^l4000000@0
RlSl1P00000309g5m0040000002NaO@0W/Gd09k5m0H000000P2X`>X00`000000Z;oZ0:RojP050000
0080Z;oZ00<000000:NojP2W_nX00P2W_nX00`000000Ykk[0:Nnj`03000000030:K:l`0000000000
0080X]Oj0`000000102Ui_/0000000000000000V0?ooo`@00000?`3oool000030?ooo`000000oooo
0180oooo0`00000=0?ooo`030000003oool0oooo00<0oooo100000001`0006X000000000000U;J80
000003i8]00000000P1DH<80101TL/`0000006Udb`00000207F3d`80000000<0Q97H0000002=WMh0
0P2=WMh20000000509NXhP000000W[?W09jci`0000000P2U_^`3000000030:[:l@00000000000080
000000<0/^Ch0000000000001@000000103oool0000000000000000F0?ooo`<00000100h/_040000
00@0S<Sl1P00000309k5m0040000002NaO@0W/Gd09k5m1@0000000@0XlWc00000000000000000P2R
eoX7000002D0oooo0`0000130?ooo`0000<0oooo0000003oool03P3oool400000140oooo00<00000
0?ooo`3oool00P3oool4000000030000JP0000009RfR0080000000@0?TRd0000001DH<8000000P1T
L/`010000000MH?C07F3d`000002082@fP050000002=WMh0SIgN08fMgP0000000P2EZ><200000080
W[?W00@000000:Fnk02U_^`000000P2[b_0>000001l0oooo1000000303Rbk`@00000102<b?`<0000
0080WlKd00<000000:37m02Pao@00`2Pao@00`000000XLSd0:78m00?000002<0oooo100000160?oo
o`0000<0oooo0000003oool02`3oool3000001H0oooo00<000000?ooo`3oool01`0000001`0V;J80
000003i8]0000000DEo205AP`P0000000P1TL/`0101aP]@0000007F3d`000002082@fP0408ZMh000
0000SIgN00000080UJSS00<0000009fcj02M/nP00`0000001`2U_^`000000:_:l02[b_0000000;;F
l`0000000P2hhoD01@000000_>oc000000000000bOkN00800000:03oool4000000@0>KC_2P000003
08o<o1L000008`3oool3000004X0oooo00000`000000oooo0?ooo`080?ooo`<000006P3oool00`00
0000oooo000000060000000602H]XP0nBK@000000000001AGl8000000P1TL/`010000000LH;D0762
e0000002082@fP030000002:WN00RYgP008000000P2EZ><010000000WK?X09fcj00000020:Bnk0D0
000000<0/]Kc0000000000000`0000000`37mn/0000000000002000002h0oooo1000000403^fkP<0
0000101bc?lC000002@0oooo0`00001=0?ooo`0000<000000?ooo`3oool01@3oool3000001h0oooo
1P0000001@0A48/0;C6S0000000nBK@000000080DEo20P0000002P1TL/`000000762e01aP]@0OI3K
00000020T=X0000008ZMh000000209>Xi0<0000000D0WK?X0000002T_^`0Y;k/000000020:c:k`03
0000002deO40]=Ga00<0000000<0`^ga00000037mn/01000000l0?ooo`h000009`3oool400000500
oooo00000`000000oooo0?ooo`020?ooo`<000008@3oool500000005024KS`000000;C6S0000000n
BK@00P000000101AGl800000069bc@0000020762e0030000001mT=/0OI3K0080000000D0RYgP0000
002CZ>@0TjST0000000209bcj08000000P2T_^`01P000000[<[_0:c:k`000000]=Ga00000080^n7b
2000001^0?ooo`<00000E03oool000030000003oool0000000800000903oool500000005024KS`00
0000;C6S0000000nBK@00`000002069bc@80000000@0LH;D0000001mT=/000000P28WN4200000080
TjST00D0000009bcj02L/nP000000:Bnk00:000000030<G[k`000000c?GZ00@00000K03oool30000
05L0oooo0002000002L0oooo100000001P0g:I@08A^?03ThY@000000@d^d00000080DUo20`000002
0722e@80000000H0OI3K00000028WN40R9gQ0000002BZ>D30000000509bcj0000000Y;k/0:Bnk000
00000P2]bNl01`000000]MC`0;GDl0000000_Moa00000035jnl00`000000103Eo=l0000000000000
001X0?ooo`@00000FP3oool000030?ooo`000000oooo02H0oooo100000001P0g:I@0000003ThY@00
0000@d^d00000080DUo20P1RL/d01P000000L8;E0722e@000000O93L000000<0R9gQ00D0000009:X
i@2BZ>D0000009^dj@03000000070:Bnk0000000[LW_0:g9k`000000]MC`000000020;gOl@@00000
00<0eOcO0000000000000P00001U0?ooo`<00000GP3oool00080oooo00<000000?ooo`3oool0903o
ool80000000404=;]01FHL80000000000080HW;=00<0L8;E0000000000000P1lT=`400000080TZSU
00H0000009^dj@2K]>T0VkCY0000002T_^`;000000030<ocj@000000000000<00000HP3oool40000
0640oooo00030?ooo`800000903oool40000000504Y2YP000000000004e@]@0000000P1FHL800`00
0000HW;=000000020722e@040000001lT=`0O93L00000080QigQ0P0000001@2BZ>D0000009^dj@2K
]>T000000080Y;k/00H000000:g9kP2]bNh000000;KDl00000020;kOl00300000037jNh0000000H0
0000G`3oool3000006D0oooo00050?ooo`030000003oool0oooo0240oooo100000003@1:@ZH00000
04e@]@1=D;D0000005IQ`P000000IG?<069bc@000000L8;E0000001lT=`00P00000208NMh@030000
002AZ>H0TJSV008000000P2K]>T00`000000Y;k/000000020:g9kP050000002fe?00]]C`0000002n
go000`0000000`3@l^P000000=Kkg`03000005d0oooo0`00001X0?ooo`001P3oool00`000000oooo
0?ooo`0P0?ooo`<0000000T0GTjX0000001JEk@0000004e@]@1MI<40EV720000001ULl`00P000000
101`P]D0000007b@g01lT=`20000000608NMh@000000TJSV096XiP000000VkCY3@0000000`37jNd0
00000=3bj005000005T0oooo1000001[0?ooo`001`3oool00`000000oooo0?ooo`0O0?ooo`800000
00<0LUZX05i>Z00000000P1JEk@00`000000GFC10000000206Ecc0030000001bP]@0000000<0O93L
00H0000008NMh@0000000000096XiP00000309^dj@040000002T_^`0Y;k/00000080[LW^00D00000
0;KDk`000000_mk_000000020<OYk@H00000E`3oool3000006l0oooo00080?ooo`030000003oool0
oooo01h0oooo00T0000008EVZ01bFZP0000006UO]01JEk@0000006MX`01MI<400`00000207:2e0@0
00000P27WN400`000000TJSV000000020000000509^dj@000000Y;k/0:Bnk00000000P2]bNh01`00
0000]]C_0;KDk`000000_mk_00000037jNd01P00001E0?ooo`<00000LP3oool000T0oooo00<00000
0?ooo`3oool07@3oool30000000307YX/P1YGk@000000080IfS000<0000006Yeb`1ZML/00`000003
07j@f`<000000`2AZ>H00`000000VkCY00000002000000060:Bnk0000000[LW^0:g9kP000000]]C_
1`000000103Fnml0000000000000001A0?ooo`@00000M@3oool000X0oooo0P00000M0?ooo`800000
00`0RW6a07YX/P000000Lfjn0000001WJ<00LWO90000001ZML/0000007J3d`00000207j@f`040000
0028WN40R9gQ000000<0TJSV00<0000009^dj@0000000P2T_^`7000000050;oNk`000000anW]0000
003?lnP01000001?0?ooo`<00000N@3oool000`0oooo00<000000?ooo`3oool06`3oool0102VPjl0
000000000000000207=^_P040000001bMlT0LWO900000080MX?C0P000000101nT=/0000008RMh@28
WN4400000080VkCY00@000000:Bnk02T_^`000000P2]bNh00`000000]]C_000000020;oNk`050000
0037jNd000000000003Do=l00`00001;0?ooo`@00000O03oool000d0oooo00<000000?ooo`3oool0
6P3oool20000000808mk^@21M;`0Lfjn0000001lNlL0LWO90000001lQM4200000080PI7J0P000000
0`28WN40000009:Xi@0209:Xi@@0000000D0Y;k/0000002]bNh0[LW^000000020;KDk`030000002o
g^l000000080000000<0c_CY0000000000000P0000190?ooo`<00000P03oool000h0oooo00<00000
0?ooo`3oool06@3oool00`000000W8:g08mk^@0200000080O7_700D0000007b5d@1lQM40O8GA0000
0002086AfP040000002:WMl0000000000080TZSU00D0000009^dj@2K]>T000000:Bnk00:00000003
0<KYkP00000000000080000000<0`?>T0000003oool0A@3oool3000008<0oooo000?0?ooo`030000
003oool0oooo01P0oooo100000002027Ol@0000007aka`24Qlh0000007b5d@000000QI7H0P000002
08ZMg`070000002CZ>@0000009:Xi@000000VkCY000000020:Bnk0040000002]bNh0[LW^00000080
]]C`00@000000;kOl0000000a^W^0`0000000`3?oMl00000000000130?ooo`@00000QP3oool00100
oooo00<000000?ooo`3oool05`3oool20000000309j:_P2CQ<40Qgo4008000000P24Qlh010000000
QI7H08FAf025TMP20000000408ZMg`000000TjST09>Xi0D0000000L0Y;k/0000002]bNh0[LW^0000
002fe?0000000080_]o`0`000000103;m^X000000000000000110?ooo`<00000RP3oool00140oooo
0P00000G0?ooo`030000002XT;`0WXZn008000000P2=R//01P24Qlh0000008^Be@000000QI7H0000
0080SIgN0P00000209>Xi0030000002L/nP000000080Y;k/2P0000001@35jnl000000000003?oMl0
000003h0oooo1000002=0?ooo`004`3oool00`000000oooo0?ooo`0D0?ooo`@0000000@0Uhg80000
002=R//000000`2;T]D010000000SIgN08fMgP00000209FXh`<0000000L0W;?X0000002T_^`0Y;k/
0000002]bNl000000080]MCa00<000000;gPl@0000000P35jnl010000000boKZ00000000000l0?oo
o`<00000T@3oool001@0oooo00<000000?ooo`3oool04`3oool01@000000ZIO30:VG``2PT/D0Uhg8
0080000000P0TYCB0000002;T]D0000009:Mf`000000SIgN00000080UJSS00<0000009fcj02M/nP0
0P0000001@2T_^`000000:g9k`2]bNl000000080]MCa00<000000;gPl@0000000P35jnl4000003T0
oooo0`00002D0?ooo`005@3oool00`000000oooo0?ooo`0C0?ooo`@000000P2JU/l010000000TYCB
00000000000209:Mf`8000000P2EZ><00`000000WK?X000000020:Bnk0l00000=P3oool4000009L0
oooo000F0?ooo`030000003oool0oooo0180oooo00H000000:VMbP000000XY[<0000002JU/l20000
0080UikI0P00000209RXh@<0000000L0WK?X0000002T_^`0Y;k/0000002/b^l000000080/mKb00<0
00000;[Rl`0000000P31kO44000003@0oooo0`00002K0?ooo`005`3oool00`000000oooo0?ooo`0B
0?ooo`030000002YWLX0XY[<008000000P2MWmH01`2GW]T000000000002LZ=l0000009RXh@000000
0P2N/nH200000080Y;k/00<000000:c:k`0000000P2ce_8010000000^^;c00000031kO43000003<0
oooo0`00002N0?ooo`00603oool200000180oooo0`0000020:BRd`<00000102LZ=l20000000409jc
iP000000YKk/0:Fnk0d00000<03oool400000:40oooo000J0?ooo`030000003oool0oooo00l0oooo
00<000000:ZTd@2ZY=400`0000020:2Yg0040000002LZ=l0000000000080XK?U0P0000001@2U_^`0
00000000002[b_0000000080/MOc00@000000;KSmP000000^_3d0`00000^0?ooo`<00000Y@3oool0
01/0oooo00<000000?ooo`3oool03P3oool400000080YJ[J00<000000:2Yg00000000P0000000`2Q
/nD00000000000020:Fnj`8000000P2[b_001P000000/MOc0000002fhoH000000;[`m0<00000:`3o
ool400000:P0oooo000L0?ooo`030000003oool0oooo00h0oooo00D000000:Z/f@2Z[=T000000:FZ
fP03000000040:>ci0000000000000000080YKk[00<000000:W:l@2Yb_402@00000Z0?ooo`<00000
[03oool001d0oooo00<000000?ooo`3oool03@3oool5000000040:JdhP0000000000000000<0Y[k[
0`0000000`2Yb_40000000000007000002P0oooo0`00002_0?ooo`007P3oool00`000000oooo0?oo
o`0=0?ooo`030000002Y]N400000008000000`2V_^/300000080Yl_b2P00000U0?ooo`@00000/P3o
ool001l0oooo00<000000?ooo`3oool0303oool200000080YkkZ00<000000:Jnj`2V_^/00`000000
0`2Wbo80000000000002000000030:CUn`000000000000<00000903oool300000;H0oooo000P0?oo
o`8000003@3oool00`000000YkkZ00000003000000030:G:l`000000000000<0000000<0Y>Gk0000
000000000`00000S0?ooo`<00000^@3oool00280oooo00<000000?ooo`3oool02P3oool200000003
0:?9m000000000000080000000<0XMOk0000000000001@00000R0?ooo`@00000_03oool002<0oooo
00<000000?ooo`3oool02@3oool30000000309WDo0000000000000H000008P3oool300000<00oooo
000T0?ooo`030000003oool0oooo00T0oooo1P00000S0?ooo`@00000``3oool002D0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0P0?ooo`<00000a`3oool002H0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0M0?ooo`<00000bP3oool002L0oooo0P00000:0?ooo`03
0000003oool0oooo01T0oooo1000003=0?ooo`00:@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01L0oooo0`00003A0?ooo`00:P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01<0oooo1000003D0?ooo`00:`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0100oooo0`00003H0?ooo`00;03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00d0oooo0`00003K0?ooo`00;@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0
oooo1000003N0?ooo`00;P3oool200000080oooo00<000000?ooo`3oool01P3oool300000>80oooo
000`0?ooo`030000003oool0000000D0oooo0`00003U0?ooo`00<@3oool2000000030?ooo`000000
000000800000j03oool00380oooo0P00003/0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {168.75, 0}} -> {0.0170535, 0.146226, \
0.00373598, 0.00373598}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampling from bins", "Subsection"],

Cell["\<\
Next I show an example that arose in a practical setting. A \
population ecologist wanting to run some random simulations enquired as to \
how one might remove random elements from a set of bins wherein different \
bins contain different quantities and the choice was to be uniform among the \
total (rather than uniform among the bins). Below is simple code for this \
task.\
\>", "Text"],

Cell[BoxData[
    \(\(removeone = 
        Compile[{{l, _Integer, 1}}, 
          Module[{chosenball, chosenbox}, 
            chosenball = 
              Random[Integer, {1, 
                  Apply[Plus, l]}]; \[IndentingNewLine]chosenbox = \(Position[
                  Map[If[# \[GreaterEqual] chosenball, 1, 0] &, 
                    Drop[FoldList[Plus, 0, l], 1]], 1]\)[\([1, 
                  1]\)]; \[IndentingNewLine]MapAt[# - 1 &, l, 
              chosenbox]]];\)\)], "Input",
  FontSize->10],

Cell[TextData[{
  "While the above is adequate for small experiments it does not do well if \
one has, say, ",
  Cell[BoxData[
      \(10\^5\)]],
  " bins, each contains up to ",
  Cell[BoxData[
      \(1000\)]],
  " elements, and we want to select perhaps several thousand (without \
replacement). Code below is better able to handle this. It utilizes a binary \
tree structure. The real point is not in the details, but rather to show that \
there is always a need for a flexible underlying programming language."
}], "Text"],

Cell[BoxData[{
    \(\(\(toTree[ll_List] /; Length[ll] \[Equal] 1 := {ll[\([1, 2]\)], 
        ll[\([1, 1]\)], {{0, 0, 0, ll[\([1, 2]\)]}}}\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(toTree[ll_List] /; 
        Length[ll] \[Equal] 2 := {ll[\([1, 2]\)] + ll[\([2, 2]\)], 
        ll[\([2, 1]\)], {{0, 0, 0, ll[\([1, 2]\)]}, {ll[\([1, 1]\)], 0, 
            ll[\([1, 2]\)], ll[\([2, 2]\)]}}}\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(toTree[ll_List] := 
      Module[{mid = Ceiling[\((Length[ll] + 1)\)/2], left, right, node}, 
        left = toTree[Take[ll, mid - 1]]; \[IndentingNewLine]right = 
          toTree[Drop[ll, mid]]; \[IndentingNewLine]node = {left[\([2]\)], 
            right[\([2]\)], left[\([1]\)], 
            ll[\([mid, 2]\)]}; \[IndentingNewLine]{left[\([1]\)] + 
            right[\([1]\)] + ll[\([mid, 2]\)], ll[\([mid, 1]\)], 
          Join[left[\([3]\)], {node}, right[\([3]\)]]}]\)}], "Input",
  FontSize->10],

Cell[BoxData[
    \(treetensor[ll_] := 
      With[{tree = toTree[Transpose[{Range[Length[ll]], ll}]]}, 
        Developer`ToPackedArray[
          Join[tree[\([3]\)], {{tree[\([1]\)], tree[\([2]\)], 0, 
                0}}]]]\)], "Input",
  FontSize->10],

Cell[BoxData[{
    \(\(\(SetAttributes[removeonetootree, HoldAll];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(removeonetootree[ll_] := 
      Module[{ball, bin, sum, node, posn, numtoleft, tlen = Length[ll]}, 
        ball = Random[
            Integer, {1, 
              ll[\([tlen, 1]\)]}]; \[IndentingNewLine]\(ll[\([tlen, 
              1]\)]--\); \[IndentingNewLine]ll[\([tlen, 3]\)] = 
          ball; \[IndentingNewLine]posn = 
          ll[\([tlen, 2]\)]; \[IndentingNewLine]node = 
          ll[\([posn]\)]; \[IndentingNewLine]numtoleft = 
          node[\([3]\)]; \[IndentingNewLine]While[\(! \((numtoleft < ball && 
                numtoleft + node[\([4]\)] \[GreaterEqual] ball)\)\), \(If[
              numtoleft \[GreaterEqual] 
                ball,  (*walk\ to\ left*) \[IndentingNewLine]\(ll[\([posn, 
                    3]\)]--\); \[IndentingNewLine]numtoleft -= 
                node[\([3]\)]; \[IndentingNewLine]posn = 
                node[\([1]\)]; \[IndentingNewLine]node = 
                ll[\([posn]\)]; \[IndentingNewLine]numtoleft += 
                node[\([3]\)], \[IndentingNewLine] (*else\ walk\ to\ right\
*) \[IndentingNewLine]numtoleft += node[\([4]\)]; \[IndentingNewLine]posn = 
                node[\([2]\)]; \[IndentingNewLine]node = 
                ll[\([posn]\)]; \[IndentingNewLine]numtoleft += 
                node[\([3]\)];\[IndentingNewLine]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]\(ll[\([posn, 
              4]\)]--\); \[IndentingNewLine]ball\[IndentingNewLine]]\)}], \
"Input",
  FontSize->10],

Cell[BoxData[{
    \(\(mylistverybig = 
        Table[Random[Integer, {1, 1000}], {10^5}];\)\), "\n", 
    \(\(newlistverybig = 
        Prepend[mylistverybig, Apply[Plus, mylistverybig]];\)\), "\n", 
    \(\(amazonrainforest = treetensor[mylistverybig];\)\)}], "Input"],

Cell[TextData[{
  "Now we remove ",
  Cell[BoxData[
      \(10\^4\)]],
  " elements."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(tt = 
          Table[removeonetootree[amazonrainforest], {10000}];\)]\)], "Input"],

Cell[BoxData[
    \({5.409999999999996`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving linear diophantine systems", "Subsection"],

Cell["\<\
Solving diophantine linear systems appears in various fields, e.g. \
balancing chemical equations, discrete optimization, etc. Furthermore one \
often wants a solution with \"small\" components. We show an approach to this \
below. The important thing to realize is that this uses relatively little \
code. This is because the needed functions, that perform Gaussian elimination \
and lattice reduction, are built into the software.\
\>", "Text"],

Cell[BoxData[{
    \(<< LinearAlgebra`MatrixManipulation`\), "\n", 
    \(systemSolve[mat_?MatrixQ, rhs_?VectorQ] /; 
        Length[rhs] \[Equal] Length[mat] := 
      Module[{newmat, modrows, hnf, j = 1, len = Length[mat], zeros, solvec, 
          nullvecs}, 
        newmat = Prepend[Transpose[mat], rhs]; \[IndentingNewLine]newmat = 
          AppendRows[newmat, 
            IdentityMatrix[
              Length[newmat]]]; \[IndentingNewLine]hnf = \
\(Developer`HermiteNormalForm[newmat]\)[\([2]\)]; \[IndentingNewLine]zeros = 
          Table[0, {len}]; \[IndentingNewLine]While[
          j \[LessEqual] Length[hnf] && 
            Take[hnf[\([j]\)], len] =!= 
              zeros, \(j++\)]; \[IndentingNewLine]solvec = 
          Drop[hnf[\([j]\)], 
              len + 1]/\(-hnf[\([j, 
                  len + 1]\)]\); \[IndentingNewLine]nullvecs = 
          Map[Drop[#, len + 1] &, Drop[hnf, j]]; \[IndentingNewLine]{solvec, 
          nullvecs}]\), "\n", 
    \(\)}], "Input",
  FontSize->10],

Cell[BoxData[
    \(\(\(smallSolution[sol_?VectorQ, lat_?MatrixQ] := 
      Module[{max, dim = Length[lat] + 1, weight, aug, newlat, k, soln}, 
        newlat = Prepend[lat, sol]; \[IndentingNewLine]max = 
          Max[Flatten[Abs[newlat]]]; \[IndentingNewLine]weight = 
          dim*max^\((dim + 1)\); \[IndentingNewLine]aug = 
          Transpose[
            Prepend[Transpose[newlat], 
              Table[If[j \[Equal] 1, weight, 0], {j, 
                  dim}]]]; \[IndentingNewLine]newlat = 
          LatticeReduce[aug]; \[IndentingNewLine]For[k = 1, 
          newlat[\([k, 1]\)] \[Equal] 0, \(k++\)]; \[IndentingNewLine]soln = 
          newlat[\([k]\)]; \[IndentingNewLine]Which[
          soln[\([1]\)] \[Equal] weight, Drop[soln, 1], 
          soln[\([1]\)] \[Equal] \(-weight\), \(-Drop[soln, 1]\), True, 
          lat[\([1]\)]]]\)\(\n\)
    \)\)], "Input",
  FontSize->10],

Cell["We will solve a random 12x16 system.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SeedRandom[1111];\)\), "\n", 
    \(\(mat = 
        Table[Random[Integer, {\(-100\), 100}], {10}, {16}];\)\), "\n", 
    \(\(rhs = 
        Table[Random[
            Integer, {\(-100\), 100}], {10}];\)\), "\[IndentingNewLine]", 
    \(Timing[\({soln, nulls} = systemSolve[mat, rhs];\)]\)}], "Input"],

Cell[BoxData[
    \({0.1100000000000034`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(soln\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 
      0, \(-1\), \(-47114560402834721861\), \(-68240898708909051807\), 
      57076359738488624446, 24218058005254943561, 112475176848363927857, 
      53169552397522644231, \(-17973012851772853680\), 1685251508622935868, 
      93145184798782184547, \(-107964932555104197133\), 
      6595938109005638296}\)], "Output"]
}, Open  ]],

Cell["\<\
Notice that solution components tend to be on the large side. We \
can improve on that.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[smallsoln = smallSolution[soln, nulls]]\)], "Input"],

Cell[BoxData[
    \({0.06000000000000398`\ Second, {546, \(-357\), \(-1211\), \(-292\), \
\(-1086\), \(-1314\), \(-50\), \(-1215\), 291, 1371, \(-494\), \(-1162\), 
        458, 406, \(-251\), \(-936\)}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["A rudimentary parser (skip me too)", "Subsection"],

Cell["\<\
In this section we present a not-too-complicated grammar and a \
random sentence generator for that grammar. Then we reverse this process  and \
\"parse\" the sentences according to that grammar.\
\>", "Text"],

Cell["\<\
First we give our grammar. It is quite capable of producing a \
variety of nonsense sentences, as we will soon see. With minor modifications \
one could probably use it to turn out scripts for bad movies.\
\>", "Text"],

Cell[CellGroupData[{

Cell["The Grammar", "Subsubsection"],

Cell[BoxData[{
    \(\(NIL = "\<\>";\)\), "\[IndentingNewLine]", 
    \(sentence := 
      Hold[Or[declarative, interrogative, 
          imperative]]\), "\[IndentingNewLine]", 
    \(declarative := {subject, predicatepast}\), "\[IndentingNewLine]", 
    \(interrogative := {qverb, subject, 
        predicatepresent}\), "\[IndentingNewLine]", 
    \(imperative := {actverb, subject}\), "\[IndentingNewLine]", 
    \(subject := 
      Hold[nounclause || {nounclause, 
            prepositionclause}]\), "\[IndentingNewLine]", 
    \(nounclause := Hold[{adjectiveclause, noun}]\), "\[IndentingNewLine]", 
    \(noun := 
      Or["\<skyscraper\>", "\<ball\>", "\<dog\>", "\<cow\>", "\<shark\>", \
"\<attorney\>", "\<hatter\>", "\<programmer\>", "\<city\>", "\<village\>", \
"\<buffalo\>", "\<moon\>", "\<librarian\>", "\<sheep\>"]\), "\
\[IndentingNewLine]", 
    \(adjectiveclause := {article, adjectivelist}\), "\[IndentingNewLine]", 
    \(adjectivelist := 
      Hold[myOr[ .6, Hold[tmpadjlist = adjective; \ NIL], 
          Hold[With[{tmp = randomPart[tmpadjlist]}, 
              tmpadjlist = 
                Complement[tmpadjlist, 
                  Unevaluated[Or[tmp]]]; \[IndentingNewLine]{tmp, 
                adjectivelist}]]]]\), "\[IndentingNewLine]", 
    \(article := 
      Or["\<a\>", "\<the\>", "\<this\>", "\<that\>"]\), \
"\[IndentingNewLine]", 
    \(adjective := 
      Or["\<big\>", "\<wet\>", "\<mad\>", "\<hideous\>", "\<red\>", \
"\<repugnant\>", "\<slimy\>", "\<delectable\>", "\<mild-mannered\>", \
"\<lazy\>", "\<silly\>", "\<crazy\>", \ "\<ferocious\>", \ "\<cute\>"]\), "\
\[IndentingNewLine]", 
    \(\(tmpadjlist = adjective;\)\), "\[IndentingNewLine]", 
    \(prepositionclause := {preposition, 
        nounclause}\), "\[IndentingNewLine]", 
    \(preposition := 
      Or["\<in\>", "\<above\>", "\<under\>", "\<from\>", "\<near\>", \
"\<at\>", "\<with\>"]\), "\[IndentingNewLine]", 
    \(predicatepresent := {verbpresent, subject}\), "\[IndentingNewLine]", 
    \(predicatepast := {verbclause, subject}\), "\[IndentingNewLine]", 
    \(verbclause := Hold[{adverblist, verbpast}]\), "\[IndentingNewLine]", 
    \(adverblist := 
      Hold[myOr[ .8, Hold[tmpadvlist = adverb; \ NIL], 
          Hold[With[{tmp = randomPart[tmpadvlist]}, 
              tmpadvlist = 
                Complement[tmpadvlist, 
                  Unevaluated[Or[tmp]]]; \[IndentingNewLine]{tmp, 
                adverblist}]]]]\), "\[IndentingNewLine]", 
    \(adverb := 
      Or["\<swiftly\>", "\<unflinchingly\>", "\<smugly\>", "\<selflessly\>", \
"\<oddly\>", "\<mightily\>"]\), "\[IndentingNewLine]", 
    \(\(tmpadvlist = adverb;\)\), "\[IndentingNewLine]", 
    \(verbpast := 
      Or["\<ate\>", "\<threw\>", "\<gnashed\>", "\<boiled\>", "\<grated\>", "\
\<milked\>", "\<spanked\>", "\<jumped\>"]\), "\[IndentingNewLine]", 
    \(verbpresent := 
      Or["\<eat\>", "\<throw\>", "\<gnash\>", "\<boil\>", "\<grate\>", \
"\<milk\>", "\<spank\>", "\<salivate\>", "\<jump\>"]\), \
"\[IndentingNewLine]", 
    \(qverb := 
      Or["\<did\>", "\<will\>", "\<could\>", "\<should\>"]\), "\
\[IndentingNewLine]", 
    \(actverb := 
      Or["\<break\>", "\<fix\>", "\<launch\>", "\<squeeze\>", \
"\<fetch\>"]\)}], "Input",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell["Generating random sentences", "Subsubsection"],

Cell["\<\
Now generate random sentences from that grammar. We also provide a \
means to format the results.\
\>", "Text"],

Cell[BoxData[{
    \(randomPart[type_] := 
      Switch[Head[type], Hold, randomPart[type[\([1]\)]], String, type, List, 
        If[Length[type] \[Equal] 0, "\<\>", Flatten[Map[randomPart, type]]], 
        myOr, With[{rnd = Random[]}, 
          randomPart[If[rnd < type[\([1]\)], type[\([2]\)], type[\([3]\)]]]], 
        Or, randomPart[
          type[\([Random[
                Integer, {1, Length[type]}]]\)]]]\), "\[IndentingNewLine]", 
    \(randomSentence[] := 
      Apply[sentenceType, 
        randomPart[sentence] /. "\<\>" \[Rule] 
            Sequence[]]\), "\[IndentingNewLine]", 
    \(isQ[type_, a_] := MemberQ[type, a]\), "\[IndentingNewLine]", 
    \(Format[sentence_sentenceType] := 
      Module[{word = First[sentence], words, punc}, 
        words = Map[StringJoin[#, "\< \>"] &, 
            sentence]; \[IndentingNewLine]punc = 
          If[isQ[qverb, word], "\<?\>", 
            If[isQ[actverb, 
                word], "\<!\>", "\<.\>"]]; \[IndentingNewLine]words[\([Length[
                words]]\)] = 
          StringReplacePart[Last[words], 
            punc, \(-1\)]; \[IndentingNewLine]words[\([1]\)] = 
          StringReplacePart[First[words], 
            ToUpperCase[StringTake[First[words], 1]], 
            1]; \[IndentingNewLine]Apply[StringJoin, words]]\)}], "Input",
  FontSize->10],

Cell["\<\
Here is a set of random sentences. Note that our random generator \
is rigged to go slightly beyond strict syntax, in that adjectives and adverbs \
are never reused within the same clause.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[randomSentence[], {20}] // TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"Should a cute ferocious buffalo grate this ball in a \
skyscraper?\"\>"},
          {"\<\"Break that city with that silly city!\"\>"},
          {"\<\"Will a red ferocious crazy shark from a mad big wet hatter \
eat the shark from this cow?\"\>"},
          {"\<\"Did the cow jump a buffalo?\"\>"},
          {"\<\"Launch this hatter!\"\>"},
          {"\<\"That buffalo grated the librarian at this shark.\"\>"},
          {"\<\"Could that mad cow near the village gnash that ball above \
this cute buffalo?\"\>"},
          {"\<\"Launch that slimy hatter!\"\>"},
          {"\<\"Should a slimy skyscraper throw a skyscraper?\"\>"},
          {"\<\"Did the village jump a mad ferocious dog?\"\>"},
          {"\<\"This buffalo threw a hideous librarian.\"\>"},
          {"\<\"The wet moon milked this librarian.\"\>"},
          {"\<\"Did a librarian grate this big delectable moon at that big \
hatter?\"\>"},
          {"\<\"This buffalo jumped this village near the programmer.\"\>"},
          {"\<\"The red buffalo from a city boiled this moon in that mad \
slimy hatter.\"\>"},
          {"\<\"Could that librarian under that crazy hatter spank that \
repugnant silly attorney?\"\>"},
          {"\<\"The cow threw that slimy dog.\"\>"},
          {"\<\"Did this skyscraper throw this moon under a sheep?\"\>"},
          {"\<\"Fetch that buffalo under a mad silly lazy wet mild-mannered \
skyscraper!\"\>"},
          {"\<\"Did this dog salivate a cow under the crazy mild-mannered \
village?\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        sentenceType[ 
        "should", "a", "cute", "ferocious", "buffalo", "grate", "this", 
          "ball", "in", "a", "skyscraper"], 
        sentenceType[ 
        "break", "that", "city", "with", "that", "silly", "city"], 
        sentenceType[ 
        "will", "a", "red", "ferocious", "crazy", "shark", "from", "a", "mad",
           "big", "wet", "hatter", "eat", "the", "shark", "from", "this", 
          "cow"], 
        sentenceType[ "did", "the", "cow", "jump", "a", "buffalo"], 
        sentenceType[ "launch", "this", "hatter"], 
        sentenceType[ 
        "that", "buffalo", "grated", "the", "librarian", "at", "this", 
          "shark"], 
        sentenceType[ 
        "could", "that", "mad", "cow", "near", "the", "village", "gnash", 
          "that", "ball", "above", "this", "cute", "buffalo"], 
        sentenceType[ "launch", "that", "slimy", "hatter"], 
        sentenceType[ 
        "should", "a", "slimy", "skyscraper", "throw", "a", "skyscraper"], 
        sentenceType[ 
        "did", "the", "village", "jump", "a", "mad", "ferocious", "dog"], 
        sentenceType[ 
        "this", "buffalo", "threw", "a", "hideous", "librarian"], 
        sentenceType[ "the", "wet", "moon", "milked", "this", "librarian"], 
        sentenceType[ 
        "did", "a", "librarian", "grate", "this", "big", "delectable", "moon",
           "at", "that", "big", "hatter"], 
        sentenceType[ 
        "this", "buffalo", "jumped", "this", "village", "near", "the", 
          "programmer"], 
        sentenceType[ 
        "the", "red", "buffalo", "from", "a", "city", "boiled", "this", 
          "moon", "in", "that", "mad", "slimy", "hatter"], 
        sentenceType[ 
        "could", "that", "librarian", "under", "that", "crazy", "hatter", 
          "spank", "that", "repugnant", "silly", "attorney"], 
        sentenceType[ "the", "cow", "threw", "that", "slimy", "dog"], 
        sentenceType[ 
        "did", "this", "skyscraper", "throw", "this", "moon", "under", "a", 
          "sheep"], 
        sentenceType[ 
        "fetch", "that", "buffalo", "under", "a", "mad", "silly", "lazy", 
          "wet", "mild-mannered", "skyscraper"], 
        sentenceType[ 
        "did", "this", "dog", "salivate", "a", "cow", "under", "the", "crazy",
           "mild-mannered", "village"]}]]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["The parser", "Subsubsection"],

Cell["\<\
Now for the parser. We will break down each sentence part and \
indicate this by encapsulating it in a special head. When we encounter empty \
subexpressions e.g. adjective lists with no adjectives, we do not return \
them; for many purposes this is acceptable and of course one could easily \
modify the parsing code below to indicate where these lists would be. Note \
that this parser assumes the input is valid, and makes no attempt to detect \
errors. \
\>", "Text"],

Cell[BoxData[{
    \(getNextWord[{}] := "\<\>"\), "\[IndentingNewLine]", 
    \(getNextWord[a_] := First[a]\)}], "Input"],

Cell[BoxData[
    \(atomParse[hed_, a_] := {hed[getNextWord[a]], 1}\)], "Input"],

Cell[BoxData[
    \(sentenceParse[a_sentenceType] := 
      With[{b = Apply[List, a]}, 
        If[isQ[qverb, First[b]], interrogativeParse[b], 
          If[isQ[actverb, First[b]], imperativeParse[b], 
            declarativeParse[b]]]]\)], "Input"],

Cell[BoxData[
    \(declarativeParse[a_] := 
      Module[{b = subjectParse[a], c}, 
        c = predicatepastParse[
            Drop[a, b[\([2]\)]]]; \[IndentingNewLine]"\<DECLARATIVE \
SENTENCE\>"[b[\([1]\)], c[\([1]\)]]]\)], "Input"],

Cell[BoxData[
    \(interrogativeParse[a_] := 
      Module[{b = atomParse["\<QUESTION \
VERB\>", a], c, d}, 
        c = subjectParse[Drop[a, b[\([2]\)]]]; \[IndentingNewLine]d = 
          predicatepresentParse[
            Drop[a, b[\([2]\)] + 
                c[\([2]\)]]]; \[IndentingNewLine]"\<INTERROGATIVE SENTENCE\>"[
          b[\([1]\)], c[\([1]\)], d[\([1]\)]]]\)], "Input"],

Cell[BoxData[
    \(imperativeParse[a_] := 
      Module[{b = atomParse["\<ACTION VERB\>", a], c}, 
        c = subjectParse[
            Drop[a, b[\([2]\)]]]; \[IndentingNewLine]"\<IMPERATIVE SENTENCE \
\>"[b[\([1]\)], c[\([1]\)]]]\)], "Input"],

Cell[BoxData[
    \(subjectParse[a_] := 
      Module[{b = nounclauseParse[a], c}, 
        c = Drop[a, 
            b[\([2]\)]]; \[IndentingNewLine]If[\(! isQ[preposition, 
              getNextWord[c]]\), {"\<SUBJECT\>"[b[\([1]\)]], b[\([2]\)]}, 
          c = prepositionclauseParse[c]; \[IndentingNewLine]{"\<SUBJECT\>"[
              b[\([1]\)], c[\([1]\)]], b[\([2]\)] + c[\([2]\)]}]]\)], "Input"],

Cell[BoxData[
    \(predicatepastParse[a_] := 
      Module[{b = verbclauseParse[a], c}, 
        c = subjectParse[
            Drop[a, b[\([2]\)]]]; \[IndentingNewLine]{"\<PREDICATE\>"[
            b[\([1]\)], c[\([1]\)]], b[\([2]\)] + c[\([2]\)]}]\)], "Input"],

Cell[BoxData[
    \(predicatepresentParse[a_] := 
      Module[{b = atomParse["\<VERB (PRESENT TENSE)\>", a], c}, 
        c = subjectParse[
            Drop[a, b[\([2]\)]]]; \[IndentingNewLine]{"\<PREDICATE\>"[
            b[\([1]\)], c[\([1]\)]], b[\([2]\)] + c[\([2]\)]}]\)], "Input"],

Cell[BoxData[
    \(verbclauseParse[a_] := 
      Module[{b = adverblistParse[a], c}, 
        c = atomParse["\<VERB (PAST TENSE)\>", 
            Drop[a, b[\([2]\)]]]; \[IndentingNewLine]If[
          b[\([2]\)] \[Equal] 0, 
          c, {"\<VERB CLAUSE\>"[b[\([1]\)], c[\([1]\)]], 
            b[\([2]\)] + c[\([2]\)]}]]\)], "Input"],

Cell[BoxData[
    \(nounclauseParse[a_] := 
      Module[{b = adjectiveclauseParse[a], c}, 
        c = atomParse["\<NOUN\>", 
            Drop[a, b[\([2]\)]]]; \[IndentingNewLine]{"\<NOUN CLAUSE\>"[
            b[\([1]\)], c[\([1]\)]], b[\([2]\)] + c[\([2]\)]}]\)], "Input"],

Cell[BoxData[
    \(adjectiveclauseParse[a_] := 
      Module[{b = atomParse["\<ARTICLE\>", a], c}, 
        c = adjectivelistParse[Drop[a, b[\([2]\)]]]; \[IndentingNewLine]If[
          c[\([2]\)] \[Equal] 0, 
          b, {"\<ADJECTIVE CLAUSE\>"[b[\([1]\)], c[\([1]\)]], 
            b[\([2]\)] + c[\([2]\)]}]]\)], "Input"],

Cell[BoxData[
    \(adjectivelistParse[a_] := 
      Module[{b = a, c, result, len = 0}, 
        result = "\<ADJECTIVE LIST\>"[]; \[IndentingNewLine]While[
          isQ[adjective, getNextWord[b]], 
          c = atomParse["\<ADJECTIVE\>", b]; \[IndentingNewLine]len += 
            c[\([2]\)]; \[IndentingNewLine]result = "\<ADJECTIVE LIST\>"[
              result, c[\([1]\)]]; \[IndentingNewLine]b = 
            Drop[b, c[\([2]\)]]]; \[IndentingNewLine]{Flatten[result, 
            Infinity, "\<ADJECTIVE LIST\>"], len}]\)], "Input"],

Cell[BoxData[
    \(prepositionclauseParse[a_] := 
      Module[{b = atomParse["\<PREPOSITION\>", a], c}, 
        c = nounclauseParse[
            Drop[a, b[\([2]\)]]]; \[IndentingNewLine]{"\<PREPOSITION \
CLAUSE\>"[b[\([1]\)], c[\([1]\)]], b[\([2]\)] + c[\([2]\)]}]\)], "Input"],

Cell[BoxData[
    \(adverblistParse[a_] := 
      Module[{b = a, c, result, len = 0}, 
        result = "\<ADVERB LIST\>"[]; \[IndentingNewLine]While[
          isQ[adverb, getNextWord[b]], 
          c = atomParse["\<ADVERB\>", b]; \[IndentingNewLine]len += 
            c[\([2]\)]; \[IndentingNewLine]result = "\<ADVERB LIST\>"[result, 
              c[\([1]\)]]; \[IndentingNewLine]b = 
            Drop[b, c[\([2]\)]]]; \[IndentingNewLine]{Flatten[result, 
            Infinity, "\<ADVERB LIST\>"], len}]\)], "Input"],

Cell["We demonstrate by parsing three random sentences.", "SmallText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[sentenceParse[randomSentence[]], \ {j, 3}]\)], "Input"],

Cell[BoxData[
    \({"DECLARATIVE SENTENCE"[
        "SUBJECT"["NOUN CLAUSE"["ARTICLE"["that"], "NOUN"["skyscraper"]], 
          "PREPOSITION CLAUSE"["PREPOSITION"["under"], 
            "NOUN CLAUSE"[
              "ADJECTIVE CLAUSE"["ARTICLE"["this"], 
                "ADJECTIVE LIST"["ADJECTIVE"["red"]]], "NOUN"["hatter"]]]], 
        "PREDICATE"["VERB (PAST TENSE)"["threw"], 
          "SUBJECT"[
            "NOUN CLAUSE"[
              "ADJECTIVE CLAUSE"["ARTICLE"["the"], 
                "ADJECTIVE LIST"["ADJECTIVE"["big"]]], 
              "NOUN"["attorney"]]]]], 
      "DECLARATIVE SENTENCE"[
        "SUBJECT"["NOUN CLAUSE"["ARTICLE"["a"], "NOUN"["skyscraper"]], 
          "PREPOSITION CLAUSE"["PREPOSITION"["in"], 
            "NOUN CLAUSE"[
              "ADJECTIVE CLAUSE"["ARTICLE"["this"], 
                "ADJECTIVE LIST"["ADJECTIVE"["wet"]]], "NOUN"["moon"]]]], 
        "PREDICATE"["VERB (PAST TENSE)"["spanked"], 
          "SUBJECT"["NOUN CLAUSE"["ARTICLE"["that"], "NOUN"["ball"]]]]], 
      "INTERROGATIVE SENTENCE"["QUESTION VERB"["could"], 
        "SUBJECT"["NOUN CLAUSE"["ARTICLE"["this"], "NOUN"["village"]]], 
        "PREDICATE"["VERB (PRESENT TENSE)"["salivate"], 
          "SUBJECT"[
            "NOUN CLAUSE"["ARTICLE"["that"], 
              "NOUN"["buffalo"]]]]]}\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Some way cool pix", "Section"],

Cell["\<\
Visualization plays an increasingly important role in computation. \
I would not dare to go into much depth with such a vast topic. I will mention \
that my colleague Michael Trott is a leading expert in the generation and \
visualization of Riemann surface, which, properly speaking, live in four \
dimensional space. While such examples may seem exotic, they serve to \
indicate how much one can do with a bit of graphics code. They also give \
pretty pictures.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ParametricPlot3D[
      Evaluate[{Re[Sin[wr + \[ImaginaryI]\ wi]], 
          Im[Sin[wr + \[ImaginaryI]\ wi]], wr}], {wr, 0, 
        4  \[Pi]}, {wi, \(-2\), 2}, PlotPoints \[Rule] {80, 31}, 
      BoxRatios \[Rule] {1, 1, 3/2}]; \)], "Input",
  FontSize->12],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.35295 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 6  scalefont  setfont
% Scaling calculations
-0.172715 1.38052 1.58022e-16 1.38052 [
[.52799 1.33592 -3.59291 0 ]
[.52799 1.33592 3.60709 5.4 ]
[.68106 1.29939 -1.74412 0 ]
[.68106 1.29939 1.85588 5.4 ]
[.84023 1.26139 -1.68892 0 ]
[.84023 1.26139 1.91108 5.4 ]
[.1006 1.15578 -3.89297 0 ]
[.1006 1.15578 3.30703 5.4 ]
[.20548 1.23505 -1.90796 0 ]
[.20548 1.23505 1.69204 5.4 ]
[.30256 1.30841 -1.87334 0 ]
[.30256 1.30841 1.72666 5.4 ]
[.06793 .25189 -3.6 -1.62202 ]
[.06793 .25189 0 3.77798 ]
[.03859 .53449 -3.6 -1.72177 ]
[.03859 .53449 0 3.67823 ]
[.00504 .85779 -7.2 -1.83686 ]
[.00504 .85779 0 3.56314 ]
[ 0 0 0 0 ]
[ 1 1.35295 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38475 1.35295 m
1 1.20566 L
s
.52796 1.31866 m
.52794 1.31004 L
s
[(-2)] .52799 1.33592 -0.00197 -1 Mshowa
.68053 1.28214 m
.68026 1.27352 L
s
[(0)] .68106 1.29939 -0.03105 -1 Mshowa
.83917 1.24416 m
.83864 1.23555 L
s
[(2)] .84023 1.26139 -0.06171 -1 Mshowa
.125 Mabswid
.4173 1.34515 m
.4174 1.33998 L
s
.45384 1.33641 m
.4539 1.33123 L
s
.49072 1.32758 m
.49075 1.3224 L
s
.56555 1.30967 m
.5655 1.30449 L
s
.6035 1.30058 m
.60342 1.2954 L
s
.64183 1.2914 m
.64171 1.28623 L
s
.7196 1.27279 m
.7194 1.26761 L
s
.75907 1.26334 m
.75883 1.25817 L
s
.79892 1.2538 m
.79864 1.24863 L
s
.87982 1.23443 m
.87946 1.22927 L
s
.92088 1.2246 m
.92048 1.21944 L
s
.96235 1.21467 m
.96191 1.20952 L
s
.25 Mabswid
0 1.06126 m
.38475 1.35295 L
s
.102 1.13859 m
.10269 1.12999 L
s
[(-2)] .1006 1.15578 .08138 -1 Mshowa
.20652 1.21782 m
.20703 1.20921 L
s
[(0)] .20548 1.23505 .05998 -1 Mshowa
.30327 1.29117 m
.30362 1.28255 L
s
[(2)] .30256 1.30841 .04075 -1 Mshowa
.125 Mabswid
.1289 1.15899 m
.1293 1.15382 L
s
.15528 1.17898 m
.15565 1.17382 L
s
.18115 1.19859 m
.18149 1.19343 L
s
.2314 1.23669 m
.23168 1.23152 L
s
.25581 1.25519 m
.25607 1.25002 L
s
.27976 1.27335 m
.27999 1.26818 L
s
.07454 1.11777 m
.07499 1.11261 L
s
.04652 1.09653 m
.047 1.09138 L
s
.01792 1.07485 m
.01844 1.0697 L
s
.32634 1.30867 m
.32653 1.30349 L
s
.349 1.32584 m
.34916 1.32067 L
s
.37124 1.3427 m
.37138 1.33753 L
s
.25 Mabswid
.08566 .22888 m
0 1.06126 L
s
.08395 .24549 m
.09197 .24229 L
s
[(0)] .06793 .25189 1 -0.39925 Mshowa
.05482 .52862 m
.06293 .52568 L
s
[(5)] .03859 .53449 1 -0.36231 Mshowa
.02148 .85254 m
.0297 .84991 L
s
[(10)] .00504 .85779 1 -0.31968 Mshowa
.125 Mabswid
.07842 .29922 m
.08324 .29733 L
s
.07275 .35435 m
.07758 .35249 L
s
.06693 .41092 m
.07177 .40909 L
s
.06095 .46899 m
.06581 .46719 L
s
.04851 .58987 m
.05339 .58814 L
s
.04203 .65282 m
.04693 .65112 L
s
.03537 .71753 m
.04028 .71587 L
s
.02853 .78407 m
.03344 .78246 L
s
.01423 .92301 m
.01917 .92147 L
s
.00676 .99557 m
.01172 .99407 L
s
.25 Mabswid
.08566 .22888 m
0 1.06126 L
s
0 1.06126 m
.38475 1.35295 L
s
.38475 1.35295 m
.40416 .57527 L
s
.40416 .57527 m
.08566 .22888 L
s
.65586 0 m
.92471 .39838 L
s
.92471 .39838 m
1 1.20566 L
s
1 1.20566 m
.68588 .86098 L
s
.68588 .86098 m
.65586 0 L
s
.08566 .22888 m
0 1.06126 L
s
0 1.06126 m
.68588 .86098 L
s
.68588 .86098 m
.65586 0 L
s
.65586 0 m
.08566 .22888 L
s
.40416 .57527 m
.92471 .39838 L
s
.92471 .39838 m
1 1.20566 L
s
1 1.20566 m
.38475 1.35295 L
s
.38475 1.35295 m
.40416 .57527 L
s
0 0 m
1 0 L
1 1.35295 L
0 1.35295 L
closepath
clip
newpath
.5 Mabswid
.6886 .4908 m .65019 .49802 L .63385 .47763 L p .573 .703 .93 r
F P
0 g
s
.63385 .47763 m .66781 .47211 L .6886 .4908 L p .573 .703 .93 r
F P
0 g
s
.66781 .47211 m .63385 .47763 L .61925 .45942 L p .556 .697 .934 r
F P
0 g
s
.72353 .47984 m .6886 .4908 L .66781 .47211 L p .572 .715 .939 r
F P
0 g
s
.61925 .45942 m .64932 .45541 L .66781 .47211 L p .556 .697 .934 r
F P
0 g
s
.64932 .45541 m .61925 .45942 L .6062 .44315 L p .536 .69 .938 r
F P
0 g
s
.66781 .47211 m .69865 .46332 L .72353 .47984 L p .572 .715 .939 r
F P
0 g
s
.69865 .46332 m .66781 .47211 L .64932 .45541 L p .554 .711 .945 r
F P
0 g
s
.75411 .4655 m .72353 .47984 L .69865 .46332 L p .574 .729 .948 r
F P
0 g
s
.6062 .44315 m .63287 .44049 L .64932 .45541 L p .536 .69 .938 r
F P
0 g
s
.63287 .44049 m .6062 .44315 L .59453 .42859 L p .513 .681 .942 r
F P
0 g
s
.64932 .45541 m .67659 .44856 L .69865 .46332 L p .554 .711 .945 r
F P
0 g
s
.67659 .44856 m .64932 .45541 L .63287 .44049 L p .533 .705 .95 r
F P
0 g
s
.69865 .46332 m .72559 .45159 L .75411 .4655 L p .574 .729 .948 r
F P
0 g
s
.72559 .45159 m .69865 .46332 L .67659 .44856 L p .555 .727 .955 r
F P
0 g
s
.59453 .42859 m .61825 .42713 L .63287 .44049 L p .513 .681 .942 r
F P
0 g
s
.61825 .42713 m .59453 .42859 L .58408 .41555 L p .485 .67 .945 r
F P
0 g
s
.63287 .44049 m .65706 .43536 L .67659 .44856 L p .533 .705 .95 r
F P
0 g
s
.65706 .43536 m .63287 .44049 L .61825 .42713 L p .507 .697 .955 r
F P
0 g
s
.77955 .4482 m .75411 .4655 L .72559 .45159 L p .578 .744 .956 r
F P
0 g
s
.67659 .44856 m .70039 .43916 L .72559 .45159 L p .555 .727 .955 r
F P
0 g
s
.70039 .43916 m .67659 .44856 L .65706 .43536 L p .532 .722 .961 r
F P
0 g
s
.58408 .41555 m .60524 .41515 L .61825 .42713 L p .485 .67 .945 r
F P
0 g
s
.60524 .41515 m .58408 .41555 L .57468 .40384 L p .453 .656 .947 r
F P
0 g
s
.61825 .42713 m .63976 .42353 L .65706 .43536 L p .507 .697 .955 r
F P
0 g
s
.63976 .42353 m .61825 .42713 L .60524 .41515 L p .476 .687 .959 r
F P
0 g
s
.72559 .45159 m .74793 .43731 L .77955 .4482 L p .578 .744 .956 r
F P
0 g
s
.74793 .43731 m .72559 .45159 L .70039 .43916 L p .559 .744 .963 r
F P
0 g
s
.65706 .43536 m .67815 .42803 L .70039 .43916 L p .532 .722 .961 r
F P
0 g
s
.67815 .42803 m .65706 .43536 L .63976 .42353 L p .503 .716 .967 r
F P
0 g
s
.51108 .69322 m .55156 .6828 L .55729 .70447 L p .733 .795 .902 r
F P
0 g
s
.55729 .70447 m .51159 .71492 L .51108 .69322 L p .733 .795 .902 r
F P
0 g
s
.60202 .6898 m .55729 .70447 L .55156 .6828 L p .735 .784 .892 r
F P
0 g
s
.55156 .6828 m .59118 .66864 L .60202 .6898 L p .735 .784 .892 r
F P
0 g
s
.64486 .67096 m .60202 .6898 L .59118 .66864 L p .735 .773 .883 r
F P
0 g
s
.57468 .40384 m .59364 .40436 L .60524 .41515 L p .453 .656 .947 r
F P
0 g
s
.59364 .40436 m .57468 .40384 L .56621 .39327 L p .417 .639 .948 r
F P
0 g
s
.47059 .69989 m .51108 .69322 L .51159 .71492 L p .728 .805 .912 r
F P
0 g
s
.51159 .71492 m .46584 .72115 L .47059 .69989 L p .728 .805 .912 r
F P
0 g
s
.60524 .41515 m .62446 .4129 L .63976 .42353 L p .476 .687 .959 r
F P
0 g
s
.62446 .4129 m .60524 .41515 L .59364 .40436 L p .439 .673 .962 r
F P
0 g
s
.59118 .66864 m .62912 .6508 L .64486 .67096 L p .735 .773 .883 r
F P
0 g
s
.68492 .64811 m .64486 .67096 L .62912 .6508 L p .734 .762 .875 r
F P
0 g
s
.70039 .43916 m .72008 .42758 L .74793 .43731 L p .559 .744 .963 r
F P
0 g
s
.72008 .42758 m .70039 .43916 L .67815 .42803 L p .534 .742 .971 r
F P
0 g
s
.63976 .42353 m .65854 .41805 L .67815 .42803 L p .503 .716 .967 r
F P
0 g
s
.65854 .41805 m .63976 .42353 L .62446 .4129 L p .468 .706 .972 r
F P
0 g
s
.43093 .70287 m .47059 .69989 L .46584 .72115 L p .721 .814 .923 r
F P
0 g
s
.46584 .72115 m .42096 .7232 L .43093 .70287 L p .721 .814 .923 r
F P
0 g
s
.79909 .42846 m .77955 .4482 L .74793 .43731 L p .585 .76 .962 r
F P
0 g
s
.56621 .39327 m .58329 .39459 L .59364 .40436 L p .417 .639 .948 r
F P
0 g
s
.58329 .39459 m .56621 .39327 L .55853 .38369 L p .376 .619 .946 r
F P
0 g
s
.59364 .40436 m .6109 .4033 L .62446 .4129 L p .439 .673 .962 r
F P
0 g
s
.6109 .4033 m .59364 .40436 L .58329 .39459 L p .397 .654 .962 r
F P
0 g
s
.62912 .6508 m .66456 .62942 L .68492 .64811 L p .734 .762 .875 r
F P
0 g
s
.72132 .62145 m .68492 .64811 L .66456 .62942 L p .731 .75 .868 r
F P
0 g
s
.67815 .42803 m .69559 .41885 L .72008 .42758 L p .534 .742 .971 r
F P
0 g
s
.69559 .41885 m .67815 .42803 L .65854 .41805 L p .503 .737 .978 r
F P
0 g
s
.62446 .4129 m .64125 .40905 L .65854 .41805 L p .468 .706 .972 r
F P
0 g
s
.64125 .40905 m .62446 .4129 L .6109 .4033 L p .426 .691 .975 r
F P
0 g
s
.55853 .38369 m .57403 .3857 L .58329 .39459 L p .376 .619 .946 r
F P
0 g
s
.57403 .3857 m .55853 .38369 L .55151 .37494 L p .333 .595 .942 r
F P
0 g
s
.74793 .43731 m .76501 .42096 L .79909 .42846 L p .585 .76 .962 r
F P
0 g
s
.76501 .42096 m .74793 .43731 L .72008 .42758 L p .566 .762 .97 r
F P
0 g
s
.51045 .67385 m .5463 .66344 L .55156 .6828 L p .741 .801 .9 r
F P
0 g
s
.55156 .6828 m .51108 .69322 L .51045 .67385 L p .741 .801 .9 r
F P
0 g
s
.59118 .66864 m .55156 .6828 L .5463 .66344 L p .743 .789 .889 r
F P
0 g
s
.5463 .66344 m .58141 .64972 L .59118 .66864 L p .743 .789 .889 r
F P
0 g
s
.62912 .6508 m .59118 .66864 L .58141 .64972 L p .743 .776 .88 r
F P
0 g
s
.39294 .70227 m .43093 .70287 L .42096 .7232 L p .711 .822 .934 r
F P
0 g
s
.42096 .7232 m .37787 .72122 L .39294 .70227 L p .711 .822 .934 r
F P
0 g
s
.58329 .39459 m .5989 .39458 L .6109 .4033 L p .397 .654 .962 r
F P
0 g
s
.5989 .39458 m .58329 .39459 L .57403 .3857 L p .349 .631 .959 r
F P
0 g
s
.47463 .68094 m .51045 .67385 L .51108 .69322 L p .737 .813 .911 r
F P
0 g
s
.51108 .69322 m .47059 .69989 L .47463 .68094 L p .737 .813 .911 r
F P
0 g
s
.65854 .41805 m .67407 .41099 L .69559 .41885 L p .503 .737 .978 r
F P
0 g
s
.67407 .41099 m .65854 .41805 L .64125 .40905 L p .464 .728 .983 r
F P
0 g
s
.58141 .64972 m .61503 .63277 L .62912 .6508 L p .743 .776 .88 r
F P
0 g
s
.66456 .62942 m .62912 .6508 L .61503 .63277 L p .741 .764 .871 r
F P
0 g
s
.6109 .4033 m .62603 .40089 L .64125 .40905 L p .426 .691 .975 r
F P
0 g
s
.62603 .40089 m .6109 .4033 L .5989 .39458 L p .375 .671 .973 r
F P
0 g
s
.55151 .37494 m .56569 .37754 L .57403 .3857 L p .333 .595 .942 r
F P
0 g
s
.56569 .37754 m .55151 .37494 L .54505 .36688 L p .29 .57 .935 r
F P
0 g
s
.66456 .62942 m .69672 .6047 L .72132 .62145 L p .731 .75 .868 r
F P
0 g
s
.75322 .59127 m .72132 .62145 L .69672 .6047 L p .727 .74 .862 r
F P
0 g
s
.72008 .42758 m .7351 .41424 L .76501 .42096 L p .566 .762 .97 r
F P
0 g
s
.7351 .41424 m .72008 .42758 L .69559 .41885 L p .541 .762 .979 r
F P
0 g
s
.57403 .3857 m .58825 .38661 L .5989 .39458 L p .349 .631 .959 r
F P
0 g
s
.58825 .38661 m .57403 .3857 L .56569 .37754 L p .299 .604 .951 r
F P
0 g
s
.4396 .68476 m .47463 .68094 L .47059 .69989 L p .729 .824 .924 r
F P
0 g
s
.47059 .69989 m .43093 .70287 L .4396 .68476 L p .729 .824 .924 r
F P
0 g
s
.61503 .63277 m .64643 .61272 L .66456 .62942 L p .741 .764 .871 r
F P
0 g
s
.69672 .6047 m .66456 .62942 L .64643 .61272 L p .738 .751 .863 r
F P
0 g
s
.64125 .40905 m .65518 .40387 L .67407 .41099 L p .464 .728 .983 r
F P
0 g
s
.65518 .40387 m .64125 .40905 L .62603 .40089 L p .414 .713 .985 r
F P
0 g
s
.5989 .39458 m .61263 .39345 L .62603 .40089 L p .375 .671 .973 r
F P
0 g
s
.61263 .39345 m .5989 .39458 L .58825 .38661 L p .316 .643 .967 r
F P
0 g
s
.54505 .36688 m .55817 .36998 L .56569 .37754 L p .29 .57 .935 r
F P
0 g
s
.55817 .36998 m .54505 .36688 L .53904 .35939 L p .251 .545 .926 r
F P
0 g
s
.69559 .41885 m .70888 .40819 L .7351 .41424 L p .541 .762 .979 r
F P
0 g
s
.70888 .40819 m .69559 .41885 L .67407 .41099 L p .509 .76 .987 r
F P
0 g
s
.56569 .37754 m .57879 .37925 L .58825 .38661 L p .299 .604 .951 r
F P
0 g
s
.57879 .37925 m .56569 .37754 L .55817 .36998 L p .248 .573 .941 r
F P
0 g
s
.35745 .69827 m .39294 .70227 L .37787 .72122 L p .698 .828 .945 r
F P
0 g
s
.37787 .72122 m .3375 .71538 L .35745 .69827 L p .698 .828 .945 r
F P
0 g
s
.54146 .64615 m .57259 .63283 L .58141 .64972 L p .753 .794 .886 r
F P
0 g
s
.58141 .64972 m .5463 .66344 L .54146 .64615 L p .753 .794 .886 r
F P
0 g
s
.61503 .63277 m .58141 .64972 L .57259 .63283 L p .752 .78 .875 r
F P
0 g
s
.50969 .65656 m .54146 .64615 L .5463 .66344 L p .751 .808 .897 r
F P
0 g
s
.5463 .66344 m .51045 .67385 L .50969 .65656 L p .751 .808 .897 r
F P
0 g
s
.62603 .40089 m .63863 .39738 L .65518 .40387 L p .414 .713 .985 r
F P
0 g
s
.63863 .39738 m .62603 .40089 L .61263 .39345 L p .352 .69 .981 r
F P
0 g
s
.81206 .40687 m .79909 .42846 L .76501 .42096 L p .596 .776 .966 r
F P
0 g
s
.53904 .35939 m .55131 .36289 L .55817 .36998 L p .251 .545 .926 r
F P
0 g
s
.55131 .36289 m .53904 .35939 L .53338 .35233 L p .218 .522 .917 r
F P
0 g
s
.58825 .38661 m .60084 .3866 L .61263 .39345 L p .316 .643 .967 r
F P
0 g
s
.60084 .3866 m .58825 .38661 L .57879 .37925 L p .253 .609 .955 r
F P
0 g
s
.40612 .68543 m .4396 .68476 L .43093 .70287 L p .718 .833 .936 r
F P
0 g
s
.43093 .70287 m .39294 .70227 L .40612 .68543 L p .718 .833 .936 r
F P
0 g
s
.57259 .63283 m .60242 .61666 L .61503 .63277 L p .752 .78 .875 r
F P
0 g
s
.64643 .61272 m .61503 .63277 L .60242 .61666 L p .75 .766 .866 r
F P
0 g
s
.69672 .6047 m .72483 .57693 L .75322 .59127 L p .727 .74 .862 r
F P
0 g
s
.77981 .55794 m .75322 .59127 L .72483 .57693 L p .722 .729 .856 r
F P
0 g
s
.47799 .66405 m .50969 .65656 L .51045 .67385 L p .747 .822 .91 r
F P
0 g
s
.51045 .67385 m .47463 .68094 L .47799 .66405 L p .747 .822 .91 r
F P
0 g
s
.64643 .61272 m .67488 .58974 L .69672 .6047 L p .738 .751 .863 r
F P
0 g
s
.72483 .57693 m .69672 .6047 L .67488 .58974 L p .733 .739 .856 r
F P
0 g
s
.55817 .36998 m .57036 .37237 L .57879 .37925 L p .248 .573 .941 r
F P
0 g
s
.57036 .37237 m .55817 .36998 L .55131 .36289 L p .204 .542 .928 r
F P
0 g
s
.67407 .41099 m .68593 .40269 L .70888 .40819 L p .509 .76 .987 r
F P
0 g
s
.68593 .40269 m .67407 .41099 L .65518 .40387 L p .465 .753 .992 r
F P
0 g
s
.53338 .35233 m .54503 .35616 L .55131 .36289 L p .218 .522 .917 r
F P
0 g
s
.54503 .35616 m .53338 .35233 L .52797 .34558 L p .195 .503 .908 r
F P
0 g
s
.61263 .39345 m .62414 .39141 L .63863 .39738 L p .352 .69 .981 r
F P
0 g
s
.62414 .39141 m .61263 .39345 L .60084 .3866 L p .277 .656 .969 r
F P
0 g
s
.76501 .42096 m .77626 .40309 L .81206 .40687 L p .596 .776 .966 r
F P
0 g
s
.77626 .40309 m .76501 .42096 L .7351 .41424 L p .578 .78 .975 r
F P
0 g
s
.57879 .37925 m .59047 .38022 L .60084 .3866 L p .253 .609 .955 r
F P
0 g
s
.59047 .38022 m .57879 .37925 L .57036 .37237 L p .189 .569 .937 r
F P
0 g
s
.60242 .61666 m .63028 .59778 L .64643 .61272 L p .75 .766 .866 r
F P
0 g
s
.67488 .58974 m .64643 .61272 L .63028 .59778 L p .746 .752 .858 r
F P
0 g
s
.55131 .36289 m .56283 .36587 L .57036 .37237 L p .204 .542 .928 r
F P
0 g
s
.56283 .36587 m .55131 .36289 L .54503 .35616 L p .169 .514 .915 r
F P
0 g
s
.44705 .66866 m .47799 .66405 L .47463 .68094 L p .739 .835 .924 r
F P
0 g
s
.47463 .68094 m .4396 .68476 L .44705 .66866 L p .739 .835 .924 r
F P
0 g
s
.65518 .40387 m .66586 .39767 L .68593 .40269 L p .465 .753 .992 r
F P
0 g
s
.66586 .39767 m .65518 .40387 L .63863 .39738 L p .407 .739 .992 r
F P
0 g
s
.52797 .34558 m .5392 .34967 L .54503 .35616 L p .195 .503 .908 r
F P
0 g
s
.5392 .34967 m .52797 .34558 L .52272 .33903 L p .185 .492 .903 r
F P
0 g
s
.60084 .3866 m .61147 .38586 L .62414 .39141 L p .277 .656 .969 r
F P
0 g
s
.61147 .38586 m .60084 .3866 L .59047 .38022 L p .193 .609 .946 r
F P
0 g
s
.7351 .41424 m .74495 .39965 L .77626 .40309 L p .578 .78 .975 r
F P
0 g
s
.74495 .39965 m .7351 .41424 L .70888 .40819 L p .554 .784 .984 r
F P
0 g
s
.57036 .37237 m .58134 .37421 L .59047 .38022 L p .189 .569 .937 r
F P
0 g
s
.58134 .37421 m .57036 .37237 L .56283 .36587 L p .133 .527 .917 r
F P
0 g
s
.54503 .35616 m .55607 .35964 L .56283 .36587 L p .169 .514 .915 r
F P
0 g
s
.55607 .35964 m .54503 .35616 L .5392 .34967 L p .15 .492 .904 r
F P
0 g
s
.63863 .39738 m .64834 .39304 L .66586 .39767 L p .407 .739 .992 r
F P
0 g
s
.64834 .39304 m .63863 .39738 L .62414 .39141 L p .331 .712 .983 r
F P
0 g
s
.37494 .6831 m .40612 .68543 L .39294 .70227 L p .703 .84 .948 r
F P
0 g
s
.39294 .70227 m .35745 .69827 L .37494 .6831 L p .703 .84 .948 r
F P
0 g
s
.53696 .63071 m .56461 .61772 L .57259 .63283 L p .763 .799 .882 r
F P
0 g
s
.57259 .63283 m .54146 .64615 L .53696 .63071 L p .763 .799 .882 r
F P
0 g
s
.60242 .61666 m .57259 .63283 L .56461 .61772 L p .762 .783 .871 r
F P
0 g
s
.67488 .58974 m .69972 .56412 L .72483 .57693 L p .733 .739 .856 r
F P
0 g
s
.7482 .54644 m .72483 .57693 L .69972 .56412 L p .728 .728 .85 r
F P
0 g
s
.72483 .57693 m .7482 .54644 L .77981 .55794 L p .722 .729 .856 r
F P
0 g
s
.50879 .64115 m .53696 .63071 L .54146 .64615 L p .762 .815 .894 r
F P
0 g
s
.54146 .64615 m .50969 .65656 L .50879 .64115 L p .762 .815 .894 r
F P
0 g
s
.32528 .69112 m .35745 .69827 L .3375 .71538 L p .681 .83 .955 r
F P
0 g
s
.3375 .71538 m .30076 .70597 L .32528 .69112 L p .681 .83 .955 r
F P
0 g
s
.63028 .59778 m .65551 .57636 L .67488 .58974 L p .746 .752 .858 r
F P
0 g
s
.69972 .56412 m .67488 .58974 L .65551 .57636 L p .74 .739 .85 r
F P
0 g
s
.52272 .33903 m .53373 .3433 L .5392 .34967 L p .185 .492 .903 r
F P
0 g
s
.53373 .3433 m .52272 .33903 L .51754 .33257 L p .189 .488 .9 r
F P
0 g
s
.56461 .61772 m .59112 .60225 L .60242 .61666 L p .762 .783 .871 r
F P
0 g
s
.63028 .59778 m .60242 .61666 L .59112 .60225 L p .758 .768 .861 r
F P
0 g
s
.70888 .40819 m .7176 .39649 L .74495 .39965 L p .554 .784 .984 r
F P
0 g
s
.7176 .39649 m .70888 .40819 L .68593 .40269 L p .521 .785 .993 r
F P
0 g
s
.59047 .38022 m .60042 .38063 L .61147 .38586 L p .193 .609 .946 r
F P
0 g
s
.60042 .38063 m .59047 .38022 L .58134 .37421 L p .106 .553 .914 r
F P
0 g
s
.56283 .36587 m .5733 .36846 L .58134 .37421 L p .133 .527 .917 r
F P
0 g
s
.5733 .36846 m .56283 .36587 L .55607 .35964 L p .093 .49 .899 r
F P
0 g
s
.41756 .67049 m .44705 .66866 L .4396 .68476 L p .727 .846 .938 r
F P
0 g
s
.4396 .68476 m .40612 .68543 L .41756 .67049 L p .727 .846 .938 r
F P
0 g
s
.48073 .64902 m .50879 .64115 L .50969 .65656 L p .758 .831 .908 r
F P
0 g
s
.50969 .65656 m .47799 .66405 L .48073 .64902 L p .758 .831 .908 r
F P
0 g
s
.62414 .39141 m .63309 .38871 L .64834 .39304 L p .331 .712 .983 r
F P
0 g
s
.63309 .38871 m .62414 .39141 L .61147 .38586 L p .235 .667 .958 r
F P
0 g
s
.5392 .34967 m .54996 .35356 L .55607 .35964 L p .15 .492 .904 r
F P
0 g
s
.54996 .35356 m .5392 .34967 L .53373 .3433 L p .149 .479 .898 r
F P
0 g
s
.80036 .52193 m .77981 .55794 L .7482 .54644 L p .716 .719 .852 r
F P
0 g
s
.59112 .60225 m .61589 .58441 L .63028 .59778 L p .758 .768 .861 r
F P
0 g
s
.65551 .57636 m .63028 .59778 L .61589 .58441 L p .754 .753 .852 r
F P
0 g
s
.68593 .40269 m .69373 .39356 L .7176 .39649 L p .521 .785 .993 r
F P
0 g
s
.69373 .39356 m .68593 .40269 L .66586 .39767 L p .475 .781 .998 r
F P
0 g
s
.49969 .83302 m .45318 .82004 L .45937 .79938 L p .567 .671 .909 r
F P
0 g
s
.45318 .82004 m .40815 .80296 L .41959 .78325 L p .58 .666 .897 r
F P
0 g
s
.41959 .78325 m .45937 .79938 L .45318 .82004 L p .58 .666 .897 r
F P
0 g
s
.51754 .33257 m .52853 .33694 L .53373 .3433 L p .189 .488 .9 r
F P
0 g
s
.52853 .33694 m .51754 .33257 L .51234 .32608 L p .206 .492 .901 r
F P
0 g
s
.58134 .37421 m .59079 .37564 L .60042 .38063 L p .106 .553 .914 r
F P
0 g
s
.59079 .37564 m .58134 .37421 L .5733 .36846 L p .028 .493 .88 r
F P
0 g
s
.54674 .84187 m .49969 .83302 L .50051 .81188 L p .554 .678 .921 r
F P
0 g
s
.45937 .79938 m .50051 .81188 L .49969 .83302 L p .567 .671 .909 r
F P
0 g
s
.55607 .35964 m .56622 .36289 L .5733 .36846 L p .093 .49 .899 r
F P
0 g
s
.56622 .36289 m .55607 .35964 L .54996 .35356 L p .075 .463 .887 r
F P
0 g
s
.61147 .38586 m .61984 .38462 L .63309 .38871 L p .235 .667 .958 r
F P
0 g
s
.61984 .38462 m .61147 .38586 L .60042 .38063 L p .119 .601 .913 r
F P
0 g
s
.45339 .65436 m .48073 .64902 L .47799 .66405 L p .75 .846 .923 r
F P
0 g
s
.47799 .66405 m .44705 .66866 L .45339 .65436 L p .75 .846 .923 r
F P
0 g
s
.53373 .3433 m .5444 .34753 L .54996 .35356 L p .149 .479 .898 r
F P
0 g
s
.5444 .34753 m .53373 .3433 L .52853 .33694 L p .164 .476 .895 r
F P
0 g
s
.40815 .80296 m .36551 .78188 L .38203 .76357 L p .594 .662 .886 r
F P
0 g
s
.38203 .76357 m .41959 .78325 L .40815 .80296 L p .594 .662 .886 r
F P
0 g
s
.66586 .39767 m .67295 .3908 L .69373 .39356 L p .475 .781 .998 r
F P
0 g
s
.67295 .3908 m .66586 .39767 L .64834 .39304 L p .41 .768 .995 r
F P
0 g
s
.65551 .57636 m .67754 .55265 L .69972 .56412 L p .74 .739 .85 r
F P
0 g
s
.72033 .53616 m .69972 .56412 L .67754 .55265 L p .734 .726 .844 r
F P
0 g
s
.69972 .56412 m .72033 .53616 L .7482 .54644 L p .728 .728 .85 r
F P
0 g
s
.5733 .36846 m .58244 .3708 L .59079 .37564 L p .028 .493 .88 r
F P
0 g
s
.58244 .3708 m .5733 .36846 L .56622 .36289 L p 0 .441 .852 r
F P
0 g
s
.51234 .32608 m .52349 .33049 L .52853 .33694 L p .206 .492 .901 r
F P
0 g
s
.52349 .33049 m .51234 .32608 L .50702 .31945 L p .233 .503 .903 r
F P
0 g
s
.59339 .84662 m .54674 .84187 L .54218 .82072 L p .543 .686 .932 r
F P
0 g
s
.50051 .81188 m .54218 .82072 L .54674 .84187 L p .554 .678 .921 r
F P
0 g
s
.54996 .35356 m .55998 .35738 L .56622 .36289 L p .075 .463 .887 r
F P
0 g
s
.55998 .35738 m .54996 .35356 L .5444 .34753 L p .083 .449 .882 r
F P
0 g
s
.61589 .58441 m .63835 .56437 L .65551 .57636 L p .754 .753 .852 r
F P
0 g
s
.67754 .55265 m .65551 .57636 L .63835 .56437 L p .748 .739 .844 r
F P
0 g
s
.60042 .38063 m .60837 .38069 L .61984 .38462 L p .119 .601 .913 r
F P
0 g
s
.60837 .38069 m .60042 .38063 L .59079 .37564 L p 0 .516 .852 r
F P
0 g
s
.53274 .61692 m .55734 .60421 L .56461 .61772 L p .774 .804 .877 r
F P
0 g
s
.56461 .61772 m .53696 .63071 L .53274 .61692 L p .774 .804 .877 r
F P
0 g
s
.59112 .60225 m .56461 .61772 L .55734 .60421 L p .772 .786 .865 r
F P
0 g
s
.50773 .62741 m .53274 .61692 L .53696 .63071 L p .774 .822 .89 r
F P
0 g
s
.53696 .63071 m .50879 .64115 L .50773 .62741 L p .774 .822 .89 r
F P
0 g
s
.64834 .39304 m .65489 .38818 L .67295 .3908 L p .41 .768 .995 r
F P
0 g
s
.65489 .38818 m .64834 .39304 L .63309 .38871 L p .319 .737 .976 r
F P
0 g
s
.81789 .38411 m .81206 .40687 L .77626 .40309 L p .61 .791 .968 r
F P
0 g
s
.76617 .51366 m .7482 .54644 L .72033 .53616 L p .721 .716 .845 r
F P
0 g
s
.7482 .54644 m .76617 .51366 L .80036 .52193 L p .716 .719 .852 r
F P
0 g
s
.52853 .33694 m .5393 .34144 L .5444 .34753 L p .164 .476 .895 r
F P
0 g
s
.5393 .34144 m .52853 .33694 L .52349 .33049 L p .194 .481 .896 r
F P
0 g
s
.55734 .60421 m .58096 .58934 L .59112 .60225 L p .772 .786 .865 r
F P
0 g
s
.61589 .58441 m .59112 .60225 L .58096 .58934 L p .768 .77 .855 r
F P
0 g
s
.39018 .66969 m .41756 .67049 L .40612 .68543 L p .709 .855 .952 r
F P
0 g
s
.40612 .68543 m .37494 .6831 L .39018 .66969 L p .709 .855 .952 r
F P
0 g
s
.34679 .67801 m .37494 .6831 L .35745 .69827 L p .683 .844 .96 r
F P
0 g
s
.35745 .69827 m .32528 .69112 L .34679 .67801 L p .683 .844 .96 r
F P
0 g
s
.56622 .36289 m .57521 .36603 L .58244 .3708 L p 0 .441 .852 r
F P
0 g
s
.57521 .36603 m .56622 .36289 L .55998 .35738 L p 0 .405 .839 r
F P
0 g
s
.36551 .78188 m .32618 .75696 L .34749 .74051 L p .608 .661 .876 r
F P
0 g
s
.34749 .74051 m .38203 .76357 L .36551 .78188 L p .608 .661 .876 r
F P
0 g
s
.59079 .37564 m .59849 .37686 L .60837 .38069 L p 0 .516 .852 r
F P
0 g
s
.59849 .37686 m .59079 .37564 L .58244 .3708 L p 0 .425 .785 r
F P
0 g
s
.48286 .63565 m .50773 .62741 L .50879 .64115 L p .771 .84 .905 r
F P
0 g
s
.50879 .64115 m .48073 .64902 L .48286 .63565 L p .771 .84 .905 r
F P
0 g
s
.5444 .34753 m .55447 .35184 L .55998 .35738 L p .083 .449 .882 r
F P
0 g
s
.55447 .35184 m .5444 .34753 L .5393 .34144 L p .115 .448 .882 r
F P
0 g
s
.50702 .31945 m .51855 .32382 L .52349 .33049 L p .233 .503 .903 r
F P
0 g
s
.51855 .32382 m .50702 .31945 L .50149 .31255 L p .267 .519 .907 r
F P
0 g
s
.77626 .40309 m .78121 .38429 L .81789 .38411 L p .61 .791 .968 r
F P
0 g
s
.78121 .38429 m .77626 .40309 L .74495 .39965 L p .594 .798 .978 r
F P
0 g
s
.42741 .65726 m .45339 .65436 L .44705 .66866 L p .736 .86 .939 r
F P
0 g
s
.44705 .66866 m .41756 .67049 L .42741 .65726 L p .736 .86 .939 r
F P
0 g
s
.63309 .38871 m .63923 .38563 L .65489 .38818 L p .319 .737 .976 r
F P
0 g
s
.63923 .38563 m .63309 .38871 L .61984 .38462 L p .196 .678 .93 r
F P
0 g
s
.58096 .58934 m .60307 .57241 L .61589 .58441 L p .768 .77 .855 r
F P
0 g
s
.63835 .56437 m .61589 .58441 L .60307 .57241 L p .762 .754 .846 r
F P
0 g
s
.52349 .33049 m .53457 .33519 L .5393 .34144 L p .194 .481 .896 r
F P
0 g
s
.53457 .33519 m .52349 .33049 L .51855 .32382 L p .233 .494 .897 r
F P
0 g
s
.74495 .39965 m .74924 .38433 L .78121 .38429 L p .594 .798 .978 r
F P
0 g
s
.74924 .38433 m .74495 .39965 L .7176 .39649 L p .572 .806 .987 r
F P
0 g
s
.55998 .35738 m .56899 .36123 L .57521 .36603 L p 0 .405 .839 r
F P
0 g
s
.56899 .36123 m .55998 .35738 L .55447 .35184 L p 0 .391 .842 r
F P
0 g
s
.58244 .3708 m .59002 .37305 L .59849 .37686 L p 0 .425 .785 r
F P
0 g
s
.59002 .37305 m .58244 .3708 L .57521 .36603 L p 0 .345 .736 r
F P
0 g
s
.61984 .38462 m .62572 .38312 L .63923 .38563 L p .196 .678 .93 r
F P
0 g
s
.62572 .38312 m .61984 .38462 L .60837 .38069 L p .041 .582 .846 r
F P
0 g
s
.63835 .56437 m .65795 .54236 L .67754 .55265 L p .748 .739 .844 r
F P
0 g
s
.69579 .52694 m .67754 .55265 L .65795 .54236 L p .741 .725 .837 r
F P
0 g
s
.67754 .55265 m .69579 .52694 L .72033 .53616 L p .734 .726 .844 r
F P
0 g
s
.63869 .84737 m .59339 .84662 L .58351 .82593 L p .533 .696 .944 r
F P
0 g
s
.54218 .82072 m .58351 .82593 L .59339 .84662 L p .543 .686 .932 r
F P
0 g
s
.29722 .68113 m .32528 .69112 L .30076 .70597 L p .662 .83 .964 r
F P
0 g
s
.30076 .70597 m .26854 .6933 L .29722 .68113 L p .662 .83 .964 r
F P
0 g
s
.5393 .34144 m .5496 .34617 L .55447 .35184 L p .115 .448 .882 r
F P
0 g
s
.5496 .34617 m .5393 .34144 L .53457 .33519 L p .164 .458 .885 r
F P
0 g
s
.4587 .64167 m .48286 .63565 L .48073 .64902 L p .763 .859 .921 r
F P
0 g
s
.48073 .64902 m .45339 .65436 L .4587 .64167 L p .763 .859 .921 r
F P
0 g
s
.50149 .31255 m .51359 .3168 L .51855 .32382 L p .267 .519 .907 r
F P
0 g
s
.51359 .3168 m .50149 .31255 L .49564 .30525 L p .305 .538 .911 r
F P
0 g
s
.7176 .39649 m .7214 .38424 L .74924 .38433 L p .572 .806 .987 r
F P
0 g
s
.7214 .38424 m .7176 .39649 L .69373 .39356 L p .541 .811 .996 r
F P
0 g
s
.60307 .57241 m .62313 .5536 L .63835 .56437 L p .762 .754 .846 r
F P
0 g
s
.65795 .54236 m .63835 .56437 L .62313 .5536 L p .756 .739 .837 r
F P
0 g
s
.73614 .50626 m .72033 .53616 L .69579 .52694 L p .727 .714 .838 r
F P
0 g
s
.72033 .53616 m .73614 .50626 L .76617 .51366 L p .721 .716 .845 r
F P
0 g
s
.81422 .4838 m .80036 .52193 L .76617 .51366 L p .709 .709 .848 r
F P
0 g
s
.60837 .38069 m .61411 .3806 L .62572 .38312 L p .041 .582 .846 r
F P
0 g
s
.61411 .3806 m .60837 .38069 L .59849 .37686 L p 0 .453 .728 r
F P
0 g
s
.58282 .3692 m .57676 .36524 L p .58174 .36826 L .473 0 0 r
F P
0 g
s
.59849 .37686 m .59002 .37305 L p .59815 .37591 L .288 0 0 r
F P
0 g
s
.6042 .37803 m .60223 .37763 L p .59815 .37591 L .288 0 0 r
F P
0 g
s
.60223 .37763 m .59849 .37686 L p .59815 .37591 L .288 0 0 r
F P
0 g
s
.58747 .37141 m .5884 .37219 L .58282 .3692 L p .408 0 0 r
F P
0 g
s
.59002 .37305 m .59582 .37536 L .6042 .37803 L p .288 0 0 r
F P
0 g
s
.59582 .37536 m .59002 .37305 L p .5898 .37294 L .408 0 0 r
F P
0 g
s
.58882 .37254 m .59582 .37536 L p .58747 .37141 L .408 0 0 r
F P
0 g
s
.58282 .3692 m .58462 .3702 L p .58747 .37141 L .408 0 0 r
F P
0 g
s
.58462 .3702 m .58882 .37254 L p .58747 .37141 L .408 0 0 r
F P
0 g
s
.58882 .37254 m .58282 .3692 L p .58174 .36826 L .473 0 0 r
F P
0 g
s
.58282 .3692 m .59002 .37305 L p .58389 .37014 L 0 .345 .736 r
F P
0 g
s
.57521 .36603 m .58282 .3692 L p .58389 .37014 L 0 .345 .736 r
F P
0 g
s
.58282 .3692 m .57521 .36603 L .56899 .36123 L p 0 .294 .721 r
F P
0 g
s
.51855 .32382 m .53012 .32865 L .53457 .33519 L p .233 .494 .897 r
F P
0 g
s
.53012 .32865 m .51855 .32382 L .51359 .3168 L p .276 .51 .899 r
F P
0 g
s
.55447 .35184 m .56367 .35633 L .56899 .36123 L p 0 .391 .842 r
F P
0 g
s
.56367 .35633 m .55447 .35184 L .5496 .34617 L p .031 .398 .854 r
F P
0 g
s
.52874 .60458 m .55069 .59209 L .55734 .60421 L p .785 .808 .871 r
F P
0 g
s
.55734 .60421 m .53274 .61692 L .52874 .60458 L p .785 .808 .871 r
F P
0 g
s
.58096 .58934 m .55734 .60421 L .55069 .59209 L p .782 .79 .859 r
F P
0 g
s
.69373 .39356 m .6972 .38401 L .7214 .38424 L p .541 .811 .996 r
F P
0 g
s
.6972 .38401 m .69373 .39356 L .67295 .3908 L p .496 .812 1 r
F P
0 g
s
.55069 .59209 m .57181 .57774 L .58096 .58934 L p .782 .79 .859 r
F P
0 g
s
.60307 .57241 m .58096 .58934 L .57181 .57774 L p .777 .772 .848 r
F P
0 g
s
.50648 .61514 m .52874 .60458 L .53274 .61692 L p .786 .828 .885 r
F P
0 g
s
.53274 .61692 m .50773 .62741 L .50648 .61514 L p .786 .828 .885 r
F P
0 g
s
.50051 .81188 m .45937 .79938 L .46467 .78096 L p .553 .659 .907 r
F P
0 g
s
.45937 .79938 m .41959 .78325 L .42956 .7657 L p .568 .654 .894 r
F P
0 g
s
.42956 .7657 m .46467 .78096 L .45937 .79938 L p .568 .654 .894 r
F P
0 g
s
.32618 .75696 m .29103 .72843 L .31676 .71428 L p .622 .661 .867 r
F P
0 g
s
.31676 .71428 m .34749 .74051 L .32618 .75696 L p .622 .661 .867 r
F P
0 g
s
.53457 .33519 m .54529 .34028 L .5496 .34617 L p .164 .458 .885 r
F P
0 g
s
.54529 .34028 m .53457 .33519 L .53012 .32865 L p .22 .475 .887 r
F P
0 g
s
.6042 .37803 m .59582 .37536 L p .60075 .377 L .413 0 0 r
F P
0 g
s
.59849 .37686 m .6042 .37803 L p .60764 .37905 L 0 .453 .728 r
F P
0 g
s
.60776 .37935 m .6042 .37803 L p .60075 .377 L .413 0 0 r
F P
0 g
s
.6042 .37803 m .61411 .3806 L p .60764 .37905 L 0 .453 .728 r
F P
0 g
s
.67295 .3908 m .6762 .38364 L .6972 .38401 L p .496 .812 1 r
F P
0 g
s
.6762 .38364 m .67295 .3908 L .65489 .38818 L p .428 .802 .993 r
F P
0 g
s
.54218 .82072 m .50051 .81188 L .50106 .79301 L p .538 .667 .92 r
F P
0 g
s
.46467 .78096 m .50106 .79301 L .50051 .81188 L p .553 .659 .907 r
F P
0 g
s
.41959 .78325 m .38203 .76357 L .39648 .74731 L p .584 .651 .882 r
F P
0 g
s
.39648 .74731 m .42956 .7657 L .41959 .78325 L p .584 .651 .882 r
F P
0 g
s
.57181 .57774 m .59162 .56161 L .60307 .57241 L p .777 .772 .848 r
F P
0 g
s
.62313 .5536 m .60307 .57241 L .59162 .56161 L p .771 .755 .839 r
F P
0 g
s
.49564 .30525 m .50854 .30932 L .51359 .3168 L p .305 .538 .911 r
F P
0 g
s
.50854 .30932 m .49564 .30525 L .48936 .29742 L p .345 .558 .915 r
F P
0 g
s
.40338 .65784 m .42741 .65726 L .41756 .67049 L p .716 .871 .955 r
F P
0 g
s
.41756 .67049 m .39018 .66969 L .40338 .65784 L p .716 .871 .955 r
F P
0 g
s
.57676 .36524 m .57175 .3611 L p .57643 .36458 L .456 0 0 r
F P
0 g
s
.57676 .36524 m .58282 .3692 L p .57709 .3659 L 0 .294 .721 r
F P
0 g
s
.58309 .36952 m .58882 .37254 L p .58383 .36952 L .473 0 0 r
F P
0 g
s
.57676 .36524 m .58309 .36952 L p .58383 .36952 L .473 0 0 r
F P
0 g
s
.58309 .36952 m .57676 .36524 L p .57643 .36458 L .456 0 0 r
F P
0 g
s
.58309 .36952 m .57851 .36625 L p .58234 .36953 L .696 .154 0 r
F P
0 g
s
.58778 .37419 m .58309 .36952 L p .58234 .36953 L .696 .154 0 r
F P
0 g
s
.56899 .36123 m .57676 .36524 L p .57709 .3659 L 0 .294 .721 r
F P
0 g
s
.57676 .36524 m .56899 .36123 L .56367 .35633 L p 0 .283 .746 r
F P
0 g
s
.48441 .62373 m .50648 .61514 L .50773 .62741 L p .784 .849 .9 r
F P
0 g
s
.50773 .62741 m .48286 .63565 L .48441 .62373 L p .784 .849 .9 r
F P
0 g
s
.5496 .34617 m .55915 .35123 L .56367 .35633 L p .031 .398 .854 r
F P
0 g
s
.55915 .35123 m .5496 .34617 L .54529 .34028 L p .111 .419 .865 r
F P
0 g
s
.65489 .38818 m .65803 .38313 L .6762 .38364 L p .428 .802 .993 r
F P
0 g
s
.65803 .38313 m .65489 .38818 L .63923 .38563 L p .326 .769 .963 r
F P
0 g
s
.36556 .66645 m .39018 .66969 L .37494 .6831 L p .685 .859 .965 r
F P
0 g
s
.37494 .6831 m .34679 .67801 L .36556 .66645 L p .685 .859 .965 r
F P
0 g
s
.62313 .5536 m .64067 .5331 L .65795 .54236 L p .756 .739 .837 r
F P
0 g
s
.67421 .51865 m .65795 .54236 L .64067 .5331 L p .748 .724 .83 r
F P
0 g
s
.65795 .54236 m .67421 .51865 L .69579 .52694 L p .741 .725 .837 r
F P
0 g
s
.43581 .64554 m .4587 .64167 L .45339 .65436 L p .748 .876 .939 r
F P
0 g
s
.45339 .65436 m .42741 .65726 L .43581 .64554 L p .748 .876 .939 r
F P
0 g
s
.51359 .3168 m .52588 .32171 L .53012 .32865 L p .276 .51 .899 r
F P
0 g
s
.52588 .32171 m .51359 .3168 L .50854 .30932 L p .321 .529 .901 r
F P
0 g
s
.77821 .47911 m .76617 .51366 L .73614 .50626 L p .713 .705 .841 r
F P
0 g
s
.76617 .51366 m .77821 .47911 L .81422 .4838 L p .709 .709 .848 r
F P
0 g
s
.70979 .49959 m .69579 .52694 L .67421 .51865 L p .733 .712 .831 r
F P
0 g
s
.69579 .52694 m .70979 .49959 L .73614 .50626 L p .727 .714 .838 r
F P
0 g
s
.63923 .38563 m .64236 .38245 L .65803 .38313 L p .326 .769 .963 r
F P
0 g
s
.64236 .38245 m .63923 .38563 L .62572 .38312 L p .179 .695 .888 r
F P
0 g
s
.53012 .32865 m .54145 .33404 L .54529 .34028 L p .22 .475 .887 r
F P
0 g
s
.54145 .33404 m .53012 .32865 L .52588 .32171 L p .278 .495 .888 r
F P
0 g
s
.59162 .56161 m .60963 .54387 L .62313 .5536 L p .771 .755 .839 r
F P
0 g
s
.64067 .5331 m .62313 .5536 L .60963 .54387 L p .764 .739 .83 r
F P
0 g
s
.56367 .35633 m .57175 .3611 L .57676 .36524 L p 0 .283 .746 r
F P
0 g
s
.57175 .3611 m .56367 .35633 L .55915 .35123 L p 0 .309 .792 r
F P
0 g
s
.58351 .82593 m .54218 .82072 L .53796 .80182 L p .525 .676 .933 r
F P
0 g
s
.50106 .79301 m .53796 .80182 L .54218 .82072 L p .538 .667 .92 r
F P
0 g
s
.38203 .76357 m .34749 .74051 L .36617 .72594 L p .6 .649 .87 r
F P
0 g
s
.36617 .72594 m .39648 .74731 L .38203 .76357 L p .6 .649 .87 r
F P
0 g
s
.62572 .38312 m .62891 .38161 L .64236 .38245 L p .179 .695 .888 r
F P
0 g
s
.62891 .38161 m .62572 .38312 L .61411 .3806 L p 0 .562 .749 r
F P
0 g
s
.6817 .84428 m .63869 .84737 L .62364 .82759 L p .524 .708 .955 r
F P
0 g
s
.58351 .82593 m .62364 .82759 L .63869 .84737 L p .533 .696 .944 r
F P
0 g
s
.54529 .34028 m .55536 .34584 L .55915 .35123 L p .111 .419 .865 r
F P
0 g
s
.55536 .34584 m .54529 .34028 L .54145 .33404 L p .197 .446 .871 r
F P
0 g
s
.46304 .6304 m .48441 .62373 L .48286 .63565 L p .777 .872 .917 r
F P
0 g
s
.48286 .63565 m .4587 .64167 L .46304 .6304 L p .777 .872 .917 r
F P
0 g
s
.48936 .29742 m .5033 .30123 L .50854 .30932 L p .345 .558 .915 r
F P
0 g
s
.5033 .30123 m .48936 .29742 L .48254 .28892 L p .383 .578 .917 r
F P
0 g
s
.32236 .67043 m .34679 .67801 L .32528 .69112 L p .66 .843 .97 r
F P
0 g
s
.32528 .69112 m .29722 .68113 L .32236 .67043 L p .66 .843 .97 r
F P
0 g
s
.52491 .59352 m .54456 .5812 L .55069 .59209 L p .797 .812 .864 r
F P
0 g
s
.55069 .59209 m .52874 .60458 L .52491 .59352 L p .797 .812 .864 r
F P
0 g
s
.57181 .57774 m .55069 .59209 L .54456 .5812 L p .792 .792 .852 r
F P
0 g
s
.61745 .38058 m .61411 .3806 L .6042 .37803 L p .226 0 0 r
F P
0 g
s
.61745 .38058 m .60776 .37935 L p .6121 .37996 L .247 0 0 r
F P
0 g
s
.61828 .38084 m .61745 .38058 L p .6121 .37996 L .247 0 0 r
F P
0 g
s
.61745 .38058 m .62891 .38161 L p .62278 .38119 L 0 .562 .749 r
F P
0 g
s
.61411 .3806 m .61745 .38058 L p .62278 .38119 L 0 .562 .749 r
F P
0 g
s
.54456 .5812 m .56353 .56727 L .57181 .57774 L p .792 .792 .852 r
F P
0 g
s
.59162 .56161 m .57181 .57774 L .56353 .56727 L p .787 .774 .841 r
F P
0 g
s
.50854 .30932 m .52176 .31423 L .52588 .32171 L p .321 .529 .901 r
F P
0 g
s
.52176 .31423 m .50854 .30932 L .5033 .30123 L p .363 .549 .902 r
F P
0 g
s
.55915 .35123 m .5677 .3567 L .57175 .3611 L p 0 .309 .792 r
F P
0 g
s
.5677 .3567 m .55915 .35123 L .55536 .34584 L p .03 .355 .83 r
F P
0 g
s
.74668 .47487 m .73614 .50626 L .70979 .49959 L p .718 .702 .834 r
F P
0 g
s
.73614 .50626 m .74668 .47487 L .77821 .47911 L p .713 .705 .841 r
F P
0 g
s
.50503 .60416 m .52491 .59352 L .52874 .60458 L p .799 .834 .878 r
F P
0 g
s
.52874 .60458 m .50648 .61514 L .50503 .60416 L p .799 .834 .878 r
F P
0 g
s
.56353 .56727 m .58137 .55185 L .59162 .56161 L p .787 .774 .841 r
F P
0 g
s
.60963 .54387 m .59162 .56161 L .58137 .55185 L p .78 .757 .832 r
F P
0 g
s
.52588 .32171 m .53803 .32735 L .54145 .33404 L p .278 .495 .888 r
F P
0 g
s
.53803 .32735 m .52588 .32171 L .52176 .31423 L p .331 .516 .888 r
F P
0 g
s
.6042 .37803 m .60776 .37935 L .61745 .38058 L p .226 0 0 r
F P
0 g
s
.60963 .54387 m .62543 .5247 L .64067 .5331 L p .764 .739 .83 r
F P
0 g
s
.65525 .51116 m .64067 .5331 L .62543 .5247 L p .756 .723 .822 r
F P
0 g
s
.64067 .5331 m .65525 .51116 L .67421 .51865 L p .748 .724 .83 r
F P
0 g
s
.68669 .49356 m .67421 .51865 L .65525 .51116 L p .739 .709 .823 r
F P
0 g
s
.67421 .51865 m .68669 .49356 L .70979 .49959 L p .733 .712 .831 r
F P
0 g
s
.54145 .33404 m .55224 .34007 L .55536 .34584 L p .197 .446 .871 r
F P
0 g
s
.55224 .34007 m .54145 .33404 L .53803 .32735 L p .274 .473 .872 r
F P
0 g
s
.29103 .72843 m .26091 .69662 L .29059 .68519 L p .636 .663 .859 r
F P
0 g
s
.29059 .68519 m .31676 .71428 L .29103 .72843 L p .636 .663 .859 r
F P
0 g
s
.59582 .37536 m .59968 .37789 L .60776 .37935 L p .413 0 0 r
F P
0 g
s
.59968 .37789 m .59582 .37536 L .58882 .37254 L p .553 0 0 r
F P
0 g
s
.57175 .3611 m .57851 .36625 L p .57839 .36604 L .456 0 0 r
F P
0 g
s
.57502 .36267 m .57851 .36625 L p .57403 .3623 L 0 .153 .657 r
F P
0 g
s
.5677 .3567 m .57502 .36267 L p .57403 .3623 L 0 .153 .657 r
F P
0 g
s
.57502 .36267 m .57255 .3587 L p .576 .36304 L 0 .115 .664 r
F P
0 g
s
.57851 .36625 m .57502 .36267 L p .57863 .36647 L .604 .092 0 r
F P
0 g
s
.57851 .36625 m .58309 .36952 L p .57839 .36604 L .456 0 0 r
F P
0 g
s
.57851 .36625 m .57175 .3611 L .5677 .3567 L p 0 .153 .657 r
F P
0 g
s
.57851 .36625 m .58376 .37187 L .58778 .37419 L p .696 .154 0 r
F P
0 g
s
.58091 .36919 m .58376 .37187 L p .58014 .36806 L .604 .092 0 r
F P
0 g
s
.57502 .36267 m .58091 .36919 L p .58014 .36806 L .604 .092 0 r
F P
0 g
s
.58376 .37187 m .57851 .36625 L p .57863 .36647 L .604 .092 0 r
F P
0 g
s
.58091 .36919 m .5792 .3661 L p .58169 .37033 L 0 0 .528 r
F P
0 g
s
.58522 .37633 m .58735 .37803 L p .58468 .37437 L .831 .357 .012 r
F P
0 g
s
.58091 .36919 m .58522 .37633 L p .58468 .37437 L .831 .357 .012 r
F P
0 g
s
.58522 .37633 m .58091 .36919 L p .58169 .37033 L 0 0 .528 r
F P
0 g
s
.58735 .37803 m .58376 .37187 L .58091 .36919 L p .831 .357 .012 r
F P
0 g
s
.58431 .37419 m .58522 .37633 L p .58273 .3721 L 0 0 .528 r
F P
0 g
s
.5792 .3661 m .58431 .37419 L p .58273 .3721 L 0 0 .528 r
F P
0 g
s
.59072 .37933 m .58778 .37419 L .58376 .37187 L p .776 .329 .186 r
F P
0 g
s
.58376 .37187 m .58735 .37803 L .59072 .37933 L p .776 .329 .186 r
F P
0 g
s
.58431 .37419 m .5846 .37158 L p .5859 .3763 L .376 .323 .671 r
F P
0 g
s
.58917 .3848 m .58735 .37803 L .58522 .37633 L p .852 .489 .365 r
F P
0 g
s
.58522 .37633 m .58783 .38412 L .58917 .3848 L p .852 .489 .365 r
F P
0 g
s
.58774 .38299 m .58431 .37419 L p .5859 .3763 L .376 .323 .671 r
F P
0 g
s
.58522 .37633 m .58431 .37419 L p .58576 .3783 L 0 0 .501 r
F P
0 g
s
.58783 .38412 m .58522 .37633 L p .58576 .3783 L 0 0 .501 r
F P
0 g
s
.58091 .36919 m .57502 .36267 L p .576 .36304 L 0 .115 .664 r
F P
0 g
s
.4854 .61312 m .50503 .60416 L .50648 .61514 L p .799 .858 .893 r
F P
0 g
s
.50648 .61514 m .48441 .62373 L .4854 .61312 L p .799 .858 .893 r
F P
0 g
s
.41472 .64739 m .43581 .64554 L .42741 .65726 L p .723 .89 .956 r
F P
0 g
s
.42741 .65726 m .40338 .65784 L .41472 .64739 L p .723 .89 .956 r
F P
0 g
s
.58137 .55185 m .59766 .53505 L .60963 .54387 L p .78 .757 .832 r
F P
0 g
s
.62543 .5247 m .60963 .54387 L .59766 .53505 L p .773 .74 .823 r
F P
0 g
s
.55536 .34584 m .56453 .35196 L .5677 .3567 L p .03 .355 .83 r
F P
0 g
s
.56453 .35196 m .55536 .34584 L .55224 .34007 L p .163 .404 .847 r
F P
0 g
s
.62364 .82759 m .58351 .82593 L .57458 .80743 L p .512 .686 .946 r
F P
0 g
s
.53796 .80182 m .57458 .80743 L .58351 .82593 L p .525 .676 .933 r
F P
0 g
s
.48254 .28892 m .49777 .29237 L .5033 .30123 L p .383 .578 .917 r
F P
0 g
s
.49777 .29237 m .48254 .28892 L .47504 .27957 L p .419 .596 .918 r
F P
0 g
s
.44287 .63518 m .46304 .6304 L .4587 .64167 L p .761 .893 .936 r
F P
0 g
s
.4587 .64167 m .43581 .64554 L .44287 .63518 L p .761 .893 .936 r
F P
0 g
s
.34749 .74051 m .31676 .71428 L .33933 .7018 L p .616 .65 .86 r
F P
0 g
s
.33933 .7018 m .36617 .72594 L .34749 .74051 L p .616 .65 .86 r
F P
0 g
s
.38187 .65628 m .40338 .65784 L .39018 .66969 L p .687 .877 .97 r
F P
0 g
s
.39018 .66969 m .36556 .66645 L .38187 .65628 L p .687 .877 .97 r
F P
0 g
s
.58882 .37254 m .59306 .37618 L .59968 .37789 L p .553 0 0 r
F P
0 g
s
.59306 .37618 m .58882 .37254 L .58309 .36952 L p .65 .101 0 r
F P
0 g
s
.71912 .47101 m .70979 .49959 L .68669 .49356 L p .723 .698 .826 r
F P
0 g
s
.70979 .49959 m .71912 .47101 L .74668 .47487 L p .718 .702 .834 r
F P
0 g
s
.5033 .30123 m .5177 .30608 L .52176 .31423 L p .363 .549 .902 r
F P
0 g
s
.5177 .30608 m .5033 .30123 L .49777 .29237 L p .401 .568 .903 r
F P
0 g
s
.57502 .36267 m .5677 .3567 L .56453 .35196 L p 0 .257 .768 r
F P
0 g
s
.52176 .31423 m .53496 .32007 L .53803 .32735 L p .331 .516 .888 r
F P
0 g
s
.53496 .32007 m .52176 .31423 L .5177 .30608 L p .378 .537 .888 r
F P
0 g
s
.50106 .79301 m .46467 .78096 L .46915 .76455 L p .537 .646 .905 r
F P
0 g
s
.46467 .78096 m .42956 .7657 L .43816 .7501 L p .554 .641 .89 r
F P
0 g
s
.43816 .7501 m .46915 .76455 L .46467 .78096 L p .554 .641 .89 r
F P
0 g
s
.82086 .44419 m .81422 .4838 L .77821 .47911 L p .701 .699 .846 r
F P
0 g
s
.77952 .36524 m .78121 .38429 L .74924 .38433 L p .615 .815 .977 r
F P
0 g
s
.74924 .38433 m .74769 .36889 L .77952 .36524 L p .615 .815 .977 r
F P
0 g
s
.74769 .36889 m .74924 .38433 L .7214 .38424 L p .597 .826 .987 r
F P
0 g
s
.81618 .36095 m .81789 .38411 L .78121 .38429 L p .627 .805 .968 r
F P
0 g
s
.78121 .38429 m .77952 .36524 L .81618 .36095 L p .627 .805 .968 r
F P
0 g
s
.7214 .38424 m .72007 .37196 L .74769 .36889 L p .597 .826 .987 r
F P
0 g
s
.72007 .37196 m .7214 .38424 L .6972 .38401 L p .57 .836 .995 r
F P
0 g
s
.6972 .38401 m .69614 .3745 L .72007 .37196 L p .57 .836 .995 r
F P
0 g
s
.69614 .3745 m .6972 .38401 L .6762 .38364 L p .53 .843 .999 r
F P
0 g
s
.53803 .32735 m .54972 .3338 L .55224 .34007 L p .274 .473 .872 r
F P
0 g
s
.54972 .3338 m .53803 .32735 L .53496 .32007 L p .34 .5 .871 r
F P
0 g
s
.62543 .5247 m .63861 .50433 L .65525 .51116 L p .756 .723 .822 r
F P
0 g
s
.66648 .48807 m .65525 .51116 L .63861 .50433 L p .747 .707 .815 r
F P
0 g
s
.65525 .51116 m .66648 .48807 L .68669 .49356 L p .739 .709 .823 r
F P
0 g
s
.58309 .36952 m .58778 .37419 L .59306 .37618 L p .65 .101 0 r
F P
0 g
s
.6762 .38364 m .67546 .37658 L .69614 .3745 L p .53 .843 .999 r
F P
0 g
s
.67546 .37658 m .6762 .38364 L .65803 .38313 L p .467 .839 .99 r
F P
0 g
s
.42956 .7657 m .39648 .74731 L .40905 .73289 L p .572 .637 .877 r
F P
0 g
s
.40905 .73289 m .43816 .7501 L .42956 .7657 L p .572 .637 .877 r
F P
0 g
s
.53884 .57136 m .55598 .5578 L .56353 .56727 L p .802 .794 .845 r
F P
0 g
s
.56353 .56727 m .54456 .5812 L .53884 .57136 L p .802 .794 .845 r
F P
0 g
s
.58137 .55185 m .56353 .56727 L .55598 .5578 L p .796 .775 .834 r
F P
0 g
s
.59766 .53505 m .61199 .51706 L .62543 .5247 L p .773 .74 .823 r
F P
0 g
s
.63861 .50433 m .62543 .5247 L .61199 .51706 L p .764 .723 .814 r
F P
0 g
s
.46647 .62038 m .4854 .61312 L .48441 .62373 L p .793 .884 .911 r
F P
0 g
s
.48441 .62373 m .46304 .6304 L .46647 .62038 L p .793 .884 .911 r
F P
0 g
s
.65803 .38313 m .65764 .37823 L .67546 .37658 L p .467 .839 .99 r
F P
0 g
s
.65764 .37823 m .65803 .38313 L .64236 .38245 L p .364 .81 .95 r
F P
0 g
s
.52116 .58356 m .53884 .57136 L .54456 .5812 L p .808 .815 .856 r
F P
0 g
s
.54456 .5812 m .52491 .59352 L .52116 .58356 L p .808 .815 .856 r
F P
0 g
s
.55224 .34007 m .56219 .3468 L .56453 .35196 L p .163 .404 .847 r
F P
0 g
s
.56219 .3468 m .55224 .34007 L .54972 .3338 L p .271 .446 .851 r
F P
0 g
s
.53796 .80182 m .50106 .79301 L .50133 .77617 L p .52 .654 .919 r
F P
0 g
s
.46915 .76455 m .50133 .77617 L .50106 .79301 L p .537 .646 .905 r
F P
0 g
s
.64236 .38245 m .64235 .37947 L .65764 .37823 L p .364 .81 .95 r
F P
0 g
s
.64235 .37947 m .64236 .38245 L .62891 .38161 L p .205 .728 .85 r
F P
0 g
s
.55598 .5578 m .57216 .54296 L .58137 .55185 L p .796 .775 .834 r
F P
0 g
s
.59766 .53505 m .58137 .55185 L .57216 .54296 L p .789 .758 .824 r
F P
0 g
s
.29722 .68113 m .26854 .6933 L p .27183 .67847 L .641 .825 .971 r
F P
0 g
s
.27183 .67847 m .27197 .67784 L .27303 .67798 L .641 .825 .971 r
F
.27183 .67847 m .27303 .67798 L .29722 .68113 L F
.28277 .67339 m .29722 .68113 L p .27197 .67784 L F P
0 g
s
.32236 .67043 m .29722 .68113 L p .30028 .66883 L .634 .838 .978 r
F P
0 g
s
.30028 .66883 m .30135 .66839 L .32236 .67043 L .634 .838 .978 r
F
.30987 .66438 m .32236 .67043 L p .30041 .6683 L F P
0 g
s
.34679 .67801 m .32236 .67043 L .34432 .66104 L p .656 .858 .977 r
F P
0 g
s
.34432 .66104 m .32236 .67043 L p .32516 .6604 L .624 .851 .986 r
F P
0 g
s
.32516 .6604 m .32612 .66 L .34432 .66104 L .624 .851 .986 r
F
.33354 .65651 m .34432 .66104 L p .32529 .65995 L F P
0 g
s
.34432 .66104 m .36556 .66645 L .34679 .67801 L p .656 .858 .977 r
F P
0 g
s
.36556 .66645 m .34432 .66104 L .36342 .65283 L p .65 .875 .982 r
F P
0 g
s
.36342 .65283 m .34432 .66104 L p .34685 .65304 L .609 .865 .991 r
F P
0 g
s
.34685 .65304 m .34771 .65268 L .36342 .65283 L .609 .865 .991 r
F
.35414 .64967 m .36342 .65283 L p .34697 .65268 L F P
0 g
s
.36342 .65283 m .38187 .65628 L .36556 .66645 L p .65 .875 .982 r
F P
0 g
s
.38187 .65628 m .36342 .65283 L .37996 .64567 L p .641 .893 .985 r
F P
0 g
s
.37996 .64567 m .36342 .65283 L p .36568 .64666 L .586 .879 .993 r
F P
0 g
s
.36568 .64666 m .36645 .64633 L .37996 .64567 L .586 .879 .993 r
F
.37199 .64374 m .37996 .64567 L p .36579 .64636 L F P
0 g
s
.37996 .64567 m .39595 .64736 L .38187 .65628 L p .641 .893 .985 r
F P
0 g
s
.39595 .64736 m .37996 .64567 L .39418 .63946 L p .623 .911 .982 r
F P
0 g
s
.39418 .63946 m .37996 .64567 L p .38204 .64091 L .548 .888 .985 r
F P
0 g
s
.38137 .62593 m .38692 .63767 L p .37865 .64117 L .633 .603 .802 r
F P
0 g
s
.37835 .64126 m .37865 .64117 L .37834 .6413 L .633 .603 .802 r
F
.38137 .62593 m .37865 .64117 L .37835 .64126 L F
.38137 .62593 m .39547 .62257 L p .39269 .6372 L .628 .585 .787 r
F P
0 g
s
.39418 .63946 m .38771 .63867 L p .39592 .63634 L .485 .882 .955 r
F P
0 g
s
.38771 .63867 m .38737 .63863 L p .39269 .6372 L .485 .882 .955 r
F P
0 g
s
.38771 .63867 m .39269 .6372 L .39592 .63634 L .485 .882 .955 r
F
.38737 .63863 m .39418 .63946 L p .38204 .64091 L .548 .888 .985 r
F P
0 g
s
.39418 .63946 m .408 .63955 L .39595 .64736 L p .623 .911 .982 r
F P
0 g
s
.408 .63955 m .39418 .63946 L .4063 .63409 L p .594 .924 .966 r
F P
0 g
s
.4063 .63409 m .39418 .63946 L p .39598 .63624 L .485 .882 .955 r
F P
0 g
s
.40052 .63426 m .40083 .63425 L p .39598 .63624 L .485 .882 .955 r
F P
0 g
s
.40083 .63425 m .4063 .63409 L p .39653 .63612 L .485 .882 .955 r
F P
0 g
s
.39598 .63624 m .40083 .63425 L .39653 .63612 L .485 .882 .955 r
F
.40518 .63235 m .40601 .63278 L .40505 .63305 L .621 .565 .771 r
F
.4063 .63409 m .40083 .63425 L p .40505 .63305 L .381 .843 .88 r
F P
0 g
s
.40778 .63233 m .40505 .63305 L .40784 .63226 L .381 .843 .88 r
F
.4063 .63409 m .40505 .63305 L .40778 .63233 L F
.39547 .62257 m .40747 .61979 L p .40505 .63305 L .621 .565 .771 r
F P
0 g
s
.40052 .63426 m .39547 .62257 L p .40505 .63305 L .621 .565 .771 r
F P
0 g
s
.41653 .62949 m .4063 .63409 L p .40784 .63226 L .381 .843 .88 r
F P
0 g
s
.40556 .63218 m .41166 .63055 L .40518 .63235 L .621 .565 .771 r
F
.41132 .62967 m .41166 .63055 L p .40556 .63218 L F P
0 g
s
.42675 .6268 m .41653 .62949 L .42501 .62557 L p .458 .887 .832 r
F P
0 g
s
.42501 .62557 m .41653 .62949 L p .4178 .62893 L .219 .737 .726 r
F P
0 g
s
.41822 .63273 m .43246 .63009 L .42437 .63818 L p .684 .94 .964 r
F P
0 g
s
.43246 .63009 m .41822 .63273 L .42675 .6268 L p .675 .959 .944 r
F P
0 g
s
.41653 .62949 m .42675 .6268 L .41822 .63273 L p .543 .922 .923 r
F P
0 g
s
.41822 .63273 m .4063 .63409 L .41653 .62949 L p .543 .922 .923 r
F P
0 g
s
.42097 .62746 m .42303 .63342 L p .41539 .63004 L .612 .542 .752 r
F P
0 g
s
.41854 .6286 m .42097 .62746 L p .4178 .62893 L .219 .737 .726 r
F P
0 g
s
.43024 .63043 m .42303 .63342 L p .42412 .62664 L .601 .516 .73 r
F P
0 g
s
.4249 .62645 m .43024 .63043 L .42412 .62664 L .601 .516 .73 r
F
.42501 .62557 m .42123 .62734 L p .42412 .62664 L 0 0 0 r
F P
0 g
s
.42599 .62615 m .42412 .62664 L .42603 .62618 L 0 0 0 r
F
.42501 .62557 m .42412 .62664 L .42599 .62615 L F
.42123 .62734 m .42501 .62557 L p .41827 .62871 L .219 .737 .726 r
F P
0 g
s
.41754 .61754 m .42588 .61577 L p .42412 .62664 L .601 .516 .73 r
F P
0 g
s
.42303 .63342 m .42097 .62746 L p .42412 .62664 L .601 .516 .73 r
F P
0 g
s
.42097 .62746 m .41754 .61754 L p .42412 .62664 L .601 .516 .73 r
F P
0 g
s
.42675 .6268 m .43912 .62299 L .43246 .63009 L p .675 .959 .944 r
F P
0 g
s
.43912 .62299 m .42675 .6268 L .43372 .62166 L p .66 .969 .903 r
F P
0 g
s
.42501 .62557 m .43372 .62166 L .42675 .6268 L p .458 .887 .832 r
F P
0 g
s
.43372 .62166 m .42544 .62537 L p .43189 .62227 L .331 .792 .67 r
F P
0 g
s
.42544 .62537 m .42501 .62557 L .43189 .62227 L p .331 .792 .67 r
F P
0 g
s
.43372 .62166 m .44444 .61676 L .43912 .62299 L p .66 .969 .903 r
F P
0 g
s
.44444 .61676 m .43492 .62111 L p .43925 .61723 L .639 .965 .835 r
F P
0 g
s
.43492 .62111 m .43372 .62166 L .43925 .61723 L p .639 .965 .835 r
F P
0 g
s
.43925 .61723 m .4485 .6113 L .44444 .61676 L p .639 .965 .835 r
F P
0 g
s
.4485 .6113 m .44062 .61636 L p .44342 .61344 L .622 .944 .742 r
F P
0 g
s
.44062 .61636 m .43925 .61723 L .44342 .61344 L p .622 .944 .742 r
F P
0 g
s
.44342 .61344 m .45137 .60654 L .4485 .6113 L p .622 .944 .742 r
F P
0 g
s
.45137 .60654 m .44502 .61205 L p .4463 .61022 L .641 .924 .649 r
F P
0 g
s
.44502 .61205 m .44342 .61344 L .4463 .61022 L p .641 .924 .649 r
F P
0 g
s
.4463 .61022 m .45308 .60239 L .45137 .60654 L p .641 .924 .649 r
F P
0 g
s
.45308 .60239 m .44826 .60796 L p .44793 .60752 L .746 .94 .608 r
F P
0 g
s
.44826 .60796 m .4463 .61022 L .44793 .60752 L p .746 .94 .608 r
F P
0 g
s
.44391 .61562 m .44731 .60878 L p .4463 .61022 L .029 0 0 r
F P
0 g
s
.44731 .60878 m .44793 .60752 L .4463 .61022 L p .029 0 0 r
F P
0 g
s
.44793 .60752 m .44523 .61298 L p .44527 .61436 L 0 0 .045 r
F P
0 g
s
.44523 .61298 m .44391 .61562 L .44527 .61436 L p 0 0 .045 r
F P
0 g
s
.43912 .62299 m .45333 .61791 L .44868 .62602 L p .756 .953 .939 r
F P
0 g
s
.44444 .61676 m .45689 .61075 L .45333 .61791 L p .772 .973 .92 r
F P
0 g
s
.45333 .61791 m .43912 .62299 L .44444 .61676 L p .772 .973 .92 r
F P
0 g
s
.45689 .61075 m .44444 .61676 L .4485 .6113 L p .794 .988 .89 r
F P
0 g
s
.44497 .62299 m .44529 .61504 L p .44527 .61436 L .749 .467 .503 r
F P
0 g
s
.44529 .61504 m .44535 .61354 L .44527 .61436 L p .749 .467 .503 r
F P
0 g
s
.44527 .61436 m .44769 .6072 L p .44793 .60752 L 0 0 .045 r
F P
0 g
s
.44769 .6072 m .44834 .60531 L .44793 .60752 L p 0 0 .045 r
F P
0 g
s
.44127 .61734 m .4457 .61106 L p .44342 .61344 L 0 0 0 r
F P
0 g
s
.4457 .61106 m .4463 .61022 L .44342 .61344 L p 0 0 0 r
F P
0 g
s
.43728 .61954 m .44286 .614 L p .43925 .61723 L 0 0 0 r
F P
0 g
s
.44286 .614 m .44342 .61344 L .43925 .61723 L p 0 0 0 r
F P
0 g
s
.43189 .62227 m .43925 .61723 L .43372 .62166 L p .331 .792 .67 r
F P
0 g
s
.44868 .62602 m .43246 .63009 L .43912 .62299 L p .756 .953 .939 r
F P
0 g
s
.43592 .62798 m .43024 .63043 L p .43107 .62481 L .586 .483 .704 r
F P
0 g
s
.43189 .62227 m .43266 .62397 L .43711 .61976 L .206 0 0 r
F
.43467 .62291 m .43711 .61976 L p .43266 .62397 L F P
0 g
s
.43711 .61976 m .43728 .61954 L .43189 .62227 L p .206 0 0 r
F P
0 g
s
.43925 .61723 m .43189 .62227 L .43728 .61954 L p 0 0 0 r
F P
0 g
s
.43189 .62227 m .42501 .62557 L p .42595 .62613 L 0 0 0 r
F P
0 g
s
.42884 .62473 m .43189 .62227 L p .42595 .62613 L 0 0 0 r
F P
0 g
s
.42834 .62405 m .4286 .62493 L p .42423 .62595 L .601 .516 .73 r
F P
0 g
s
.4286 .62493 m .43024 .63043 L p .42512 .62662 L .601 .516 .73 r
F P
0 g
s
.42595 .62613 m .42603 .62618 L .42884 .62473 L 0 0 0 r
F
.4286 .62493 m .42884 .62473 L p .42603 .62618 L F P
0 g
s
.4286 .62493 m .42512 .62662 L .42423 .62595 L .601 .516 .73 r
F
.42662 .62653 m .4286 .62493 L p .42603 .62618 L 0 0 0 r
F P
0 g
s
.43467 .62291 m .43592 .62798 L p .43107 .62481 L .586 .483 .704 r
F P
0 g
s
.43189 .62227 m .42884 .62473 L p .43115 .62427 L .206 0 0 r
F P
0 g
s
.42588 .61577 m .4326 .61447 L p .43115 .62427 L .586 .483 .704 r
F P
0 g
s
.43024 .63043 m .4286 .62493 L p .43115 .62427 L .586 .483 .704 r
F P
0 g
s
.4286 .62493 m .42588 .61577 L p .43115 .62427 L .586 .483 .704 r
F P
0 g
s
.43263 .62389 m .43115 .62427 L .43266 .62397 L .206 0 0 r
F
.43189 .62227 m .43115 .62427 L .43263 .62389 L F
.42662 .62653 m .4331 .62494 L p .43266 .62397 L F P
0 g
s
.43115 .62427 m .43266 .62397 L .43107 .62481 L .586 .483 .704 r
F
.42884 .62473 m .42662 .62653 L p .43266 .62397 L .206 0 0 r
F P
0 g
s
.43125 .62356 m .43467 .62291 L .43266 .62397 L .586 .483 .704 r
F
.43125 .62356 m .43266 .62397 L .43115 .62427 L F
.4326 .61447 m .43445 .62201 L p .43125 .62356 L F P
0 g
s
.43445 .62201 m .43467 .62291 L p .43125 .62356 L .586 .483 .704 r
F P
0 g
s
.4331 .62494 m .43467 .62291 L p .43266 .62397 L .206 0 0 r
F P
0 g
s
.41854 .6286 m .42662 .62653 L p .42603 .62618 L 0 0 0 r
F P
0 g
s
.42123 .62734 m .41854 .6286 L p .42603 .62618 L 0 0 0 r
F P
0 g
s
.42423 .62595 m .4249 .62645 L .42412 .62664 L .601 .516 .73 r
F
.42588 .61577 m .42834 .62405 L p .42423 .62595 L F P
0 g
s
.42097 .62746 m .42123 .62734 L p .4178 .62893 L .219 .737 .726 r
F P
0 g
s
.4178 .62893 m .42123 .62734 L .41827 .62871 L .219 .737 .726 r
F
.42437 .63818 m .408 .63955 L .41822 .63273 L p .684 .94 .964 r
F P
0 g
s
.4063 .63409 m .41822 .63273 L .408 .63955 L p .594 .924 .966 r
F P
0 g
s
.42303 .63342 m .41418 .63701 L p .41539 .63004 L .612 .542 .752 r
F P
0 g
s
.41754 .61754 m .42097 .62746 L p .4178 .62893 L .612 .542 .752 r
F P
0 g
s
.41754 .61754 m .4178 .62893 L .41547 .62955 L .612 .542 .752 r
F
.40747 .61979 m .41754 .61754 L p .41547 .62955 L F P
0 g
s
.41653 .62949 m .41194 .63049 L p .41547 .62955 L .219 .737 .726 r
F P
0 g
s
.41194 .63049 m .41166 .63055 L p .4178 .62893 L .219 .737 .726 r
F P
0 g
s
.41166 .63055 m .41653 .62949 L p .40784 .63226 L .381 .843 .88 r
F P
0 g
s
.41418 .63701 m .41166 .63055 L p .41547 .62955 L .612 .542 .752 r
F P
0 g
s
.41166 .63055 m .40747 .61979 L p .41547 .62955 L .612 .542 .752 r
F P
0 g
s
.41775 .62895 m .41547 .62955 L .4178 .62893 L .219 .737 .726 r
F
.41653 .62949 m .41547 .62955 L .41775 .62895 L F
.4178 .62893 m .41166 .63055 L .41786 .6289 L F
.41547 .62955 m .4178 .62893 L .41539 .63004 L .612 .542 .752 r
F
.40873 .6312 m .41854 .6286 L p .41786 .6289 L .219 .737 .726 r
F P
0 g
s
.41166 .63055 m .40873 .6312 L p .41786 .6289 L .219 .737 .726 r
F P
0 g
s
.41166 .63055 m .40937 .63158 L .40518 .63235 L .621 .565 .771 r
F
.41188 .63112 m .40601 .63278 L .40518 .63235 L F
.40873 .6312 m .41166 .63055 L p .40784 .63226 L .381 .843 .88 r
F P
0 g
s
.41166 .63055 m .41188 .63112 L p .40937 .63158 L .621 .565 .771 r
F P
0 g
s
.41188 .63112 m .41418 .63701 L p .40601 .63278 L .621 .565 .771 r
F P
0 g
s
.40083 .63425 m .40052 .63426 L p .40784 .63226 L .381 .843 .88 r
F P
0 g
s
.40355 .64126 m .40052 .63426 L p .40505 .63305 L .621 .565 .771 r
F P
0 g
s
.40784 .63226 m .40052 .63426 L .40791 .63218 L .381 .843 .88 r
F
.41418 .63701 m .40355 .64126 L p .40505 .63305 L .621 .565 .771 r
F P
0 g
s
.40601 .63278 m .41418 .63701 L .40505 .63305 L .621 .565 .771 r
F
.40747 .61979 m .41132 .62967 L p .40518 .63235 L F P
0 g
s
.39284 .63642 m .40077 .63483 L .39269 .6372 L .628 .585 .787 r
F
.39547 .62257 m .40052 .63426 L p .39284 .63642 L F P
0 g
s
.40052 .63426 m .40077 .63483 L p .39284 .63642 L .628 .585 .787 r
F P
0 g
s
.39703 .63435 m .40873 .6312 L p .40791 .63218 L .381 .843 .88 r
F P
0 g
s
.40052 .63426 m .39703 .63435 L p .40791 .63218 L .381 .843 .88 r
F P
0 g
s
.39703 .63435 m .40052 .63426 L p .39598 .63624 L .485 .882 .955 r
F P
0 g
s
.40355 .64126 m .39097 .64624 L p .39259 .63772 L .628 .585 .787 r
F P
0 g
s
.39269 .6372 m .39327 .63742 L .39259 .63772 L .628 .585 .787 r
F
.39327 .63742 m .40355 .64126 L .39259 .63772 L F
.40077 .63483 m .40355 .64126 L p .39269 .6372 L F P
0 g
s
.39097 .64624 m .38737 .63863 L p .39269 .6372 L .628 .585 .787 r
F P
0 g
s
.38737 .63863 m .38137 .62593 L p .39269 .6372 L .628 .585 .787 r
F P
0 g
s
.39592 .63634 m .38737 .63863 L .39606 .63609 L .485 .882 .955 r
F
.38326 .63812 m .39703 .63435 L p .39606 .63609 L F P
0 g
s
.38692 .63767 m .38765 .63922 L p .37834 .6413 L .633 .603 .802 r
F P
0 g
s
.37996 .64567 m .37237 .64383 L p .37819 .64207 L .548 .888 .985 r
F P
0 g
s
.38198 .64106 m .37819 .64207 L .38204 .64091 L .548 .888 .985 r
F
.37996 .64567 m .37819 .64207 L .38198 .64106 L F
.36491 .62991 m .38137 .62593 L p .37819 .64207 L .633 .603 .802 r
F P
0 g
s
.37623 .65202 m .37199 .64374 L p .37819 .64207 L .633 .603 .802 r
F P
0 g
s
.37199 .64374 m .36491 .62991 L p .37819 .64207 L .633 .603 .802 r
F P
0 g
s
.38765 .63922 m .39097 .64624 L p .37939 .64171 L .633 .603 .802 r
F P
0 g
s
.38765 .63922 m .37939 .64171 L .37834 .6413 L .633 .603 .802 r
F
.37834 .6413 m .3798 .64187 L .37808 .64261 L F
.36491 .62991 m .37147 .64273 L p .36175 .6468 L .638 .619 .814 r
F P
0 g
s
.36149 .64688 m .36175 .6468 L .36148 .64691 L .638 .619 .814 r
F
.36491 .62991 m .36175 .6468 L .36149 .64688 L F
.36718 .64257 m .38326 .63812 L p .38213 .64071 L .548 .888 .985 r
F P
0 g
s
.38204 .64091 m .38108 .64102 L .38213 .64071 L .548 .888 .985 r
F
.38108 .64102 m .36718 .64257 L .38213 .64071 L F
.37147 .64273 m .37199 .64374 L p .36175 .6468 L .638 .619 .814 r
F P
0 g
s
.36342 .65283 m .35456 .64981 L p .36132 .64774 L .586 .879 .993 r
F P
0 g
s
.36572 .64655 m .36132 .64774 L .36579 .64636 L .586 .879 .993 r
F
.36342 .65283 m .36132 .64774 L .36572 .64655 L F
.34585 .63459 m .36491 .62991 L p .36132 .64774 L .638 .619 .814 r
F P
0 g
s
.35911 .65869 m .35414 .64967 L p .36132 .64774 L .638 .619 .814 r
F P
0 g
s
.35414 .64967 m .34585 .63459 L p .36132 .64774 L .638 .619 .814 r
F P
0 g
s
.36568 .64666 m .36579 .64636 L .36645 .64633 L .586 .879 .993 r
F
.37199 .64374 m .37623 .65202 L p .36175 .6468 L .638 .619 .814 r
F P
0 g
s
.34585 .63459 m .35355 .64859 L p .34223 .6533 L .642 .633 .826 r
F P
0 g
s
.342 .65337 m .34223 .6533 L .34199 .6534 L .642 .633 .826 r
F
.34585 .63459 m .34223 .6533 L .342 .65337 L F
.34853 .64776 m .36718 .64257 L p .36589 .64609 L .586 .879 .993 r
F P
0 g
s
.36579 .64636 m .3647 .64645 L .36589 .64609 L .586 .879 .993 r
F
.3647 .64645 m .34853 .64776 L .36589 .64609 L F
.36175 .6468 m .36296 .64723 L .36148 .64691 L .638 .619 .814 r
F
.36296 .64723 m .36267 .64732 L .36148 .64691 L F
.36148 .64691 m .36314 .64749 L .3612 .6483 L F
.35355 .64859 m .35414 .64967 L p .34223 .6533 L .642 .633 .826 r
F P
0 g
s
.34432 .66104 m .33402 .65671 L p .34181 .65429 L .609 .865 .991 r
F P
0 g
s
.34689 .65291 m .34181 .65429 L .34697 .65268 L .609 .865 .991 r
F
.34432 .66104 m .34181 .65429 L .34689 .65291 L F
.32386 .64004 m .34585 .63459 L p .34181 .65429 L .642 .633 .826 r
F P
0 g
s
.33933 .66636 m .33354 .65651 L p .34181 .65429 L .642 .633 .826 r
F P
0 g
s
.33354 .65651 m .32386 .64004 L p .34181 .65429 L .642 .633 .826 r
F P
0 g
s
.34685 .65304 m .34697 .65268 L .34771 .65268 L .609 .865 .991 r
F
.35414 .64967 m .35911 .65869 L p .34223 .6533 L .642 .633 .826 r
F P
0 g
s
.32386 .64004 m .33286 .65536 L p .31977 .66077 L .645 .645 .836 r
F P
0 g
s
.31956 .66084 m .31977 .66077 L .31956 .66086 L .645 .645 .836 r
F
.32386 .64004 m .31977 .66077 L .31956 .66084 L F
.32701 .65377 m .34853 .64776 L p .34708 .65233 L .609 .865 .991 r
F P
0 g
s
.34697 .65268 m .34574 .65275 L .34708 .65233 L .609 .865 .991 r
F
.34574 .65275 m .32701 .65377 L .34708 .65233 L F
.34223 .6533 m .34358 .65373 L .34199 .6534 L .642 .633 .826 r
F
.34358 .65373 m .34333 .65381 L .34199 .6534 L F
.34199 .6534 m .34387 .65398 L .34168 .65489 L F
.33286 .65536 m .33354 .65651 L p .31977 .66077 L .645 .645 .836 r
F P
0 g
s
.32236 .67043 m .31041 .66464 L p .31936 .66182 L .624 .851 .986 r
F P
0 g
s
.3252 .66024 m .31936 .66182 L .32529 .65995 L .624 .851 .986 r
F
.32236 .67043 m .31936 .66182 L .3252 .66024 L F
.29859 .64634 m .32386 .64004 L p .31936 .66182 L .645 .645 .836 r
F P
0 g
s
.31661 .67515 m .30987 .66438 L p .31936 .66182 L .645 .645 .836 r
F P
0 g
s
.30987 .66438 m .29859 .64634 L p .31936 .66182 L .645 .645 .836 r
F P
0 g
s
.32516 .6604 m .32529 .65995 L .32612 .66 L .624 .851 .986 r
F
.33354 .65651 m .33933 .66636 L p .31977 .66077 L .645 .645 .836 r
F P
0 g
s
.29859 .64634 m .30909 .66313 L p .29403 .66933 L .647 .657 .845 r
F P
0 g
s
.29385 .66939 m .29403 .66933 L .29384 .66941 L .647 .657 .845 r
F
.29859 .64634 m .29403 .66933 L .29385 .66939 L F
.3023 .66071 m .32701 .65377 L p .32541 .65953 L .624 .851 .986 r
F P
0 g
s
.32529 .65995 m .32389 .66 L .32541 .65953 L .624 .851 .986 r
F
.32389 .66 m .3023 .66071 L .32541 .65953 L F
.31977 .66077 m .3213 .66121 L .31956 .66086 L .645 .645 .836 r
F
.3213 .66121 m .32107 .66128 L .31956 .66086 L F
.31956 .66086 m .32169 .66145 L .31922 .66248 L F
.30909 .66313 m .30987 .66438 L p .29403 .66933 L .647 .657 .845 r
F P
0 g
s
.29722 .68113 m .28339 .67371 L p .29363 .67046 L .634 .838 .978 r
F P
0 g
s
.30032 .66865 m .29363 .67046 L .30041 .6683 L .634 .838 .978 r
F
.29722 .68113 m .29363 .67046 L .30032 .66865 L F
.26966 .6536 m .29859 .64634 L p .29363 .67046 L .647 .657 .845 r
F P
0 g
s
.29059 .68519 m .28277 .67339 L p .29363 .67046 L .647 .657 .845 r
F P
0 g
s
.28277 .67339 m .26966 .6536 L p .29363 .67046 L .647 .657 .845 r
F P
0 g
s
.30028 .66883 m .30041 .6683 L .30135 .66839 L .634 .838 .978 r
F
.30987 .66438 m .31661 .67515 L p .29403 .66933 L .647 .657 .845 r
F P
0 g
s
.26446 .67916 m .28277 .67339 L .27197 .67784 L .65 .667 .853 r
F
.26966 .6536 m .28277 .67339 L p .26446 .67916 L F P
0 g
s
.23662 .66192 m .26966 .6536 L p .26423 .68032 L .65 .667 .853 r
F P
0 g
s
.26854 .6933 m .25254 .68407 L p .26423 .68032 L .641 .825 .971 r
F P
0 g
s
.26091 .69662 m .25184 .68366 L p .26423 .68032 L .65 .667 .853 r
F P
0 g
s
.25184 .68366 m .23662 .66192 L p .26423 .68032 L .65 .667 .853 r
F P
0 g
s
.27188 .67826 m .26423 .68032 L .27197 .67784 L .641 .825 .971 r
F
.26854 .6933 m .26423 .68032 L .27188 .67826 L F
.24169 .6778 m .274 .66868 L p .27197 .67784 L F P
0 g
s
.26446 .67916 m .27197 .67784 L .26423 .68032 L .65 .667 .853 r
F
.25254 .68407 m .24169 .6778 L p .27197 .67784 L .641 .825 .971 r
F P
0 g
s
.26423 .68032 m .27197 .67784 L .26407 .6811 L .65 .667 .853 r
F
.274 .66868 m .3023 .66071 L p .30054 .66778 L .634 .838 .978 r
F P
0 g
s
.30041 .6683 m .29883 .66832 L .30054 .66778 L .634 .838 .978 r
F
.29883 .66832 m .274 .66868 L .30054 .66778 L F
.29403 .66933 m .29576 .66978 L .29384 .66941 L .647 .657 .845 r
F
.29576 .66978 m .29556 .66984 L .29384 .66941 L F
.29384 .66941 m .29626 .67002 L .29348 .67117 L F
.28339 .67371 m .274 .66868 L p .30041 .6683 L .634 .838 .978 r
F P
0 g
s
.29576 .66978 m .31661 .67515 L .29556 .66984 L .647 .657 .845 r
F
.31041 .66464 m .30987 .66438 L p .32529 .65995 L .624 .851 .986 r
F P
0 g
s
.30987 .66438 m .3023 .66071 L p .32389 .66 L .624 .851 .986 r
F P
0 g
s
.30987 .66438 m .32389 .66 L .32529 .65995 L .624 .851 .986 r
F
.3213 .66121 m .33933 .66636 L .32107 .66128 L .645 .645 .836 r
F
.33402 .65671 m .33354 .65651 L p .34697 .65268 L .609 .865 .991 r
F P
0 g
s
.33354 .65651 m .32701 .65377 L p .34574 .65275 L .609 .865 .991 r
F P
0 g
s
.33354 .65651 m .34574 .65275 L .34697 .65268 L .609 .865 .991 r
F
.34358 .65373 m .35911 .65869 L .34333 .65381 L .642 .633 .826 r
F
.35456 .64981 m .35414 .64967 L p .36579 .64636 L .586 .879 .993 r
F P
0 g
s
.35414 .64967 m .34853 .64776 L p .3647 .64645 L .586 .879 .993 r
F P
0 g
s
.35414 .64967 m .3647 .64645 L .36579 .64636 L .586 .879 .993 r
F
.36296 .64723 m .37623 .65202 L .36267 .64732 L .638 .619 .814 r
F
.37237 .64383 m .37199 .64374 L p .38204 .64091 L .548 .888 .985 r
F P
0 g
s
.37199 .64374 m .36718 .64257 L p .38108 .64102 L .548 .888 .985 r
F P
0 g
s
.37199 .64374 m .38108 .64102 L .38204 .64091 L .548 .888 .985 r
F
.38737 .63863 m .38326 .63812 L p .39606 .63609 L .485 .882 .955 r
F P
0 g
s
.38326 .63812 m .38737 .63863 L p .38204 .64091 L .548 .888 .985 r
F P
0 g
s
.39097 .64624 m .37623 .65202 L p .37808 .64261 L .633 .603 .802 r
F P
0 g
s
.3798 .64187 m .39097 .64624 L .37808 .64261 L .633 .603 .802 r
F
.36718 .64257 m .37199 .64374 L p .36579 .64636 L .586 .879 .993 r
F P
0 g
s
.37623 .65202 m .35911 .65869 L p .3612 .6483 L .638 .619 .814 r
F P
0 g
s
.36314 .64749 m .37623 .65202 L .3612 .6483 L .638 .619 .814 r
F
.34853 .64776 m .35414 .64967 L p .34697 .65268 L .609 .865 .991 r
F P
0 g
s
.35911 .65869 m .33933 .66636 L p .34168 .65489 L .642 .633 .826 r
F P
0 g
s
.34387 .65398 m .35911 .65869 L .34168 .65489 L .642 .633 .826 r
F
.32701 .65377 m .33354 .65651 L p .32529 .65995 L .624 .851 .986 r
F P
0 g
s
.33933 .66636 m .31661 .67515 L p .31922 .66248 L .645 .645 .836 r
F P
0 g
s
.32169 .66145 m .33933 .66636 L .31922 .66248 L .645 .645 .836 r
F
.3023 .66071 m .30987 .66438 L p .30041 .6683 L .634 .838 .978 r
F P
0 g
s
.31661 .67515 m .29059 .68519 L p .29348 .67117 L .647 .657 .845 r
F P
0 g
s
.29626 .67002 m .31661 .67515 L .29348 .67117 L .647 .657 .845 r
F
.29059 .68519 m .26091 .69662 L p .26407 .6811 L .65 .667 .853 r
F P
0 g
s
.28277 .67339 m .29059 .68519 L p .26407 .6811 L .65 .667 .853 r
F P
0 g
s
.274 .66868 m .28277 .67339 L p .27197 .67784 L .641 .825 .971 r
F P
0 g
s
.62891 .38161 m .62931 .38034 L .64235 .37947 L p .205 .728 .85 r
F P
0 g
s
.62931 .38034 m .62891 .38161 L .61745 .38058 L p .013 0 0 r
F P
0 g
s
.50336 .59433 m .52116 .58356 L .52491 .59352 L p .813 .838 .869 r
F P
0 g
s
.52491 .59352 m .50503 .60416 L .50336 .59433 L p .813 .838 .869 r
F P
0 g
s
.61828 .38084 m .61654 .38162 L .61907 .38111 L p 0 0 0 r
F P
0 g
s
.61828 .38084 m .62931 .38034 L p .6175 .38058 L .013 0 0 r
F P
0 g
s
.62685 .37957 m .62931 .38034 L .61828 .38084 L p 0 0 0 r
F P
0 g
s
.61907 .38111 m .62685 .37957 L p .61828 .38084 L 0 0 0 r
F P
0 g
s
.61745 .38058 m .61828 .38084 L p .6175 .38058 L .013 0 0 r
F P
0 g
s
.56453 .35196 m .57255 .3587 L .57502 .36267 L p 0 .257 .768 r
F P
0 g
s
.57255 .3587 m .56453 .35196 L .56219 .3468 L p .128 .35 .813 r
F P
0 g
s
.69504 .46746 m .68669 .49356 L .66648 .48807 L p .729 .695 .818 r
F P
0 g
s
.68669 .49356 m .69504 .46746 L .71912 .47101 L p .723 .698 .826 r
F P
0 g
s
.78386 .44336 m .77821 .47911 L .74668 .47487 L p .704 .695 .839 r
F P
0 g
s
.77821 .47911 m .78386 .44336 L .82086 .44419 L p .701 .699 .846 r
F P
0 g
s
.60776 .37935 m .60906 .381 L .61828 .38084 L p .247 0 0 r
F P
0 g
s
.60906 .381 m .60776 .37935 L .59968 .37789 L p .441 0 0 r
F P
0 g
s
.57216 .54296 m .58701 .52699 L .59766 .53505 L p .789 .758 .824 r
F P
0 g
s
.61199 .51706 m .59766 .53505 L .58701 .52699 L p .782 .74 .815 r
F P
0 g
s
.47504 .27957 m .49185 .28257 L .49777 .29237 L p .419 .596 .918 r
F P
0 g
s
.49185 .28257 m .47504 .27957 L .46672 .26919 L p .451 .614 .918 r
F P
0 g
s
.39648 .74731 m .36617 .72594 L .38247 .71306 L p .591 .636 .864 r
F P
0 g
s
.38247 .71306 m .40905 .73289 L .39648 .74731 L p .591 .636 .864 r
F P
0 g
s
.59968 .37789 m .60148 .3808 L .60906 .381 L p .441 0 0 r
F P
0 g
s
.60148 .3808 m .59968 .37789 L .59306 .37618 L p .58 .087 .047 r
F P
0 g
s
.49777 .29237 m .51362 .2971 L .5177 .30608 L p .401 .568 .903 r
F P
0 g
s
.51362 .2971 m .49777 .29237 L .49185 .28257 L p .436 .586 .903 r
F P
0 g
s
.48584 .60364 m .50336 .59433 L .50503 .60416 L p .815 .865 .885 r
F P
0 g
s
.50503 .60416 m .4854 .61312 L .48584 .60364 L p .815 .865 .885 r
F P
0 g
s
.5177 .30608 m .53219 .31207 L .53496 .32007 L p .378 .537 .888 r
F P
0 g
s
.53219 .31207 m .5177 .30608 L .51362 .2971 L p .418 .557 .887 r
F P
0 g
s
.53496 .32007 m .54778 .32691 L .54972 .3338 L p .34 .5 .871 r
F P
0 g
s
.54778 .32691 m .53496 .32007 L .53219 .31207 L p .393 .524 .87 r
F P
0 g
s
.61199 .51706 m .62402 .49807 L .63861 .50433 L p .764 .723 .814 r
F P
0 g
s
.64882 .48301 m .63861 .50433 L .62402 .49807 L p .754 .706 .806 r
F P
0 g
s
.63861 .50433 m .64882 .48301 L .66648 .48807 L p .747 .707 .815 r
F P
0 g
s
.54972 .3338 m .56065 .34111 L .56219 .3468 L p .271 .446 .851 r
F P
0 g
s
.56065 .34111 m .54972 .3338 L .54778 .32691 L p .352 .48 .85 r
F P
0 g
s
.59306 .37618 m .5954 .38025 L .60148 .3808 L p .58 .087 .047 r
F P
0 g
s
.5954 .38025 m .59306 .37618 L .58778 .37419 L p .684 .228 .162 r
F P
0 g
s
.57458 .80743 m .53796 .80182 L .53402 .78494 L p .504 .664 .933 r
F P
0 g
s
.50133 .77617 m .53402 .78494 L .53796 .80182 L p .52 .654 .919 r
F P
0 g
s
.72149 .83756 m .6817 .84428 L .66172 .82587 L p .517 .721 .965 r
F P
0 g
s
.62364 .82759 m .66172 .82587 L .6817 .84428 L p .524 .708 .955 r
F P
0 g
s
.42437 .63818 m .44287 .63518 L .43581 .64554 L p .733 .91 .955 r
F P
0 g
s
.43581 .64554 m .41472 .64739 L .42437 .63818 L p .733 .91 .955 r
F P
0 g
s
.75159 .44253 m .74668 .47487 L .71912 .47101 L p .708 .691 .831 r
F P
0 g
s
.74668 .47487 m .75159 .44253 L .78386 .44336 L p .704 .695 .839 r
F P
0 g
s
.56219 .3468 m .57106 .35428 L .57255 .3587 L p .128 .35 .813 r
F P
0 g
s
.57106 .35428 m .56219 .3468 L .56065 .34111 L p .277 .415 .822 r
F P
0 g
s
.58701 .52699 m .60014 .51002 L .61199 .51706 L p .782 .74 .815 r
F P
0 g
s
.62402 .49807 m .61199 .51706 L .60014 .51002 L p .773 .723 .806 r
F P
0 g
s
.44868 .62602 m .46647 .62038 L .46304 .6304 L p .777 .91 .931 r
F P
0 g
s
.46304 .6304 m .44287 .63518 L .44868 .62602 L p .777 .91 .931 r
F P
0 g
s
.67406 .46416 m .66648 .48807 L .64882 .48301 L p .736 .691 .808 r
F P
0 g
s
.66648 .48807 m .67406 .46416 L .69504 .46746 L p .729 .695 .818 r
F P
0 g
s
.58778 .37419 m .59072 .37933 L .5954 .38025 L p .684 .228 .162 r
F P
0 g
s
.39595 .64736 m .41472 .64739 L .40338 .65784 L p .688 .896 .972 r
F P
0 g
s
.40338 .65784 m .38187 .65628 L .39595 .64736 L p .688 .896 .972 r
F P
0 g
s
.31676 .71428 m .29059 .68519 L .31661 .67515 L p .632 .652 .852 r
F P
0 g
s
.31661 .67515 m .33933 .7018 L .31676 .71428 L p .632 .652 .852 r
F P
0 g
s
.53346 .56242 m .54906 .54915 L .55598 .5578 L p .812 .795 .836 r
F P
0 g
s
.55598 .5578 m .53884 .57136 L .53346 .56242 L p .812 .795 .836 r
F P
0 g
s
.57216 .54296 m .55598 .5578 L .54906 .54915 L p .805 .776 .827 r
F P
0 g
s
.66172 .82587 m .62364 .82759 L .61015 .80991 L p .501 .699 .958 r
F P
0 g
s
.57458 .80743 m .61015 .80991 L .62364 .82759 L p .512 .686 .946 r
F P
0 g
s
.57255 .3587 m .5792 .3661 L .58091 .36919 L p 0 .115 .664 r
F P
0 g
s
.5792 .3661 m .57255 .3587 L .57106 .35428 L p .114 .293 .768 r
F P
0 g
s
.54906 .54915 m .56386 .53482 L .57216 .54296 L p .805 .776 .827 r
F P
0 g
s
.58701 .52699 m .57216 .54296 L .56386 .53482 L p .798 .759 .817 r
F P
0 g
s
.51746 .57455 m .53346 .56242 L .53884 .57136 L p .819 .816 .847 r
F P
0 g
s
.53884 .57136 m .52116 .58356 L .51746 .57455 L p .819 .816 .847 r
F P
0 g
s
.72346 .44166 m .71912 .47101 L .69504 .46746 L p .712 .686 .823 r
F P
0 g
s
.71912 .47101 m .72346 .44166 L .75159 .44253 L p .708 .691 .831 r
F P
0 g
s
.46903 .61149 m .48584 .60364 L .4854 .61312 L p .811 .895 .902 r
F P
0 g
s
.4854 .61312 m .46647 .62038 L .46903 .61149 L p .811 .895 .902 r
F P
0 g
s
.56386 .53482 m .57752 .51955 L .58701 .52699 L p .798 .759 .817 r
F P
0 g
s
.60014 .51002 m .58701 .52699 L .57752 .51955 L p .791 .742 .808 r
F P
0 g
s
.36617 .72594 m .33933 .7018 L .35904 .69081 L p .609 .637 .853 r
F P
0 g
s
.35904 .69081 m .38247 .71306 L .36617 .72594 L p .609 .637 .853 r
F P
0 g
s
.50142 .58547 m .51746 .57455 L .52116 .58356 L p .825 .84 .859 r
F P
0 g
s
.52116 .58356 m .50336 .59433 L .50142 .58547 L p .825 .84 .859 r
F P
0 g
s
.60014 .51002 m .61124 .49226 L .62402 .49807 L p .773 .723 .806 r
F P
0 g
s
.63342 .47832 m .62402 .49807 L .61124 .49226 L p .763 .705 .797 r
F P
0 g
s
.62402 .49807 m .63342 .47832 L .64882 .48301 L p .754 .706 .806 r
F P
0 g
s
.54778 .32691 m .55989 .33479 L .56065 .34111 L p .352 .48 .85 r
F P
0 g
s
.55989 .33479 m .54778 .32691 L .54637 .31927 L p .412 .51 .849 r
F P
0 g
s
.53219 .31207 m .54637 .31927 L .54778 .32691 L p .393 .524 .87 r
F P
0 g
s
.56065 .34111 m .57053 .34932 L .57106 .35428 L p .277 .415 .822 r
F P
0 g
s
.57053 .34932 m .56065 .34111 L .55989 .33479 L p .374 .462 .822 r
F P
0 g
s
.6558 .46104 m .64882 .48301 L .63342 .47832 L p .743 .688 .799 r
F P
0 g
s
.64882 .48301 m .6558 .46104 L .67406 .46416 L p .736 .691 .808 r
F P
0 g
s
.54637 .31927 m .53219 .31207 L .52967 .3032 L p .436 .546 .869 r
F P
0 g
s
.51362 .2971 m .52967 .3032 L .53219 .31207 L p .418 .557 .887 r
F P
0 g
s
.46672 .26919 m .48541 .27163 L .49185 .28257 L p .451 .614 .918 r
F P
0 g
s
.48541 .27163 m .46672 .26919 L .45741 .25757 L p .48 .629 .918 r
F P
0 g
s
.57106 .35428 m .5786 .36254 L .5792 .3661 L p .114 .293 .768 r
F P
0 g
s
.5786 .36254 m .57106 .35428 L .57053 .34932 L p .308 .391 .785 r
F P
0 g
s
.52967 .3032 m .51362 .2971 L .50944 .2871 L p .453 .576 .887 r
F P
0 g
s
.49185 .28257 m .50944 .2871 L .51362 .2971 L p .436 .586 .903 r
F P
0 g
s
.50944 .2871 m .49185 .28257 L .48541 .27163 L p .467 .603 .903 r
F P
0 g
s
.69899 .44075 m .69504 .46746 L .67406 .46416 L p .717 .681 .813 r
F P
0 g
s
.69504 .46746 m .69899 .44075 L .72346 .44166 L p .712 .686 .823 r
F P
0 g
s
.57752 .51955 m .58969 .50349 L .60014 .51002 L p .791 .742 .808 r
F P
0 g
s
.61124 .49226 m .60014 .51002 L .58969 .50349 L p .783 .724 .798 r
F P
0 g
s
.61654 .38162 m .61828 .38084 L .60906 .381 L p .165 0 0 r
F P
0 g
s
.60906 .381 m .60803 .38316 L .61654 .38162 L p .165 0 0 r
F P
0 g
s
.60803 .38316 m .60906 .381 L .60148 .3808 L p .366 0 0 r
F P
0 g
s
.60148 .3808 m .60115 .38423 L .60803 .38316 L p .366 0 0 r
F P
0 g
s
.60115 .38423 m .60148 .3808 L .5954 .38025 L p .506 .083 .172 r
F P
0 g
s
.48573 .59514 m .50142 .58547 L .50336 .59433 L p .83 .868 .873 r
F P
0 g
s
.50336 .59433 m .48584 .60364 L .48573 .59514 L p .83 .868 .873 r
F P
0 g
s
.58431 .37419 m .5792 .3661 L .5786 .36254 L p .177 .266 .718 r
F P
0 g
s
.63914 .377 m .64235 .37947 L .62931 .38034 L p .294 .791 .839 r
F P
0 g
s
.62931 .38034 m .62685 .37957 L .63914 .377 L p .294 .791 .839 r
F P
0 g
s
.5954 .38025 m .59578 .38486 L .60115 .38423 L p .506 .083 .172 r
F P
0 g
s
.59578 .38486 m .5954 .38025 L .59072 .37933 L p .607 .237 .316 r
F P
0 g
s
.61015 .80991 m .57458 .80743 L .5665 .79089 L p .489 .675 .947 r
F P
0 g
s
.53402 .78494 m .5665 .79089 L .57458 .80743 L p .504 .664 .933 r
F P
0 g
s
.50133 .77617 m .46915 .76455 L .47286 .74995 L p .518 .632 .902 r
F P
0 g
s
.46915 .76455 m .43816 .7501 L .44551 .73624 L p .538 .626 .886 r
F P
0 g
s
.44551 .73624 m .47286 .74995 L .46915 .76455 L p .538 .626 .886 r
F P
0 g
s
.43816 .7501 m .40905 .73289 L .4199 .72012 L p .559 .622 .871 r
F P
0 g
s
.4199 .72012 m .44551 .73624 L .43816 .7501 L p .559 .622 .871 r
F P
0 g
s
.65365 .37384 m .65764 .37823 L .64235 .37947 L p .439 .862 .945 r
F P
0 g
s
.64235 .37947 m .63914 .377 L .65365 .37384 L p .439 .862 .945 r
F P
0 g
s
.59072 .37933 m .59181 .38505 L .59578 .38486 L p .607 .237 .316 r
F P
0 g
s
.59181 .38505 m .59072 .37933 L .58735 .37803 L p .701 .361 .397 r
F P
0 g
s
.43246 .63009 m .44868 .62602 L .44287 .63518 L p .743 .932 .95 r
F P
0 g
s
.44287 .63518 m .42437 .63818 L .43246 .63009 L p .743 .932 .95 r
F P
0 g
s
.67773 .43979 m .67406 .46416 L .6558 .46104 L p .723 .675 .803 r
F P
0 g
s
.67406 .46416 m .67773 .43979 L .69899 .44075 L p .717 .681 .813 r
F P
0 g
s
.61124 .49226 m .62003 .4739 L .63342 .47832 L p .763 .705 .797 r
F P
0 g
s
.63996 .45807 m .63342 .47832 L .62003 .4739 L p .751 .686 .789 r
F P
0 g
s
.63342 .47832 m .63996 .45807 L .6558 .46104 L p .743 .688 .799 r
F P
0 g
s
.58969 .50349 m .60008 .48681 L .61124 .49226 L p .783 .724 .798 r
F P
0 g
s
.62003 .4739 m .61124 .49226 L .60008 .48681 L p .773 .705 .788 r
F P
0 g
s
.67065 .37003 m .67546 .37658 L .65764 .37823 L p .526 .878 .985 r
F P
0 g
s
.65764 .37823 m .65365 .37384 L .67065 .37003 L p .526 .878 .985 r
F P
0 g
s
.52833 .55425 m .54264 .5412 L .54906 .54915 L p .82 .795 .828 r
F P
0 g
s
.54906 .54915 m .53346 .56242 L .52833 .55425 L p .82 .795 .828 r
F P
0 g
s
.56386 .53482 m .54906 .54915 L .54264 .5412 L p .813 .777 .819 r
F P
0 g
s
.45333 .61791 m .46903 .61149 L .46647 .62038 L p .795 .927 .922 r
F P
0 g
s
.46647 .62038 m .44868 .62602 L .45333 .61791 L p .795 .927 .922 r
F P
0 g
s
.54264 .5412 m .55632 .52728 L .56386 .53482 L p .813 .777 .819 r
F P
0 g
s
.57752 .51955 m .56386 .53482 L .55632 .52728 L p .807 .76 .81 r
F P
0 g
s
.58735 .37803 m .58917 .3848 L .59181 .38505 L p .701 .361 .397 r
F P
0 g
s
.57053 .34932 m .57909 .35844 L .5786 .36254 L p .308 .391 .785 r
F P
0 g
s
.57909 .35844 m .57053 .34932 L .57096 .34373 L p .412 .45 .789 r
F P
0 g
s
.55989 .33479 m .57096 .34373 L .57053 .34932 L p .374 .462 .822 r
F P
0 g
s
.57096 .34373 m .55989 .33479 L .55988 .32772 L p .438 .497 .823 r
F P
0 g
s
.54637 .31927 m .55988 .32772 L .55989 .33479 L p .412 .51 .849 r
F P
0 g
s
.51373 .56637 m .52833 .55425 L .53346 .56242 L p .828 .815 .837 r
F P
0 g
s
.53346 .56242 m .51746 .57455 L .51373 .56637 L p .828 .815 .837 r
F P
0 g
s
.53402 .78494 m .50133 .77617 L .50134 .76116 L p .499 .64 .918 r
F P
0 g
s
.47286 .74995 m .50134 .76116 L .50133 .77617 L p .518 .632 .902 r
F P
0 g
s
.55632 .52728 m .56904 .51263 L .57752 .51955 L p .807 .76 .81 r
F P
0 g
s
.58969 .50349 m .57752 .51955 L .56904 .51263 L p .8 .744 .801 r
F P
0 g
s
.5786 .36254 m .5846 .37158 L .58431 .37419 L p .177 .266 .718 r
F P
0 g
s
.5846 .37158 m .5786 .36254 L .57909 .35844 L p .382 .388 .741 r
F P
0 g
s
.69047 .36551 m .69614 .3745 L .67546 .37658 L p .576 .872 .995 r
F P
0 g
s
.67546 .37658 m .67065 .37003 L .69047 .36551 L p .576 .872 .995 r
F P
0 g
s
.408 .63955 m .42437 .63818 L .41472 .64739 L p .687 .918 .972 r
F P
0 g
s
.41472 .64739 m .39595 .64736 L .408 .63955 L p .687 .918 .972 r
F P
0 g
s
.40905 .73289 m .38247 .71306 L .3966 .7017 L p .58 .621 .857 r
F P
0 g
s
.3966 .7017 m .4199 .72012 L .40905 .73289 L p .58 .621 .857 r
F P
0 g
s
.55988 .32772 m .54637 .31927 L .54548 .31074 L p .457 .535 .849 r
F P
0 g
s
.52967 .3032 m .54548 .31074 L .54637 .31927 L p .436 .546 .869 r
F P
0 g
s
.65932 .43874 m .6558 .46104 L .63996 .45807 L p .729 .671 .793 r
F P
0 g
s
.6558 .46104 m .65932 .43874 L .67773 .43979 L p .723 .675 .803 r
F P
0 g
s
.47077 .60356 m .48573 .59514 L .48584 .60364 L p .83 .903 .89 r
F P
0 g
s
.48584 .60364 m .46903 .61149 L .47077 .60356 L p .83 .903 .89 r
F P
0 g
s
.56904 .51263 m .58046 .49736 L .58969 .50349 L p .8 .744 .801 r
F P
0 g
s
.60008 .48681 m .58969 .50349 L .58046 .49736 L p .792 .726 .791 r
F P
0 g
s
.49919 .57747 m .51373 .56637 L .51746 .57455 L p .837 .839 .847 r
F P
0 g
s
.51746 .57455 m .50142 .58547 L .49919 .57747 L p .837 .839 .847 r
F P
0 g
s
.54548 .31074 m .52967 .3032 L .52735 .29327 L p .471 .566 .87 r
F P
0 g
s
.50944 .2871 m .52735 .29327 L .52967 .3032 L p .453 .576 .887 r
F P
0 g
s
.71349 .36017 m .72007 .37196 L .69614 .3745 L p .607 .858 .991 r
F P
0 g
s
.69614 .3745 m .69047 .36551 L .71349 .36017 L p .607 .858 .991 r
F P
0 g
s
.58431 .37419 m .58774 .38299 L .58783 .38412 L p 0 0 .501 r
F P
0 g
s
.60008 .48681 m .60841 .46969 L .62003 .4739 L p .773 .705 .788 r
F P
0 g
s
.62626 .45518 m .62003 .4739 L .60841 .46969 L p .761 .685 .779 r
F P
0 g
s
.62003 .4739 m .62626 .45518 L .63996 .45807 L p .751 .686 .789 r
F P
0 g
s
.33933 .7018 m .31661 .67515 L .33933 .66636 L p .627 .64 .843 r
F P
0 g
s
.33933 .66636 m .35904 .69081 L .33933 .7018 L p .627 .64 .843 r
F P
0 g
s
.8199 .40382 m .82086 .44419 L .78386 .44336 L p .692 .691 .844 r
F P
0 g
s
.52735 .29327 m .50944 .2871 L .50508 .2759 L p .483 .593 .888 r
F P
0 g
s
.48541 .27163 m .50508 .2759 L .50944 .2871 L p .467 .603 .903 r
F P
0 g
s
.57909 .35844 m .5861 .36844 L .5846 .37158 L p .382 .388 .741 r
F P
0 g
s
.5861 .36844 m .57909 .35844 L .58069 .35372 L p .472 .451 .753 r
F P
0 g
s
.57096 .34373 m .58069 .35372 L .57909 .35844 L p .412 .45 .789 r
F P
0 g
s
.58046 .49736 m .59033 .48163 L .60008 .48681 L p .792 .726 .791 r
F P
0 g
s
.60841 .46969 m .60008 .48681 L .59033 .48163 L p .784 .708 .78 r
F P
0 g
s
.64342 .4376 m .63996 .45807 L .62626 .45518 L p .737 .667 .781 r
F P
0 g
s
.63996 .45807 m .64342 .4376 L .65932 .43874 L p .729 .671 .793 r
F P
0 g
s
.58069 .35372 m .57096 .34373 L .57235 .3374 L p .474 .491 .795 r
F P
0 g
s
.55988 .32772 m .57235 .3374 L .57096 .34373 L p .438 .497 .823 r
F P
0 g
s
.74017 .35393 m .74769 .36889 L .72007 .37196 L p .626 .843 .983 r
F P
0 g
s
.72007 .37196 m .71349 .36017 L .74017 .35393 L p .626 .843 .983 r
F P
0 g
s
.78283 .40706 m .78386 .44336 L .75159 .44253 L p .695 .686 .837 r
F P
0 g
s
.78386 .44336 m .78283 .40706 L .8199 .40382 L p .692 .691 .844 r
F P
0 g
s
.45741 .25757 m .47834 .25934 L .48541 .27163 L p .48 .629 .918 r
F P
0 g
s
.47834 .25934 m .45741 .25757 L .44691 .24448 L p .506 .643 .917 r
F P
0 g
s
.50508 .2759 m .48541 .27163 L .47834 .25934 L p .494 .619 .903 r
F P
0 g
s
.5846 .37158 m .58892 .38139 L .58774 .38299 L p .376 .323 .671 r
F P
0 g
s
.58892 .38139 m .5846 .37158 L .5861 .36844 L p .497 .419 .698 r
F P
0 g
s
.48507 .58751 m .49919 .57747 L .50142 .58547 L p .845 .868 .859 r
F P
0 g
s
.50142 .58547 m .48573 .59514 L .48507 .58751 L p .845 .868 .859 r
F P
0 g
s
.7506 .40979 m .75159 .44253 L .72346 .44166 L p .697 .68 .829 r
F P
0 g
s
.75159 .44253 m .7506 .40979 L .78283 .40706 L p .695 .686 .837 r
F P
0 g
s
.59478 .39092 m .59142 .39194 L p .59142 .39061 L .619 .48 .67 r
F P
0 g
s
.59287 .38987 m .59478 .39092 L .59142 .39061 L .619 .48 .67 r
F
.59181 .38505 m .59111 .39061 L p .59369 .38913 L .409 .1 .326 r
F P
0 g
s
.59111 .39061 m .59109 .39078 L p .59369 .38913 L .409 .1 .326 r
F P
0 g
s
.59181 .38505 m .58917 .3848 L p .59072 .39039 L .458 .206 .444 r
F P
0 g
s
.59111 .39061 m .59142 .39194 L p .58935 .39162 L .616 .45 .634 r
F P
0 g
s
.59101 .39141 m .59111 .39061 L p .59072 .39039 L .458 .206 .444 r
F P
0 g
s
.59111 .39061 m .59181 .38505 L p .59072 .39039 L .458 .206 .444 r
F P
0 g
s
.59072 .39039 m .59111 .39061 L .58935 .39148 L .616 .45 .634 r
F
.58918 .3913 m .58939 .39249 L p .58861 .39215 L .651 .439 .584 r
F P
0 g
s
.58865 .39259 m .58918 .39223 L p .58891 .3906 L .417 .234 .522 r
F P
0 g
s
.58783 .38412 m .58865 .39259 L p .58891 .3906 L .417 .234 .522 r
F P
0 g
s
.58861 .39215 m .5887 .39219 L .58865 .39259 L .651 .439 .584 r
F
.58939 .39249 m .58865 .39259 L p .5887 .39219 L F P
0 g
s
.58917 .3848 m .58783 .38412 L p .58877 .38978 L .417 .234 .522 r
F P
0 g
s
.58877 .38978 m .58892 .39034 L .58917 .3848 L .417 .234 .522 r
F
.58918 .3913 m .58917 .3848 L p .58891 .3906 L F P
0 g
s
.59045 .38941 m .58929 .39142 L .59072 .39039 L .458 .206 .444 r
F
.58917 .3848 m .58918 .3913 L p .59045 .38941 L F P
0 g
s
.58918 .3913 m .58774 .38299 L p .58926 .39138 L .616 .45 .634 r
F P
0 g
s
.58937 .39199 m .58918 .3913 L .58926 .39138 L .616 .45 .634 r
F
.58939 .39249 m .58918 .3913 L p .58937 .39199 L F P
0 g
s
.58918 .3913 m .58918 .39161 L p .58929 .39142 L .458 .206 .444 r
F P
0 g
s
.58918 .3913 m .58929 .39142 L .59045 .38941 L .458 .206 .444 r
F
.58929 .39142 m .58918 .39161 L .58935 .39148 L F
.58929 .39142 m .58935 .39148 L .59072 .39039 L F
.58774 .38299 m .58892 .38139 L p .58935 .39148 L .616 .45 .634 r
F P
0 g
s
.58935 .39148 m .58937 .39199 L .58926 .39138 L .616 .45 .634 r
F
.58935 .39148 m .58926 .39138 L .58774 .38299 L F
.58877 .38978 m .58891 .3906 L .58892 .39034 L .417 .234 .522 r
F
.58831 .38908 m .58918 .3913 L .58861 .39215 L .651 .439 .584 r
F
.58918 .39223 m .58918 .3913 L p .58891 .3906 L .417 .234 .522 r
F P
0 g
s
.58774 .38299 m .58918 .3913 L p .58831 .38908 L .651 .439 .584 r
F P
0 g
s
.58918 .39223 m .59101 .39141 L p .59072 .39039 L .458 .206 .444 r
F P
0 g
s
.58935 .39148 m .59111 .39061 L .58935 .39162 L .616 .45 .634 r
F
.58918 .39161 m .58918 .39223 L p .59072 .39039 L .458 .206 .444 r
F P
0 g
s
.58926 .38954 m .59072 .39039 L .58935 .39148 L .616 .45 .634 r
F
.58892 .38139 m .59111 .39061 L p .58926 .38954 L F P
0 g
s
.58892 .38139 m .59138 .37928 L p .59142 .39061 L .619 .48 .67 r
F P
0 g
s
.59142 .39194 m .59111 .39061 L p .59142 .39061 L .619 .48 .67 r
F P
0 g
s
.59111 .39061 m .58892 .38139 L p .59142 .39061 L .619 .48 .67 r
F P
0 g
s
.59369 .38913 m .59135 .39061 L .59381 .38939 L .409 .1 .326 r
F
.59135 .39061 m .59109 .39078 L .59142 .39061 L F
.59135 .39061 m .59142 .39061 L .59381 .38939 L F
.59142 .39194 m .58939 .39249 L p .58935 .39162 L .616 .45 .634 r
F P
0 g
s
.59436 .38946 m .59478 .39092 L p .59312 .39001 L .619 .48 .67 r
F P
0 g
s
.59436 .38946 m .59312 .39001 L .59141 .38908 L .619 .48 .67 r
F
.59578 .38486 m .59436 .38946 L p .59819 .38774 L .316 0 .154 r
F P
0 g
s
.59436 .38946 m .59483 .38934 L .59819 .38774 L .316 0 .154 r
F
.59827 .38784 m .59954 .38942 L .59483 .38934 L .626 .509 .7 r
F
.59899 .38781 m .60115 .38423 L p .59832 .38778 L .316 0 .154 r
F P
0 g
s
.59827 .38784 m .59899 .38781 L .59832 .38778 L .316 0 .154 r
F
.60115 .38423 m .59578 .38486 L p .59827 .38784 L F P
0 g
s
.59954 .38942 m .59899 .38781 L p .59962 .38784 L .632 .534 .725 r
F P
0 g
s
.59899 .38781 m .59954 .38942 L p .59827 .38784 L .626 .509 .7 r
F P
0 g
s
.60577 .3874 m .59954 .38942 L p .59963 .3876 L .632 .534 .725 r
F P
0 g
s
.60115 .38423 m .59899 .38781 L p .59963 .3876 L .166 0 0 r
F P
0 g
s
.60115 .38423 m .59963 .3876 L .60419 .38576 L .166 0 0 r
F
.60803 .38316 m .60115 .38423 L p .60414 .38573 L F P
0 g
s
.60414 .38573 m .60425 .38572 L .60803 .38316 L .166 0 0 r
F
.6051 .38565 m .60803 .38316 L p .60419 .38576 L F P
0 g
s
.60577 .3874 m .6051 .38565 L p .60591 .38557 L .638 .556 .745 r
F P
0 g
s
.60803 .38316 m .6051 .38565 L p .60593 .38534 L 0 0 0 r
F P
0 g
s
.61168 .38311 m .61361 .38483 L .60593 .38534 L .638 .556 .745 r
F
.61279 .38291 m .61654 .38162 L p .61175 .38309 L 0 0 0 r
F P
0 g
s
.61168 .38311 m .61279 .38291 L .61175 .38309 L 0 0 0 r
F
.61654 .38162 m .60803 .38316 L p .61168 .38311 L F P
0 g
s
.60709 .36951 m .61545 .36489 L p .61382 .38252 L .643 .575 .763 r
F P
0 g
s
.61382 .38252 m .61371 .38256 L .60709 .36951 L .643 .575 .763 r
F
.61654 .38162 m .61279 .38291 L p .61382 .38252 L .269 .76 .681 r
F P
0 g
s
.61545 .36489 m .62213 .37936 L p .61382 .38252 L .643 .575 .763 r
F P
0 g
s
.62088 .37984 m .61382 .38252 L .62131 .37966 L .269 .76 .681 r
F
.61654 .38162 m .61382 .38252 L .62088 .37984 L F
.62319 .38166 m .61361 .38483 L p .61382 .38252 L .643 .575 .763 r
F P
0 g
s
.62685 .37957 m .61654 .38162 L p .62088 .37984 L .269 .76 .681 r
F P
0 g
s
.62213 .37936 m .62222 .37956 L p .62088 .37984 L .643 .575 .763 r
F P
0 g
s
.62156 .37956 m .62222 .37956 L p .62088 .37984 L .269 .76 .681 r
F P
0 g
s
.61545 .36489 m .6256 .35945 L p .62348 .37907 L .647 .592 .779 r
F P
0 g
s
.62348 .37907 m .62335 .37912 L .61545 .36489 L .647 .592 .779 r
F
.62685 .37957 m .62222 .37956 L p .62348 .37907 L .439 .877 .864 r
F P
0 g
s
.6256 .35945 m .63347 .37533 L p .63197 .37589 L .647 .592 .779 r
F P
0 g
s
.62362 .37777 m .63197 .37589 L .62348 .37907 L .647 .592 .779 r
F
.6256 .35945 m .63197 .37589 L .62362 .37777 L F
.6256 .35945 m .63777 .35308 L p .63507 .37494 L .651 .608 .793 r
F P
0 g
s
.63507 .37494 m .63493 .37499 L .6256 .35945 L .651 .608 .793 r
F
.63914 .377 m .63357 .37553 L p .63507 .37494 L .542 .913 .949 r
F P
0 g
s
.63777 .35308 m .64695 .37054 L p .64517 .37119 L .651 .608 .793 r
F P
0 g
s
.63524 .37357 m .64517 .37119 L .63507 .37494 L .651 .608 .793 r
F
.63777 .35308 m .64517 .37119 L .63524 .37357 L F
.63777 .35308 m .65218 .34567 L p .64883 .37003 L .653 .621 .805 r
F P
0 g
s
.64883 .37003 m .64867 .37009 L .63777 .35308 L .653 .621 .805 r
F
.65365 .37384 m .64705 .37074 L p .64883 .37003 L .598 .91 .98 r
F P
0 g
s
.65218 .34567 m .66282 .36489 L p .66073 .36565 L .653 .621 .805 r
F P
0 g
s
.64903 .36857 m .66073 .36565 L .64883 .37003 L .653 .621 .805 r
F
.65218 .34567 m .66073 .36565 L .64903 .36857 L F
.65218 .34567 m .66913 .33705 L p .66502 .36426 L .656 .634 .816 r
F P
0 g
s
.66502 .36426 m .66485 .36433 L .65218 .34567 L .656 .634 .816 r
F
.67065 .37003 m .66294 .3651 L p .66502 .36426 L .629 .893 .987 r
F P
0 g
s
.66913 .33705 m .6814 .35827 L p .67896 .35916 L .656 .634 .816 r
F P
0 g
s
.66526 .36268 m .67896 .35916 L .66502 .36426 L .656 .634 .816 r
F
.66913 .33705 m .67896 .35916 L .66526 .36268 L F
.66913 .33705 m .68897 .32705 L p .68397 .3575 L .658 .645 .825 r
F P
0 g
s
.68397 .3575 m .68377 .35758 L .66913 .33705 L .658 .645 .825 r
F
.69047 .36551 m .68153 .3585 L p .68397 .3575 L .646 .874 .983 r
F P
0 g
s
.68897 .32705 m .70306 .35055 L p .70022 .35159 L .658 .645 .825 r
F P
0 g
s
.68425 .35579 m .70022 .35159 L .68397 .3575 L .658 .645 .825 r
F
.68897 .32705 m .70022 .35159 L .68425 .35579 L F
.71349 .36017 m .69047 .36551 L p .70022 .35159 L .646 .874 .983 r
F P
0 g
s
.70321 .3508 m .71349 .36017 L p .70035 .35167 L .646 .874 .983 r
F P
0 g
s
.70022 .35159 m .70321 .3508 L .70035 .35167 L .646 .874 .983 r
F
.68897 .32705 m .71212 .31547 L p .70605 .34963 L .66 .655 .834 r
F P
0 g
s
.70605 .34963 m .70582 .34973 L .68897 .32705 L .66 .655 .834 r
F
.71349 .36017 m .70321 .3508 L p .70605 .34963 L .656 .855 .976 r
F P
0 g
s
.71212 .31547 m .72824 .34158 L p .72494 .34278 L .66 .655 .834 r
F P
0 g
s
.70638 .34775 m .72494 .34278 L .70605 .34963 L .66 .655 .834 r
F
.71212 .31547 m .72494 .34278 L .70638 .34775 L F
.74017 .35393 m .71349 .36017 L p .72494 .34278 L .656 .855 .976 r
F P
0 g
s
.7284 .34185 m .74017 .35393 L p .72509 .34289 L .656 .855 .976 r
F P
0 g
s
.72494 .34278 m .7284 .34185 L .72509 .34289 L .656 .855 .976 r
F
.71212 .31547 m .73906 .30206 L p .73171 .34049 L .661 .663 .841 r
F P
0 g
s
.73171 .34049 m .73145 .34059 L .71212 .31547 L .661 .663 .841 r
F
.74017 .35393 m .7284 .34185 L p .73171 .34049 L .662 .838 .968 r
F P
0 g
s
.73906 .30206 m .75746 .33117 L p .75363 .33256 L .661 .663 .841 r
F P
0 g
s
.7321 .33841 m .75363 .33256 L .73171 .34049 L .661 .663 .841 r
F
.73906 .30206 m .75363 .33256 L .7321 .33841 L F
.77102 .34665 m .74017 .35393 L p .75363 .33256 L .662 .838 .968 r
F P
0 g
s
.75764 .33147 m .77102 .34665 L p .7538 .33269 L .662 .838 .968 r
F P
0 g
s
.75363 .33256 m .75764 .33147 L .7538 .33269 L .662 .838 .968 r
F
.73906 .30206 m .7704 .28651 L p .76148 .32988 L .663 .671 .848 r
F P
0 g
s
.76148 .32988 m .76119 .33 L .73906 .30206 L .663 .671 .848 r
F
.77102 .34665 m .75764 .33147 L p .76148 .32988 L .666 .824 .959 r
F P
0 g
s
.7704 .28651 m .79133 .3191 L p .78689 .3207 L .663 .671 .848 r
F P
0 g
s
.76195 .32756 m .78689 .3207 L .76148 .32988 L .663 .671 .848 r
F
.7704 .28651 m .78689 .3207 L .76195 .32756 L F
.80668 .33819 m .77102 .34665 L p .78689 .3207 L .666 .824 .959 r
F P
0 g
s
.79154 .31943 m .80668 .33819 L p .78689 .3207 L .666 .824 .959 r
F P
0 g
s
.77102 .34665 m .76148 .32988 L .78689 .3207 L .666 .824 .959 r
F
.79133 .3191 m .79454 .32411 L p .76148 .32988 L .663 .671 .848 r
F P
0 g
s
.78934 .3167 m .79154 .31943 L p .78689 .3207 L .666 .824 .959 r
F P
0 g
s
.78689 .3207 m .76148 .32988 L .78798 .31892 L .666 .824 .959 r
F
.79454 .32411 m .76029 .33565 L p .76148 .32988 L .663 .671 .848 r
F P
0 g
s
.75764 .33147 m .73906 .30206 L p .7614 .33027 L .663 .671 .848 r
F P
0 g
s
.7557 .32926 m .78934 .3167 L p .78798 .31892 L .666 .824 .959 r
F P
0 g
s
.74017 .35393 m .73171 .34049 L .75363 .33256 L .662 .838 .968 r
F
.75746 .33117 m .75764 .33147 L p .73171 .34049 L .661 .663 .841 r
F P
0 g
s
.75764 .33147 m .76029 .33565 L p .73335 .34021 L .661 .663 .841 r
F P
0 g
s
.75764 .33147 m .73335 .34021 L .73171 .34049 L .661 .663 .841 r
F
.75764 .33147 m .7557 .32926 L p .78798 .31892 L .666 .824 .959 r
F P
0 g
s
.76148 .32988 m .7614 .33027 L .76119 .33 L .663 .671 .848 r
F
.76029 .33565 m .75764 .33147 L p .7614 .33027 L F P
0 g
s
.7557 .32926 m .75764 .33147 L p .75363 .33256 L .662 .838 .968 r
F P
0 g
s
.75363 .33256 m .73171 .34049 L .75457 .33107 L .662 .838 .968 r
F
.76029 .33565 m .73073 .34561 L p .73171 .34049 L .661 .663 .841 r
F P
0 g
s
.7284 .34185 m .71212 .31547 L p .73164 .34084 L .661 .663 .841 r
F P
0 g
s
.7267 .3401 m .7557 .32926 L p .75457 .33107 L .662 .838 .968 r
F P
0 g
s
.71349 .36017 m .70605 .34963 L .72494 .34278 L .656 .855 .976 r
F
.72824 .34158 m .7284 .34185 L p .70605 .34963 L .66 .655 .834 r
F P
0 g
s
.7284 .34185 m .73073 .34561 L p .70748 .3494 L .66 .655 .834 r
F P
0 g
s
.7284 .34185 m .70748 .3494 L .70605 .34963 L .66 .655 .834 r
F
.7284 .34185 m .7267 .3401 L p .75457 .33107 L .662 .838 .968 r
F P
0 g
s
.73171 .34049 m .73164 .34084 L .73145 .34059 L .661 .663 .841 r
F
.73073 .34561 m .7284 .34185 L p .73164 .34084 L F P
0 g
s
.7267 .3401 m .7284 .34185 L p .72494 .34278 L .656 .855 .976 r
F P
0 g
s
.72494 .34278 m .70605 .34963 L .72575 .34155 L .656 .855 .976 r
F
.73073 .34561 m .70524 .35419 L p .70605 .34963 L .66 .655 .834 r
F P
0 g
s
.70321 .3508 m .68897 .32705 L p .70599 .34995 L .66 .655 .834 r
F P
0 g
s
.70172 .34945 m .7267 .3401 L p .72575 .34155 L .656 .855 .976 r
F P
0 g
s
.69047 .36551 m .68397 .3575 L .70022 .35159 L .646 .874 .983 r
F
.70306 .35055 m .70321 .3508 L p .68397 .3575 L .658 .645 .825 r
F P
0 g
s
.70321 .3508 m .70524 .35419 L p .68522 .35731 L .658 .645 .825 r
F P
0 g
s
.70321 .3508 m .68522 .35731 L .68397 .3575 L .658 .645 .825 r
F
.70321 .3508 m .70172 .34945 L p .72575 .34155 L .656 .855 .976 r
F P
0 g
s
.70605 .34963 m .70599 .34995 L .70582 .34973 L .66 .655 .834 r
F
.70524 .35419 m .70321 .3508 L p .70599 .34995 L F P
0 g
s
.70172 .34945 m .70321 .3508 L p .70022 .35159 L .646 .874 .983 r
F P
0 g
s
.70022 .35159 m .68397 .3575 L .70092 .35058 L .646 .874 .983 r
F
.67886 .35929 m .67908 .35923 L .69047 .36551 L .629 .893 .987 r
F
.68153 .3585 m .69047 .36551 L p .67896 .35916 L F P
0 g
s
.70524 .35419 m .6833 .36156 L p .68397 .3575 L .658 .645 .825 r
F P
0 g
s
.68153 .3585 m .66913 .33705 L p .68392 .35779 L .658 .645 .825 r
F P
0 g
s
.68024 .35749 m .70172 .34945 L p .70092 .35058 L .646 .874 .983 r
F P
0 g
s
.69047 .36551 m .67065 .37003 L p .67886 .35929 L .629 .893 .987 r
F P
0 g
s
.67886 .35929 m .67896 .35916 L .67908 .35923 L .629 .893 .987 r
F
.67065 .37003 m .66502 .36426 L .67896 .35916 L F
.6814 .35827 m .6833 .36156 L p .66502 .36426 L .656 .634 .816 r
F P
0 g
s
.68153 .3585 m .68024 .35749 L p .70092 .35058 L .646 .874 .983 r
F P
0 g
s
.68397 .3575 m .68392 .35779 L .68377 .35758 L .658 .645 .825 r
F
.6833 .36156 m .68153 .3585 L p .68392 .35779 L F P
0 g
s
.68024 .35749 m .68153 .3585 L p .67896 .35916 L .629 .893 .987 r
F P
0 g
s
.67896 .35916 m .66502 .36426 L .67958 .35835 L .629 .893 .987 r
F
.67065 .37003 m .65365 .37384 L p .66064 .36575 L .598 .91 .98 r
F P
0 g
s
.66064 .36575 m .66084 .3657 L .67065 .37003 L .598 .91 .98 r
F
.66294 .3651 m .67065 .37003 L p .66073 .36565 L F P
0 g
s
.6833 .36156 m .66447 .36788 L p .66502 .36426 L .656 .634 .816 r
F P
0 g
s
.66294 .3651 m .65218 .34567 L p .66498 .36452 L .656 .634 .816 r
F P
0 g
s
.66182 .36439 m .68024 .35749 L p .67958 .35835 L .629 .893 .987 r
F P
0 g
s
.66294 .3651 m .66182 .36439 L p .67958 .35835 L .629 .893 .987 r
F P
0 g
s
.66502 .36426 m .66498 .36452 L .66485 .36433 L .656 .634 .816 r
F
.66447 .36788 m .66294 .3651 L p .66498 .36452 L F P
0 g
s
.66064 .36575 m .66073 .36565 L .66084 .3657 L .598 .91 .98 r
F
.66182 .36439 m .66294 .3651 L p .66073 .36565 L F P
0 g
s
.66073 .36565 m .64883 .37003 L .66128 .36501 L .598 .91 .98 r
F
.65365 .37384 m .64883 .37003 L .66073 .36565 L F
.65365 .37384 m .63914 .377 L p .64509 .37127 L .542 .913 .949 r
F P
0 g
s
.64509 .37127 m .64526 .37122 L .65365 .37384 L .542 .913 .949 r
F
.64705 .37074 m .65365 .37384 L p .64517 .37119 L F P
0 g
s
.66447 .36788 m .64838 .37327 L p .64883 .37003 L .653 .621 .805 r
F P
0 g
s
.66282 .36489 m .66447 .36788 L p .64883 .37003 L .653 .621 .805 r
F P
0 g
s
.64705 .37074 m .63777 .35308 L p .64879 .37028 L .653 .621 .805 r
F P
0 g
s
.6461 .3703 m .66182 .36439 L p .66128 .36501 L .598 .91 .98 r
F P
0 g
s
.64705 .37074 m .6461 .3703 L p .66128 .36501 L .598 .91 .98 r
F P
0 g
s
.64883 .37003 m .64879 .37028 L .64867 .37009 L .653 .621 .805 r
F
.64838 .37327 m .64705 .37074 L p .64879 .37028 L F P
0 g
s
.64509 .37127 m .64517 .37119 L .64526 .37122 L .542 .913 .949 r
F
.6461 .3703 m .64705 .37074 L p .64517 .37119 L F P
0 g
s
.64517 .37119 m .63507 .37494 L .64567 .37071 L .542 .913 .949 r
F
.63914 .377 m .63507 .37494 L .64517 .37119 L F
.63914 .377 m .62685 .37957 L p .6319 .37594 L .439 .877 .864 r
F P
0 g
s
.6319 .37594 m .63206 .3759 L .63914 .377 L .439 .877 .864 r
F
.63357 .37553 m .63914 .377 L p .63197 .37589 L F P
0 g
s
.64838 .37327 m .63471 .37783 L p .63507 .37494 L .651 .608 .793 r
F P
0 g
s
.64695 .37054 m .64838 .37327 L p .63507 .37494 L .651 .608 .793 r
F P
0 g
s
.63357 .37553 m .6256 .35945 L p .63504 .37517 L .651 .608 .793 r
F P
0 g
s
.63277 .37532 m .6461 .3703 L p .64567 .37071 L .542 .913 .949 r
F P
0 g
s
.63357 .37553 m .63277 .37532 L p .64567 .37071 L .542 .913 .949 r
F P
0 g
s
.63507 .37494 m .63504 .37517 L .63493 .37499 L .651 .608 .793 r
F
.63471 .37783 m .63357 .37553 L p .63504 .37517 L F P
0 g
s
.6319 .37594 m .63197 .37589 L .63206 .3759 L .439 .877 .864 r
F
.63277 .37532 m .63357 .37553 L p .63197 .37589 L F P
0 g
s
.63197 .37589 m .62348 .37907 L .63243 .37556 L .439 .877 .864 r
F
.62685 .37957 m .62348 .37907 L .63197 .37589 L F
.62222 .37956 m .62685 .37957 L p .62096 .37983 L .269 .76 .681 r
F P
0 g
s
.63471 .37783 m .62319 .38166 L p .62348 .37907 L .647 .592 .779 r
F P
0 g
s
.63347 .37533 m .63471 .37783 L p .62348 .37907 L .647 .592 .779 r
F P
0 g
s
.62222 .37956 m .61545 .36489 L p .62345 .3793 L .647 .592 .779 r
F P
0 g
s
.62156 .37956 m .63277 .37532 L p .63243 .37556 L .439 .877 .864 r
F P
0 g
s
.62222 .37956 m .62156 .37956 L p .63243 .37556 L .439 .877 .864 r
F P
0 g
s
.62348 .37907 m .62345 .3793 L .62335 .37912 L .647 .592 .779 r
F
.62319 .38166 m .62222 .37956 L p .62345 .3793 L F P
0 g
s
.62088 .37984 m .62222 .37956 L .62096 .37983 L .269 .76 .681 r
F
.62088 .37984 m .62319 .38166 L .61382 .38252 L .643 .575 .763 r
F
.62222 .37956 m .62319 .38166 L p .62088 .37984 L F P
0 g
s
.61279 .38291 m .60709 .36951 L p .6138 .38274 L .643 .575 .763 r
F P
0 g
s
.61225 .3831 m .62156 .37956 L p .62131 .37966 L .269 .76 .681 r
F P
0 g
s
.61279 .38291 m .61225 .3831 L p .62131 .37966 L .269 .76 .681 r
F P
0 g
s
.61382 .38252 m .6138 .38274 L .61371 .38256 L .643 .575 .763 r
F
.61361 .38483 m .61279 .38291 L p .6138 .38274 L F P
0 g
s
.61271 .38271 m .61279 .38291 L p .61168 .38311 L .638 .556 .745 r
F P
0 g
s
.61279 .38291 m .61361 .38483 L p .61168 .38311 L .638 .556 .745 r
F P
0 g
s
.61225 .3831 m .61279 .38291 L p .61168 .38311 L 0 0 0 r
F P
0 g
s
.61168 .38311 m .60593 .38534 L .61209 .3831 L 0 0 0 r
F
.60803 .38316 m .60593 .38534 L .61168 .38311 L F
.61361 .38483 m .60577 .3874 L p .60593 .38534 L .638 .556 .745 r
F P
0 g
s
.60709 .36951 m .61271 .38271 L p .60593 .38534 L .638 .556 .745 r
F P
0 g
s
.6051 .38565 m .60038 .3734 L p .60591 .38557 L .638 .556 .745 r
F P
0 g
s
.60501 .38543 m .60577 .3874 L p .59963 .3876 L .632 .534 .725 r
F P
0 g
s
.60468 .386 m .61225 .3831 L p .61209 .3831 L 0 0 0 r
F P
0 g
s
.60593 .38534 m .60591 .38557 L .60582 .38538 L .638 .556 .745 r
F
.6051 .38565 m .60468 .386 L p .61209 .3831 L 0 0 0 r
F P
0 g
s
.60038 .3734 m .60709 .36951 L p .60593 .38534 L .638 .556 .745 r
F P
0 g
s
.60593 .38534 m .60582 .38538 L .60038 .3734 L .638 .556 .745 r
F
.60414 .38573 m .60419 .38576 L .60425 .38572 L .166 0 0 r
F
.60468 .386 m .6051 .38565 L p .60419 .38576 L F P
0 g
s
.60038 .3734 m .60501 .38543 L p .60419 .38576 L .632 .534 .725 r
F P
0 g
s
.5997 .38633 m .60419 .38576 L .59963 .3876 L .632 .534 .725 r
F
.60038 .3734 m .60419 .38576 L .5997 .38633 L F
.60419 .38576 m .59963 .3876 L .6046 .38597 L .166 0 0 r
F
.59868 .38833 m .60468 .386 L p .6046 .38597 L F P
0 g
s
.59963 .3876 m .59962 .38784 L .59954 .38763 L .632 .534 .725 r
F
.59899 .38781 m .59518 .37664 L p .59962 .38784 L F P
0 g
s
.59899 .38781 m .59868 .38833 L p .6046 .38597 L .166 0 0 r
F P
0 g
s
.59518 .37664 m .60038 .3734 L p .59963 .3876 L .632 .534 .725 r
F P
0 g
s
.59963 .3876 m .59954 .38763 L .59518 .37664 L .632 .534 .725 r
F
.59891 .38757 m .59899 .38781 L p .59827 .38784 L .626 .509 .7 r
F P
0 g
s
.59868 .38833 m .59899 .38781 L p .59827 .38784 L .316 0 .154 r
F P
0 g
s
.59483 .38934 m .59594 .38907 L .59726 .38828 L .316 0 .154 r
F
.59483 .38934 m .59726 .38828 L .59819 .38774 L F
.59954 .38942 m .59478 .39092 L p .59483 .38934 L .626 .509 .7 r
F P
0 g
s
.59578 .38486 m .59181 .38505 L p .59381 .38939 L .409 .1 .326 r
F P
0 g
s
.59436 .38946 m .59578 .38486 L p .59381 .38939 L .409 .1 .326 r
F P
0 g
s
.59518 .37664 m .59891 .38757 L p .59483 .38934 L .626 .509 .7 r
F P
0 g
s
.59138 .37928 m .59518 .37664 L p .59483 .38934 L .626 .509 .7 r
F P
0 g
s
.59478 .39092 m .59436 .38946 L p .59483 .38934 L .626 .509 .7 r
F P
0 g
s
.59436 .38946 m .59138 .37928 L p .59483 .38934 L .626 .509 .7 r
F P
0 g
s
.59436 .38946 m .59415 .39012 L p .59594 .38907 L .316 0 .154 r
F P
0 g
s
.59415 .39012 m .59868 .38833 L p .59819 .38774 L .316 0 .154 r
F P
0 g
s
.59101 .39141 m .59415 .39012 L p .59381 .38939 L .409 .1 .326 r
F P
0 g
s
.59109 .39078 m .59101 .39141 L p .59381 .38939 L .409 .1 .326 r
F P
0 g
s
.59141 .38908 m .59287 .38987 L .59142 .39061 L .619 .48 .67 r
F
.59138 .37928 m .59436 .38946 L p .59141 .38908 L F P
0 g
s
.59415 .39012 m .59436 .38946 L p .59381 .38939 L .409 .1 .326 r
F P
0 g
s
.57235 .3374 m .55988 .32772 L .56065 .31975 L p .482 .526 .826 r
F P
0 g
s
.54548 .31074 m .56065 .31975 L .55988 .32772 L p .457 .535 .849 r
F P
0 g
s
.5665 .79089 m .53402 .78494 L .53031 .76987 L p .48 .649 .933 r
F P
0 g
s
.50134 .76116 m .53031 .76987 L .53402 .78494 L p .499 .64 .918 r
F P
0 g
s
.72262 .41205 m .72346 .44166 L .69899 .44075 L p .7 .674 .821 r
F P
0 g
s
.72346 .44166 m .72262 .41205 L .7506 .40979 L p .697 .68 .829 r
F P
0 g
s
.53663 .53381 m .54943 .52023 L .55632 .52728 L p .821 .778 .812 r
F P
0 g
s
.55632 .52728 m .54264 .5412 L .53663 .53381 L p .821 .778 .812 r
F P
0 g
s
.56904 .51263 m .55632 .52728 L .54943 .52023 L p .815 .762 .804 r
F P
0 g
s
.38247 .71306 m .35904 .69081 L .37617 .68115 L p .601 .622 .845 r
F P
0 g
s
.37617 .68115 m .3966 .7017 L .38247 .71306 L p .601 .622 .845 r
F P
0 g
s
.58865 .39259 m .58783 .38412 L .58774 .38299 L p .651 .439 .584 r
F P
0 g
s
.54943 .52023 m .56142 .50609 L .56904 .51263 L p .815 .762 .804 r
F P
0 g
s
.58046 .49736 m .56904 .51263 L .56142 .50609 L p .809 .747 .794 r
F P
0 g
s
.52335 .54671 m .53663 .53381 L .54264 .5412 L p .828 .794 .819 r
F P
0 g
s
.54264 .5412 m .52833 .55425 L .52335 .54671 L p .828 .794 .819 r
F P
0 g
s
.59033 .48163 m .59837 .46561 L .60841 .46969 L p .784 .708 .78 r
F P
0 g
s
.61447 .45233 m .60841 .46969 L .59837 .46561 L p .772 .686 .769 r
F P
0 g
s
.60841 .46969 m .61447 .45233 L .62626 .45518 L p .761 .685 .779 r
F P
0 g
s
.62976 .43634 m .62626 .45518 L .61447 .45233 L p .746 .664 .77 r
F P
0 g
s
.62626 .45518 m .62976 .43634 L .64342 .4376 L p .737 .667 .781 r
F P
0 g
s
.69836 .41389 m .69899 .44075 L .67773 .43979 L p .704 .667 .811 r
F P
0 g
s
.69899 .44075 m .69836 .41389 L .72262 .41205 L p .7 .674 .821 r
F P
0 g
s
.77102 .34665 m .77952 .36524 L .74769 .36889 L p .638 .829 .974 r
F P
0 g
s
.74769 .36889 m .74017 .35393 L .77102 .34665 L p .638 .829 .974 r
F P
0 g
s
.56142 .50609 m .57231 .49151 L .58046 .49736 L p .809 .747 .794 r
F P
0 g
s
.59033 .48163 m .58046 .49736 L .57231 .49151 L p .803 .73 .784 r
F P
0 g
s
.5861 .36844 m .59138 .37928 L .58892 .38139 L p .497 .419 .698 r
F P
0 g
s
.59138 .37928 m .5861 .36844 L .58884 .36471 L p .548 .471 .721 r
F P
0 g
s
.58069 .35372 m .58884 .36471 L .5861 .36844 L p .472 .451 .753 r
F P
0 g
s
.45689 .61075 m .47077 .60356 L .46903 .61149 L p .817 .941 .908 r
F P
0 g
s
.46903 .61149 m .45333 .61791 L .45689 .61075 L p .817 .941 .908 r
F P
0 g
s
.5099 .55886 m .52335 .54671 L .52833 .55425 L p .836 .812 .827 r
F P
0 g
s
.52833 .55425 m .51373 .56637 L .5099 .55886 L p .836 .812 .827 r
F P
0 g
s
.67737 .41535 m .67773 .43979 L .65932 .43874 L p .708 .66 .8 r
F P
0 g
s
.67773 .43979 m .67737 .41535 L .69836 .41389 L p .704 .667 .811 r
F P
0 g
s
.66172 .82587 m .69689 .82097 L .72149 .83756 L p .517 .721 .965 r
F P
0 g
s
.69689 .82097 m .66172 .82587 L .64389 .80941 L p .492 .713 .969 r
F P
0 g
s
.61015 .80991 m .64389 .80941 L .66172 .82587 L p .501 .699 .958 r
F P
0 g
s
.58884 .36471 m .58069 .35372 L .58345 .34829 L p .521 .493 .766 r
F P
0 g
s
.57235 .3374 m .58345 .34829 L .58069 .35372 L p .474 .491 .795 r
F P
0 g
s
.56065 .31975 m .54548 .31074 L .5451 .30115 L p .491 .557 .851 r
F P
0 g
s
.52735 .29327 m .5451 .30115 L .54548 .31074 L p .471 .566 .87 r
F P
0 g
s
.65927 .41645 m .65932 .43874 L .64342 .4376 L p .713 .653 .789 r
F P
0 g
s
.65932 .43874 m .65927 .41645 L .67737 .41535 L p .708 .66 .8 r
F P
0 g
s
.57231 .49151 m .58183 .47662 L .59033 .48163 L p .803 .73 .784 r
F P
0 g
s
.59837 .46561 m .59033 .48163 L .58183 .47662 L p .796 .712 .772 r
F P
0 g
s
.59837 .46561 m .60438 .44946 L .61447 .45233 L p .772 .686 .769 r
F P
0 g
s
.61809 .43495 m .61447 .45233 L .60438 .44946 L p .757 .663 .757 r
F P
0 g
s
.61447 .45233 m .61809 .43495 L .62976 .43634 L p .746 .664 .77 r
F P
0 g
s
.64389 .80941 m .61015 .80991 L .59805 .79409 L p .475 .687 .96 r
F P
0 g
s
.5665 .79089 m .59805 .79409 L .61015 .80991 L p .489 .675 .947 r
F P
0 g
s
.4717 .59649 m .48507 .58751 L .48573 .59514 L p .85 .905 .873 r
F P
0 g
s
.48573 .59514 m .47077 .60356 L .4717 .59649 L p .85 .905 .873 r
F P
0 g
s
.64371 .4172 m .64342 .4376 L .62976 .43634 L p .719 .646 .776 r
F P
0 g
s
.64342 .4376 m .64371 .4172 L .65927 .41645 L p .713 .653 .789 r
F P
0 g
s
.58345 .34829 m .57235 .3374 L .57474 .33021 L p .514 .522 .802 r
F P
0 g
s
.56065 .31975 m .57474 .33021 L .57235 .3374 L p .482 .526 .826 r
F P
0 g
s
.49662 .57018 m .5099 .55886 L .51373 .56637 L p .846 .834 .834 r
F P
0 g
s
.51373 .56637 m .49919 .57747 L .49662 .57018 L p .846 .834 .834 r
F P
0 g
s
.58183 .47662 m .58973 .46158 L .59837 .46561 L p .796 .712 .772 r
F P
0 g
s
.60438 .44946 m .59837 .46561 L .58973 .46158 L p .786 .691 .759 r
F P
0 g
s
.80668 .33819 m .81618 .36095 L .77952 .36524 L p .646 .816 .965 r
F P
0 g
s
.77952 .36524 m .77102 .34665 L .80668 .33819 L p .646 .816 .965 r
F P
0 g
s
.75712 .82751 m .72149 .83756 L .69689 .82097 L p .513 .736 .974 r
F P
0 g
s
.58884 .36471 m .59518 .37664 L .59138 .37928 L p .548 .471 .721 r
F P
0 g
s
.5451 .30115 m .52735 .29327 L .5252 .28209 L p .499 .584 .871 r
F P
0 g
s
.50508 .2759 m .5252 .28209 L .52735 .29327 L p .483 .593 .888 r
F P
0 g
s
.63043 .41764 m .62976 .43634 L .61809 .43495 L p .727 .641 .762 r
F P
0 g
s
.62976 .43634 m .63043 .41764 L .64371 .4172 L p .719 .646 .776 r
F P
0 g
s
.59518 .37664 m .58884 .36471 L .59287 .36032 L p .576 .508 .741 r
F P
0 g
s
.58345 .34829 m .59287 .36032 L .58884 .36471 L p .521 .493 .766 r
F P
0 g
s
.58865 .39259 m .58789 .39953 L p .58736 .40035 L .969 .788 .357 r
F P
0 g
s
.58789 .39953 m .58766 .40173 L .58736 .40035 L p .969 .788 .357 r
F P
0 g
s
.58382 .40632 m .58643 .40179 L p .58736 .40035 L .961 .906 .54 r
F P
0 g
s
.58766 .40173 m .58865 .39259 L .58939 .39249 L p .868 .635 .583 r
F P
0 g
s
.58939 .39249 m .58921 .40267 L .58766 .40173 L p .868 .635 .583 r
F P
0 g
s
.58643 .40179 m .58832 .39849 L .58736 .40035 L p .961 .906 .54 r
F P
0 g
s
.58736 .40035 m .58918 .39223 L .58865 .39259 L p .969 .788 .357 r
F P
0 g
s
.47286 .74995 m .44551 .73624 L .4517 .72395 L p .519 .609 .882 r
F P
0 g
s
.44551 .73624 m .4199 .72012 L .42916 .70883 L p .543 .605 .865 r
F P
0 g
s
.42916 .70883 m .4517 .72395 L .44551 .73624 L p .543 .605 .865 r
F P
0 g
s
.58921 .40267 m .58939 .39249 L .59142 .39194 L p .757 .561 .632 r
F P
0 g
s
.58832 .39849 m .59101 .39141 L .58918 .39223 L p 0 0 .08 r
F P
0 g
s
.58766 .39903 m .58736 .40035 L .58832 .39849 L p 0 0 .08 r
F P
0 g
s
.58832 .39849 m .58382 .40632 L .58508 .40295 L p .807 .9 .491 r
F P
0 g
s
.58508 .40295 m .58928 .39771 L p .58832 .39849 L .807 .9 .491 r
F P
0 g
s
.58928 .39771 m .59056 .39613 L .58832 .39849 L p .807 .9 .491 r
F P
0 g
s
.58918 .39223 m .58766 .39903 L p .58832 .39849 L 0 0 .08 r
F P
0 g
s
.58973 .46158 m .59582 .44653 L .60438 .44946 L p .786 .691 .759 r
F P
0 g
s
.6082 .43339 m .60438 .44946 L .59582 .44653 L p .772 .665 .745 r
F P
0 g
s
.60438 .44946 m .6082 .43339 L .61809 .43495 L p .757 .663 .757 r
F P
0 g
s
.61917 .41776 m .61809 .43495 L .6082 .43339 L p .737 .637 .748 r
F P
0 g
s
.61809 .43495 m .61917 .41776 L .63043 .41764 L p .727 .641 .762 r
F P
0 g
s
.59142 .39194 m .59205 .40317 L .58921 .40267 L p .757 .561 .632 r
F P
0 g
s
.59205 .40317 m .59142 .39194 L .59478 .39092 L p .712 .549 .666 r
F P
0 g
s
.50134 .76116 m .47286 .74995 L .47585 .73695 L p .496 .615 .899 r
F P
0 g
s
.4517 .72395 m .47585 .73695 L .47286 .74995 L p .519 .609 .882 r
F P
0 g
s
.54306 .51355 m .55455 .49984 L .56142 .50609 L p .822 .764 .798 r
F P
0 g
s
.56142 .50609 m .54943 .52023 L .54306 .51355 L p .822 .764 .798 r
F P
0 g
s
.57231 .49151 m .56142 .50609 L .55455 .49984 L p .818 .751 .789 r
F P
0 g
s
.59056 .39613 m .59415 .39012 L .59101 .39141 L p 0 0 .072 r
F P
0 g
s
.59056 .39613 m .58508 .40295 L .58756 .39898 L p .704 .902 .54 r
F P
0 g
s
.58756 .39898 m .5931 .3941 L p .59056 .39613 L .704 .902 .54 r
F P
0 g
s
.5931 .3941 m .59412 .39321 L .59056 .39613 L p .704 .902 .54 r
F P
0 g
s
.59101 .39141 m .58864 .39766 L p .59056 .39613 L 0 0 .072 r
F P
0 g
s
.58864 .39766 m .58832 .39849 L .59056 .39613 L p 0 0 .072 r
F P
0 g
s
.57474 .33021 m .56065 .31975 L .5622 .31074 L p .515 .551 .83 r
F P
0 g
s
.5451 .30115 m .5622 .31074 L .56065 .31975 L p .491 .557 .851 r
F P
0 g
s
.59287 .36032 m .58345 .34829 L .5874 .34205 L p .553 .525 .779 r
F P
0 g
s
.57474 .33021 m .5874 .34205 L .58345 .34829 L p .514 .522 .802 r
F P
0 g
s
.53093 .52686 m .54306 .51355 L .54943 .52023 L p .827 .777 .805 r
F P
0 g
s
.54943 .52023 m .53663 .53381 L .53093 .52686 L p .827 .777 .805 r
F P
0 g
s
.25458 .61997 m .26966 .6536 L .23662 .66192 L p .663 .672 .848 r
F P
0 g
s
.25632 .65422 m .274 .66868 L .24169 .6778 L p .619 .818 .977 r
F P
0 g
s
.23662 .66192 m .21887 .62484 L .25458 .61997 L p .663 .672 .848 r
F P
0 g
s
.24169 .6778 m .22101 .65996 L .25632 .65422 L p .619 .818 .977 r
F P
0 g
s
.55455 .49984 m .5651 .48585 L .57231 .49151 L p .818 .751 .789 r
F P
0 g
s
.58183 .47662 m .57231 .49151 L .5651 .48585 L p .814 .737 .779 r
F P
0 g
s
.48382 .58062 m .49662 .57018 L .49919 .57747 L p .858 .863 .843 r
F P
0 g
s
.49919 .57747 m .48507 .58751 L .48382 .58062 L p .858 .863 .843 r
F P
0 g
s
.59287 .36032 m .60038 .3734 L .59518 .37664 L p .576 .508 .741 r
F P
0 g
s
.59478 .39092 m .59622 .40326 L .59205 .40317 L p .712 .549 .666 r
F P
0 g
s
.59622 .40326 m .59478 .39092 L .59954 .38942 L p .692 .555 .695 r
F P
0 g
s
.5651 .48585 m .57445 .4717 L .58183 .47662 L p .814 .737 .779 r
F P
0 g
s
.58973 .46158 m .58183 .47662 L .57445 .4717 L p .809 .72 .766 r
F P
0 g
s
.5252 .28209 m .50508 .2759 L .50046 .26325 L p .508 .609 .888 r
F P
0 g
s
.47834 .25934 m .50046 .26325 L .50508 .2759 L p .494 .619 .903 r
F P
0 g
s
.51845 .53968 m .53093 .52686 L .53663 .53381 L p .834 .791 .811 r
F P
0 g
s
.53663 .53381 m .52335 .54671 L .51845 .53968 L p .834 .791 .811 r
F P
0 g
s
.4199 .72012 m .3966 .7017 L .40876 .69169 L p .567 .604 .849 r
F P
0 g
s
.40876 .69169 m .42916 .70883 L .4199 .72012 L p .567 .604 .849 r
F P
0 g
s
.59582 .44653 m .59992 .43163 L .6082 .43339 L p .772 .665 .745 r
F P
0 g
s
.60973 .41756 m .6082 .43339 L .59992 .43163 L p .751 .636 .733 r
F P
0 g
s
.6082 .43339 m .60973 .41756 L .61917 .41776 L p .737 .637 .748 r
F P
0 g
s
.59412 .39321 m .59868 .38833 L .59415 .39012 L p 0 0 0 r
F P
0 g
s
.59415 .39012 m .59088 .39559 L p .59412 .39321 L 0 0 0 r
F P
0 g
s
.59868 .38833 m .59443 .39288 L p .59906 .38969 L 0 0 0 r
F P
0 g
s
.59443 .39288 m .59412 .39321 L .59906 .38969 L p 0 0 0 r
F P
0 g
s
.59906 .38969 m .60468 .386 L .59868 .38833 L p 0 0 0 r
F P
0 g
s
.59642 .38895 m .60475 .38577 L p .59906 .38969 L .701 .976 .776 r
F P
0 g
s
.60468 .386 m .59906 .38969 L .6055 .38549 L p 0 0 0 r
F P
0 g
s
.60475 .38577 m .6055 .38549 L .59906 .38969 L p .701 .976 .776 r
F P
0 g
s
.59131 .39434 m .5982 .3902 L p .59412 .39321 L .684 .94 .655 r
F P
0 g
s
.5982 .3902 m .59906 .38969 L .59412 .39321 L p .684 .94 .655 r
F P
0 g
s
.59088 .39559 m .59056 .39613 L .59412 .39321 L p 0 0 0 r
F P
0 g
s
.57445 .4717 m .58237 .45753 L .58973 .46158 L p .809 .72 .766 r
F P
0 g
s
.59582 .44653 m .58973 .46158 L .58237 .45753 L p .802 .699 .751 r
F P
0 g
s
.35904 .69081 m .33933 .66636 L .35911 .65869 L p .622 .626 .834 r
F P
0 g
s
.35911 .65869 m .37617 .68115 L .35904 .69081 L p .622 .626 .834 r
F P
0 g
s
.59954 .38942 m .60181 .40293 L .59622 .40326 L p .692 .555 .695 r
F P
0 g
s
.60181 .40293 m .59954 .38942 L .60577 .3874 L p .682 .567 .719 r
F P
0 g
s
.59805 .79409 m .5665 .79089 L .55914 .77611 L p .461 .661 .948 r
F P
0 g
s
.53031 .76987 m .55914 .77611 L .5665 .79089 L p .48 .649 .933 r
F P
0 g
s
.58237 .45753 m .58864 .44347 L .59582 .44653 L p .802 .699 .751 r
F P
0 g
s
.59992 .43163 m .59582 .44653 L .58864 .44347 L p .79 .673 .734 r
F P
0 g
s
.61767 .40098 m .61917 .41776 L .60973 .41756 L p .711 .609 .741 r
F P
0 g
s
.61917 .41776 m .61767 .40098 L .62823 .39933 L p .703 .617 .758 r
F P
0 g
s
.62823 .39933 m .63043 .41764 L .61917 .41776 L p .703 .617 .758 r
F P
0 g
s
.60038 .3734 m .59287 .36032 L .59828 .3552 L p .595 .536 .759 r
F P
0 g
s
.5874 .34205 m .59828 .3552 L .59287 .36032 L p .553 .525 .779 r
F P
0 g
s
.50593 .55191 m .51845 .53968 L .52335 .54671 L p .842 .807 .816 r
F P
0 g
s
.52335 .54671 m .5099 .55886 L .50593 .55191 L p .842 .807 .816 r
F P
0 g
s
.63043 .41764 m .62823 .39933 L .64079 .39718 L p .698 .627 .773 r
F P
0 g
s
.64079 .39718 m .64371 .4172 L .63043 .41764 L p .698 .627 .773 r
F P
0 g
s
.59077 .41503 m .59205 .40317 L .59622 .40326 L p .768 .608 .68 r
F P
0 g
s
.59622 .40326 m .59566 .41621 L .59077 .41503 L p .768 .608 .68 r
F P
0 g
s
.59566 .41621 m .59622 .40326 L .60181 .40293 L p .74 .6 .702 r
F P
0 g
s
.59992 .43163 m .60194 .41705 L .60973 .41756 L p .751 .636 .733 r
F P
0 g
s
.60892 .40218 m .60973 .41756 L .60194 .41705 L p .722 .602 .723 r
F P
0 g
s
.60973 .41756 m .60892 .40218 L .61767 .40098 L p .711 .609 .741 r
F P
0 g
s
.5872 .41348 m .58921 .40267 L .59205 .40317 L p .816 .636 .658 r
F P
0 g
s
.59205 .40317 m .59077 .41503 L .5872 .41348 L p .816 .636 .658 r
F P
0 g
s
.58864 .44347 m .59311 .42965 L .59992 .43163 L p .79 .673 .734 r
F P
0 g
s
.60194 .41705 m .59992 .43163 L .59311 .42965 L p .771 .64 .717 r
F P
0 g
s
.60181 .40293 m .60194 .41705 L .59566 .41621 L p .74 .6 .702 r
F P
0 g
s
.60194 .41705 m .60181 .40293 L .60892 .40218 L p .722 .602 .723 r
F P
0 g
s
.60577 .3874 m .60892 .40218 L .60181 .40293 L p .682 .567 .719 r
F P
0 g
s
.64371 .4172 m .64079 .39718 L .6556 .3945 L p .694 .636 .787 r
F P
0 g
s
.6556 .3945 m .65927 .41645 L .64371 .4172 L p .694 .636 .787 r
F P
0 g
s
.50046 .26325 m .47834 .25934 L .47048 .24544 L p .517 .632 .903 r
F P
0 g
s
.44691 .24448 m .47048 .24544 L .47834 .25934 L p .506 .643 .917 r
F P
0 g
s
.45941 .60441 m .4717 .59649 L .47077 .60356 L p .842 .949 .888 r
F P
0 g
s
.47077 .60356 m .45689 .61075 L .45941 .60441 L p .842 .949 .888 r
F P
0 g
s
.59311 .42965 m .59566 .41621 L .60194 .41705 L p .771 .64 .717 r
F P
0 g
s
.58487 .41154 m .58766 .40173 L .58921 .40267 L p .893 .701 .636 r
F P
0 g
s
.58921 .40267 m .5872 .41348 L .58487 .41154 L p .893 .701 .636 r
F P
0 g
s
.53031 .76987 m .50134 .76116 L .50106 .74778 L p .474 .623 .916 r
F P
0 g
s
.47585 .73695 m .50106 .74778 L .50134 .76116 L p .496 .615 .899 r
F P
0 g
s
.47048 .24544 m .44691 .24448 L .43501 .22964 L p .528 .655 .916 r
F P
0 g
s
.60892 .40218 m .60577 .3874 L .61361 .38483 L p .677 .581 .74 r
F P
0 g
s
.61361 .38483 m .61767 .40098 L .60892 .40218 L p .677 .581 .74 r
F P
0 g
s
.65927 .41645 m .6556 .3945 L .67293 .39124 L p .691 .645 .799 r
F P
0 g
s
.67293 .39124 m .67737 .41535 L .65927 .41645 L p .691 .645 .799 r
F P
0 g
s
.59828 .3552 m .60709 .36951 L .60038 .3734 L p .595 .536 .759 r
F P
0 g
s
.5874 .34205 m .57474 .33021 L .57819 .32201 L p .543 .548 .81 r
F P
0 g
s
.5622 .31074 m .57819 .32201 L .57474 .33021 L p .515 .551 .83 r
F P
0 g
s
.58764 .42741 m .59077 .41503 L .59566 .41621 L p .799 .654 .703 r
F P
0 g
s
.59566 .41621 m .59311 .42965 L .58764 .42741 L p .799 .654 .703 r
F P
0 g
s
.58375 .40917 m .58736 .40035 L .58766 .40173 L p .981 .815 .605 r
F P
0 g
s
.58766 .40173 m .58487 .41154 L .58375 .40917 L p .981 .815 .605 r
F P
0 g
s
.5622 .31074 m .5451 .30115 L .54521 .29029 L p .518 .577 .854 r
F P
0 g
s
.5252 .28209 m .54521 .29029 L .5451 .30115 L p .499 .584 .871 r
F P
0 g
s
.67737 .41535 m .67293 .39124 L .69311 .38733 L p .689 .654 .81 r
F P
0 g
s
.69311 .38733 m .69836 .41389 L .67737 .41535 L p .689 .654 .81 r
F P
0 g
s
.61767 .40098 m .61361 .38483 L .62319 .38166 L p .675 .595 .758 r
F P
0 g
s
.62319 .38166 m .62823 .39933 L .61767 .40098 L p .675 .595 .758 r
F P
0 g
s
.49367 .56349 m .50593 .55191 L .5099 .55886 L p .853 .826 .821 r
F P
0 g
s
.5099 .55886 m .49662 .57018 L .49367 .56349 L p .853 .826 .821 r
F P
0 g
s
.58271 .44024 m .58764 .42741 L .59311 .42965 L p .814 .688 .725 r
F P
0 g
s
.59311 .42965 m .58864 .44347 L .58271 .44024 L p .814 .688 .725 r
F P
0 g
s
.47183 .59016 m .48382 .58062 L .48507 .58751 L p .868 .9 .853 r
F P
0 g
s
.48507 .58751 m .4717 .59649 L .47183 .59016 L p .868 .9 .853 r
F P
0 g
s
.58341 .42487 m .5872 .41348 L .59077 .41503 L p .838 .683 .691 r
F P
0 g
s
.59077 .41503 m .58764 .42741 L .58341 .42487 L p .838 .683 .691 r
F P
0 g
s
.57613 .4534 m .58271 .44024 L .58864 .44347 L p .821 .712 .745 r
F P
0 g
s
.58864 .44347 m .58237 .45753 L .57613 .4534 L p .821 .712 .745 r
F P
0 g
s
.6055 .38549 m .61225 .3831 L .60468 .386 L p 0 0 0 r
F P
0 g
s
.58736 .40035 m .58375 .40917 L .58382 .40632 L p .961 .906 .54 r
F P
0 g
s
.3966 .7017 m .37617 .68115 L .39097 .67269 L p .591 .606 .835 r
F P
0 g
s
.39097 .67269 m .40876 .69169 L .3966 .7017 L p .591 .606 .835 r
F P
0 g
s
.56806 .46679 m .57613 .4534 L .58237 .45753 L p .824 .731 .762 r
F P
0 g
s
.58237 .45753 m .57445 .4717 L .56806 .46679 L p .824 .731 .762 r
F P
0 g
s
.5587 .48028 m .56806 .46679 L .57445 .4717 L p .825 .745 .775 r
F P
0 g
s
.57445 .4717 m .5651 .48585 L .5587 .48028 L p .825 .745 .775 r
F P
0 g
s
.5483 .49376 m .5587 .48028 L .5651 .48585 L p .827 .757 .786 r
F P
0 g
s
.5651 .48585 m .55455 .49984 L .5483 .49376 L p .827 .757 .786 r
F P
0 g
s
.69836 .41389 m .69311 .38733 L .71653 .38271 L p .687 .662 .82 r
F P
0 g
s
.71653 .38271 m .72262 .41205 L .69836 .41389 L p .687 .662 .82 r
F P
0 g
s
.59828 .3552 m .5874 .34205 L .59265 .33488 L p .575 .551 .791 r
F P
0 g
s
.57819 .32201 m .59265 .33488 L .5874 .34205 L p .543 .548 .81 r
F P
0 g
s
.62823 .39933 m .62319 .38166 L .63471 .37783 L p .674 .608 .774 r
F P
0 g
s
.63471 .37783 m .64079 .39718 L .62823 .39933 L p .674 .608 .774 r
F P
0 g
s
.53712 .50711 m .5483 .49376 L .55455 .49984 L p .829 .767 .794 r
F P
0 g
s
.55455 .49984 m .54306 .51355 L .53712 .50711 L p .829 .767 .794 r
F P
0 g
s
.58036 .42198 m .58487 .41154 L .5872 .41348 L p .887 .732 .684 r
F P
0 g
s
.5872 .41348 m .58341 .42487 L .58036 .42198 L p .887 .732 .684 r
F P
0 g
s
.57794 .43678 m .58341 .42487 L .58764 .42741 L p .843 .713 .72 r
F P
0 g
s
.58764 .42741 m .58271 .44024 L .57794 .43678 L p .843 .713 .72 r
F P
0 g
s
.52543 .52024 m .53712 .50711 L .54306 .51355 L p .832 .777 .799 r
F P
0 g
s
.54306 .51355 m .53093 .52686 L .52543 .52024 L p .832 .777 .799 r
F P
0 g
s
.60709 .36951 m .59828 .3552 L .60518 .34923 L p .609 .56 .775 r
F P
0 g
s
.59265 .33488 m .60518 .34923 L .59828 .3552 L p .575 .551 .791 r
F P
0 g
s
.60518 .34923 m .61545 .36489 L .60709 .36951 L p .609 .56 .775 r
F P
0 g
s
.48198 .57435 m .49367 .56349 L .49662 .57018 L p .867 .851 .825 r
F P
0 g
s
.49662 .57018 m .48382 .58062 L .48198 .57435 L p .867 .851 .825 r
F P
0 g
s
.72262 .41205 m .71653 .38271 L .74363 .37727 L p .686 .67 .829 r
F P
0 g
s
.74363 .37727 m .7506 .40979 L .72262 .41205 L p .686 .67 .829 r
F P
0 g
s
.51354 .53304 m .52543 .52024 L .53093 .52686 L p .838 .787 .804 r
F P
0 g
s
.53093 .52686 m .51845 .53968 L .51354 .53304 L p .838 .787 .804 r
F P
0 g
s
.61354 .38053 m .62156 .37956 L .61225 .3831 L p .518 .911 .788 r
F P
0 g
s
.61225 .3831 m .6055 .38549 L .61354 .38053 L p .518 .911 .788 r
F P
0 g
s
.64079 .39718 m .63471 .37783 L .64838 .37327 L p .673 .621 .788 r
F P
0 g
s
.64838 .37327 m .6556 .3945 L .64079 .39718 L p .673 .621 .788 r
F P
0 g
s
.57843 .41868 m .58375 .40917 L .58487 .41154 L p .939 .804 .685 r
F P
0 g
s
.58487 .41154 m .58036 .42198 L .57843 .41868 L p .939 .804 .685 r
F P
0 g
s
.57093 .44911 m .57794 .43678 L .58271 .44024 L p .842 .732 .743 r
F P
0 g
s
.58271 .44024 m .57613 .4534 L .57093 .44911 L p .842 .732 .743 r
F P
0 g
s
.54521 .29029 m .5252 .28209 L .52316 .26943 L p .523 .601 .873 r
F P
0 g
s
.50046 .26325 m .52316 .26943 L .5252 .28209 L p .508 .609 .888 r
F P
0 g
s
.57819 .32201 m .5622 .31074 L .56458 .30049 L p .54 .572 .836 r
F P
0 g
s
.54521 .29029 m .56458 .30049 L .5622 .31074 L p .518 .577 .854 r
F P
0 g
s
.57424 .43301 m .58036 .42198 L .58341 .42487 L p .876 .749 .719 r
F P
0 g
s
.58341 .42487 m .57794 .43678 L .57424 .43301 L p .876 .749 .719 r
F P
0 g
s
.55914 .77611 m .53031 .76987 L .52677 .75641 L p .451 .633 .932 r
F P
0 g
s
.50106 .74778 m .52677 .75641 L .53031 .76987 L p .474 .623 .916 r
F P
0 g
s
.50172 .54541 m .51354 .53304 L .51845 .53968 L p .845 .799 .806 r
F P
0 g
s
.51845 .53968 m .50593 .55191 L .50172 .54541 L p .845 .799 .806 r
F P
0 g
s
.56255 .46178 m .57093 .44911 L .57613 .4534 L p .839 .746 .761 r
F P
0 g
s
.57613 .4534 m .56806 .46679 L .56255 .46178 L p .839 .746 .761 r
F P
0 g
s
.2872 .64926 m .3023 .66071 L .274 .66868 L p .608 .828 .984 r
F P
0 g
s
.26966 .6536 m .25458 .61997 L .2858 .61577 L p .662 .663 .84 r
F P
0 g
s
.2858 .61577 m .29859 .64634 L .26966 .6536 L p .662 .663 .84 r
F P
0 g
s
.274 .66868 m .25632 .65422 L .2872 .64926 L p .608 .828 .984 r
F P
0 g
s
.7506 .40979 m .74363 .37727 L .77496 .37091 L p .684 .677 .837 r
F P
0 g
s
.77496 .37091 m .78283 .40706 L .7506 .40979 L p .684 .677 .837 r
F P
0 g
s
.46092 .5988 m .47183 .59016 L .4717 .59649 L p .87 .949 .862 r
F P
0 g
s
.4717 .59649 m .45941 .60441 L .46092 .5988 L p .87 .949 .862 r
F P
0 g
s
.4485 .6113 m .45941 .60441 L .45689 .61075 L p .794 .988 .89 r
F P
0 g
s
.55302 .47469 m .56255 .46178 L .56806 .46679 L p .836 .756 .774 r
F P
0 g
s
.56806 .46679 m .5587 .48028 L .55302 .47469 L p .836 .756 .774 r
F P
0 g
s
.57759 .41492 m .58382 .40632 L .58375 .40917 L p .968 .884 .694 r
F P
0 g
s
.58375 .40917 m .57843 .41868 L .57759 .41492 L p .968 .884 .694 r
F P
0 g
s
.6556 .3945 m .64838 .37327 L .66447 .36788 L p .673 .632 .801 r
F P
0 g
s
.66447 .36788 m .67293 .39124 L .6556 .3945 L p .673 .632 .801 r
F P
0 g
s
.59265 .33488 m .57819 .32201 L .58277 .31264 L p .564 .57 .818 r
F P
0 g
s
.56458 .30049 m .58277 .31264 L .57819 .32201 L p .54 .572 .836 r
F P
0 g
s
.62336 .37472 m .63277 .37532 L .62156 .37956 L p .603 .951 .901 r
F P
0 g
s
.62156 .37956 m .61354 .38053 L .62336 .37472 L p .603 .951 .901 r
F P
0 g
s
.54258 .48774 m .55302 .47469 L .5587 .48028 L p .835 .763 .784 r
F P
0 g
s
.5587 .48028 m .5483 .49376 L .54258 .48774 L p .835 .763 .784 r
F P
0 g
s
.61545 .36489 m .60518 .34923 L .6137 .3423 L p .619 .58 .789 r
F P
0 g
s
.6137 .3423 m .6256 .35945 L .61545 .36489 L p .619 .58 .789 r
F P
0 g
s
.49029 .55729 m .50172 .54541 L .50593 .55191 L p .856 .814 .808 r
F P
0 g
s
.50593 .55191 m .49367 .56349 L .49029 .55729 L p .856 .814 .808 r
F P
0 g
s
.56666 .44458 m .57424 .43301 L .57794 .43678 L p .864 .759 .745 r
F P
0 g
s
.57794 .43678 m .57093 .44911 L .56666 .44458 L p .864 .759 .745 r
F P
0 g
s
.47115 .58447 m .48198 .57435 L .48382 .58062 L p .883 .886 .83 r
F P
0 g
s
.48382 .58062 m .47183 .59016 L .47115 .58447 L p .883 .886 .83 r
F P
0 g
s
.37617 .68115 m .35911 .65869 L .37623 .65202 L p .615 .611 .823 r
F P
0 g
s
.37623 .65202 m .39097 .67269 L .37617 .68115 L p .615 .611 .823 r
F P
0 g
s
.59412 .39321 m .58756 .39898 L .59131 .39434 L p .684 .94 .655 r
F P
0 g
s
.57155 .42888 m .57843 .41868 L .58036 .42198 L p .907 .796 .726 r
F P
0 g
s
.58036 .42198 m .57424 .43301 L .57155 .42888 L p .907 .796 .726 r
F P
0 g
s
.5315 .50082 m .54258 .48774 L .5483 .49376 L p .834 .77 .79 r
F P
0 g
s
.5483 .49376 m .53712 .50711 L .5315 .50082 L p .834 .77 .79 r
F P
0 g
s
.47585 .73695 m .4517 .72395 L .45681 .71304 L p .496 .589 .877 r
F P
0 g
s
.4517 .72395 m .42916 .70883 L .43698 .69885 L p .523 .585 .858 r
F P
0 g
s
.43698 .69885 m .45681 .71304 L .4517 .72395 L p .523 .585 .858 r
F P
0 g
s
.52316 .26943 m .50046 .26325 L .49548 .2489 L p .53 .623 .889 r
F P
0 g
s
.47048 .24544 m .49548 .2489 L .50046 .26325 L p .517 .632 .903 r
F P
0 g
s
.78283 .40706 m .77496 .37091 L .81112 .36351 L p .683 .683 .844 r
F P
0 g
s
.81112 .36351 m .8199 .40382 L .78283 .40706 L p .683 .683 .844 r
F P
0 g
s
.60518 .34923 m .59265 .33488 L .59929 .32663 L p .591 .573 .802 r
F P
0 g
s
.58277 .31264 m .59929 .32663 L .59265 .33488 L p .564 .57 .818 r
F P
0 g
s
.59929 .32663 m .6137 .3423 L .60518 .34923 L p .591 .573 .802 r
F P
0 g
s
.42916 .70883 m .40876 .69169 L .41913 .68288 L p .551 .584 .841 r
F P
0 g
s
.41913 .68288 m .43698 .69885 L .42916 .70883 L p .551 .584 .841 r
F P
0 g
s
.57784 .41063 m .58508 .40295 L .58382 .40632 L p .956 .946 .713 r
F P
0 g
s
.58382 .40632 m .57759 .41492 L .57784 .41063 L p .956 .946 .713 r
F P
0 g
s
.52005 .51383 m .5315 .50082 L .53712 .50711 L p .836 .776 .795 r
F P
0 g
s
.53712 .50711 m .52543 .52024 L .52005 .51383 L p .836 .776 .795 r
F P
0 g
s
.64389 .80941 m .67502 .80614 L .69689 .82097 L p .492 .713 .969 r
F P
0 g
s
.67502 .80614 m .64389 .80941 L .62798 .79469 L p .462 .702 .971 r
F P
0 g
s
.59805 .79409 m .62798 .79469 L .64389 .80941 L p .475 .687 .96 r
F P
0 g
s
.55782 .4566 m .56666 .44458 L .57093 .44911 L p .854 .764 .763 r
F P
0 g
s
.57093 .44911 m .56255 .46178 L .55782 .4566 L p .854 .764 .763 r
F P
0 g
s
.50106 .74778 m .47585 .73695 L .47814 .72539 L p .47 .595 .896 r
F P
0 g
s
.45681 .71304 m .47814 .72539 L .47585 .73695 L p .496 .589 .877 r
F P
0 g
s
.67293 .39124 m .66447 .36788 L .6833 .36156 L p .673 .643 .812 r
F P
0 g
s
.6833 .36156 m .69311 .38733 L .67293 .39124 L p .673 .643 .812 r
F P
0 g
s
.56458 .30049 m .54521 .29029 L .54583 .27795 L p .54 .594 .857 r
F P
0 g
s
.52316 .26943 m .54583 .27795 L .54521 .29029 L p .523 .601 .873 r
F P
0 g
s
.62798 .79469 m .59805 .79409 L .58718 .77994 L p .443 .673 .961 r
F P
0 g
s
.55914 .77611 m .58718 .77994 L .59805 .79409 L p .461 .661 .948 r
F P
0 g
s
.47951 .56861 m .49029 .55729 L .49367 .56349 L p .87 .834 .808 r
F P
0 g
s
.49367 .56349 m .48198 .57435 L .47951 .56861 L p .87 .834 .808 r
F P
0 g
s
.50853 .52667 m .52005 .51383 L .52543 .52024 L p .839 .783 .797 r
F P
0 g
s
.52543 .52024 m .51354 .53304 L .50853 .52667 L p .839 .783 .797 r
F P
0 g
s
.56981 .42431 m .57759 .41492 L .57843 .41868 L p .929 .848 .742 r
F P
0 g
s
.57843 .41868 m .57155 .42888 L .56981 .42431 L p .929 .848 .742 r
F P
0 g
s
.56326 .43972 m .57155 .42888 L .57424 .43301 L p .884 .79 .752 r
F P
0 g
s
.57424 .43301 m .56666 .44458 L .56326 .43972 L p .884 .79 .752 r
F P
0 g
s
.63514 .36794 m .6461 .3703 L .63277 .37532 L p .648 .948 .953 r
F P
0 g
s
.63277 .37532 m .62336 .37472 L .63514 .36794 L p .648 .948 .953 r
F P
0 g
s
.54794 .469 m .55782 .4566 L .56255 .46178 L p .847 .768 .775 r
F P
0 g
s
.56255 .46178 m .55302 .47469 L .54794 .469 L p .847 .768 .775 r
F P
0 g
s
.59906 .38969 m .59131 .39434 L .59642 .38895 L p .701 .976 .776 r
F P
0 g
s
.49548 .2489 m .47048 .24544 L .46167 .22962 L p .538 .645 .903 r
F P
0 g
s
.43501 .22964 m .46167 .22962 L .47048 .24544 L p .528 .655 .916 r
F P
0 g
s
.40876 .69169 m .39097 .67269 L .40366 .66529 L p .579 .587 .825 r
F P
0 g
s
.40366 .66529 m .41913 .68288 L .40876 .69169 L p .579 .587 .825 r
F P
0 g
s
.49722 .53925 m .50853 .52667 L .51354 .53304 L p .846 .79 .797 r
F P
0 g
s
.51354 .53304 m .50172 .54541 L .49722 .53925 L p .846 .79 .797 r
F P
0 g
s
.57917 .40571 m .58756 .39898 L .58508 .40295 L p .916 .979 .748 r
F P
0 g
s
.58508 .40295 m .57784 .41063 L .57917 .40571 L p .916 .979 .748 r
F P
0 g
s
.69689 .82097 m .72832 .81316 L .75712 .82751 L p .513 .736 .974 r
F P
0 g
s
.72832 .81316 m .69689 .82097 L .67502 .80614 L p .486 .728 .979 r
F P
0 g
s
.46144 .59381 m .47115 .58447 L .47183 .59016 L p .896 .935 .833 r
F P
0 g
s
.47183 .59016 m .46092 .5988 L .46144 .59381 L p .896 .935 .833 r
F P
0 g
s
.6256 .35945 m .6137 .3423 L .62401 .33428 L p .627 .598 .801 r
F P
0 g
s
.62401 .33428 m .63777 .35308 L .6256 .35945 L p .627 .598 .801 r
F P
0 g
s
.46167 .22962 m .43501 .22964 L .42146 .21273 L p .548 .665 .914 r
F P
0 g
s
.53727 .48168 m .54794 .469 L .55302 .47469 L p .841 .771 .784 r
F P
0 g
s
.55302 .47469 m .54258 .48774 L .53727 .48168 L p .841 .771 .784 r
F P
0 g
s
.45137 .60654 m .46092 .5988 L .45941 .60441 L p .826 .996 .852 r
F P
0 g
s
.45941 .60441 m .4485 .6113 L .45137 .60654 L p .826 .996 .852 r
F P
0 g
s
.69311 .38733 m .6833 .36156 L .70524 .35419 L p .673 .653 .822 r
F P
0 g
s
.70524 .35419 m .71653 .38271 L .69311 .38733 L p .673 .653 .822 r
F P
0 g
s
.52677 .75641 m .50106 .74778 L .5005 .73583 L p .444 .604 .914 r
F P
0 g
s
.47814 .72539 m .5005 .73583 L .50106 .74778 L p .47 .595 .896 r
F P
0 g
s
.58277 .31264 m .56458 .30049 L .56784 .2888 L p .559 .59 .841 r
F P
0 g
s
.54583 .27795 m .56784 .2888 L .56458 .30049 L p .54 .594 .857 r
F P
0 g
s
.55379 .45115 m .56326 .43972 L .56666 .44458 L p .867 .785 .768 r
F P
0 g
s
.56666 .44458 m .55782 .4566 L .55379 .45115 L p .867 .785 .768 r
F P
0 g
s
.46965 .57932 m .47951 .56861 L .48198 .57435 L p .89 .862 .806 r
F P
0 g
s
.48198 .57435 m .47115 .58447 L .46965 .57932 L p .89 .862 .806 r
F P
0 g
s
.52609 .49456 m .53727 .48168 L .54258 .48774 L p .838 .773 .789 r
F P
0 g
s
.54258 .48774 m .5315 .50082 L .52609 .49456 L p .838 .773 .789 r
F P
0 g
s
.4864 .55148 m .49722 .53925 L .50172 .54541 L p .855 .799 .795 r
F P
0 g
s
.50172 .54541 m .49029 .55729 L .4864 .55148 L p .855 .799 .795 r
F P
0 g
s
.29859 .64634 m .2858 .61577 L .31304 .6122 L p .662 .653 .831 r
F P
0 g
s
.31304 .6122 m .32386 .64004 L .29859 .64634 L p .662 .653 .831 r
F P
0 g
s
.31415 .645 m .32701 .65377 L .3023 .66071 L p .591 .838 .992 r
F P
0 g
s
.3023 .66071 m .2872 .64926 L .31415 .645 L p .591 .838 .992 r
F P
0 g
s
.58718 .77994 m .55914 .77611 L .55241 .76288 L p .429 .644 .947 r
F P
0 g
s
.52677 .75641 m .55241 .76288 L .55914 .77611 L p .451 .633 .932 r
F P
0 g
s
.56902 .4192 m .57784 .41063 L .57759 .41492 L p .935 .894 .765 r
F P
0 g
s
.57759 .41492 m .56981 .42431 L .56902 .4192 L p .935 .894 .765 r
F P
0 g
s
.6137 .3423 m .59929 .32663 L .60747 .31713 L p .603 .591 .812 r
F P
0 g
s
.60747 .31713 m .62401 .33428 L .6137 .3423 L p .603 .591 .812 r
F P
0 g
s
.56067 .43445 m .56981 .42431 L .57155 .42888 L p .898 .823 .765 r
F P
0 g
s
.57155 .42888 m .56326 .43972 L .56067 .43445 L p .898 .823 .765 r
F P
0 g
s
.60297 .3827 m .61354 .38053 L .6055 .38549 L p .72 .988 .866 r
F P
0 g
s
.6055 .38549 m .59642 .38895 L .60297 .3827 L p .72 .988 .866 r
F P
0 g
s
.51469 .50752 m .52609 .49456 L .5315 .50082 L p .838 .775 .792 r
F P
0 g
s
.5315 .50082 m .52005 .51383 L .51469 .50752 L p .838 .775 .792 r
F P
0 g
s
.54583 .27795 m .52316 .26943 L .52122 .25503 L p .543 .616 .875 r
F P
0 g
s
.49548 .2489 m .52122 .25503 L .52316 .26943 L p .53 .623 .889 r
F P
0 g
s
.59929 .32663 m .58277 .31264 L .58857 .30191 L p .58 .589 .826 r
F P
0 g
s
.56784 .2888 m .58857 .30191 L .58277 .31264 L p .559 .59 .841 r
F P
0 g
s
.64914 .36006 m .66182 .36439 L .6461 .3703 L p .67 .928 .972 r
F P
0 g
s
.6461 .3703 m .63514 .36794 L .64914 .36006 L p .67 .928 .972 r
F P
0 g
s
.58162 .40008 m .59131 .39434 L .58756 .39898 L p .875 .993 .797 r
F P
0 g
s
.58756 .39898 m .57917 .40571 L .58162 .40008 L p .875 .993 .797 r
F P
0 g
s
.54338 .46309 m .55379 .45115 L .55782 .4566 L p .855 .782 .779 r
F P
0 g
s
.55782 .4566 m .54794 .469 L .54338 .46309 L p .855 .782 .779 r
F P
0 g
s
.58857 .30191 m .60747 .31713 L .59929 .32663 L p .58 .589 .826 r
F P
0 g
s
.47635 .5633 m .4864 .55148 L .49029 .55729 L p .868 .811 .791 r
F P
0 g
s
.49029 .55729 m .47951 .56861 L .47635 .5633 L p .868 .811 .791 r
F P
0 g
s
.39097 .67269 m .37623 .65202 L .39097 .64624 L p .607 .593 .812 r
F P
0 g
s
.39097 .64624 m .40366 .66529 L .39097 .67269 L p .607 .593 .812 r
F P
0 g
s
.50334 .52047 m .51469 .50752 L .52005 .51383 L p .839 .777 .792 r
F P
0 g
s
.52005 .51383 m .50853 .52667 L .50334 .52047 L p .839 .777 .792 r
F P
0 g
s
.71653 .38271 m .70524 .35419 L .73073 .34561 L p .673 .662 .831 r
F P
0 g
s
.73073 .34561 m .74363 .37727 L .71653 .38271 L p .673 .662 .831 r
F P
0 g
s
.5323 .47548 m .54338 .46309 L .54794 .469 L p .846 .779 .786 r
F P
0 g
s
.54794 .469 m .53727 .48168 L .5323 .47548 L p .846 .779 .786 r
F P
0 g
s
.49234 .53332 m .50334 .52047 L .50853 .52667 L p .844 .78 .79 r
F P
0 g
s
.50853 .52667 m .49722 .53925 L .49234 .53332 L p .844 .78 .79 r
F P
0 g
s
.46097 .58938 m .46965 .57932 L .47115 .58447 L p .913 .904 .801 r
F P
0 g
s
.47115 .58447 m .46144 .59381 L .46097 .58938 L p .913 .904 .801 r
F P
0 g
s
.45308 .60239 m .46144 .59381 L .46092 .5988 L p .872 .992 .813 r
F P
0 g
s
.46092 .5988 m .45137 .60654 L .45308 .60239 L p .872 .992 .813 r
F P
0 g
s
.63777 .35308 m .62401 .33428 L .63634 .32499 L p .633 .613 .812 r
F P
0 g
s
.63634 .32499 m .65218 .34567 L .63777 .35308 L p .633 .613 .812 r
F P
0 g
s
.5504 .44532 m .56067 .43445 L .56326 .43972 L p .876 .807 .778 r
F P
0 g
s
.56326 .43972 m .55379 .45115 L .5504 .44532 L p .876 .807 .778 r
F P
0 g
s
.56915 .41346 m .57917 .40571 L .57784 .41063 L p .923 .926 .794 r
F P
0 g
s
.57784 .41063 m .56902 .4192 L .56915 .41346 L p .923 .926 .794 r
F P
0 g
s
.55885 .42867 m .56902 .4192 L .56981 .42431 L p .904 .854 .783 r
F P
0 g
s
.56981 .42431 m .56067 .43445 L .55885 .42867 L p .904 .854 .783 r
F P
0 g
s
.45681 .71304 m .43698 .69885 L .44346 .69003 L p .499 .563 .851 r
F P
0 g
s
.43698 .69885 m .41913 .68288 L .42785 .67515 L p .531 .562 .831 r
F P
0 g
s
.42785 .67515 m .44346 .69003 L .43698 .69885 L p .531 .562 .831 r
F P
0 g
s
.46731 .57463 m .47635 .5633 L .47951 .56861 L p .887 .829 .784 r
F P
0 g
s
.47951 .56861 m .46965 .57932 L .46731 .57463 L p .887 .829 .784 r
F P
0 g
s
.61112 .37545 m .62336 .37472 L .61354 .38053 L p .729 .977 .92 r
F P
0 g
s
.61354 .38053 m .60297 .3827 L .61112 .37545 L p .729 .977 .92 r
F P
0 g
s
.47814 .72539 m .45681 .71304 L .46091 .70337 L p .469 .567 .872 r
F P
0 g
s
.44346 .69003 m .46091 .70337 L .45681 .71304 L p .499 .563 .851 r
F P
0 g
s
.55241 .76288 m .52677 .75641 L .52336 .74437 L p .419 .613 .93 r
F P
0 g
s
.5005 .73583 m .52336 .74437 L .52677 .75641 L p .444 .604 .914 r
F P
0 g
s
.52082 .48821 m .5323 .47548 L .53727 .48168 L p .841 .776 .79 r
F P
0 g
s
.53727 .48168 m .52609 .49456 L .52082 .48821 L p .841 .776 .79 r
F P
0 g
s
.48195 .54596 m .49234 .53332 L .49722 .53925 L p .85 .783 .785 r
F P
0 g
s
.49722 .53925 m .4864 .55148 L .48195 .54596 L p .85 .783 .785 r
F P
0 g
s
.58524 .39364 m .59642 .38895 L .59131 .39434 L p .844 .993 .847 r
F P
0 g
s
.59131 .39434 m .58162 .40008 L .58524 .39364 L p .844 .993 .847 r
F P
0 g
s
.32386 .64004 m .31304 .6122 L .33676 .60918 L p .661 .642 .82 r
F P
0 g
s
.33676 .60918 m .34585 .63459 L .32386 .64004 L p .661 .642 .82 r
F P
0 g
s
.56784 .2888 m .54583 .27795 L .54698 .26387 L p .558 .61 .861 r
F P
0 g
s
.52122 .25503 m .54698 .26387 L .54583 .27795 L p .543 .616 .875 r
F P
0 g
s
.41913 .68288 m .40366 .66529 L .41444 .65885 L p .564 .565 .813 r
F P
0 g
s
.41444 .65885 m .42785 .67515 L .41913 .68288 L p .564 .565 .813 r
F P
0 g
s
.52122 .25503 m .49548 .2489 L .49003 .23254 L p .548 .636 .89 r
F P
0 g
s
.46167 .22962 m .49003 .23254 L .49548 .2489 L p .538 .645 .903 r
F P
0 g
s
.78771 .81449 m .75712 .82751 L .72832 .81316 L p .512 .752 .982 r
F P
0 g
s
.33762 .64138 m .34853 .64776 L .32701 .65377 L p .567 .848 .997 r
F P
0 g
s
.32701 .65377 m .31415 .645 L .33762 .64138 L p .567 .848 .997 r
F P
0 g
s
.21887 .62484 m .20827 .58595 L .24585 .58481 L p .675 .678 .845 r
F P
0 g
s
.24585 .58481 m .25458 .61997 L .21887 .62484 L p .675 .678 .845 r
F P
0 g
s
.66562 .35091 m .68024 .35749 L .66182 .36439 L p .68 .905 .975 r
F P
0 g
s
.66182 .36439 m .64914 .36006 L .66562 .35091 L p .68 .905 .975 r
F P
0 g
s
.50925 .5012 m .52082 .48821 L .52609 .49456 L p .838 .774 .791 r
F P
0 g
s
.52609 .49456 m .51469 .50752 L .50925 .5012 L p .838 .774 .791 r
F P
0 g
s
.53927 .45687 m .5504 .44532 L .55379 .45115 L p .861 .796 .786 r
F P
0 g
s
.55379 .45115 m .54338 .46309 L .53927 .45687 L p .861 .796 .786 r
F P
0 g
s
.5005 .73583 m .47814 .72539 L .47978 .71509 L p .439 .573 .892 r
F P
0 g
s
.46091 .70337 m .47978 .71509 L .47814 .72539 L p .469 .567 .872 r
F P
0 g
s
.47245 .55832 m .48195 .54596 L .4864 .55148 L p .861 .787 .777 r
F P
0 g
s
.4864 .55148 m .47635 .5633 L .47245 .55832 L p .861 .787 .777 r
F P
0 g
s
.62401 .33428 m .60747 .31713 L .61736 .3062 L p .613 .608 .822 r
F P
0 g
s
.61736 .3062 m .63634 .32499 L .62401 .33428 L p .613 .608 .822 r
F P
0 g
s
.74363 .37727 m .73073 .34561 L .76029 .33565 L p .673 .669 .838 r
F P
0 g
s
.76029 .33565 m .77496 .37091 L .74363 .37727 L p .673 .669 .838 r
F P
0 g
s
.49787 .51433 m .50925 .5012 L .51469 .50752 L p .837 .772 .789 r
F P
0 g
s
.51469 .50752 m .50334 .52047 L .49787 .51433 L p .837 .772 .789 r
F P
0 g
s
.57022 .40699 m .58162 .40008 L .57917 .40571 L p .902 .944 .825 r
F P
0 g
s
.57917 .40571 m .56915 .41346 L .57022 .40699 L p .902 .944 .825 r
F P
0 g
s
.45367 .59878 m .46097 .58938 L .46144 .59381 L p .923 .966 .779 r
F P
0 g
s
.46144 .59381 m .45308 .60239 L .45367 .59878 L p .923 .966 .779 r
F P
0 g
s
.4595 .58543 m .46731 .57463 L .46965 .57932 L p .913 .856 .771 r
F P
0 g
s
.46965 .57932 m .46097 .58938 L .4595 .58543 L p .913 .856 .771 r
F P
0 g
s
.54759 .43902 m .55885 .42867 L .56067 .43445 L p .88 .828 .791 r
F P
0 g
s
.56067 .43445 m .5504 .44532 L .54759 .43902 L p .88 .828 .791 r
F P
0 g
s
.52756 .46901 m .53927 .45687 L .54338 .46309 L p .849 .787 .79 r
F P
0 g
s
.54338 .46309 m .5323 .47548 L .52756 .46901 L p .849 .787 .79 r
F P
0 g
s
.55776 .42226 m .56915 .41346 L .56902 .4192 L p .901 .878 .804 r
F P
0 g
s
.56902 .4192 m .55885 .42867 L .55776 .42226 L p .901 .878 .804 r
F P
0 g
s
.58857 .30191 m .56784 .2888 L .57206 .27543 L p .575 .606 .847 r
F P
0 g
s
.54698 .26387 m .57206 .27543 L .56784 .2888 L p .558 .61 .861 r
F P
0 g
s
.48698 .52751 m .49787 .51433 L .50334 .52047 L p .839 .77 .785 r
F P
0 g
s
.50334 .52047 m .49234 .53332 L .48698 .52751 L p .839 .77 .785 r
F P
0 g
s
.40366 .66529 m .39097 .64624 L .40355 .64126 L p .597 .573 .798 r
F P
0 g
s
.40355 .64126 m .41444 .65885 L .40366 .66529 L p .597 .573 .798 r
F P
0 g
s
.60747 .31713 m .58857 .30191 L .59573 .2896 L p .593 .606 .833 r
F P
0 g
s
.59573 .2896 m .61736 .3062 L .60747 .31713 L p .593 .606 .833 r
F P
0 g
s
.46406 .57032 m .47245 .55832 L .47635 .5633 L p .875 .792 .764 r
F P
0 g
s
.47635 .5633 m .46731 .57463 L .46406 .57032 L p .875 .792 .764 r
F P
0 g
s
.62101 .36708 m .63514 .36794 L .62336 .37472 L p .73 .955 .946 r
F P
0 g
s
.62336 .37472 m .61112 .37545 L .62101 .36708 L p .73 .955 .946 r
F P
0 g
s
.65218 .34567 m .63634 .32499 L .65093 .31425 L p .639 .626 .822 r
F P
0 g
s
.65093 .31425 m .66913 .33705 L .65218 .34567 L p .639 .626 .822 r
F P
0 g
s
.49003 .23254 m .46167 .22962 L .45172 .21156 L p .555 .656 .902 r
F P
0 g
s
.42146 .21273 m .45172 .21156 L .46167 .22962 L p .548 .665 .914 r
F P
0 g
s
.62798 .79469 m .6556 .79286 L .67502 .80614 L p .462 .702 .971 r
F P
0 g
s
.6556 .79286 m .62798 .79469 L .61379 .7815 L p .427 .688 .973 r
F P
0 g
s
.58718 .77994 m .61379 .7815 L .62798 .79469 L p .443 .673 .961 r
F P
0 g
s
.59011 .38624 m .60297 .3827 L .59642 .38895 L p .819 .981 .887 r
F P
0 g
s
.59642 .38895 m .58524 .39364 L .59011 .38624 L p .819 .981 .887 r
F P
0 g
s
.57206 .27543 m .59573 .2896 L .58857 .30191 L p .575 .606 .847 r
F P
0 g
s
.61379 .7815 m .58718 .77994 L .57738 .76726 L p .407 .656 .961 r
F P
0 g
s
.55241 .76288 m .57738 .76726 L .58718 .77994 L p .429 .644 .947 r
F P
0 g
s
.51558 .48167 m .52756 .46901 L .5323 .47548 L p .842 .78 .792 r
F P
0 g
s
.5323 .47548 m .52082 .48821 L .51558 .48167 L p .842 .78 .792 r
F P
0 g
s
.47685 .54063 m .48698 .52751 L .49234 .53332 L p .843 .767 .778 r
F P
0 g
s
.49234 .53332 m .48195 .54596 L .47685 .54063 L p .843 .767 .778 r
F P
0 g
s
.34585 .63459 m .33676 .60918 L .35733 .60666 L p .66 .629 .808 r
F P
0 g
s
.35733 .60666 m .36491 .62991 L .34585 .63459 L p .66 .629 .808 r
F P
0 g
s
.25458 .61997 m .24585 .58481 L .27866 .58391 L p .676 .67 .837 r
F P
0 g
s
.27866 .58391 m .2858 .61577 L .25458 .61997 L p .676 .67 .837 r
F P
0 g
s
.52336 .74437 m .5005 .73583 L .49963 .72516 L p .41 .582 .91 r
F P
0 g
s
.47978 .71509 m .49963 .72516 L .5005 .73583 L p .439 .573 .892 r
F P
0 g
s
.53553 .4502 m .54759 .43902 L .5504 .44532 L p .863 .809 .795 r
F P
0 g
s
.5504 .44532 m .53927 .45687 L .53553 .4502 L p .863 .809 .795 r
F P
0 g
s
.35797 .63832 m .36718 .64257 L .34853 .64776 L p .53 .855 .997 r
F P
0 g
s
.34853 .64776 m .33762 .64138 L .35797 .63832 L p .53 .855 .997 r
F P
0 g
s
.45172 .21156 m .42146 .21273 L .40594 .19337 L p .565 .674 .912 r
F P
0 g
s
.50363 .49475 m .51558 .48167 L .52082 .48821 L p .837 .773 .791 r
F P
0 g
s
.52082 .48821 m .50925 .5012 L .50363 .49475 L p .837 .773 .791 r
F P
0 g
s
.68493 .34031 m .70172 .34945 L .68024 .35749 L p .684 .882 .972 r
F P
0 g
s
.68024 .35749 m .66562 .35091 L .68493 .34031 L p .684 .882 .972 r
F P
0 g
s
.46774 .55359 m .47685 .54063 L .48195 .54596 L p .849 .762 .767 r
F P
0 g
s
.48195 .54596 m .47245 .55832 L .46774 .55359 L p .849 .762 .767 r
F P
0 g
s
.45312 .59566 m .4595 .58543 L .46097 .58938 L p .947 .903 .747 r
F P
0 g
s
.46097 .58938 m .45367 .59878 L .45312 .59566 L p .947 .903 .747 r
F P
0 g
s
.457 .58188 m .46406 .57032 L .46731 .57463 L p .895 .799 .746 r
F P
0 g
s
.46731 .57463 m .4595 .58543 L .457 .58188 L p .895 .799 .746 r
F P
0 g
s
.57738 .76726 m .55241 .76288 L .54621 .75102 L p .392 .624 .945 r
F P
0 g
s
.52336 .74437 m .54621 .75102 L .55241 .76288 L p .419 .613 .93 r
F P
0 g
s
.54698 .26387 m .52122 .25503 L .51932 .23856 L p .56 .629 .877 r
F P
0 g
s
.49003 .23254 m .51932 .23856 L .52122 .25503 L p .548 .636 .89 r
F P
0 g
s
.57225 .39965 m .58524 .39364 L .58162 .40008 L p .876 .947 .855 r
F P
0 g
s
.58162 .40008 m .57022 .40699 L .57225 .39965 L p .876 .947 .855 r
F P
0 g
s
.67502 .80614 m .70281 .80034 L .72832 .81316 L p .486 .728 .979 r
F P
0 g
s
.70281 .80034 m .67502 .80614 L .6556 .79286 L p .452 .718 .981 r
F P
0 g
s
.77496 .37091 m .76029 .33565 L .79454 .32411 L p .673 .677 .845 r
F P
0 g
s
.79454 .32411 m .81112 .36351 L .77496 .37091 L p .673 .677 .845 r
F P
0 g
s
.46091 .70337 m .44346 .69003 L .4487 .68225 L p .469 .536 .843 r
F P
0 g
s
.44346 .69003 m .42785 .67515 L .43505 .66838 L p .506 .535 .821 r
F P
0 g
s
.43505 .66838 m .4487 .68225 L .44346 .69003 L p .506 .535 .821 r
F P
0 g
s
.5453 .43211 m .55776 .42226 L .55885 .42867 L p .879 .844 .806 r
F P
0 g
s
.55885 .42867 m .54759 .43902 L .5453 .43211 L p .879 .844 .806 r
F P
0 g
s
.49203 .50814 m .50363 .49475 L .50925 .5012 L p .834 .767 .788 r
F P
0 g
s
.50925 .5012 m .49787 .51433 L .49203 .50814 L p .834 .767 .788 r
F P
0 g
s
.42785 .67515 m .41444 .65885 L .42346 .65326 L p .545 .54 .8 r
F P
0 g
s
.42346 .65326 m .43505 .66838 L .42785 .67515 L p .545 .54 .8 r
F P
0 g
s
.44793 .60752 m .45367 .59878 L .45308 .60239 L p .746 .94 .608 r
F P
0 g
s
.5574 .41511 m .57022 .40699 L .56915 .41346 L p .889 .893 .826 r
F P
0 g
s
.56915 .41346 m .55776 .42226 L .5574 .41511 L p .889 .893 .826 r
F P
0 g
s
.52298 .46216 m .53553 .4502 L .53927 .45687 L p .85 .794 .797 r
F P
0 g
s
.53927 .45687 m .52756 .46901 L .52298 .46216 L p .85 .794 .797 r
F P
0 g
s
.24478 .63827 m .25632 .65422 L .22101 .65996 L p .599 .807 .98 r
F P
0 g
s
.22101 .65996 m .20722 .64035 L .24478 .63827 L p .599 .807 .98 r
F P
0 g
s
.45986 .56631 m .46774 .55359 L .47245 .55832 L p .857 .756 .751 r
F P
0 g
s
.47245 .55832 m .46406 .57032 L .45986 .56631 L p .857 .756 .751 r
F P
0 g
s
.47978 .71509 m .46091 .70337 L .46406 .69477 L p .434 .541 .866 r
F P
0 g
s
.4487 .68225 m .46406 .69477 L .46091 .70337 L p .469 .536 .843 r
F P
0 g
s
.48106 .52172 m .49203 .50814 L .49787 .51433 L p .833 .76 .782 r
F P
0 g
s
.49787 .51433 m .48698 .52751 L .48106 .52172 L p .833 .76 .782 r
F P
0 g
s
.2858 .61577 m .27866 .58391 L .30725 .58325 L p .677 .662 .827 r
F P
0 g
s
.30725 .58325 m .31304 .6122 L .2858 .61577 L p .677 .662 .827 r
F P
0 g
s
.36491 .62991 m .35733 .60666 L .37512 .60461 L p .658 .616 .795 r
F P
0 g
s
.37512 .60461 m .38137 .62593 L .36491 .62991 L p .658 .616 .795 r
F P
0 g
s
.63634 .32499 m .61736 .3062 L .62916 .29359 L p .621 .622 .83 r
F P
0 g
s
.62916 .29359 m .65093 .31425 L .63634 .32499 L p .621 .622 .83 r
F P
0 g
s
.41444 .65885 m .40355 .64126 L .41418 .63701 L p .584 .55 .783 r
F P
0 g
s
.41418 .63701 m .42346 .65326 L .41444 .65885 L p .584 .55 .783 r
F P
0 g
s
.59634 .37774 m .61112 .37545 L .60297 .3827 L p .799 .962 .915 r
F P
0 g
s
.60297 .3827 m .59011 .38624 L .59634 .37774 L p .799 .962 .915 r
F P
0 g
s
.63286 .3574 m .64914 .36006 L .63514 .36794 L p .727 .929 .957 r
F P
0 g
s
.63514 .36794 m .62101 .36708 L .63286 .3574 L p .727 .929 .957 r
F P
0 g
s
.47101 .5354 m .48106 .52172 L .48698 .52751 L p .834 .752 .773 r
F P
0 g
s
.48698 .52751 m .47685 .54063 L .47101 .5354 L p .834 .752 .773 r
F P
0 g
s
.45144 .59297 m .457 .58188 L .4595 .58543 L p .923 .811 .717 r
F P
0 g
s
.4595 .58543 m .45312 .59566 L .45144 .59297 L p .923 .811 .717 r
F P
0 g
s
.51028 .47481 m .52298 .46216 L .52756 .46901 L p .84 .782 .796 r
F P
0 g
s
.52756 .46901 m .51558 .48167 L .51028 .47481 L p .84 .782 .796 r
F P
0 g
s
.45343 .57869 m .45986 .56631 L .46406 .57032 L p .865 .745 .729 r
F P
0 g
s
.46406 .57032 m .457 .58188 L .45343 .57869 L p .865 .745 .729 r
F P
0 g
s
.54621 .75102 m .52336 .74437 L .52001 .73357 L p .381 .591 .927 r
F P
0 g
s
.49963 .72516 m .52001 .73357 L .52336 .74437 L p .41 .582 .91 r
F P
0 g
s
.37556 .63579 m .38326 .63812 L .36718 .64257 L p .472 .852 .984 r
F P
0 g
s
.36718 .64257 m .35797 .63832 L .37556 .63579 L p .472 .852 .984 r
F P
0 g
s
.44342 .61344 m .43728 .61954 L .44127 .61734 L p 0 0 0 r
F P
0 g
s
.53209 .44297 m .5453 .43211 L .54759 .43902 L p .861 .819 .806 r
F P
0 g
s
.54759 .43902 m .53553 .4502 L .53209 .44297 L p .861 .819 .806 r
F P
0 g
s
.49963 .72516 m .47978 .71509 L .48077 .7059 L p .401 .548 .887 r
F P
0 g
s
.46406 .69477 m .48077 .7059 L .47978 .71509 L p .434 .541 .866 r
F P
0 g
s
.44834 .60531 m .45312 .59566 L .45367 .59878 L p .928 .959 .646 r
F P
0 g
s
.45367 .59878 m .44793 .60752 L .44834 .60531 L p .928 .959 .646 r
F P
0 g
s
.46212 .54904 m .47101 .5354 L .47685 .54063 L p .835 .741 .76 r
F P
0 g
s
.47685 .54063 m .46774 .55359 L .46212 .54904 L p .835 .741 .76 r
F P
0 g
s
.66913 .33705 m .65093 .31425 L .6681 .30184 L p .643 .639 .831 r
F P
0 g
s
.6681 .30184 m .68897 .32705 L .66913 .33705 L p .643 .639 .831 r
F P
0 g
s
.57206 .27543 m .54698 .26387 L .54869 .24775 L p .574 .624 .864 r
F P
0 g
s
.51932 .23856 m .54869 .24775 L .54698 .26387 L p .56 .629 .877 r
F P
0 g
s
.49774 .48805 m .51028 .47481 L .51558 .48167 L p .834 .772 .793 r
F P
0 g
s
.51558 .48167 m .50363 .49475 L .49774 .48805 L p .834 .772 .793 r
F P
0 g
s
.31304 .6122 m .30725 .58325 L .33212 .58281 L p .678 .652 .817 r
F P
0 g
s
.33212 .58281 m .33676 .60918 L .31304 .6122 L p .678 .652 .817 r
F P
0 g
s
.45463 .56254 m .46212 .54904 L .46774 .55359 L p .836 .726 .743 r
F P
0 g
s
.46774 .55359 m .45986 .56631 L .45463 .56254 L p .836 .726 .743 r
F P
0 g
s
.57528 .3913 m .59011 .38624 L .58524 .39364 L p .851 .941 .88 r
F P
0 g
s
.58524 .39364 m .57225 .39965 L .57528 .3913 L p .851 .941 .88 r
F P
0 g
s
.61736 .3062 m .59573 .2896 L .6044 .27544 L p .604 .62 .84 r
F P
0 g
s
.6044 .27544 m .62916 .29359 L .61736 .3062 L p .604 .62 .84 r
F P
0 g
s
.38137 .62593 m .37512 .60461 L .39042 .60299 L p .657 .601 .781 r
F P
0 g
s
.39042 .60299 m .39547 .62257 L .38137 .62593 L p .657 .601 .781 r
F P
0 g
s
.54351 .42447 m .5574 .41511 L .55776 .42226 L p .872 .855 .823 r
F P
0 g
s
.55776 .42226 m .5453 .43211 L .54351 .42447 L p .872 .855 .823 r
F P
0 g
s
.70749 .32804 m .7267 .3401 L .70172 .34945 L p .686 .861 .966 r
F P
0 g
s
.70172 .34945 m .68493 .34031 L .70749 .32804 L p .686 .861 .966 r
F P
0 g
s
.4857 .50178 m .49774 .48805 L .50363 .49475 L p .829 .762 .788 r
F P
0 g
s
.50363 .49475 m .49203 .50814 L .4857 .50178 L p .829 .762 .788 r
F P
0 g
s
.44859 .59067 m .45343 .57869 L .457 .58188 L p .873 .726 .697 r
F P
0 g
s
.457 .58188 m .45144 .59297 L .44859 .59067 L p .873 .726 .697 r
F P
0 g
s
.51932 .23856 m .49003 .23254 L .48401 .21381 L p .564 .647 .891 r
F P
0 g
s
.45172 .21156 m .48401 .21381 L .49003 .23254 L p .555 .656 .902 r
F P
0 g
s
.55776 .40707 m .57225 .39965 L .57022 .40699 L p .873 .9 .848 r
F P
0 g
s
.57022 .40699 m .5574 .41511 L .55776 .40707 L p .873 .9 .848 r
F P
0 g
s
.27757 .63654 m .2872 .64926 L .25632 .65422 L p .583 .815 .987 r
F P
0 g
s
.25632 .65422 m .24478 .63827 L .27757 .63654 L p .583 .815 .987 r
F P
0 g
s
.51848 .4548 m .53209 .44297 L .53553 .4502 L p .848 .8 .804 r
F P
0 g
s
.53553 .4502 m .52298 .46216 L .51848 .4548 L p .848 .8 .804 r
F P
0 g
s
.4463 .61022 m .44127 .61734 L .44391 .61562 L p .029 0 0 r
F P
0 g
s
.44752 .60353 m .45144 .59297 L .45312 .59566 L p .966 .84 .668 r
F P
0 g
s
.45312 .59566 m .44834 .60531 L .44752 .60353 L p .966 .84 .668 r
F P
0 g
s
.4487 .68225 m .43505 .66838 L .44085 .66245 L p .472 .503 .809 r
F P
0 g
s
.43505 .66838 m .42346 .65326 L .43086 .64844 L p .519 .509 .785 r
F P
0 g
s
.43086 .64844 m .44085 .66245 L .43505 .66838 L p .519 .509 .785 r
F P
0 g
s
.59573 .2896 m .57206 .27543 L .57732 .26008 L p .588 .621 .852 r
F P
0 g
s
.54869 .24775 m .57732 .26008 L .57206 .27543 L p .574 .624 .864 r
F P
0 g
s
.47446 .51586 m .4857 .50178 L .49203 .50814 L p .826 .751 .781 r
F P
0 g
s
.49203 .50814 m .48106 .52172 L .47446 .51586 L p .826 .751 .781 r
F P
0 g
s
.44871 .5758 m .45463 .56254 L .45986 .56631 L p .833 .703 .72 r
F P
0 g
s
.45986 .56631 m .45343 .57869 L .44871 .5758 L p .833 .703 .72 r
F P
0 g
s
.57732 .26008 m .6044 .27544 L .59573 .2896 L p .588 .621 .852 r
F P
0 g
s
.42346 .65326 m .41418 .63701 L .42303 .63342 L p .567 .522 .765 r
F P
0 g
s
.42303 .63342 m .43086 .64844 L .42346 .65326 L p .567 .522 .765 r
F P
0 g
s
.46406 .69477 m .4487 .68225 L .45276 .67538 L p .429 .505 .835 r
F P
0 g
s
.44085 .66245 m .45276 .67538 L .4487 .68225 L p .472 .503 .809 r
F P
0 g
s
.72832 .81316 m .75522 .80279 L .78771 .81449 L p .512 .752 .982 r
F P
0 g
s
.75522 .80279 m .72832 .81316 L .70281 .80034 L p .483 .746 .987 r
F P
0 g
s
.33676 .60918 m .33212 .58281 L .35371 .58258 L p .68 .642 .805 r
F P
0 g
s
.35371 .58258 m .35733 .60666 L .33676 .60918 L p .68 .642 .805 r
F P
0 g
s
.46431 .53017 m .47446 .51586 L .48106 .52172 L p .823 .739 .771 r
F P
0 g
s
.48106 .52172 m .47101 .5354 L .46431 .53017 L p .823 .739 .771 r
F P
0 g
s
.39068 .63373 m .39703 .63435 L .38326 .63812 L p .38 .826 .942 r
F P
0 g
s
.38326 .63812 m .37556 .63579 L .39068 .63373 L p .38 .826 .942 r
F P
0 g
s
.52001 .73357 m .49963 .72516 L .49845 .71559 L p .37 .557 .906 r
F P
0 g
s
.48077 .7059 m .49845 .71559 L .49963 .72516 L p .401 .548 .887 r
F P
0 g
s
.60404 .36798 m .62101 .36708 L .61112 .37545 L p .782 .939 .931 r
F P
0 g
s
.61112 .37545 m .59634 .37774 L .60404 .36798 L p .782 .939 .931 r
F P
0 g
s
.4555 .54458 m .46431 .53017 L .47101 .5354 L p .82 .723 .758 r
F P
0 g
s
.47101 .5354 m .46212 .54904 L .4555 .54458 L p .82 .723 .758 r
F P
0 g
s
.39547 .62257 m .39042 .60299 L .40349 .60177 L p .655 .585 .764 r
F P
0 g
s
.40349 .60177 m .40747 .61979 L .39547 .62257 L p .655 .585 .764 r
F P
0 g
s
.44451 .58871 m .44871 .5758 L .45343 .57869 L p .823 .668 .691 r
F P
0 g
s
.45343 .57869 m .44859 .59067 L .44451 .58871 L p .823 .668 .691 r
F P
0 g
s
.50482 .46751 m .51848 .4548 L .52298 .46216 L p .837 .785 .801 r
F P
0 g
s
.52298 .46216 m .51028 .47481 L .50482 .46751 L p .837 .785 .801 r
F P
0 g
s
.64692 .34622 m .66562 .35091 L .64914 .36006 L p .722 .904 .959 r
F P
0 g
s
.64914 .36006 m .63286 .3574 L .64692 .34622 L p .722 .904 .959 r
F P
0 g
s
.44547 .60217 m .44859 .59067 L .45144 .59297 L p .87 .688 .654 r
F P
0 g
s
.45144 .59297 m .44752 .60353 L .44547 .60217 L p .87 .688 .654 r
F P
0 g
s
.48077 .7059 m .46406 .69477 L .46629 .68713 L p .39 .511 .859 r
F P
0 g
s
.45276 .67538 m .46629 .68713 L .46406 .69477 L p .429 .505 .835 r
F P
0 g
s
.44826 .55895 m .4555 .54458 L .46212 .54904 L p .815 .703 .741 r
F P
0 g
s
.46212 .54904 m .45463 .56254 L .44826 .55895 L p .815 .703 .741 r
F P
0 g
s
.57738 .76726 m .60111 .76967 L .61379 .7815 L p .407 .656 .961 r
F P
0 g
s
.60111 .76967 m .57738 .76726 L .56852 .75587 L p .365 .635 .958 r
F P
0 g
s
.54621 .75102 m .56852 .75587 L .57738 .76726 L p .392 .624 .945 r
F P
0 g
s
.5289 .43504 m .54351 .42447 L .5453 .43211 L p .856 .827 .818 r
F P
0 g
s
.5453 .43211 m .53209 .44297 L .5289 .43504 L p .856 .827 .818 r
F P
0 g
s
.61379 .7815 m .63836 .78097 L .6556 .79286 L p .427 .688 .973 r
F P
0 g
s
.63836 .78097 m .61379 .7815 L .60111 .76967 L p .385 .669 .972 r
F P
0 g
s
.35733 .60666 m .35371 .58258 L .37241 .58256 L p .681 .631 .792 r
F P
0 g
s
.37241 .58256 m .37512 .60461 L .35733 .60666 L p .681 .631 .792 r
F P
0 g
s
.44276 .57315 m .44826 .55895 L .45463 .56254 L p .805 .675 .72 r
F P
0 g
s
.45463 .56254 m .44871 .5758 L .44276 .57315 L p .805 .675 .72 r
F P
0 g
s
.49146 .481 m .50482 .46751 L .51028 .47481 L p .829 .771 .797 r
F P
0 g
s
.51028 .47481 m .49774 .48805 L .49146 .481 L p .829 .771 .797 r
F P
0 g
s
.65093 .31425 m .62916 .29359 L .64315 .27905 L p .628 .635 .838 r
F P
0 g
s
.64315 .27905 m .6681 .30184 L .65093 .31425 L p .628 .635 .838 r
F P
0 g
s
.30616 .63515 m .31415 .645 L .2872 .64926 L p .56 .821 .995 r
F P
0 g
s
.2872 .64926 m .27757 .63654 L .30616 .63515 L p .56 .821 .995 r
F P
0 g
s
.44535 .61354 m .44752 .60353 L .44834 .60531 L p .895 .86 .413 r
F P
0 g
s
.44834 .60531 m .44527 .61436 L .44535 .61354 L p .895 .86 .413 r
F P
0 g
s
.56852 .75587 m .54621 .75102 L .54045 .74036 L p .35 .6 .941 r
F P
0 g
s
.52001 .73357 m .54045 .74036 L .54621 .75102 L p .381 .591 .927 r
F P
0 g
s
.44214 .60119 m .44451 .58871 L .44859 .59067 L p .791 .608 .654 r
F P
0 g
s
.44859 .59067 m .44547 .60217 L .44214 .60119 L p .791 .608 .654 r
F P
0 g
s
.40747 .61979 m .40349 .60177 L .41455 .60093 L p .654 .567 .745 r
F P
0 g
s
.41455 .60093 m .41754 .61754 L .40747 .61979 L p .654 .567 .745 r
F P
0 g
s
.40358 .63212 m .40873 .6312 L .39703 .63435 L p .236 .752 .843 r
F P
0 g
s
.39703 .63435 m .39068 .63373 L .40358 .63212 L p .236 .752 .843 r
F P
0 g
s
.48401 .21381 m .45172 .21156 L .4404 .19083 L p .571 .665 .902 r
F P
0 g
s
.40594 .19337 m .4404 .19083 L .45172 .21156 L p .565 .674 .912 r
F P
0 g
s
.44018 .62604 m .43592 .62798 L p .43658 .62301 L .564 .443 .673 r
F P
0 g
s
.44127 .61734 m .43728 .61954 L p .43774 .62192 L .374 0 .069 r
F P
0 g
s
.43774 .62192 m .43781 .62227 L .43828 .62161 L .374 0 .069 r
F
.43774 .62192 m .43828 .62161 L .44127 .61734 L F
.44391 .61562 m .44127 .61734 L p .44156 .62107 L .496 .123 .262 r
F P
0 g
s
.4414 .62119 m .44308 .62458 L .44067 .62177 L .527 .387 .633 r
F
.44127 .61734 m .43954 .62087 L p .44076 .62099 L .496 .123 .262 r
F P
0 g
s
.44154 .62079 m .44076 .62099 L .44156 .62107 L .496 .123 .262 r
F
.44127 .61734 m .44076 .62099 L .44154 .62079 L F
.4393 .62137 m .44127 .61734 L p .43781 .62227 L .374 0 .069 r
F P
0 g
s
.43783 .61361 m .44166 .61317 L p .44076 .62099 L .527 .387 .633 r
F P
0 g
s
.44018 .62604 m .4393 .62137 L p .44076 .62099 L .527 .387 .633 r
F P
0 g
s
.4393 .62137 m .43783 .61361 L p .44076 .62099 L .527 .387 .633 r
F P
0 g
s
.44254 .62029 m .44391 .61562 L p .44156 .62107 L .496 .123 .262 r
F P
0 g
s
.44265 .62118 m .44308 .62458 L p .44133 .62105 L .527 .387 .633 r
F P
0 g
s
.44391 .61562 m .44282 .61935 L p .44396 .61986 L .596 .278 .401 r
F P
0 g
s
.44282 .61935 m .44254 .62029 L p .44351 .62 L .596 .278 .401 r
F P
0 g
s
.44282 .61935 m .44351 .62 L .44396 .61986 L .596 .278 .401 r
F
.44527 .61436 m .44391 .61562 L p .44397 .62043 L F P
0 g
s
.44375 .62076 m .44467 .62357 L .44338 .62133 L .446 .289 .574 r
F
.44454 .62097 m .44467 .62357 L p .44351 .62 L F P
0 g
s
.44399 .62284 m .44447 .61965 L p .44397 .62043 L .596 .278 .401 r
F P
0 g
s
.44447 .61965 m .44527 .61436 L p .44397 .62043 L .596 .278 .401 r
F P
0 g
s
.44467 .62357 m .44308 .62458 L p .44338 .62133 L .446 .289 .574 r
F P
0 g
s
.44351 .62 m .44375 .62076 L .44338 .62133 L .446 .289 .574 r
F
.44527 .61436 m .44495 .61648 L p .4451 .61915 L .749 .467 .503 r
F P
0 g
s
.44495 .61648 m .44447 .61965 L p .44496 .61926 L .749 .467 .503 r
F P
0 g
s
.44495 .61648 m .44496 .61926 L .4451 .61915 L .749 .467 .503 r
F
.44497 .62299 m .44467 .62357 L p .44496 .61926 L 0 0 .33 r
F P
0 g
s
.44535 .61354 m .44497 .62299 L p .44496 .61926 L 0 0 .33 r
F P
0 g
s
.44415 .61315 m .44535 .61354 L p .44496 .61926 L 0 0 .33 r
F P
0 g
s
.44467 .62357 m .44447 .61965 L p .44496 .61926 L 0 0 .33 r
F P
0 g
s
.44447 .61965 m .44415 .61315 L p .44496 .61926 L 0 0 .33 r
F P
0 g
s
.4451 .61915 m .44447 .61965 L .44502 .62155 L .749 .467 .503 r
F
.44399 .62284 m .44497 .62299 L p .44502 .62155 L F P
0 g
s
.44447 .61965 m .44399 .62284 L p .44502 .62155 L .749 .467 .503 r
F P
0 g
s
.44377 .61721 m .44454 .62097 L .44351 .62 L .446 .289 .574 r
F
.44415 .61315 m .44447 .61965 L p .44377 .61721 L F P
0 g
s
.44447 .61965 m .44454 .62097 L p .44377 .61721 L .446 .289 .574 r
F P
0 g
s
.44166 .61317 m .44415 .61315 L p .44351 .62 L .446 .289 .574 r
F P
0 g
s
.44308 .62458 m .44254 .62029 L p .44351 .62 L .446 .289 .574 r
F P
0 g
s
.44254 .62029 m .44166 .61317 L p .44351 .62 L .446 .289 .574 r
F P
0 g
s
.44396 .61986 m .44254 .62029 L .44397 .62094 L .596 .278 .401 r
F
.44172 .62311 m .44399 .62284 L p .44397 .62094 L F P
0 g
s
.44141 .61978 m .44265 .62118 L .44086 .6201 L .527 .387 .633 r
F
.44265 .62118 m .44133 .62105 L .44086 .6201 L F
.44254 .62029 m .44172 .62311 L p .44397 .62094 L .596 .278 .401 r
F P
0 g
s
.44241 .6192 m .44254 .62029 L p .44141 .61978 L .527 .387 .633 r
F P
0 g
s
.44254 .62029 m .44265 .62118 L p .44141 .61978 L .527 .387 .633 r
F P
0 g
s
.44308 .62458 m .44018 .62604 L p .44067 .62177 L .527 .387 .633 r
F P
0 g
s
.43781 .62227 m .44018 .62604 L .43658 .62301 L .564 .443 .673 r
F
.4393 .62137 m .43943 .62208 L p .43781 .62227 L F P
0 g
s
.43943 .62208 m .44018 .62604 L p .43781 .62227 L .564 .443 .673 r
F P
0 g
s
.43728 .61954 m .43491 .6226 L p .43666 .6224 L .374 0 .069 r
F P
0 g
s
.43778 .62211 m .43666 .6224 L .43781 .62227 L .374 0 .069 r
F
.43728 .61954 m .43666 .6224 L .43778 .62211 L F
.4326 .61447 m .43783 .61361 L p .43666 .6224 L .564 .443 .673 r
F P
0 g
s
.43592 .62798 m .43467 .62291 L p .43666 .6224 L .564 .443 .673 r
F P
0 g
s
.43467 .62291 m .4326 .61447 L p .43666 .6224 L .564 .443 .673 r
F P
0 g
s
.43783 .61361 m .4393 .62137 L p .43658 .62301 L .564 .443 .673 r
F P
0 g
s
.4331 .62494 m .43811 .6238 L p .43781 .62227 L .374 0 .069 r
F P
0 g
s
.43491 .6226 m .4331 .62494 L p .43781 .62227 L .374 0 .069 r
F P
0 g
s
.43811 .6238 m .44172 .62311 L p .44156 .62107 L .496 .123 .262 r
F P
0 g
s
.44086 .6201 m .4414 .62119 L .44067 .62177 L .527 .387 .633 r
F
.43954 .62087 m .43811 .6238 L p .44156 .62107 L .496 .123 .262 r
F P
0 g
s
.44172 .62311 m .44254 .62029 L p .44156 .62107 L .496 .123 .262 r
F P
0 g
s
.44166 .61317 m .44241 .6192 L p .44086 .6201 L .527 .387 .633 r
F P
0 g
s
.43811 .6238 m .4393 .62137 L p .43781 .62227 L .374 0 .069 r
F P
0 g
s
.43914 .58707 m .44276 .57315 L .44871 .5758 L p .785 .635 .695 r
F P
0 g
s
.44871 .5758 m .44451 .58871 L .43914 .58707 L p .785 .635 .695 r
F P
0 g
s
.57939 .38177 m .59634 .37774 L .59011 .38624 L p .828 .928 .899 r
F P
0 g
s
.59011 .38624 m .57528 .3913 L .57939 .38177 L p .828 .928 .899 r
F P
0 g
s
.44085 .66245 m .43086 .64844 L .43678 .6443 L p .482 .471 .768 r
F P
0 g
s
.43086 .64844 m .42303 .63342 L .43024 .63043 L p .543 .488 .745 r
F P
0 g
s
.43024 .63043 m .43678 .6443 L .43086 .64844 L p .543 .488 .745 r
F P
0 g
s
.47877 .49514 m .49146 .481 L .49774 .48805 L p .823 .758 .791 r
F P
0 g
s
.49774 .48805 m .4857 .50178 L .47877 .49514 L p .823 .758 .791 r
F P
0 g
s
.54218 .41594 m .55776 .40707 L .5574 .41511 L p .861 .861 .839 r
F P
0 g
s
.5574 .41511 m .54351 .42447 L .54218 .41594 L p .861 .861 .839 r
F P
0 g
s
.37512 .60461 m .37241 .58256 L .38853 .58275 L p .683 .619 .778 r
F P
0 g
s
.38853 .58275 m .39042 .60299 L .37512 .60461 L p .683 .619 .778 r
F P
0 g
s
.68897 .32705 m .6681 .30184 L .68822 .28748 L p .647 .649 .838 r
F P
0 g
s
.68822 .28748 m .71212 .31547 L .68897 .32705 L p .647 .649 .838 r
F P
0 g
s
.45276 .67538 m .44085 .66245 L .44533 .65729 L p .425 .464 .796 r
F P
0 g
s
.43678 .6443 m .44533 .65729 L .44085 .66245 L p .482 .471 .768 r
F P
0 g
s
.46706 .50981 m .47877 .49514 L .4857 .50178 L p .818 .744 .783 r
F P
0 g
s
.4857 .50178 m .47446 .51586 L .46706 .50981 L p .818 .744 .783 r
F P
0 g
s
.55886 .39799 m .57528 .3913 L .57225 .39965 L p .854 .898 .866 r
F P
0 g
s
.57225 .39965 m .55776 .40707 L .55886 .39799 L p .854 .898 .866 r
F P
0 g
s
.49845 .71559 m .48077 .7059 L .48113 .69768 L p .355 .519 .882 r
F P
0 g
s
.46629 .68713 m .48113 .69768 L .48077 .7059 L p .39 .511 .859 r
F P
0 g
s
.44415 .61315 m .44547 .60217 L .44752 .60353 L p .809 .584 .597 r
F P
0 g
s
.44752 .60353 m .44535 .61354 L .44415 .61315 L p .809 .584 .597 r
F P
0 g
s
.51396 .44679 m .5289 .43504 L .53209 .44297 L p .843 .805 .813 r
F P
0 g
s
.53209 .44297 m .51848 .4548 L .51396 .44679 L p .843 .805 .813 r
F P
0 g
s
.45663 .52486 m .46706 .50981 L .47446 .51586 L p .812 .729 .772 r
F P
0 g
s
.47446 .51586 m .46431 .53017 L .45663 .52486 L p .812 .729 .772 r
F P
0 g
s
.43748 .60059 m .43914 .58707 L .44451 .58871 L p .744 .577 .668 r
F P
0 g
s
.44451 .58871 m .44214 .60119 L .43748 .60059 L p .744 .577 .668 r
F P
0 g
s
.54869 .24775 m .51932 .23856 L .51743 .21967 L p .575 .641 .879 r
F P
0 g
s
.48401 .21381 m .51743 .21967 L .51932 .23856 L p .564 .647 .891 r
F P
0 g
s
.6556 .79286 m .68023 .78885 L .70281 .80034 L p .452 .718 .981 r
F P
0 g
s
.68023 .78885 m .6556 .79286 L .63836 .78097 L p .412 .704 .982 r
F P
0 g
s
.44775 .54013 m .45663 .52486 L .46431 .53017 L p .806 .71 .76 r
F P
0 g
s
.46431 .53017 m .4555 .54458 L .44775 .54013 L p .806 .71 .76 r
F P
0 g
s
.39042 .60299 m .38853 .58275 L .40236 .58315 L p .685 .607 .763 r
F P
0 g
s
.40236 .58315 m .40349 .60177 L .39042 .60299 L p .685 .607 .763 r
F P
0 g
s
.41754 .61754 m .41455 .60093 L .42381 .60046 L p .652 .549 .724 r
F P
0 g
s
.42381 .60046 m .42588 .61577 L .41754 .61754 L p .652 .549 .724 r
F P
0 g
s
.44064 .55546 m .44775 .54013 L .4555 .54458 L p .797 .688 .744 r
F P
0 g
s
.4555 .54458 m .44826 .55895 L .44064 .55546 L p .797 .688 .744 r
F P
0 g
s
.73378 .31383 m .7557 .32926 L .7267 .3401 L p .685 .843 .959 r
F P
0 g
s
.7267 .3401 m .70749 .32804 L .73378 .31383 L p .685 .843 .959 r
F P
0 g
s
.43547 .57071 m .44064 .55546 L .44826 .55895 L p .782 .658 .726 r
F P
0 g
s
.44826 .55895 m .44276 .57315 L .43547 .57071 L p .782 .658 .726 r
F P
0 g
s
.46629 .68713 m .45276 .67538 L .4557 .66931 L p .375 .466 .825 r
F P
0 g
s
.44533 .65729 m .4557 .66931 L .45276 .67538 L p .425 .464 .796 r
F P
0 g
s
.43237 .58571 m .43547 .57071 L .44276 .57315 L p .758 .62 .706 r
F P
0 g
s
.44276 .57315 m .43914 .58707 L .43237 .58571 L p .758 .62 .706 r
F P
0 g
s
.54045 .74036 m .52001 .73357 L .51668 .72386 L p .338 .566 .922 r
F P
0 g
s
.49845 .71559 m .51668 .72386 L .52001 .73357 L p .37 .557 .906 r
F P
0 g
s
.44166 .61317 m .44214 .60119 L .44547 .60217 L p .699 .499 .614 r
F P
0 g
s
.44547 .60217 m .44415 .61315 L .44166 .61317 L p .699 .499 .614 r
F P
0 g
s
.4404 .19083 m .40594 .19337 L .3881 .17113 L p .579 .682 .91 r
F P
0 g
s
.41448 .63093 m .41854 .6286 L .40873 .6312 L p 0 0 0 r
F P
0 g
s
.40873 .6312 m .40358 .63212 L .41448 .63093 L p 0 0 0 r
F P
0 g
s
.40349 .60177 m .40236 .58315 L .41414 .58377 L p .689 .595 .746 r
F P
0 g
s
.41414 .58377 m .41455 .60093 L .40349 .60177 L p .689 .595 .746 r
F P
0 g
s
.43141 .60034 m .43237 .58571 L .43914 .58707 L p .718 .57 .687 r
F P
0 g
s
.43914 .58707 m .43748 .60059 L .43141 .60034 L p .718 .57 .687 r
F P
0 g
s
.43678 .6443 m .43024 .63043 L .43592 .62798 L p .508 .444 .72 r
F P
0 g
s
.33104 .63406 m .33762 .64138 L .31415 .645 L p .528 .826 .999 r
F P
0 g
s
.31415 .645 m .30616 .63515 L .33104 .63406 L p .528 .826 .999 r
F P
0 g
s
.43783 .61361 m .43748 .60059 L .44214 .60119 L p .666 .495 .644 r
F P
0 g
s
.44214 .60119 m .44166 .61317 L .43783 .61361 L p .666 .495 .644 r
F P
0 g
s
.42588 .61577 m .42381 .60046 L .43141 .60034 L p .652 .529 .701 r
F P
0 g
s
.43141 .60034 m .4326 .61447 L .42588 .61577 L p .652 .529 .701 r
F P
0 g
s
.41455 .60093 m .41414 .58377 L .42408 .58462 L p .694 .583 .727 r
F P
0 g
s
.42408 .58462 m .42381 .60046 L .41455 .60093 L p .694 .583 .727 r
F P
0 g
s
.49909 .45962 m .51396 .44679 L .51848 .4548 L p .833 .786 .808 r
F P
0 g
s
.51848 .4548 m .50482 .46751 L .49909 .45962 L p .833 .786 .808 r
F P
0 g
s
.61339 .35674 m .63286 .3574 L .62101 .36708 L p .766 .916 .939 r
F P
0 g
s
.62101 .36708 m .60404 .36798 L .61339 .35674 L p .766 .916 .939 r
F P
0 g
s
.4326 .61447 m .43141 .60034 L .43748 .60059 L p .655 .51 .674 r
F P
0 g
s
.43748 .60059 m .43783 .61361 L .4326 .61447 L p .655 .51 .674 r
F P
0 g
s
.20827 .58595 m .2053 .54593 L .24386 .54872 L p .687 .686 .844 r
F P
0 g
s
.24386 .54872 m .24585 .58481 L .20827 .58595 L p .687 .686 .844 r
F P
0 g
s
.44533 .65729 m .43678 .6443 L .44129 .64078 L p .427 .419 .748 r
F P
0 g
s
.43592 .62798 m .44129 .64078 L .43678 .6443 L p .508 .444 .72 r
F P
0 g
s
.42381 .60046 m .42408 .58462 L .43237 .58571 L p .703 .574 .707 r
F P
0 g
s
.43237 .58571 m .43141 .60034 L .42381 .60046 L p .703 .574 .707 r
F P
0 g
s
.43547 .57071 m .43237 .58571 L .42408 .58462 L p .739 .615 .72 r
F P
0 g
s
.62916 .29359 m .6044 .27544 L .61477 .25912 L p .613 .633 .847 r
F P
0 g
s
.61477 .25912 m .64315 .27905 L .62916 .29359 L p .613 .633 .847 r
F P
0 g
s
.42408 .58462 m .42671 .56842 L .43547 .57071 L p .739 .615 .72 r
F P
0 g
s
.44064 .55546 m .43547 .57071 L .42671 .56842 L p .764 .65 .735 r
F P
0 g
s
.5259 .42626 m .54218 .41594 L .54351 .42447 L p .848 .831 .83 r
F P
0 g
s
.54351 .42447 m .5289 .43504 L .5259 .42626 L p .848 .831 .83 r
F P
0 g
s
.48113 .69768 m .46629 .68713 L .46763 .68033 L p .334 .475 .852 r
F P
0 g
s
.4557 .66931 m .46763 .68033 L .46629 .68713 L p .375 .466 .825 r
F P
0 g
s
.24585 .58481 m .24386 .54872 L .27745 .55129 L p .689 .679 .835 r
F P
0 g
s
.27745 .55129 m .27866 .58391 L .24585 .58481 L p .689 .679 .835 r
F P
0 g
s
.42358 .63013 m .42662 .62653 L .41854 .6286 L p .199 0 0 r
F P
0 g
s
.41854 .6286 m .41448 .63093 L .42358 .63013 L p .199 0 0 r
F P
0 g
s
.42671 .56842 m .43163 .55202 L .44064 .55546 L p .764 .65 .735 r
F P
0 g
s
.44775 .54013 m .44064 .55546 L .43163 .55202 L p .781 .678 .75 r
F P
0 g
s
.66349 .3333 m .68493 .34031 L .66562 .35091 L p .717 .881 .957 r
F P
0 g
s
.66562 .35091 m .64692 .34622 L .66349 .3333 L p .717 .881 .957 r
F P
0 g
s
.42671 .56842 m .42408 .58462 L .41414 .58377 L p .726 .617 .735 r
F P
0 g
s
.48468 .47344 m .49909 .45962 L .50482 .46751 L p .824 .77 .802 r
F P
0 g
s
.50482 .46751 m .49146 .481 L .48468 .47344 L p .824 .77 .802 r
F P
0 g
s
.4557 .66931 m .44533 .65729 L .44856 .65279 L p .355 .411 .781 r
F P
0 g
s
.44129 .64078 m .44856 .65279 L .44533 .65729 L p .427 .419 .748 r
F P
0 g
s
.44129 .64078 m .43592 .62798 L .44018 .62604 L p .449 .382 .69 r
F P
0 g
s
.51668 .72386 m .49845 .71559 L .49693 .70699 L p .322 .529 .9 r
F P
0 g
s
.48113 .69768 m .49693 .70699 L .49845 .71559 L p .355 .519 .882 r
F P
0 g
s
.43163 .55202 m .43873 .53561 L .44775 .54013 L p .781 .678 .75 r
F P
0 g
s
.45663 .52486 m .44775 .54013 L .43873 .53561 L p .793 .702 .764 r
F P
0 g
s
.27866 .58391 m .27745 .55129 L .3067 .55366 L p .692 .672 .826 r
F P
0 g
s
.3067 .55366 m .30725 .58325 L .27866 .58391 L p .692 .672 .826 r
F P
0 g
s
.57732 .26008 m .54869 .24775 L .551 .22922 L p .586 .636 .868 r
F P
0 g
s
.51743 .21967 m .551 .22922 L .54869 .24775 L p .575 .641 .879 r
F P
0 g
s
.41633 .56625 m .41414 .58377 L .40236 .58315 L p .717 .622 .751 r
F P
0 g
s
.41414 .58377 m .41633 .56625 L .42671 .56842 L p .726 .617 .735 r
F P
0 g
s
.43873 .53561 m .44783 .51937 L .45663 .52486 L p .793 .702 .764 r
F P
0 g
s
.46706 .50981 m .45663 .52486 L .44783 .51937 L p .802 .722 .776 r
F P
0 g
s
.4711 .48811 m .48468 .47344 L .49146 .481 L p .816 .755 .795 r
F P
0 g
s
.49146 .481 m .47877 .49514 L .4711 .48811 L p .816 .755 .795 r
F P
0 g
s
.30725 .58325 m .3067 .55366 L .33212 .5559 L p .695 .664 .816 r
F P
0 g
s
.33212 .5559 m .33212 .58281 L .30725 .58325 L p .695 .664 .816 r
F P
0 g
s
.40412 .56417 m .40236 .58315 L .38853 .58275 L p .71 .63 .765 r
F P
0 g
s
.40236 .58315 m .40412 .56417 L .41633 .56625 L p .717 .622 .751 r
F P
0 g
s
.43163 .55202 m .42671 .56842 L .41633 .56625 L p .75 .647 .746 r
F P
0 g
s
.44783 .51937 m .45872 .50347 L .46706 .50981 L p .802 .722 .776 r
F P
0 g
s
.47877 .49514 m .46706 .50981 L .45872 .50347 L p .809 .739 .786 r
F P
0 g
s
.35264 .63326 m .35797 .63832 L .33762 .64138 L p .481 .825 .998 r
F P
0 g
s
.33762 .64138 m .33104 .63406 L .35264 .63326 L p .481 .825 .998 r
F P
0 g
s
.45872 .50347 m .4711 .48811 L .47877 .49514 L p .809 .739 .786 r
F P
0 g
s
.33212 .58281 m .33212 .5559 L .3542 .55802 L p .698 .656 .805 r
F P
0 g
s
.3542 .55802 m .35371 .58258 L .33212 .58281 L p .698 .656 .805 r
F P
0 g
s
.38988 .56212 m .38853 .58275 L .37241 .58256 L p .705 .638 .779 r
F P
0 g
s
.38853 .58275 m .38988 .56212 L .40412 .56417 L p .71 .63 .765 r
F P
0 g
s
.43102 .62972 m .4331 .62494 L .42662 .62653 L p .401 0 0 r
F P
0 g
s
.42662 .62653 m .42358 .63013 L .43102 .62972 L p .401 0 0 r
F P
0 g
s
.35371 .58258 m .3542 .55802 L .37334 .56009 L p .701 .647 .793 r
F P
0 g
s
.37334 .56009 m .37241 .58256 L .35371 .58258 L p .701 .647 .793 r
F P
0 g
s
.37241 .58256 m .37334 .56009 L .38988 .56212 L p .705 .638 .779 r
F P
0 g
s
.54128 .40637 m .55886 .39799 L .55776 .40707 L p .847 .862 .853 r
F P
0 g
s
.55776 .40707 m .54218 .41594 L .54128 .40637 L p .847 .862 .853 r
F P
0 g
s
.6044 .27544 m .57732 .26008 L .58376 .24242 L p .599 .634 .857 r
F P
0 g
s
.58376 .24242 m .61477 .25912 L .6044 .27544 L p .599 .634 .857 r
F P
0 g
s
.58466 .37087 m .60404 .36798 L .59634 .37774 L p .807 .912 .911 r
F P
0 g
s
.59634 .37774 m .57939 .38177 L .58466 .37087 L p .807 .912 .911 r
F P
0 g
s
.44856 .65279 m .44129 .64078 L .44446 .63782 L p .332 .343 .721 r
F P
0 g
s
.44018 .62604 m .44446 .63782 L .44129 .64078 L p .449 .382 .69 r
F P
0 g
s
.44446 .63782 m .44018 .62604 L .44308 .62458 L p .331 .275 .644 r
F P
0 g
s
.551 .22922 m .58376 .24242 L .57732 .26008 L p .586 .636 .868 r
F P
0 g
s
.46763 .68033 m .4557 .66931 L .45758 .66396 L p .299 .416 .814 r
F P
0 g
s
.44856 .65279 m .45758 .66396 L .4557 .66931 L p .355 .411 .781 r
F P
0 g
s
.56072 .38768 m .57939 .38177 L .57528 .3913 L p .835 .892 .881 r
F P
0 g
s
.57528 .3913 m .55886 .39799 L .56072 .38768 L p .835 .892 .881 r
F P
0 g
s
.50936 .43797 m .5259 .42626 L .5289 .43504 L p .836 .807 .823 r
F P
0 g
s
.5289 .43504 m .51396 .44679 L .50936 .43797 L p .836 .807 .823 r
F P
0 g
s
.41633 .56625 m .42107 .54857 L .43163 .55202 L p .75 .647 .746 r
F P
0 g
s
.43873 .53561 m .43163 .55202 L .42107 .54857 L p .768 .674 .759 r
F P
0 g
s
.43693 .62968 m .43811 .6238 L .4331 .62494 L p .55 .09 .115 r
F P
0 g
s
.4331 .62494 m .43102 .62972 L .43693 .62968 L p .55 .09 .115 r
F P
0 g
s
.42107 .54857 m .41633 .56625 L .40412 .56417 L p .74 .648 .759 r
F P
0 g
s
.70281 .80034 m .72654 .79233 L .75522 .80279 L p .483 .746 .987 r
F P
0 g
s
.72654 .79233 m .70281 .80034 L .68023 .78885 L p .446 .736 .989 r
F P
0 g
s
.44308 .62458 m .44636 .63538 L .44446 .63782 L p .331 .275 .644 r
F P
0 g
s
.44636 .63538 m .44308 .62458 L .44467 .62357 L p 0 .018 .524 r
F P
0 g
s
.49693 .70699 m .48113 .69768 L .48085 .6903 L p .299 .486 .875 r
F P
0 g
s
.46763 .68033 m .48085 .6903 L .48113 .69768 L p .334 .475 .852 r
F P
0 g
s
.81239 .79895 m .78771 .81449 L .75522 .80279 L p .516 .769 .988 r
F P
0 g
s
.56852 .75587 m .58977 .75903 L .60111 .76967 L p .365 .635 .958 r
F P
0 g
s
.58977 .75903 m .56852 .75587 L .56046 .74561 L p .317 .609 .952 r
F P
0 g
s
.54045 .74036 m .56046 .74561 L .56852 .75587 L p .35 .6 .941 r
F P
0 g
s
.6681 .30184 m .64315 .27905 L .65962 .26225 L p .633 .646 .845 r
F P
0 g
s
.65962 .26225 m .68822 .28748 L .6681 .30184 L p .633 .646 .845 r
F P
0 g
s
.44142 .63003 m .44172 .62311 L .43811 .6238 L p .661 .259 .273 r
F P
0 g
s
.43811 .6238 m .43693 .62968 L .44142 .63003 L p .661 .259 .273 r
F P
0 g
s
.37133 .63273 m .37556 .63579 L .35797 .63832 L p .41 .812 .982 r
F P
0 g
s
.35797 .63832 m .35264 .63326 L .37133 .63273 L p .41 .812 .982 r
F P
0 g
s
.51743 .21967 m .48401 .21381 L .47728 .19227 L p .578 .658 .891 r
F P
0 g
s
.4404 .19083 m .47728 .19227 L .48401 .21381 L p .571 .665 .902 r
F P
0 g
s
.44701 .6334 m .44641 .63187 L p .44836 .63633 L .808 .419 0 r
F P
0 g
s
.45113 .64265 m .44701 .6334 L p .44836 .63633 L .808 .419 0 r
F P
0 g
s
.44701 .6334 m .44636 .63538 L p .44566 .63049 L 0 .018 .524 r
F P
0 g
s
.44467 .62357 m .44701 .6334 L p .44566 .63049 L 0 .018 .524 r
F P
0 g
s
.44701 .6334 m .44467 .62357 L .44497 .62299 L p .88 .585 .069 r
F P
0 g
s
.45758 .66396 m .44856 .65279 L .45059 .64889 L p .242 .335 .759 r
F P
0 g
s
.44446 .63782 m .45059 .64889 L .44856 .65279 L p .332 .343 .721 r
F P
0 g
s
.42107 .54857 m .42827 .53095 L .43873 .53561 L p .768 .674 .759 r
F P
0 g
s
.44783 .51937 m .43873 .53561 L .42827 .53095 L p .781 .697 .77 r
F P
0 g
s
.60111 .76967 m .62305 .77028 L .63836 .78097 L p .385 .669 .972 r
F P
0 g
s
.62305 .77028 m .60111 .76967 L .58977 .75903 L p .336 .646 .967 r
F P
0 g
s
.56046 .74561 m .54045 .74036 L .53504 .73074 L p .304 .574 .935 r
F P
0 g
s
.51668 .72386 m .53504 .73074 L .54045 .74036 L p .338 .566 .922 r
F P
0 g
s
.45059 .64889 m .44446 .63782 L .44636 .63538 L p .147 .211 .673 r
F P
0 g
s
.44456 .63075 m .44399 .62284 L .44172 .62311 L p .762 .402 .373 r
F P
0 g
s
.44172 .62311 m .44142 .63003 L .44456 .63075 L p .762 .402 .373 r
F P
0 g
s
.44497 .62299 m .44641 .63187 L .44701 .6334 L p .88 .585 .069 r
F P
0 g
s
.44641 .63187 m .44497 .62299 L .44399 .62284 L p .888 .546 .394 r
F P
0 g
s
.71212 .31547 m .68822 .28748 L .71173 .27087 L p .65 .659 .845 r
F P
0 g
s
.71173 .27087 m .73906 .30206 L .71212 .31547 L p .65 .659 .845 r
F P
0 g
s
.44399 .62284 m .44456 .63075 L .44641 .63187 L p .888 .546 .394 r
F P
0 g
s
.40876 .54505 m .40412 .56417 L .38988 .56212 L p .731 .652 .771 r
F P
0 g
s
.40412 .56417 m .40876 .54505 L .42107 .54857 L p .74 .648 .759 r
F P
0 g
s
.493 .451 m .50936 .43797 L .51396 .44679 L p .826 .787 .815 r
F P
0 g
s
.51396 .44679 m .49909 .45962 L .493 .451 L p .826 .787 .815 r
F P
0 g
s
.76438 .29736 m .78934 .3167 L .7557 .32926 L p .685 .828 .952 r
F P
0 g
s
.7557 .32926 m .73378 .31383 L .76438 .29736 L p .685 .828 .952 r
F P
0 g
s
.42827 .53095 m .43775 .51359 L .44783 .51937 L p .781 .697 .77 r
F P
0 g
s
.45872 .50347 m .44783 .51937 L .43775 .51359 L p .792 .717 .781 r
F P
0 g
s
.42827 .53095 m .42107 .54857 L .40876 .54505 L p .757 .673 .768 r
F P
0 g
s
.48085 .6903 m .46763 .68033 L .46811 .67425 L p .259 .431 .842 r
F P
0 g
s
.45758 .66396 m .46811 .67425 L .46763 .68033 L p .299 .416 .814 r
F P
0 g
s
.53504 .73074 m .51668 .72386 L .51331 .71509 L p .289 .538 .915 r
F P
0 g
s
.49693 .70699 m .51331 .71509 L .51668 .72386 L p .322 .529 .9 r
F P
0 g
s
.62459 .3438 m .64692 .34622 L .63286 .3574 L p .753 .893 .941 r
F P
0 g
s
.63286 .3574 m .61339 .35674 L .62459 .3438 L p .753 .893 .941 r
F P
0 g
s
.38744 .63246 m .39068 .63373 L .37556 .63579 L p .302 .772 .937 r
F P
0 g
s
.37556 .63579 m .37133 .63273 L .38744 .63246 L p .302 .772 .937 r
F P
0 g
s
.52302 .41644 m .54128 .40637 L .54218 .41594 L p .838 .833 .842 r
F P
0 g
s
.54218 .41594 m .5259 .42626 L .52302 .41644 L p .838 .833 .842 r
F P
0 g
s
.47727 .46524 m .493 .451 L .49909 .45962 L p .817 .769 .808 r
F P
0 g
s
.49909 .45962 m .48468 .47344 L .47727 .46524 L p .817 .769 .808 r
F P
0 g
s
.39447 .54138 m .38988 .56212 L .37334 .56009 L p .724 .658 .783 r
F P
0 g
s
.38988 .56212 m .39447 .54138 L .40876 .54505 L p .731 .652 .771 r
F P
0 g
s
.44636 .63538 m .45144 .64553 L .45059 .64889 L p .147 .211 .673 r
F P
0 g
s
.45144 .64553 m .44636 .63538 L .44701 .6334 L p 0 0 .52 r
F P
0 g
s
.43775 .51359 m .44928 .49672 L .45872 .50347 L p .792 .717 .781 r
F P
0 g
s
.4711 .48811 m .45872 .50347 L .44928 .49672 L p .801 .735 .791 r
F P
0 g
s
.5325 1.06873 m .57593 1.0552 L .58487 1.07492 L p .727 .826 .926 r
F P
0 g
s
.58487 1.07492 m .53588 1.08867 L .5325 1.06873 L p .727 .826 .926 r
F P
0 g
s
.63233 1.05731 m .58487 1.07492 L .57593 1.0552 L p .73 .813 .916 r
F P
0 g
s
.44928 .49672 m .46256 .48054 L .4711 .48811 L p .801 .735 .791 r
F P
0 g
s
.48468 .47344 m .4711 .48811 L .46256 .48054 L p .809 .752 .8 r
F P
0 g
s
.46256 .48054 m .47727 .46524 L .48468 .47344 L p .809 .752 .8 r
F P
0 g
s
.46811 .67425 m .45758 .66396 L .4584 .65923 L p .186 .35 .796 r
F P
0 g
s
.45059 .64889 m .4584 .65923 L .45758 .66396 L p .242 .335 .759 r
F P
0 g
s
.63836 .78097 m .66028 .77855 L .68023 .78885 L p .412 .704 .982 r
F P
0 g
s
.6p .816 .881 .892 r
F P
0 g
s
.57939 .38177 m .56072 .38768 L .56338 .37592 L p .816 .881 .892 r
F P
0 g
s
.47728 .19227 m .4404 .19083 L .42746 .16696 L p .584 .673 .901 r
F P
0 g
s
.3881 .17113 m .42746 .16696 L .4404 .19083 L p .579 .682 .91 r
F P
0 g
s
.41617 .52605 m .42618 .50742 L .43775 .51359 L p .771 .694 .778 r
F P
0 g
s
.44928 .49672 m .43775 .51359 L .42618 .50742 L p .782 .714 .788 r
F P
0 g
s
.42288 .63322 m .42358 .63013 L .41448 .63093 L p .287 0 0 r
F P
0 g
s
.41448 .63093 m .41299 .6327 L .42288 .63322 L p .287 0 0 r
F P
0 g
s
.44456 .63075 m .44696 .63815 L .44965 .64021 L p .888 .467 .183 r
F P
0 g
s
.44696 .63815 m .44456 .63075 L .44142 .63003 L p .812 .382 .225 r
F P
0 g
s
.551 .22922 m .51743 .21967 L .51551 .19792 L p .587 .652 .881 r
F P
0 g
s
.47728 .19227 m .51551 .19792 L .51743 .21967 L p .578 .658 .891 r
F P
0 g
s
.47992 .68365 m .46811 .67425 L .46773 .6688 L p .159 .376 .827 r
F P
0 g
s
.4584 .65923 m .46773 .6688 L .46811 .67425 L p .186 .35 .796 r
F P
0 g
s
.43109 .634 m .43102 .62972 L .42358 .63013 L p .477 0 0 r
F P
0 g
s
.42358 .63013 m .42288 .63322 L .43109 .634 L p .477 0 0 r
F P
0 g
s
.44142 .63003 m .44302 .63645 L .44696 .63815 L p .812 .382 .225 r
F P
0 g
s
.44302 .63645 m .44142 .63003 L .43693 .62968 L p .722 .264 .163 r
F P
0 g
s
.46773 .6688 m .4584 .65923 L .45819 .65504 L p .019 .257 .759 r
F P
0 g
s
.43776 .63507 m .43693 .62968 L .43102 .62972 L p .617 .113 .03 r
F P
0 g
s
.43102 .62972 m .43109 .634 L .43776 .63507 L p .617 .113 .03 r
F P
0 g
s
.43693 .62968 m .43776 .63507 L .44302 .63645 L p .722 .264 .163 r
F P
0 g
s
.4022 .52083 m .39447 .54138 L .37793 .53751 L p .74 .677 .789 r
F P
0 g
s
.39447 .54138 m .4022 .52083 L .41617 .52605 L p .748 .674 .779 r
F P
0 g
s
.33684 .52887 m .33212 .5559 L .3067 .55366 L p .709 .677 .817 r
F P
0 g
s
.33212 .5559 m .33684 .52887 L .35884 .53337 L p .713 .67 .806 r
F P
0 g
s
.48643 .44148 m .50457 .42817 L .50936 .43797 L p .818 .787 .823 r
F P
0 g
s
.50936 .43797 m .493 .451 L .48643 .44148 L p .818 .787 .823 r
F P
0 g
s
.42618 .50742 m .43855 .48942 L .44928 .49672 L p .782 .714 .788 r
F P
0 g
s
.46256 .48054 m .44928 .49672 L .43855 .48942 L p .792 .733 .797 r
F P
0 g
s
.42618 .50742 m .41617 .52605 L .4022 .52083 L p .762 .694 .787 r
F P
0 g
s
.44511 1.08551 m .4886 1.07882 L .48632 1.09854 L p .71 .85 .949 r
F P
0 g
s
.48632 1.09854 m .43718 1.10459 L .44511 1.08551 L p .71 .85 .949 r
F P
0 g
s
.56046 .74561 m .57958 .7494 L .58977 .75903 L p .317 .609 .952 r
F P
0 g
s
.57958 .7494 m .56046 .74561 L .55309 .73631 L p .265 .58 .943 r
F P
0 g
s
.53504 .73074 m .55309 .73631 L .56046 .74561 L p .304 .574 .935 r
F P
0 g
s
.55309 .73631 m .53504 .73074 L .5299 .72202 L p .253 .544 .925 r
F P
0 g
s
.51331 .71509 m .5299 .72202 L .53504 .73074 L p .289 .538 .915 r
F P
0 g
s
.43855 .48942 m .45298 .47229 L .46256 .48054 L p .792 .733 .797 r
F P
0 g
s
.47727 .46524 m .46256 .48054 L .45298 .47229 L p .801 .751 .806 r
F P
0 g
s
.46907 .45624 m .48643 .44148 L .493 .451 L p .809 .768 .815 r
F P
0 g
s
.493 .451 m .47727 .46524 L .46907 .45624 L p .809 .768 .815 r
F P
0 g
s
.31151 .52394 m .3067 .55366 L .27745 .55129 L p .705 .683 .827 r
F P
0 g
s
.3067 .55366 m .31151 .52394 L .33684 .52887 L p .709 .677 .817 r
F P
0 g
s
.68023 .78885 m .70125 .78295 L .72654 .79233 L p .446 .736 .989 r
F P
0 g
s
.70125 .78295 m .68023 .78885 L .66028 .77855 L p .4 .722 .989 r
F P
0 g
s
.45298 .47229 m .46907 .45624 L .47727 .46524 L p .801 .751 .806 r
F P
0 g
s
.42746 .16696 m .3881 .17113 L .36753 .14547 L p .592 .688 .909 r
F P
0 g
s
.52023 .40539 m .54082 .39554 L .54128 .40637 L p .826 .831 .852 r
F P
0 g
s
.54128 .40637 m .52302 .41644 L .52023 .40539 L p .826 .831 .852 r
F P
0 g
s
.5299 .72202 m .51331 .71509 L .50984 .70713 L p .236 .507 .905 r
F P
0 g
s
.49503 .69923 m .50984 .70713 L .51331 .71509 L p .268 .498 .892 r
F P
0 g
s
.61477 .25912 m .58376 .24242 L .59153 .22205 L p .609 .645 .861 r
F P
0 g
s
.59153 .22205 m .62709 .24029 L .61477 .25912 L p .609 .645 .861 r
F P
0 g
s
.58977 .75903 m .60945 .76063 L .62305 .77028 L p .336 .646 .967 r
F P
0 g
s
.60945 .76063 m .58977 .75903 L .57958 .7494 L p .28 .617 .958 r
F P
0 g
s
.75522 .80279 m .77683 .79026 L .81239 .79895 L p .516 .769 .988 r
F P
0 g
s
.77683 .79026 m .75522 .80279 L .72654 .79233 L p .485 .764 .993 r
F P
0 g
s
.58376 .24242 m .551 .22922 L .55397 .20786 L p .597 .648 .871 r
F P
0 g
s
.51551 .19792 m .55397 .20786 L .551 .22922 L p .587 .652 .881 r
F P
0 g
s
.68822 .28748 m .65962 .26225 L .67897 .2428 L p .638 .656 .851 r
F P
0 g
s
.67897 .2428 m .71173 .27087 L .68822 .28748 L p .638 .656 .851 r
F P
0 g
s
.3861 .51518 m .37793 .53751 L .35884 .53337 L p .734 .681 .8 r
F P
0 g
s
.37793 .53751 m .3861 .51518 L .4022 .52083 L p .74 .677 .789 r
F P
0 g
s
.63789 .32887 m .66349 .3333 L .64692 .34622 L p .742 .873 .941 r
F P
0 g
s
.64692 .34622 m .62459 .3438 L .63789 .32887 L p .742 .873 .941 r
F P
0 g
s
.73906 .30206 m .71173 .27087 L .73918 .25161 L p .652 .667 .852 r
F P
0 g
s
.73918 .25161 m .7704 .28651 L .73906 .30206 L p .652 .667 .852 r
F P
0 g
s
.50984 .70713 m .49503 .69923 L .49273 .69217 L p .205 .463 .882 r
F P
0 g
s
.47992 .68365 m .49273 .69217 L .49503 .69923 L p .229 .448 .865 r
F P
0 g
s
.23987 .6214 m .24478 .63827 L .20722 .64035 L p .581 .795 .981 r
F P
0 g
s
.20722 .64035 m .20092 .61962 L .23987 .6214 L p .581 .795 .981 r
F P
0 g
s
.45819 .65504 m .46646 .66389 L .46773 .6688 L p .019 .257 .759 r
F P
0 g
s
.4022 .52083 m .41291 .50075 L .42618 .50742 L p .762 .694 .787 r
F P
0 g
s
.43855 .48942 m .42618 .50742 L .41291 .50075 L p .774 .713 .796 r
F P
0 g
s
.55397 .20786 m .59153 .22205 L .58376 .24242 L p .597 .648 .871 r
F P
0 g
s
.28236 .51847 m .27745 .55129 L .24386 .54872 L p .701 .689 .835 r
F P
0 g
s
.27745 .55129 m .28236 .51847 L .31151 .52394 L p .705 .683 .827 r
F P
0 g
s
.49273 .69217 m .47992 .68365 L .47833 .67762 L p .145 .404 .851 r
F P
0 g
s
.46773 .6688 m .47833 .67762 L .47992 .68365 L p .159 .376 .827 r
F P
0 g
s
.47833 .67762 m .46773 .6688 L .46646 .66389 L p .028 .309 .798 r
F P
0 g
s
.41291 .50075 m .4022 .52083 L .3861 .51518 L p .754 .696 .796 r
F P
0 g
s
.618 1.03826 m .65782 1.01798 L .6773 1.03593 L p .731 .799 .906 r
F P
0 g
s
.71882 1.0109 m .6773 1.03593 L .65782 1.01798 L p .73 .786 .897 r
F P
0 g
s
.27381 .62307 m .27757 .63654 L .24478 .63827 L p .561 .799 .988 r
F P
0 g
s
.24478 .63827 m .23987 .6214 L .27381 .62307 L p .561 .799 .988 r
F P
0 g
s
.44696 .63815 m .45115 .64508 L .4546 .64802 L p .789 .299 0 r
F P
0 g
s
.45115 .64508 m .44696 .63815 L .44302 .63645 L p .774 .27 0 r
F P
0 g
s
.54078 .38325 m .56338 .37592 L .56072 .38768 L p .817 .853 .876 r
F P
0 g
s
.56072 .38768 m .54082 .39554 L .54078 .38325 L p .817 .853 .876 r
F P
0 g
s
.62305 .77028 m .64264 .76927 L .66028 .77855 L p .363 .684 .979 r
F P
0 g
s
.64264 .76927 m .62305 .77028 L .60945 .76063 L p .305 .658 .972 r
F P
0 g
s
.49952 .4172 m .52023 .40539 L .52302 .41644 L p .818 .807 .841 r
F P
0 g
s
.52302 .41644 m .50457 .42817 L .49952 .4172 L p .818 .807 .841 r
F P
0 g
s
.70567 .30107 m .73378 .31383 L .70749 .32804 L p .706 .843 .948 r
F P
0 g
s
.70749 .32804 m .68293 .31836 L .70567 .30107 L p .706 .843 .948 r
F P
0 g
s
.24884 .51237 m .24386 .54872 L .2053 .54593 L p .698 .695 .844 r
F P
0 g
s
.24386 .54872 m .24884 .51237 L .28236 .51847 L p .701 .689 .835 r
F P
0 g
s
.41291 .50075 m .42634 .48145 L .43855 .48942 L p .774 .713 .796 r
F P
0 g
s
.45298 .47229 m .43855 .48942 L .42634 .48145 L p .784 .732 .804 r
F P
0 g
s
.5992 .34399 m .62459 .3438 L .61339 .35674 L p .772 .876 .923 r
F P
0 g
s
.61339 .35674 m .59122 .35837 L .5992 .34399 L p .772 .876 .923 r
F P
0 g
s
.30337 .62466 m .30616 .63515 L .27757 .63654 L p .534 .802 .995 r
F P
0 g
s
.27757 .63654 m .27381 .62307 L .30337 .62466 L p .534 .802 .995 r
F P
0 g
s
.36757 .50901 m .35884 .53337 L .33684 .52887 L p .727 .686 .81 r
F P
0 g
s
.35884 .53337 m .36757 .50901 L .3861 .51518 L p .734 .681 .8 r
F P
0 g
s
.44302 .63645 m .44652 .64244 L .45115 .64508 L p .774 .27 0 r
F P
0 g
s
.44652 .64244 m .44302 .63645 L .43776 .63507 L p .706 .18 0 r
F P
0 g
s
.56692 .36248 m .59122 .35837 L .58466 .37087 L p .799 .869 .9 r
F P
0 g
s
.58466 .37087 m .56338 .37592 L .56692 .36248 L p .799 .869 .9 r
F P
0 g
s
.32907 .6262 m .33104 .63406 L .30616 .63515 L p .497 .802 .999 r
F P
0 g
s
.30616 .63515 m .30337 .62466 L .32907 .6262 L p .497 .802 .999 r
F P
0 g
s
.43776 .63507 m .44061 .64007 L .44652 .64244 L p .706 .18 0 r
F P
0 g
s
.44061 .64007 m .43776 .63507 L .43109 .634 L p .605 .048 0 r
F P
0 g
s
.51551 .19792 m .47728 .19227 L .46968 .16742 L p .59 .667 .892 r
F P
0 g
s
.42746 .16696 m .46968 .16742 L .47728 .19227 L p .584 .673 .901 r
F P
0 g
s
.47924 .43087 m .49952 .4172 L .50457 .42817 L p .809 .786 .831 r
F P
0 g
s
.50457 .42817 m .48643 .44148 L .47924 .43087 L p .809 .786 .831 r
F P
0 g
s
.42634 .48145 m .44216 .4632 L .45298 .47229 L p .784 .732 .804 r
F P
0 g
s
.46907 .45624 m .45298 .47229 L .44216 .4632 L p .793 .749 .813 r
F P
0 g
s
.46646 .66389 m .47605 .67211 L .47833 .67762 L p .028 .309 .798 r
F P
0 g
s
.47605 .67211 m .46646 .66389 L .46429 .65944 L p 0 .23 .748 r
F P
0 g
s
.2053 .54593 m .21029 .50552 L .24884 .51237 L p .698 .695 .844 r
F P
0 g
s
.3514 .62772 m .35264 .63326 L .33104 .63406 L p .445 .795 .998 r
F P
0 g
s
.33104 .63406 m .32907 .6262 L .3514 .62772 L p .445 .795 .998 r
F P
0 g
s
.43109 .634 m .43334 .63791 L .44061 .64007 L p .605 .048 0 r
F P
0 g
s
.43334 .63791 m .43109 .634 L .42288 .63322 L p .467 0 0 r
F P
0 g
s
.5299 .72202 m .54629 .72783 L .55309 .73631 L p .253 .544 .925 r
F P
0 g
s
.54629 .72783 m .5299 .72202 L .52494 .71404 L p .2 .512 .913 r
F P
0 g
s
.50984 .70713 m .52494 .71404 L .5299 .72202 L p .236 .507 .905 r
F P
0 g
s
.3861 .51518 m .39768 .49344 L .41291 .50075 L p .754 .696 .796 r
F P
0 g
s
.42634 .48145 m .41291 .50075 L .39768 .49344 L p .765 .714 .804 r
F P
0 g
s
.52494 .71404 m .50984 .70713 L .50622 .69983 L p .179 .475 .893 r
F P
0 g
s
.49273 .69217 m .50622 .69983 L .50984 .70713 L p .205 .463 .882 r
F P
0 g
s
.47833 .67762 m .48998 .68571 L .49273 .69217 L p .145 .404 .851 r
F P
0 g
s
.48998 .68571 m .47833 .67762 L .47605 .67211 L p .047 .355 .829 r
F P
0 g
s
.44216 .4632 m .45994 .44626 L .46907 .45624 L p .793 .749 .813 r
F P
0 g
s
.48643 .44148 m .46907 .45624 L .45994 .44626 L p .801 .767 .822 r
F P
0 g
s
.37073 .62925 m .37133 .63273 L .35264 .63326 L p .369 .775 .983 r
F P
0 g
s
.35264 .63326 m .3514 .62772 L .37073 .62925 L p .369 .775 .983 r
F P
0 g
s
.45994 .44626 m .47924 .43087 L .48643 .44148 L p .801 .767 .822 r
F P
0 g
s
.42288 .63322 m .42456 .63594 L .43334 .63791 L p .467 0 0 r
F P
0 g
s
.42456 .63594 m .42288 .63322 L .41299 .6327 L p .287 0 0 r
F P
0 g
s
.39768 .49344 m .3861 .51518 L .36757 .50901 L p .746 .698 .806 r
F P
0 g
s
.50622 .69983 m .49273 .69217 L .48998 .68571 L p .135 .427 .868 r
F P
0 g
s
.55309 .73631 m .57041 .74065 L .57958 .7494 L p .265 .58 .943 r
F P
0 g
s
.57041 .74065 m .55309 .73631 L .54629 .72783 L p .21 .547 .93 r
F P
0 g
s
.38744 .63081 m .38744 .63246 L .37133 .63273 L p .26 .731 .943 r
F P
0 g
s
.37133 .63273 m .37073 .62925 L .38744 .63081 L p .26 .731 .943 r
F P
0 g
s
.41299 .6327 m .41411 .63412 L .42456 .63594 L p .287 0 0 r
F P
0 g
s
.41411 .63412 m .41299 .6327 L .40124 .63245 L p 0 .504 .714 r
F P
0 g
s
.40181 .63242 m .40124 .63245 L .38744 .63246 L p .108 .645 .858 r
F P
0 g
s
.38744 .63246 m .38744 .63081 L .40181 .63242 L p .108 .645 .858 r
F P
0 g
s
.40124 .63245 m .40181 .63242 L .41411 .63412 L p 0 .504 .714 r
F P
0 g
s
.40293 1.08889 m .44511 1.08551 L .43718 1.10459 L p .696 .859 .96 r
F P
0 g
s
.43718 1.10459 m .38943 1.1069 L .40293 1.08889 L p .696 .859 .96 r
F P
0 g
s
.34622 .5022 m .33684 .52887 L .31151 .52394 L p .722 .69 .82 r
F P
0 g
s
.33684 .52887 m .34622 .5022 L .36757 .50901 L p .727 .686 .81 r
F P
0 g
s
.51746 .39289 m .54078 .38325 L .54082 .39554 L p .813 .828 .862 r
F P
0 g
s
.54082 .39554 m .52023 .40539 L .51746 .39289 L p .813 .828 .862 r
F P
0 g
s
.65962 .26225 m .62709 .24029 L .64165 .2185 L p .627 .655 .858 r
F P
0 g
s
.64165 .2185 m .67897 .2428 L .65962 .26225 L p .627 .655 .858 r
F P
0 g
s
.57958 .7494 m .59734 .75188 L .60945 .76063 L p .28 .617 .958 r
F P
0 g
s
.59734 .75188 m .57958 .7494 L .57041 .74065 L p .219 .583 .944 r
F P
0 g
s
.66028 .77855 m .67899 .77452 L .70125 .78295 L p .4 .722 .989 r
F P
0 g
s
.67899 .77452 m .66028 .77855 L .64264 .76927 L p .343 .701 .983 r
F P
0 g
s
.45703 .65161 m .45115 .64508 L .44652 .64244 L p .636 .088 0 r
F P
0 g
s
.46429 .65944 m .47302 .66703 L .47605 .67211 L p 0 .23 .748 r
F P
0 g
s
.47302 .66703 m .46429 .65944 L .46116 .65536 L p 0 .155 .675 r
F P
0 g
s
.72654 .79233 m .74556 .78249 L .77683 .79026 L p .485 .764 .993 r
F P
0 g
s
.74556 .78249 m .72654 .79233 L .70125 .78295 L p .445 .756 .995 r
F P
0 g
s
.39768 .49344 m .4124 .47264 L .42634 .48145 L p .765 .714 .804 r
F P
0 g
s
.44216 .4632 m .42634 .48145 L .4124 .47264 L p .775 .731 .812 r
F P
0 g
s
.65358 .31162 m .68293 .31836 L .66349 .3333 L p .732 .855 .939 r
F P
0 g
s
.66349 .3333 m .63789 .32887 L .65358 .31162 L p .732 .855 .939 r
F P
0 g
s
.47605 .67211 m .48673 .67973 L .48998 .68571 L p .047 .355 .829 r
F P
0 g
s
.48673 .67973 m .47605 .67211 L .47302 .66703 L p 0 .306 .798 r
F P
0 g
s
.44652 .64244 m .45182 .6481 L .45703 .65161 L p .636 .088 0 r
F P
0 g
s
.45182 .6481 m .44652 .64244 L .44061 .64007 L p .598 .028 0 r
F P
0 g
s
.60945 .76063 m .62707 .76087 L .64264 .76927 L p .305 .658 .972 r
F P
0 g
s
.62707 .76087 m .60945 .76063 L .59734 .75188 L p .238 .623 .957 r
F P
0 g
s
.32166 .49461 m .31151 .52394 L .28236 .51847 L p .717 .695 .829 r
F P
0 g
s
.31151 .52394 m .32166 .49461 L .34622 .5022 L p .722 .69 .82 r
F P
0 g
s
.3802 .48536 m .36757 .50901 L .34622 .5022 L p .74 .701 .815 r
F P
0 g
s
.36757 .50901 m .3802 .48536 L .39768 .49344 L p .746 .698 .806 r
F P
0 g
s
.54117 .36923 m .56692 .36248 L .56338 .37592 L p .801 .845 .884 r
F P
0 g
s
.56338 .37592 m .54078 .38325 L .54117 .36923 L p .801 .845 .884 r
F P
0 g
s
.49408 .40482 m .51746 .39289 L .52023 .40539 L p .807 .805 .85 r
F P
0 g
s
.52023 .40539 m .49952 .4172 L .49408 .40482 L p .807 .805 .85 r
F P
0 g
s
.55397 .20786 m .51551 .19792 L .51352 .17279 L p .598 .661 .883 r
F P
0 g
s
.46968 .16742 m .51352 .17279 L .51551 .19792 L p .59 .667 .892 r
F P
0 g
s
.4124 .47264 m .39768 .49344 L .3802 .48536 L p .758 .715 .812 r
F P
0 g
s
.48998 .68571 m .50238 .6931 L .50622 .69983 L p .135 .427 .868 r
F P
0 g
s
.50238 .6931 m .48998 .68571 L .48673 .67973 L p .062 .391 .85 r
F P
0 g
s
.65782 1.01798 m .69455 .99449 L .71882 1.0109 L p .73 .786 .897 r
F P
0 g
s
.75598 .98244 m .71882 1.0109 L .69455 .99449 L p .727 .773 .889 r
F P
0 g
s
.52932 1.0509 m .56782 1.03756 L .57593 1.0552 L p .738 .833 .923 r
F P
0 g
s
.57593 1.0552 m .5325 1.06873 L .52932 1.0509 L p .738 .833 .923 r
F P
0 g
s
.618 1.03826 m .57593 1.0552 L .56782 1.03756 L p .741 .818 .912 r
F P
0 g
s
.4124 .47264 m .42989 .45309 L .44216 .4632 L p .775 .731 .812 r
F P
0 g
s
.45994 .44626 m .44216 .4632 L .42989 .45309 L p .784 .749 .82 r
F P
0 g
s
.71173 .27087 m .67897 .2428 L .70164 .22026 L p .642 .665 .856 r
F P
0 g
s
.70164 .22026 m .73918 .25161 L .71173 .27087 L p .642 .665 .856 r
F P
0 g
s
.50622 .69983 m .52008 .7067 L .52494 .71404 L p .179 .475 .893 r
F P
0 g
s
.52008 .7067 m .50622 .69983 L .50238 .6931 L p .121 .443 .879 r
F P
0 g
s
.46116 .65536 m .46919 .66229 L .47302 .66703 L p 0 .155 .675 r
F P
0 g
s
.46968 .16742 m .42746 .16696 L .41258 .13936 L p .596 .681 .901 r
F P
0 g
s
.36753 .14547 m .41258 .13936 L .42746 .16696 L p .592 .688 .909 r
F P
0 g
s
.44061 .64007 m .44543 .64478 L .45182 .6481 L p .598 .028 0 r
F P
0 g
s
.44543 .64478 m .44061 .64007 L .43334 .63791 L p .51 0 0 r
F P
0 g
s
.52494 .71404 m .53995 .72005 L .54629 .72783 L p .2 .512 .913 r
F P
0 g
s
.53995 .72005 m .52494 .71404 L .52008 .7067 L p .147 .48 .899 r
F P
0 g
s
.62709 .24029 m .59153 .22205 L .60082 .19849 L p .616 .655 .865 r
F P
0 g
s
.60082 .19849 m .64165 .2185 L .62709 .24029 L p .616 .655 .865 r
F P
0 g
s
.60878 .32744 m .63789 .32887 L .62459 .3438 L p .759 .86 .924 r
F P
0 g
s
.62459 .3438 m .5992 .34399 L .60878 .32744 L p .759 .86 .924 r
F P
0 g
s
.57141 .34706 m .5992 .34399 L .59122 .35837 L p .783 .857 .905 r
F P
0 g
s
.59122 .35837 m .56692 .36248 L .57141 .34706 L p .783 .857 .905 r
F P
0 g
s
.49042 1.0612 m .52932 1.0509 L .5325 1.06873 L p .731 .847 .935 r
F P
0 g
s
.5325 1.06873 m .4886 1.07882 L .49042 1.0612 L p .731 .847 .935 r
F P
0 g
s
.73225 .28103 m .76438 .29736 L .73378 .31383 L p .702 .828 .943 r
F P
0 g
s
.73378 .31383 m .70567 .30107 L .73225 .28103 L p .702 .828 .943 r
F P
0 g
s
.47128 .41894 m .49408 .40482 L .49952 .4172 L p .8 .785 .839 r
F P
0 g
s
.49952 .4172 m .47924 .43087 L .47128 .41894 L p .8 .785 .839 r
F P
0 g
s
.54629 .72783 m .56209 .73264 L .57041 .74065 L p .21 .547 .93 r
F P
0 g
s
.56209 .73264 m .54629 .72783 L .53995 .72005 L p .155 .512 .914 r
F P
0 g
s
.42989 .45309 m .44969 .4351 L .45994 .44626 L p .784 .749 .82 r
F P
0 g
s
.47924 .43087 m .45994 .44626 L .44969 .4351 L p .792 .766 .829 r
F P
0 g
s
.56782 1.03756 m .60512 1.02121 L .618 1.03826 L p .741 .818 .912 r
F P
0 g
s
.65782 1.01798 m .618 1.03826 L .60512 1.02121 L p .741 .803 .901 r
F P
0 g
s
.44969 .4351 m .47128 .41894 L .47924 .43087 L p .792 .766 .829 r
F P
0 g
s
.43334 .63791 m .43773 .64159 L .44543 .64478 L p .51 0 0 r
F P
0 g
s
.43773 .64159 m .43334 .63791 L .42456 .63594 L p .381 0 0 r
F P
0 g
s
.59153 .22205 m .55397 .20786 L .55768 .18317 L p .607 .657 .874 r
F P
0 g
s
.51352 .17279 m .55768 .18317 L .55397 .20786 L p .598 .661 .883 r
F P
0 g
s
.47302 .66703 m .48292 .67415 L .48673 .67973 L p 0 .306 .798 r
F P
0 g
s
.48292 .67415 m .47302 .66703 L .46919 .66229 L p 0 .264 .76 r
F P
0 g
s
.29339 .48609 m .28236 .51847 L .24884 .51237 L p .712 .7 .837 r
F P
0 g
s
.28236 .51847 m .29339 .48609 L .32166 .49461 L p .717 .695 .829 r
F P
0 g
s
.57041 .74065 m .58656 .7439 L .59734 .75188 L p .219 .583 .944 r
F P
0 g
s
.58656 .7439 m .57041 .74065 L .56209 .73264 L p .157 .544 .926 r
F P
0 g
s
.55768 .18317 m .60082 .19849 L .59153 .22205 L p .607 .657 .874 r
F P
0 g
s
.42456 .63594 m .4286 .63848 L .43773 .64159 L p .381 0 0 r
F P
0 g
s
.4286 .63848 m .42456 .63594 L .41411 .63412 L p .22 0 0 r
F P
0 g
s
.83038 .78139 m .81239 .79895 L .77683 .79026 L p .524 .786 .993 r
F P
0 g
s
.64264 .76927 m .6594 .7669 L .67899 .77452 L p .343 .701 .983 r
F P
0 g
s
.6594 .7669 m .64264 .76927 L .62707 .76087 L p .274 .67 .97 r
F P
0 g
s
.3802 .48536 m .39645 .46282 L .4124 .47264 L p .758 .715 .812 r
F P
0 g
s
.42989 .45309 m .4124 .47264 L .39645 .46282 L p .767 .731 .82 r
F P
0 g
s
.3601 .47635 m .34622 .5022 L .32166 .49461 L p .733 .704 .824 r
F P
0 g
s
.34622 .5022 m .3601 .47635 L .3802 .48536 L p .74 .701 .815 r
F P
0 g
s
.51467 .37867 m .54117 .36923 L .54078 .38325 L p .8 .823 .869 r
F P
0 g
s
.54078 .38325 m .51746 .39289 L .51467 .37867 L p .8 .823 .869 r
F P
0 g
s
.48673 .67973 m .49824 .68681 L .50238 .6931 L p .062 .391 .85 r
F P
0 g
s
.49824 .68681 m .48673 .67973 L .48292 .67415 L p 0 .358 .83 r
F P
0 g
s
.70125 .78295 m .71808 .7755 L .74556 .78249 L p .445 .756 .995 r
F P
0 g
s
.71808 .7755 m .70125 .78295 L .67899 .77452 L p .394 .742 .992 r
F P
0 g
s
.41786 .63539 m .41411 .63412 L .40181 .63242 L p 0 .518 .793 r
F P
0 g
s
.41786 .63539 m .40532 .63226 L p .41311 .63409 L .023 .542 .863 r
F P
0 g
s
.41411 .63412 m .41786 .63539 L p .42259 .63667 L .22 0 0 r
F P
0 g
s
.42419 .6367 m .41786 .63539 L p .41311 .63409 L .023 .542 .863 r
F P
0 g
s
.41786 .63539 m .4286 .63848 L p .42259 .63667 L .22 0 0 r
F P
0 g
s
.45195 1.06849 m .49042 1.0612 L .4886 1.07882 L p .72 .86 .948 r
F P
0 g
s
.4886 1.07882 m .44511 1.08551 L .45195 1.06849 L p .72 .86 .948 r
F P
0 g
s
.50238 .6931 m .51523 .69986 L .52008 .7067 L p .121 .443 .879 r
F P
0 g
s
.51523 .69986 m .50238 .6931 L .49824 .68681 L p .066 .414 .863 r
F P
0 g
s
.39645 .46282 m .3802 .48536 L .3601 .47635 L p .75 .717 .821 r
F P
0 g
s
.4521 .64933 m .45882 .65352 L p .45328 .6499 L .422 0 0 r
F P
0 g
s
.44543 .64478 m .4521 .64933 L p .45328 .6499 L .422 0 0 r
F P
0 g
s
.4521 .64933 m .44419 .64519 L p .45092 .64877 L 0 .333 .75 r
F P
0 g
s
.45182 .6481 m .45882 .65352 L p .45924 .65379 L .439 0 0 r
F P
0 g
s
.45882 .65352 m .45182 .6481 L .44543 .64478 L p .422 0 0 r
F P
0 g
s
.4521 .64933 m .46049 .65385 L .46736 .6588 L p 0 .275 .716 r
F P
0 g
s
.46049 .65385 m .4521 .64933 L p .45092 .64877 L 0 .333 .75 r
F P
0 g
s
.45882 .65352 m .4521 .64933 L p .4584 .65324 L 0 .275 .716 r
F P
0 g
s
.46736 .6588 m .45882 .65352 L p .4584 .65324 L 0 .275 .716 r
F P
0 g
s
.45882 .65352 m .46448 .65781 L p .45924 .65379 L .439 0 0 r
F P
0 g
s
.59734 .75188 m .61331 .75323 L .62707 .76087 L p .238 .623 .957 r
F P
0 g
s
.61331 .75323 m .59734 .75188 L .58656 .7439 L p .165 .581 .935 r
F P
0 g
s
.46919 .66229 m .47848 .66886 L .48292 .67415 L p 0 .264 .76 r
F P
0 g
s
.47848 .66886 m .46919 .66229 L .46448 .65781 L p 0 .24 .726 r
F P
0 g
s
.52008 .7067 m .53396 .71283 L .53995 .72005 L p .147 .48 .899 r
F P
0 g
s
.53396 .71283 m .52008 .7067 L .51523 .69986 L p .099 .45 .883 r
F P
0 g
s
.40181 .63242 m .40532 .63226 L .41786 .63539 L p 0 .518 .793 r
F P
0 g
s
.40532 .63226 m .40181 .63242 L .38744 .63081 L p .117 .629 .894 r
F P
0 g
s
.60512 1.02121 m .64042 1.00191 L .65782 1.01798 L p .741 .803 .901 r
F P
0 g
s
.69455 .99449 m .65782 1.01798 L .64042 1.00191 L p .739 .788 .892 r
F P
0 g
s
.36296 1.0891 m .40293 1.08889 L .38943 1.1069 L p .676 .866 .971 r
F P
0 g
s
.38943 1.1069 m .34406 1.10563 L .36296 1.0891 L p .676 .866 .971 r
F P
0 g
s
.39645 .46282 m .41591 .44176 L .42989 .45309 L p .767 .731 .82 r
F P
0 g
s
.44969 .4351 m .42989 .45309 L .41591 .44176 L p .776 .748 .828 r
F P
0 g
s
.26084 .47647 m .24884 .51237 L .21029 .50552 L p .708 .704 .845 r
F P
0 g
s
.24884 .51237 m .26084 .47647 L .29339 .48609 L p .712 .7 .837 r
F P
0 g
s
.53995 .72005 m .55451 .72523 L .56209 .73264 L p .155 .512 .914 r
F P
0 g
s
.55451 .72523 m .53995 .72005 L .53396 .71283 L p .104 .478 .896 r
F P
0 g
s
.38744 .63081 m .39074 .62904 L .40532 .63226 L p .117 .629 .894 r
F P
0 g
s
.39074 .62904 m .38744 .63081 L .37073 .62925 L p .25 .702 .955 r
F P
0 g
s
.48817 .39078 m .51467 .37867 L .51746 .39289 L p .796 .802 .857 r
F P
0 g
s
.51746 .39289 m .49408 .40482 L .48817 .39078 L p .796 .802 .857 r
F P
0 g
s
.67203 .29166 m .70567 .30107 L .68293 .31836 L p .723 .839 .936 r
F P
0 g
s
.68293 .31836 m .65358 .31162 L .67203 .29166 L p .723 .839 .936 r
F P
0 g
s
.4521 .64933 m .44543 .64478 L .43773 .64159 L p .354 0 0 r
F P
0 g
s
.542 .35317 m .57141 .34706 L .56692 .36248 L p .787 .836 .89 r
F P
0 g
s
.56692 .36248 m .54117 .36923 L .542 .35317 L p .787 .836 .89 r
F P
0 g
s
.48292 .67415 m .49375 .68086 L .49824 .68681 L p 0 .358 .83 r
F P
0 g
s
.49375 .68086 m .48292 .67415 L .47848 .66886 L p 0 .334 .81 r
F P
0 g
s
.37073 .62925 m .37386 .62567 L .39074 .62904 L p .25 .702 .955 r
F P
0 g
s
.37386 .62567 m .37073 .62925 L .3514 .62772 L p .35 .745 .985 r
F P
0 g
s
.67897 .2428 m .64165 .2185 L .65879 .19322 L p .633 .664 .862 r
F P
0 g
s
.65879 .19322 m .70164 .22026 L .67897 .2428 L p .633 .664 .862 r
F P
0 g
s
.56209 .73264 m .57692 .73655 L .58656 .7439 L p .157 .544 .926 r
F P
0 g
s
.57692 .73655 m .56209 .73264 L .55451 .72523 L p .096 .503 .903 r
F P
0 g
s
.33699 .46622 m .32166 .49461 L .29339 .48609 L p .727 .708 .832 r
F P
0 g
s
.32166 .49461 m .33699 .46622 L .3601 .47635 L p .733 .704 .824 r
F P
0 g
s
.41591 .44176 m .4381 .42254 L .44969 .4351 L p .776 .748 .828 r
F P
0 g
s
.47128 .41894 m .44969 .4351 L .4381 .42254 L p .783 .765 .837 r
F P
0 g
s
.51352 .17279 m .46968 .16742 L .46103 .13865 L p .601 .675 .892 r
F P
0 g
s
.41258 .13936 m .46103 .13865 L .46968 .16742 L p .596 .681 .901 r
F P
0 g
s
.46448 .65781 m .47332 .66377 L .47848 .66886 L p 0 .24 .726 r
F P
0 g
s
.4624 .40546 m .48817 .39078 L .49408 .40482 L p .79 .783 .846 r
F P
0 g
s
.49408 .40482 m .47128 .41894 L .4624 .40546 L p .79 .783 .846 r
F P
0 g
s
.3514 .62772 m .35436 .62209 L .37386 .62567 L p .35 .745 .985 r
F P
0 g
s
.35436 .62209 m .3514 .62772 L .32907 .6262 L p .423 .767 .996 r
F P
0 g
s
.49824 .68681 m .51032 .69341 L .51523 .69986 L p .066 .414 .863 r
F P
0 g
s
.51032 .69341 m .49824 .68681 L .49375 .68086 L p .019 .391 .849 r
F P
0 g
s
.4381 .42254 m .4624 .40546 L .47128 .41894 L p .783 .765 .837 r
F P
0 g
s
.62707 .76087 m .64218 .75997 L .6594 .7669 L p .274 .67 .97 r
F P
0 g
s
.64218 .75997 m .62707 .76087 L .61331 .75323 L p .192 .627 .946 r
F P
0 g
s
.43773 .64159 m .4286 .63848 L p .43967 .64324 L 0 .325 .683 r
F P
0 g
s
.44419 .64519 m .44277 .64439 L p .43967 .64324 L 0 .325 .683 r
F P
0 g
s
.44277 .64439 m .43773 .64159 L p .43967 .64324 L 0 .325 .683 r
F P
0 g
s
.4286 .63848 m .43494 .641 L .44419 .64519 L p 0 .325 .683 r
F P
0 g
s
.43494 .641 m .4286 .63848 L .41786 .63539 L p 0 .438 .778 r
F P
0 g
s
.42419 .6367 m .43494 .641 L p .42391 .63738 L 0 .438 .778 r
F P
0 g
s
.41786 .63539 m .41947 .63572 L p .42391 .63738 L 0 .438 .778 r
F P
0 g
s
.41947 .63572 m .42419 .6367 L p .42391 .63738 L 0 .438 .778 r
F P
0 g
s
.44419 .64519 m .43494 .641 L p .44222 .64424 L 0 .408 .802 r
F P
0 g
s
.43773 .64159 m .44419 .64519 L p .44615 .64613 L .354 0 0 r
F P
0 g
s
.45256 .64885 m .44419 .64519 L p .44222 .64424 L 0 .408 .802 r
F P
0 g
s
.44419 .64519 m .4521 .64933 L p .44615 .64613 L .354 0 0 r
F P
0 g
s
.77683 .79026 m .79248 .77605 L .83038 .78139 L p .524 .786 .993 r
F P
0 g
s
.79248 .77605 m .77683 .79026 L .74556 .78249 L p .492 .785 .997 r
F P
0 g
s
.57695 .32931 m .60878 .32744 L .5992 .34399 L p .769 .844 .909 r
F P
0 g
s
.5992 .34399 m .57141 .34706 L .57695 .32931 L p .769 .844 .909 r
F P
0 g
s
.3601 .47635 m .37816 .45179 L .39645 .46282 L p .75 .717 .821 r
F P
0 g
s
.41591 .44176 m .39645 .46282 L .37816 .45179 L p .759 .732 .828 r
F P
0 g
s
.6202 .30832 m .65358 .31162 L .63789 .32887 L p .747 .845 .924 r
F P
0 g
s
.63789 .32887 m .60878 .32744 L .6202 .30832 L p .747 .845 .924 r
F P
0 g
s
.32907 .6262 m .33187 .61824 L .35436 .62209 L p .423 .767 .996 r
F P
0 g
s
.33187 .61824 m .32907 .6262 L .30337 .62466 L p .476 .778 .997 r
F P
0 g
s
.67899 .77452 m .69398 .76918 L .71808 .7755 L p .394 .742 .992 r
F P
0 g
s
.69398 .76918 m .67899 .77452 L .6594 .7669 L p .328 .719 .982 r
F P
0 g
s
.51523 .69986 m .52823 .70605 L .53396 .71283 L p .099 .45 .883 r
F P
0 g
s
.52823 .70605 m .51523 .69986 L .51032 .69341 L p .057 .425 .869 r
F P
0 g
s
.69455 .99449 m .72734 .96801 L .75598 .98244 L p .727 .773 .889 r
F P
0 g
s
.78788 .95083 m .75598 .98244 L .72734 .96801 L p .722 .76 .882 r
F P
0 g
s
.37816 .45179 m .3601 .47635 L .33699 .46622 L p .743 .719 .829 r
F P
0 g
s
.58656 .7439 m .60115 .74621 L .61331 .75323 L p .165 .581 .935 r
F P
0 g
s
.60115 .74621 m .58656 .7439 L .57692 .73655 L p .09 .532 .907 r
F P
0 g
s
.30337 .62466 m .30598 .61403 L .33187 .61824 L p .476 .778 .997 r
F P
0 g
s
.30598 .61403 m .30337 .62466 L .27381 .62307 L p .515 .782 .993 r
F P
0 g
s
.21029 .50552 m .22334 .46557 L .26084 .47647 L p .708 .704 .845 r
F P
0 g
s
.47848 .66886 m .48881 .67515 L .49375 .68086 L p 0 .334 .81 r
F P
0 g
s
.48881 .67515 m .47848 .66886 L .47332 .66377 L p 0 .325 .797 r
F P
0 g
s
.41471 1.07285 m .45195 1.06849 L .44511 1.08551 L p .704 .871 .96 r
F P
0 g
s
.44511 1.08551 m .40293 1.08889 L .41471 1.07285 L p .704 .871 .96 r
F P
0 g
s
.45882 .65352 m .46736 .6588 L .47332 .66377 L p 0 .243 .709 r
F P
0 g
s
.53396 .71283 m .54754 .71832 L .55451 .72523 L p .104 .478 .896 r
F P
0 g
s
.54754 .71832 m .53396 .71283 L .52823 .70605 L p .061 .447 .879 r
F P
0 g
s
.27381 .62307 m .2762 .6094 L .30598 .61403 L p .515 .782 .993 r
F P
0 g
s
.2762 .6094 m .27381 .62307 L .23987 .6214 L p .544 .782 .987 r
F P
0 g
s
.51179 .36242 m .542 .35317 L .54117 .36923 L p .787 .817 .876 r
F P
0 g
s
.54117 .36923 m .51467 .37867 L .51179 .36242 L p .787 .817 .876 r
F P
0 g
s
.64042 1.00191 m .67294 .97981 L .69455 .99449 L p .739 .788 .892 r
F P
0 g
s
.72734 .96801 m .69455 .99449 L .67294 .97981 L p .735 .773 .883 r
F P
0 g
s
.23987 .6214 m .24195 .60426 L .2762 .6094 L p .544 .782 .987 r
F P
0 g
s
.24195 .60426 m .23987 .6214 L .20092 .61962 L p .566 .781 .98 r
F P
0 g
s
.49375 .68086 m .50526 .68725 L .51032 .69341 L p .019 .391 .849 r
F P
0 g
s
.50526 .68725 m .49375 .68086 L .48881 .67515 L p 0 .377 .838 r
F P
0 g
s
.64165 .2185 m .60082 .19849 L .61185 .17115 L p .623 .664 .869 r
F P
0 g
s
.61185 .17115 m .65879 .19322 L .64165 .2185 L p .623 .664 .869 r
F P
0 g
s
.55451 .72523 m .56827 .72971 L .57692 .73655 L p .096 .503 .903 r
F P
0 g
s
.56827 .72971 m .55451 .72523 L .54754 .71832 L p .044 .464 .881 r
F P
0 g
s
.37816 .45179 m .39995 .42897 L .41591 .44176 L p .759 .732 .828 r
F P
0 g
s
.4381 .42254 m .41591 .44176 L .39995 .42897 L p .767 .748 .835 r
F P
0 g
s
.31038 .45477 m .29339 .48609 L .26084 .47647 L p .721 .711 .84 r
F P
0 g
s
.29339 .48609 m .31038 .45477 L .33699 .46622 L p .727 .708 .832 r
F P
0 g
s
.55768 .18317 m .51352 .17279 L .51142 .14367 L p .607 .67 .884 r
F P
0 g
s
.46103 .13865 m .51142 .14367 L .51352 .17279 L p .601 .675 .892 r
F P
0 g
s
.52628 1.03497 m .56043 1.02179 L .56782 1.03756 L p .75 .839 .919 r
F P
0 g
s
.56782 1.03756 m .52932 1.0509 L .52628 1.03497 L p .75 .839 .919 r
F P
0 g
s
.60512 1.02121 m .56782 1.03756 L .56043 1.02179 L p .752 .822 .907 r
F P
0 g
s
.20092 .61962 m .20257 .59851 L .24195 .60426 L p .566 .781 .98 r
F P
0 g
s
.47332 .66377 m .48334 .66958 L .48881 .67515 L p 0 .325 .797 r
F P
0 g
s
.48334 .66958 m .47332 .66377 L .46736 .6588 L p 0 .334 .795 r
F P
0 g
s
.61331 .75323 m .62706 .75363 L .64218 .75997 L p .192 .627 .946 r
F P
0 g
s
.62706 .75363 m .61331 .75323 L .60115 .74621 L p .101 .573 .91 r
F P
0 g
s
.51032 .69341 m .52266 .69961 L .52823 .70605 L p .057 .425 .869 r
F P
0 g
s
.52266 .69961 m .51032 .69341 L .50526 .68725 L p .027 .408 .858 r
F P
0 g
s
.74556 .78249 m .75927 .77124 L .79248 .77605 L p .492 .785 .997 r
F P
0 g
s
.75927 .77124 m .74556 .78249 L .71808 .7755 L p .451 .779 .998 r
F P
0 g
s
.56043 1.02179 m .59353 1.00595 L .60512 1.02121 L p .752 .822 .907 r
F P
0 g
s
.64042 1.00191 m .60512 1.02121 L .59353 1.00595 L p .752 .806 .896 r
F P
0 g
s
.49182 1.04547 m .52628 1.03497 L .52932 1.0509 L p .743 .856 .932 r
F P
0 g
s
.52932 1.0509 m .49042 1.0612 L .49182 1.04547 L p .743 .856 .932 r
F P
0 g
s
.6594 .7669 m .67285 .76344 L .69398 .76918 L p .328 .719 .982 r
F P
0 g
s
.67285 .76344 m .6594 .7669 L .64218 .75997 L p .246 .682 .96 r
F P
0 g
s
.48164 .37478 m .51179 .36242 L .51467 .37867 L p .784 .798 .864 r
F P
0 g
s
.51467 .37867 m .48817 .39078 L .48164 .37478 L p .784 .798 .864 r
F P
0 g
s
.40532 .63226 m .41173 .63222 L .42419 .6367 L p .023 .542 .863 r
F P
0 g
s
.41173 .63222 m .40532 .63226 L .39074 .62904 L p .152 .624 .926 r
F P
0 g
s
.57692 .73655 m .5904 .7397 L .60115 .74621 L p .09 .532 .907 r
F P
0 g
s
.5904 .7397 m .57692 .73655 L .56827 .72971 L p .019 .481 .875 r
F P
0 g
s
.39995 .42897 m .42493 .4083 L .4381 .42254 L p .767 .748 .835 r
F P
0 g
s
.4624 .40546 m .4381 .42254 L .42493 .4083 L p .774 .764 .844 r
F P
0 g
s
.60082 .19849 m .55768 .18317 L .56222 .15453 L p .615 .666 .876 r
F P
0 g
s
.56222 .15453 m .61185 .17115 L .60082 .19849 L p .615 .666 .876 r
F P
0 g
s
.52823 .70605 m .54106 .71177 L .54754 .71832 L p .061 .447 .879 r
F P
0 g
s
.54106 .71177 m .52823 .70605 L .52266 .69961 L p .031 .424 .865 r
F P
0 g
s
.51142 .14367 m .56222 .15453 L .55768 .18317 L p .607 .67 .884 r
F P
0 g
s
.33699 .46622 m .35715 .43933 L .37816 .45179 L p .743 .719 .829 r
F P
0 g
s
.39995 .42897 m .37816 .45179 L .35715 .43933 L p .752 .733 .835 r
F P
0 g
s
.54329 .33472 m .57695 .32931 L .57141 .34706 L p .774 .827 .894 r
F P
0 g
s
.57141 .34706 m .542 .35317 L .54329 .33472 L p .774 .827 .894 r
F P
0 g
s
.35715 .43933 m .33699 .46622 L .31038 .45477 L p .736 .721 .837 r
F P
0 g
s
.48881 .67515 m .49995 .68126 L .50526 .68725 L p 0 .377 .838 r
F P
0 g
s
.49995 .68126 m .48881 .67515 L .48334 .66958 L p 0 .376 .835 r
F P
0 g
s
.44419 .64519 m .45256 .64885 L .46049 .65385 L p 0 .333 .75 r
F P
0 g
s
.45241 .39014 m .48164 .37478 L .48817 .39078 L p .78 .78 .853 r
F P
0 g
s
.48817 .39078 m .4624 .40546 L .45241 .39014 L p .78 .78 .853 r
F P
0 g
s
.69369 .26852 m .73225 .28103 L .70567 .30107 L p .716 .825 .933 r
F P
0 g
s
.70567 .30107 m .67203 .29166 L .69369 .26852 L p .716 .825 .933 r
F P
0 g
s
.42493 .4083 m .45241 .39014 L .4624 .40546 L p .774 .764 .844 r
F P
0 g
s
.39074 .62904 m .39732 .62745 L .41173 .63222 L p .152 .624 .926 r
F P
0 g
s
.39732 .62745 m .39074 .62904 L .37386 .62567 L p .261 .682 .966 r
F P
0 g
s
.46736 .6588 m .47724 .66405 L .48334 .66958 L p 0 .334 .795 r
F P
0 g
s
.47724 .66405 m .46736 .6588 L .46049 .65385 L p 0 .363 .808 r
F P
0 g
s
.54754 .71832 m .56047 .72327 L .56827 .72971 L p .044 .464 .881 r
F P
0 g
s
.56047 .72327 m .54754 .71832 L .54106 .71177 L p .004 .43 .862 r
F P
0 g
s
.59353 1.00595 m .62487 .98754 L .64042 1.00191 L p .752 .806 .896 r
F P
0 g
s
.67294 .97981 m .64042 1.00191 L .62487 .98754 L p .749 .789 .885 r
F P
0 g
s
.45778 1.05332 m .49182 1.04547 L .49042 1.0612 L p .732 .871 .946 r
F P
0 g
s
.49042 1.0612 m .45195 1.06849 L .45778 1.05332 L p .732 .871 .946 r
F P
0 g
s
.50526 .68725 m .51715 .69338 L .52266 .69961 L p .027 .408 .858 r
F P
0 g
s
.51715 .69338 m .50526 .68725 L .49995 .68126 L p .011 .4 .852 r
F P
0 g
s
.32608 1.08634 m .36296 1.0891 L .34406 1.10563 L p .652 .868 .98 r
F P
0 g
s
.34406 1.10563 m .30205 1.10099 L .32608 1.08634 L p .652 .868 .98 r
F P
0 g
s
.58369 .30884 m .6202 .30832 L .60878 .32744 L p .756 .832 .91 r
F P
0 g
s
.60878 .32744 m .57695 .32931 L .58369 .30884 L p .756 .832 .91 r
F P
0 g
s
.60115 .74621 m .6138 .74776 L .62706 .75363 L p .101 .573 .91 r
F P
0 g
s
.6138 .74776 m .60115 .74621 L .5904 .7397 L p .007 .508 .865 r
F P
0 g
s
.27971 .44177 m .26084 .47647 L .22334 .46557 L p .716 .714 .847 r
F P
0 g
s
.26084 .47647 m .27971 .44177 L .31038 .45477 L p .721 .711 .84 r
F P
0 g
s
.43494 .641 m .44345 .64369 L .45256 .64885 L p 0 .408 .802 r
F P
0 g
s
.44345 .64369 m .43494 .641 L .42419 .6367 L p 0 .488 .859 r
F P
0 g
s
.63372 .2862 m .67203 .29166 L .65358 .31162 L p .736 .831 .924 r
F P
0 g
s
.65358 .31162 m .6202 .30832 L .63372 .2862 L p .736 .831 .924 r
F P
0 g
s
.71808 .7755 m .7302 .76688 L .75927 .77124 L p .451 .779 .998 r
F P
0 g
s
.7302 .76688 m .71808 .7755 L .69398 .76918 L p .396 .765 .993 r
F P
0 g
s
.37386 .62567 m .3807 .62233 L .39732 .62745 L p .261 .682 .966 r
F P
0 g
s
.3807 .62233 m .37386 .62567 L .35436 .62209 L p .347 .72 .986 r
F P
0 g
s
.64218 .75997 m .65437 .75818 L .67285 .76344 L p .246 .682 .96 r
F P
0 g
s
.65437 .75818 m .64218 .75997 L .62706 .75363 L p .146 .628 .921 r
F P
0 g
s
.56827 .72971 m .58087 .7336 L .5904 .7397 L p .019 .481 .875 r
F P
0 g
s
.58087 .7336 m .56827 .72971 L .56047 .72327 L p 0 .433 .845 r
F P
0 g
s
.52266 .69961 m .53496 .70549 L .54106 .71177 L p .031 .424 .865 r
F P
0 g
s
.53496 .70549 m .52266 .69961 L .51715 .69338 L p .015 .409 .857 r
F P
0 g
s
.37952 1.07442 m .41471 1.07285 L .40293 1.08889 L p .682 .879 .972 r
F P
0 g
s
.40293 1.08889 m .36296 1.0891 L .37952 1.07442 L p .682 .879 .972 r
F P
0 g
s
.48334 .66958 m .4943 .67534 L .49995 .68126 L p 0 .376 .835 r
F P
0 g
s
.4943 .67534 m .48334 .66958 L .47724 .66405 L p 0 .389 .84 r
F P
0 g
s
.46049 .65385 m .47039 .65847 L .47724 .66405 L p 0 .363 .808 r
F P
0 g
s
.47039 .65847 m .46049 .65385 L .45256 .64885 L p 0 .407 .833 r
F P
0 g
s
.35715 .43933 m .38166 .41445 L .39995 .42897 L p .752 .733 .835 r
F P
0 g
s
.42493 .4083 m .39995 .42897 L .38166 .41445 L p .759 .747 .842 r
F P
0 g
s
.67294 .97981 m .70195 .9551 L .72734 .96801 L p .735 .773 .883 r
F P
0 g
s
.75542 .9388 m .72734 .96801 L .70195 .9551 L p .73 .759 .876 r
F P
0 g
s
.72734 .96801 m .75542 .9388 L .78788 .95083 L p .722 .76 .882 r
F P
0 g
s
.50876 .34378 m .54329 .33472 L .542 .35317 L p .775 .81 .881 r
F P
0 g
s
.542 .35317 m .51179 .36242 L .50876 .34378 L p .775 .81 .881 r
F P
0 g
s
.35436 .62209 m .36155 .61675 L .3807 .62233 L p .347 .72 .986 r
F P
0 g
s
.36155 .61675 m .35436 .62209 L .33187 .61824 L p .413 .742 .993 r
F P
0 g
s
.54106 .71177 m .55339 .71712 L .56047 .72327 L p .004 .43 .862 r
F P
0 g
s
.55339 .71712 m .54106 .71177 L .53496 .70549 L p 0 .407 .849 r
F P
0 g
s
.42419 .6367 m .43296 .63829 L .44345 .64369 L p 0 .488 .859 r
F P
0 g
s
.43296 .63829 m .42419 .6367 L .41173 .63222 L p .097 .561 .91 r
F P
0 g
s
.49995 .68126 m .51161 .68726 L .51715 .69338 L p .011 .4 .852 r
F P
0 g
s
.51161 .68726 m .49995 .68126 L .4943 .67534 L p .011 .404 .854 r
F P
0 g
s
.81369 .91643 m .78788 .95083 L .75542 .9388 L p .716 .747 .876 r
F P
0 g
s
.33297 .42517 m .31038 .45477 L .27971 .44177 L p .73 .723 .844 r
F P
0 g
s
.31038 .45477 m .33297 .42517 L .35715 .43933 L p .736 .721 .837 r
F P
0 g
s
.62487 .98754 m .65373 .96667 L .67294 .97981 L p .749 .789 .885 r
F P
0 g
s
.70195 .9551 m .67294 .97981 L .65373 .96667 L p .745 .773 .876 r
F P
0 g
s
.5904 .7397 m .60218 .74226 L .6138 .74776 L p .007 .508 .865 r
F P
0 g
s
.60218 .74226 m .5904 .7397 L .58087 .7336 L p 0 .44 .816 r
F P
0 g
s
.38166 .41445 m .35715 .43933 L .33297 .42517 L p .744 .734 .842 r
F P
0 g
s
.69398 .76918 m .70479 .76289 L .7302 .76688 L p .396 .765 .993 r
F P
0 g
s
.70479 .76289 m .69398 .76918 L .67285 .76344 L p .322 .74 .976 r
F P
0 g
s
.47724 .66405 m .48822 .6694 L .4943 .67534 L p 0 .389 .84 r
F P
0 g
s
.48822 .6694 m .47724 .66405 L .47039 .65847 L p 0 .415 .854 r
F P
0 g
s
.45256 .64885 m .46267 .65273 L .47039 .65847 L p 0 .407 .833 r
F P
0 g
s
.46267 .65273 m .45256 .64885 L .44345 .64369 L p .004 .462 .868 r
F P
0 g
s
.62706 .75363 m .63824 .75331 L .65437 .75818 L p .146 .628 .921 r
F P
0 g
s
.63824 .75331 m .62706 .75363 L .6138 .74776 L p .032 .556 .863 r
F P
0 g
s
.38166 .41445 m .4099 .39208 L .42493 .4083 L p .759 .747 .842 r
F P
0 g
s
.45241 .39014 m .42493 .4083 L .4099 .39208 L p .765 .762 .85 r
F P
0 g
s
.51715 .69338 m .52914 .69935 L .53496 .70549 L p .015 .409 .857 r
F P
0 g
s
.52914 .69935 m .51715 .69338 L .51161 .68726 L p .015 .406 .855 r
F P
0 g
s
.33187 .61824 m .33949 .61061 L .36155 .61675 L p .413 .742 .993 r
F P
0 g
s
.33949 .61061 m .33187 .61824 L .30598 .61403 L p .464 .755 .993 r
F P
0 g
s
.56047 .72327 m .57243 .7278 L .58087 .7336 L p 0 .433 .845 r
F P
0 g
s
.57243 .7278 m .56047 .72327 L .55339 .71712 L p 0 .394 .823 r
F P
0 g
s
.42492 1.05859 m .45778 1.05332 L .45195 1.06849 L p .714 .885 .96 r
F P
0 g
s
.45195 1.06849 m .41471 1.07285 L .42492 1.05859 L p .714 .885 .96 r
F P
0 g
s
.47436 .35646 m .50876 .34378 L .51179 .36242 L p .773 .794 .87 r
F P
0 g
s
.51179 .36242 m .48164 .37478 L .47436 .35646 L p .773 .794 .87 r
F P
0 g
s
.41173 .63222 m .42091 .63254 L .43296 .63829 L p .097 .561 .91 r
F P
0 g
s
.42091 .63254 m .41173 .63222 L .39732 .62745 L p .197 .622 .947 r
F P
0 g
s
.52335 1.02074 m .55367 1.00768 L .56043 1.02179 L p .762 .846 .914 r
F P
0 g
s
.56043 1.02179 m .52628 1.03497 L .52335 1.02074 L p .762 .846 .914 r
F P
0 g
s
.59353 1.00595 m .56043 1.02179 L .55367 1.00768 L p .764 .827 .901 r
F P
0 g
s
.84098 .76242 m .83038 .78139 L .79248 .77605 L p .537 .805 .995 r
F P
0 g
s
.22334 .46557 m .24433 .42692 L .27971 .44177 L p .716 .714 .847 r
F P
0 g
s
.4099 .39208 m .44109 .37264 L .45241 .39014 L p .765 .762 .85 r
F P
0 g
s
.48164 .37478 m .45241 .39014 L .44109 .37264 L p .77 .778 .859 r
F P
0 g
s
.53496 .70549 m .54691 .71115 L .55339 .71712 L p 0 .407 .849 r
F P
0 g
s
.54691 .71115 m .53496 .70549 L .52914 .69935 L p 0 .395 .844 r
F P
0 g
s
.44109 .37264 m .47436 .35646 L .48164 .37478 L p .77 .778 .859 r
F P
0 g
s
.4943 .67534 m .50593 .68115 L .51161 .68726 L p .011 .404 .854 r
F P
0 g
s
.50593 .68115 m .4943 .67534 L .48822 .6694 L p .028 .418 .862 r
F P
0 g
s
.55367 1.00768 m .58309 .99229 L .59353 1.00595 L p .764 .827 .901 r
F P
0 g
s
.62487 .98754 m .59353 1.00595 L .58309 .99229 L p .763 .809 .889 r
F P
0 g
s
.54509 .31346 m .58369 .30884 L .57695 .32931 L p .761 .818 .897 r
F P
0 g
s
.57695 .32931 m .54329 .33472 L .54509 .31346 L p .761 .818 .897 r
F P
0 g
s
.30598 .61403 m .3141 .60378 L .33949 .61061 L p .464 .755 .993 r
F P
0 g
s
.3141 .60378 m .30598 .61403 L .2762 .6094 L p .502 .762 .989 r
F P
0 g
s
.49279 1.03145 m .52335 1.02074 L .52628 1.03497 L p .756 .865 .928 r
F P
0 g
s
.52628 1.03497 m .49182 1.04547 L .49279 1.03145 L p .756 .865 .928 r
F P
0 g
s
.44345 .64369 m .45392 .64672 L .46267 .65273 L p .004 .462 .868 r
F P
0 g
s
.45392 .64672 m .44345 .64369 L .43296 .63829 L p .082 .519 .903 r
F P
0 g
s
.47039 .65847 m .48157 .66331 L .48822 .6694 L p 0 .415 .854 r
F P
0 g
s
.48157 .66331 m .47039 .65847 L .46267 .65273 L p .035 .451 .875 r
F P
0 g
s
.58087 .7336 m .592 .73706 L .60218 .74226 L p 0 .44 .816 r
F P
0 g
s
.592 .73706 m .58087 .7336 L .57243 .7278 L p 0 .377 .773 r
F P
0 g
s
.67285 .76344 m .68261 .75921 L .70479 .76289 L p .322 .74 .976 r
F P
0 g
s
.68261 .75921 m .67285 .76344 L .65437 .75818 L p .227 .697 .942 r
F P
0 g
s
.39732 .62745 m .40707 .62634 L .42091 .63254 L p .197 .622 .947 r
F P
0 g
s
.40707 .62634 m .39732 .62745 L .3807 .62233 L p .284 .668 .971 r
F P
0 g
s
.6138 .74776 m .62417 .74875 L .63824 .75331 L p .032 .556 .863 r
F P
0 g
s
.62417 .74875 m .6138 .74776 L .60218 .74226 L p 0 .468 .789 r
F P
0 g
s
.51161 .68726 m .5235 .69326 L .52914 .69935 L p .015 .406 .855 r
F P
0 g
s
.5235 .69326 m .51161 .68726 L .50593 .68115 L p .03 .413 .861 r
F P
0 g
s
.55339 .71712 m .56492 .7222 L .57243 .7278 L p 0 .394 .823 r
F P
0 g
s
.56492 .7222 m .55339 .71712 L .54691 .71115 L p 0 .369 .812 r
F P
0 g
s
.58309 .99229 m .61096 .97466 L .62487 .98754 L p .763 .809 .889 r
F P
0 g
s
.65373 .96667 m .62487 .98754 L .61096 .97466 L p .759 .791 .878 r
F P
0 g
s
.79248 .77605 m .80159 .7607 L .84098 .76242 L p .537 .805 .995 r
F P
0 g
s
.80159 .7607 m .79248 .77605 L .75927 .77124 L p .507 .806 .999 r
F P
0 g
s
.33297 .42517 m .36064 .3979 L .38166 .41445 L p .744 .734 .842 r
F P
0 g
s
.4099 .39208 m .38166 .41445 L .36064 .3979 L p .751 .747 .849 r
F P
0 g
s
.59179 .28516 m .63372 .2862 L .6202 .30832 L p .745 .821 .911 r
F P
0 g
s
.6202 .30832 m .58369 .30884 L .59179 .28516 L p .745 .821 .911 r
F P
0 g
s
.2762 .6094 m .28487 .59614 L .3141 .60378 L p .502 .762 .989 r
F P
0 g
s
.28487 .59614 m .2762 .6094 L .24195 .60426 L p .531 .765 .983 r
F P
0 g
s
.48822 .6694 m .50002 .67494 L .50593 .68115 L p .028 .418 .862 r
F P
0 g
s
.50002 .67494 m .48822 .6694 L .48157 .66331 L p .059 .443 .876 r
F P
0 g
s
.52914 .69935 m .54093 .70527 L .54691 .71115 L p 0 .395 .844 r
F P
0 g
s
.54093 .70527 m .52914 .69935 L .5235 .69326 L p 0 .396 .848 r
F P
0 g
s
.65373 .96667 m .67945 .94355 L .70195 .9551 L p .745 .773 .876 r
F P
0 g
s
.72673 .92804 m .70195 .9551 L .67945 .94355 L p .738 .758 .868 r
F P
0 g
s
.70195 .9551 m .72673 .92804 L .75542 .9388 L p .73 .759 .876 r
F P
0 g
s
.46268 1.03982 m .49279 1.03145 L .49182 1.04547 L p .745 .883 .943 r
F P
0 g
s
.49182 1.04547 m .45778 1.05332 L .46268 1.03982 L p .745 .883 .943 r
F P
0 g
s
.43296 .63829 m .44399 .64034 L .45392 .64672 L p .082 .519 .903 r
F P
0 g
s
.44399 .64034 m .43296 .63829 L .42091 .63254 L p .163 .573 .934 r
F P
0 g
s
.64968 .26053 m .69369 .26852 L .67203 .29166 L p .727 .82 .922 r
F P
0 g
s
.67203 .29166 m .63372 .2862 L .64968 .26053 L p .727 .82 .922 r
F P
0 g
s
.52368 1.23816 m .47288 1.22578 L .47665 1.2069 L p .505 .682 .945 r
F P
0 g
s
.47288 1.22578 m .42318 1.2097 L .43268 1.19142 L p .526 .676 .933 r
F P
0 g
s
.43268 1.19142 m .47665 1.2069 L .47288 1.22578 L p .526 .676 .933 r
F P
0 g
s
.3051 .409 m .27971 .44177 L .24433 .42692 L p .724 .725 .851 r
F P
0 g
s
.27971 .44177 m .3051 .409 L .33297 .42517 L p .73 .723 .844 r
F P
0 g
s
.46267 .65273 m .47425 .65697 L .48157 .66331 L p .035 .451 .875 r
F P
0 g
s
.47425 .65697 m .46267 .65273 L .45392 .64672 L p .091 .493 .9 r
F P
0 g
s
.65437 .75818 m .66329 .75577 L .68261 .75921 L p .227 .697 .942 r
F P
0 g
s
.66329 .75577 m .65437 .75818 L .63824 .75331 L p .106 .629 .881 r
F P
0 g
s
.3807 .62233 m .39116 .61956 L .40707 .62634 L p .284 .668 .971 r
F P
0 g
s
.39116 .61956 m .3807 .62233 L .36155 .61675 L p .356 .7 .984 r
F P
0 g
s
.57243 .7278 m .58311 .73204 L .592 .73706 L p 0 .377 .773 r
F P
0 g
s
.58311 .73204 m .57243 .7278 L .56492 .7222 L p 0 .328 .745 r
F P
0 g
s
.77803 .9072 m .75542 .9388 L .72673 .92804 L p .723 .745 .869 r
F P
0 g
s
.75542 .9388 m .77803 .9072 L .81369 .91643 L p .716 .747 .876 r
F P
0 g
s
.34717 1.07337 m .37952 1.07442 L .36296 1.0891 L p .653 .882 .982 r
F P
0 g
s
.36296 1.0891 m .32608 1.08634 L .34717 1.07337 L p .653 .882 .982 r
F P
0 g
s
.60218 .74226 m .61195 .74442 L .62417 .74875 L p 0 .468 .789 r
F P
0 g
s
.61195 .74442 m .60218 .74226 L .592 .73706 L p 0 .375 .71 r
F P
0 g
s
.42318 1.2097 m .37554 1.18994 L .39063 1.17269 L p .547 .673 .921 r
F P
0 g
s
.39063 1.17269 m .43268 1.19142 L .42318 1.2097 L p .547 .673 .921 r
F P
0 g
s
.50553 .32231 m .54509 .31346 L .54329 .33472 L p .763 .804 .885 r
F P
0 g
s
.54329 .33472 m .50876 .34378 L .50553 .32231 L p .763 .804 .885 r
F P
0 g
s
.36064 .3979 m .33297 .42517 L .3051 .409 L p .737 .735 .849 r
F P
0 g
s
.50593 .68115 m .51794 .68711 L .5235 .69326 L p .03 .413 .861 r
F P
0 g
s
.51794 .68711 m .50593 .68115 L .50002 .67494 L p .06 .43 .871 r
F P
0 g
s
.54691 .71115 m .55822 .7167 L .56492 .7222 L p 0 .369 .812 r
F P
0 g
s
.55822 .7167 m .54691 .71115 L .54093 .70527 L p 0 .36 .815 r
F P
0 g
s
.75927 .77124 m .76719 .75908 L .80159 .7607 L p .507 .806 .999 r
F P
0 g
s
.76719 .75908 m .75927 .77124 L .7302 .76688 L p .466 .803 .999 r
F P
0 g
s
.39395 1.06139 m .42492 1.05859 L .41471 1.07285 L p .688 .894 .972 r
F P
0 g
s
.41471 1.07285 m .37952 1.07442 L .39395 1.06139 L p .688 .894 .972 r
F P
0 g
s
.61096 .97466 m .63664 .9549 L .65373 .96667 L p .759 .791 .878 r
F P
0 g
s
.67945 .94355 m .65373 .96667 L .63664 .9549 L p .754 .773 .869 r
F P
0 g
s
.24195 .60426 m .25121 .58754 L .28487 .59614 L p .531 .765 .983 r
F P
0 g
s
.25121 .58754 m .24195 .60426 L .20257 .59851 L p .554 .766 .977 r
F P
0 g
s
.57457 1.24684 m .52368 1.23816 L .52165 1.21908 L p .484 .688 .957 r
F P
0 g
s
.47665 1.2069 m .52165 1.21908 L .52368 1.23816 L p .505 .682 .945 r
F P
0 g
s
.36064 .3979 m .39267 .37353 L .4099 .39208 L p .751 .747 .849 r
F P
0 g
s
.44109 .37264 m .4099 .39208 L .39267 .37353 L p .756 .761 .856 r
F P
0 g
s
.48157 .66331 m .49376 .6685 L .50002 .67494 L p .059 .443 .876 r
F P
0 g
s
.49376 .6685 m .48157 .66331 L .47425 .65697 L p .102 .474 .894 r
F P
0 g
s
.5235 .69326 m .53533 .69936 L .54093 .70527 L p 0 .396 .848 r
F P
0 g
s
.53533 .69936 m .5235 .69326 L .51794 .68711 L p .027 .408 .858 r
F P
0 g
s
.29316 1.08087 m .32608 1.08634 L .30205 1.10099 L p .624 .866 .988 r
F P
0 g
s
.30205 1.10099 m .26436 1.09326 L .29316 1.08087 L p .624 .866 .988 r
F P
0 g
s
.42091 .63254 m .43268 .63347 L .44399 .64034 L p .163 .573 .934 r
F P
0 g
s
.43268 .63347 m .42091 .63254 L .40707 .62634 L p .241 .619 .957 r
F P
0 g
s
.63824 .75331 m .64651 .75252 L .66329 .75577 L p .106 .629 .881 r
F P
0 g
s
.64651 .75252 m .63824 .75331 L .62417 .74875 L p 0 .532 .79 r
F P
0 g
s
.36155 .61675 m .37287 .61209 L .39116 .61956 L p .356 .7 .984 r
F P
0 g
s
.37287 .61209 m .36155 .61675 L .33949 .61061 L p .414 .721 .988 r
F P
0 g
s
.45392 .64672 m .46612 .65027 L .47425 .65697 L p .091 .493 .9 r
F P
0 g
s
.46612 .65027 m .45392 .64672 L .44399 .64034 L p .154 .537 .923 r
F P
0 g
s
.56492 .7222 m .57534 .72714 L .58311 .73204 L p 0 .328 .745 r
F P
0 g
s
.57534 .72714 m .56492 .7222 L .55822 .7167 L p 0 .3 .739 r
F P
0 g
s
.60136 .74024 m .59222 .73614 L p .59902 .7391 L .427 0 0 r
F P
0 g
s
.60136 .74024 m .61195 .74442 L p .60368 .74137 L 0 .375 .71 r
F P
0 g
s
.62417 .74875 m .61195 .74442 L p .62618 .74796 L .18 0 0 r
F P
0 g
s
.63197 .7494 m .6305 .74928 L p .62618 .74796 L .18 0 0 r
F P
0 g
s
.6305 .74928 m .62417 .74875 L p .62618 .74796 L .18 0 0 r
F P
0 g
s
.60557 .74166 m .60731 .74259 L .60136 .74024 L p .316 0 0 r
F P
0 g
s
.61944 .74635 m .63197 .7494 L p .62367 .74733 L .18 0 0 r
F P
0 g
s
.61195 .74442 m .61944 .74635 L p .62367 .74733 L .18 0 0 r
F P
0 g
s
.61944 .74635 m .61195 .74442 L p .61035 .74379 L .316 0 0 r
F P
0 g
s
.61944 .74635 m .60868 .74332 L p .61517 .74536 L .397 0 0 r
F P
0 g
s
.62442 .74826 m .61944 .74635 L p .61517 .74536 L .397 0 0 r
F P
0 g
s
.60868 .74332 m .61944 .74635 L p .60557 .74166 L .316 0 0 r
F P
0 g
s
.60136 .74024 m .60255 .74074 L p .60557 .74166 L .316 0 0 r
F P
0 g
s
.60255 .74074 m .60868 .74332 L p .60557 .74166 L .316 0 0 r
F P
0 g
s
.60868 .74332 m .60136 .74024 L p .59902 .7391 L .427 0 0 r
F P
0 g
s
.592 .73706 m .60136 .74024 L p .60368 .74137 L 0 .375 .71 r
F P
0 g
s
.592 .73706 m .58311 .73204 L p .59336 .73665 L .291 0 0 r
F P
0 g
s
.60136 .74024 m .59807 .73912 L p .59336 .73665 L .291 0 0 r
F P
0 g
s
.59222 .73614 m .60136 .74024 L p .5938 .73684 L .291 0 0 r
F P
0 g
s
.58311 .73204 m .59222 .73614 L p .5938 .73684 L .291 0 0 r
F P
0 g
s
.59222 .73614 m .58755 .73404 L p .58312 .73129 L .351 0 0 r
F P
0 g
s
.58439 .73206 m .59222 .73614 L p .58523 .73241 L .351 0 0 r
F P
0 g
s
.58097 .73014 m .58439 .73206 L .58523 .73241 L .351 0 0 r
F
.57772 .72791 m .58439 .73206 L p .57784 .728 L 0 .188 .604 r
F P
0 g
s
.5751 .7263 m .57772 .72791 L .57784 .728 L 0 .188 .604 r
F
.57211 .72363 m .57772 .72791 L p .5715 .72352 L 0 .189 .644 r
F P
0 g
s
.56269 .7173 m .57211 .72363 L p .5715 .72352 L 0 .189 .644 r
F P
0 g
s
.57211 .72363 m .56745 .71913 L p .57272 .72373 L 0 .088 .576 r
F P
0 g
s
.57772 .72791 m .57211 .72363 L p .5776 .72782 L .527 0 0 r
F P
0 g
s
.57219 .72449 m .57772 .72791 L p .5751 .7263 L 0 .188 .604 r
F P
0 g
s
.58311 .73204 m .57534 .72714 L p .58312 .73129 L .351 0 0 r
F P
0 g
s
.57534 .72714 m .57783 .72849 L p .58097 .73014 L .351 0 0 r
F P
0 g
s
.57783 .72849 m .58439 .73206 L p .58097 .73014 L .351 0 0 r
F P
0 g
s
.58755 .73404 m .58311 .73204 L p .58312 .73129 L .351 0 0 r
F P
0 g
s
.58439 .73206 m .57534 .72714 L .56857 .72225 L p 0 .188 .604 r
F P
0 g
s
.57772 .72791 m .56857 .72225 L .56269 .7173 L p 0 .189 .644 r
F P
0 g
s
.5802 .73028 m .58541 .73379 L p .5799 .72958 L .527 0 0 r
F P
0 g
s
.57211 .72363 m .5802 .73028 L p .5799 .72958 L .527 0 0 r
F P
0 g
s
.5802 .73028 m .57211 .72363 L p .57272 .72373 L 0 .088 .576 r
F P
0 g
s
.5761 .7265 m .5802 .73028 L p .57492 .72566 L 0 .088 .576 r
F P
0 g
s
.56745 .71913 m .5761 .7265 L p .57492 .72566 L 0 .088 .576 r
F P
0 g
s
.5761 .7265 m .57304 .72238 L p .57728 .72734 L 0 .062 .607 r
F P
0 g
s
.5802 .73028 m .5761 .7265 L p .5805 .73098 L .627 .105 0 r
F P
0 g
s
.58541 .73379 m .57772 .72791 L p .5776 .72782 L .527 0 0 r
F P
0 g
s
.58439 .73206 m .57772 .72791 L p .58354 .7317 L .545 0 0 r
F P
0 g
s
.57772 .72791 m .58541 .73379 L .59181 .73709 L p .545 0 0 r
F P
0 g
s
.58331 .73439 m .58675 .73735 L p .58234 .73286 L .627 .105 0 r
F P
0 g
s
.5761 .7265 m .58331 .73439 L p .58234 .73286 L .627 .105 0 r
F P
0 g
s
.58675 .73735 m .5802 .73028 L p .5805 .73098 L .627 .105 0 r
F P
0 g
s
.5802 .73028 m .58675 .73735 L .59142 .74 L p .702 .162 0 r
F P
0 g
s
.59142 .74 m .58541 .73379 L .5802 .73028 L p .702 .162 0 r
F P
0 g
s
.57304 .72238 m .58104 .73105 L .58331 .73439 L p 0 .062 .607 r
F P
0 g
s
.58331 .73439 m .58104 .73105 L p .58428 .73592 L 0 0 .475 r
F P
0 g
s
.58888 .74285 m .58331 .73439 L p .58428 .73592 L 0 0 .475 r
F P
0 g
s
.58331 .73439 m .5761 .7265 L p .57728 .72734 L 0 .062 .607 r
F P
0 g
s
.59181 .73709 m .58439 .73206 L p .58354 .7317 L .545 0 0 r
F P
0 g
s
.56857 .72225 m .57219 .72449 L p .5751 .7263 L 0 .188 .604 r
F P
0 g
s
.59222 .73614 m .58439 .73206 L p .59054 .73539 L .506 0 0 r
F P
0 g
s
.59054 .73539 m .59064 .73544 L .59222 .73614 L .506 0 0 r
F
.59807 .73912 m .592 .73706 L p .59336 .73665 L .291 0 0 r
F P
0 g
s
.59953 .74025 m .59222 .73614 L p .59064 .73544 L .506 0 0 r
F P
0 g
s
.46617 .33539 m .50553 .32231 L .50876 .34378 L p .763 .789 .875 r
F P
0 g
s
.50876 .34378 m .47436 .35646 L .46617 .33539 L p .763 .789 .875 r
F P
0 g
s
.7302 .76688 m .73719 .75753 L .76719 .75908 L p .466 .803 .999 r
F P
0 g
s
.73719 .75753 m .7302 .76688 L .70479 .76289 L p .409 .791 .991 r
F P
0 g
s
.37554 1.18994 m .33096 1.16661 L .3514 1.1508 L p .567 .671 .909 r
F P
0 g
s
.3514 1.1508 m .39063 1.17269 L .37554 1.18994 L p .567 .671 .909 r
F P
0 g
s
.43368 1.04593 m .46268 1.03982 L .45778 1.05332 L p .725 .899 .957 r
F P
0 g
s
.45778 1.05332 m .42492 1.05859 L .43368 1.04593 L p .725 .899 .957 r
F P
0 g
s
.39267 .37353 m .42818 .35256 L .44109 .37264 L p .756 .761 .856 r
F P
0 g
s
.47436 .35646 m .44109 .37264 L .42818 .35256 L p .76 .775 .865 r
F P
0 g
s
.54093 .70527 m .55221 .71122 L .55822 .7167 L p 0 .36 .815 r
F P
0 g
s
.55221 .71122 m .54093 .70527 L .53533 .69936 L p 0 .367 .827 r
F P
0 g
s
.52048 1.00802 m .54744 .99505 L .55367 1.00768 L p .776 .852 .908 r
F P
0 g
s
.55367 1.00768 m .52335 1.02074 L .52048 1.00802 L p .776 .852 .908 r
F P
0 g
s
.58309 .99229 m .55367 1.00768 L .54744 .99505 L p .777 .831 .895 r
F P
0 g
s
.50002 .67494 m .51236 .68078 L .51794 .68711 L p .06 .43 .871 r
F P
0 g
s
.51236 .68078 m .50002 .67494 L .49376 .6685 L p .1 .455 .885 r
F P
0 g
s
.54744 .99505 m .57365 .98005 L .58309 .99229 L p .777 .831 .895 r
F P
0 g
s
.61096 .97466 m .58309 .99229 L .57365 .98005 L p .774 .811 .882 r
F P
0 g
s
.83264 .87971 m .81369 .91643 L .77803 .9072 L p .709 .735 .872 r
F P
0 g
s
.20257 .59851 m .21245 .57779 L .25121 .58754 L p .554 .766 .977 r
F P
0 g
s
.42818 .35256 m .46617 .33539 L .47436 .35646 L p .76 .775 .865 r
F P
0 g
s
.62417 .74875 m .63197 .7494 L .64651 .75252 L p 0 .532 .79 r
F P
0 g
s
.49336 1.01894 m .52048 1.00802 L .52335 1.02074 L p .771 .874 .923 r
F P
0 g
s
.52335 1.02074 m .49279 1.03145 L .49336 1.01894 L p .771 .874 .923 r
F P
0 g
s
.54745 .28887 m .59179 .28516 L .58369 .30884 L p .75 .81 .9 r
F P
0 g
s
.58369 .30884 m .54509 .31346 L .54745 .28887 L p .75 .81 .9 r
F P
0 g
s
.47425 .65697 m .48705 .66173 L .49376 .6685 L p .102 .474 .894 r
F P
0 g
s
.48705 .66173 m .47425 .65697 L .46612 .65027 L p .154 .509 .912 r
F P
0 g
s
.70479 .76289 m .71107 .75603 L .73719 .75753 L p .409 .791 .991 r
F P
0 g
s
.71107 .75603 m .70479 .76289 L .68261 .75921 L p .331 .766 .968 r
F P
0 g
s
.51794 .68711 m .53003 .69332 L .53533 .69936 L p .027 .408 .858 r
F P
0 g
s
.53003 .69332 m .51794 .68711 L .51236 .68078 L p .073 .428 .871 r
F P
0 g
s
.57365 .98005 m .59851 .9631 L .61096 .97466 L p .774 .811 .882 r
F P
0 g
s
.63664 .9549 m .61096 .97466 L .59851 .9631 L p .77 .792 .871 r
F P
0 g
s
.40707 .62634 m .41977 .62597 L .43268 .63347 L p .241 .619 .957 r
F P
0 g
s
.41977 .62597 m .40707 .62634 L .39116 .61956 L p .311 .655 .971 r
F P
0 g
s
.62456 1.25191 m .57457 1.24684 L .56677 1.22799 L p .463 .696 .968 r
F P
0 g
s
.52165 1.21908 m .56677 1.22799 L .57457 1.24684 L p .484 .688 .957 r
F P
0 g
s
.55822 .7167 m .56857 .72225 L .57534 .72714 L p 0 .3 .739 r
F P
0 g
s
.56857 .72225 m .55822 .7167 L .55221 .71122 L p 0 .296 .755 r
F P
0 g
s
.33949 .61061 m .35184 .60377 L .37287 .61209 L p .414 .721 .988 r
F P
0 g
s
.35184 .60377 m .33949 .61061 L .3141 .60378 L p .459 .735 .987 r
F P
0 g
s
.63664 .9549 m .65954 .93318 L .67945 .94355 L p .754 .773 .869 r
F P
0 g
s
.70141 .91839 m .67945 .94355 L .65954 .93318 L p .747 .756 .86 r
F P
0 g
s
.67945 .94355 m .70141 .91839 L .72673 .92804 L p .738 .758 .868 r
F P
0 g
s
.44399 .64034 m .45701 .64307 L .46612 .65027 L p .154 .537 .923 r
F P
0 g
s
.45701 .64307 m .44399 .64034 L .43268 .63347 L p .219 .578 .943 r
F P
0 g
s
.3051 .409 m .33641 .37892 L .36064 .3979 L p .737 .735 .849 r
F P
0 g
s
.39267 .37353 m .36064 .3979 L .33641 .37892 L p .743 .747 .855 r
F P
0 g
s
.74664 .89893 m .72673 .92804 L .70141 .91839 L p .731 .743 .861 r
F P
0 g
s
.72673 .92804 m .74664 .89893 L .77803 .9072 L p .723 .745 .869 r
F P
0 g
s
.24433 .42692 m .2729 .39047 L .3051 .409 L p .724 .725 .851 r
F P
0 g
s
.53533 .69936 m .54679 .70564 L .55221 .71122 L p 0 .367 .827 r
F P
0 g
s
.54679 .70564 m .53533 .69936 L .53003 .69332 L p .003 .387 .845 r
F P
0 g
s
.49376 .6685 m .50665 .67417 L .51236 .68078 L p .1 .455 .885 r
F P
0 g
s
.50665 .67417 m .49376 .6685 L .48705 .66173 L p .149 .484 .9 r
F P
0 g
s
.68261 .75921 m .68835 .75455 L .71107 .75603 L p .331 .766 .968 r
F P
0 g
s
.68835 .75455 m .68261 .75921 L .66329 .75577 L p .225 .718 .92 r
F P
0 g
s
.4667 1.02781 m .49336 1.01894 L .49279 1.03145 L p .759 .895 .938 r
F P
0 g
s
.49279 1.03145 m .46268 1.03982 L .4667 1.02781 L p .759 .895 .938 r
F P
0 g
s
.33641 .37892 m .3051 .409 L .2729 .39047 L p .73 .736 .855 r
F P
0 g
s
.59851 .9631 m .62144 .94431 L .63664 .9549 L p .77 .792 .871 r
F P
0 g
s
.65954 .93318 m .63664 .9549 L .62144 .94431 L p .764 .773 .861 r
F P
0 g
s
.33096 1.16661 m .29038 1.13984 L .31584 1.12589 L p .587 .671 .898 r
F P
0 g
s
.31584 1.12589 m .3514 1.1508 L .33096 1.16661 L p .587 .671 .898 r
F P
0 g
s
.55221 .71122 m .56269 .7173 L .56857 .72225 L p 0 .296 .755 r
F P
0 g
s
.56269 .7173 m .55221 .71122 L .54679 .70564 L p 0 .314 .786 r
F P
0 g
s
.60145 .25767 m .64968 .26053 L .63372 .2862 L p .735 .811 .911 r
F P
0 g
s
.63372 .2862 m .59179 .28516 L .60145 .25767 L p .735 .811 .911 r
F P
0 g
s
.51236 .68078 m .52492 .68704 L .53003 .69332 L p .073 .428 .871 r
F P
0 g
s
.52492 .68704 m .51236 .68078 L .50665 .67417 L p .125 .455 .885 r
F P
0 g
s
.46612 .65027 m .47974 .6545 L .48705 .66173 L p .154 .509 .912 r
F P
0 g
s
.47974 .6545 m .46612 .65027 L .45701 .64307 L p .21 .545 .929 r
F P
0 g
s
.39116 .61956 m .40501 .6177 L .41977 .62597 L p .311 .655 .971 r
F P
0 g
s
.40501 .6177 m .39116 .61956 L .37287 .61209 L p .371 .683 .978 r
F P
0 g
s
.66329 .75577 m .66865 .75306 L .68835 .75455 L p .225 .718 .92 r
F P
0 g
s
.66865 .75306 m .66329 .75577 L .64651 .75252 L p .087 .634 .833 r
F P
0 g
s
.3141 .60378 m .32764 .59444 L .35184 .60377 L p .459 .735 .987 r
F P
0 g
s
.32764 .59444 m .3141 .60378 L .28487 .59614 L p .496 .744 .983 r
F P
0 g
s
.36559 1.0619 m .39395 1.06139 L .37952 1.07442 L p .653 .897 .982 r
F P
0 g
s
.37952 1.07442 m .34717 1.07337 L .36559 1.0619 L p .653 .897 .982 r
F P
0 g
s
.79454 .87363 m .77803 .9072 L .74664 .89893 L p .715 .732 .864 r
F P
0 g
s
.77803 .9072 m .79454 .87363 L .83264 .87971 L p .709 .735 .872 r
F P
0 g
s
.43268 .63347 m .44676 .63524 L .45701 .64307 L p .219 .578 .943 r
F P
0 g
s
.44676 .63524 m .43268 .63347 L .41977 .62597 L p .282 .614 .957 r
F P
0 g
s
.40643 1.04986 m .43368 1.04593 L .42492 1.05859 L p .694 .91 .97 r
F P
0 g
s
.42492 1.05859 m .39395 1.06139 L .40643 1.04986 L p .694 .91 .97 r
F P
0 g
s
.53003 .69332 m .54188 .69987 L .54679 .70564 L p .003 .387 .845 r
F P
0 g
s
.54188 .69987 m .53003 .69332 L .52492 .68704 L p .069 .414 .864 r
F P
0 g
s
.50202 .29751 m .54745 .28887 L .54509 .31346 L p .753 .797 .889 r
F P
0 g
s
.54509 .31346 m .50553 .32231 L .50202 .29751 L p .753 .797 .889 r
F P
0 g
s
.33641 .37892 m .37284 .3522 L .39267 .37353 L p .743 .747 .855 r
F P
0 g
s
.42818 .35256 m .39267 .37353 L .37284 .3522 L p .748 .759 .862 r
F P
0 g
s
.48705 .66173 m .50072 .66713 L .50665 .67417 L p .149 .484 .9 r
F P
0 g
s
.50072 .66713 m .48705 .66173 L .47974 .6545 L p .2 .515 .914 r
F P
0 g
s
.64651 .75252 m .65163 .75153 L .66865 .75306 L p .087 .634 .833 r
F P
0 g
s
.65163 .75153 m .64651 .75252 L .63197 .7494 L p .076 0 0 r
F P
0 g
s
.54167 .98373 m .56508 .96906 L .57365 .98005 L p .789 .835 .887 r
F P
0 g
s
.57365 .98005 m .54744 .99505 L .54167 .98373 L p .789 .835 .887 r
F P
0 g
s
.59851 .9631 m .57365 .98005 L .56508 .96906 L p .786 .814 .874 r
F P
0 g
s
.31843 1.06994 m .34717 1.07337 L .32608 1.08634 L p .618 .879 .99 r
F P
0 g
s
.32608 1.08634 m .29316 1.08087 L .31843 1.06994 L p .618 .879 .99 r
F P
0 g
s
.51763 .99665 m .54167 .98373 L .54744 .99505 L p .79 .858 .901 r
F P
0 g
s
.54744 .99505 m .52048 1.00802 L .51763 .99665 L p .79 .858 .901 r
F P
0 g
s
.59222 .73614 m .59953 .74025 L .60868 .74332 L p .427 0 0 r
F P
0 g
s
.54679 .70564 m .5576 .7122 L .56269 .7173 L p 0 .314 .786 r
F P
0 g
s
.5576 .7122 m .54679 .70564 L .54188 .69987 L p 0 .347 .821 r
F P
0 g
s
.65954 .93318 m .67908 .90973 L .70141 .91839 L p .747 .756 .86 r
F P
0 g
s
.71902 .89151 m .70141 .91839 L .67908 .90973 L p .739 .74 .852 r
F P
0 g
s
.70141 .91839 m .71902 .89151 L .74664 .89893 L p .731 .743 .861 r
F P
0 g
s
.44109 1.03469 m .4667 1.02781 L .46268 1.03982 L p .737 .914 .953 r
F P
0 g
s
.46268 1.03982 m .43368 1.04593 L .44109 1.03469 L p .737 .914 .953 r
F P
0 g
s
.62144 .94431 m .64191 .92385 L .65954 .93318 L p .764 .773 .861 r
F P
0 g
s
.67908 .90973 m .65954 .93318 L .64191 .92385 L p .756 .755 .851 r
F P
0 g
s
.52165 1.21908 m .47665 1.2069 L .4798 1.19002 L p .486 .667 .943 r
F P
0 g
s
.47665 1.2069 m .43268 1.19142 L .44092 1.17512 L p .51 .662 .929 r
F P
0 g
s
.44092 1.17512 m .4798 1.19002 L .47665 1.2069 L p .51 .662 .929 r
F P
0 g
s
.50665 .67417 m .51992 .68041 L .52492 .68704 L p .125 .455 .885 r
F P
0 g
s
.51992 .68041 m .50665 .67417 L .50072 .66713 L p .181 .484 .899 r
F P
0 g
s
.43268 1.19142 m .39063 1.17269 L .40383 1.15733 L p .534 .659 .916 r
F P
0 g
s
.40383 1.15733 m .44092 1.17512 L .43268 1.19142 L p .534 .659 .916 r
F P
0 g
s
.56508 .96906 m .58734 .9527 L .59851 .9631 L p .786 .814 .874 r
F P
0 g
s
.62144 .94431 m .59851 .9631 L .58734 .9527 L p .781 .793 .863 r
F P
0 g
s
.45701 .64307 m .47171 .64666 L .47974 .6545 L p .21 .545 .929 r
F P
0 g
s
.47171 .64666 m .45701 .64307 L .44676 .63524 L p .265 .578 .942 r
F P
0 g
s
.67263 1.25348 m .62456 1.25191 L .61109 1.23369 L p .443 .705 .977 r
F P
0 g
s
.56677 1.22799 m .61109 1.23369 L .62456 1.25191 L p .463 .696 .968 r
F P
0 g
s
.63197 .7494 m .63697 .74994 L .65163 .75153 L p .076 0 0 r
F P
0 g
s
.63697 .74994 m .63197 .7494 L .61944 .74635 L p .245 0 0 r
F P
0 g
s
.49351 1.00778 m .51763 .99665 L .52048 1.00802 L p .786 .882 .916 r
F P
0 g
s
.52048 1.00802 m .49336 1.01894 L .49351 1.00778 L p .786 .882 .916 r
F P
0 g
s
.37287 .61209 m .3881 .6085 L .40501 .6177 L p .371 .683 .978 r
F P
0 g
s
.3881 .6085 m .37287 .61209 L .35184 .60377 L p .421 .703 .98 r
F P
0 g
s
.45688 .31109 m .50202 .29751 L .50553 .32231 L p .753 .785 .879 r
F P
0 g
s
.50553 .32231 m .46617 .33539 L .45688 .31109 L p .753 .785 .879 r
F P
0 g
s
.37284 .3522 m .41338 .32943 L .42818 .35256 L p .748 .759 .862 r
F P
0 g
s
.46617 .33539 m .42818 .35256 L .41338 .32943 L p .751 .772 .87 r
F P
0 g
s
.28487 .59614 m .29978 .5839 L .32764 .59444 L p .496 .744 .983 r
F P
0 g
s
.29978 .5839 m .28487 .59614 L .25121 .58754 L p .524 .749 .978 r
F P
0 g
s
.52492 .68704 m .53738 .6938 L .54188 .69987 L p .069 .414 .864 r
F P
0 g
s
.53738 .6938 m .52492 .68704 L .51992 .68041 L p .138 .446 .879 r
F P
0 g
s
.41977 .62597 m .43515 .62663 L .44676 .63524 L p .282 .614 .957 r
F P
0 g
s
.43515 .62663 m .41977 .62597 L .40501 .6177 L p .339 .644 .966 r
F P
0 g
s
.57211 .72363 m .56269 .7173 L .5576 .7122 L p 0 .226 .711 r
F P
0 g
s
.58439 .73206 m .59181 .73709 L .59953 .74025 L p .506 0 0 r
F P
0 g
s
.84363 .7427 m .84098 .76242 L .80159 .7607 L p .556 .822 .996 r
F P
0 g
s
.41338 .32943 m .45688 .31109 L .46617 .33539 L p .751 .772 .87 r
F P
0 g
s
.56677 1.22799 m .52165 1.21908 L .51966 1.20202 L p .461 .673 .956 r
F P
0 g
s
.4798 1.19002 m .51966 1.20202 L .52165 1.21908 L p .486 .667 .943 r
F P
0 g
s
.76111 .86817 m .74664 .89893 L .71902 .89151 L p .722 .728 .855 r
F P
0 g
s
.74664 .89893 m .76111 .86817 L .79454 .87363 L p .715 .732 .864 r
F P
0 g
s
.61944 .74635 m .62442 .74826 L .63697 .74994 L p .245 0 0 r
F P
0 g
s
.58734 .9527 m .60791 .93477 L .62144 .94431 L p .781 .793 .863 r
F P
0 g
s
.64191 .92385 m .62144 .94431 L .60791 .93477 L p .774 .774 .852 r
F P
0 g
s
.47974 .6545 m .49445 .65955 L .50072 .66713 L p .2 .515 .914 r
F P
0 g
s
.49445 .65955 m .47974 .6545 L .47171 .64666 L p .253 .546 .926 r
F P
0 g
s
.39063 1.17269 m .3514 1.1508 L .36933 1.13676 L p .558 .657 .902 r
F P
0 g
s
.36933 1.13676 m .40383 1.15733 L .39063 1.17269 L p .558 .657 .902 r
F P
0 g
s
.54188 .69987 m .55319 .70684 L .5576 .7122 L p 0 .347 .821 r
F P
0 g
s
.55319 .70684 m .54188 .69987 L .53738 .6938 L p .052 .388 .849 r
F P
0 g
s
.80159 .7607 m .80368 .7448 L .84363 .7427 L p .556 .822 .996 r
F P
0 g
s
.80368 .7448 m .80159 .7607 L .76719 .75908 L p .529 .827 .999 r
F P
0 g
s
.2729 .39047 m .30841 .35709 L .33641 .37892 L p .73 .736 .855 r
F P
0 g
s
.37284 .3522 m .33641 .37892 L .30841 .35709 L p .736 .747 .861 r
F P
0 g
s
.46988 1.01712 m .49351 1.00778 L .49336 1.01894 L p .775 .907 .932 r
F P
0 g
s
.49336 1.01894 m .4667 1.02781 L .46988 1.01712 L p .775 .907 .932 r
F P
0 g
s
.76719 .75908 m .76893 .74653 L .80368 .7448 L p .529 .827 .999 r
F P
0 g
s
.76893 .74653 m .76719 .75908 L .73719 .75753 L p .491 .828 .999 r
F P
0 g
s
.50072 .66713 m .51493 .67329 L .51992 .68041 L p .181 .484 .899 r
F P
0 g
s
.51493 .67329 m .50072 .66713 L .49445 .65955 L p .236 .514 .91 r
F P
0 g
s
.60868 .74332 m .61377 .74646 L .62442 .74826 L p .397 0 0 r
F P
0 g
s
.61377 .74646 m .60868 .74332 L .59953 .74025 L p .519 0 0 r
F P
0 g
s
.55042 .26034 m .60145 .25767 L .59179 .28516 L p .741 .802 .901 r
F P
0 g
s
.59179 .28516 m .54745 .28887 L .55042 .26034 L p .741 .802 .901 r
F P
0 g
s
.29038 1.13984 m .25474 1.10989 L .28477 1.09819 L p .606 .673 .888 r
F P
0 g
s
.28477 1.09819 m .31584 1.12589 L .29038 1.13984 L p .606 .673 .888 r
F P
0 g
s
.5576 .7122 m .56745 .71913 L .57211 .72363 L p 0 .226 .711 r
F P
0 g
s
.56745 .71913 m .5576 .7122 L .55319 .70684 L p 0 .285 .778 r
F P
0 g
s
.84407 .8412 m .83264 .87971 L .79454 .87363 L p .7 .724 .868 r
F P
0 g
s
.73719 .75753 m .73873 .74792 L .76893 .74653 L p .491 .828 .999 r
F P
0 g
s
.73873 .74792 m .73719 .75753 L .71107 .75603 L p .437 .821 .989 r
F P
0 g
s
.44676 .63524 m .4628 .63807 L .47171 .64666 L p .265 .578 .942 r
F P
0 g
s
.4628 .63807 m .44676 .63524 L .43515 .62663 L p .318 .608 .952 r
F P
0 g
s
.26503 1.07301 m .29316 1.08087 L .26436 1.09326 L p .592 .86 .994 r
F P
0 g
s
.26436 1.09326 m .23195 1.08278 L .26503 1.07301 L p .592 .86 .994 r
F P
0 g
s
.64191 .92385 m .65941 .9019 L .67908 .90973 L p .756 .755 .851 r
F P
0 g
s
.69477 .88481 m .67908 .90973 L .65941 .9019 L p .747 .738 .843 r
F P
0 g
s
.67908 .90973 m .69477 .88481 L .71902 .89151 L p .739 .74 .852 r
F P
0 g
s
.51992 .68041 m .53321 .68732 L .53738 .6938 L p .138 .446 .879 r
F P
0 g
s
.53321 .68732 m .51992 .68041 L .51493 .67329 L p .205 .478 .892 r
F P
0 g
s
.35184 .60377 m .36869 .59818 L .3881 .6085 L p .421 .703 .98 r
F P
0 g
s
.36869 .59818 m .35184 .60377 L .32764 .59444 L p .461 .717 .979 r
F P
0 g
s
.71107 .75603 m .71253 .74901 L .73873 .74792 L p .437 .821 .989 r
F P
0 g
s
.71253 .74901 m .71107 .75603 L .68835 .75455 L p .36 .798 .961 r
F P
0 g
s
.38159 1.05179 m .40643 1.04986 L .39395 1.06139 L p .651 .912 .98 r
F P
0 g
s
.39395 1.06139 m .36559 1.0619 L .38159 1.05179 L p .651 .912 .98 r
F P
0 g
s
.60791 .93477 m .62632 .9154 L .64191 .92385 L p .774 .774 .852 r
F P
0 g
s
.65941 .9019 m .64191 .92385 L .62632 .9154 L p .766 .754 .842 r
F P
0 g
s
.41713 1.03967 m .44109 1.03469 L .43368 1.04593 L p .702 .927 .966 r
F P
0 g
s
.43368 1.04593 m .40643 1.04986 L .41713 1.03967 L p .702 .927 .966 r
F P
0 g
s
.25121 .58754 m .26767 .57195 L .29978 .5839 L p .524 .749 .978 r
F P
0 g
s
.26767 .57195 m .25121 .58754 L .21245 .57779 L p .547 .752 .972 r
F P
0 g
s
.59953 .74025 m .60482 .74451 L .61377 .74646 L p .519 0 0 r
F P
0 g
s
.60482 .74451 m .59953 .74025 L .59181 .73709 L p .611 .056 0 r
F P
0 g
s
.40501 .6177 m .42196 .61706 L .43515 .62663 L p .339 .644 .966 r
F P
0 g
s
.42196 .61706 m .40501 .6177 L .3881 .6085 L p .389 .668 .97 r
F P
0 g
s
.53625 .97356 m .55726 .95915 L .56508 .96906 L p .802 .838 .878 r
F P
0 g
s
.56508 .96906 m .54167 .98373 L .53625 .97356 L p .802 .838 .878 r
F P
0 g
s
.58734 .9527 m .56508 .96906 L .55726 .95915 L p .798 .815 .866 r
F P
0 g
s
.53738 .6938 m .54942 .70114 L .55319 .70684 L p .052 .388 .849 r
F P
0 g
s
.54942 .70114 m .53738 .6938 L .53321 .68732 L p .144 .428 .868 r
F P
0 g
s
.68835 .75455 m .68984 .74981 L .71253 .74901 L p .36 .798 .961 r
F P
0 g
s
.68984 .74981 m .68835 .75455 L .66865 .75306 L p .25 .749 .901 r
F P
0 g
s
.51475 .98645 m .53625 .97356 L .54167 .98373 L p .805 .863 .892 r
F P
0 g
s
.54167 .98373 m .51763 .99665 L .51475 .98645 L p .805 .863 .892 r
F P
0 g
s
.61109 1.23369 m .56677 1.22799 L .55966 1.21112 L p .436 .681 .967 r
F P
0 g
s
.51966 1.20202 m .55966 1.21112 L .56677 1.22799 L p .461 .673 .956 r
F P
0 g
s
.55726 .95915 m .57728 .9433 L .58734 .9527 L p .798 .815 .866 r
F P
0 g
s
.60791 .93477 m .58734 .9527 L .57728 .9433 L p .792 .794 .854 r
F P
0 g
s
.73181 .86323 m .71902 .89151 L .69477 .88481 L p .729 .724 .846 r
F P
0 g
s
.71902 .89151 m .73181 .86323 L .76111 .86817 L p .722 .728 .855 r
F P
0 g
s
.47171 .64666 m .48772 .65128 L .49445 .65955 L p .253 .546 .926 r
F P
0 g
s
.48772 .65128 m .47171 .64666 L .4628 .63807 L p .303 .575 .936 r
F P
0 g
s
.3514 1.1508 m .31584 1.12589 L .33818 1.11354 L p .58 .658 .89 r
F P
0 g
s
.33818 1.11354 m .36933 1.13676 L .3514 1.1508 L p .58 .658 .89 r
F P
0 g
s
.66865 .75306 m .67025 .75034 L .68984 .74981 L p .25 .749 .901 r
F P
0 g
s
.67025 .75034 m .66865 .75306 L .65163 .75153 L p .102 .656 .793 r
F P
0 g
s
.55319 .70684 m .56367 .71433 L .56745 .71913 L p 0 .285 .778 r
F P
0 g
s
.56367 .71433 m .55319 .70684 L .54942 .70114 L p .023 .348 .825 r
F P
0 g
s
.44726 1.02472 m .46988 1.01712 L .4667 1.02781 L p .752 .929 .947 r
F P
0 g
s
.4667 1.02781 m .44109 1.03469 L .44726 1.02472 L p .752 .929 .947 r
F P
0 g
s
.59181 .73709 m .59741 .74237 L .60482 .74451 L p .611 .056 0 r
F P
0 g
s
.59741 .74237 m .59181 .73709 L .58541 .73379 L p .676 .134 0 r
F P
0 g
s
.34053 1.06033 m .36559 1.0619 L .34717 1.07337 L p .609 .892 .989 r
F P
0 g
s
.34717 1.07337 m .31843 1.06994 L .34053 1.06033 L p .609 .892 .989 r
F P
0 g
s
.49326 .9978 m .51475 .98645 L .51763 .99665 L p .803 .889 .907 r
F P
0 g
s
.51763 .99665 m .49351 1.00778 L .49326 .9978 L p .803 .889 .907 r
F P
0 g
s
.65163 .75153 m .6534 .75061 L .67025 .75034 L p .102 .656 .793 r
F P
0 g
s
.6534 .75061 m .65163 .75153 L .63697 .74994 L p .077 0 0 r
F P
0 g
s
.49445 .65955 m .50987 .66557 L .51493 .67329 L p .236 .514 .91 r
F P
0 g
s
.50987 .66557 m .49445 .65955 L .48772 .65128 L p .288 .543 .919 r
F P
0 g
s
.80437 .83859 m .79454 .87363 L .76111 .86817 L p .706 .719 .86 r
F P
0 g
s
.79454 .87363 m .80437 .83859 L .84407 .8412 L p .7 .724 .868 r
F P
0 g
s
.57728 .9433 m .59585 .92611 L .60791 .93477 L p .792 .794 .854 r
F P
0 g
s
.62632 .9154 m .60791 .93477 L .59585 .92611 L p .784 .774 .843 r
F P
0 g
s
.30841 .35709 m .34994 .32759 L .37284 .3522 L p .736 .747 .861 r
F P
0 g
s
.41338 .32943 m .37284 .3522 L .34994 .32759 L p .74 .758 .867 r
F P
0 g
s
.63697 .74994 m .63898 .75062 L .6534 .75061 L p .077 0 0 r
F P
0 g
s
.63898 .75062 m .63697 .74994 L .62442 .74826 L p .259 0 0 r
F P
0 g
s
.51493 .67329 m .52931 .68031 L .53321 .68732 L p .205 .478 .892 r
F P
0 g
s
.52931 .68031 m .51493 .67329 L .50987 .66557 L p .265 .508 .9 r
F P
0 g
s
.5761 .7265 m .56745 .71913 L .56367 .71433 L p 0 .191 .71 r
F P
0 g
s
.43515 .62663 m .45283 .62856 L .4628 .63807 L p .318 .608 .952 r
F P
0 g
s
.45283 .62856 m .43515 .62663 L .42196 .61706 L p .366 .634 .957 r
F P
0 g
s
.58541 .73379 m .59142 .74 L .59741 .74237 L p .676 .134 0 r
F P
0 g
s
.62632 .9154 m .64211 .8948 L .65941 .9019 L p .766 .754 .842 r
F P
0 g
s
.6735 .87873 m .65941 .9019 L .64211 .8948 L p .756 .736 .834 r
F P
0 g
s
.65941 .9019 m .6735 .87873 L .69477 .88481 L p .747 .738 .843 r
F P
0 g
s
.53321 .68732 m .54619 .69499 L .54942 .70114 L p .144 .428 .868 r
F P
0 g
s
.54619 .69499 m .53321 .68732 L .52931 .68031 L p .225 .466 .879 r
F P
0 g
s
.49814 .26876 m .55042 .26034 L .54745 .28887 L p .743 .791 .891 r
F P
0 g
s
.54745 .28887 m .50202 .29751 L .49814 .26876 L p .743 .791 .891 r
F P
0 g
s
.62442 .74826 m .62674 .75037 L .63898 .75062 L p .259 0 0 r
F P
0 g
s
.62674 .75037 m .62442 .74826 L .61377 .74646 L p .418 0 0 r
F P
0 g
s
.32764 .59444 m .34639 .58653 L .36869 .59818 L p .461 .717 .979 r
F P
0 g
s
.34639 .58653 m .32764 .59444 L .29978 .5839 L p .494 .727 .976 r
F P
0 g
s
.61109 1.23369 m .6537 1.23631 L .67263 1.25348 L p .443 .705 .977 r
F P
0 g
s
.54942 .70114 m .56071 .70914 L .56367 .71433 L p .023 .348 .825 r
F P
0 g
s
.56071 .70914 m .54942 .70114 L .54619 .69499 L p .149 .404 .85 r
F P
0 g
s
.47226 1.0076 m .49326 .9978 L .49351 1.00778 L p .793 .918 .922 r
F P
0 g
s
.49351 1.00778 m .46988 1.01712 L .47226 1.0076 L p .793 .918 .922 r
F P
0 g
s
.70618 .85873 m .69477 .88481 L .6735 .87873 L p .736 .72 .836 r
F P
0 g
s
.69477 .88481 m .70618 .85873 L .73181 .86323 L p .729 .724 .846 r
F P
0 g
s
.59585 .92611 m .61252 .90772 L .62632 .9154 L p .784 .774 .843 r
F P
0 g
s
.64211 .8948 m .62632 .9154 L .61252 .90772 L p .776 .754 .833 r
F P
0 g
s
.3881 .6085 m .40691 .60635 L .42196 .61706 L p .389 .668 .97 r
F P
0 g
s
.40691 .60635 m .3881 .6085 L .36869 .59818 L p .431 .687 .971 r
F P
0 g
s
.21245 .57779 m .23063 .55832 L .26767 .57195 L p .547 .752 .972 r
F P
0 g
s
.61377 .74646 m .61645 .74985 L .62674 .75037 L p .418 0 0 r
F P
0 g
s
.61645 .74985 m .61377 .74646 L .60482 .74451 L p .541 .018 0 r
F P
0 g
s
.4798 1.19002 m .44092 1.17512 L .448 1.16059 L p .492 .645 .925 r
F P
0 g
s
.44092 1.17512 m .40383 1.15733 L .41529 1.14368 L p .519 .642 .91 r
F P
0 g
s
.41529 1.14368 m .448 1.16059 L .44092 1.17512 L p .519 .642 .91 r
F P
0 g
s
.4628 .63807 m .48041 .64215 L .48772 .65128 L p .303 .575 .936 r
F P
0 g
s
.48041 .64215 m .4628 .63807 L .45283 .62856 L p .349 .601 .942 r
F P
0 g
s
.76967 .8362 m .76111 .86817 L .73181 .86323 L p .711 .714 .851 r
F P
0 g
s
.76111 .86817 m .76967 .8362 L .80437 .83859 L p .706 .719 .86 r
F P
0 g
s
.56367 .71433 m .57304 .72238 L .5761 .7265 L p 0 .191 .71 r
F P
0 g
s
.57304 .72238 m .56367 .71433 L .56071 .70914 L p 0 .296 .793 r
F P
0 g
s
.51966 1.20202 m .4798 1.19002 L .48237 1.17496 L p .463 .65 .94 r
F P
0 g
s
.448 1.16059 m .48237 1.17496 L .4798 1.19002 L p .492 .645 .925 r
F P
0 g
s
.60482 .74451 m .60793 .74907 L .61645 .74985 L p .541 .018 0 r
F P
0 g
s
.60793 .74907 m .60482 .74451 L .59741 .74237 L p .636 .148 .076 r
F P
0 g
s
.53111 .96438 m .55005 .95018 L .55726 .95915 L p .815 .84 .868 r
F P
0 g
s
.55726 .95915 m .53625 .97356 L .53111 .96438 L p .815 .84 .868 r
F P
0 g
s
.57728 .9433 m .55726 .95915 L .55005 .95018 L p .809 .817 .856 r
F P
0 g
s
.34994 .32759 m .39634 .30268 L .41338 .32943 L p .74 .758 .867 r
F P
0 g
s
.45688 .31109 m .41338 .32943 L .39634 .30268 L p .743 .769 .874 r
F P
0 g
s
.55005 .95018 m .56819 .93476 L .57728 .9433 L p .809 .817 .856 r
F P
0 g
s
.59585 .92611 m .57728 .9433 L .56819 .93476 L p .802 .795 .845 r
F P
0 g
s
.48772 .65128 m .50463 .65707 L .50987 .66557 L p .288 .543 .919 r
F P
0 g
s
.50463 .65707 m .48772 .65128 L .48041 .64215 L p .335 .57 .925 r
F P
0 g
s
.5118 .97729 m .53111 .96438 L .53625 .97356 L p .819 .866 .881 r
F P
0 g
s
.53625 .97356 m .51475 .98645 L .5118 .97729 L p .819 .866 .881 r
F P
0 g
s
.29404 1.06444 m .31843 1.06994 L .29316 1.08087 L p .579 .869 .995 r
F P
0 g
s
.29316 1.08087 m .26503 1.07301 L .29404 1.06444 L p .579 .869 .995 r
F P
0 g
s
.44625 .28294 m .49814 .26876 L .50202 .29751 L p .744 .78 .882 r
F P
0 g
s
.50202 .29751 m .45688 .31109 L .44625 .28294 L p .744 .78 .882 r
F P
0 g
s
.42618 1.03066 m .44726 1.02472 L .44109 1.03469 L p .711 .944 .957 r
F P
0 g
s
.44109 1.03469 m .41713 1.03967 L .42618 1.03066 L p .711 .944 .957 r
F P
0 g
s
.39538 1.04288 m .41713 1.03967 L .40643 1.04986 L p .648 .928 .973 r
F P
0 g
s
.40643 1.04986 m .38159 1.05179 L .39538 1.04288 L p .648 .928 .973 r
F P
0 g
s
.40383 1.15733 m .36933 1.13676 L .38496 1.12432 L p .546 .641 .895 r
F P
0 g
s
.38496 1.12432 m .41529 1.14368 L .40383 1.15733 L p .546 .641 .895 r
F P
0 g
s
.50987 .66557 m .52559 .67263 L .52931 .68031 L p .265 .508 .9 r
F P
0 g
s
.52559 .67263 m .50987 .66557 L .50463 .65707 L p .319 .537 .907 r
F P
0 g
s
.59741 .74237 m .60102 .748 L .60793 .74907 L p .636 .148 .076 r
F P
0 g
s
.60102 .748 m .59741 .74237 L .59142 .74 L p .715 .249 .141 r
F P
0 g
s
.6537 1.23631 m .61109 1.23369 L .59896 1.21738 L p .412 .69 .976 r
F P
0 g
s
.55966 1.21112 m .59896 1.21738 L .61109 1.23369 L p .436 .681 .967 r
F P
0 g
s
.52931 .68031 m .54347 .68826 L .54619 .69499 L p .225 .466 .879 r
F P
0 g
s
.54347 .68826 m .52931 .68031 L .52559 .67263 L p .293 .499 .886 r
F P
0 g
s
.31584 1.12589 m .28477 1.09819 L .31112 1.08788 L p .602 .66 .879 r
F P
0 g
s
.31112 1.08788 m .33818 1.11354 L .31584 1.12589 L p .602 .66 .879 r
F P
0 g
s
.56819 .93476 m .58507 .91822 L .59585 .92611 L p .802 .795 .845 r
F P
0 g
s
.61252 .90772 m .59585 .92611 L .58507 .91822 L p .795 .774 .834 r
F P
0 g
s
.39634 .30268 m .44625 .28294 L .45688 .31109 L p .743 .769 .874 r
F P
0 g
s
.54619 .69499 m .55851 .70346 L .56071 .70914 L p .149 .404 .85 r
F P
0 g
s
.55851 .70346 m .54619 .69499 L .54347 .68826 L p .248 .45 .862 r
F P
0 g
s
.61252 .90772 m .62688 .8883 L .64211 .8948 L p .776 .754 .833 r
F P
0 g
s
.65487 .87317 m .64211 .8948 L .62688 .8883 L p .766 .734 .824 r
F P
0 g
s
.64211 .8948 m .65487 .87317 L .6735 .87873 L p .756 .736 .834 r
F P
0 g
s
.26503 1.07301 m .23195 1.08278 L p .23271 1.08136 L .559 .848 .998 r
F P
0 g
s
.23271 1.08136 m .24303 1.07801 L .26503 1.07301 L .559 .848 .998 r
F
.26243 1.07187 m .26503 1.07301 L p .23332 1.08022 L F P
0 g
s
.28477 1.09819 m .25474 1.10989 L p .25847 1.073 L .625 .677 .88 r
F P
0 g
s
.25898 1.06797 m .26223 1.07178 L p .25851 1.07267 L .625 .677 .88 r
F P
0 g
s
.22494 1.07704 m .25898 1.06797 L p .25847 1.073 L .625 .677 .88 r
F P
0 g
s
.29404 1.06444 m .26503 1.07301 L p .26572 1.07188 L .538 .855 .997 r
F P
0 g
s
.26572 1.07188 m .27487 1.06893 L .29404 1.06444 L .538 .855 .997 r
F
.2918 1.0636 m .29404 1.06444 L p .26629 1.07095 L F P
0 g
s
.31112 1.08788 m .28477 1.09819 L p .28834 1.0646 L .622 .665 .87 r
F P
0 g
s
.28882 1.06003 m .29163 1.06354 L p .28837 1.06429 L .622 .665 .87 r
F P
0 g
s
.25898 1.06797 m .28882 1.06003 L p .28834 1.0646 L .622 .665 .87 r
F P
0 g
s
.31843 1.06994 m .29404 1.06444 L .31939 1.05694 L p .559 .878 .992 r
F P
0 g
s
.31939 1.05694 m .29404 1.06444 L p .29465 1.06356 L .508 .858 .992 r
F P
0 g
s
.29465 1.06356 m .30276 1.06098 L .31939 1.05694 L .508 .858 .992 r
F
.31748 1.05637 m .31939 1.05694 L p .29518 1.06282 L F P
0 g
s
.31939 1.05694 m .34053 1.06033 L .31843 1.06994 L p .559 .878 .992 r
F P
0 g
s
.33415 1.07881 m .31112 1.08788 L p .31445 1.05725 L .619 .651 .86 r
F P
0 g
s
.3149 1.05309 m .31733 1.05633 L p .31448 1.05696 L .619 .651 .86 r
F P
0 g
s
.28882 1.06003 m .3149 1.05309 L p .31445 1.05725 L .619 .651 .86 r
F P
0 g
s
.34053 1.06033 m .31939 1.05694 L .34147 1.0504 L p .532 .884 .982 r
F P
0 g
s
.34147 1.0504 m .31939 1.05694 L p .31994 1.05629 L .465 .855 .977 r
F P
0 g
s
.31994 1.05629 m .32712 1.05403 L .34147 1.0504 L .465 .855 .977 r
F
.33983 1.05008 m .34147 1.0504 L p .32042 1.05572 L F P
0 g
s
.36559 1.0619 m .34053 1.06033 L .35975 1.05189 L p .596 .904 .984 r
F P
0 g
s
.34147 1.0504 m .35975 1.05189 L .34053 1.06033 L p .532 .884 .982 r
F P
0 g
s
.3542 1.07087 m .33415 1.07881 L p .3372 1.05084 L .615 .636 .848 r
F P
0 g
s
.33762 1.04706 m .3397 1.05005 L p .33723 1.05057 L .615 .636 .848 r
F P
0 g
s
.3149 1.05309 m .33762 1.04706 L p .3372 1.05084 L .615 .636 .848 r
F P
0 g
s
.35975 1.05189 m .34147 1.0504 L .3606 1.04473 L p .491 .883 .96 r
F P
0 g
s
.3606 1.04473 m .34147 1.0504 L p .34194 1.04996 L .404 .84 .945 r
F P
0 g
s
.34194 1.04996 m .34831 1.04798 L .3606 1.04473 L .404 .84 .945 r
F
.35921 1.04462 m .3606 1.04473 L p .34239 1.04954 L F P
0 g
s
.35975 1.05189 m .38159 1.05179 L .36559 1.0619 L p .596 .904 .984 r
F P
0 g
s
.38159 1.05179 m .35975 1.05189 L .37637 1.0445 L p .576 .914 .971 r
F P
0 g
s
.3606 1.04473 m .37637 1.0445 L .35975 1.05189 L p .491 .883 .96 r
F P
0 g
s
.37155 1.06393 m .3542 1.07087 L p .35694 1.04529 L .61 .618 .834 r
F P
0 g
s
.35731 1.04184 m .3591 1.04461 L p .35696 1.04503 L .61 .618 .834 r
F P
0 g
s
.33762 1.04706 m .35731 1.04184 L p .35694 1.04529 L .61 .618 .834 r
F P
0 g
s
.37637 1.0445 m .3606 1.04473 L .37709 1.03983 L p .431 .867 .916 r
F P
0 g
s
.37709 1.03983 m .3606 1.04473 L p .36101 1.04446 L .315 .801 .883 r
F P
0 g
s
.36101 1.04446 m .36665 1.04273 L .37709 1.03983 L .315 .801 .883 r
F
.37591 1.03992 m .37709 1.03983 L p .36142 1.04419 L F P
0 g
s
.37637 1.0445 m .39538 1.04288 L .38159 1.05179 L p .576 .914 .971 r
F P
0 g
s
.39538 1.04288 m .37637 1.0445 L .39065 1.03805 L p .547 .918 .944 r
F P
0 g
s
.37709 1.03983 m .39065 1.03805 L .37637 1.0445 L p .431 .867 .916 r
F P
0 g
s
.38646 1.05788 m .37155 1.06393 L p .37396 1.04049 L .604 .599 .819 r
F P
0 g
s
.37428 1.03735 m .37581 1.03993 L p .37398 1.04025 L .604 .599 .819 r
F P
0 g
s
.35731 1.04184 m .37428 1.03735 L p .37396 1.04049 L .604 .599 .819 r
F P
0 g
s
.39065 1.03805 m .37709 1.03983 L .39119 1.03563 L p .344 .823 .835 r
F P
0 g
s
.39119 1.03563 m .37709 1.03983 L p .37743 1.03971 L .192 .723 .774 r
F P
0 g
s
.37743 1.03971 m .38243 1.03821 L .39119 1.03563 L .192 .723 .774 r
F
.3902 1.03589 m .39119 1.03563 L p .37781 1.03958 L F P
0 g
s
.39917 1.05264 m .38646 1.05788 L p .38854 1.03639 L .597 .577 .803 r
F P
0 g
s
.37428 1.03735 m .38881 1.03351 L p .38854 1.03639 L .597 .577 .803 r
F P
0 g
s
.38854 1.03639 m .38437 1.03763 L .37428 1.03735 L .597 .577 .803 r
F
.37743 1.03971 m .37781 1.03958 L .38243 1.03821 L .192 .723 .774 r
F
.37581 1.03993 m .37428 1.03735 L p .38841 1.03774 L .597 .577 .803 r
F P
0 g
s
.37781 1.03958 m .37788 1.03955 L .3902 1.03589 L .192 .723 .774 r
F
.38259 1.03793 m .39011 1.03591 L p .37788 1.03955 L F P
0 g
s
.39011 1.03591 m .3902 1.03589 L p .37788 1.03955 L .192 .723 .774 r
F P
0 g
s
.38881 1.03351 m .40113 1.03028 L p .40092 1.0327 L .587 .553 .784 r
F P
0 g
s
.41713 1.03967 m .39538 1.04288 L .40716 1.03505 L p .643 .943 .958 r
F P
0 g
s
.39065 1.03805 m .40716 1.03505 L .39538 1.04288 L p .547 .918 .944 r
F P
0 g
s
.40716 1.03505 m .39065 1.03805 L .40279 1.03244 L p .503 .908 .895 r
F P
0 g
s
.39119 1.03563 m .40279 1.03244 L .39065 1.03805 L p .344 .823 .835 r
F P
0 g
s
.39917 1.05264 m .39023 1.03612 L p .40079 1.03421 L .587 .553 .784 r
F P
0 g
s
.39023 1.03612 m .39011 1.03591 L p .39182 1.03564 L .587 .553 .784 r
F P
0 g
s
.40079 1.03421 m .39023 1.03612 L .39182 1.03564 L .587 .553 .784 r
F
.40279 1.03244 m .39119 1.03563 L .40312 1.03206 L p .224 .737 .703 r
F P
0 g
s
.40986 1.04812 m .39917 1.05264 L p .4009 1.0329 L .587 .553 .784 r
F P
0 g
s
.40312 1.03206 m .39119 1.03563 L p .39146 1.03563 L 0 0 0 r
F P
0 g
s
.39146 1.03563 m .3959 1.03435 L .40312 1.03206 L 0 0 0 r
F
.40223 1.03252 m .40986 1.04812 L p .4009 1.0329 L .587 .553 .784 r
F P
0 g
s
.39146 1.03563 m .39182 1.03564 L .3959 1.03435 L 0 0 0 r
F
.40231 1.03248 m .40312 1.03206 L p .39182 1.03564 L F P
0 g
s
.39119 1.03563 m .39011 1.03591 L p .39182 1.03564 L 0 0 0 r
F P
0 g
s
.40092 1.0327 m .40079 1.03421 L .39011 1.03591 L .587 .553 .784 r
F
.39182 1.03564 m .39189 1.03564 L .40231 1.03248 L 0 0 0 r
F
.396 1.03574 m .40223 1.03252 L p .39189 1.03564 L F P
0 g
s
.40223 1.03252 m .40231 1.03248 L p .39189 1.03564 L 0 0 0 r
F P
0 g
s
.4171 1.02819 m .40348 1.03224 L p .41299 1.02759 L .441 .876 .815 r
F P
0 g
s
.40348 1.03224 m .40279 1.03244 L .41299 1.02759 L p .441 .876 .815 r
F P
0 g
s
.41299 1.02759 m .42535 1.02218 L .4171 1.02819 L p .441 .876 .815 r
F P
0 g
s
.42535 1.02218 m .41377 1.02725 L p .4214 1.02342 L .36 .814 .694 r
F P
0 g
s
.41377 1.02725 m .41299 1.02759 L .4214 1.02342 L p .36 .814 .694 r
F P
0 g
s
.42535 1.02218 m .43986 1.0157 L .43373 1.02271 L p .623 .959 .893 r
F P
0 g
s
.43373 1.02271 m .4171 1.02819 L .42535 1.02218 L p .623 .959 .893 r
F P
0 g
s
.43986 1.0157 m .42535 1.02218 L .43203 1.01695 L p .61 .954 .835 r
F P
0 g
s
.42123 1.02659 m .42779 1.02021 L p .4214 1.02342 L .074 0 0 r
F P
0 g
s
.43203 1.01695 m .42535 1.02218 L p .42181 1.02329 L .36 .814 .694 r
F P
0 g
s
.4214 1.02342 m .42332 1.02225 L p .42181 1.02329 L .36 .814 .694 r
F P
0 g
s
.42332 1.02225 m .43203 1.01695 L p .42181 1.02329 L .36 .814 .694 r
F P
0 g
s
.43203 1.01695 m .44468 1.00953 L .43986 1.0157 L p .61 .954 .835 r
F P
0 g
s
.44468 1.00953 m .43373 1.01594 L p .43724 1.01239 L .604 .942 .764 r
F P
0 g
s
.43373 1.01594 m .43203 1.01695 L .43724 1.01239 L p .604 .942 .764 r
F P
0 g
s
.43724 1.01239 m .44825 1.00409 L .44468 1.00953 L p .604 .942 .764 r
F P
0 g
s
.44825 1.00409 m .43918 1.01093 L p .44106 1.00845 L .623 .932 .693 r
F P
0 g
s
.43918 1.01093 m .43724 1.01239 L .44106 1.00845 L p .623 .932 .693 r
F P
0 g
s
.44106 1.00845 m .45062 .9993 L .44825 1.00409 L p .623 .932 .693 r
F P
0 g
s
.45062 .9993 m .4433 1.0063 L p .44355 1.00505 L .691 .94 .648 r
F P
0 g
s
.4433 1.0063 m .44106 1.00845 L .44355 1.00505 L p .691 .94 .648 r
F P
0 g
s
.44106 1.00845 m .44085 1.00876 L .44262 1.00639 L 0 0 0 r
F
.43709 1.01436 m .44146 1.00806 L p .44085 1.00876 L F P
0 g
s
.44146 1.00806 m .44262 1.00639 L p .44085 1.00876 L 0 0 0 r
F P
0 g
s
.44262 1.00639 m .44355 1.00505 L .44106 1.00845 L p 0 0 0 r
F P
0 g
s
.44355 1.00505 m .43709 1.01436 L .43941 1.01233 L p 0 0 0 r
F P
0 g
s
.43941 1.01233 m .44375 1.00405 L p .44355 1.00505 L 0 0 0 r
F P
0 g
s
.43373 1.02271 m .45226 1.01588 L .44726 1.02472 L p .721 .961 .943 r
F P
0 g
s
.45226 1.01588 m .43373 1.02271 L .43986 1.0157 L p .735 .976 .922 r
F P
0 g
s
.43798 1.02125 m .44037 1.01073 L .43941 1.01233 L p .417 .12 .351 r
F P
0 g
s
.44037 1.01073 m .43798 1.02125 L .43856 1.02094 L p .337 .099 .398 r
F P
0 g
s
.43856 1.02094 m .43962 1.01227 L p .44037 1.01073 L .337 .099 .398 r
F P
0 g
s
.43941 1.01233 m .44037 1.01073 L p .44116 1.00908 L 0 0 0 r
F P
0 g
s
.43335 1.01686 m .44019 1.00939 L p .43724 1.01239 L 0 0 0 r
F P
0 g
s
.44106 1.00845 m .43335 1.01686 L .43709 1.01436 L p 0 0 0 r
F P
0 g
s
.43962 1.01227 m .43996 1.00953 L .44037 1.01073 L p .337 .099 .398 r
F P
0 g
s
.44211 1.00732 m .44116 1.00908 L .44037 1.01073 L 0 0 0 r
F
.44475 1.00214 m .44193 1.00752 L p .44211 1.00732 L F P
0 g
s
.44193 1.00752 m .43941 1.01233 L p .44211 1.00732 L 0 0 0 r
F P
0 g
s
.44375 1.00405 m .44475 1.00214 L .44355 1.00505 L p 0 0 0 r
F P
0 g
s
.44019 1.00939 m .44106 1.00845 L .43724 1.01239 L p 0 0 0 r
F P
0 g
s
.43203 1.01695 m .4214 1.02342 L .42815 1.01986 L p 0 0 0 r
F P
0 g
s
.42815 1.01986 m .43335 1.01686 L p .43669 1.01303 L 0 0 0 r
F P
0 g
s
.43724 1.01239 m .43531 1.01397 L p .43669 1.01303 L 0 0 0 r
F P
0 g
s
.42815 1.01986 m .43724 1.01239 L .43203 1.01695 L p 0 0 0 r
F P
0 g
s
.43531 1.01397 m .42815 1.01986 L p .43669 1.01303 L 0 0 0 r
F P
0 g
s
.42779 1.02021 m .42815 1.01986 L .4214 1.02342 L p .074 0 0 r
F P
0 g
s
.41308 1.02906 m .42107 1.02365 L p .41299 1.02759 L 0 0 0 r
F P
0 g
s
.42107 1.02365 m .4214 1.02342 L .41299 1.02759 L p 0 0 0 r
F P
0 g
s
.40312 1.03206 m .41299 1.02759 L .40279 1.03244 L p .224 .737 .703 r
F P
0 g
s
.41299 1.02759 m .40312 1.03206 L .41308 1.02906 L p 0 0 0 r
F P
0 g
s
.40279 1.03244 m .4171 1.02819 L .40716 1.03505 L p .503 .908 .895 r
F P
0 g
s
.40716 1.03505 m .42618 1.03066 L .41713 1.03967 L p .643 .943 .958 r
F P
0 g
s
.42618 1.03066 m .40716 1.03505 L .4171 1.02819 L p .634 .954 .933 r
F P
0 g
s
.41871 1.04425 m .40986 1.04812 L p .41126 1.02998 L .574 .525 .762 r
F P
0 g
s
.41308 1.02906 m .40312 1.03206 L p .40332 1.03215 L .136 0 0 r
F P
0 g
s
.40332 1.03215 m .40727 1.03107 L .41308 1.02906 L .136 0 0 r
F
.41236 1.02968 m .41871 1.04425 L p .41126 1.02998 L .574 .525 .762 r
F P
0 g
s
.40986 1.04812 m .40233 1.03273 L p .40367 1.03232 L .574 .525 .762 r
F P
0 g
s
.41126 1.02998 m .41116 1.03128 L .40367 1.03232 L .574 .525 .762 r
F
.41116 1.03128 m .40986 1.04812 L .40367 1.03232 L F
.396 1.03574 m .40729 1.034 L p .40367 1.03232 L .136 0 0 r
F P
0 g
s
.40312 1.03206 m .40223 1.03252 L p .40367 1.03232 L .136 0 0 r
F P
0 g
s
.40223 1.03252 m .396 1.03574 L p .40367 1.03232 L .136 0 0 r
F P
0 g
s
.40367 1.03232 m .40374 1.03234 L .41242 1.02962 L .136 0 0 r
F
.40729 1.034 m .41236 1.02968 L p .40374 1.03234 L F P
0 g
s
.41236 1.02968 m .41242 1.02962 L p .40374 1.03234 L .136 0 0 r
F P
0 g
s
.4171 1.02819 m .43373 1.02271 L .42618 1.03066 L p .634 .954 .933 r
F P
0 g
s
.4214 1.02342 m .41308 1.02906 L .42123 1.02659 L p .074 0 0 r
F P
0 g
s
.42586 1.04098 m .41871 1.04425 L p .41977 1.02757 L .556 .491 .738 r
F P
0 g
s
.42123 1.02659 m .41308 1.02906 L p .41321 1.0292 L .296 0 0 r
F P
0 g
s
.41321 1.0292 m .41672 1.02833 L .42123 1.02659 L .296 0 0 r
F
.42072 1.02727 m .42123 1.02659 L p .41356 1.02955 L F P
0 g
s
.41991 1.02539 m .42066 1.02735 L p .41977 1.02757 L .556 .491 .738 r
F P
0 g
s
.42066 1.02735 m .42586 1.04098 L p .41977 1.02757 L .556 .491 .738 r
F P
0 g
s
.41321 1.0292 m .41356 1.02955 L .41672 1.02833 L .296 0 0 r
F
.41871 1.04425 m .41245 1.0299 L p .41356 1.02955 L .556 .491 .738 r
F P
0 g
s
.41977 1.02757 m .41969 1.02888 L .41356 1.02955 L .556 .491 .738 r
F
.41969 1.02888 m .41871 1.04425 L .41356 1.02955 L F
.40729 1.034 m .41665 1.03268 L p .41356 1.02955 L .296 0 0 r
F P
0 g
s
.41308 1.02906 m .41236 1.02968 L p .41356 1.02955 L .296 0 0 r
F P
0 g
s
.41236 1.02968 m .40729 1.034 L p .41356 1.02955 L .296 0 0 r
F P
0 g
s
.42815 1.01986 m .42123 1.02659 L .4277 1.0246 L p .208 0 0 r
F P
0 g
s
.44726 1.02472 m .42618 1.03066 L .43373 1.02271 L p .721 .961 .943 r
F P
0 g
s
.43141 1.03824 m .42586 1.04098 L p .42658 1.02563 L .531 .45 .709 r
F P
0 g
s
.4277 1.0246 m .42123 1.02659 L p .42129 1.02669 L .427 0 .04 r
F P
0 g
s
.42129 1.02669 m .42438 1.02607 L .4277 1.0246 L .427 0 .04 r
F
.42732 1.02538 m .4277 1.0246 L p .42164 1.02729 L F P
0 g
s
.42667 1.02367 m .42727 1.02549 L p .42658 1.02563 L .531 .45 .709 r
F P
0 g
s
.42727 1.02549 m .43141 1.03824 L p .42658 1.02563 L .531 .45 .709 r
F P
0 g
s
.42129 1.02669 m .42164 1.02729 L .42438 1.02607 L .427 0 .04 r
F
.42586 1.04098 m .42075 1.02759 L p .42164 1.02729 L .531 .45 .709 r
F P
0 g
s
.42658 1.02563 m .42652 1.02701 L .42164 1.02729 L .531 .45 .709 r
F
.42652 1.02701 m .42586 1.04098 L .42164 1.02729 L F
.41665 1.03268 m .42425 1.03175 L p .42164 1.02729 L .427 0 .04 r
F P
0 g
s
.42123 1.02659 m .42066 1.02735 L p .42164 1.02729 L .427 0 .04 r
F P
0 g
s
.42066 1.02735 m .41665 1.03268 L p .42164 1.02729 L .427 0 .04 r
F P
0 g
s
.4277 1.0246 m .43335 1.01686 L .42815 1.01986 L p .208 0 0 r
F P
0 g
s
.43335 1.01686 m .4277 1.0246 L .4326 1.02306 L p .31 0 .099 r
F P
0 g
s
.4326 1.02306 m .4277 1.0246 L p .42805 1.02552 L .529 .117 .205 r
F P
0 g
s
.43141 1.03824 m .42736 1.02577 L p .42805 1.02552 L .491 .395 .675 r
F P
0 g
s
.4318 1.02413 m .43176 1.02563 L .42805 1.02552 L .491 .395 .675 r
F
.43176 1.02563 m .43141 1.03824 L .42805 1.02552 L F
.42425 1.03175 m .4302 1.03122 L p .42805 1.02552 L .529 .117 .205 r
F P
0 g
s
.4277 1.0246 m .42727 1.02549 L p .42805 1.02552 L .529 .117 .205 r
F P
0 g
s
.42727 1.02549 m .42425 1.03175 L p .42805 1.02552 L .529 .117 .205 r
F P
0 g
s
.43546 1.03599 m .43141 1.03824 L p .4318 1.02413 L .491 .395 .675 r
F P
0 g
s
.4323 1.02408 m .43234 1.02393 L p .4318 1.02413 L .529 .117 .205 r
F P
0 g
s
.43234 1.02393 m .4326 1.02306 L p .42805 1.02552 L .529 .117 .205 r
F P
0 g
s
.43185 1.02238 m .4323 1.02408 L p .4318 1.02413 L .491 .395 .675 r
F P
0 g
s
.4323 1.02408 m .43546 1.03599 L p .4318 1.02413 L .491 .395 .675 r
F P
0 g
s
.4302 1.03122 m .4323 1.02408 L p .42805 1.02552 L .529 .117 .205 r
F P
0 g
s
.42805 1.02552 m .4323 1.02408 L .4318 1.02413 L .529 .117 .205 r
F
.4318 1.02394 m .4318 1.02413 L .42727 1.02549 L .491 .395 .675 r
F
.42736 1.02577 m .42727 1.02549 L p .4318 1.02413 L F P
0 g
s
.42667 1.02367 m .43185 1.02238 L p .4318 1.02394 L .491 .395 .675 r
F P
0 g
s
.42727 1.02549 m .42667 1.02367 L p .4318 1.02394 L .491 .395 .675 r
F P
0 g
s
.42164 1.02729 m .4217 1.0274 L .42732 1.02538 L .427 0 .04 r
F
.42425 1.03175 m .42727 1.02549 L p .4217 1.0274 L F P
0 g
s
.42727 1.02549 m .42732 1.02538 L p .4217 1.0274 L .427 0 .04 r
F P
0 g
s
.42659 1.02544 m .42658 1.02563 L .42066 1.02735 L .531 .45 .709 r
F
.42075 1.02759 m .42066 1.02735 L p .42658 1.02563 L F P
0 g
s
.41991 1.02539 m .42667 1.02367 L p .42659 1.02544 L .531 .45 .709 r
F P
0 g
s
.42066 1.02735 m .41991 1.02539 L p .42659 1.02544 L .531 .45 .709 r
F P
0 g
s
.41356 1.02955 m .41362 1.02961 L .42072 1.02727 L .296 0 0 r
F
.41665 1.03268 m .42066 1.02735 L p .41362 1.02961 L F P
0 g
s
.42066 1.02735 m .42072 1.02727 L p .41362 1.02961 L .296 0 0 r
F P
0 g
s
.41978 1.02738 m .41977 1.02757 L .41236 1.02968 L .556 .491 .738 r
F
.41245 1.0299 m .41236 1.02968 L p .41977 1.02757 L F P
0 g
s
.41144 1.02759 m .41991 1.02539 L p .41978 1.02738 L .556 .491 .738 r
F P
0 g
s
.41242 1.02962 m .41308 1.02906 L p .40367 1.03232 L .136 0 0 r
F P
0 g
s
.41236 1.02968 m .41144 1.02759 L p .41978 1.02738 L .556 .491 .738 r
F P
0 g
s
.41144 1.02759 m .41236 1.02968 L p .41126 1.02998 L .574 .525 .762 r
F P
0 g
s
.40332 1.03215 m .40367 1.03232 L .40727 1.03107 L .136 0 0 r
F
.41128 1.02978 m .41126 1.02998 L .40223 1.03252 L .574 .525 .762 r
F
.40233 1.03273 m .40223 1.03252 L p .41126 1.02998 L F P
0 g
s
.40113 1.03028 m .41144 1.02759 L p .41128 1.02978 L .574 .525 .762 r
F P
0 g
s
.40223 1.03252 m .40113 1.03028 L p .41128 1.02978 L .574 .525 .762 r
F P
0 g
s
.40113 1.03028 m .40223 1.03252 L p .4009 1.0329 L .587 .553 .784 r
F P
0 g
s
.39182 1.03564 m .39011 1.03591 L .39188 1.03564 L 0 0 0 r
F
.39011 1.03591 m .38881 1.03351 L p .40092 1.0327 L .587 .553 .784 r
F P
0 g
s
.39011 1.03591 m .39917 1.05264 L p .38854 1.03639 L .597 .577 .803 r
F P
0 g
s
.38854 1.03639 m .38841 1.03774 L .38437 1.03763 L .597 .577 .803 r
F
.38259 1.03793 m .396 1.03574 L p .39188 1.03564 L 0 0 0 r
F P
0 g
s
.39011 1.03591 m .38259 1.03793 L p .39188 1.03564 L 0 0 0 r
F P
0 g
s
.38856 1.03615 m .39011 1.03591 L .38854 1.03639 L .597 .577 .803 r
F
.38881 1.03351 m .39011 1.03591 L p .38856 1.03615 L F P
0 g
s
.37709 1.03983 m .37581 1.03993 L p .37781 1.03958 L .192 .723 .774 r
F P
0 g
s
.37398 1.04025 m .37581 1.03993 L .37396 1.04049 L .604 .599 .819 r
F
.37396 1.04049 m .36923 1.04189 L .35731 1.04184 L F
.36101 1.04446 m .36142 1.04419 L .36665 1.04273 L .315 .801 .883 r
F
.3591 1.04461 m .35731 1.04184 L p .37381 1.04191 L .604 .599 .819 r
F P
0 g
s
.36685 1.04061 m .37591 1.03992 L p .36142 1.04419 L .315 .801 .883 r
F P
0 g
s
.38646 1.05788 m .37581 1.03993 L p .38841 1.03774 L .597 .577 .803 r
F P
0 g
s
.37781 1.03958 m .37581 1.03993 L .37787 1.03956 L .192 .723 .774 r
F
.36685 1.04061 m .38259 1.03793 L p .37787 1.03956 L F P
0 g
s
.37581 1.03993 m .36685 1.04061 L p .37787 1.03956 L .192 .723 .774 r
F P
0 g
s
.37581 1.03993 m .38646 1.05788 L p .37396 1.04049 L .604 .599 .819 r
F P
0 g
s
.37396 1.04049 m .37381 1.04191 L .36923 1.04189 L .604 .599 .819 r
F
.3606 1.04473 m .3591 1.04461 L p .36142 1.04419 L .315 .801 .883 r
F P
0 g
s
.35696 1.04503 m .3591 1.04461 L .35694 1.04529 L .61 .618 .834 r
F
.35694 1.04529 m .35157 1.04686 L .33762 1.04706 L F
.34194 1.04996 m .34239 1.04954 L .34831 1.04798 L .404 .84 .945 r
F
.3397 1.05005 m .33762 1.04706 L p .35678 1.04678 L .61 .618 .834 r
F P
0 g
s
.34695 1.01854 m .35731 1.04184 L .33762 1.04706 L p .638 .63 .826 r
F P
0 g
s
.3485 1.04382 m .35921 1.04462 L p .34239 1.04954 L .404 .84 .945 r
F P
0 g
s
.37155 1.06393 m .3591 1.04461 L p .37381 1.04191 L .604 .599 .819 r
F P
0 g
s
.36142 1.04419 m .3591 1.04461 L .36149 1.04414 L .315 .801 .883 r
F
.3485 1.04382 m .36685 1.04061 L p .36149 1.04414 L F P
0 g
s
.3591 1.04461 m .3485 1.04382 L p .36149 1.04414 L .315 .801 .883 r
F P
0 g
s
.3591 1.04461 m .37155 1.06393 L p .35694 1.04529 L .61 .618 .834 r
F P
0 g
s
.35694 1.04529 m .35678 1.04678 L .35157 1.04686 L .61 .618 .834 r
F
.34147 1.0504 m .3397 1.05005 L p .34239 1.04954 L .404 .84 .945 r
F P
0 g
s
.33723 1.05057 m .3397 1.05005 L .3372 1.05084 L .615 .636 .848 r
F
.3372 1.05084 m .33111 1.05261 L .3149 1.05309 L F
.31994 1.05629 m .32042 1.05572 L .32712 1.05403 L .465 .855 .977 r
F
.31733 1.05633 m .3149 1.05309 L p .33703 1.05244 L .615 .636 .848 r
F P
0 g
s
.32536 1.02186 m .33762 1.04706 L .3149 1.05309 L p .639 .645 .84 r
F P
0 g
s
.32726 1.04761 m .33983 1.05008 L p .32042 1.05572 L .465 .855 .977 r
F P
0 g
s
.3542 1.07087 m .3397 1.05005 L p .35678 1.04678 L .61 .618 .834 r
F P
0 g
s
.34239 1.04954 m .3397 1.05005 L .34246 1.04947 L .404 .84 .945 r
F
.33762 1.04706 m .32536 1.02186 L .34695 1.01854 L p .638 .63 .826 r
F P
0 g
s
.32726 1.04761 m .3485 1.04382 L p .34246 1.04947 L .404 .84 .945 r
F P
0 g
s
.3397 1.05005 m .32726 1.04761 L p .34246 1.04947 L .404 .84 .945 r
F P
0 g
s
.3397 1.05005 m .3542 1.07087 L p .3372 1.05084 L .615 .636 .848 r
F P
0 g
s
.3372 1.05084 m .33703 1.05244 L .33111 1.05261 L .615 .636 .848 r
F
.31939 1.05694 m .31733 1.05633 L p .32042 1.05572 L .465 .855 .977 r
F P
0 g
s
.31448 1.05696 m .31733 1.05633 L .31445 1.05725 L .619 .651 .86 r
F
.31445 1.05725 m .30755 1.05924 L .28882 1.06003 L F
.29465 1.06356 m .29518 1.06282 L .30276 1.06098 L .508 .858 .992 r
F
.29163 1.06354 m .28882 1.06003 L p .31427 1.05896 L .619 .651 .86 r
F P
0 g
s
.30048 1.02576 m .3149 1.05309 L .28882 1.06003 L p .641 .659 .852 r
F P
0 g
s
.30278 1.05204 m .31748 1.05637 L p .29518 1.06282 L .508 .858 .992 r
F P
0 g
s
.33415 1.07881 m .31733 1.05633 L p .33703 1.05244 L .615 .636 .848 r
F P
0 g
s
.32042 1.05572 m .31733 1.05633 L .3205 1.05563 L .465 .855 .977 r
F
.3149 1.05309 m .30048 1.02576 L .32536 1.02186 L p .639 .645 .84 r
F P
0 g
s
.30278 1.05204 m .32726 1.04761 L p .3205 1.05563 L .465 .855 .977 r
F P
0 g
s
.31733 1.05633 m .30278 1.05204 L p .3205 1.05563 L .465 .855 .977 r
F P
0 g
s
.31733 1.05633 m .33415 1.07881 L p .31445 1.05725 L .619 .651 .86 r
F P
0 g
s
.31445 1.05725 m .31427 1.05896 L .30755 1.05924 L .619 .651 .86 r
F
.29404 1.06444 m .29163 1.06354 L p .29518 1.06282 L .508 .858 .992 r
F P
0 g
s
.28837 1.06429 m .29163 1.06354 L .28834 1.0646 L .622 .665 .87 r
F
.28834 1.0646 m .28052 1.06685 L .25898 1.06797 L F
.26572 1.07188 m .26629 1.07095 L .27487 1.06893 L .538 .855 .997 r
F
.26223 1.07178 m .25898 1.06797 L p .28814 1.06645 L .622 .665 .87 r
F P
0 g
s
.2719 1.03032 m .28882 1.06003 L .25898 1.06797 L p .641 .671 .863 r
F P
0 g
s
.27467 1.05719 m .2918 1.0636 L p .26629 1.07095 L .538 .855 .997 r
F P
0 g
s
.31112 1.08788 m .29163 1.06354 L p .31427 1.05896 L .619 .651 .86 r
F P
0 g
s
.29518 1.06282 m .29163 1.06354 L .29526 1.0627 L .508 .858 .992 r
F
.28882 1.06003 m .2719 1.03032 L .30048 1.02576 L p .641 .659 .852 r
F P
0 g
s
.27467 1.05719 m .30278 1.05204 L p .29526 1.0627 L .508 .858 .992 r
F P
0 g
s
.29163 1.06354 m .27467 1.05719 L p .29526 1.0627 L .508 .858 .992 r
F P
0 g
s
.29163 1.06354 m .31112 1.08788 L p .28834 1.0646 L .622 .665 .87 r
F P
0 g
s
.28834 1.0646 m .28814 1.06645 L .28052 1.06685 L .622 .665 .87 r
F
.26503 1.07301 m .26223 1.07178 L p .26629 1.07095 L .538 .855 .997 r
F P
0 g
s
.25851 1.07267 m .26223 1.07178 L .25847 1.073 L .625 .677 .88 r
F
.25847 1.073 m .23332 1.08022 L .22494 1.07704 L F
.23195 1.08278 m .2287 1.08119 L p .23332 1.08022 L .559 .848 .998 r
F P
0 g
s
.22896 1.08147 m .2287 1.08119 L p .23332 1.08022 L .625 .677 .88 r
F P
0 g
s
.2287 1.08119 m .22494 1.07704 L p .23332 1.08022 L .625 .677 .88 r
F P
0 g
s
.22494 1.07704 m .20179 1.04168 L .23918 1.0356 L p .642 .683 .873 r
F P
0 g
s
.23918 1.0356 m .25898 1.06797 L .22494 1.07704 L p .642 .683 .873 r
F P
0 g
s
.20572 1.06995 m .24248 1.06313 L p .23332 1.08022 L .559 .848 .998 r
F P
0 g
s
.2287 1.08119 m .20572 1.06995 L p .23332 1.08022 L .559 .848 .998 r
F P
0 g
s
.24248 1.06313 m .26243 1.07187 L p .23332 1.08022 L .559 .848 .998 r
F P
0 g
s
.28477 1.09819 m .26223 1.07178 L p .28814 1.06645 L .622 .665 .87 r
F P
0 g
s
.26629 1.07095 m .26223 1.07178 L .26638 1.0708 L .538 .855 .997 r
F
.25898 1.06797 m .23918 1.0356 L .2719 1.03032 L p .641 .671 .863 r
F P
0 g
s
.24248 1.06313 m .27467 1.05719 L p .26638 1.0708 L .538 .855 .997 r
F P
0 g
s
.26223 1.07178 m .24248 1.06313 L p .26638 1.0708 L .538 .855 .997 r
F P
0 g
s
.26223 1.07178 m .28477 1.09819 L p .25847 1.073 L .625 .677 .88 r
F P
0 g
s
.23271 1.08136 m .23332 1.08022 L .24303 1.07801 L .559 .848 .998 r
F
.25474 1.10989 m .22896 1.08147 L p .25847 1.073 L .625 .677 .88 r
F P
0 g
s
.55966 1.21112 m .51966 1.20202 L .51767 1.18677 L p .434 .656 .953 r
F P
0 g
s
.48237 1.17496 m .51767 1.18677 L .51966 1.20202 L p .463 .65 .94 r
F P
0 g
s
.49257 .98887 m .5118 .97729 L .51475 .98645 L p .82 .895 .895 r
F P
0 g
s
.51475 .98645 m .49326 .9978 L .49257 .98887 L p .82 .895 .895 r
F P
0 g
s
.45226 1.01588 m .47226 1.0076 L .46988 1.01712 L p .77 .944 .936 r
F P
0 g
s
.46988 1.01712 m .44726 1.02472 L .45226 1.01588 L p .77 .944 .936 r
F P
0 g
s
.68379 .85461 m .6735 .87873 L .65487 .87317 L p .745 .717 .826 r
F P
0 g
s
.6735 .87873 m .68379 .85461 L .70618 .85873 L p .736 .72 .836 r
F P
0 g
s
.73937 .83397 m .73181 .86323 L .70618 .85873 L p .717 .709 .841 r
F P
0 g
s
.73181 .86323 m .73937 .83397 L .76967 .8362 L p .711 .714 .851 r
F P
0 g
s
.42196 .61706 m .44159 .61794 L .45283 .62856 L p .366 .634 .957 r
F P
0 g
s
.44159 .61794 m .42196 .61706 L .40691 .60635 L p .408 .656 .96 r
F P
0 g
s
.59142 .74 m .5956 .74663 L .60102 .748 L p .715 .249 .141 r
F P
0 g
s
.5956 .74663 m .59142 .74 L .58675 .73735 L p .786 .318 .128 r
F P
0 g
s
.56071 .70914 m .57097 .71783 L .57304 .72238 L p 0 .296 .793 r
F P
0 g
s
.57097 .71783 m .56071 .70914 L .55851 .70346 L p .161 .377 .826 r
F P
0 g
s
.58507 .91822 m .6003 .90068 L .61252 .90772 L p .795 .774 .834 r
F P
0 g
s
.62688 .8883 m .61252 .90772 L .6003 .90068 L p .786 .754 .824 r
F P
0 g
s
.29978 .5839 m .32071 .57331 L .34639 .58653 L p .494 .727 .976 r
F P
0 g
s
.32071 .57331 m .29978 .5839 L .26767 .57195 L p .521 .734 .971 r
F P
0 g
s
.58104 .73105 m .57304 .72238 L .57097 .71783 L p 0 .24 .753 r
F P
0 g
s
.58675 .73735 m .59158 .74492 L .5956 .74663 L p .786 .318 .128 r
F P
0 g
s
.59158 .74492 m .58675 .73735 L .58331 .73439 L p .805 .318 0 r
F P
0 g
s
.36869 .59818 m .3897 .59427 L .40691 .60635 L p .431 .687 .971 r
F P
0 g
s
.3897 .59427 m .36869 .59818 L .34639 .58653 L p .467 .701 .97 r
F P
0 g
s
.45283 .62856 m .47236 .63199 L .48041 .64215 L p .349 .601 .942 r
F P
0 g
s
.47236 .63199 m .45283 .62856 L .44159 .61794 L p .391 .624 .946 r
F P
0 g
s
.36933 1.13676 m .33818 1.11354 L .3577 1.10263 L p .572 .642 .882 r
F P
0 g
s
.3577 1.10263 m .38496 1.12432 L .36933 1.13676 L p .572 .642 .882 r
F P
0 g
s
.47388 .99911 m .49257 .98887 L .49326 .9978 L p .813 .926 .91 r
F P
0 g
s
.49326 .9978 m .47226 1.0076 L .47388 .99911 L p .813 .926 .91 r
F P
0 g
s
.71296 .83186 m .70618 .85873 L .68379 .85461 L p .724 .703 .831 r
F P
0 g
s
.70618 .85873 m .71296 .83186 L .73937 .83397 L p .717 .709 .841 r
F P
0 g
s
.65172 .75004 m .6534 .75061 L .63898 .75062 L p .017 0 0 r
F P
0 g
s
.63792 .75167 m .63376 .75333 L .63555 .75288 L p 0 0 0 r
F P
0 g
s
.63792 .75167 m .65172 .75004 L p .64006 .75057 L .017 0 0 r
F P
0 g
s
.64657 .75012 m .65172 .75004 L .63792 .75167 L p 0 0 0 r
F P
0 g
s
.63555 .75288 m .64657 .75012 L p .63792 .75167 L 0 0 0 r
F P
0 g
s
.63898 .75062 m .63792 .75167 L p .64006 .75057 L .017 0 0 r
F P
0 g
s
.63792 .75167 m .63898 .75062 L .62674 .75037 L p .207 0 0 r
F P
0 g
s
.66796 .74796 m .67025 .75034 L .6534 .75061 L p .164 .703 .777 r
F P
0 g
s
.6534 .75061 m .65172 .75004 L .66796 .74796 L p .164 .703 .777 r
F P
0 g
s
.62674 .75037 m .6263 .75287 L .63792 .75167 L p .207 0 0 r
F P
0 g
s
.6263 .75287 m .62674 .75037 L .61645 .74985 L p .371 0 0 r
F P
0 g
s
.68694 .74539 m .68984 .74981 L .67025 .75034 L p .308 .794 .895 r
F P
0 g
s
.67025 .75034 m .66796 .74796 L .68694 .74539 L p .308 .794 .895 r
F P
0 g
s
.48041 .64215 m .49913 .64764 L .50463 .65707 L p .335 .57 .925 r
F P
0 g
s
.49913 .64764 m .48041 .64215 L .47236 .63199 L p .378 .594 .93 r
F P
0 g
s
.54347 .68826 m .55705 .6972 L .55851 .70346 L p .248 .45 .862 r
F P
0 g
s
.55705 .6972 m .54347 .68826 L .5412 .68083 L p .323 .488 .868 r
F P
0 g
s
.52559 .67263 m .5412 .68083 L .54347 .68826 L p .293 .499 .886 r
F P
0 g
s
.62688 .8883 m .63857 .86804 L .65487 .87317 L p .766 .734 .824 r
F P
0 g
s
.66426 .85078 m .65487 .87317 L .63857 .86804 L p .754 .714 .815 r
F P
0 g
s
.65487 .87317 m .66426 .85078 L .68379 .85461 L p .745 .717 .826 r
F P
0 g
s
.61645 .74985 m .61664 .75367 L .6263 .75287 L p .371 0 0 r
F P
0 g
s
.61664 .75367 m .61645 .74985 L .60793 .74907 L p .496 .026 .068 r
F P
0 g
s
.52617 .95606 m .54337 .94202 L .55005 .95018 L p .827 .84 .858 r
F P
0 g
s
.55005 .95018 m .53111 .96438 L .52617 .95606 L p .827 .84 .858 r
F P
0 g
s
.56819 .93476 m .55005 .95018 L .54337 .94202 L p .82 .817 .847 r
F P
0 g
s
.70902 .74228 m .71253 .74901 L .68984 .74981 L p .411 .836 .959 r
F P
0 g
s
.68984 .74981 m .68694 .74539 L .70902 .74228 L p .411 .836 .959 r
F P
0 g
s
.54337 .94202 m .55991 .92695 L .56819 .93476 L p .82 .817 .847 r
F P
0 g
s
.58507 .91822 m .56819 .93476 L .55991 .92695 L p .812 .796 .836 r
F P
0 g
s
.58331 .73439 m .58888 .74285 L p .58816 .74056 L .805 .318 0 r
F P
0 g
s
.58746 .74037 m .58888 .74285 L p .58564 .73796 L 0 0 .475 r
F P
0 g
s
.58104 .73105 m .58746 .74037 L p .58564 .73796 L 0 0 .475 r
F P
0 g
s
.58888 .74285 m .59158 .74492 L p .58816 .74056 L .805 .318 0 r
F P
0 g
s
.58746 .74037 m .58729 .73745 L p .58929 .74279 L .202 .241 .68 r
F P
0 g
s
.58888 .74285 m .58746 .74037 L p .58961 .74514 L 0 0 .388 r
F P
0 g
s
.59266 .75192 m .58888 .74285 L p .58961 .74514 L 0 0 .388 r
F P
0 g
s
.59455 .75304 m .59158 .74492 L .58888 .74285 L p .875 .47 .256 r
F P
0 g
s
.59266 .75192 m .59455 .75304 L p .5922 .74882 L .875 .47 .256 r
F P
0 g
s
.58888 .74285 m .59266 .75192 L p .5922 .74882 L .875 .47 .256 r
F P
0 g
s
.59212 .75037 m .59266 .75192 L p .59051 .74714 L 0 0 .388 r
F P
0 g
s
.58746 .74037 m .59212 .75037 L p .59051 .74714 L 0 0 .388 r
F P
0 g
s
.59158 .74492 m .59455 .75304 L .59782 .75377 L p .758 .384 .346 r
F P
0 g
s
.59557 .76178 m .59455 .75304 L .59266 .75192 L p .749 .459 .492 r
F P
0 g
s
.59212 .75037 m .59293 .74838 L p .59374 .75362 L .49 .371 .644 r
F P
0 g
s
.59454 .76163 m .59266 .75192 L p .59312 .75502 L .169 .133 .572 r
F P
0 g
s
.59454 .76163 m .59557 .76178 L p .59436 .7577 L .749 .459 .492 r
F P
0 g
s
.59266 .75192 m .59454 .76163 L p .59436 .7577 L .749 .459 .492 r
F P
0 g
s
.59446 .77199 m .59454 .76163 L p .59471 .76574 L .816 .569 .566 r
F P
0 g
s
.59571 .77238 m .59446 .77199 L p .59462 .76809 L .816 .569 .566 r
F P
0 g
s
.59488 .76685 m .59571 .77238 L .59462 .76809 L .816 .569 .566 r
F
.5952 .7653 m .59571 .77238 L p .59471 .76574 L F P
0 g
s
.59484 .76881 m .59557 .76178 L .59454 .76163 L p 0 0 .125 r
F P
0 g
s
.59455 .75304 m .59557 .76178 L .598 .76151 L p .615 .326 .456 r
F P
0 g
s
.598 .76151 m .59557 .76178 L p .59571 .76391 L .202 .003 .371 r
F P
0 g
s
.59571 .76391 m .59606 .76407 L .598 .76151 L .202 .003 .371 r
F
.59575 .76448 m .59627 .76498 L .598 .76151 L F
.59729 .76466 m .59836 .77236 L p .5965 .76578 L .7 .507 .624 r
F P
0 g
s
.59729 .76466 m .5965 .76578 L .59627 .76498 L .7 .507 .624 r
F
.59836 .77236 m .59571 .77238 L p .59627 .76498 L F P
0 g
s
.59782 .75377 m .598 .76151 L .60187 .76081 L p .545 .222 .371 r
F P
0 g
s
.598 .76151 m .59782 .75377 L .59455 .75304 L p .615 .326 .456 r
F P
0 g
s
.60187 .76081 m .598 .76151 L p .59831 .76348 L .264 0 .294 r
F P
0 g
s
.59831 .76348 m .59878 .7635 L .60187 .76081 L .264 0 .294 r
F
.59837 .76385 m .59925 .76397 L .60187 .76081 L F
.60082 .76357 m .60247 .77193 L p .59952 .76462 L .668 .511 .663 r
F P
0 g
s
.60082 .76357 m .59952 .76462 L .59925 .76397 L .668 .511 .663 r
F
.60247 .77193 m .59836 .77236 L p .59925 .76397 L F P
0 g
s
.60247 .77193 m .60082 .76357 L p .60356 .76367 L .657 .527 .694 r
F P
0 g
s
.60234 .76233 m .60203 .76289 L .60244 .76265 L .229 0 .162 r
F
.60187 .76081 m .60082 .76357 L p .60234 .76233 L F P
0 g
s
.60356 .76367 m .60082 .76357 L .60244 .76265 L .657 .527 .694 r
F
.60727 .75967 m .60876 .75408 L .60253 .75411 L p .473 .1 .251 r
F P
0 g
s
.60253 .75411 m .60187 .76081 L .60727 .75967 L p .473 .1 .251 r
F P
0 g
s
.61429 .75806 m .61664 .75367 L .60876 .75408 L p .377 0 .088 r
F P
0 g
s
.60876 .75408 m .60727 .75967 L .61429 .75806 L p .377 0 .088 r
F P
0 g
s
.61429 .75806 m .60727 .75967 L p .60805 .76095 L .14 0 0 r
F P
0 g
s
.60972 .76066 m .60957 .7616 L .60878 .76082 L .653 .547 .721 r
F
.60811 .77106 m .60585 .76202 L p .60957 .7616 L F P
0 g
s
.60805 .76095 m .60972 .76066 L .61429 .75806 L .14 0 0 r
F
.61247 .75999 m .61538 .76976 L p .61005 .76119 L .653 .547 .721 r
F P
0 g
s
.61247 .75999 m .61005 .76119 L .60972 .76066 L .653 .547 .721 r
F
.61538 .76976 m .60811 .77106 L p .60972 .76066 L F P
0 g
s
.60793 .74907 m .60876 .75408 L .61664 .75367 L p .496 .026 .068 r
F P
0 g
s
.62306 .75597 m .6263 .75287 L .61664 .75367 L p .245 0 0 r
F P
0 g
s
.61664 .75367 m .61429 .75806 L .62306 .75597 L p .245 0 0 r
F P
0 g
s
.62306 .75597 m .61429 .75806 L p .6153 .75871 L .008 0 0 r
F P
0 g
s
.6174 .75826 m .61727 .75899 L .6153 .75871 L .653 .566 .745 r
F
.61727 .75899 m .61538 .76976 L .61531 .75983 L F
.61727 .75899 m .61531 .75983 L .6153 .75871 L F
.62442 .76798 m .61538 .76976 L p .61727 .75899 L F P
0 g
s
.6174 .75826 m .62083 .75742 L .61727 .75899 L .653 .566 .745 r
F
.62083 .75742 m .62442 .76798 L p .61727 .75899 L F P
0 g
s
.61709 .75985 m .62059 .75757 L p .6174 .75826 L .008 0 0 r
F P
0 g
s
.6153 .75871 m .61538 .75876 L .6174 .75826 L .008 0 0 r
F
.61538 .75876 m .61709 .75985 L .6174 .75826 L F
.62059 .75757 m .62083 .75742 L p .6153 .75871 L F P
0 g
s
.62083 .75742 m .62306 .75597 L p .61592 .75849 L .008 0 0 r
F P
0 g
s
.6153 .75871 m .62083 .75742 L .61592 .75849 L .008 0 0 r
F
.63376 .75333 m .63792 .75167 L .6263 .75287 L p .075 0 0 r
F P
0 g
s
.6263 .75287 m .62306 .75597 L .63376 .75333 L p .075 0 0 r
F P
0 g
s
.63376 .75333 m .62306 .75597 L p .62433 .75592 L 0 0 0 r
F P
0 g
s
.6269 .7553 m .62674 .75612 L .62584 .75556 L .653 .585 .766 r
F
.82367 .70408 m .78576 .71402 L p .79129 .7041 L .633 .862 .985 r
F P
0 g
s
.77098 .69592 m .80691 .68309 L p .80086 .70049 L .657 .688 .868 r
F P
0 g
s
.80086 .70049 m .80056 .70136 L .79922 .70111 L .657 .688 .868 r
F
.80086 .70049 m .79922 .70111 L .77098 .69592 L F
.80056 .70136 m .79791 .70214 L .77098 .69592 L F
.78576 .71402 m .77829 .709 L p .79129 .7041 L .633 .862 .985 r
F P
0 g
s
.79129 .7041 m .80056 .70136 L .82367 .70408 L .633 .862 .985 r
F
.80691 .68309 m .81521 .69765 L p .80056 .70136 L .657 .688 .868 r
F P
0 g
s
.81462 .6972 m .81521 .69765 L p .80056 .70136 L .633 .862 .985 r
F P
0 g
s
.81521 .69765 m .82367 .70408 L p .80056 .70136 L .633 .862 .985 r
F P
0 g
s
.76893 .74653 m .76424 .73416 L .79845 .72901 L p .557 .847 .998 r
F P
0 g
s
.78576 .71402 m .79845 .72901 L .76424 .73416 L p .59 .864 .994 r
F P
0 g
s
.82367 .70408 m .83792 .72299 L .79845 .72901 L p .605 .852 .991 r
F P
0 g
s
.79845 .72901 m .78576 .71402 L .82367 .70408 L p .605 .852 .991 r
F P
0 g
s
.8289 .72166 m .79038 .73061 L p .80056 .70136 L .657 .688 .868 r
F P
0 g
s
.81521 .69765 m .8289 .72166 L p .80056 .70136 L .657 .688 .868 r
F P
0 g
s
.77829 .709 m .77098 .69592 L p .80011 .70265 L .657 .688 .868 r
F P
0 g
s
.74004 .70699 m .77098 .69592 L p .7659 .71142 L .657 .679 .859 r
F P
0 g
s
.7659 .71142 m .76565 .7122 L .76447 .71196 L .657 .679 .859 r
F
.7659 .71142 m .76447 .71196 L .74004 .70699 L F
.76565 .7122 m .76333 .71288 L .74004 .70699 L F
.75303 .72258 m .74647 .71878 L p .75766 .71454 L .625 .876 .989 r
F P
0 g
s
.78576 .71402 m .75303 .72258 L p .75734 .7151 L .625 .876 .989 r
F P
0 g
s
.75734 .7151 m .75766 .71454 L .75935 .71451 L .625 .876 .989 r
F
.75734 .7151 m .75935 .71451 L .78576 .71402 L F
.75766 .71454 m .76565 .7122 L .78576 .71402 L F
.77098 .69592 m .77829 .709 L p .76565 .7122 L .657 .679 .859 r
F P
0 g
s
.77777 .70864 m .77829 .709 L p .76565 .7122 L .625 .876 .989 r
F P
0 g
s
.77829 .709 m .78576 .71402 L p .76565 .7122 L .625 .876 .989 r
F P
0 g
s
.76424 .73416 m .76893 .74653 L .73873 .74792 L p .525 .852 .997 r
F P
0 g
s
.73873 .74792 m .73462 .73856 L .76424 .73416 L p .525 .852 .997 r
F P
0 g
s
.75303 .72258 m .76424 .73416 L .73462 .73856 L p .567 .874 .994 r
F P
0 g
s
.76424 .73416 m .75303 .72258 L .78576 .71402 L p .59 .864 .994 r
F P
0 g
s
.79038 .73061 m .7571 .73831 L p .76565 .7122 L .657 .679 .859 r
F P
0 g
s
.77829 .709 m .79038 .73061 L p .76565 .7122 L .657 .679 .859 r
F P
0 g
s
.74647 .71878 m .74004 .70699 L p .76526 .71337 L .657 .679 .859 r
F P
0 g
s
.71343 .71652 m .74004 .70699 L p .73578 .72083 L .657 .669 .85 r
F P
0 g
s
.73578 .72083 m .73556 .72154 L .73453 .72131 L .657 .669 .85 r
F
.73578 .72083 m .73453 .72131 L .71343 .71652 L F
.73556 .72154 m .73352 .72213 L .71343 .71652 L F
.7248 .72995 m .71906 .72721 L p .72868 .72354 L .612 .891 .989 r
F P
0 g
s
.75303 .72258 m .7248 .72995 L p .72841 .72399 L .612 .891 .989 r
F P
0 g
s
.72841 .72399 m .72868 .72354 L .73016 .72348 L .612 .891 .989 r
F
.72841 .72399 m .73016 .72348 L .75303 .72258 L F
.72868 .72354 m .73556 .72154 L .75303 .72258 L F
.74004 .70699 m .74647 .71878 L p .73556 .72154 L .657 .669 .85 r
F P
0 g
s
.746 .71851 m .74647 .71878 L p .73556 .72154 L .612 .891 .989 r
F P
0 g
s
.74647 .71878 m .75303 .72258 L p .73556 .72154 L .612 .891 .989 r
F P
0 g
s
.73462 .73856 m .73873 .74792 L .71253 .74901 L p .479 .851 .987 r
F P
0 g
s
.71253 .74901 m .70902 .74228 L .73462 .73856 L p .479 .851 .987 r
F P
0 g
s
.7248 .72995 m .73462 .73856 L .70902 .74228 L p .533 .881 .986 r
F P
0 g
s
.73462 .73856 m .7248 .72995 L .75303 .72258 L p .567 .874 .994 r
F P
0 g
s
.7571 .73831 m .72837 .74492 L p .73556 .72154 L .657 .669 .85 r
F P
0 g
s
.74647 .71878 m .7571 .73831 L p .73556 .72154 L .657 .669 .85 r
F P
0 g
s
.71906 .72721 m .71343 .71652 L p .73523 .72261 L .657 .669 .85 r
F P
0 g
s
.69059 .72474 m .71343 .71652 L p .70985 .72893 L .657 .658 .84 r
F P
0 g
s
.70985 .72893 m .70966 .72959 L .70875 .72935 L .657 .658 .84 r
F
.70985 .72893 m .70875 .72935 L .69059 .72474 L F
.70966 .72959 m .70787 .7301 L .69059 .72474 L F
.7005 .73627 m .69549 .73446 L p .70375 .73128 L .592 .904 .984 r
F P
0 g
s
.7248 .72995 m .7005 .73627 L p .70352 .73164 L .592 .904 .984 r
F P
0 g
s
.70352 .73164 m .70375 .73128 L .70505 .7312 L .592 .904 .984 r
F
.70352 .73164 m .70505 .7312 L .7248 .72995 L F
.70375 .73128 m .70966 .72959 L .7248 .72995 L F
.71343 .71652 m .71906 .72721 L p .70966 .72959 L .657 .658 .84 r
F P
0 g
s
.71864 .72701 m .71906 .72721 L p .70966 .72959 L .592 .904 .984 r
F P
0 g
s
.71906 .72721 m .7248 .72995 L p .70966 .72959 L .592 .904 .984 r
F P
0 g
s
.7005 .73627 m .70902 .74228 L .68694 .74539 L p .481 .877 .961 r
F P
0 g
s
.70902 .74228 m .7005 .73627 L .7248 .72995 L p .533 .881 .986 r
F P
0 g
s
.72837 .74492 m .7036 .75058 L p .70966 .72959 L .657 .658 .84 r
F P
0 g
s
.71906 .72721 m .72837 .74492 L p .70966 .72959 L .657 .658 .84 r
F P
0 g
s
.69549 .73446 m .69059 .72474 L p .70938 .73057 L .657 .658 .84 r
F P
0 g
s
.67104 .7318 m .69059 .72474 L p .68758 .73589 L .656 .646 .828 r
F P
0 g
s
.68758 .73589 m .68742 .73649 L .68662 .73626 L .656 .646 .828 r
F
.68758 .73589 m .68662 .73626 L .67104 .7318 L F
.68742 .73649 m .68583 .73694 L .67104 .7318 L F
.67962 .74167 m .67528 .74067 L p .68235 .73793 L .561 .912 .966 r
F P
0 g
s
.7005 .73627 m .67962 .74167 L p .68215 .7382 L .561 .912 .966 r
F P
0 g
s
.68215 .7382 m .68235 .73793 L .68349 .73782 L .561 .912 .966 r
F
.68215 .7382 m .68349 .73782 L .7005 .73627 L F
.68235 .73793 m .68742 .73649 L .7005 .73627 L F
.69059 .72474 m .69549 .73446 L p .68742 .73649 L .656 .646 .828 r
F P
0 g
s
.69511 .73432 m .69549 .73446 L p .68742 .73649 L .561 .912 .966 r
F P
0 g
s
.69549 .73446 m .7005 .73627 L p .68742 .73649 L .561 .912 .966 r
F P
0 g
s
.67962 .74167 m .68694 .74539 L .66796 .74796 L p .399 .85 .905 r
F P
0 g
s
.68694 .74539 m .67962 .74167 L .7005 .73627 L p .481 .877 .961 r
F P
0 g
s
.7036 .75058 m .68231 .7554 L p .68742 .73649 L .656 .646 .828 r
F P
0 g
s
.69549 .73446 m .7036 .75058 L p .68742 .73649 L .656 .646 .828 r
F P
0 g
s
.67528 .74067 m .67104 .7318 L p .68717 .73741 L .656 .646 .828 r
F P
0 g
s
.65439 .73785 m .67104 .7318 L p .66852 .74184 L .655 .633 .815 r
F P
0 g
s
.66852 .74184 m .66837 .74241 L .66766 .74218 L .655 .633 .815 r
F
.66852 .74184 m .66766 .74218 L .65439 .73785 L F
.66837 .74241 m .66695 .7428 L .65439 .73785 L F
.66176 .74625 m .65803 .74598 L p .66404 .74361 L .509 .906 .925 r
F P
0 g
s
.67962 .74167 m .66176 .74625 L p .66387 .7438 L .509 .906 .925 r
F P
0 g
s
.66387 .7438 m .66404 .74361 L .66505 .74348 L .509 .906 .925 r
F
.66387 .7438 m .66505 .74348 L .67962 .74167 L F
.66404 .74361 m .66837 .74241 L .67962 .74167 L F
.67104 .7318 m .67528 .74067 L p .66837 .74241 L .655 .633 .815 r
F P
0 g
s
.67494 .7406 m .67528 .74067 L p .66837 .74241 L .509 .906 .925 r
F P
0 g
s
.67528 .74067 m .67962 .74167 L p .66837 .74241 L .509 .906 .925 r
F P
0 g
s
.66176 .74625 m .66796 .74796 L .65172 .75004 L p .277 .78 .796 r
F P
0 g
s
.66796 .74796 m .66176 .74625 L .67962 .74167 L p .399 .85 .905 r
F P
0 g
s
.68231 .7554 m .66407 .75948 L p .66837 .74241 L .655 .633 .815 r
F P
0 g
s
.67528 .74067 m .68231 .7554 L p .66837 .74241 L .655 .633 .815 r
F P
0 g
s
.65803 .74598 m .65439 .73785 L p .66815 .74328 L .655 .633 .815 r
F P
0 g
s
.64028 .74301 m .65439 .73785 L p .65227 .74691 L .655 .618 .8 r
F P
0 g
s
.65227 .74691 m .65214 .74745 L .65151 .74722 L .655 .618 .8 r
F
.65227 .74691 m .65151 .74722 L .64028 .74301 L F
.65214 .74745 m .65087 .7478 L .64028 .74301 L F
.64657 .75012 m .64338 .75048 L p .64847 .74844 L .428 .871 .843 r
F P
0 g
s
.66176 .74625 m .64657 .75012 L p .64832 .74857 L .428 .871 .843 r
F P
0 g
s
.64832 .74857 m .64847 .74844 L .64936 .74829 L .428 .871 .843 r
F
.64832 .74857 m .64936 .74829 L .66176 .74625 L F
.64847 .74844 m .65214 .74745 L .66176 .74625 L F
.65439 .73785 m .65803 .74598 L p .65214 .74745 L .655 .618 .8 r
F P
0 g
s
.65772 .74596 m .65803 .74598 L p .65214 .74745 L .428 .871 .843 r
F P
0 g
s
.65803 .74598 m .66176 .74625 L p .65214 .74745 L .428 .871 .843 r
F P
0 g
s
.65172 .75004 m .64657 .75012 L .66176 .74625 L p .277 .78 .796 r
F P
0 g
s
.66407 .75948 m .64854 .76289 L p .65214 .74745 L .655 .618 .8 r
F P
0 g
s
.65803 .74598 m .66407 .75948 L p .65214 .74745 L .655 .618 .8 r
F P
0 g
s
.64338 .75048 m .64028 .74301 L p .65195 .74828 L .655 .618 .8 r
F P
0 g
s
.62845 .74739 m .64028 .74301 L p .63852 .7512 L .654 .602 .784 r
F P
0 g
s
.63852 .7512 m .63841 .75172 L .63785 .75148 L .654 .602 .784 r
F
.63852 .7512 m .63785 .75148 L .62845 .74739 L F
.63841 .75172 m .63725 .75202 L .62845 .74739 L F
.63376 .75333 m .63106 .75427 L p .63532 .75252 L .307 .785 .699 r
F P
0 g
s
.64657 .75012 m .63376 .75333 L p .63519 .75258 L .307 .785 .699 r
F P
0 g
s
.63519 .75258 m .63532 .75252 L .63611 .75235 L .307 .785 .699 r
F
.63519 .75258 m .63611 .75235 L .64657 .75012 L F
.63532 .75252 m .63841 .75172 L .64657 .75012 L F
.64028 .74301 m .64338 .75048 L p .63841 .75172 L .654 .602 .784 r
F P
0 g
s
.6431 .75051 m .64338 .75048 L p .63841 .75172 L .307 .785 .699 r
F P
0 g
s
.64338 .75048 m .64657 .75012 L p .63841 .75172 L .307 .785 .699 r
F P
0 g
s
.64854 .76289 m .6354 .76571 L p .63841 .75172 L .654 .602 .784 r
F P
0 g
s
.64338 .75048 m .64854 .76289 L p .63841 .75172 L .654 .602 .784 r
F P
0 g
s
.62503 .75573 m .62745 .75514 L .63376 .75333 L 0 0 0 r
F
.63106 .75427 m .63376 .75333 L p .6269 .7553 L F P
0 g
s
.63106 .75427 m .62845 .74739 L p .63824 .75254 L .654 .602 .784 r
F P
0 g
s
.63106 .75427 m .6354 .76571 L p .6269 .7553 L .653 .585 .766 r
F P
0 g
s
.63081 .75436 m .63106 .75427 L p .6269 .7553 L 0 0 0 r
F P
0 g
s
.6354 .76571 m .62442 .76798 L p .6269 .7553 L .653 .585 .766 r
F P
0 g
s
.62845 .74739 m .63106 .75427 L p .6269 .7553 L .653 .585 .766 r
F P
0 g
s
.62421 .75592 m .62246 .75672 L .62433 .75592 L 0 0 0 r
F
.62306 .75597 m .62083 .75742 L p .62421 .75592 L F P
0 g
s
.62674 .75612 m .62282 .75657 L .62584 .75556 L .653 .585 .766 r
F
.62282 .75657 m .62062 .75682 L .62433 .75592 L F
.62282 .75657 m .62433 .75592 L .62584 .75556 L F
.62674 .75612 m .62083 .75742 L .62282 .75657 L F
.62083 .75742 m .62059 .75757 L p .62246 .75672 L 0 0 0 r
F P
0 g
s
.62083 .75742 m .62246 .75672 L .62421 .75592 L 0 0 0 r
F
.62442 .76798 m .62083 .75742 L p .62674 .75612 L .653 .585 .766 r
F P
0 g
s
.62433 .75592 m .62059 .75757 L .62447 .75592 L 0 0 0 r
F
.62246 .75672 m .62059 .75757 L .62433 .75592 L F
.62083 .75742 m .62062 .75682 L p .62282 .75657 L .653 .585 .766 r
F P
0 g
s
.62433 .75592 m .62745 .75514 L .62503 .75573 L 0 0 0 r
F
.62062 .75682 m .61867 .75107 L p .62584 .75556 L .653 .585 .766 r
F P
0 g
s
.62656 .75584 m .63081 .75436 L p .62433 .75592 L 0 0 0 r
F P
0 g
s
.62656 .75584 m .63804 .7511 L p .63532 .75252 L .307 .785 .699 r
F P
0 g
s
.63106 .75427 m .62656 .75584 L p .63532 .75252 L .307 .785 .699 r
F P
0 g
s
.63804 .7511 m .65176 .74552 L p .64847 .74844 L .428 .871 .843 r
F P
0 g
s
.64338 .75048 m .63804 .7511 L p .64847 .74844 L .428 .871 .843 r
F P
0 g
s
.65176 .74552 m .668 .73901 L p .66404 .74361 L .509 .906 .925 r
F P
0 g
s
.65803 .74598 m .65176 .74552 L p .66404 .74361 L .509 .906 .925 r
F P
0 g
s
.668 .73901 m .68708 .73143 L p .68235 .73793 L .561 .912 .966 r
F P
0 g
s
.67528 .74067 m .668 .73901 L p .68235 .73793 L .561 .912 .966 r
F P
0 g
s
.68708 .73143 m .70939 .72262 L p .70375 .73128 L .592 .904 .984 r
F P
0 g
s
.69549 .73446 m .68708 .73143 L p .70375 .73128 L .592 .904 .984 r
F P
0 g
s
.70939 .72262 m .73542 .71239 L p .72868 .72354 L .612 .891 .989 r
F P
0 g
s
.71906 .72721 m .70939 .72262 L p .72868 .72354 L .612 .891 .989 r
F P
0 g
s
.73542 .71239 m .76571 .70054 L p .75766 .71454 L .625 .876 .989 r
F P
0 g
s
.74647 .71878 m .73542 .71239 L p .75766 .71454 L .625 .876 .989 r
F P
0 g
s
.76571 .70054 m .80093 .68679 L p .79129 .7041 L .633 .862 .985 r
F P
0 g
s
.77829 .709 m .76571 .70054 L p .79129 .7041 L .633 .862 .985 r
F P
0 g
s
.80093 .68679 m .81462 .6972 L p .79129 .7041 L .633 .862 .985 r
F P
0 g
s
.80056 .70136 m .80011 .70265 L .79791 .70214 L .657 .688 .868 r
F
.79038 .73061 m .77829 .709 L p .80011 .70265 L F P
0 g
s
.76571 .70054 m .77777 .70864 L p .75766 .71454 L .625 .876 .989 r
F P
0 g
s
.76565 .7122 m .76526 .71337 L .76333 .71288 L .657 .679 .859 r
F
.7571 .73831 m .74647 .71878 L p .76526 .71337 L F P
0 g
s
.73542 .71239 m .746 .71851 L p .72868 .72354 L .612 .891 .989 r
F P
0 g
s
.73556 .72154 m .73523 .72261 L .73352 .72213 L .657 .669 .85 r
F
.72837 .74492 m .71906 .72721 L p .73523 .72261 L F P
0 g
s
.70939 .72262 m .71864 .72701 L p .70375 .73128 L .592 .904 .984 r
F P
0 g
s
.70966 .72959 m .70938 .73057 L .70787 .7301 L .657 .658 .84 r
F
.7036 .75058 m .69549 .73446 L p .70938 .73057 L F P
0 g
s
.68708 .73143 m .69511 .73432 L p .68235 .73793 L .561 .912 .966 r
F P
0 g
s
.68742 .73649 m .68717 .73741 L .68583 .73694 L .656 .646 .828 r
F
.68231 .7554 m .67528 .74067 L p .68717 .73741 L F P
0 g
s
.668 .73901 m .67494 .7406 L p .66404 .74361 L .509 .906 .925 r
F P
0 g
s
.66837 .74241 m .66815 .74328 L .66695 .7428 L .655 .633 .815 r
F
.66407 .75948 m .65803 .74598 L p .66815 .74328 L F P
0 g
s
.65176 .74552 m .65772 .74596 L p .64847 .74844 L .428 .871 .843 r
F P
0 g
s
.65214 .74745 m .65195 .74828 L .65087 .7478 L .655 .618 .8 r
F
.64854 .76289 m .64338 .75048 L p .65195 .74828 L F P
0 g
s
.63804 .7511 m .6431 .75051 L p .63532 .75252 L .307 .785 .699 r
F P
0 g
s
.63841 .75172 m .63824 .75254 L .63725 .75202 L .654 .602 .784 r
F
.6354 .76571 m .63106 .75427 L p .63824 .75254 L F P
0 g
s
.62433 .75592 m .6269 .7553 L .62745 .75514 L 0 0 0 r
F
.61867 .75107 m .62845 .74739 L p .6269 .7553 L .653 .585 .766 r
F P
0 g
s
.6269 .7553 m .62584 .75556 L .61867 .75107 L .653 .585 .766 r
F
.61867 .75107 m .62083 .75742 L p .6174 .75826 L .653 .566 .745 r
F P
0 g
s
.61709 .75985 m .62656 .75584 L p .62447 .75592 L 0 0 0 r
F P
0 g
s
.62059 .75757 m .61709 .75985 L p .62447 .75592 L 0 0 0 r
F P
0 g
s
.61538 .76976 m .61247 .75999 L p .6153 .75871 L .653 .566 .745 r
F P
0 g
s
.61749 .75773 m .6174 .75826 L .6153 .75871 L .653 .566 .745 r
F
.61073 .75412 m .61867 .75107 L p .61749 .75773 L F P
0 g
s
.61519 .75864 m .61482 .75893 L .6153 .75871 L .008 0 0 r
F
.61429 .75806 m .61247 .75999 L p .61519 .75864 L F P
0 g
s
.61247 .75999 m .60944 .7632 L p .61519 .75864 L .008 0 0 r
F P
0 g
s
.61247 .75999 m .61429 .75806 L p .60972 .76066 L .14 0 0 r
F P
0 g
s
.61247 .75999 m .61073 .75412 L p .61749 .75773 L .653 .566 .745 r
F P
0 g
s
.60944 .7632 m .61709 .75985 L p .6153 .75871 L .008 0 0 r
F P
0 g
s
.61482 .75893 m .60944 .7632 L .6153 .75871 L .008 0 0 r
F
.61225 .76023 m .61247 .75999 L p .60972 .76066 L .14 0 0 r
F P
0 g
s
.61073 .75412 m .61247 .75999 L p .60972 .76066 L .653 .547 .721 r
F P
0 g
s
.60292 .76236 m .60411 .76222 L .60727 .75967 L .229 0 .162 r
F
.60585 .76202 m .60727 .75967 L p .60371 .76255 L F P
0 g
s
.60727 .75967 m .60187 .76081 L p .60244 .76265 L .229 0 .162 r
F P
0 g
s
.60727 .75967 m .60585 .76202 L p .60805 .76095 L .14 0 0 r
F P
0 g
s
.60585 .76202 m .60449 .7566 L p .60862 .76067 L .653 .547 .721 r
F P
0 g
s
.60957 .7616 m .60585 .76202 L .60862 .76067 L .653 .547 .721 r
F
.60811 .77106 m .60247 .77193 L p .60371 .76255 L .657 .527 .694 r
F P
0 g
s
.60585 .76202 m .60811 .77106 L p .60371 .76255 L .657 .527 .694 r
F P
0 g
s
.60347 .76596 m .60944 .7632 L p .60805 .76095 L .14 0 0 r
F P
0 g
s
.60585 .76202 m .60347 .76596 L p .60805 .76095 L .14 0 0 r
F P
0 g
s
.60944 .7632 m .61225 .76023 L p .60805 .76095 L .14 0 0 r
F P
0 g
s
.60449 .7566 m .61073 .75412 L p .60972 .76066 L .653 .547 .721 r
F P
0 g
s
.60972 .76066 m .60878 .76082 L .60449 .7566 L .653 .547 .721 r
F
.60244 .76265 m .60371 .76255 L .60411 .76222 L .229 0 .162 r
F
.60244 .76265 m .60411 .76222 L .60292 .76236 L F
.60563 .76238 m .60585 .76202 L p .60371 .76255 L F P
0 g
s
.60449 .7566 m .60585 .76202 L p .60371 .76255 L .657 .527 .694 r
F P
0 g
s
.6028 .76262 m .60244 .76265 L .60271 .7625 L .657 .527 .694 r
F
.60356 .76367 m .60244 .76265 L .6028 .76262 L F
.60082 .76357 m .60187 .76081 L p .59925 .76397 L .264 0 .294 r
F P
0 g
s
.60187 .76081 m .60253 .75411 L .59782 .75377 L p .545 .222 .371 r
F P
0 g
s
.59983 .75856 m .60449 .7566 L p .60356 .76367 L .657 .527 .694 r
F P
0 g
s
.60347 .76596 m .60563 .76238 L p .60244 .76265 L .229 0 .162 r
F P
0 g
s
.60082 .76357 m .59906 .76818 L p .60234 .76233 L .229 0 .162 r
F P
0 g
s
.60082 .76357 m .59983 .75856 L p .60271 .7625 L .657 .527 .694 r
F P
0 g
s
.59906 .76818 m .60347 .76596 L p .60244 .76265 L .229 0 .162 r
F P
0 g
s
.60203 .76289 m .59906 .76818 L .60244 .76265 L .229 0 .162 r
F
.6006 .76414 m .60082 .76357 L p .59925 .76397 L .264 0 .294 r
F P
0 g
s
.59983 .75856 m .60082 .76357 L p .59925 .76397 L .668 .511 .663 r
F P
0 g
s
.59831 .76348 m .59837 .76385 L .59878 .7635 L .264 0 .294 r
F
.59837 .76385 m .59909 .7655 L .59836 .76386 L .668 .511 .663 r
F
.59925 .76397 m .59909 .7655 L .59837 .76385 L F
.59836 .77236 m .59729 .76466 L p .59909 .7655 L F P
0 g
s
.59827 .76326 m .59799 .76414 L .59837 .76385 L .264 0 .294 r
F
.598 .76151 m .59729 .76466 L p .59827 .76326 L F P
0 g
s
.59729 .76466 m .59799 .76414 L .59827 .76326 L .264 0 .294 r
F
.59729 .76466 m .598 .76151 L p .59627 .76498 L .202 .003 .371 r
F P
0 g
s
.59729 .76466 m .59665 .76003 L p .59836 .76386 L .668 .511 .663 r
F P
0 g
s
.59909 .7655 m .59729 .76466 L .59836 .76386 L .668 .511 .663 r
F
.59729 .76466 m .59612 .76991 L p .59799 .76414 L .264 0 .294 r
F P
0 g
s
.59906 .76818 m .6006 .76414 L p .59837 .76385 L .264 0 .294 r
F P
0 g
s
.59934 .76313 m .59925 .76397 L .59837 .76385 L .668 .511 .663 r
F
.59665 .76003 m .59983 .75856 L p .59934 .76313 L F P
0 g
s
.59934 .76313 m .59836 .76386 L .59665 .76003 L .668 .511 .663 r
F
.59612 .76991 m .59906 .76818 L p .59837 .76385 L .264 0 .294 r
F P
0 g
s
.59799 .76414 m .59612 .76991 L .59837 .76385 L .264 0 .294 r
F
.59705 .76572 m .59729 .76466 L p .59627 .76498 L .202 .003 .371 r
F P
0 g
s
.59665 .76003 m .59729 .76466 L p .59627 .76498 L .7 .507 .624 r
F P
0 g
s
.59571 .76391 m .59575 .76448 L .59606 .76407 L .202 .003 .371 r
F
.59627 .76498 m .59571 .77238 L .59575 .76448 L .7 .507 .624 r
F
.59612 .76991 m .59705 .76572 L p .59575 .76448 L .202 .003 .371 r
F P
0 g
s
.59571 .77238 m .5952 .7653 L p .59575 .76448 L .7 .507 .624 r
F P
0 g
s
.59638 .76353 m .59627 .76498 L .59575 .76448 L .7 .507 .624 r
F
.5949 .76105 m .59665 .76003 L p .59638 .76353 L F P
0 g
s
.59566 .76313 m .59541 .76498 L .59575 .76448 L .202 .003 .371 r
F
.59557 .76178 m .5952 .7653 L p .59566 .76313 L F P
0 g
s
.5952 .7653 m .5946 .77117 L p .59566 .76313 L .202 .003 .371 r
F P
0 g
s
.5952 .7653 m .5949 .76105 L p .59638 .76353 L .7 .507 .624 r
F P
0 g
s
.5946 .77117 m .59612 .76991 L p .59575 .76448 L .202 .003 .371 r
F P
0 g
s
.59541 .76498 m .5946 .77117 L .59575 .76448 L .202 .003 .371 r
F
.59471 .76574 m .59488 .76685 L .59462 .76809 L .816 .569 .566 r
F
.5949 .76105 m .5952 .7653 L p .59471 .76574 L F P
0 g
s
.5946 .77117 m .59484 .76881 L p .59471 .76574 L 0 0 .125 r
F P
0 g
s
.59454 .76163 m .59457 .76587 L .59471 .76574 L 0 0 .125 r
F
.59457 .76587 m .5946 .77117 L .59471 .76574 L F
.59472 .76557 m .59471 .76574 L .59454 .76163 L .816 .569 .566 r
F
.59454 .76163 m .5949 .76105 L p .59472 .76557 L F P
0 g
s
.5949 .76105 m .59212 .75037 L p .59374 .75362 L .49 .371 .644 r
F P
0 g
s
.59266 .75192 m .59212 .75037 L p .59312 .75502 L .169 .133 .572 r
F P
0 g
s
.59212 .75037 m .58746 .74037 L p .58929 .74279 L .202 .241 .68 r
F P
0 g
s
.55851 .70346 m .56985 .71279 L .57097 .71783 L p .161 .377 .826 r
F P
0 g
s
.56985 .71279 m .55851 .70346 L .55705 .6972 L p .279 .435 .838 r
F P
0 g
s
.5412 .68083 m .52559 .67263 L .522 .66414 L p .348 .528 .891 r
F P
0 g
s
.50463 .65707 m .522 .66414 L .52559 .67263 L p .319 .537 .907 r
F P
0 g
s
.6003 .90068 m .61351 .8823 L .62688 .8883 L p .786 .754 .824 r
F P
0 g
s
.63857 .86804 m .62688 .8883 L .61351 .8823 L p .776 .733 .813 r
F P
0 g
s
.522 .66414 m .50463 .65707 L .49913 .64764 L p .365 .562 .912 r
F P
0 g
s
.60876 .75408 m .60793 .74907 L .60102 .748 L p .59 .169 .21 r
F P
0 g
s
.84746 .80153 m .84407 .8412 L .80437 .83859 L p .691 .713 .866 r
F P
0 g
s
.57097 .71783 m .57991 .72727 L .58104 .73105 L p 0 .24 .753 r
F P
0 g
s
.57991 .72727 m .57097 .71783 L .56985 .71279 L p .197 .354 .795 r
F P
0 g
s
.55991 .92695 m .5754 .91096 L .58507 .91822 L p .812 .796 .836 r
F P
0 g
s
.6003 .90068 m .58507 .91822 L .5754 .91096 L p .805 .775 .826 r
F P
0 g
s
.50872 .96902 m .52617 .95606 L .53111 .96438 L p .833 .866 .869 r
F P
0 g
s
.53111 .96438 m .5118 .97729 L .50872 .96902 L p .833 .866 .869 r
F P
0 g
s
.59896 1.21738 m .55966 1.21112 L .55314 1.19602 L p .405 .663 .965 r
F P
0 g
s
.51767 1.18677 m .55314 1.19602 L .55966 1.21112 L p .434 .656 .953 r
F P
0 g
s
.60102 .748 m .60253 .75411 L .60876 .75408 L p .59 .169 .21 r
F P
0 g
s
.60253 .75411 m .60102 .748 L .5956 .74663 L p .671 .284 .305 r
F P
0 g
s
.5956 .74663 m .59782 .75377 L .60253 .75411 L p .671 .284 .305 r
F P
0 g
s
.59782 .75377 m .5956 .74663 L .59158 .74492 L p .758 .384 .346 r
F P
0 g
s
.68997 .82985 m .68379 .85461 L .66426 .85078 L p .731 .698 .819 r
F P
0 g
s
.68379 .85461 m .68997 .82985 L .71296 .83186 L p .724 .703 .831 r
F P
0 g
s
.79845 .72901 m .80368 .7448 L .76893 .74653 L p .557 .847 .998 r
F P
0 g
s
.58746 .74037 m .58104 .73105 L .57991 .72727 L p .02 .204 .713 r
F P
0 g
s
.5754 .91096 m .58947 .89416 L .6003 .90068 L p .805 .775 .826 r
F P
0 g
s
.61351 .8823 m .6003 .90068 L .58947 .89416 L p .796 .754 .815 r
F P
0 g
s
.8071 .80265 m .80437 .83859 L .76967 .8362 L p .695 .707 .857 r
F P
0 g
s
.80437 .83859 m .8071 .80265 L .84746 .80153 L p .691 .713 .866 r
F P
0 g
s
.49145 .98085 m .50872 .96902 L .5118 .97729 L p .836 .896 .882 r
F P
0 g
s
.5118 .97729 m .49257 .98887 L .49145 .98085 L p .836 .896 .882 r
F P
0 g
s
.40691 .60635 m .42886 .60598 L .44159 .61794 L p .408 .656 .96 r
F P
0 g
s
.42886 .60598 m .40691 .60635 L .3897 .59427 L p .445 .673 .96 r
F P
0 g
s
.45617 1.00804 m .47388 .99911 L .47226 1.0076 L p .79 .957 .922 r
F P
0 g
s
.47226 1.0076 m .45226 1.01588 L .45617 1.00804 L p .79 .957 .922 r
F P
0 g
s
.83792 .72299 m .84363 .7427 L .80368 .7448 L p .579 .839 .994 r
F P
0 g
s
.80368 .7448 m .79845 .72901 L .83792 .72299 L p .579 .839 .994 r
F P
0 g
s
.61351 .8823 m .62434 .86326 L .63857 .86804 L p .776 .733 .813 r
F P
0 g
s
.64727 .84718 m .63857 .86804 L .62434 .86326 L p .763 .711 .804 r
F P
0 g
s
.63857 .86804 m .64727 .84718 L .66426 .85078 L p .754 .714 .815 r
F P
0 g
s
.56985 .71279 m .5799 .72298 L .57991 .72727 L p .197 .354 .795 r
F P
0 g
s
.5799 .72298 m .56985 .71279 L .56967 .70714 L p .327 .424 .808 r
F P
0 g
s
.55705 .6972 m .56967 .70714 L .56985 .71279 L p .279 .435 .838 r
F P
0 g
s
.56967 .70714 m .55705 .6972 L .55629 .69021 L p .359 .478 .844 r
F P
0 g
s
.5412 .68083 m .55629 .69021 L .55705 .6972 L p .323 .488 .868 r
F P
0 g
s
.77196 .80352 m .76967 .8362 L .73937 .83397 L p .699 .701 .848 r
F P
0 g
s
.76967 .8362 m .77196 .80352 L .8071 .80265 L p .695 .707 .857 r
F P
0 g
s
.48237 1.17496 m .448 1.16059 L .45398 1.14766 L p .47 .626 .92 r
F P
0 g
s
.448 1.16059 m .41529 1.14368 L .42514 1.13156 L p .502 .623 .904 r
F P
0 g
s
.42514 1.13156 m .45398 1.14766 L .448 1.16059 L p .502 .623 .904 r
F P
0 g
s
.58947 .89416 m .60176 .8767 L .61351 .8823 L p .796 .754 .815 r
F P
0 g
s
.62434 .86326 m .61351 .8823 L .60176 .8767 L p .786 .733 .804 r
F P
0 g
s
.57991 .72727 m .58729 .73745 L .58746 .74037 L p .02 .204 .713 r
F P
0 g
s
.58729 .73745 m .57991 .72727 L .5799 .72298 L p .276 .349 .758 r
F P
0 g
s
.55629 .69021 m .5412 .68083 L .53935 .67256 L p .38 .52 .872 r
F P
0 g
s
.522 .66414 m .53935 .67256 L .5412 .68083 L p .348 .528 .891 r
F P
0 g
s
.67002 .82789 m .66426 .85078 L .64727 .84718 L p .739 .693 .807 r
F P
0 g
s
.66426 .85078 m .67002 .82789 L .68997 .82985 L p .731 .698 .819 r
F P
0 g
s
.33818 1.11354 m .31112 1.08788 L .33415 1.07881 L p .596 .645 .87 r
F P
0 g
s
.33415 1.07881 m .3577 1.10263 L .33818 1.11354 L p .596 .645 .87 r
F P
0 g
s
.51767 1.18677 m .48237 1.17496 L .48437 1.16153 L p .437 .63 .936 r
F P
0 g
s
.45398 1.14766 m .48437 1.16153 L .48237 1.17496 L p .47 .626 .92 r
F P
0 g
s
.26767 .57195 m .2911 .55822 L .32071 .57331 L p .521 .734 .971 r
F P
0 g
s
.2911 .55822 m .26767 .57195 L .23063 .55832 L p .543 .739 .966 r
F P
0 g
s
.44159 .61794 m .46341 .62058 L .47236 .63199 L p .391 .624 .946 r
F P
0 g
s
.46341 .62058 m .44159 .61794 L .42886 .60598 L p .428 .644 .948 r
F P
0 g
s
.41529 1.14368 m .38496 1.12432 L .3985 1.11331 L p .532 .623 .887 r
F P
0 g
s
.3985 1.11331 m .42514 1.13156 L .41529 1.14368 L p .532 .623 .887 r
F P
0 g
s
.53935 .67256 m .522 .66414 L .51846 .65466 L p .394 .555 .895 r
F P
0 g
s
.49913 .64764 m .51846 .65466 L .522 .66414 L p .365 .562 .912 r
F P
0 g
s
.47476 .99153 m .49145 .98085 L .49257 .98887 L p .834 .931 .894 r
F P
0 g
s
.49257 .98887 m .47388 .99911 L .47476 .99153 L p .834 .931 .894 r
F P
0 g
s
.59896 1.21738 m .63674 1.22093 L .6537 1.23631 L p .412 .69 .976 r
F P
0 g
s
.53708 .93453 m .55233 .91975 L .55991 .92695 L p .829 .816 .837 r
F P
0 g
s
.55991 .92695 m .54337 .94202 L .53708 .93453 L p .829 .816 .837 r
F P
0 g
s
.5754 .91096 m .55991 .92695 L .55233 .91975 L p .822 .796 .827 r
F P
0 g
s
.34639 .58653 m .36996 .58057 L .3897 .59427 L p .467 .701 .97 r
F P
0 g
s
.36996 .58057 m .34639 .58653 L .32071 .57331 L p .497 .712 .967 r
F P
0 g
s
.7414 .80416 m .73937 .83397 L .71296 .83186 L p .704 .694 .838 r
F P
0 g
s
.73937 .83397 m .7414 .80416 L .77196 .80352 L p .699 .701 .848 r
F P
0 g
s
.52134 .94847 m .53708 .93453 L .54337 .94202 L p .837 .838 .847 r
F P
0 g
s
.54337 .94202 m .52617 .95606 L .52134 .94847 L p .837 .838 .847 r
F P
0 g
s
.55233 .91975 m .5667 .90422 L .5754 .91096 L p .822 .796 .827 r
F P
0 g
s
.58947 .89416 m .5754 .91096 L .5667 .90422 L p .815 .776 .817 r
F P
0 g
s
.51846 .65466 m .49913 .64764 L .49324 .63709 L p .405 .586 .915 r
F P
0 g
s
.47236 .63199 m .49324 .63709 L .49913 .64764 L p .378 .594 .93 r
F P
0 g
s
.49324 .63709 m .47236 .63199 L .46341 .62058 L p .415 .615 .933 r
F P
0 g
s
.60176 .8767 m .61195 .85873 L .62434 .86326 L p .786 .733 .804 r
F P
0 g
s
.63254 .84375 m .62434 .86326 L .61195 .85873 L p .774 .711 .792 r
F P
0 g
s
.62434 .86326 m .63254 .84375 L .64727 .84718 L p .763 .711 .804 r
F P
0 g
s
.5667 .90422 m .57984 .88807 L .58947 .89416 L p .815 .776 .817 r
F P
0 g
s
.60176 .8767 m .58947 .89416 L .57984 .88807 L p .807 .756 .806 r
F P
0 g
s
.50547 .96151 m .52134 .94847 L .52617 .95606 L p .845 .864 .856 r
F P
0 g
s
.52617 .95606 m .50872 .96902 L .50547 .96151 L p .845 .864 .856 r
F P
0 g
s
.71485 .80459 m .71296 .83186 L .68997 .82985 L p .71 .687 .827 r
F P
0 g
s
.71296 .83186 m .71485 .80459 L .7414 .80416 L p .704 .694 .838 r
F P
0 g
s
.65275 .82596 m .64727 .84718 L .63254 .84375 L p .748 .689 .795 r
F P
0 g
s
.64727 .84718 m .65275 .82596 L .67002 .82789 L p .739 .693 .807 r
F P
0 g
s
.5799 .72298 m .58839 .73402 L .58729 .73745 L p .276 .349 .758 r
F P
0 g
s
.58839 .73402 m .5799 .72298 L .58101 .71809 L p .396 .425 .773 r
F P
0 g
s
.56967 .70714 m .58101 .71809 L .5799 .72298 L p .327 .424 .808 r
F P
0 g
s
.58101 .71809 m .56967 .70714 L .57044 .70078 L p .405 .472 .816 r
F P
0 g
s
.55629 .69021 m .57044 .70078 L .56967 .70714 L p .359 .478 .844 r
F P
0 g
s
.55314 1.19602 m .51767 1.18677 L .51565 1.17315 L p .403 .636 .95 r
F P
0 g
s
.48437 1.16153 m .51565 1.17315 L .51767 1.18677 L p .437 .63 .936 r
F P
0 g
s
.58729 .73745 m .59293 .74838 L .59212 .75037 L p .202 .241 .68 r
F P
0 g
s
.59293 .74838 m .58729 .73745 L .58839 .73402 L p .403 .377 .715 r
F P
0 g
s
.57984 .88807 m .59144 .87141 L .60176 .8767 L p .807 .756 .806 r
F P
0 g
s
.61195 .85873 m .60176 .8767 L .59144 .87141 L p .798 .735 .794 r
F P
0 g
s
.63674 1.22093 m .59896 1.21738 L .58802 1.20278 L p .375 .671 .973 r
F P
0 g
s
.55314 1.19602 m .58802 1.20278 L .59896 1.21738 L p .405 .663 .965 r
F P
0 g
s
.43986 1.0157 m .45617 1.00804 L .45226 1.01588 L p .735 .976 .922 r
F P
0 g
s
.38496 1.12432 m .3577 1.10263 L .37466 1.09302 L p .561 .624 .872 r
F P
0 g
s
.37466 1.09302 m .3985 1.11331 L .38496 1.12432 L p .561 .624 .872 r
F P
0 g
s
.69184 .80482 m .68997 .82985 L .67002 .82789 L p .716 .68 .814 r
F P
0 g
s
.68997 .82985 m .69184 .80482 L .71485 .80459 L p .71 .687 .827 r
F P
0 g
s
.57044 .70078 m .55629 .69021 L .55623 .68238 L p .416 .513 .849 r
F P
0 g
s
.53935 .67256 m .55623 .68238 L .55629 .69021 L p .38 .52 .872 r
F P
0 g
s
.48986 .97361 m .50547 .96151 L .50872 .96902 L p .852 .894 .866 r
F P
0 g
s
.50872 .96902 m .49145 .98085 L .48986 .97361 L p .852 .894 .866 r
F P
0 g
s
.45904 1.00108 m .47476 .99153 L .47388 .99911 L p .814 .967 .903 r
F P
0 g
s
.47388 .99911 m .45617 1.00804 L .45904 1.00108 L p .814 .967 .903 r
F P
0 g
s
.61195 .85873 m .6198 .84044 L .63254 .84375 L p .774 .711 .792 r
F P
0 g
s
.63786 .82401 m .63254 .84375 L .6198 .84044 L p .759 .687 .782 r
F P
0 g
s
.63254 .84375 m .63786 .82401 L .65275 .82596 L p .748 .689 .795 r
F P
0 g
s
.59212 .75037 m .5949 .76105 L .59454 .76163 L p .169 .133 .572 r
F P
0 g
s
.67195 .80483 m .67002 .82789 L .65275 .82596 L p .722 .673 .801 r
F P
0 g
s
.67002 .82789 m .67195 .80483 L .69184 .80482 L p .716 .68 .814 r
F P
0 g
s
.59144 .87141 m .60119 .85439 L .61195 .85873 L p .798 .735 .794 r
F P
0 g
s
.6198 .84044 m .61195 .85873 L .60119 .85439 L p .786 .712 .782 r
F P
0 g
s
.55623 .68238 m .53935 .67256 L .53788 .66327 L p .424 .547 .876 r
F P
0 g
s
.51846 .65466 m .53788 .66327 L .53935 .67256 L p .394 .555 .895 r
F P
0 g
s
.58839 .73402 m .59509 .7459 L .59293 .74838 L p .403 .377 .715 r
F P
0 g
s
.59509 .7459 m .58839 .73402 L .59076 .73003 L p .484 .443 .736 r
F P
0 g
s
.58101 .71809 m .59076 .73003 L .58839 .73402 L p .396 .425 .773 r
F P
0 g
s
.3897 .59427 m .41437 .59244 L .42886 .60598 L p .445 .673 .96 r
F P
0 g
s
.41437 .59244 m .3897 .59427 L .36996 .58057 L p .476 .687 .959 r
F P
0 g
s
.59076 .73003 m .58101 .71809 L .58328 .71252 L p .462 .474 .785 r
F P
0 g
s
.57044 .70078 m .58328 .71252 L .58101 .71809 L p .405 .472 .816 r
F P
0 g
s
.53111 .92758 m .54531 .91302 L .55233 .91975 L p .838 .815 .828 r
F P
0 g
s
.55233 .91975 m .53708 .93453 L .53111 .92758 L p .838 .815 .828 r
F P
0 g
s
.5667 .90422 m .55233 .91975 L .54531 .91302 L p .831 .796 .819 r
F P
0 g
s
.54531 .91302 m .55881 .89789 L .5667 .90422 L p .831 .796 .819 r
F P
0 g
s
.57984 .88807 m .5667 .90422 L .55881 .89789 L p .824 .779 .809 r
F P
0 g
s
.55881 .89789 m .57127 .88228 L .57984 .88807 L p .824 .779 .809 r
F P
0 g
s
.59144 .87141 m .57984 .88807 L .57127 .88228 L p .818 .76 .798 r
F P
0 g
s
.59293 .74838 m .59665 .76003 L .5949 .76105 L p .49 .371 .644 r
F P
0 g
s
.59665 .76003 m .59293 .74838 L .59509 .7459 L p .549 .437 .679 r
F P
0 g
s
.65482 .80465 m .65275 .82596 L .63786 .82401 L p .73 .666 .787 r
F P
0 g
s
.65275 .82596 m .65482 .80465 L .67195 .80483 L p .722 .673 .801 r
F P
0 g
s
.51655 .94149 m .53111 .92758 L .53708 .93453 L p .846 .835 .835 r
F P
0 g
s
.53708 .93453 m .52134 .94847 L .51655 .94149 L p .846 .835 .835 r
F P
0 g
s
.47488 .98473 m .48986 .97361 L .49145 .98085 L p .855 .93 .876 r
F P
0 g
s
.49145 .98085 m .47476 .99153 L .47488 .98473 L p .855 .93 .876 r
F P
0 g
s
.53788 .66327 m .51846 .65466 L .51491 .64399 L p .431 .578 .899 r
F P
0 g
s
.49324 .63709 m .51491 .64399 L .51846 .65466 L p .405 .586 .915 r
F P
0 g
s
.58328 .71252 m .57044 .70078 L .57217 .69359 L p .457 .509 .824 r
F P
0 g
s
.55623 .68238 m .57217 .69359 L .57044 .70078 L p .416 .513 .849 r
F P
0 g
s
.60119 .85439 m .60885 .83717 L .6198 .84044 L p .786 .712 .782 r
F P
0 g
s
.62509 .82201 m .6198 .84044 L .60885 .83717 L p .772 .686 .769 r
F P
0 g
s
.6198 .84044 m .62509 .82201 L .63786 .82401 L p .759 .687 .782 r
F P
0 g
s
.57127 .88228 m .58239 .86633 L .59144 .87141 L p .818 .76 .798 r
F P
0 g
s
.60119 .85439 m .59144 .87141 L .58239 .86633 L p .81 .739 .786 r
F P
0 g
s
.50199 .95465 m .51655 .94149 L .52134 .94847 L p .855 .858 .843 r
F P
0 g
s
.52134 .94847 m .50547 .96151 L .50199 .95465 L p .855 .858 .843 r
F P
0 g
s
.64015 .80426 m .63786 .82401 L .62509 .82201 L p .74 .661 .772 r
F P
0 g
s
.63786 .82401 m .64015 .80426 L .65482 .80465 L p .73 .666 .787 r
F P
0 g
s
.59242 .78299 m .59446 .77199 L .59571 .77238 L p .894 .677 .602 r
F P
0 g
s
.59165 .78122 m .5946 .77117 L .59446 .77199 L p 1 .818 .505 r
F P
0 g
s
.59446 .77199 m .59242 .78299 L .59165 .78122 L p 1 .818 .505 r
F P
0 g
s
.5946 .77117 m .59227 .77911 L p .59222 .77901 L .718 .741 .228 r
F P
0 g
s
.59227 .77911 m .59165 .78122 L .59222 .77901 L p .718 .741 .228 r
F P
0 g
s
.58722 .78523 m .59215 .77887 L p .59222 .77901 L .885 .939 .57 r
F P
0 g
s
.59222 .77901 m .59485 .77287 L p .5946 .77117 L .718 .741 .228 r
F P
0 g
s
.59612 .76991 m .59283 .77759 L p .59413 .7763 L 0 0 0 r
F P
0 g
s
.59283 .77759 m .59222 .77901 L .59413 .7763 L p 0 0 0 r
F P
0 g
s
.59571 .77238 m .59453 .78435 L .59242 .78299 L p .894 .677 .602 r
F P
0 g
s
.59453 .78435 m .59571 .77238 L .59836 .77236 L p .798 .604 .639 r
F P
0 g
s
.59413 .7763 m .58722 .78523 L .58931 .78105 L p .77 .932 .575 r
F P
0 g
s
.58931 .78105 m .59581 .77465 L p .59413 .7763 L .77 .932 .575 r
F P
0 g
s
.59581 .77465 m .59743 .77306 L .59413 .7763 L p .77 .932 .575 r
F P
0 g
s
.59215 .77887 m .59413 .7763 L .59222 .77901 L p .885 .939 .57 r
F P
0 g
s
.59485 .77287 m .59612 .76991 L .5946 .77117 L p .718 .741 .228 r
F P
0 g
s
.59454 .76163 m .59447 .77034 L p .5946 .77117 L 0 0 .125 r
F P
0 g
s
.59447 .77034 m .59446 .77199 L .5946 .77117 L p 0 0 .125 r
F P
0 g
s
.59509 .7459 m .59983 .75856 L .59665 .76003 L p .549 .437 .679 r
F P
0 g
s
.59983 .75856 m .59509 .7459 L .59866 .74289 L p .576 .48 .708 r
F P
0 g
s
.59076 .73003 m .59866 .74289 L .59509 .7459 L p .484 .443 .736 r
F P
0 g
s
.51491 .64399 m .49324 .63709 L .48685 .62519 L p .439 .606 .918 r
F P
0 g
s
.46341 .62058 m .48685 .62519 L .49324 .63709 L p .415 .615 .933 r
F P
0 g
s
.42886 .60598 m .45339 .60769 L .46341 .62058 L p .428 .644 .948 r
F P
0 g
s
.45339 .60769 m .42886 .60598 L .41437 .59244 L p .46 .661 .948 r
F P
0 g
s
.58239 .86633 m .59188 .85016 L .60119 .85439 L p .81 .739 .786 r
F P
0 g
s
.60885 .83717 m .60119 .85439 L .59188 .85016 L p .801 .716 .772 r
F P
0 g
s
.59866 .74289 m .59076 .73003 L .59447 .72538 L p .527 .488 .756 r
F P
0 g
s
.58328 .71252 m .59447 .72538 L .59076 .73003 L p .462 .474 .785 r
F P
0 g
s
.58802 1.20278 m .55314 1.19602 L .54713 1.18252 L p .369 .642 .961 r
F P
0 g
s
.51565 1.17315 m .54713 1.18252 L .55314 1.19602 L p .403 .636 .95 r
F P
0 g
s
.3577 1.10263 m .33415 1.07881 L .3542 1.07087 L p .589 .629 .859 r
F P
0 g
s
.3542 1.07087 m .37466 1.09302 L .3577 1.10263 L p .589 .629 .859 r
F P
0 g
s
.48685 .62519 m .46341 .62058 L .45339 .60769 L p .448 .634 .935 r
F P
0 g
s
.23063 .55832 m .2569 .54093 L .2911 .55822 L p .543 .739 .966 r
F P
0 g
s
.57217 .69359 m .55623 .68238 L .55687 .67353 L p .457 .542 .855 r
F P
0 g
s
.53788 .66327 m .55687 .67353 L .55623 .68238 L p .424 .547 .876 r
F P
0 g
s
.32071 .57331 m .34725 .56495 L .36996 .58057 L p .497 .712 .967 r
F P
0 g
s
.34725 .56495 m .32071 .57331 L .2911 .55822 L p .522 .72 .963 r
F P
0 g
s
.60885 .83717 m .61421 .81993 L .62509 .82201 L p .772 .686 .769 r
F P
0 g
s
.62766 .80366 m .62509 .82201 L .61421 .81993 L p .752 .658 .757 r
F P
0 g
s
.62509 .82201 m .62766 .80366 L .64015 .80426 L p .74 .661 .772 r
F P
0 g
s
.59188 .85016 m .5995 .83391 L .60885 .83717 L p .801 .716 .772 r
F P
0 g
s
.61421 .81993 m .60885 .83717 L .5995 .83391 L p .787 .69 .757 r
F P
0 g
s
.48778 .96704 m .50199 .95465 L .50547 .96151 L p .865 .887 .849 r
F P
0 g
s
.50547 .96151 m .48986 .97361 L .48778 .96704 L p .865 .887 .849 r
F P
0 g
s
.44468 1.00953 m .45904 1.00108 L .45617 1.00804 L p .754 .988 .894 r
F P
0 g
s
.45617 1.00804 m .43986 1.0157 L .44468 1.00953 L p .754 .988 .894 r
F P
0 g
s
.59447 .72538 m .58328 .71252 L .58676 .70616 L p .504 .512 .798 r
F P
0 g
s
.57217 .69359 m .58676 .70616 L .58328 .71252 L p .457 .509 .824 r
F P
0 g
s
.48437 1.16153 m .45398 1.14766 L .45895 1.13616 L p .444 .604 .914 r
F P
0 g
s
.45398 1.14766 m .42514 1.13156 L .43352 1.12081 L p .481 .602 .896 r
F P
0 g
s
.43352 1.12081 m .45895 1.13616 L .45398 1.14766 L p .481 .602 .896 r
F P
0 g
s
.59866 .74289 m .60449 .7566 L .59983 .75856 L p .576 .48 .708 r
F P
0 g
s
.60449 .7566 m .59866 .74289 L .6037 .73929 L p .593 .513 .733 r
F P
0 g
s
.59447 .72538 m .6037 .73929 L .59866 .74289 L p .527 .488 .756 r
F P
0 g
s
.42514 1.13156 m .3985 1.11331 L .41013 1.10358 L p .515 .602 .878 r
F P
0 g
s
.41013 1.10358 m .43352 1.12081 L .42514 1.13156 L p .515 .602 .878 r
F P
0 g
s
.4609 .99488 m .47488 .98473 L .47476 .99153 L p .842 .97 .881 r
F P
0 g
s
.47476 .99153 m .45904 1.00108 L .4609 .99488 L p .842 .97 .881 r
F P
0 g
s
.66997 .78192 m .67195 .80483 L .65482 .80465 L p .703 .653 .798 r
F P
0 g
s
.67195 .80483 m .66997 .78192 L .68929 .77987 L p .698 .663 .812 r
F P
0 g
s
.68929 .77987 m .69184 .80482 L .67195 .80483 L p .698 .663 .812 r
F P
0 g
s
.69184 .80482 m .68929 .77987 L .71173 .77735 L p .693 .672 .825 r
F P
0 g
s
.71173 .77735 m .71485 .80459 L .69184 .80482 L p .693 .672 .825 r
F P
0 g
s
.65342 .78353 m .65482 .80465 L .64015 .80426 L p .709 .644 .782 r
F P
0 g
s
.65482 .80465 m .65342 .78353 L .66997 .78192 L p .703 .653 .798 r
F P
0 g
s
.71485 .80459 m .71173 .77735 L .73774 .77431 L p .69 .681 .836 r
F P
0 g
s
.73774 .77431 m .7414 .80416 L .71485 .80459 L p .69 .681 .836 r
F P
0 g
s
.53874 .90667 m .5516 .89185 L .55881 .89789 L p .838 .797 .812 r
F P
0 g
s
.55881 .89789 m .54531 .91302 L .53874 .90667 L p .838 .797 .812 r
F P
0 g
s
.57127 .88228 m .55881 .89789 L .5516 .89185 L p .833 .782 .803 r
F P
0 g
s
.5516 .89185 m .56361 .87672 L .57127 .88228 L p .833 .782 .803 r
F P
0 g
s
.58239 .86633 m .57127 .88228 L .56361 .87672 L p .828 .765 .792 r
F P
0 g
s
.5995 .83391 m .60505 .81773 L .61421 .81993 L p .787 .69 .757 r
F P
0 g
s
.61714 .80283 m .61421 .81993 L .60505 .81773 L p .768 .659 .742 r
F P
0 g
s
.61421 .81993 m .61714 .80283 L .62766 .80366 L p .752 .658 .757 r
F P
0 g
s
.63933 .78475 m .64015 .80426 L .62766 .80366 L p .716 .635 .766 r
F P
0 g
s
.64015 .80426 m .63933 .78475 L .65342 .78353 L p .709 .644 .782 r
F P
0 g
s
.7414 .80416 m .73774 .77431 L .76779 .77069 L p .686 .689 .847 r
F P
0 g
s
.76779 .77069 m .77196 .80352 L .7414 .80416 L p .686 .689 .847 r
F P
0 g
s
.52533 .92108 m .53874 .90667 L .54531 .91302 L p .844 .812 .819 r
F P
0 g
s
.54531 .91302 m .53111 .92758 L .52533 .92108 L p .844 .812 .819 r
F P
0 g
s
.56361 .87672 m .57445 .86138 L .58239 .86633 L p .828 .765 .792 r
F P
0 g
s
.59188 .85016 m .58239 .86633 L .57445 .86138 L p .823 .747 .779 r
F P
0 g
s
.62744 .78558 m .62766 .80366 L .61714 .80283 L p .726 .628 .748 r
F P
0 g
s
.62766 .80366 m .62744 .78558 L .63933 .78475 L p .716 .635 .766 r
F P
0 g
s
.51565 1.17315 m .48437 1.16153 L .48583 1.14955 L p .407 .608 .931 r
F P
0 g
s
.45895 1.13616 m .48583 1.14955 L .48437 1.16153 L p .444 .604 .914 r
F P
0 g
s
.77196 .80352 m .76779 .77069 L .80247 .76642 L p .683 .697 .856 r
F P
0 g
s
.80247 .76642 m .8071 .80265 L .77196 .80352 L p .683 .697 .856 r
F P
0 g
s
.59836 .77236 m .59802 .78532 L .59453 .78435 L p .798 .604 .639 r
F P
0 g
s
.59802 .78532 m .59836 .77236 L .60247 .77193 L p .746 .58 .669 r
F P
0 g
s
.57445 .86138 m .58385 .84596 L .59188 .85016 L p .823 .747 .779 r
F P
0 g
s
.5995 .83391 m .59188 .85016 L .58385 .84596 L p .817 .725 .764 r
F P
0 g
s
.55687 .67353 m .53788 .66327 L .53678 .65279 L p .459 .571 .88 r
F P
0 g
s
.51491 .64399 m .53678 .65279 L .53788 .66327 L p .431 .578 .899 r
F P
0 g
s
.6037 .73929 m .61073 .75412 L .60449 .7566 L p .593 .513 .733 r
F P
0 g
s
.6037 .73929 m .59447 .72538 L .59959 .72 L p .555 .522 .774 r
F P
0 g
s
.58676 .70616 m .59959 .72 L .59447 .72538 L p .504 .512 .798 r
F P
0 g
s
.60247 .77193 m .60295 .78592 L .59802 .78532 L p .746 .58 .669 r
F P
0 g
s
.60295 .78592 m .60247 .77193 L .60811 .77106 L p .719 .578 .696 r
F P
0 g
s
.51171 .93499 m .52533 .92108 L .53111 .92758 L p .852 .829 .824 r
F P
0 g
s
.53111 .92758 m .51655 .94149 L .51171 .93499 L p .852 .829 .824 r
F P
0 g
s
.60505 .81773 m .60839 .80176 L .61714 .80283 L p .768 .659 .742 r
F P
0 g
s
.61753 .78605 m .61714 .80283 L .60839 .80176 L p .741 .623 .729 r
F P
0 g
s
.61714 .80283 m .61753 .78605 L .62744 .78558 L p .726 .628 .748 r
F P
0 g
s
.58385 .84596 m .59158 .83058 L .5995 .83391 L p .817 .725 .764 r
F P
0 g
s
.60505 .81773 m .5995 .83391 L .59158 .83058 L p .806 .698 .746 r
F P
0 g
s
.8071 .80265 m .80247 .76642 L .84245 .76142 L p .68 .704 .865 r
F P
0 g
s
.84245 .76142 m .84746 .80153 L .8071 .80265 L p .68 .704 .865 r
F P
0 g
s
.58676 .70616 m .57217 .69359 L .57492 .68542 L p .493 .539 .832 r
F P
0 g
s
.55687 .67353 m .57492 .68542 L .57217 .69359 L p .457 .542 .855 r
F P
0 g
s
.47427 .97861 m .48778 .96704 L .48986 .97361 L p .874 .922 .855 r
F P
0 g
s
.48986 .97361 m .47488 .98473 L .47427 .97861 L p .874 .922 .855 r
F P
0 g
s
.60811 .77106 m .60942 .78616 L .60295 .78592 L p .719 .578 .696 r
F P
0 g
s
.60942 .78616 m .60811 .77106 L .61538 .76976 L p .703 .585 .721 r
F P
0 g
s
.59158 .83058 m .59743 .81536 L .60505 .81773 L p .806 .698 .746 r
F P
0 g
s
.60839 .80176 m .60505 .81773 L .59743 .81536 L p .789 .665 .727 r
F P
0 g
s
.3985 1.11331 m .37466 1.09302 L .3893 1.08457 L p .549 .605 .861 r
F P
0 g
s
.3893 1.08457 m .41013 1.10358 L .3985 1.11331 L p .549 .605 .861 r
F P
0 g
s
.59743 .81536 m .60126 .80043 L .60839 .80176 L p .789 .665 .727 r
F P
0 g
s
.60942 .78616 m .60839 .80176 L .60126 .80043 L p .761 .625 .709 r
F P
0 g
s
.60839 .80176 m .60942 .78616 L .61753 .78605 L p .741 .623 .729 r
F P
0 g
s
.60126 .80043 m .60295 .78592 L .60942 .78616 L p .761 .625 .709 r
F P
0 g
s
.61538 .76976 m .61753 .78605 L .60942 .78616 L p .703 .585 .721 r
F P
0 g
s
.61753 .78605 m .61538 .76976 L .62442 .76798 L p .693 .596 .743 r
F P
0 g
s
.62442 .76798 m .62744 .78558 L .61753 .78605 L p .693 .596 .743 r
F P
0 g
s
.61073 .75412 m .6037 .73929 L .61032 .73502 L p .606 .541 .755 r
F P
0 g
s
.59959 .72 m .61032 .73502 L .6037 .73929 L p .555 .522 .774 r
F P
0 g
s
.59562 .79882 m .59802 .78532 L .60295 .78592 L p .792 .637 .689 r
F P
0 g
s
.60295 .78592 m .60126 .80043 L .59562 .79882 L p .792 .637 .689 r
F P
0 g
s
.49821 .94833 m .51171 .93499 L .51655 .94149 L p .862 .849 .829 r
F P
0 g
s
.51655 .94149 m .50199 .95465 L .49821 .94833 L p .862 .849 .829 r
F P
0 g
s
.62744 .78558 m .62442 .76798 L .6354 .76571 L p .687 .609 .763 r
F P
0 g
s
.6354 .76571 m .63933 .78475 L .62744 .78558 L p .687 .609 .763 r
F P
0 g
s
.59413 .7763 m .59906 .76818 L .59612 .76991 L p 0 0 0 r
F P
0 g
s
.59138 .7969 m .59453 .78435 L .59802 .78532 L p .838 .667 .671 r
F P
0 g
s
.59802 .78532 m .59562 .79882 L .59138 .7969 L p .838 .667 .671 r
F P
0 g
s
.61032 .73502 m .61867 .75107 L .61073 .75412 L p .606 .541 .755 r
F P
0 g
s
.59123 .81279 m .59562 .79882 L .60126 .80043 L p .816 .681 .714 r
F P
0 g
s
.60126 .80043 m .59743 .81536 L .59123 .81279 L p .816 .681 .714 r
F P
0 g
s
.63933 .78475 m .6354 .76571 L .64854 .76289 L p .683 .622 .781 r
F P
0 g
s
.64854 .76289 m .65342 .78353 L .63933 .78475 L p .683 .622 .781 r
F P
0 g
s
.58802 1.20278 m .62155 1.20716 L .63674 1.22093 L p .375 .671 .973 r
F P
0 g
s
.58845 .79462 m .59242 .78299 L .59453 .78435 L p .902 .727 .655 r
F P
0 g
s
.59453 .78435 m .59138 .7969 L .58845 .79462 L p .902 .727 .655 r
F P
0 g
s
.53678 .65279 m .51491 .64399 L .51128 .63193 L p .463 .599 .902 r
F P
0 g
s
.48685 .62519 m .51128 .63193 L .51491 .64399 L p .439 .606 .918 r
F P
0 g
s
.58497 .82712 m .59123 .81279 L .59743 .81536 L p .829 .713 .737 r
F P
0 g
s
.59743 .81536 m .59158 .83058 L .58497 .82712 L p .829 .713 .737 r
F P
0 g
s
.59959 .72 m .58676 .70616 L .59151 .69887 L p .533 .542 .81 r
F P
0 g
s
.57492 .68542 m .59151 .69887 L .58676 .70616 L p .493 .539 .832 r
F P
0 g
s
.57699 .84172 m .58497 .82712 L .59158 .83058 L p .835 .738 .758 r
F P
0 g
s
.59158 .83058 m .58385 .84596 L .57699 .84172 L p .835 .738 .758 r
F P
0 g
s
.59743 .77306 m .60347 .76596 L .59906 .76818 L p 0 0 0 r
F P
0 g
s
.59906 .76818 m .59472 .77533 L p .59743 .77306 L 0 0 0 r
F P
0 g
s
.60347 .76596 m .59799 .7724 L p .60219 .76921 L 0 0 0 r
F P
0 g
s
.59799 .7724 m .59743 .77306 L .60219 .76921 L p 0 0 0 r
F P
0 g
s
.60219 .76921 m .60944 .7632 L .60347 .76596 L p 0 0 0 r
F P
0 g
s
.60944 .7632 m .60271 .76878 L p .60849 .76469 L 0 0 0 r
F P
0 g
s
.60271 .76878 m .60219 .76921 L .60849 .76469 L p 0 0 0 r
F P
0 g
s
.60849 .76469 m .61709 .75985 L .60944 .7632 L p 0 0 0 r
F P
0 g
s
.60373 .76419 m .61539 .7598 L p .60849 .76469 L .688 .977 .807 r
F P
0 g
s
.61539 .7598 m .61647 .7594 L .60849 .76469 L p .688 .977 .807 r
F P
0 g
s
.59748 .77063 m .60727 .76535 L p .60219 .76921 L .686 .96 .722 r
F P
0 g
s
.60727 .76535 m .60849 .76469 L .60219 .76921 L p .686 .96 .722 r
F P
0 g
s
.5927 .77621 m .6008 .77024 L p .59743 .77306 L .705 .939 .635 r
F P
0 g
s
.6008 .77024 m .60219 .76921 L .59743 .77306 L p .705 .939 .635 r
F P
0 g
s
.59472 .77533 m .59413 .7763 L .59743 .77306 L p 0 0 0 r
F P
0 g
s
.56749 .85647 m .57699 .84172 L .58385 .84596 L p .837 .757 .774 r
F P
0 g
s
.58385 .84596 m .57445 .86138 L .56749 .85647 L p .837 .757 .774 r
F P
0 g
s
.65342 .78353 m .64854 .76289 L .66407 .75948 L p .68 .634 .797 r
F P
0 g
s
.66407 .75948 m .66997 .78192 L .65342 .78353 L p .68 .634 .797 r
F P
0 g
s
.55673 .87127 m .56749 .85647 L .57445 .86138 L p .839 .772 .788 r
F P
0 g
s
.57445 .86138 m .56361 .87672 L .55673 .87127 L p .839 .772 .788 r
F P
0 g
s
.36996 .58057 m .3978 .57703 L .41437 .59244 L p .476 .687 .959 r
F P
0 g
s
.3978 .57703 m .36996 .58057 L .34725 .56495 L p .503 .698 .957 r
F P
0 g
s
.54713 1.18252 m .51565 1.17315 L .51357 1.16097 L p .367 .612 .945 r
F P
0 g
s
.48583 1.14955 m .51357 1.16097 L .51565 1.17315 L p .407 .608 .931 r
F P
0 g
s
.58634 .80996 m .59138 .7969 L .59562 .79882 L p .852 .709 .704 r
F P
0 g
s
.59562 .79882 m .59123 .81279 L .58634 .80996 L p .852 .709 .704 r
F P
0 g
s
.54497 .88601 m .55673 .87127 L .56361 .87672 L p .841 .786 .798 r
F P
0 g
s
.56361 .87672 m .5516 .89185 L .54497 .88601 L p .841 .786 .798 r
F P
0 g
s
.48516 .96104 m .49821 .94833 L .50199 .95465 L p .874 .874 .832 r
F P
0 g
s
.50199 .95465 m .48778 .96704 L .48516 .96104 L p .874 .874 .832 r
F P
0 g
s
.5868 .79195 m .59165 .78122 L .59242 .78299 L p .97 .821 .639 r
F P
0 g
s
.59242 .78299 m .58845 .79462 L .5868 .79195 L p .97 .821 .639 r
F P
0 g
s
.57492 .68542 m .55687 .67353 L .55825 .6635 L p .489 .566 .861 r
F P
0 g
s
.53678 .65279 m .55825 .6635 L .55687 .67353 L p .459 .571 .88 r
F P
0 g
s
.44825 1.00409 m .4609 .99488 L .45904 1.00108 L p .782 .996 .861 r
F P
0 g
s
.45904 1.00108 m .44468 1.00953 L .44825 1.00409 L p .782 .996 .861 r
F P
0 g
s
.53251 .90059 m .54497 .88601 L .5516 .89185 L p .844 .798 .806 r
F P
0 g
s
.5516 .89185 m .53874 .90667 L .53251 .90059 L p .844 .798 .806 r
F P
0 g
s
.61032 .73502 m .59959 .72 L .60622 .71378 L p .574 .55 .79 r
F P
0 g
s
.59151 .69887 m .60622 .71378 L .59959 .72 L p .533 .542 .81 r
F P
0 g
s
.61867 .75107 m .61032 .73502 L .61864 .73001 L p .615 .565 .775 r
F P
0 g
s
.61864 .73001 m .62845 .74739 L .61867 .75107 L p .615 .565 .775 r
F P
0 g
s
.66997 .78192 m .66407 .75948 L .68231 .7554 L p .678 .647 .812 r
F P
0 g
s
.68231 .7554 m .68929 .77987 L .66997 .78192 L p .678 .647 .812 r
F P
0 g
s
.46178 .98936 m .47427 .97861 L .47488 .98473 L p .871 .966 .855 r
F P
0 g
s
.47488 .98473 m .4609 .99488 L .46178 .98936 L p .871 .966 .855 r
F P
0 g
s
.51966 .91491 m .53251 .90059 L .53874 .90667 L p .849 .809 .811 r
F P
0 g
s
.53874 .90667 m .52533 .92108 L .51966 .91491 L p .849 .809 .811 r
F P
0 g
s
.60622 .71378 m .61864 .73001 L .61032 .73502 L p .574 .55 .79 r
F P
0 g
s
.57954 .82348 m .58634 .80996 L .59123 .81279 L p .855 .737 .732 r
F P
0 g
s
.59123 .81279 m .58497 .82712 L .57954 .82348 L p .855 .737 .732 r
F P
0 g
s
.62155 1.20716 m .58802 1.20278 L .57813 1.18971 L p .333 .648 .968 r
F P
0 g
s
.54713 1.18252 m .57813 1.18971 L .58802 1.20278 L p .369 .642 .961 r
F P
0 g
s
.58267 .80683 m .58845 .79462 L .59138 .7969 L p .895 .755 .699 r
F P
0 g
s
.59138 .7969 m .58634 .80996 L .58267 .80683 L p .895 .755 .699 r
F P
0 g
s
.51128 .63193 m .48685 .62519 L .47984 .61171 L p .468 .625 .92 r
F P
0 g
s
.45339 .60769 m .47984 .61171 L .48685 .62519 L p .448 .634 .935 r
F P
0 g
s
.58639 .78884 m .59222 .77901 L .59165 .78122 L p .98 .912 .607 r
F P
0 g
s
.59165 .78122 m .5868 .79195 L .58639 .78884 L p .98 .912 .607 r
F P
0 g
s
.37466 1.09302 m .3542 1.07087 L .37155 1.06393 L p .581 .61 .846 r
F P
0 g
s
.37155 1.06393 m .3893 1.08457 L .37466 1.09302 L p .581 .61 .846 r
F P
0 g
s
.50674 .92888 m .51966 .91491 L .52533 .92108 L p .856 .822 .814 r
F P
0 g
s
.52533 .92108 m .51171 .93499 L .50674 .92888 L p .856 .822 .814 r
F P
0 g
s
.57116 .83736 m .57954 .82348 L .58497 .82712 L p .854 .757 .755 r
F P
0 g
s
.58497 .82712 m .57699 .84172 L .57116 .83736 L p .854 .757 .755 r
F P
0 g
s
.68929 .77987 m .68231 .7554 L .7036 .75058 L p .676 .658 .825 r
F P
0 g
s
.7036 .75058 m .71173 .77735 L .68929 .77987 L p .676 .658 .825 r
F P
0 g
s
.41437 .59244 m .44206 .59304 L .45339 .60769 L p .46 .661 .948 r
F P
0 g
s
.44206 .59304 m .41437 .59244 L .3978 .57703 L p .487 .675 .948 r
F P
0 g
s
.47289 .97308 m .48516 .96104 L .48778 .96704 L p .888 .906 .833 r
F P
0 g
s
.48778 .96704 m .47427 .97861 L .47289 .97308 L p .888 .906 .833 r
F P
0 g
s
.47984 .61171 m .45339 .60769 L .44206 .59304 L p .476 .65 .935 r
F P
0 g
s
.5614 .85151 m .57116 .83736 L .57699 .84172 L p .852 .771 .772 r
F P
0 g
s
.57699 .84172 m .56749 .85647 L .5614 .85151 L p .852 .771 .772 r
F P
0 g
s
.59151 .69887 m .57492 .68542 L .57872 .6761 L p .52 .565 .841 r
F P
0 g
s
.55825 .6635 m .57872 .6761 L .57492 .68542 L p .489 .566 .861 r
F P
0 g
s
.59222 .77901 m .58639 .78884 L .58722 .78523 L p .885 .939 .57 r
F P
0 g
s
.58016 .80334 m .5868 .79195 L .58845 .79462 L p .937 .817 .701 r
F P
0 g
s
.58845 .79462 m .58267 .80683 L .58016 .80334 L p .937 .817 .701 r
F P
0 g
s
.49407 .94244 m .50674 .92888 L .51171 .93499 L p .866 .837 .816 r
F P
0 g
s
.51171 .93499 m .49821 .94833 L .49407 .94244 L p .866 .837 .816 r
F P
0 g
s
.57521 .81958 m .58267 .80683 L .58634 .80996 L p .884 .771 .732 r
F P
0 g
s
.58634 .80996 m .57954 .82348 L .57521 .81958 L p .884 .771 .732 r
F P
0 g
s
.62845 .74739 m .61864 .73001 L .62884 .72416 L p .622 .586 .792 r
F P
0 g
s
.62884 .72416 m .64028 .74301 L .62845 .74739 L p .622 .586 .792 r
F P
0 g
s
.55052 .86585 m .5614 .85151 L .56749 .85647 L p .849 .782 .785 r
F P
0 g
s
.56749 .85647 m .55673 .87127 L .55052 .86585 L p .849 .782 .785 r
F P
0 g
s
.55825 .6635 m .53678 .65279 L .53601 .64088 L p .487 .592 .885 r
F P
0 g
s
.51128 .63193 m .53601 .64088 L .53678 .65279 L p .463 .599 .902 r
F P
0 g
s
.53879 .88026 m .55052 .86585 L .55673 .87127 L p .848 .791 .795 r
F P
0 g
s
.55673 .87127 m .54497 .88601 L .53879 .88026 L p .848 .791 .795 r
F P
0 g
s
.71173 .77735 m .7036 .75058 L .72837 .74492 L p .674 .668 .837 r
F P
0 g
s
.72837 .74492 m .73774 .77431 L .71173 .77735 L p .674 .668 .837 r
F P
0 g
s
.2911 .55822 m .32106 .54706 L .34725 .56495 L p .522 .72 .963 r
F P
0 g
s
.32106 .54706 m .2911 .55822 L .2569 .54093 L p .542 .726 .959 r
F P
0 g
s
.60622 .71378 m .59151 .69887 L .59765 .69051 L p .554 .567 .822 r
F P
0 g
s
.57872 .6761 m .59765 .69051 L .59151 .69887 L p .52 .565 .841 r
F P
0 g
s
.61864 .73001 m .60622 .71378 L .61451 .70659 L p .588 .574 .805 r
F P
0 g
s
.61451 .70659 m .62884 .72416 L .61864 .73001 L p .588 .574 .805 r
F P
0 g
s
.45895 1.13616 m .43352 1.12081 L .44054 1.11129 L p .455 .578 .888 r
F P
0 g
s
.43352 1.12081 m .41013 1.10358 L .42 1.095 L p .495 .578 .868 r
F P
0 g
s
.42 1.095 m .44054 1.11129 L .43352 1.12081 L p .495 .578 .868 r
F P
0 g
s
.56626 .8328 m .57521 .81958 L .57954 .82348 L p .874 .782 .756 r
F P
0 g
s
.57954 .82348 m .57116 .83736 L .56626 .8328 L p .874 .782 .756 r
F P
0 g
s
.52651 .89467 m .53879 .88026 L .54497 .88601 L p .849 .798 .801 r
F P
0 g
s
.54497 .88601 m .53251 .90059 L .52651 .89467 L p .849 .798 .801 r
F P
0 g
s
.48583 1.14955 m .45895 1.13616 L .46296 1.12593 L p .413 .579 .907 r
F P
0 g
s
.44054 1.11129 m .46296 1.12593 L .45895 1.13616 L p .455 .578 .888 r
F P
0 g
s
.59765 .69051 m .61451 .70659 L .60622 .71378 L p .554 .567 .822 r
F P
0 g
s
.57877 .79942 m .58639 .78884 L .5868 .79195 L p .962 .886 .709 r
F P
0 g
s
.5868 .79195 m .58016 .80334 L .57877 .79942 L p .962 .886 .709 r
F P
0 g
s
.48196 .95551 m .49407 .94244 L .49821 .94833 L p .879 .855 .815 r
F P
0 g
s
.49821 .94833 m .48516 .96104 L .48196 .95551 L p .879 .855 .815 r
F P
0 g
s
.45062 .9993 m .46178 .98936 L .4609 .99488 L p .823 .999 .828 r
F P
0 g
s
.4609 .99488 m .44825 1.00409 L .45062 .9993 L p .823 .999 .828 r
F P
0 g
s
.57813 1.18971 m .54713 1.18252 L .54155 1.17044 L p .326 .617 .955 r
F P
0 g
s
.51357 1.16097 m .54155 1.17044 L .54713 1.18252 L p .367 .612 .945 r
F P
0 g
s
.20179 1.04168 m .18606 1.0043 L .22599 1.0015 L p .658 .69 .869 r
F P
0 g
s
.22599 1.0015 m .23918 1.0356 L .20179 1.04168 L p .658 .69 .869 r
F P
0 g
s
.5719 .81536 m .58016 .80334 L .58267 .80683 L p .911 .814 .738 r
F P
0 g
s
.58267 .80683 m .57521 .81958 L .5719 .81536 L p .911 .814 .738 r
F P
0 g
s
.61647 .7594 m .62656 .75584 L .61709 .75985 L p .446 .85 .667 r
F P
0 g
s
.61709 .75985 m .60849 .76469 L .61647 .7594 L p .446 .85 .667 r
F P
0 g
s
.514 .90896 m .52651 .89467 L .53251 .90059 L p .852 .806 .805 r
F P
0 g
s
.53251 .90059 m .51966 .91491 L .514 .90896 L p .852 .806 .805 r
F P
0 g
s
.46168 .98443 m .47289 .97308 L .47427 .97861 L p .898 .948 .829 r
F P
0 g
s
.47427 .97861 m .46178 .98936 L .46168 .98443 L p .898 .948 .829 r
F P
0 g
s
.41013 1.10358 m .3893 1.08457 L .40183 1.07715 L p .534 .582 .849 r
F P
0 g
s
.40183 1.07715 m .42 1.095 L .41013 1.10358 L p .534 .582 .849 r
F P
0 g
s
.55606 .84642 m .56626 .8328 L .57116 .83736 L p .865 .788 .774 r
F P
0 g
s
.57116 .83736 m .5614 .85151 L .55606 .84642 L p .865 .788 .774 r
F P
0 g
s
.64028 .74301 m .62884 .72416 L .64112 .71735 L p .627 .604 .808 r
F P
0 g
s
.64112 .71735 m .65439 .73785 L .64028 .74301 L p .627 .604 .808 r
F P
0 g
s
.73774 .77431 m .72837 .74492 L .7571 .73831 L p .672 .678 .847 r
F P
0 g
s
.7571 .73831 m .76779 .77069 L .73774 .77431 L p .672 .678 .847 r
F P
0 g
s
.50156 .92306 m .514 .90896 L .51966 .91491 L p .857 .814 .806 r
F P
0 g
s
.51966 .91491 m .50674 .92888 L .50156 .92306 L p .857 .814 .806 r
F P
0 g
s
.51357 1.16097 m .48583 1.14955 L .48676 1.13887 L p .37 .582 .924 r
F P
0 g
s
.46296 1.12593 m .48676 1.13887 L .48583 1.14955 L p .413 .579 .907 r
F P
0 g
s
.54486 .86035 m .55606 .84642 L .5614 .85151 L p .858 .793 .786 r
F P
0 g
s
.5614 .85151 m .55052 .86585 L .54486 .86035 L p .858 .793 .786 r
F P
0 g
s
.57848 .795 m .58722 .78523 L .58639 .78884 L p .954 .943 .723 r
F P
0 g
s
.58639 .78884 m .57877 .79942 L .57848 .795 L p .954 .943 .723 r
F P
0 g
s
.57872 .6761 m .55825 .6635 L .56038 .65207 L p .513 .588 .867 r
F P
0 g
s
.53601 .64088 m .56038 .65207 L .55825 .6635 L p .487 .592 .885 r
F P
0 g
s
.47071 .96804 m .48196 .95551 L .48516 .96104 L p .896 .88 .811 r
F P
0 g
s
.48516 .96104 m .47289 .97308 L .47071 .96804 L p .896 .88 .811 r
F P
0 g
s
.59743 .77306 m .58931 .78105 L .5927 .77621 L p .705 .939 .635 r
F P
0 g
s
.53601 .64088 m .51128 .63193 L .50749 .61821 L p .489 .617 .905 r
F P
0 g
s
.47984 .61171 m .50749 .61821 L .51128 .63193 L p .468 .625 .92 r
F P
0 g
s
.56222 .82797 m .5719 .81536 L .57521 .81958 L p .891 .811 .762 r
F P
0 g
s
.57521 .81958 m .56626 .8328 L .56222 .82797 L p .891 .811 .762 r
F P
0 g
s
.22623 1.05167 m .24248 1.06313 L .20572 1.06995 L p .528 .834 .999 r
F P
0 g
s
.20572 1.06995 m .18653 1.05528 L .22623 1.05167 L p .528 .834 .999 r
F P
0 g
s
.48949 .93688 m .50156 .92306 L .50674 .92888 L p .865 .822 .804 r
F P
0 g
s
.50674 .92888 m .49407 .94244 L .48949 .93688 L p .865 .822 .804 r
F P
0 g
s
.56955 .81074 m .57877 .79942 L .58016 .80334 L p .93 .86 .751 r
F P
0 g
s
.58016 .80334 m .5719 .81536 L .56955 .81074 L p .93 .86 .751 r
F P
0 g
s
.53296 .87451 m .54486 .86035 L .55052 .86585 L p .854 .796 .794 r
F P
0 g
s
.55052 .86585 m .53879 .88026 L .53296 .87451 L p .854 .796 .794 r
F P
0 g
s
.62629 .75324 m .63804 .7511 L .62656 .75584 L p .525 .916 .803 r
F P
0 g
s
.62656 .75584 m .61647 .7594 L .62629 .75324 L p .525 .916 .803 r
F P
0 g
s
.62884 .72416 m .61451 .70659 L .62462 .69828 L p .599 .595 .819 r
F P
0 g
s
.62462 .69828 m .64112 .71735 L .62884 .72416 L p .599 .595 .819 r
F P
0 g
s
.3893 1.08457 m .37155 1.06393 L .38646 1.05788 L p .57 .589 .833 r
F P
0 g
s
.38646 1.05788 m .40183 1.07715 L .3893 1.08457 L p .57 .589 .833 r
F P
0 g
s
.76779 .77069 m .7571 .73831 L .79038 .73061 L p .67 .687 .857 r
F P
0 g
s
.79038 .73061 m .80247 .76642 L .76779 .77069 L p .67 .687 .857 r
F P
0 g
s
.52065 .8888 m .53296 .87451 L .53879 .88026 L p .852 .799 .798 r
F P
0 g
s
.53879 .88026 m .52651 .89467 L .52065 .8888 L p .852 .799 .798 r
F P
0 g
s
.59765 .69051 m .57872 .6761 L .58369 .66544 L p .541 .587 .849 r
F P
0 g
s
.56038 .65207 m .58369 .66544 L .57872 .6761 L p .513 .588 .867 r
F P
0 g
s
.55139 .8411 m .56222 .82797 L .56626 .8328 L p .876 .808 .778 r
F P
0 g
s
.56626 .8328 m .55606 .84642 L .55139 .8411 L p .876 .808 .778 r
F P
0 g
s
.47812 .95035 m .48949 .93688 L .49407 .94244 L p .877 .833 .799 r
F P
0 g
s
.49407 .94244 m .48196 .95551 L .47812 .95035 L p .877 .833 .799 r
F P
0 g
s
.45182 .99508 m .46168 .98443 L .46178 .98936 L p .876 .993 .8 r
F P
0 g
s
.46178 .98936 m .45062 .9993 L .45182 .99508 L p .876 .993 .8 r
F P
0 g
s
.57929 .78999 m .58931 .78105 L .58722 .78523 L p .919 .978 .747 r
F P
0 g
s
.58722 .78523 m .57848 .795 L .57929 .78999 L p .919 .978 .747 r
F P
0 g
s
.61451 .70659 m .59765 .69051 L .6053 .6809 L p .57 .589 .833 r
F P
0 g
s
.6053 .6809 m .62462 .69828 L .61451 .70659 L p .57 .589 .833 r
F P
0 g
s
.65439 .73785 m .64112 .71735 L .65574 .70944 L p .632 .621 .822 r
F P
0 g
s
.65574 .70944 m .67104 .7318 L .65439 .73785 L p .632 .621 .822 r
F P
0 g
s
.60219 .76921 m .5927 .77621 L .59748 .77063 L p .686 .96 .722 r
F P
0 g
s
.50824 .90313 m .52065 .8888 L .52651 .89467 L p .853 .802 .8 r
F P
0 g
s
.52651 .89467 m .514 .90896 L .50824 .90313 L p .853 .802 .8 r
F P
0 g
s
.4606 .98 m .47071 .96804 L .47289 .97308 L p .915 .916 .803 r
F P
0 g
s
.47289 .97308 m .46168 .98443 L .4606 .98 L p .915 .916 .803 r
F P
0 g
s
.58369 .66544 m .6053 .6809 L .59765 .69051 L p .541 .587 .849 r
F P
0 g
s
.23918 1.0356 m .22599 1.0015 L .26087 .99914 L p .659 .68 .858 r
F P
0 g
s
.26087 .99914 m .2719 1.03032 L .23918 1.0356 L p .659 .68 .858 r
F P
0 g
s
.34725 .56495 m .37877 .55939 L .3978 .57703 L p .503 .698 .957 r
F P
0 g
s
.37877 .55939 m .34725 .56495 L .32106 .54706 L p .525 .708 .954 r
F P
0 g
s
.54155 1.17044 m .51357 1.16097 L .5114 1.15009 L p .325 .585 .937 r
F P
0 g
s
.48676 1.13887 m .5114 1.15009 L .51357 1.16097 L p .37 .582 .924 r
F P
0 g
s
.50749 .61821 m .47984 .61171 L .47204 .59634 L p .493 .641 .922 r
F P
0 g
s
.44206 .59304 m .47204 .59634 L .47984 .61171 L p .476 .65 .935 r
F P
0 g
s
.55897 .82276 m .56955 .81074 L .5719 .81536 L p .904 .841 .773 r
F P
0 g
s
.5719 .81536 m .56222 .82797 L .55897 .82276 L p .904 .841 .773 r
F P
0 g
s
.56813 .80562 m .57848 .795 L .57877 .79942 L p .934 .903 .769 r
F P
0 g
s
.57877 .79942 m .56955 .81074 L .56813 .80562 L p .934 .903 .769 r
F P
0 g
s
.53967 .85468 m .55139 .8411 L .55606 .84642 L p .866 .805 .789 r
F P
0 g
s
.55606 .84642 m .54486 .86035 L .53967 .85468 L p .866 .805 .789 r
F P
0 g
s
.49606 .91741 m .50824 .90313 L .514 .90896 L p .856 .804 .799 r
F P
0 g
s
.514 .90896 m .50156 .92306 L .49606 .91741 L p .856 .804 .799 r
F P
0 g
s
.57813 1.18971 m .60795 1.19482 L .62155 1.20716 L p .333 .648 .968 r
F P
0 g
s
.4677 .96341 m .47812 .95035 L .48196 .95551 L p .894 .848 .791 r
F P
0 g
s
.48196 .95551 m .47071 .96804 L .4677 .96341 L p .894 .848 .791 r
F P
0 g
s
.63815 .74609 m .65176 .74552 L .63804 .7511 L p .581 .943 .892 r
F P
0 g
s
.63804 .7511 m .62629 .75324 L .63815 .74609 L p .581 .943 .892 r
F P
0 g
s
.56038 .65207 m .53601 .64088 L .53559 .6273 L p .511 .611 .889 r
F P
0 g
s
.50749 .61821 m .53559 .6273 L .53601 .64088 L p .489 .617 .905 r
F P
0 g
s
.80247 .76642 m .79038 .73061 L .8289 .72166 L p .669 .695 .866 r
F P
0 g
s
.8289 .72166 m .84245 .76142 L .80247 .76642 L p .669 .695 .866 r
F P
0 g
s
.52737 .86864 m .53967 .85468 L .54486 .86035 L p .858 .803 .795 r
F P
0 g
s
.54486 .86035 m .53296 .87451 L .52737 .86864 L p .858 .803 .795 r
F P
0 g
s
.4844 .93155 m .49606 .91741 L .50156 .92306 L p .862 .807 .795 r
F P
0 g
s
.50156 .92306 m .48949 .93688 L .4844 .93155 L p .862 .807 .795 r
F P
0 g
s
.47204 .59634 m .44206 .59304 L .42919 .5763 L p .5 .665 .936 r
F P
0 g
s
.3978 .57703 m .42919 .5763 L .44206 .59304 L p .487 .675 .948 r
F P
0 g
s
.46296 1.12593 m .44054 1.11129 L .44628 1.10285 L p .423 .55 .879 r
F P
0 g
s
.44054 1.11129 m .42 1.095 L .42826 1.08743 L p .469 .551 .857 r
F P
0 g
s
.42826 1.08743 m .44628 1.10285 L .44054 1.11129 L p .469 .551 .857 r
F P
0 g
s
.42919 .5763 m .3978 .57703 L .37877 .55939 L p .511 .687 .946 r
F P
0 g
s
.60795 1.19482 m .57813 1.18971 L .56915 1.178 L p .284 .62 .959 r
F P
0 g
s
.54155 1.17044 m .56915 1.178 L .57813 1.18971 L p .326 .617 .955 r
F P
0 g
s
.58122 .78429 m .5927 .77621 L .58931 .78105 L p .876 .994 .782 r
F P
0 g
s
.58931 .78105 m .57929 .78999 L .58122 .78429 L p .876 .994 .782 r
F P
0 g
s
.54731 .83545 m .55897 .82276 L .56222 .82797 L p .884 .828 .787 r
F P
0 g
s
.56222 .82797 m .55139 .8411 L .54731 .83545 L p .884 .828 .787 r
F P
0 g
s
.42 1.095 m .40183 1.07715 L .41243 1.07066 L p .514 .556 .836 r
F P
0 g
s
.41243 1.07066 m .42826 1.08743 L .42 1.095 L p .514 .556 .836 r
F P
0 g
s
.60849 .76469 m .59748 .77063 L .60373 .76419 L p .688 .977 .807 r
F P
0 g
s
.26093 1.04859 m .27467 1.05719 L .24248 1.06313 L p .5 .836 .998 r
F P
0 g
s
.24248 1.06313 m .22623 1.05167 L .26093 1.04859 L p .5 .836 .998 r
F P
0 g
s
.64112 .71735 m .62462 .69828 L .63677 .68869 L p .607 .613 .831 r
F P
0 g
s
.63677 .68869 m .65574 .70944 L .64112 .71735 L p .607 .613 .831 r
F P
0 g
s
.51481 .88289 m .52737 .86864 L .53296 .87451 L p .854 .8 .798 r
F P
0 g
s
.53296 .87451 m .52065 .8888 L .51481 .88289 L p .854 .8 .798 r
F P
0 g
s
.48676 1.13887 m .46296 1.12593 L .46607 1.11683 L p .376 .55 .899 r
F P
0 g
s
.44628 1.10285 m .46607 1.11683 L .46296 1.12593 L p .423 .55 .879 r
F P
0 g
s
.45187 .99137 m .4606 .98 L .46168 .98443 L p .925 .964 .776 r
F P
0 g
s
.46168 .98443 m .45182 .99508 L .45187 .99137 L p .925 .964 .776 r
F P
0 g
s
.47355 .94548 m .4844 .93155 L .48949 .93688 L p .871 .81 .787 r
F P
0 g
s
.48949 .93688 m .47812 .95035 L .47355 .94548 L p .871 .81 .787 r
F P
0 g
s
.45851 .976 m .4677 .96341 L .47071 .96804 L p .916 .87 .778 r
F P
0 g
s
.47071 .96804 m .4606 .98 L .45851 .976 L p .916 .87 .778 r
F P
0 g
s
.55645 .81709 m .56813 .80562 L .56955 .81074 L p .908 .87 .789 r
F P
0 g
s
.56955 .81074 m .55897 .82276 L .55645 .81709 L p .908 .87 .789 r
F P
0 g
s
.56763 .79991 m .57929 .78999 L .57848 .795 L p .924 .935 .793 r
F P
0 g
s
.57848 .795 m .56813 .80562 L .56763 .79991 L p .924 .935 .793 r
F P
0 g
s
.44355 1.00505 m .45182 .99508 L .45062 .9993 L p .691 .94 .648 r
F P
0 g
s
.67104 .7318 m .65574 .70944 L .67299 .70027 L p .635 .636 .834 r
F P
0 g
s
.67299 .70027 m .69059 .72474 L .67104 .7318 L p .635 .636 .834 r
F P
0 g
s
.50229 .89732 m .51481 .88289 L .52065 .8888 L p .852 .798 .798 r
F P
0 g
s
.52065 .8888 m .50824 .90313 L .50229 .89732 L p .852 .798 .798 r
F P
0 g
s
.2719 1.03032 m .26087 .99914 L .2913 .99718 L p .66 .669 .847 r
F P
0 g
s
.2913 .99718 m .30048 1.02576 L .2719 1.03032 L p .66 .669 .847 r
F P
0 g
s
.40183 1.07715 m .38646 1.05788 L .39917 1.05264 L p .557 .565 .817 r
F P
0 g
s
.39917 1.05264 m .41243 1.07066 L .40183 1.07715 L p .557 .565 .817 r
F P
0 g
s
.53485 .84874 m .54731 .83545 L .55139 .8411 L p .87 .818 .795 r
F P
0 g
s
.55139 .8411 m .53967 .85468 L .53485 .84874 L p .87 .818 .795 r
F P
0 g
s
.58369 .66544 m .56038 .65207 L .56332 .63899 L p .533 .608 .873 r
F P
0 g
s
.53559 .6273 m .56332 .63899 L .56038 .65207 L p .511 .611 .889 r
F P
0 g
s
.4638 .9591 m .47355 .94548 L .47812 .95035 L p .884 .813 .774 r
F P
0 g
s
.47812 .95035 m .4677 .96341 L .4638 .9591 L p .884 .813 .774 r
F P
0 g
s
.49015 .91185 m .50229 .89732 L .50824 .90313 L p .853 .795 .794 r
F P
0 g
s
.50824 .90313 m .49606 .91741 L .49015 .91185 L p .853 .795 .794 r
F P
0 g
s
.2569 .54093 m .29078 .52648 L .32106 .54706 L p .542 .726 .959 r
F P
0 g
s
.65229 .73779 m .668 .73901 L .65176 .74552 L p .616 .945 .942 r
F P
0 g
s
.65176 .74552 m .63815 .74609 L .65229 .73779 L p .616 .945 .942 r
F P
0 g
s
.56915 1.178 m .54155 1.17044 L .53632 1.1596 L p .278 .587 .945 r
F P
0 g
s
.5114 1.15009 m .53632 1.1596 L .54155 1.17044 L p .325 .585 .937 r
F P
0 g
s
.62462 .69828 m .6053 .6809 L .61463 .66986 L p .582 .608 .843 r
F P
0 g
s
.61463 .66986 m .63677 .68869 L .62462 .69828 L p .582 .608 .843 r
F P
0 g
s
.5114 1.15009 m .48676 1.13887 L .48717 1.12933 L p .327 .552 .916 r
F P
0 g
s
.46607 1.11683 m .48717 1.12933 L .48676 1.13887 L p .376 .55 .899 r
F P
0 g
s
.58432 .77779 m .59748 .77063 L .5927 .77621 L p .839 .998 .824 r
F P
0 g
s
.5927 .77621 m .58122 .78429 L .58432 .77779 L p .839 .998 .824 r
F P
0 g
s
.52194 .86256 m .53485 .84874 L .53967 .85468 L p .86 .809 .799 r
F P
0 g
s
.53967 .85468 m .52737 .86864 L .52194 .86256 L p .86 .809 .799 r
F P
0 g
s
.47869 .92638 m .49015 .91185 L .49606 .91741 L p .855 .792 .788 r
F P
0 g
s
.49606 .91741 m .4844 .93155 L .47869 .92638 L p .855 .792 .788 r
F P
0 g
s
.53559 .6273 m .50749 .61821 L .50348 .60254 L p .511 .634 .908 r
F P
0 g
s
.47204 .59634 m .50348 .60254 L .50749 .61821 L p .493 .641 .922 r
F P
0 g
s
.6053 .6809 m .58369 .66544 L .58992 .65322 L p .557 .606 .858 r
F P
0 g
s
.56332 .63899 m .58992 .65322 L .58369 .66544 L p .533 .608 .873 r
F P
0 g
s
.54374 .82937 m .55645 .81709 L .55897 .82276 L p .888 .847 .798 r
F P
0 g
s
.55897 .82276 m .54731 .83545 L .54374 .82937 L p .888 .847 .798 r
F P
0 g
s
.58992 .65322 m .61463 .66986 L .6053 .6809 L p .557 .606 .858 r
F P
0 g
s
.45076 .9881 m .45851 .976 L .4606 .98 L p .944 .904 .753 r
F P
0 g
s
.4606 .98 m .45187 .99137 L .45076 .9881 L p .944 .904 .753 r
F P
0 g
s
.61159 .75677 m .62629 .75324 L .61647 .7594 L p .695 .982 .874 r
F P
0 g
s
.61647 .7594 m .60373 .76419 L .61159 .75677 L p .695 .982 .874 r
F P
0 g
s
.44475 1.00214 m .45187 .99137 L .45182 .99508 L p .825 .968 .652 r
F P
0 g
s
.45182 .99508 m .44355 1.00505 L .44475 1.00214 L p .825 .968 .652 r
F P
0 g
s
.45537 .97237 m .4638 .9591 L .4677 .96341 L p .901 .818 .756 r
F P
0 g
s
.4677 .96341 m .45851 .976 L .45537 .97237 L p .901 .818 .756 r
F P
0 g
s
.56802 .7935 m .58122 .78429 L .57929 .78999 L p .903 .955 .821 r
F P
0 g
s
.57929 .78999 m .56763 .79991 L .56802 .7935 L p .903 .955 .821 r
F P
0 g
s
.55463 .81083 m .56763 .79991 L .56813 .80562 L p .905 .894 .808 r
F P
0 g
s
.56813 .80562 m .55645 .81709 L .55463 .81083 L p .905 .894 .808 r
F P
0 g
s
.50889 .87682 m .52194 .86256 L .52737 .86864 L p .853 .802 .799 r
F P
0 g
s
.52737 .86864 m .51481 .88289 L .50889 .87682 L p .853 .802 .799 r
F P
0 g
s
.46819 .94081 m .47869 .92638 L .4844 .93155 L p .86 .787 .777 r
F P
0 g
s
.4844 .93155 m .47355 .94548 L .46819 .94081 L p .86 .787 .777 r
F P
0 g
s
.35731 1.04184 m .34695 1.01854 L .3656 1.01575 L p .635 .613 .81 r
F P
0 g
s
.3656 1.01575 m .37428 1.03735 L .35731 1.04184 L p .635 .613 .81 r
F P
0 g
s
.30048 1.02576 m .2913 .99718 L .31779 .99557 L p .661 .656 .834 r
F P
0 g
s
.31779 .99557 m .32536 1.02186 L .30048 1.02576 L p .661 .656 .834 r
F P
0 g
s
.29121 1.04599 m .30278 1.05204 L .27467 1.05719 L p .46 .833 .991 r
F P
0 g
s
.27467 1.05719 m .26093 1.04859 L .29121 1.04599 L p .46 .833 .991 r
F P
0 g
s
.49604 .89143 m .50889 .87682 L .51481 .88289 L p .849 .794 .797 r
F P
0 g
s
.51481 .88289 m .50229 .89732 L .49604 .89143 L p .849 .794 .797 r
F P
0 g
s
.65574 .70944 m .63677 .68869 L .65122 .67761 L p .614 .629 .842 r
F P
0 g
s
.65122 .67761 m .67299 .70027 L .65574 .70944 L p .614 .629 .842 r
F P
0 g
s
.53032 .84241 m .54374 .82937 L .54731 .83545 L p .872 .83 .803 r
F P
0 g
s
.54731 .83545 m .53485 .84874 L .53032 .84241 L p .872 .83 .803 r
F P
0 g
s
.69059 .72474 m .67299 .70027 L .69325 .68965 L p .638 .65 .845 r
F P
0 g
s
.69325 .68965 m .71343 .71652 L .69059 .72474 L p .638 .65 .845 r
F P
0 g
s
.44628 1.10285 m .42826 1.08743 L .43501 1.08077 L p .436 .519 .845 r
F P
0 g
s
.42826 1.08743 m .41243 1.07066 L .42125 1.06499 L p .489 .525 .821 r
F P
0 g
s
.42125 1.06499 m .43501 1.08077 L .42826 1.08743 L p .489 .525 .821 r
F P
0 g
s
.45893 .95506 m .46819 .94081 L .47355 .94548 L p .867 .78 .762 r
F P
0 g
s
.47355 .94548 m .4638 .9591 L .45893 .95506 L p .867 .78 .762 r
F P
0 g
s
.46607 1.11683 m .44628 1.10285 L .45082 1.09537 L p .383 .517 .868 r
F P
0 g
s
.43501 1.08077 m .45082 1.09537 L .44628 1.10285 L p .436 .519 .845 r
F P
0 g
s
.53632 1.1596 m .5114 1.15009 L .50911 1.14034 L p .276 .553 .927 r
F P
0 g
s
.48717 1.12933 m .50911 1.14034 L .5114 1.15009 L p .327 .552 .916 r
F P
0 g
s
.48373 .90628 m .49604 .89143 L .50229 .89732 L p .847 .787 .792 r
F P
0 g
s
.50229 .89732 m .49015 .91185 L .48373 .90628 L p .847 .787 .792 r
F P
0 g
s
.44848 .98522 m .45537 .97237 L .45851 .976 L p .924 .824 .729 r
F P
0 g
s
.45851 .976 m .45076 .9881 L .44848 .98522 L p .924 .824 .729 r
F P
0 g
s
.41243 1.07066 m .39917 1.05264 L .40986 1.04812 L p .54 .537 .8 r
F P
0 g
s
.40986 1.04812 m .42125 1.06499 L .41243 1.07066 L p .54 .537 .8 r
F P
0 g
s
.58865 .77037 m .60373 .76419 L .59748 .77063 L p .811 .995 .865 r
F P
0 g
s
.59748 .77063 m .58432 .77779 L .58865 .77037 L p .811 .995 .865 r
F P
0 g
s
.66901 .72819 m .68708 .73143 L .668 .73901 L p .637 .934 .967 r
F P
0 g
s
.668 .73901 m .65229 .73779 L .66901 .72819 L p .637 .934 .967 r
F P
0 g
s
.44467 .99968 m .45076 .9881 L .45187 .99137 L p .954 .952 .685 r
F P
0 g
s
.45187 .99137 m .44475 1.00214 L .44467 .99968 L p .954 .952 .685 r
F P
0 g
s
.50348 .60254 m .47204 .59634 L .46329 .57873 L p .515 .656 .923 r
F P
0 g
s
.42919 .5763 m .46329 .57873 L .47204 .59634 L p .5 .665 .936 r
F P
0 g
s
.51655 .85615 m .53032 .84241 L .53485 .84874 L p .86 .815 .804 r
F P
0 g
s
.53485 .84874 m .52194 .86256 L .51655 .85615 L p .86 .815 .804 r
F P
0 g
s
.47226 .92126 m .48373 .90628 L .49015 .91185 L p .847 .778 .784 r
F P
0 g
s
.49015 .91185 m .47869 .92638 L .47226 .92126 L p .847 .778 .784 r
F P
0 g
s
.54063 .82274 m .55463 .81083 L .55645 .81709 L p .886 .863 .812 r
F P
0 g
s
.55645 .81709 m .54374 .82937 L .54063 .82274 L p .886 .863 .812 r
F P
0 g
s
.45112 .96904 m .45893 .95506 L .4638 .9591 L p .875 .769 .741 r
F P
0 g
s
.4638 .9591 m .45537 .97237 L .45112 .96904 L p .875 .769 .741 r
F P
0 g
s
.48717 1.12933 m .46607 1.11683 L .46831 1.10872 L p .329 .517 .889 r
F P
0 g
s
.45082 1.09537 m .46831 1.10872 L .46607 1.11683 L p .383 .517 .868 r
F P
0 g
s
.56332 .63899 m .53559 .6273 L .53549 .61175 L p .53 .628 .893 r
F P
0 g
s
.50348 .60254 m .53549 .61175 L .53559 .6273 L p .511 .634 .908 r
F P
0 g
s
.32536 1.02186 m .31779 .99557 L .34078 .9943 L p .662 .643 .82 r
F P
0 g
s
.34078 .9943 m .34695 1.01854 L .32536 1.02186 L p .662 .643 .82 r
F P
0 g
s
.62123 .74821 m .63815 .74609 L .62629 .75324 L p .699 .974 .92 r
F P
0 g
s
.62629 .75324 m .61159 .75677 L .62123 .74821 L p .699 .974 .92 r
F P
0 g
s
.37428 1.03735 m .3656 1.01575 L .38163 1.01346 L p .632 .594 .793 r
F P
0 g
s
.38163 1.01346 m .38881 1.03351 L .37428 1.03735 L p .632 .594 .793 r
F P
0 g
s
.56934 .78627 m .58432 .77779 L .58122 .78429 L p .878 .964 .849 r
F P
0 g
s
.58122 .78429 m .56802 .7935 L .56934 .78627 L p .878 .964 .849 r
F P
0 g
s
.46193 .93627 m .47226 .92126 L .47869 .92638 L p .848 .766 .772 r
F P
0 g
s
.47869 .92638 m .46819 .94081 L .46193 .93627 L p .848 .766 .772 r
F P
0 g
s
.56915 1.178 m .59574 1.18375 L .60795 1.19482 L p .284 .62 .959 r
F P
0 g
s
.55346 .80388 m .56802 .7935 L .56763 .79991 L p .894 .911 .829 r
F P
0 g
s
.56763 .79991 m .55463 .81083 L .55346 .80388 L p .894 .911 .829 r
F P
0 g
s
.32106 .54706 m .35686 .53912 L .37877 .55939 L p .525 .708 .954 r
F P
0 g
s
.35686 .53912 m .32106 .54706 L .29078 .52648 L p .544 .715 .951 r
F P
0 g
s
.50278 .87049 m .51655 .85615 L .52194 .86256 L p .851 .803 .803 r
F P
0 g
s
.52194 .86256 m .50889 .87682 L .50278 .87049 L p .851 .803 .803 r
F P
0 g
s
.63677 .68869 m .61463 .66986 L .62585 .65714 L p .592 .625 .853 r
F P
0 g
s
.62585 .65714 m .65122 .67761 L .63677 .68869 L p .592 .625 .853 r
F P
0 g
s
.31757 1.04382 m .32726 1.04761 L .30278 1.05204 L p .405 .822 .972 r
F P
0 g
s
.30278 1.05204 m .29121 1.04599 L .31757 1.04382 L p .405 .822 .972 r
F P
0 g
s
.18606 1.0043 m .17834 .96544 L .21991 .96619 L p .673 .698 .866 r
F P
0 g
s
.21991 .96619 m .22599 1.0015 L .18606 1.0043 L p .673 .698 .866 r
F P
0 g
s
.59574 1.18375 m .56915 1.178 L .56096 1.16747 L p .228 .587 .946 r
F P
0 g
s
.53632 1.1596 m .56096 1.16747 L .56915 1.178 L p .278 .587 .945 r
F P
0 g
s
.453 .9512 m .46193 .93627 L .46819 .94081 L p .848 .751 .755 r
F P
0 g
s
.46819 .94081 m .45893 .95506 L .453 .9512 L p .848 .751 .755 r
F P
0 g
s
.44496 .98268 m .45112 .96904 L .45537 .97237 L p .882 .751 .712 r
F P
0 g
s
.45537 .97237 m .44848 .98522 L .44496 .98268 L p .882 .751 .712 r
F P
0 g
s
.4433 .99762 m .44848 .98522 L .45076 .9881 L p .956 .839 .686 r
F P
0 g
s
.45076 .9881 m .44467 .99968 L .4433 .99762 L p .956 .839 .686 r
F P
0 g
s
.48937 .88534 m .50278 .87049 L .50889 .87682 L p .845 .791 .799 r
F P
0 g
s
.50889 .87682 m .49604 .89143 L .48937 .88534 L p .845 .791 .799 r
F P
0 g
s
.52599 .83558 m .54063 .82274 L .54374 .82937 L p .87 .84 .813 r
F P
0 g
s
.54374 .82937 m .53032 .84241 L .52599 .83558 L p .87 .84 .813 r
F P
0 g
s
.46329 .57873 m .42919 .5763 L .41448 .55711 L p .521 .677 .935 r
F P
0 g
s
.37877 .55939 m .41448 .55711 L .42919 .5763 L p .511 .687 .946 r
F P
0 g
s
.50911 1.14034 m .48717 1.12933 L .48706 1.12079 L p .275 .517 .905 r
F P
0 g
s
.46831 1.10872 m .48706 1.12079 L .48717 1.12933 L p .329 .517 .889 r
F P
0 g
s
.34695 1.01854 m .34078 .9943 L .36067 .99333 L p .663 .629 .805 r
F P
0 g
s
.36067 .99333 m .3656 1.01575 L .34695 1.01854 L p .663 .629 .805 r
F P
0 g
s
.58992 .65322 m .56332 .63899 L .56715 .62399 L p .55 .625 .879 r
F P
0 g
s
.53549 .61175 m .56715 .62399 L .56332 .63899 L p .53 .628 .893 r
F P
0 g
s
.44568 .96596 m .453 .9512 L .45893 .95506 L p .847 .729 .733 r
F P
0 g
s
.45893 .95506 m .45112 .96904 L .44568 .96596 L p .847 .729 .733 r
F P
0 g
s
.41448 .55711 m .37877 .55939 L .35686 .53912 L p .531 .697 .945 r
F P
0 g
s
.47667 .90059 m .48937 .88534 L .49604 .89143 L p .841 .779 .793 r
F P
0 g
s
.49604 .89143 m .48373 .90628 L .47667 .90059 L p .841 .779 .793 r
F P
0 g
s
.44037 1.01073 m .44467 .99968 L .44475 1.00214 L p 0 0 0 r
F P
0 g
s
.61463 .66986 m .58992 .65322 L .59756 .63918 L p .571 .623 .865 r
F P
0 g
s
.59756 .63918 m .62585 .65714 L .61463 .66986 L p .571 .623 .865 r
F P
0 g
s
.38881 1.03351 m .38163 1.01346 L .39529 1.01161 L p .629 .574 .773 r
F P
0 g
s
.39529 1.01161 m .40113 1.03028 L .38881 1.03351 L p .629 .574 .773 r
F P
0 g
s
.43501 1.08077 m .42125 1.06499 L .42843 1.06007 L p .455 .489 .804 r
F P
0 g
s
.42125 1.06499 m .40986 1.04812 L .41871 1.04425 L p .517 .503 .78 r
F P
0 g
s
.41871 1.04425 m .42843 1.06007 L .42125 1.06499 L p .517 .503 .78 r
F P
0 g
s
.45082 1.09537 m .43501 1.08077 L .44037 1.07492 L p .392 .48 .831 r
F P
0 g
s
.42843 1.06007 m .44037 1.07492 L .43501 1.08077 L p .455 .489 .804 r
F P
0 g
s
.59431 .76188 m .61159 .75677 L .60373 .76419 L p .789 .984 .899 r
F P
0 g
s
.60373 .76419 m .58865 .77037 L .59431 .76188 L p .789 .984 .899 r
F P
0 g
s
.22599 1.0015 m .21991 .96619 L .25615 .96694 L p .675 .69 .856 r
F P
0 g
s
.25615 .96694 m .26087 .99914 L .22599 1.0015 L p .675 .69 .856 r
F P
0 g
s
.56096 1.16747 m .53632 1.1596 L .53137 1.14987 L p .223 .553 .932 r
F P
0 g
s
.50911 1.14034 m .53137 1.14987 L .53632 1.1596 L p .276 .553 .927 r
F P
0 g
s
.71343 .71652 m .69325 .68965 L .71694 .67735 L p .641 .662 .855 r
F P
0 g
s
.71694 .67735 m .74004 .70699 L .71343 .71652 L p .641 .662 .855 r
F P
0 g
s
.56715 .62399 m .59756 .63918 L .58992 .65322 L p .55 .625 .879 r
F P
0 g
s
.465 .9161 m .47667 .90059 L .48373 .90628 L p .837 .766 .783 r
F P
0 g
s
.48373 .90628 m .47226 .92126 L .465 .9161 L p .837 .766 .783 r
F P
0 g
s
.44062 .99593 m .44496 .98268 L .44848 .98522 L p .884 .719 .672 r
F P
0 g
s
.44848 .98522 m .4433 .99762 L .44062 .99593 L p .884 .719 .672 r
F P
0 g
s
.4326 1.02306 m .43709 1.01436 L .43335 1.01686 L p .31 0 .099 r
F P
0 g
s
.67299 .70027 m .65122 .67761 L .66829 .66481 L p .62 .643 .852 r
F P
0 g
s
.66829 .66481 m .69325 .68965 L .67299 .70027 L p .62 .643 .852 r
F P
0 g
s
.53791 .81543 m .55346 .80388 L .55463 .81083 L p .879 .876 .828 r
F P
0 g
s
.55463 .81083 m .54063 .82274 L .53791 .81543 L p .879 .876 .828 r
F P
0 g
s
.44016 .98044 m .44568 .96596 L .45112 .96904 L p .84 .697 .705 r
F P
0 g
s
.45112 .96904 m .44496 .98268 L .44016 .98044 L p .84 .697 .705 r
F P
0 g
s
.51111 .84929 m .52599 .83558 L .53032 .84241 L p .857 .821 .812 r
F P
0 g
s
.53032 .84241 m .51655 .85615 L .51111 .84929 L p .857 .821 .812 r
F P
0 g
s
.68867 .71707 m .70939 .72262 L .68708 .73143 L p .649 .917 .978 r
F P
0 g
s
.68708 .73143 m .66901 .72819 L .68867 .71707 L p .649 .917 .978 r
F P
0 g
s
.45466 .93177 m .465 .9161 L .47226 .92126 L p .834 .749 .77 r
F P
0 g
s
.47226 .92126 m .46193 .93627 L .45466 .93177 L p .834 .749 .77 r
F P
0 g
s
.46831 1.10872 m .45082 1.09537 L .45424 1.08874 L p .33 .477 .856 r
F P
0 g
s
.44037 1.07492 m .45424 1.08874 L .45082 1.09537 L p .392 .48 .831 r
F P
0 g
s
.34045 1.04204 m .3485 1.04382 L .32726 1.04761 L p .327 .793 .933 r
F P
0 g
s
.32726 1.04761 m .31757 1.04382 L .34045 1.04204 L p .327 .793 .933 r
F P
0 g
s
.3656 1.01575 m .36067 .99333 L .37781 .99267 L p .664 .614 .788 r
F P
0 g
s
.37781 .99267 m .38163 1.01346 L .3656 1.01575 L p .664 .614 .788 r
F P
0 g
s
.43996 1.00953 m .4433 .99762 L .44467 .99968 L p .993 .878 .589 r
F P
0 g
s
.44467 .99968 m .44037 1.01073 L .43996 1.00953 L p .993 .878 .589 r
F P
0 g
s
.4459 .94747 m .45466 .93177 L .46193 .93627 L p .829 .729 .754 r
F P
0 g
s
.46193 .93627 m .453 .9512 L .4459 .94747 L p .829 .729 .754 r
F P
0 g
s
.57161 .77806 m .58865 .77037 L .58432 .77779 L p .853 .963 .875 r
F P
0 g
s
.58432 .77779 m .56934 .78627 L .57161 .77806 L p .853 .963 .875 r
F P
0 g
s
.63285 .73834 m .65229 .73779 L .63815 .74609 L p .701 .959 .947 r
F P
0 g
s
.63815 .74609 m .62123 .74821 L .63285 .73834 L p .701 .959 .947 r
F P
0 g
s
.55294 .7961 m .56934 .78627 L .56802 .7935 L p .878 .92 .85 r
F P
0 g
s
.56802 .7935 m .55346 .80388 L .55294 .7961 L p .878 .92 .85 r
F P
0 g
s
.26087 .99914 m .25615 .96694 L .28771 .96772 L p .678 .68 .844 r
F P
0 g
s
.28771 .96772 m .2913 .99718 L .26087 .99914 L p .678 .68 .844 r
F P
0 g
s
.43895 .96307 m .4459 .94747 L .453 .9512 L p .821 .701 .733 r
F P
0 g
s
.453 .9512 m .44568 .96596 L .43895 .96307 L p .821 .701 .733 r
F P
0 g
s
.49637 .86378 m .51111 .84929 L .51655 .85615 L p .847 .804 .808 r
F P
0 g
s
.51655 .85615 m .50278 .87049 L .49637 .86378 L p .847 .804 .808 r
F P
0 g
s
.53549 .61175 m .50348 .60254 L .49915 .58455 L p .53 .649 .91 r
F P
0 g
s
.46329 .57873 m .49915 .58455 L .50348 .60254 L p .515 .656 .923 r
F P
0 g
s
.40113 1.03028 m .39529 1.01161 L .40681 1.01018 L p .625 .551 .752 r
F P
0 g
s
.40681 1.01018 m .41144 1.02759 L .40113 1.03028 L p .625 .551 .752 r
F P
0 g
s
.43657 .99458 m .44016 .98044 L .44496 .98268 L p .817 .646 .67 r
F P
0 g
s
.44496 .98268 m .44062 .99593 L .43657 .99458 L p .817 .646 .67 r
F P
0 g
s
.43601 1.02195 m .43941 1.01233 L .43709 1.01436 L p .38 .032 .244 r
F P
0 g
s
.43709 1.01436 m .4326 1.02306 L .43601 1.02195 L p .38 .032 .244 r
F P
0 g
s
.48706 1.12079 m .46831 1.10872 L .46971 1.10149 L p .271 .477 .876 r
F P
0 g
s
.45424 1.08874 m .46971 1.10149 L .46831 1.10872 L p .33 .477 .856 r
F P
0 g
s
.53137 1.14987 m .50911 1.14034 L .50664 1.13157 L p .22 .517 .914 r
F P
0 g
s
.48706 1.12079 m .50664 1.13157 L .50911 1.14034 L p .275 .517 .905 r
F P
0 g
s
.43398 .97846 m .43895 .96307 L .44568 .96596 L p .804 .663 .708 r
F P
0 g
s
.44568 .96596 m .44016 .98044 L .43398 .97846 L p .804 .663 .708 r
F P
0 g
s
.43819 1.00872 m .44062 .99593 L .4433 .99762 L p .86 .654 .622 r
F P
0 g
s
.4433 .99762 m .43996 1.00953 L .43819 1.00872 L p .86 .654 .622 r
F P
0 g
s
.38163 1.01346 m .37781 .99267 L .39248 .99229 L p .666 .598 .769 r
F P
0 g
s
.39248 .99229 m .39529 1.01161 L .38163 1.01346 L p .666 .598 .769 r
F P
0 g
s
.48216 .87895 m .49637 .86378 L .50278 .87049 L p .84 .789 .803 r
F P
0 g
s
.50278 .87049 m .48937 .88534 L .48216 .87895 L p .84 .789 .803 r
F P
0 g
s
.2913 .99718 m .28771 .96772 L .31517 .96854 L p .681 .669 .832 r
F P
0 g
s
.31517 .96854 m .31779 .99557 L .2913 .99718 L p .681 .669 .832 r
F P
0 g
s
.52179 .8281 m .53791 .81543 L .54063 .82274 L p .864 .848 .825 r
F P
0 g
s
.54063 .82274 m .52599 .83558 L .52179 .8281 L p .864 .848 .825 r
F P
0 g
s
.42843 1.06007 m .41871 1.04425 L .42586 1.04098 L p .484 .462 .758 r
F P
0 g
s
.44037 1.07492 m .42843 1.06007 L .43409 1.0558 L p .407 .442 .785 r
F P
0 g
s
.42586 1.04098 m .43409 1.0558 L .42843 1.06007 L p .484 .462 .758 r
F P
0 g
s
.43941 1.01233 m .43601 1.02195 L .43798 1.02125 L p .417 .12 .351 r
F P
0 g
s
.46884 .89468 m .48216 .87895 L .48937 .88534 L p .833 .773 .795 r
F P
0 g
s
.48937 .88534 m .47667 .90059 L .46884 .89468 L p .833 .773 .795 r
F P
0 g
s
.4311 .99354 m .43398 .97846 L .44016 .98044 L p .772 .611 .679 r
F P
0 g
s
.44016 .98044 m .43657 .99458 L .4311 .99354 L p .772 .611 .679 r
F P
0 g
s
.36024 1.04063 m .36685 1.04061 L .3485 1.04382 L p .219 .737 .86 r
F P
0 g
s
.3485 1.04382 m .34045 1.04204 L .36024 1.04063 L p .219 .737 .86 r
F P
0 g
s
.43501 1.00828 m .43657 .99458 L .44062 .99593 L p .758 .561 .63 r
F P
0 g
s
.44062 .99593 m .43819 1.00872 L .43501 1.00828 L p .758 .561 .63 r
F P
0 g
s
.41144 1.02759 m .40681 1.01018 L .4164 1.00915 L p .619 .527 .727 r
F P
0 g
s
.4164 1.00915 m .41991 1.02539 L .41144 1.02759 L p .619 .527 .727 r
F P
0 g
s
.45676 .91082 m .46884 .89468 L .47667 .90059 L p .827 .756 .785 r
F P
0 g
s
.47667 .90059 m .465 .9161 L .45676 .91082 L p .827 .756 .785 r
F P
0 g
s
.39529 1.01161 m .39248 .99229 L .40495 .99218 L p .668 .581 .749 r
F P
0 g
s
.40495 .99218 m .40681 1.01018 L .39529 1.01161 L p .668 .581 .749 r
F P
0 g
s
.45424 1.08874 m .44037 1.07492 L .44441 1.06978 L p .33 .432 .814 r
F P
0 g
s
.43409 1.0558 m .44441 1.06978 L .44037 1.07492 L p .407 .442 .785 r
F P
0 g
s
.31779 .99557 m .31517 .96854 L .33901 .96941 L p .685 .658 .818 r
F P
0 g
s
.33901 .96941 m .34078 .9943 L .31779 .99557 L p .685 .658 .818 r
F P
0 g
s
.44623 .92724 m .45676 .91082 L .465 .9161 L p .82 .737 .772 r
F P
0 g
s
.465 .9161 m .45466 .93177 L .44623 .92724 L p .82 .737 .772 r
F P
0 g
s
.43751 .94379 m .44623 .92724 L .45466 .93177 L p .812 .713 .756 r
F P
0 g
s
.45466 .93177 m .4459 .94747 L .43751 .94379 L p .812 .713 .756 r
F P
0 g
s
.43081 .96032 m .43751 .94379 L .4459 .94747 L p .798 .683 .738 r
F P
0 g
s
.4459 .94747 m .43895 .96307 L .43081 .96032 L p .798 .683 .738 r
F P
0 g
s
.65122 .67761 m .62585 .65714 L .6392 .64245 L p .601 .64 .861 r
F P
0 g
s
.6392 .64245 m .66829 .66481 L .65122 .67761 L p .601 .64 .861 r
F P
0 g
s
.60143 .75213 m .62123 .74821 L .61159 .75677 L p .771 .968 .924 r
F P
0 g
s
.61159 .75677 m .59431 .76188 L .60143 .75213 L p .771 .968 .924 r
F P
0 g
s
.4263 .97671 m .43081 .96032 L .43895 .96307 L p .777 .646 .717 r
F P
0 g
s
.43895 .96307 m .43398 .97846 L .4263 .97671 L p .777 .646 .717 r
F P
0 g
s
.43038 1.00821 m .4311 .99354 L .43657 .99458 L p .712 .537 .652 r
F P
0 g
s
.43657 .99458 m .43501 1.00828 L .43038 1.00821 L p .712 .537 .652 r
F P
0 g
s
.53555 .8073 m .55294 .7961 L .55346 .80388 L p .868 .883 .845 r
F P
0 g
s
.55346 .80388 m .53791 .81543 L .53555 .8073 L p .868 .883 .845 r
F P
0 g
s
.42409 .9928 m .4263 .97671 L .43398 .97846 L p .743 .598 .695 r
F P
0 g
s
.43398 .97846 m .4311 .99354 L .42409 .9928 L p .743 .598 .695 r
F P
0 g
s
.50552 .84185 m .52179 .8281 L .52599 .83558 L p .852 .825 .821 r
F P
0 g
s
.52599 .83558 m .51111 .84929 L .50552 .84185 L p .852 .825 .821 r
F P
0 g
s
.40681 1.01018 m .40495 .99218 L .41542 .99235 L p .671 .565 .727 r
F P
0 g
s
.41542 .99235 m .4164 1.00915 L .40681 1.01018 L p .671 .565 .727 r
F P
0 g
s
.34078 .9943 m .33901 .96941 L .35966 .97035 L p .688 .647 .803 r
F P
0 g
s
.35966 .97035 m .36067 .99333 L .34078 .9943 L p .688 .647 .803 r
F P
0 g
s
.50664 1.13157 m .48706 1.12079 L .48641 1.11313 L p .213 .477 .89 r
F P
0 g
s
.46971 1.10149 m .48641 1.11313 L .48706 1.12079 L p .271 .477 .876 r
F P
0 g
s
.43774 1.02103 m .43819 1.00872 L .43996 1.00953 L p .643 .411 .553 r
F P
0 g
s
.43996 1.00953 m .43856 1.02094 L .43774 1.02103 L p .643 .411 .553 r
F P
0 g
s
.41991 1.02539 m .4164 1.00915 L .42421 1.00849 L p .613 .499 .7 r
F P
0 g
s
.42421 1.00849 m .42667 1.02367 L .41991 1.02539 L p .613 .499 .7 r
F P
0 g
s
.42421 1.00849 m .42409 .9928 L .4311 .99354 L p .689 .539 .677 r
F P
0 g
s
.4311 .99354 m .43038 1.00821 L .42421 1.00849 L p .689 .539 .677 r
F P
0 g
s
.46971 1.10149 m .45424 1.08874 L .45656 1.08286 L p .26 .428 .84 r
F P
0 g
s
.44441 1.06978 m .45656 1.08286 L .45424 1.08874 L p .33 .432 .814 r
F P
0 g
s
.43409 1.0558 m .42586 1.04098 L .43141 1.03824 L p .434 .409 .732 r
F P
0 g
s
.36067 .99333 m .35966 .97035 L .37748 .97138 L p .692 .635 .787 r
F P
0 g
s
.37748 .97138 m .37781 .99267 L .36067 .99333 L p .692 .635 .787 r
F P
0 g
s
.4164 1.00915 m .41542 .99235 L .42409 .9928 L p .677 .55 .702 r
F P
0 g
s
.42409 .9928 m .42421 1.00849 L .4164 1.00915 L p .677 .55 .702 r
F P
0 g
s
.56096 1.16747 m .58475 1.17378 L .59574 1.18375 L p .228 .587 .946 r
F P
0 g
s
.38037 1.03831 m .36685 1.04061 L p .37727 1.03956 L .077 .639 .739 r
F P
0 g
s
.36685 1.04061 m .36024 1.04063 L .37727 1.03956 L p .077 .639 .739 r
F P
0 g
s
.37727 1.03956 m .36024 1.04063 L p .37435 1.04074 L .01 .584 .738 r
F P
0 g
s
.36024 1.04063 m .35749 1.04016 L .37542 1.04075 L p .01 .584 .738 r
F P
0 g
s
.37542 1.04075 m .35749 1.04016 L p .37696 1.04173 L 0 .559 .767 r
F P
0 g
s
.37713 1.04175 m .37542 1.04075 L p .37696 1.04173 L 0 .559 .767 r
F P
0 g
s
.37542 1.04075 m .37727 1.03956 L p .375 1.04048 L .01 .584 .738 r
F P
0 g
s
.37435 1.04074 m .37542 1.04075 L .375 1.04048 L .01 .584 .738 r
F
.37727 1.03956 m .38259 1.03793 L .38037 1.03831 L p .077 .639 .739 r
F P
0 g
s
.56715 .62399 m .53549 .61175 L .53573 .59387 L p .546 .643 .897 r
F P
0 g
s
.49915 .58455 m .53573 .59387 L .53549 .61175 L p .53 .649 .91 r
F P
0 g
s
.74004 .70699 m .71694 .67735 L .74461 .66309 L p .643 .673 .863 r
F P
0 g
s
.74461 .66309 m .77098 .69592 L .74004 .70699 L p .643 .673 .863 r
F P
0 g
s
.43551 1.0215 m .43501 1.00828 L .43819 1.00872 L p .599 .405 .591 r
F P
0 g
s
.43819 1.00872 m .43774 1.02103 L .43551 1.0215 L p .599 .405 .591 r
F P
0 g
s
.4263 .97671 m .42409 .9928 L .41542 .99235 L p .724 .597 .714 r
F P
0 g
s
.55307 .78732 m .57161 .77806 L .56934 .78627 L p .86 .923 .87 r
F P
0 g
s
.56934 .78627 m .55294 .7961 L .55307 .78732 L p .86 .923 .87 r
F P
0 g
s
.57489 .76871 m .59431 .76188 L .58865 .77037 L p .828 .955 .898 r
F P
0 g
s
.58865 .77037 m .57161 .77806 L .57489 .76871 L p .828 .955 .898 r
F P
0 g
s
.58475 1.17378 m .56096 1.16747 L .55344 1.15799 L p .165 .548 .928 r
F P
0 g
s
.53137 1.14987 m .55344 1.15799 L .56096 1.16747 L p .223 .553 .932 r
F P
0 g
s
.37781 .99267 m .37748 .97138 L .39281 .9725 L p .697 .623 .77 r
F P
0 g
s
.39281 .9725 m .39248 .99229 L .37781 .99267 L p .697 .623 .77 r
F P
0 g
s
.7117 .70419 m .73542 .71239 L .70939 .72262 L p .655 .899 .982 r
F P
0 g
s
.70939 .72262 m .68867 .71707 L .7117 .70419 L p .655 .899 .982 r
F P
0 g
s
.42667 1.02367 m .42421 1.00849 L .43038 1.00821 L p .607 .469 .668 r
F P
0 g
s
.41542 .99235 m .417 .97515 L .4263 .97671 L p .724 .597 .714 r
F P
0 g
s
.43081 .96032 m .4263 .97671 L .417 .97515 L p .757 .638 .729 r
F P
0 g
s
.43185 1.02238 m .43038 1.00821 L .43501 1.00828 L p .6 .437 .632 r
F P
0 g
s
.43501 1.00828 m .43551 1.0215 L .43185 1.02238 L p .6 .437 .632 r
F P
0 g
s
.417 .97515 m .41542 .99235 L .40495 .99218 L p .712 .603 .733 r
F P
0 g
s
.43038 1.00821 m .43185 1.02238 L .42667 1.02367 L p .607 .469 .668 r
F P
0 g
s
.39248 .99229 m .39281 .9725 L .4059 .97375 L p .703 .612 .752 r
F P
0 g
s
.4059 .97375 m .40495 .99218 L .39248 .99229 L p .703 .612 .752 r
F P
0 g
s
.48954 .85657 m .50552 .84185 L .51111 .84929 L p .842 .805 .815 r
F P
0 g
s
.51111 .84929 m .49637 .86378 L .48954 .85657 L p .842 .805 .815 r
F P
0 g
s
.44441 1.06978 m .43409 1.0558 L .4383 1.05212 L p .332 .38 .762 r
F P
0 g
s
.43141 1.03824 m .4383 1.05212 L .43409 1.0558 L p .434 .409 .732 r
F P
0 g
s
.40495 .99218 m .4059 .97375 L .417 .97515 L p .712 .603 .733 r
F P
0 g
s
.417 .97515 m .42111 .95767 L .43081 .96032 L p .757 .638 .729 r
F P
0 g
s
.43751 .94379 m .43081 .96032 L .42111 .95767 L p .78 .674 .746 r
F P
0 g
s
.64669 .72694 m .66901 .72819 L .65229 .73779 L p .699 .939 .962 r
F P
0 g
s
.65229 .73779 m .63285 .73834 L .64669 .72694 L p .699 .939 .962 r
F P
0 g
s
.49915 .58455 m .46329 .57873 L .4534 .55849 L p .533 .668 .924 r
F P
0 g
s
.41448 .55711 m .4534 .55849 L .46329 .57873 L p .521 .677 .935 r
F P
0 g
s
.21689 1.03915 m .22623 1.05167 L .18653 1.05528 L p .501 .817 1 r
F P
0 g
s
.18653 1.05528 m .17511 1.0393 L .21689 1.03915 L p .501 .817 1 r
F P
0 g
s
.69325 .68965 m .66829 .66481 L .68835 .65 L p .624 .656 .861 r
F P
0 g
s
.68835 .65 m .71694 .67735 L .69325 .68965 L p .624 .656 .861 r
F P
0 g
s
.42111 .95767 m .42766 .9401 L .43751 .94379 L p .78 .674 .746 r
F P
0 g
s
.44623 .92724 m .43751 .94379 L .42766 .9401 L p .796 .703 .762 r
F P
0 g
s
.43601 1.02195 m .4326 1.02306 L p .43289 1.02421 L .614 .252 .331 r
F P
0 g
s
.43587 1.02286 m .43601 1.02195 L p .43476 1.02286 L .614 .252 .331 r
F P
0 g
s
.43289 1.02421 m .43551 1.02302 L .43476 1.02286 L .614 .252 .331 r
F
.43551 1.02302 m .43587 1.02286 L .43476 1.02286 L F
.43807 1.03419 m .43546 1.03599 L p .43551 1.02302 L .414 .311 .628 r
F P
0 g
s
.43551 1.0215 m .43583 1.02309 L p .43551 1.02302 L .414 .311 .628 r
F P
0 g
s
.43583 1.02309 m .43807 1.03419 L p .43551 1.02302 L .414 .311 .628 r
F P
0 g
s
.43185 1.02238 m .43551 1.0215 L p .43551 1.02302 L .414 .311 .628 r
F P
0 g
s
.43546 1.03599 m .43239 1.02443 L p .43289 1.02421 L .414 .311 .628 r
F P
0 g
s
.4355 1.02477 m .43546 1.03599 L .43289 1.02421 L .414 .311 .628 r
F
.4302 1.03122 m .43462 1.03105 L p .43289 1.02421 L .614 .252 .331 r
F P
0 g
s
.4326 1.02306 m .4323 1.02408 L p .43289 1.02421 L .614 .252 .331 r
F P
0 g
s
.4323 1.02408 m .4302 1.03122 L p .43289 1.02421 L .614 .252 .331 r
F P
0 g
s
.43551 1.02302 m .4355 1.02477 L .43289 1.02421 L .414 .311 .628 r
F
.43239 1.02443 m .43185 1.02238 L p .43551 1.02302 L F P
0 g
s
.43551 1.0215 m .43774 1.02103 L p .43776 1.02206 L .203 .124 .539 r
F P
0 g
s
.43856 1.02094 m .43798 1.02125 L p .43821 1.02337 L .847 .542 .473 r
F P
0 g
s
.43856 1.02094 m .43859 1.02148 L .43849 1.02143 L .807 .609 .05 r
F
.43798 1.02125 m .43793 1.0225 L p .43821 1.02337 L .847 .542 .473 r
F P
0 g
s
.43859 1.02148 m .43882 1.02528 L .43793 1.0225 L .807 .609 .05 r
F
.43928 1.03282 m .43793 1.0225 L p .43882 1.02528 L F P
0 g
s
.43928 1.03282 m .43807 1.03419 L p .43793 1.02874 L .203 .124 .539 r
F P
0 g
s
.43777 1.02222 m .43928 1.03282 L .43793 1.02874 L .203 .124 .539 r
F
.43793 1.0225 m .43928 1.03282 L p .43777 1.02222 L F P
0 g
s
.43807 1.03419 m .43594 1.02363 L p .43625 1.02339 L .203 .124 .539 r
F P
0 g
s
.43777 1.02222 m .43783 1.02452 L .43625 1.02339 L .203 .124 .539 r
F
.43783 1.02452 m .43807 1.03419 L .43625 1.02339 L F
.43462 1.03105 m .43758 1.03126 L p .43625 1.02339 L .704 .38 .425 r
F P
0 g
s
.43601 1.02195 m .43583 1.02309 L p .43625 1.02339 L .704 .38 .425 r
F P
0 g
s
.43583 1.02309 m .43462 1.03105 L p .43625 1.02339 L .704 .38 .425 r
F P
0 g
s
.43758 1.03126 m .43912 1.03185 L p .43821 1.02337 L .847 .542 .473 r
F P
0 g
s
.43793 1.0225 m .43758 1.03126 L p .43821 1.02337 L .847 .542 .473 r
F P
0 g
s
.43912 1.03185 m .43856 1.02094 L p .43821 1.02337 L .847 .542 .473 r
F P
0 g
s
.43774 1.02103 m .43856 1.02094 L p .43849 1.02143 L .807 .609 .05 r
F P
0 g
s
.43793 1.0225 m .43774 1.02103 L p .43859 1.02148 L .807 .609 .05 r
F P
0 g
s
.43625 1.02339 m .43648 1.02476 L .43795 1.02208 L .704 .38 .425 r
F
.43758 1.03126 m .43793 1.0225 L p .43648 1.02476 L F P
0 g
s
.43793 1.0225 m .43795 1.02208 L p .43648 1.02476 L .704 .38 .425 r
F P
0 g
s
.43912 1.03185 m .43928 1.03282 L p .43898 1.0279 L .807 .609 .05 r
F P
0 g
s
.43856 1.02094 m .43912 1.03185 L p .43898 1.0279 L .807 .609 .05 r
F P
0 g
s
.44262 1.04631 m .43807 1.03419 L .43928 1.03282 L p 0 0 .458 r
F P
0 g
s
.43912 1.03185 m .43758 1.03126 L p .43926 1.0358 L .898 .531 .334 r
F P
0 g
s
.4428 1.04408 m .43928 1.03282 L p .44064 1.0369 L .899 .55 .074 r
F P
0 g
s
.4428 1.04408 m .44262 1.04631 L p .44124 1.04073 L 0 0 .458 r
F P
0 g
s
.43928 1.03282 m .4428 1.04408 L p .44124 1.04073 L 0 0 .458 r
F P
0 g
s
.44906 1.05785 m .44262 1.04631 L .4428 1.04408 L p 0 0 .453 r
F P
0 g
s
.4428 1.04408 m .44166 1.04226 L p .44436 1.04745 L .82 .398 0 r
F P
0 g
s
.4482 1.05483 m .44906 1.05785 L p .44647 1.05216 L 0 0 .453 r
F P
0 g
s
.4428 1.04408 m .4482 1.05483 L p .44647 1.05216 L 0 0 .453 r
F P
0 g
s
.45725 1.06881 m .44906 1.05785 L .4482 1.05483 L p 0 0 .514 r
F P
0 g
s
.4482 1.05483 m .44611 1.05219 L p .44993 1.05751 L .699 .231 0 r
F P
0 g
s
.45537 1.06507 m .45725 1.06881 L p .4535 1.06303 L 0 0 .514 r
F P
0 g
s
.4482 1.05483 m .45537 1.06507 L p .4535 1.06303 L 0 0 .514 r
F P
0 g
s
.44611 1.05219 m .45238 1.0617 L .45537 1.06507 L p .699 .231 0 r
F P
0 g
s
.45537 1.06507 m .45238 1.0617 L p .45723 1.06713 L .566 .076 0 r
F P
0 g
s
.46413 1.07484 m .45537 1.06507 L p .45723 1.06713 L .566 .076 0 r
F P
0 g
s
.45537 1.06507 m .4482 1.05483 L p .44993 1.05751 L .699 .231 0 r
F P
0 g
s
.4482 1.05483 m .4428 1.04408 L p .44436 1.04745 L .82 .398 0 r
F P
0 g
s
.44166 1.04226 m .43912 1.03185 L p .43926 1.0358 L .898 .531 .334 r
F P
0 g
s
.43928 1.03282 m .43912 1.03185 L p .44064 1.0369 L .899 .55 .074 r
F P
0 g
s
.43795 1.02208 m .43798 1.02125 L p .43625 1.02339 L .704 .38 .425 r
F P
0 g
s
.43774 1.02103 m .43793 1.0225 L p .43777 1.02222 L .203 .124 .539 r
F P
0 g
s
.43601 1.02195 m .43625 1.02339 L .43753 1.02181 L .704 .38 .425 r
F
.43798 1.02125 m .43734 1.02148 L p .43753 1.02181 L F P
0 g
s
.43734 1.02148 m .43601 1.02195 L p .43753 1.02181 L .704 .38 .425 r
F P
0 g
s
.43776 1.02206 m .43777 1.02222 L .43583 1.02309 L .203 .124 .539 r
F
.43594 1.02363 m .43583 1.02309 L p .43777 1.02222 L F P
0 g
s
.43583 1.02309 m .43551 1.0215 L p .43776 1.02206 L .203 .124 .539 r
F P
0 g
s
.43289 1.02421 m .43299 1.02461 L .43587 1.02286 L .614 .252 .331 r
F
.43462 1.03105 m .43583 1.02309 L p .43299 1.02461 L F P
0 g
s
.43583 1.02309 m .43587 1.02286 L p .43299 1.02461 L .614 .252 .331 r
F P
0 g
s
.42111 .95767 m .417 .97515 L .4059 .97375 L p .743 .638 .744 r
F P
0 g
s
.62585 .65714 m .59756 .63918 L .60679 .62299 L p .582 .639 .872 r
F P
0 g
s
.60679 .62299 m .6392 .64245 L .62585 .65714 L p .582 .639 .872 r
F P
0 g
s
.47427 .87214 m .48954 .85657 L .49637 .86378 L p .833 .787 .808 r
F P
0 g
s
.49637 .86378 m .48216 .87895 L .47427 .87214 L p .833 .787 .808 r
F P
0 g
s
.55344 1.15799 m .53137 1.14987 L .52661 1.1411 L p .162 .513 .914 r
F P
0 g
s
.50664 1.13157 m .52661 1.1411 L .53137 1.14987 L p .22 .517 .914 r
F P
0 g
s
.42766 .9401 m .43649 .92259 L .44623 .92724 L p .796 .703 .762 r
F P
0 g
s
.45676 .91082 m .44623 .92724 L .43649 .92259 L p .808 .728 .777 r
F P
0 g
s
.4383 1.05212 m .43141 1.03824 L .43546 1.03599 L p .349 .33 .697 r
F P
0 g
s
.51764 .81985 m .53555 .8073 L .53791 .81543 L p .856 .853 .838 r
F P
0 g
s
.53791 .81543 m .52179 .8281 L .51764 .81985 L p .856 .853 .838 r
F P
0 g
s
.43649 .92259 m .4474 .90531 L .45676 .91082 L p .808 .728 .777 r
F P
0 g
s
.46884 .89468 m .45676 .91082 L .4474 .90531 L p .817 .75 .789 r
F P
0 g
s
.4601 .88844 m .47427 .87214 L .48216 .87895 L p .825 .769 .8 r
F P
0 g
s
.48216 .87895 m .46884 .89468 L .4601 .88844 L p .825 .769 .8 r
F P
0 g
s
.45656 1.08286 m .44441 1.06978 L .44718 1.06527 L p .239 .367 .792 r
F P
0 g
s
.4383 1.05212 m .44718 1.06527 L .44441 1.06978 L p .332 .38 .762 r
F P
0 g
s
.39185 1.03882 m .396 1.03574 L .38259 1.03793 L p .091 0 0 r
F P
0 g
s
.38259 1.03793 m .37727 1.03956 L .39185 1.03882 L p .091 0 0 r
F P
0 g
s
.48641 1.11313 m .46971 1.10149 L .47028 1.09502 L p .196 .429 .859 r
F P
0 g
s
.45656 1.08286 m .47028 1.09502 L .46971 1.10149 L p .26 .428 .84 r
F P
0 g
s
.4474 .90531 m .4601 .88844 L .46884 .89468 L p .817 .75 .789 r
F P
0 g
s
.59756 .63918 m .56715 .62399 L .57196 .60672 L p .564 .64 .884 r
F P
0 g
s
.53573 .59387 m .57196 .60672 L .56715 .62399 L p .546 .643 .897 r
F P
0 g
s
.40967 .95507 m .4059 .97375 L .39281 .9725 L p .731 .642 .76 r
F P
0 g
s
.4059 .97375 m .40967 .95507 L .42111 .95767 L p .743 .638 .744 r
F P
0 g
s
.42766 .9401 m .42111 .95767 L .40967 .95507 L p .766 .67 .757 r
F P
0 g
s
.57196 .60672 m .60679 .62299 L .59756 .63918 L p .564 .64 .884 r
F P
0 g
s
.44718 1.06527 m .4383 1.05212 L .44113 1.04898 L p .207 .288 .727 r
F P
0 g
s
.43546 1.03599 m .44113 1.04898 L .4383 1.05212 L p .349 .33 .697 r
F P
0 g
s
.39628 .95248 m .39281 .9725 L .37748 .97138 L p .723 .649 .775 r
F P
0 g
s
.39281 .9725 m .39628 .95248 L .40967 .95507 L p .731 .642 .76 r
F P
0 g
s
.52661 1.1411 m .50664 1.13157 L .50397 1.12368 L p .155 .476 .896 r
F P
0 g
s
.48641 1.11313 m .50397 1.12368 L .50664 1.13157 L p .213 .477 .89 r
F P
0 g
s
.44113 1.04898 m .43546 1.03599 L .43807 1.03419 L p .174 .192 .639 r
F P
0 g
s
.29078 .52648 m .33153 .51574 L .35686 .53912 L p .544 .715 .951 r
F P
0 g
s
.25334 1.03911 m .26093 1.04859 L .22623 1.05167 L p .467 .815 .998 r
F P
0 g
s
.22623 1.05167 m .21689 1.03915 L .25334 1.03911 L p .467 .815 .998 r
F P
0 g
s
.40421 1.03838 m .40729 1.034 L .396 1.03574 L p .264 0 0 r
F P
0 g
s
.396 1.03574 m .39185 1.03882 L .40421 1.03838 L p .264 0 0 r
F P
0 g
s
.40967 .95507 m .41617 .93633 L .42766 .9401 L p .766 .67 .757 r
F P
0 g
s
.43649 .92259 m .42766 .9401 L .41617 .93633 L p .783 .698 .771 r
F P
0 g
s
.49968 .83368 m .51764 .81985 L .52179 .8281 L p .845 .828 .831 r
F P
0 g
s
.52179 .8281 m .50552 .84185 L .49968 .83368 L p .845 .828 .831 r
F P
0 g
s
.47028 1.09502 m .45656 1.08286 L .45784 1.07763 L p .161 .366 .817 r
F P
0 g
s
.44718 1.06527 m .45784 1.07763 L .45656 1.08286 L p .239 .367 .792 r
F P
0 g
s
.38069 .94983 m .37748 .97138 L .35966 .97035 L p .716 .657 .791 r
F P
0 g
s
.37748 .97138 m .38069 .94983 L .39628 .95248 L p .723 .649 .775 r
F P
0 g
s
.53351 .79819 m .55307 .78732 L .55294 .7961 L p .855 .886 .86 r
F P
0 g
s
.55294 .7961 m .53555 .8073 L .53351 .79819 L p .855 .886 .86 r
F P
0 g
s
.4534 .55849 m .41448 .55711 L .39759 .53499 L p .539 .687 .935 r
F P
0 g
s
.35686 .53912 m .39759 .53499 L .41448 .55711 L p .531 .697 .945 r
F P
0 g
s
.61015 .74093 m .63285 .73834 L .62123 .74821 L p .756 .95 .941 r
F P
0 g
s
.62123 .74821 m .60143 .75213 L .61015 .74093 L p .756 .95 .941 r
F P
0 g
s
.41617 .93633 m .40967 .95507 L .39628 .95248 L p .754 .671 .77 r
F P
0 g
s
.43807 1.03419 m .44262 1.04631 L .44113 1.04898 L p .174 .192 .639 r
F P
0 g
s
.41617 .93633 m .42526 .91774 L .43649 .92259 L p .783 .698 .771 r
F P
0 g
s
.4474 .90531 m .43649 .92259 L .42526 .91774 L p .796 .723 .784 r
F P
0 g
s
.36263 .9471 m .35966 .97035 L .33901 .96941 L p .709 .666 .805 r
F P
0 g
s
.35966 .97035 m .36263 .9471 L .38069 .94983 L p .716 .657 .791 r
F P
0 g
s
.41457 1.03825 m .41665 1.03268 L .40729 1.034 L p .416 0 0 r
F P
0 g
s
.40729 1.034 m .40421 1.03838 L .41457 1.03825 L p .416 0 0 r
F P
0 g
s
.50397 1.12368 m .48641 1.11313 L .48522 1.10623 L p .138 .431 .87 r
F P
0 g
s
.47028 1.09502 m .48522 1.10623 L .48641 1.11313 L p .196 .429 .859 r
F P
0 g
s
.45784 1.07763 m .44718 1.06527 L .44872 1.06131 L p .096 .274 .756 r
F P
0 g
s
.44113 1.04898 m .44872 1.06131 L .44718 1.06527 L p .207 .288 .727 r
F P
0 g
s
.39759 .53499 m .35686 .53912 L .33153 .51574 L p .549 .705 .943 r
F P
0 g
s
.34174 .94423 m .33901 .96941 L .31517 .96854 L p .704 .675 .819 r
F P
0 g
s
.33901 .96941 m .34174 .94423 L .36263 .9471 L p .709 .666 .805 r
F P
0 g
s
.48216 .8487 m .49968 .83368 L .50552 .84185 L p .835 .806 .823 r
F P
0 g
s
.50552 .84185 m .48954 .85657 L .48216 .8487 L p .835 .806 .823 r
F P
0 g
s
.55384 .77737 m .57489 .76871 L .57161 .77806 L p .84 .919 .887 r
F P
0 g
s
.57161 .77806 m .55307 .78732 L .55384 .77737 L p .84 .919 .887 r
F P
0 g
s
.44872 1.06131 m .44113 1.04898 L .44262 1.04631 L p 0 .131 .655 r
F P
0 g
s
.57925 .75803 m .60143 .75213 L .59431 .76188 L p .807 .943 .915 r
F P
0 g
s
.59431 .76188 m .57489 .76871 L .57925 .75803 L p .807 .943 .915 r
F P
0 g
s
.42526 .91774 m .43672 .89948 L .4474 .90531 L p .796 .723 .784 r
F P
0 g
s
.4601 .88844 m .4474 .90531 L .43672 .89948 L p .807 .745 .795 r
F P
0 g
s
.42311 1.03842 m .42425 1.03175 L .41665 1.03268 L p .536 .048 .044 r
F P
0 g
s
.41665 1.03268 m .41457 1.03825 L .42311 1.03842 L p .536 .048 .044 r
F P
0 g
s
.2851 1.03919 m .29121 1.04599 L .26093 1.04859 L p .421 .807 .989 r
F P
0 g
s
.26093 1.04859 m .25334 1.03911 L .2851 1.03919 L p .421 .807 .989 r
F P
0 g
s
.31765 .94117 m .31517 .96854 L .28771 .96772 L p .699 .684 .832 r
F P
0 g
s
.31517 .96854 m .31765 .94117 L .34174 .94423 L p .704 .675 .819 r
F P
0 g
s
.40283 .93243 m .39628 .95248 L .38069 .94983 L p .744 .674 .783 r
F P
0 g
s
.39628 .95248 m .40283 .93243 L .41617 .93633 L p .754 .671 .77 r
F P
0 g
s
.42526 .91774 m .41617 .93633 L .40283 .93243 L p .771 .697 .781 r
F P
0 g
s
.46554 .86478 m .48216 .8487 L .48954 .85657 L p .825 .786 .815 r
F P
0 g
s
.48954 .85657 m .47427 .87214 L .46554 .86478 L p .825 .786 .815 r
F P
0 g
s
.43672 .89948 m .45026 .88176 L .4601 .88844 L p .807 .745 .795 r
F P
0 g
s
.47427 .87214 m .4601 .88844 L .45026 .88176 L p .816 .766 .806 r
F P
0 g
s
.43912 1.03185 m .44166 1.04226 L .4428 1.04408 L p .899 .55 .074 r
F P
0 g
s
.42998 1.0389 m .4302 1.03122 L .42425 1.03175 L p .631 .192 .187 r
F P
0 g
s
.42425 1.03175 m .42311 1.03842 L .42998 1.0389 L p .631 .192 .187 r
F P
0 g
s
.66829 .66481 m .6392 .64245 L .65501 .62548 L p .608 .653 .869 r
F P
0 g
s
.65501 .62548 m .68835 .65 L .66829 .66481 L p .608 .653 .869 r
F P
0 g
s
.45026 .88176 m .46554 .86478 L .47427 .87214 L p .816 .766 .806 r
F P
0 g
s
.28991 .93785 m .28771 .96772 L .25615 .96694 L p .695 .693 .844 r
F P
0 g
s
.28771 .96772 m .28991 .93785 L .31765 .94117 L p .699 .684 .832 r
F P
0 g
s
.73861 .68927 m .76571 .70054 L .73542 .71239 L p .658 .882 .981 r
F P
0 g
s
.73542 .71239 m .7117 .70419 L .73861 .68927 L p .658 .882 .981 r
F P
0 g
s
.66308 .71377 m .68867 .71707 L .66901 .72819 L p .696 .919 .969 r
F P
0 g
s
.66901 .72819 m .64669 .72694 L .66308 .71377 L p .696 .919 .969 r
F P
0 g
s
.43758 1.03126 m .43918 1.0408 L .44166 1.04226 L p .898 .531 .334 r
F P
0 g
s
.43918 1.0408 m .43758 1.03126 L .43462 1.03105 L p .797 .424 .349 r
F P
0 g
s
.43531 1.03969 m .43462 1.03105 L .4302 1.03122 L p .713 .314 .29 r
F P
0 g
s
.4302 1.03122 m .42998 1.0389 L .43531 1.03969 L p .713 .314 .29 r
F P
0 g
s
.53573 .59387 m .49915 .58455 L .49441 .56383 L p .546 .662 .912 r
F P
0 g
s
.4534 .55849 m .49441 .56383 L .49915 .58455 L p .533 .668 .924 r
F P
0 g
s
.48522 1.10623 m .47028 1.09502 L .47002 1.0892 L p .1 .371 .834 r
F P
0 g
s
.45784 1.07763 m .47002 1.0892 L .47028 1.09502 L p .161 .366 .817 r
F P
0 g
s
.43462 1.03105 m .43531 1.03969 L .43918 1.0408 L p .797 .424 .349 r
F P
0 g
s
.77098 .69592 m .74461 .66309 L .77687 .64656 L p .644 .682 .871 r
F P
0 g
s
.77687 .64656 m .80691 .68309 L .77098 .69592 L p .644 .682 .871 r
F P
0 g
s
.258 .93423 m .25615 .96694 L .21991 .96619 L p .69 .701 .855 r
F P
0 g
s
.25615 .96694 m .258 .93423 L .28991 .93785 L p .695 .693 .844 r
F P
0 g
s
.51346 .81064 m .53351 .79819 L .53555 .8073 L p .846 .856 .851 r
F P
0 g
s
.53555 .8073 m .51764 .81985 L .51346 .81064 L p .846 .856 .851 r
F P
0 g
s
.44262 1.04631 m .44906 1.05785 L .44872 1.06131 L p 0 .131 .655 r
F P
0 g
s
.55344 1.15799 m .57482 1.16478 L .58475 1.17378 L p .165 .548 .928 r
F P
0 g
s
.57482 1.16478 m .55344 1.15799 L .54648 1.14942 L p .098 .504 .904 r
F P
0 g
s
.52661 1.1411 m .54648 1.14942 L .55344 1.15799 L p .162 .513 .914 r
F P
0 g
s
.2213 .93022 m .21991 .96619 L .17834 .96544 L p .686 .708 .865 r
F P
0 g
s
.21991 .96619 m .2213 .93022 L .258 .93423 L p .69 .701 .855 r
F P
0 g
s
.31273 1.03939 m .31757 1.04382 L .29121 1.04599 L p .358 .789 .969 r
F P
0 g
s
.29121 1.04599 m .2851 1.03919 L .31273 1.03939 L p .358 .789 .969 r
F P
0 g
s
.47002 1.0892 m .45784 1.07763 L .45807 1.07297 L p .023 .282 .779 r
F P
0 g
s
.44872 1.06131 m .45807 1.07297 L .45784 1.07763 L p .096 .274 .756 r
F P
0 g
s
.38739 .9283 m .38069 .94983 L .36263 .9471 L p .735 .679 .796 r
F P
0 g
s
.38069 .94983 m .38739 .9283 L .40283 .93243 L p .744 .674 .783 r
F P
0 g
s
.40283 .93243 m .41233 .91259 L .42526 .91774 L p .771 .697 .781 r
F P
0 g
s
.43672 .89948 m .42526 .91774 L .41233 .91259 L p .785 .721 .792 r
F P
0 g
s
.45807 1.07297 m .44872 1.06131 L .44906 1.05785 L p 0 .135 .68 r
F P
0 g
s
.54648 1.14942 m .52661 1.1411 L .52196 1.13315 L p .095 .47 .892 r
F P
0 g
s
.50397 1.12368 m .52196 1.13315 L .52661 1.1411 L p .155 .476 .896 r
F P
0 g
s
.17834 .96544 m .17912 .92577 L .2213 .93022 L p .686 .708 .865 r
F P
0 g
s
.71694 .67735 m .68835 .65 L .71188 .63284 L p .628 .668 .869 r
F P
0 g
s
.71188 .63284 m .74461 .66309 L .71694 .67735 L p .628 .668 .869 r
F P
0 g
s
.41233 .91259 m .40283 .93243 L .38739 .9283 L p .761 .698 .792 r
F P
0 g
s
.33672 1.03971 m .34045 1.04204 L .31757 1.04382 L p .271 .752 .928 r
F P
0 g
s
.31757 1.04382 m .31273 1.03939 L .33672 1.03971 L p .271 .752 .928 r
F P
0 g
s
.52196 1.13315 m .50397 1.12368 L .50104 1.11652 L p .083 .43 .872 r
F P
0 g
s
.48522 1.10623 m .50104 1.11652 L .50397 1.12368 L p .138 .431 .87 r
F P
0 g
s
.49347 .82462 m .51346 .81064 L .51764 .81985 L p .836 .83 .841 r
F P
0 g
s
.51764 .81985 m .49968 .83368 L .49347 .82462 L p .836 .83 .841 r
F P
0 g
s
.41233 .91259 m .42454 .89321 L .43672 .89948 L p .785 .721 .792 r
F P
0 g
s
.45026 .88176 m .43672 .89948 L .42454 .89321 L p .797 .743 .803 r
F P
0 g
s
.53173 .7879 m .55384 .77737 L .55307 .78732 L p .839 .886 .874 r
F P
0 g
s
.55307 .78732 m .53351 .79819 L .53173 .7879 L p .839 .886 .874 r
F P
0 g
s
.36955 .92389 m .36263 .9471 L .34174 .94423 L p .728 .686 .809 r
F P
0 g
s
.36263 .9471 m .36955 .92389 L .38739 .9283 L p .735 .679 .796 r
F P
0 g
s
.50104 1.11652 m .48522 1.10623 L .48345 1.09998 L p .05 .377 .843 r
F P
0 g
s
.47002 1.0892 m .48345 1.09998 L .48522 1.10623 L p .1 .371 .834 r
F P
0 g
s
.44166 1.04226 m .44611 1.05219 L .4482 1.05483 L p .82 .398 0 r
F P
0 g
s
.44611 1.05219 m .44166 1.04226 L .43918 1.0408 L p .875 .439 .142 r
F P
0 g
s
.6392 .64245 m .60679 .62299 L .61782 .60428 L p .591 .652 .879 r
F P
0 g
s
.61782 .60428 m .65501 .62548 L .6392 .64245 L p .591 .652 .879 r
F P
0 g
s
.62068 .72802 m .64669 .72694 L .63285 .73834 L p .743 .931 .951 r
F P
0 g
s
.63285 .73834 m .61015 .74093 L .62068 .72802 L p .743 .931 .951 r
F P
0 g
s
.35749 1.04016 m .36024 1.04063 L .34045 1.04204 L p .156 .688 .855 r
F P
0 g
s
.34045 1.04204 m .33672 1.03971 L .35749 1.04016 L p .156 .688 .855 r
F P
0 g
s
.44906 1.05785 m .45725 1.06881 L .45807 1.07297 L p 0 .135 .68 r
F P
0 g
s
.42454 .89321 m .43916 .87451 L .45026 .88176 L p .797 .743 .803 r
F P
0 g
s
.46554 .86478 m .45026 .88176 L .43916 .87451 L p .807 .764 .813 r
F P
0 g
s
.57196 .60672 m .53573 .59387 L .53632 .57326 L p .56 .657 .9 r
F P
0 g
s
.49441 .56383 m .53632 .57326 L .53573 .59387 L p .546 .662 .912 r
F P
0 g
s
.47409 .84003 m .49347 .82462 L .49968 .83368 L p .826 .806 .832 r
F P
0 g
s
.49968 .83368 m .48216 .8487 L .47409 .84003 L p .826 .806 .832 r
F P
0 g
s
.48345 1.09998 m .47002 1.0892 L .46893 1.08396 L p 0 .3 .795 r
F P
0 g
s
.45807 1.07297 m .46893 1.08396 L .47002 1.0892 L p .023 .282 .779 r
F P
0 g
s
.46893 1.08396 m .45807 1.07297 L .45725 1.06881 L p 0 .172 .709 r
F P
0 g
s
.43918 1.0408 m .44275 1.0499 L .44611 1.05219 L p .875 .439 .142 r
F P
0 g
s
.44275 1.0499 m .43918 1.0408 L .43531 1.03969 L p .819 .382 .201 r
F P
0 g
s
.43916 .87451 m .45582 .85672 L .46554 .86478 L p .807 .764 .813 r
F P
0 g
s
.48216 .8487 m .46554 .86478 L .45582 .85672 L p .817 .785 .823 r
F P
0 g
s
.55529 .76605 m .57925 .75803 L .57489 .76871 L p .82 .912 .901 r
F P
0 g
s
.57489 .76871 m .55384 .77737 L .55529 .76605 L p .82 .912 .901 r
F P
0 g
s
.45582 .85672 m .47409 .84003 L .48216 .8487 L p .817 .785 .823 r
F P
0 g
s
.38739 .9283 m .39743 .90706 L .41233 .91259 L p .761 .698 .792 r
F P
0 g
s
.42454 .89321 m .41233 .91259 L .39743 .90706 L p .775 .721 .802 r
F P
0 g
s
.39743 .90706 m .38739 .9283 L .36955 .92389 L p .752 .701 .804 r
F P
0 g
s
.34897 .9191 m .34174 .94423 L .31765 .94117 L p .721 .692 .822 r
F P
0 g
s
.34174 .94423 m .34897 .9191 L .36955 .92389 L p .728 .686 .809 r
F P
0 g
s
.5848 .74579 m .61015 .74093 L .60143 .75213 L p .787 .928 .928 r
F P
0 g
s
.60143 .75213 m .57925 .75803 L .5848 .74579 L p .787 .928 .928 r
F P
0 g
s
.43531 1.03969 m .43807 1.04791 L .44275 1.0499 L p .819 .382 .201 r
F P
0 g
s
.43807 1.04791 m .43531 1.03969 L .42998 1.0389 L p .749 .296 .174 r
F P
0 g
s
.39081 1.04149 m .39185 1.03882 L .37727 1.03956 L p .157 0 0 r
F P
0 g
s
.37727 1.03956 m .37542 1.04075 L .39081 1.04149 L p .157 0 0 r
F P
0 g
s
.60679 .62299 m .57196 .60672 L .57787 .58679 L p .576 .653 .889 r
F P
0 g
s
.57787 .58679 m .61782 .60428 L .60679 .62299 L p .576 .653 .889 r
F P
0 g
s
.53632 .57326 m .57787 .58679 L .57196 .60672 L p .56 .657 .9 r
F P
0 g
s
.49441 .56383 m .4534 .55849 L .44211 .53513 L p .549 .679 .924 r
F P
0 g
s
.39759 .53499 m .44211 .53513 L .4534 .55849 L p .539 .687 .935 r
F P
0 g
s
.42998 1.0389 m .43197 1.04619 L .43807 1.04791 L p .749 .296 .174 r
F P
0 g
s
.43197 1.04619 m .42998 1.0389 L .42311 1.03842 L p .673 .189 .093 r
F P
0 g
s
.40395 1.04238 m .40421 1.03838 L .39185 1.03882 L p .322 0 0 r
F P
0 g
s
.39185 1.03882 m .39081 1.04149 L .40395 1.04238 L p .322 0 0 r
F P
0 g
s
.50917 .8003 m .53173 .7879 L .53351 .79819 L p .833 .856 .863 r
F P
0 g
s
.53351 .79819 m .51346 .81064 L .50917 .8003 L p .833 .856 .863 r
F P
0 g
s
.42311 1.03842 m .42434 1.04471 L .43197 1.04619 L p .673 .189 .093 r
F P
0 g
s
.42434 1.04471 m .42311 1.03842 L .41457 1.03825 L p .581 .059 0 r
F P
0 g
s
.41506 1.04345 m .41457 1.03825 L .40421 1.03838 L p .466 0 0 r
F P
0 g
s
.40421 1.03838 m .40395 1.04238 L .41506 1.04345 L p .466 0 0 r
F P
0 g
s
.41457 1.03825 m .41506 1.04345 L .42434 1.04471 L p .581 .059 0 r
F P
0 g
s
.68237 .69853 m .7117 .70419 L .68867 .71707 L p .692 .9 .971 r
F P
0 g
s
.68867 .71707 m .66308 .71377 L .68237 .69853 L p .692 .9 .971 r
F P
0 g
s
.39743 .90706 m .4106 .88639 L .42454 .89321 L p .775 .721 .802 r
F P
0 g
s
.43916 .87451 m .42454 .89321 L .4106 .88639 L p .787 .743 .812 r
F P
0 g
s
.32527 .91385 m .31765 .94117 L .28991 .93785 L p .715 .699 .834 r
F P
0 g
s
.31765 .94117 m .32527 .91385 L .34897 .9191 L p .721 .692 .822 r
F P
0 g
s
.54648 1.14942 m .5658 1.15661 L .57482 1.16478 L p .098 .504 .904 r
F P
0 g
s
.5658 1.15661 m .54648 1.14942 L .53997 1.14161 L p .029 .457 .875 r
F P
0 g
s
.52196 1.13315 m .53997 1.14161 L .54648 1.14942 L p .095 .47 .892 r
F P
0 g
s
.77002 .67196 m .80093 .68679 L .76571 .70054 L p .66 .867 .978 r
F P
0 g
s
.76571 .70054 m .73861 .68927 L .77002 .67196 L p .66 .867 .978 r
F P
0 g
s
.53997 1.14161 m .52196 1.13315 L .51736 1.12591 L p .025 .423 .864 r
F P
0 g
s
.50104 1.11652 m .51736 1.12591 L .52196 1.13315 L p .083 .43 .872 r
F P
0 g
s
.45725 1.06881 m .46698 1.0792 L .46893 1.08396 L p 0 .172 .709 r
F P
0 g
s
.46698 1.0792 m .45725 1.06881 L .45537 1.06507 L p 0 .041 .588 r
F P
0 g
s
.51736 1.12591 m .50104 1.11652 L .4978 1.10998 L p .004 .38 .842 r
F P
0 g
s
.48345 1.09998 m .4978 1.10998 L .50104 1.11652 L p .05 .377 .843 r
F P
0 g
s
.45238 1.0617 m .44611 1.05219 L .44275 1.0499 L p .792 .298 0 r
F P
0 g
s
.3803 .90104 m .36955 .92389 L .34897 .9191 L p .744 .705 .815 r
F P
0 g
s
.36955 .92389 m .3803 .90104 L .39743 .90706 L p .752 .701 .804 r
F P
0 g
s
.46893 1.08396 m .48107 1.09428 L .48345 1.09998 L p 0 .3 .795 r
F P
0 g
s
.48107 1.09428 m .46893 1.08396 L .46698 1.0792 L p 0 .216 .736 r
F P
0 g
s
.4978 1.10998 m .48345 1.09998 L .48107 1.09428 L p 0 .317 .805 r
F P
0 g
s
.4106 .88639 m .39743 .90706 L .3803 .90104 L p .766 .722 .812 r
F P
0 g
s
.48677 .8145 m .50917 .8003 L .51346 .81064 L p .825 .83 .852 r
F P
0 g
s
.51346 .81064 m .49347 .82462 L .48677 .8145 L p .825 .83 .852 r
F P
0 g
s
.68835 .65 m .65501 .62548 L .67364 .60582 L p .614 .665 .876 r
F P
0 g
s
.67364 .60582 m .71188 .63284 L .68835 .65 L p .614 .665 .876 r
F P
0 g
s
.4106 .88639 m .42655 .86655 L .43916 .87451 L p .787 .743 .812 r
F P
0 g
s
.45582 .85672 m .43916 .87451 L .42655 .86655 L p .798 .764 .822 r
F P
0 g
s
.53021 .77624 m .55529 .76605 L .55384 .77737 L p .823 .882 .887 r
F P
0 g
s
.55384 .77737 m .53173 .7879 L .53021 .77624 L p .823 .882 .887 r
F P
0 g
s
.29796 .90804 m .28991 .93785 L .258 .93423 L p .709 .706 .845 r
F P
0 g
s
.28991 .93785 m .29796 .90804 L .32527 .91385 L p .715 .699 .834 r
F P
0 g
s
.44275 1.0499 m .44823 1.05863 L .45238 1.0617 L p .792 .298 0 r
F P
0 g
s
.44823 1.05863 m .44275 1.0499 L .43807 1.04791 L p .781 .282 .001 r
F P
0 g
s
.46515 .83039 m .48677 .8145 L .49347 .82462 L p .817 .806 .841 r
F P
0 g
s
.49347 .82462 m .47409 .84003 L .46515 .83039 L p .817 .806 .841 r
F P
0 g
s
.42655 .86655 m .4449 .8478 L .45582 .85672 L p .798 .764 .822 r
F P
0 g
s
.47409 .84003 m .45582 .85672 L .4449 .8478 L p .807 .785 .831 r
F P
0 g
s
.45537 1.06507 m .46413 1.07484 L p .46218 1.07335 L 0 .041 .588 r
F P
0 g
s
.46033 1.07081 m .46413 1.07484 L p .45927 1.0694 L .566 .076 0 r
F P
0 g
s
.45238 1.0617 m .46033 1.07081 L p .45927 1.0694 L .566 .076 0 r
F P
0 g
s
.46033 1.07081 m .45549 1.06704 L p .46139 1.07222 L .527 0 0 r
F P
0 g
s
.46413 1.07484 m .46033 1.07081 L p .4661 1.07633 L 0 .051 .553 r
F P
0 g
s
.46977 1.07959 m .47429 1.08417 L p .46851 1.07864 L 0 .051 .553 r
F P
0 g
s
.46033 1.07081 m .46977 1.07959 L p .46851 1.07864 L 0 .051 .553 r
F P
0 g
s
.47429 1.08417 m .46413 1.07484 L p .4661 1.07633 L 0 .051 .553 r
F P
0 g
s
.47804 1.08904 m .46698 1.0792 L .46413 1.07484 L p 0 .128 .651 r
F P
0 g
s
.46413 1.07484 m .47429 1.08417 L .47804 1.08904 L p 0 .128 .651 r
F P
0 g
s
.46437 1.07522 m .46977 1.07959 L p .46386 1.07439 L .527 0 0 r
F P
0 g
s
.45549 1.06704 m .46437 1.07522 L p .46386 1.07439 L .527 0 0 r
F P
0 g
s
.46413 1.07484 m .46698 1.0792 L p .46218 1.07335 L 0 .041 .588 r
F P
0 g
s
.46437 1.07522 m .45801 1.07098 L p .46489 1.07605 L .43 0 0 r
F P
0 g
s
.46977 1.07959 m .46437 1.07522 L p .47103 1.08054 L 0 .117 .587 r
F P
0 g
s
.46977 1.07959 m .46033 1.07081 L p .46139 1.07222 L .527 0 0 r
F P
0 g
s
.48561 1.09312 m .47429 1.08417 L .46977 1.07959 L p 0 .145 .636 r
F P
0 g
s
.46977 1.07959 m .48048 1.0881 L .48561 1.09312 L p 0 .145 .636 r
F P
0 g
s
.47466 1.08324 m .48048 1.0881 L p .47381 1.08277 L 0 .117 .587 r
F P
0 g
s
.46437 1.07522 m .47466 1.08324 L p .47381 1.08277 L 0 .117 .587 r
F P
0 g
s
.47466 1.08324 m .46437 1.07522 L p .46489 1.07605 L .43 0 0 r
F P
0 g
s
.47466 1.08324 m .46806 1.07844 L p .47552 1.08371 L 0 .2 .656 r
F P
0 g
s
.48612 1.09119 m .47466 1.08324 L p .47552 1.08371 L 0 .2 .656 r
F P
0 g
s
.48048 1.0881 m .46977 1.07959 L p .47103 1.08054 L 0 .117 .587 r
F P
0 g
s
.44211 .53513 m .39759 .53499 L .37809 .50941 L p .555 .696 .934 r
F P
0 g
s
.33153 .51574 m .37809 .50941 L .39759 .53499 L p .549 .705 .943 r
F P
0 g
s
.4449 .8478 m .46515 .83039 L .47409 .84003 L p .807 .785 .831 r
F P
0 g
s
.74461 .66309 m .71188 .63284 L .73943 .61293 L p .632 .678 .876 r
F P
0 g
s
.73943 .61293 m .77687 .64656 L .74461 .66309 L p .632 .678 .876 r
F P
0 g
s
.63325 .71313 m .66308 .71377 L .64669 .72694 L p .731 .912 .956 r
F P
0 g
s
.64669 .72694 m .62068 .72802 L .63325 .71313 L p .731 .912 .956 r
F P
0 g
s
.43807 1.04791 m .44284 1.05581 L .44823 1.05863 L p .781 .282 .001 r
F P
0 g
s
.44284 1.05581 m .43807 1.04791 L .43197 1.04619 L p .732 .221 0 r
F P
0 g
s
.36058 .89441 m .34897 .9191 L .32527 .91385 L p .736 .71 .827 r
F P
0 g
s
.34897 .9191 m .36058 .89441 L .3803 .90104 L p .744 .705 .815 r
F P
0 g
s
.55746 .7531 m .5848 .74579 L .57925 .75803 L p .802 .902 .912 r
F P
0 g
s
.57925 .75803 m .55529 .76605 L .55746 .7531 L p .802 .902 .912 r
F P
0 g
s
.3803 .90104 m .39463 .87887 L .4106 .88639 L p .766 .722 .812 r
F P
0 g
s
.42655 .86655 m .4106 .88639 L .39463 .87887 L p .778 .743 .821 r
F P
0 g
s
.46698 1.0792 m .47804 1.08904 L .48107 1.09428 L p 0 .216 .736 r
F P
0 g
s
.26653 .90155 m .258 .93423 L .2213 .93022 L p .703 .713 .856 r
F P
0 g
s
.258 .93423 m .26653 .90155 L .29796 .90804 L p .709 .706 .845 r
F P
0 g
s
.59165 .73172 m .62068 .72802 L .61015 .74093 L p .77 .913 .936 r
F P
0 g
s
.61015 .74093 m .5848 .74579 L .59165 .73172 L p .77 .913 .936 r
F P
0 g
s
.53632 .57326 m .49441 .56383 L .48915 .53988 L p .56 .673 .914 r
F P
0 g
s
.44211 .53513 m .48915 .53988 L .49441 .56383 L p .549 .679 .924 r
F P
0 g
s
.43197 1.04619 m .43612 1.0532 L .44284 1.05581 L p .732 .221 0 r
F P
0 g
s
.43612 1.0532 m .43197 1.04619 L .42434 1.04471 L p .663 .13 0 r
F P
0 g
s
.48107 1.09428 m .49419 1.10397 L .4978 1.10998 L p 0 .317 .805 r
F P
0 g
s
.49419 1.10397 m .48107 1.09428 L .47804 1.08904 L p 0 .254 .756 r
F P
0 g
s
.39463 .87887 m .3803 .90104 L .36058 .89441 L p .757 .725 .823 r
F P
0 g
s
.4978 1.10998 m .51273 1.11925 L .51736 1.12591 L p .004 .38 .842 r
F P
0 g
s
.51273 1.11925 m .4978 1.10998 L .49419 1.10397 L p 0 .329 .806 r
F P
0 g
s
.46033 1.07081 m .45238 1.0617 L .44823 1.05863 L p .665 .139 0 r
F P
0 g
s
.51736 1.12591 m .53381 1.13446 L .53997 1.14161 L p .025 .423 .864 r
F P
0 g
s
.53381 1.13446 m .51736 1.12591 L .51273 1.11925 L p 0 .376 .832 r
F P
0 g
s
.50469 .78861 m .53021 .77624 L .53173 .7879 L p .82 .854 .874 r
F P
0 g
s
.53173 .7879 m .50917 .8003 L .50469 .78861 L p .82 .854 .874 r
F P
0 g
s
.53997 1.14161 m .55757 1.14914 L .5658 1.15661 L p .029 .457 .875 r
F P
0 g
s
.55757 1.14914 m .53997 1.14161 L .53381 1.13446 L p 0 .408 .843 r
F P
0 g
s
.42434 1.04471 m .42793 1.05076 L .43612 1.0532 L p .663 .13 0 r
F P
0 g
s
.42793 1.05076 m .42434 1.04471 L .41506 1.04345 L p .575 .014 0 r
F P
0 g
s
.65501 .62548 m .61782 .60428 L .63093 .58261 L p .599 .664 .884 r
F P
0 g
s
.63093 .58261 m .67364 .60582 L .65501 .62548 L p .599 .664 .884 r
F P
0 g
s
.39463 .87887 m .4122 .85771 L .42655 .86655 L p .778 .743 .821 r
F P
0 g
s
.4449 .8478 m .42655 .86655 L .4122 .85771 L p .788 .764 .831 r
F P
0 g
s
.41506 1.04345 m .41814 1.04843 L .42793 1.05076 L p .575 .014 0 r
F P
0 g
s
.41814 1.04843 m .41506 1.04345 L .40395 1.04238 L p .463 0 0 r
F P
0 g
s
.23034 .89425 m .2213 .93022 L .17912 .92577 L p .698 .719 .865 r
F P
0 g
s
.2213 .93022 m .23034 .89425 L .26653 .90155 L p .703 .713 .856 r
F P
0 g
s
.33789 .88704 m .32527 .91385 L .29796 .90804 L p .729 .715 .838 r
F P
0 g
s
.32527 .91385 m .33789 .88704 L .36058 .89441 L p .736 .71 .827 r
F P
0 g
s
.44823 1.05863 m .45549 1.06704 L .46033 1.07081 L p .665 .139 0 r
F P
0 g
s
.45549 1.06704 m .44823 1.05863 L .44284 1.05581 L p .686 .144 0 r
F P
0 g
s
.70502 .68088 m .73861 .68927 L .7117 .70419 L p .688 .883 .971 r
F P
0 g
s
.7117 .70419 m .68237 .69853 L .70502 .68088 L p .688 .883 .971 r
F P
0 g
s
.40395 1.04238 m .40655 1.04618 L .41814 1.04843 L p .463 0 0 r
F P
0 g
s
.40655 1.04618 m .40395 1.04238 L .39081 1.04149 L p .325 0 0 r
F P
0 g
s
.47944 .80309 m .50469 .78861 L .50917 .8003 L p .814 .829 .862 r
F P
0 g
s
.50917 .8003 m .48677 .8145 L .47944 .80309 L p .814 .829 .862 r
F P
0 g
s
.39081 1.04149 m .39297 1.04396 L .40655 1.04618 L p .325 0 0 r
F P
0 g
s
.39297 1.04396 m .39081 1.04149 L .37542 1.04075 L p .17 0 0 r
F P
0 g
s
.4122 .85771 m .43256 .83785 L .4449 .8478 L p .788 .764 .831 r
F P
0 g
s
.46515 .83039 m .4449 .8478 L .43256 .83785 L p .798 .784 .84 r
F P
0 g
s
.37542 1.04075 m .37713 1.04175 L .39297 1.04396 L p .17 0 0 r
F P
0 g
s
.57787 .58679 m .53632 .57326 L .53727 .5494 L p .572 .668 .904 r
F P
0 g
s
.48915 .53988 m .53727 .5494 L .53632 .57326 L p .56 .673 .914 r
F P
0 g
s
.47804 1.08904 m .49015 1.09838 L .49419 1.10397 L p 0 .254 .756 r
F P
0 g
s
.49015 1.09838 m .47804 1.08904 L .47429 1.08417 L p 0 .193 .697 r
F P
0 g
s
.45518 .81957 m .47944 .80309 L .48677 .8145 L p .806 .806 .851 r
F P
0 g
s
.48677 .8145 m .46515 .83039 L .45518 .81957 L p .806 .806 .851 r
F P
0 g
s
.35749 1.04016 m .35876 1.03949 L .37713 1.04175 L p 0 .559 .767 r
F P
0 g
s
.35876 1.03949 m .35749 1.04016 L .33672 1.03971 L p .125 .656 .867 r
F P
0 g
s
.5289 .76294 m .55746 .7531 L .55529 .76605 L p .806 .875 .897 r
F P
0 g
s
.55529 .76605 m .53021 .77624 L .5289 .76294 L p .806 .875 .897 r
F P
0 g
s
.36058 .89441 m .37631 .87053 L .39463 .87887 L p .757 .725 .823 r
F P
0 g
s
.4122 .85771 m .39463 .87887 L .37631 .87053 L p .769 .745 .831 r
F P
0 g
s
.43256 .83785 m .45518 .81957 L .46515 .83039 L p .798 .784 .84 r
F P
0 g
s
.61782 .60428 m .57787 .58679 L .58502 .5637 L p .586 .665 .894 r
F P
0 g
s
.58502 .5637 m .63093 .58261 L .61782 .60428 L p .586 .665 .894 r
F P
0 g
s
.33672 1.03971 m .33752 1.03716 L .35876 1.03949 L p .125 .656 .867 r
F P
0 g
s
.33752 1.03716 m .33672 1.03971 L .31273 1.03939 L p .238 .72 .932 r
F P
0 g
s
.44284 1.05581 m .44954 1.06347 L .45549 1.06704 L p .686 .144 0 r
F P
0 g
s
.44954 1.06347 m .44284 1.05581 L .43612 1.0532 L p .66 .105 0 r
F P
0 g
s
.37631 .87053 m .36058 .89441 L .33789 .88704 L p .749 .728 .833 r
F P
0 g
s
.49419 1.10397 m .50798 1.11307 L .51273 1.11925 L p 0 .329 .806 r
F P
0 g
s
.50798 1.11307 m .49419 1.10397 L .49015 1.09838 L p 0 .28 .766 r
F P
0 g
s
.31273 1.03939 m .31301 1.0347 L .33752 1.03716 L p .238 .72 .932 r
F P
0 g
s
.31301 1.0347 m .31273 1.03939 L .2851 1.03919 L p .326 .76 .969 r
F P
0 g
s
.21497 1.02611 m .21689 1.03915 L .17511 1.0393 L p .479 .8 1 r
F P
0 g
s
.17511 1.0393 m .1721 1.02266 L .21497 1.02611 L p .479 .8 1 r
F P
0 g
s
.2851 1.03919 m .28478 1.03207 L .31301 1.0347 L p .326 .76 .969 r
F P
0 g
s
.28478 1.03207 m .2851 1.03919 L .25334 1.03911 L p .392 .782 .989 r
F P
0 g
s
.2523 1.02922 m .25334 1.03911 L .21689 1.03915 L p .442 .794 .997 r
F P
0 g
s
.21689 1.03915 m .21497 1.02611 L .2523 1.02922 L p .442 .794 .997 r
F P
0 g
s
.25334 1.03911 m .2523 1.02922 L .28478 1.03207 L p .392 .782 .989 r
F P
0 g
s
.17912 .92577 m .18867 .886 L .23034 .89425 L p .698 .719 .865 r
F P
0 g
s
.53727 .5494 m .58502 .5637 L .57787 .58679 L p .572 .668 .904 r
F P
0 g
s
.51273 1.11925 m .52788 1.12784 L .53381 1.13446 L p 0 .376 .832 r
F P
0 g
s
.52788 1.12784 m .51273 1.11925 L .50798 1.11307 L p 0 .331 .798 r
F P
0 g
s
.53381 1.13446 m .54997 1.14225 L .55757 1.14914 L p 0 .408 .843 r
F P
0 g
s
.54997 1.14225 m .53381 1.13446 L .52788 1.12784 L p 0 .361 .809 r
F P
0 g
s
.31177 .87879 m .29796 .90804 L .26653 .90155 L p .722 .721 .849 r
F P
0 g
s
.29796 .90804 m .31177 .87879 L .33789 .88704 L p .729 .715 .838 r
F P
0 g
s
.43612 1.0532 m .44236 1.06004 L .44954 1.06347 L p .66 .105 0 r
F P
0 g
s
.44236 1.06004 m .43612 1.0532 L .42793 1.05076 L p .603 .032 0 r
F P
0 g
s
.64816 .69592 m .68237 .69853 L .66308 .71377 L p .72 .894 .959 r
F P
0 g
s
.66308 .71377 m .63325 .71313 L .64816 .69592 L p .72 .894 .959 r
F P
0 g
s
.71188 .63284 m .67364 .60582 L .69555 .58298 L p .619 .676 .882 r
F P
0 g
s
.69555 .58298 m .73943 .61293 L .71188 .63284 L p .619 .676 .882 r
F P
0 g
s
.56039 .73825 m .59165 .73172 L .5848 .74579 L p .784 .891 .921 r
F P
0 g
s
.5848 .74579 m .55746 .7531 L .56039 .73825 L p .784 .891 .921 r
F P
0 g
s
.48915 .53988 m .44211 .53513 L .42917 .50805 L p .563 .689 .925 r
F P
0 g
s
.37809 .50941 m .42917 .50805 L .44211 .53513 L p .555 .696 .934 r
F P
0 g
s
.47429 1.08417 m .48561 1.09312 L .49015 1.09838 L p 0 .193 .697 r
F P
0 g
s
.37631 .87053 m .3958 .84783 L .4122 .85771 L p .769 .745 .831 r
F P
0 g
s
.43256 .83785 m .4122 .85771 L .3958 .84783 L p .779 .764 .84 r
F P
0 g
s
.59998 .71551 m .63325 .71313 L .62068 .72802 L p .754 .897 .942 r
F P
0 g
s
.62068 .72802 m .59165 .73172 L .59998 .71551 L p .754 .897 .942 r
F P
0 g
s
.49992 .77532 m .5289 .76294 L .53021 .77624 L p .805 .85 .883 r
F P
0 g
s
.53021 .77624 m .50469 .78861 L .49992 .77532 L p .805 .85 .883 r
F P
0 g
s
.46437 1.07522 m .45549 1.06704 L .44954 1.06347 L p .558 .003 0 r
F P
0 g
s
.42793 1.05076 m .43383 1.05668 L .44236 1.06004 L p .603 .032 0 r
F P
0 g
s
.43383 1.05668 m .42793 1.05076 L .41814 1.04843 L p .521 0 0 r
F P
0 g
s
.49015 1.09838 m .50304 1.10728 L .50798 1.11307 L p 0 .28 .766 r
F P
0 g
s
.50304 1.10728 m .49015 1.09838 L .48561 1.09312 L p 0 .238 .725 r
F P
0 g
s
.35528 .86118 m .33789 .88704 L .31177 .87879 L p .741 .732 .843 r
F P
0 g
s
.33789 .88704 m .35528 .86118 L .37631 .87053 L p .749 .728 .833 r
F P
0 g
s
.3958 .84783 m .37631 .87053 L .35528 .86118 L p .76 .746 .841 r
F P
0 g
s
.41814 1.04843 m .42377 1.05334 L .43383 1.05668 L p .521 0 0 r
F P
0 g
s
.42377 1.05334 m .41814 1.04843 L .40655 1.04618 L p .414 0 0 r
F P
0 g
s
.50798 1.11307 m .52211 1.12165 L .52788 1.12784 L p 0 .331 .798 r
F P
0 g
s
.52211 1.12165 m .50798 1.11307 L .50304 1.10728 L p 0 .292 .765 r
F P
0 g
s
.3958 .84783 m .41855 .82667 L .43256 .83785 L p .779 .764 .84 r
F P
0 g
s
.45518 .81957 m .43256 .83785 L .41855 .82667 L p .788 .784 .849 r
F P
0 g
s
.47134 .79017 m .49992 .77532 L .50469 .78861 L p .801 .826 .871 r
F P
0 g
s
.50469 .78861 m .47944 .80309 L .47134 .79017 L p .801 .826 .871 r
F P
0 g
s
.44954 1.06347 m .45801 1.07098 L .46437 1.07522 L p .558 .003 0 r
F P
0 g
s
.45801 1.07098 m .44954 1.06347 L .44236 1.06004 L p .546 0 0 r
F P
0 g
s
.28169 .86949 m .26653 .90155 L .23034 .89425 L p .715 .726 .858 r
F P
0 g
s
.26653 .90155 m .28169 .86949 L .31177 .87879 L p .722 .721 .849 r
F P
0 g
s
.52788 1.12784 m .5429 1.13583 L .54997 1.14225 L p 0 .361 .809 r
F P
0 g
s
.5429 1.13583 m .52788 1.12784 L .52211 1.12165 L p 0 .32 .777 r
F P
0 g
s
.41855 .82667 m .44396 .80736 L .45518 .81957 L p .788 .784 .849 r
F P
0 g
s
.47944 .80309 m .45518 .81957 L .44396 .80736 L p .795 .805 .86 r
F P
0 g
s
.40655 1.04618 m .41201 1.04996 L .42377 1.05334 L p .414 0 0 r
F P
0 g
s
.41201 1.04996 m .40655 1.04618 L .39297 1.04396 L p .285 0 0 r
F P
0 g
s
.44396 .80736 m .47134 .79017 L .47944 .80309 L p .795 .805 .86 r
F P
0 g
s
.73158 .66039 m .77002 .67196 L .73861 .68927 L p .683 .867 .968 r
F P
0 g
s
.73861 .68927 m .70502 .68088 L .73158 .66039 L p .683 .867 .968 r
F P
0 g
s
.52779 .74771 m .56039 .73825 L .55746 .7531 L p .79 .868 .906 r
F P
0 g
s
.55746 .7531 m .5289 .76294 L .52779 .74771 L p .79 .868 .906 r
F P
0 g
s
.48561 1.09312 m .49781 1.10176 L .50304 1.10728 L p 0 .238 .725 r
F P
0 g
s
.49781 1.10176 m .48561 1.09312 L .48048 1.0881 L p 0 .208 .689 r
F P
0 g
s
.39297 1.04396 m .39832 1.04647 L .41201 1.04996 L p .285 0 0 r
F P
0 g
s
.39297 1.04396 m .37713 1.04175 L p .39512 1.04575 L 0 .445 .703 r
F P
0 g
s
.39781 1.04623 m .39297 1.04396 L p .39512 1.04575 L 0 .445 .703 r
F P
0 g
s
.37713 1.04175 m .38245 1.04281 L .39832 1.04647 L p 0 .445 .703 r
F P
0 g
s
.38245 1.04281 m .37713 1.04175 L .35876 1.03949 L p 0 .555 .81 r
F P
0 g
s
.3641 1.03892 m .38245 1.04281 L p .36301 1.04009 L 0 .555 .81 r
F P
0 g
s
.35876 1.03949 m .35931 1.03944 L p .36301 1.04009 L 0 .555 .81 r
F P
0 g
s
.35931 1.03944 m .3641 1.03892 L p .36301 1.04009 L 0 .555 .81 r
F P
0 g
s
.39832 1.04647 m .39781 1.04623 L p .39512 1.04575 L 0 .445 .703 r
F P
0 g
s
.44236 1.06004 m .45057 1.06681 L .45801 1.07098 L p .546 0 0 r
F P
0 g
s
.45057 1.06681 m .44236 1.06004 L .43383 1.05668 L p .501 0 0 r
F P
0 g
s
.67364 .60582 m .63093 .58261 L .64646 .55744 L p .606 .675 .89 r
F P
0 g
s
.64646 .55744 m .69555 .58298 L .67364 .60582 L p .606 .675 .89 r
F P
0 g
s
.53727 .5494 m .48915 .53988 L .48323 .51208 L p .572 .683 .915 r
F P
0 g
s
.42917 .50805 m .48323 .51208 L .48915 .53988 L p .563 .689 .925 r
F P
0 g
s
.35528 .86118 m .37702 .83669 L .3958 .84783 L p .76 .746 .841 r
F P
0 g
s
.41855 .82667 m .3958 .84783 L .37702 .83669 L p .769 .765 .849 r
F P
0 g
s
.50304 1.10728 m .51638 1.11579 L .52211 1.12165 L p 0 .292 .765 r
F P
0 g
s
.51638 1.11579 m .50304 1.10728 L .49781 1.10176 L p 0 .262 .738 r
F P
0 g
s
.33108 .85063 m .31177 .87879 L .28169 .86949 L p .733 .736 .853 r
F P
0 g
s
.31177 .87879 m .33108 .85063 L .35528 .86118 L p .741 .732 .843 r
F P
0 g
s
.24701 .85895 m .23034 .89425 L .18867 .886 L p .709 .73 .867 r
F P
0 g
s
.23034 .89425 m .24701 .85895 L .28169 .86949 L p .715 .726 .858 r
F P
0 g
s
.43383 1.05668 m .4419 1.06262 L .45057 1.06681 L p .501 0 0 r
F P
0 g
s
.4419 1.06262 m .43383 1.05668 L .42377 1.05334 L p .427 0 0 r
F P
0 g
s
.52211 1.12165 m .53623 1.12979 L .5429 1.13583 L p 0 .32 .777 r
F P
0 g
s
.53623 1.12979 m .52211 1.12165 L .51638 1.11579 L p 0 .288 .751 r
F P
0 g
s
.56417 .72115 m .59998 .71551 L .59165 .73172 L p .768 .879 .927 r
F P
0 g
s
.59165 .73172 m .56039 .73825 L .56417 .72115 L p .768 .879 .927 r
F P
0 g
s
.37702 .83669 m .35528 .86118 L .33108 .85063 L p .751 .749 .85 r
F P
0 g
s
.66577 .67598 m .70502 .68088 L .68237 .69853 L p .711 .878 .959 r
F P
0 g
s
.68237 .69853 m .64816 .69592 L .66577 .67598 L p .711 .878 .959 r
F P
0 g
s
.3641 1.03892 m .35876 1.03949 L .33752 1.03716 L p .122 .639 .89 r
F P
0 g
s
.48048 1.0881 m .49221 1.09643 L .49781 1.10176 L p 0 .208 .689 r
F P
0 g
s
.49221 1.09643 m .48048 1.0881 L .47466 1.08324 L p 0 .194 .664 r
F P
0 g
s
.49476 .76013 m .52779 .74771 L .5289 .76294 L p .791 .845 .892 r
F P
0 g
s
.5289 .76294 m .49992 .77532 L .49476 .76013 L p .791 .845 .892 r
F P
0 g
s
.46806 1.07844 m .46054 1.07364 L p .46835 1.07873 L 0 .226 .666 r
F P
0 g
s
.46806 1.07844 m .47466 1.08324 L p .46777 1.07816 L .43 0 0 r
F P
0 g
s
.46806 1.07844 m .47945 1.08596 L .48612 1.09119 L p 0 .2 .656 r
F P
0 g
s
.47945 1.08596 m .46806 1.07844 L p .46835 1.07873 L 0 .226 .666 r
F P
0 g
s
.45801 1.07098 m .46806 1.07844 L p .46777 1.07816 L .43 0 0 r
F P
0 g
s
.46806 1.07844 m .45801 1.07098 L .45057 1.06681 L p .42 0 0 r
F P
0 g
s
.60998 .69678 m .64816 .69592 L .63325 .71313 L p .741 .882 .945 r
F P
0 g
s
.63325 .71313 m .59998 .71551 L .60998 .69678 L p .741 .882 .945 r
F P
0 g
s
.37702 .83669 m .40257 .814 L .41855 .82667 L p .769 .765 .849 r
F P
0 g
s
.44396 .80736 m .41855 .82667 L .40257 .814 L p .777 .784 .858 r
F P
0 g
s
.63093 .58261 m .58502 .5637 L .59361 .53688 L p .594 .676 .898 r
F P
0 g
s
.59361 .53688 m .64646 .55744 L .63093 .58261 L p .594 .676 .898 r
F P
0 g
s
.58502 .5637 m .53727 .5494 L .53862 .52169 L p .583 .679 .906 r
F P
0 g
s
.48323 .51208 m .53862 .52169 L .53727 .5494 L p .572 .683 .915 r
F P
0 g
s
.33752 1.03716 m .34293 1.03473 L .3641 1.03892 L p .122 .639 .89 r
F P
0 g
s
.34293 1.03473 m .33752 1.03716 L .31301 1.0347 L p .227 .697 .942 r
F P
0 g
s
.42377 1.05334 m .43184 1.05835 L .4419 1.06262 L p .427 0 0 r
F P
0 g
s
.43184 1.05835 m .42377 1.05334 L .41201 1.04996 L p .33 0 0 r
F P
0 g
s
.49781 1.10176 m .5106 1.11016 L .51638 1.11579 L p 0 .262 .738 r
F P
0 g
s
.5106 1.11016 m .49781 1.10176 L .49221 1.09643 L p 0 .245 .718 r
F P
0 g
s
.53862 .52169 m .59361 .53688 L .58502 .5637 L p .583 .679 .906 r
F P
0 g
s
.46228 .77544 m .49476 .76013 L .49992 .77532 L p .789 .824 .879 r
F P
0 g
s
.49992 .77532 m .47134 .79017 L .46228 .77544 L p .789 .824 .879 r
F P
0 g
s
.40257 .814 m .43125 .79348 L .44396 .80736 L p .777 .784 .858 r
F P
0 g
s
.47134 .79017 m .44396 .80736 L .43125 .79348 L p .784 .803 .868 r
F P
0 g
s
.31301 1.0347 m .31853 1.03014 L .34293 1.03473 L p .227 .697 .942 r
F P
0 g
s
.31853 1.03014 m .31301 1.0347 L .28478 1.03207 L p .31 .736 .973 r
F P
0 g
s
.43125 .79348 m .46228 .77544 L .47134 .79017 L p .784 .803 .868 r
F P
0 g
s
.47466 1.08324 m .48612 1.09119 L .49221 1.09643 L p 0 .194 .664 r
F P
0 g
s
.51638 1.11579 m .52985 1.12401 L .53623 1.12979 L p 0 .288 .751 r
F P
0 g
s
.52985 1.12401 m .51638 1.11579 L .5106 1.11016 L p 0 .268 .735 r
F P
0 g
s
.46054 1.07364 m .45197 1.06872 L p .46027 1.07364 L 0 .269 .695 r
F P
0 g
s
.46054 1.07364 m .46806 1.07844 L p .46082 1.07363 L .42 0 0 r
F P
0 g
s
.46054 1.07364 m .47206 1.08064 L .47945 1.08596 L p 0 .226 .666 r
F P
0 g
s
.47206 1.08064 m .46054 1.07364 L p .46027 1.07364 L 0 .269 .695 r
F P
0 g
s
.45057 1.06681 m .46054 1.07364 L p .46082 1.07363 L .42 0 0 r
F P
0 g
s
.46054 1.07364 m .45057 1.06681 L .4419 1.06262 L p .381 0 0 r
F P
0 g
s
.41201 1.04996 m .42021 1.05391 L .43184 1.05835 L p .33 0 0 r
F P
0 g
s
.41201 1.04996 m .39832 1.04647 L p .41621 1.05255 L 0 .37 .684 r
F P
0 g
s
.41922 1.05344 m .41201 1.04996 L p .41621 1.05255 L 0 .37 .684 r
F P
0 g
s
.39832 1.04647 m .40678 1.04922 L .42021 1.05391 L p 0 .37 .684 r
F P
0 g
s
.40678 1.04922 m .39832 1.04647 L .38245 1.04281 L p 0 .472 .778 r
F P
0 g
s
.3913 1.04421 m .40678 1.04922 L p .38816 1.04432 L 0 .472 .778 r
F P
0 g
s
.38245 1.04281 m .38371 1.04301 L p .38816 1.04432 L 0 .472 .778 r
F P
0 g
s
.38371 1.04301 m .3913 1.04421 L p .38816 1.04432 L 0 .472 .778 r
F P
0 g
s
.42021 1.05391 m .41922 1.05344 L p .41621 1.05255 L 0 .37 .684 r
F P
0 g
s
.18867 .886 m .207 .84694 L .24701 .85895 L p .709 .73 .867 r
F P
0 g
s
.30321 .83867 m .28169 .86949 L .24701 .85895 L p .725 .739 .862 r
F P
0 g
s
.28169 .86949 m .30321 .83867 L .33108 .85063 L p .733 .736 .853 r
F P
0 g
s
.33108 .85063 m .35545 .82407 L .37702 .83669 L p .751 .749 .85 r
F P
0 g
s
.40257 .814 m .37702 .83669 L .35545 .82407 L p .76 .766 .858 r
F P
0 g
s
.28478 1.03207 m .29042 1.02509 L .31853 1.03014 L p .31 .736 .973 r
F P
0 g
s
.29042 1.02509 m .28478 1.03207 L .2523 1.02922 L p .375 .76 .989 r
F P
0 g
s
.52685 .7302 m .56417 .72115 L .56039 .73825 L p .775 .859 .912 r
F P
0 g
s
.56039 .73825 m .52779 .74771 L .52685 .7302 L p .775 .859 .912 r
F P
0 g
s
.49221 1.09643 m .50466 1.10465 L .5106 1.11016 L p 0 .245 .718 r
F P
0 g
s
.50466 1.10465 m .49221 1.09643 L .48612 1.09119 L p 0 .243 .711 r
F P
0 g
s
.35545 .82407 m .33108 .85063 L .30321 .83867 L p .742 .751 .859 r
F P
0 g
s
.45197 1.06872 m .44218 1.06362 L p .45112 1.06837 L 0 .326 .737 r
F P
0 g
s
.45197 1.06872 m .46054 1.07364 L p .45282 1.06907 L .381 0 0 r
F P
0 g
s
.45197 1.06872 m .46381 1.07512 L .47206 1.08064 L p 0 .269 .695 r
F P
0 g
s
.46381 1.07512 m .45197 1.06872 L p .45112 1.06837 L 0 .326 .737 r
F P
0 g
s
.4419 1.06262 m .45197 1.06872 L p .45282 1.06907 L .381 0 0 r
F P
0 g
s
.4419 1.06262 m .43184 1.05835 L p .4469 1.06611 L 0 .255 .637 r
F P
0 g
s
.44218 1.06362 m .45197 1.06872 L p .44363 1.06443 L 0 .255 .637 r
F P
0 g
s
.43184 1.05835 m .44218 1.06362 L p .44363 1.06443 L 0 .255 .637 r
F P
0 g
s
.43184 1.05835 m .42021 1.05391 L p .43776 1.06167 L 0 .335 .703 r
F P
0 g
s
.44218 1.06362 m .44077 1.0629 L p .43776 1.06167 L 0 .335 .703 r
F P
0 g
s
.44077 1.0629 m .43184 1.05835 L p .43776 1.06167 L 0 .335 .703 r
F P
0 g
s
.42021 1.05391 m .42282 1.05496 L p .42785 1.05729 L 0 .335 .703 r
F P
0 g
s
.42282 1.05496 m .43099 1.05823 L p .42785 1.05729 L 0 .335 .703 r
F P
0 g
s
.43099 1.05823 m .42021 1.05391 L .40678 1.04922 L p 0 .419 .774 r
F P
0 g
s
.41819 1.05246 m .43099 1.05823 L p .4136 1.05176 L 0 .419 .774 r
F P
0 g
s
.40678 1.04922 m .40883 1.04981 L p .4136 1.05176 L 0 .419 .774 r
F P
0 g
s
.40883 1.04981 m .41819 1.05246 L p .4136 1.05176 L 0 .419 .774 r
F P
0 g
s
.44218 1.06362 m .43099 1.05823 L p .44073 1.06281 L 0 .391 .788 r
F P
0 g
s
.45011 1.0676 m .4419 1.06262 L p .4469 1.06611 L 0 .255 .637 r
F P
0 g
s
.45456 1.06932 m .44218 1.06362 L p .44073 1.06281 L 0 .391 .788 r
F P
0 g
s
.43099 1.05823 m .44218 1.06362 L p .42785 1.05729 L 0 .335 .703 r
F P
0 g
s
.45197 1.06872 m .45011 1.0676 L p .4469 1.06611 L 0 .255 .637 r
F P
0 g
s
.2523 1.02922 m .25806 1.01947 L .29042 1.02509 L p .375 .76 .989 r
F P
0 g
s
.25806 1.01947 m .2523 1.02922 L .21497 1.02611 L p .425 .775 .996 r
F P
0 g
s
.5106 1.11016 m .52366 1.11839 L .52985 1.12401 L p 0 .268 .735 r
F P
0 g
s
.52366 1.11839 m .5106 1.11016 L .50466 1.10465 L p 0 .261 .729 r
F P
0 g
s
.35545 .82407 m .38427 .79959 L .40257 .814 L p .76 .766 .858 r
F P
0 g
s
.43125 .79348 m .40257 .814 L .38427 .79959 L p .767 .783 .866 r
F P
0 g
s
.3913 1.04421 m .38245 1.04281 L .3641 1.03892 L p .03 .561 .856 r
F P
0 g
s
.56888 .70141 m .60998 .69678 L .59998 .71551 L p .754 .867 .931 r
F P
0 g
s
.59998 .71551 m .56417 .72115 L .56888 .70141 L p .754 .867 .931 r
F P
0 g
s
.21497 1.02611 m .22081 1.01317 L .25806 1.01947 L p .425 .775 .996 r
F P
0 g
s
.22081 1.01317 m .21497 1.02611 L .1721 1.02266 L p .464 .783 .998 r
F P
0 g
s
.48612 1.09119 m .49847 1.09917 L .50466 1.10465 L p 0 .243 .711 r
F P
0 g
s
.49847 1.09917 m .48612 1.09119 L .47945 1.08596 L p 0 .256 .716 r
F P
0 g
s
.48911 .7427 m .52685 .7302 L .52779 .74771 L p .778 .839 .899 r
F P
0 g
s
.52779 .74771 m .49476 .76013 L .48911 .7427 L p .778 .839 .899 r
F P
0 g
s
.68651 .65281 m .73158 .66039 L .70502 .68088 L p .703 .863 .958 r
F P
0 g
s
.70502 .68088 m .66577 .67598 L .68651 .65281 L p .703 .863 .958 r
F P
0 g
s
.6219 .67507 m .66577 .67598 L .64816 .69592 L p .729 .869 .946 r
F P
0 g
s
.64816 .69592 m .60998 .69678 L .6219 .67507 L p .729 .869 .946 r
F P
0 g
s
.38427 .79959 m .41677 .77763 L .43125 .79348 L p .767 .783 .866 r
F P
0 g
s
.46228 .77544 m .43125 .79348 L .41677 .77763 L p .773 .801 .876 r
F P
0 g
s
.50466 1.10465 m .51754 1.11284 L .52366 1.11839 L p 0 .261 .729 r
F P
0 g
s
.51754 1.11284 m .50466 1.10465 L .49847 1.09917 L p 0 .268 .735 r
F P
0 g
s
.27105 .82503 m .24701 .85895 L .207 .84694 L p .718 .742 .871 r
F P
0 g
s
.24701 .85895 m .27105 .82503 L .30321 .83867 L p .725 .739 .862 r
F P
0 g
s
.1721 1.02266 m .17793 1.00606 L .22081 1.01317 L p .464 .783 .998 r
F P
0 g
s
.3641 1.03892 m .37346 1.03876 L .3913 1.04421 L p .03 .561 .856 r
F P
0 g
s
.37346 1.03876 m .3641 1.03892 L .34293 1.03473 L p .14 .631 .914 r
F P
0 g
s
.45206 .75858 m .48911 .7427 L .49476 .76013 L p .776 .82 .887 r
F P
0 g
s
.49476 .76013 m .46228 .77544 L .45206 .75858 L p .776 .82 .887 r
F P
0 g
s
.41677 .77763 m .45206 .75858 L .46228 .77544 L p .773 .801 .876 r
F P
0 g
s
.30321 .83867 m .33062 .80968 L .35545 .82407 L p .742 .751 .859 r
F P
0 g
s
.38427 .79959 m .35545 .82407 L .33062 .80968 L p .75 .767 .866 r
F P
0 g
s
.47945 1.08596 m .4919 1.09363 L .49847 1.09917 L p 0 .256 .716 r
F P
0 g
s
.4919 1.09363 m .47945 1.08596 L .47206 1.08064 L p 0 .284 .735 r
F P
0 g
s
.33062 .80968 m .30321 .83867 L .27105 .82503 L p .734 .753 .868 r
F P
0 g
s
.34293 1.03473 m .35293 1.03278 L .37346 1.03876 L p .14 .631 .914 r
F P
0 g
s
.35293 1.03278 m .34293 1.03473 L .31853 1.03014 L p .232 .682 .953 r
F P
0 g
s
.49847 1.09917 m .51139 1.10727 L .51754 1.11284 L p 0 .268 .735 r
F P
0 g
s
.51139 1.10727 m .49847 1.09917 L .4919 1.09363 L p 0 .288 .751 r
F P
0 g
s
.52608 .71001 m .56888 .70141 L .56417 .72115 L p .761 .851 .918 r
F P
0 g
s
.56417 .72115 m .52685 .7302 L .52608 .71001 L p .761 .851 .918 r
F P
0 g
s
.41819 1.05246 m .40678 1.04922 L .3913 1.04421 L p 0 .5 .84 r
F P
0 g
s
.47206 1.08064 m .48483 1.08793 L .4919 1.09363 L p 0 .284 .735 r
F P
0 g
s
.48483 1.08793 m .47206 1.08064 L .46381 1.07512 L p 0 .325 .765 r
F P
0 g
s
.44218 1.06362 m .45456 1.06932 L .46381 1.07512 L p 0 .326 .737 r
F P
0 g
s
.31853 1.03014 m .32928 1.02615 L .35293 1.03278 L p .232 .682 .953 r
F P
0 g
s
.32928 1.02615 m .31853 1.03014 L .29042 1.02509 L p .308 .717 .977 r
F P
0 g
s
.33062 .80968 m .36324 .7831 L .38427 .79959 L p .75 .767 .866 r
F P
0 g
s
.41677 .77763 m .38427 .79959 L .36324 .7831 L p .757 .783 .874 r
F P
0 g
s
.207 .84694 m .23389 .8094 L .27105 .82503 L p .718 .742 .871 r
F P
0 g
s
.4919 1.09363 m .5051 1.10156 L .51139 1.10727 L p 0 .288 .751 r
F P
0 g
s
.5051 1.10156 m .4919 1.09363 L .48483 1.08793 L p 0 .32 .777 r
F P
0 g
s
.3913 1.04421 m .40351 1.04619 L .41819 1.05246 L p 0 .5 .84 r
F P
0 g
s
.40351 1.04619 m .3913 1.04421 L .37346 1.03876 L p .077 .57 .895 r
F P
0 g
s
.48284 .72263 m .52608 .71001 L .52685 .7302 L p .764 .833 .905 r
F P
0 g
s
.52685 .7302 m .48911 .7427 L .48284 .72263 L p .764 .833 .905 r
F P
0 g
s
.57466 .67854 m .6219 .67507 L .60998 .69678 L p .741 .856 .934 r
F P
0 g
s
.60998 .69678 m .56888 .70141 L .57466 .67854 L p .741 .856 .934 r
F P
0 g
s
.46381 1.07512 m .47714 1.08195 L .48483 1.08793 L p 0 .325 .765 r
F P
0 g
s
.47714 1.08195 m .46381 1.07512 L .45456 1.06932 L p 0 .376 .803 r
F P
0 g
s
.43099 1.05823 m .44412 1.06312 L .45456 1.06932 L p 0 .391 .788 r
F P
0 g
s
.44412 1.06312 m .43099 1.05823 L .41819 1.05246 L p 0 .459 .839 r
F P
0 g
s
.29042 1.02509 m .30206 1.01874 L .32928 1.02615 L p .308 .717 .977 r
F P
0 g
s
.30206 1.01874 m .29042 1.02509 L .25806 1.01947 L p .369 .741 .989 r
F P
0 g
s
.36324 .7831 m .4002 .75945 L .41677 .77763 L p .757 .783 .874 r
F P
0 g
s
.45206 .75858 m .41677 .77763 L .4002 .75945 L p .761 .799 .883 r
F P
0 g
s
.27105 .82503 m .30196 .7932 L .33062 .80968 L p .734 .753 .868 r
F P
0 g
s
.36324 .7831 m .33062 .80968 L .30196 .7932 L p .741 .767 .874 r
F P
0 g
s
.44045 .73918 m .48284 .72263 L .48911 .7427 L p .764 .816 .894 r
F P
0 g
s
.48911 .7427 m .45206 .75858 L .44045 .73918 L p .764 .816 .894 r
F P
0 g
s
.30196 .7932 m .27105 .82503 L .23389 .8094 L p .726 .755 .876 r
F P
0 g
s
.4002 .75945 m .44045 .73918 L .45206 .75858 L p .761 .799 .883 r
F P
0 g
s
.63605 .64984 m .68651 .65281 L .66577 .67598 L p .719 .856 .947 r
F P
0 g
s
.66577 .67598 m .6219 .67507 L .63605 .64984 L p .719 .856 .947 r
F P
0 g
s
.37346 1.03876 m .38668 1.03931 L .40351 1.04619 L p .077 .57 .895 r
F P
0 g
s
.38668 1.03931 m .37346 1.03876 L .35293 1.03278 L p .17 .627 .936 r
F P
0 g
s
.48483 1.08793 m .49855 1.09562 L .5051 1.10156 L p 0 .32 .777 r
F P
0 g
s
.49855 1.09562 m .48483 1.08793 L .47714 1.08195 L p 0 .361 .809 r
F P
0 g
s
.45456 1.06932 m .46867 1.07559 L .47714 1.08195 L p 0 .376 .803 r
F P
0 g
s
.46867 1.07559 m .45456 1.06932 L .44412 1.06312 L p 0 .431 .843 r
F P
0 g
s
.25806 1.01947 m .2707 1.01041 L .30206 1.01874 L p .369 .741 .989 r
F P
0 g
s
.2707 1.01041 m .25806 1.01947 L .22081 1.01317 L p .417 .757 .995 r
F P
0 g
s
.41819 1.05246 m .43229 1.0564 L .44412 1.06312 L p 0 .459 .839 r
F P
0 g
s
.43229 1.0564 m .41819 1.05246 L .40351 1.04619 L p .042 .523 .885 r
F P
0 g
s
.35293 1.03278 m .36735 1.03167 L .38668 1.03931 L p .17 .627 .936 r
F P
0 g
s
.36735 1.03167 m .35293 1.03278 L .32928 1.02615 L p .25 .67 .963 r
F P
0 g
s
.52545 .68663 m .57466 .67854 L .56888 .70141 L p .749 .842 .922 r
F P
0 g
s
.56888 .70141 m .52608 .71001 L .52545 .68663 L p .749 .842 .922 r
F P
0 g
s
.47714 1.08195 m .49162 1.08933 L .49855 1.09562 L p 0 .361 .809 r
F P
0 g
s
.49162 1.08933 m .47714 1.08195 L .46867 1.07559 L p 0 .408 .843 r
F P
0 g
s
.30196 .7932 m .33898 .76415 L .36324 .7831 L p .741 .767 .874 r
F P
0 g
s
.4002 .75945 m .36324 .7831 L .33898 .76415 L p .747 .782 .882 r
F P
0 g
s
.44412 1.06312 m .45927 1.06873 L .46867 1.07559 L p 0 .431 .843 r
F P
0 g
s
.45927 1.06873 m .44412 1.06312 L .43229 1.0564 L p .031 .487 .881 r
F P
0 g
s
.22081 1.01317 m .23455 1.00097 L .2707 1.01041 L p .417 .757 .995 r
F P
0 g
s
.23455 1.00097 m .22081 1.01317 L .17793 1.00606 L p .455 .767 .996 r
F P
0 g
s
.40351 1.04619 m .41883 1.04903 L .43229 1.0564 L p .042 .523 .885 r
F P
0 g
s
.41883 1.04903 m .40351 1.04619 L .38668 1.03931 L p .128 .579 .923 r
F P
0 g
s
.32928 1.02615 m .34513 1.02313 L .36735 1.03167 L p .25 .67 .963 r
F P
0 g
s
.34513 1.02313 m .32928 1.02615 L .30206 1.01874 L p .317 .702 .98 r
F P
0 g
s
.46867 1.07559 m .48417 1.08258 L .49162 1.08933 L p 0 .408 .843 r
F P
0 g
s
.48417 1.08258 m .46867 1.07559 L .45927 1.06873 L p .029 .457 .875 r
F P
0 g
s
.23389 .8094 m .26881 .77425 L .30196 .7932 L p .726 .755 .876 r
F P
0 g
s
.33898 .76415 m .30196 .7932 L .26881 .77425 L p .732 .768 .881 r
F P
0 g
s
.47579 .69941 m .52545 .68663 L .52608 .71001 L p .752 .827 .91 r
F P
0 g
s
.52608 .71001 m .48284 .72263 L .47579 .69941 L p .752 .827 .91 r
F P
0 g
s
.33898 .76415 m .38112 .73851 L .4002 .75945 L p .747 .782 .882 r
F P
0 g
s
.44045 .73918 m .4002 .75945 L .38112 .73851 L p .751 .797 .89 r
F P
0 g
s
.58165 .65196 m .63605 .64984 L .6219 .67507 L p .73 .846 .936 r
F P
0 g
s
.6219 .67507 m .57466 .67854 L .58165 .65196 L p .73 .846 .936 r
F P
0 g
s
.43229 1.0564 m .44875 1.06123 L .45927 1.06873 L p .031 .487 .881 r
F P
0 g
s
.44875 1.06123 m .43229 1.0564 L .41883 1.04903 L p .107 .538 .913 r
F P
0 g
s
.17793 1.00606 m .19285 .99024 L .23455 1.00097 L p .455 .767 .996 r
F P
0 g
s
.38668 1.03931 m .40347 1.04087 L .41883 1.04903 L p .128 .579 .923 r
F P
0 g
s
.40347 1.04087 m .38668 1.03931 L .36735 1.03167 L p .206 .625 .95 r
F P
0 g
s
.42718 .71679 m .47579 .69941 L .48284 .72263 L p .753 .812 .9 r
F P
0 g
s
.48284 .72263 m .44045 .73918 L .42718 .71679 L p .753 .812 .9 r
F P
0 g
s
.38112 .73851 m .42718 .71679 L .44045 .73918 L p .751 .797 .89 r
F P
0 g
s
.45927 1.06873 m .47607 1.07524 L .48417 1.08258 L p .029 .457 .875 r
F P
0 g
s
.47607 1.07524 m .45927 1.06873 L .44875 1.06123 L p .098 .504 .904 r
F P
0 g
s
.30206 1.01874 m .31956 1.01351 L .34513 1.02313 L p .317 .702 .98 r
F P
0 g
s
.31956 1.01351 m .30206 1.01874 L .2707 1.01041 L p .371 .725 .989 r
F P
0 g
s
.41883 1.04903 m .43689 1.05295 L .44875 1.06123 L p .107 .538 .913 r
F P
0 g
s
.43689 1.05295 m .41883 1.04903 L .40347 1.04087 L p .179 .584 .939 r
F P
0 g
s
.36735 1.03167 m .38591 1.03175 L .40347 1.04087 L p .206 .625 .95 r
F P
0 g
s
.38591 1.03175 m .36735 1.03167 L .34513 1.02313 L p .274 .662 .969 r
F P
0 g
s
.26881 .77425 m .31092 .74229 L .33898 .76415 L p .732 .768 .881 r
F P
0 g
s
.38112 .73851 m .33898 .76415 L .31092 .74229 L p .737 .781 .888 r
F P
0 g
s
.52497 .65947 m .58165 .65196 L .57466 .67854 L p .737 .834 .925 r
F P
0 g
s
.57466 .67854 m .52545 .68663 L .52497 .65947 L p .737 .834 .925 r
F P
0 g
s
.44875 1.06123 m .46716 1.06716 L .47607 1.07524 L p .098 .504 .904 r
F P
0 g
s
.46716 1.06716 m .44875 1.06123 L .43689 1.05295 L p .165 .548 .928 r
F P
0 g
s
.2707 1.01041 m .2901 1.0026 L .31956 1.01351 L p .371 .725 .989 r
F P
0 g
s
.2901 1.0026 m .2707 1.01041 L .23455 1.00097 L p .416 .741 .993 r
F P
0 g
s
.40347 1.04087 m .42346 1.04372 L .43689 1.05295 L p .179 .584 .939 r
F P
0 g
s
.42346 1.04372 m .40347 1.04087 L .38591 1.03175 L p .245 .623 .958 r
F P
0 g
s
.31092 .74229 m .35908 .71427 L .38112 .73851 L p .737 .781 .888 r
F P
0 g
s
.42718 .71679 m .38112 .73851 L .35908 .71427 L p .741 .795 .896 r
F P
0 g
s
.34513 1.02313 m .36576 1.02149 L .38591 1.03175 L p .274 .662 .969 r
F P
0 g
s
.36576 1.02149 m .34513 1.02313 L .31956 1.01351 L p .332 .69 .98 r
F P
0 g
s
.46779 .67246 m .52497 .65947 L .52545 .68663 L p .741 .821 .914 r
F P
0 g
s
.52545 .68663 m .47579 .69941 L .46779 .67246 L p .741 .821 .914 r
F P
0 g
s
.43689 1.05295 m .45726 1.05818 L .46716 1.06716 L p .165 .548 .928 r
F P
0 g
s
.45726 1.05818 m .43689 1.05295 L .42346 1.04372 L p .228 .587 .946 r
F P
0 g
s
.35908 .71427 m .41191 .69083 L .42718 .71679 L p .741 .795 .896 r
F P
0 g
s
.47579 .69941 m .42718 .71679 L .41191 .69083 L p .742 .808 .905 r
F P
0 g
s
.41191 .69083 m .46779 .67246 L .47579 .69941 L p .742 .808 .905 r
F P
0 g
s
.23455 1.00097 m .25611 .99018 L .2901 1.0026 L p .416 .741 .993 r
F P
0 g
s
.25611 .99018 m .23455 1.00097 L .19285 .99024 L p .451 .752 .993 r
F P
0 g
s
.38591 1.03175 m .40818 1.03335 L .42346 1.04372 L p .245 .623 .958 r
F P
0 g
s
.40818 1.03335 m .38591 1.03175 L .36576 1.02149 L p .303 .655 .971 r
F P
0 g
s
.31956 1.01351 m .34261 1.00987 L .36576 1.02149 L p .332 .69 .98 r
F P
0 g
s
.34261 1.00987 m .31956 1.01351 L .2901 1.0026 L p .38 .711 .987 r
F P
0 g
s
.42346 1.04372 m .44616 1.04811 L .45726 1.05818 L p .228 .587 .946 r
F P
0 g
s
.44616 1.04811 m .42346 1.04372 L .40818 1.03335 L p .284 .62 .959 r
F P
0 g
s
.19285 .99024 m .21682 .97597 L .25611 .99018 L p .451 .752 .993 r
F P
0 g
s
.36576 1.02149 m .39072 1.02162 L .40818 1.03335 L p .303 .655 .971 r
F P
0 g
s
.39072 1.02162 m .36576 1.02149 L .34261 1.00987 L p .352 .68 .978 r
F P
0 g
s
.2901 1.0026 m .31594 .99663 L .34261 1.00987 L p .38 .711 .987 r
F P
0 g
s
.31594 .99663 m .2901 1.0026 L .25611 .99018 L p .42 .727 .989 r
F P
0 g
s
.40818 1.03335 m .43363 1.03675 L .44616 1.04811 L p .284 .62 .959 r
F P
0 g
s
.43363 1.03675 m .40818 1.03335 L .39072 1.02162 L p .333 .648 .968 r
F P
0 g
s
.34261 1.00987 m .3707 1.00827 L .39072 1.02162 L p .352 .68 .978 r
F P
0 g
s
.3707 1.00827 m .34261 1.00987 L .31594 .99663 L p .395 .7 .982 r
F P
0 g
s
.25611 .99018 m .28515 .98147 L .31594 .99663 L p .42 .727 .989 r
F P
0 g
s
.28515 .98147 m .25611 .99018 L .21682 .97597 L p .453 .739 .989 r
F P
0 g
s
.39072 1.02162 m .4194 1.02384 L .43363 1.03675 L p .333 .648 .968 r
F P
0 g
s
.4194 1.02384 m .39072 1.02162 L .3707 1.00827 L p .375 .671 .973 r
F P
0 g
s
.31594 .99663 m .34767 .993 L .3707 1.00827 L p .395 .7 .982 r
F P
0 g
s
.34767 .993 m .31594 .99663 L .28515 .98147 L p .43 .715 .984 r
F P
0 g
s
.21682 .97597 m .24952 .96405 L .28515 .98147 L p .453 .739 .989 r
F P
0 g
s
.3707 1.00827 m .40315 1.00911 L .4194 1.02384 L p .375 .671 .973 r
F P
0 g
s
.40315 1.00911 m .3707 1.00827 L .34767 .993 L p .412 .69 .976 r
F P
0 g
s
.28515 .98147 m .32108 .97546 L .34767 .993 L p .43 .715 .984 r
F P
0 g
s
.32108 .97546 m .28515 .98147 L .24952 .96405 L p .46 .728 .984 r
F P
0 g
s
.34767 .993 m .38451 .99221 L .40315 1.00911 L p .412 .69 .976 r
F P
0 g
s
.38451 .99221 m .34767 .993 L .32108 .97546 L p .443 .705 .977 r
F P
0 g
s
.24952 .96405 m .2903 .95523 L .32108 .97546 L p .46 .728 .984 r
F P
0 g
s
.32108 .97546 m .36303 .97273 L .38451 .99221 L p .443 .705 .977 r
F P
0 g
s
.36303 .97273 m .32108 .97546 L .2903 .95523 L p .469 .717 .977 r
F P
0 g
s
.2903 .95523 m .33818 .9502 L .36303 .97273 L p .469 .717 .977 r
F P
0 g
s
.25 Mabswid
.65586 0 m
.92471 .39838 L
s
.92471 .39838 m
1 1.20566 L
s
1 1.20566 m
.68588 .86098 L
s
.68588 .86098 m
.65586 0 L
s
.08566 .22888 m
0 1.06126 L
s
0 1.06126 m
.68588 .86098 L
s
.68588 .86098 m
.65586 0 L
s
.65586 0 m
.08566 .22888 L
s
0 1.06126 m
.38475 1.35295 L
s
.102 1.13859 m
.10269 1.12999 L
s
[(-2)] .1006 1.15578 .08138 -1 Mshowa
.20652 1.21782 m
.20703 1.20921 L
s
[(0)] .20548 1.23505 .05998 -1 Mshowa
.30327 1.29117 m
.30362 1.28255 L
s
[(2)] .30256 1.30841 .04075 -1 Mshowa
.125 Mabswid
.1289 1.15899 m
.1293 1.15382 L
s
.15528 1.17898 m
.15565 1.17382 L
s
.18115 1.19859 m
.18149 1.19343 L
s
.2314 1.23669 m
.23168 1.23152 L
s
.25581 1.25519 m
.25607 1.25002 L
s
.27976 1.27335 m
.27999 1.26818 L
s
.07454 1.11777 m
.07499 1.11261 L
s
.04652 1.09653 m
.047 1.09138 L
s
.01792 1.07485 m
.01844 1.0697 L
s
.32634 1.30867 m
.32653 1.30349 L
s
.349 1.32584 m
.34916 1.32067 L
s
.37124 1.3427 m
.37138 1.33753 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.812, 359.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000490001Ib000`400?l00000o`00003oo`3oool:
0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00[P3oool2000005T0oooo002/
0?ooo`80000000<0oooo000000000000F03oool00:T0oooo0`0000030?ooo`800000F03oool00:L0
oooo0P0000060?ooo`030000003oool0000005L0oooo002T0?ooo`<00000203oool010000000oooo
0?ooo`00001F0?ooo`00XP3oool2000000/0oooo00@000000?ooo`3oool00000EP3oool009l0oooo
0`00000=0?ooo`050000003oool0oooo0?ooo`000000E@3oool009d0oooo0P00000@0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0DP3oool009X0oooo0`00000B0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0DP3oool009P0oooo0P00000E0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0D@3oool009D0oooo0`00000G0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0D03oool009<0oooo0P00000J0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0D03oool00900oooo0`00000L0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0C`3oool008h0oooo0P00000O0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0CP3oool008/0oooo0`00000R0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0C@3oool008T0oooo0P00000U0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0C@3oool008H0oooo0`00000W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0C03oool008@0oooo0P00000Z0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
B`3oool00840oooo0`00000/0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0B`3o
ool007l0oooo0P00000_0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0BP3oool0
07`0oooo0`00000a0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0B@3oool007X0
oooo0P00000d0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0B@3oool007L0oooo
0`00000f0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0B03oool007D0oooo0P00
000i0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0A`3oool00780oooo0`00000k
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0A`3oool00700oooo0P00000n0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0AP3oool006d0oooo0`0000100?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0A@3oool006/0oooo0P0000130?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0A@3oool006P0oooo0`0000150?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0A03oool006H0oooo0P0000180?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0@`3oool006@0oooo0P00001:0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0@`3oool00640oooo0`00001<0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0@P3oool005l0oooo0P00001?0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0@@3oool005`0oooo0`00001A0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0@@3oool005X0oooo0P00001D0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0@03oool005L0oooo0`00001F0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0?`3oool005D0oooo0P00000D0?oooaT00000;03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo03l0oooo001B0?ooo`<00000403oool6000000H0U;;^00<0000009b^iP2L[^H0
2@2L[^H00`000000W:kV09b^iP0409b^iPT000008`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo03h0oooo001@0?ooo`800000503oool00`000000U;;^09BbkP0809BbkP030000002L
[^H0W:kV00X0W:kV00<0000009b^iP2L[^H02@2L[^H00`000000W:[V09bZiP04000001l0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0m0?ooo`00C@3oool3000001H0oooo00<00000
09BbkP2D/^h02@2D/^h00`000000W:kV09b^iP0909b^iP030000002L[^H0W:kV00T0W:kV00<00000
09bZiP2LZ^H0102LZ^H4000001/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0l
0?ooo`00B`3oool2000001X0oooo00<0000009BbkP2D/^h0202D/^h00`000000W:kV09b^iP0909b^
iP030000002L[^H0W:kV00T0W:kV00<0000009bZiP2LZ^H0202LZ^H4000001L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0l0?ooo`00B03oool3000001d0oooo00<0000009BbkP2D
/^h0202D/^h00`000000W:kV09b^iP0809b^iP030000002L[^H0W:kV00T0W:kV00<0000009bZiP2L
Z^H02P2LZ^H00`000000W:[V00000002000001@0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0k0?ooo`00AP3oool200000240oooo00<0000009BbkP2D/^h01`2D/^h00`000000W:kV
09b^iP0909b^iP030000002L[^H0W:kV00P0W:kV00<0000009bZiP2LZ^H02P2LZ^H00`000000W:[V
09bZiP0209bZiP@000004@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03X0oooo
00130?ooo`<000008`3oool00`000000U;;^09BbkP0309BbkQH000001@2L[^H00`000000W:[V09bZ
iP0:09bZiP030000002LZ^H0W:[V00H0W:[V0`00000>0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0>P3oool00440oooo0P00000W0?ooo`D000001@2D[^h00`000000U:kV09B^iP08
09B^iP030000002DZ^H0U:[V00<0U:[V1`00000:09bZiP030000002LZ^H0W:[V00X0W:[V0P00000<
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0>@3oool003h0oooo0`00000Z0?oo
o`030000002D[^h0U:k^00L0U:k^00<0000009B^iP2D[^H0202D[^H00`000000U:[V09BZiP0709BZ
iP030000002LZ^H0000000<000001P2LZ^H00`000000W:[V09bZiP0;09bZiP<000002P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo03P0oooo000l0?ooo`800000;P3oool00`000000
U:k^09B^kP0609B^kP030000002D[^H0U:kV00P0U:kV00<0000009BZiP2DZ^H01`2DZ^H00`000000
W:[V09bZiP0309bZiP@000000P2LZ^H00`000000W:[V09bZiP0:09bZiP040000002LZ]h0W:[N09bZ
gP800000203oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03P0oooo000i0?ooo`<0
0000<03oool00`000000U:k^09B^kP0709B^kP030000002D[^H0U:kV00L0U:kV00<0000009BZiP2D
Z^H01`2DZ^H00`000000W:[V09bZiP0709bZiP@000002`2LZ^H00`000000W:[N09bZgP0309bZgP80
00001P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03L0oooo000g0?ooo`800000
=03oool00`000000U:k^09B^kP0609B^kP030000002D[^H0U:kV00P0U:kV00<0000009BZiP2DZ^H0
1`2DZ^H00`000000W:[V09bZiP0809bZiP030000002LZ]h00000008000001`2LZ^H00`000000W:[N
09bZgP0609bZgP800000103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03H0oooo
000d0?ooo`<00000=`3oool00`000000U:k^09B^kP0209B^kQ4000001`2DZ^H00`000000W:[V09bZ
iP0809bZiP030000002LZ]h0W:[N0080W:[N0P00000509bZiP030000002LZ]h0W:[N00P0W:[N0P00
00020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0=P3oool00380oooo0P00000k
0?ooo`@000001@2D[^h00`000000U:[V09BZiP0609BZiP030000002DZ^H0U:[V00D000000P2DZ^H0
0`000000W:[V09bZiP0809bZiP030000002LZ]h0W:[N00@0W:[N0`0000000`2LZ^H0000009bZgP0<
09bZgP<000007`3oool00`000000oooo0?ooo`0e0?ooo`00;`3oool3000003h0oooo00<0000009B^
kP2D[^h01@2D[^h00`000000U:[V09BZiP0709BZiP030000002DZ^H0U:[V00@0U:[V1@00000709bZ
iP030000002LZ]h0W:[N00P0W:[N0`00000<09bZgP040000002TZ]h00000000001l0oooo00<00000
0?ooo`3oool0=03oool002d0oooo0P0000120?ooo`030000002D[^h0U:k^00D0U:k^00<0000009BZ
iP2DZ^H01P2DZ^H00`000000U:[V09BZiP0609BZiP030000002DYNH0U:GV00D000000P2LZ^H00`00
0000W:[N09bZgP0909bZgP040000002LYMh00000000000X0W:[N00D000000:BZgP000000Y:[N0000
000N0?ooo`030000003oool0oooo03@0oooo000Z0?ooo`<00000A03oool00`000000U:k^09B^kP05
09B^kP030000002DZ^H0U:[V00H0U:[V00<0000009BZiP2DZ^H01P2DZ^H00`000000U:GV09BUiP05
09BUiP@000002@2LZ]h00`000000W:GN09bUgP0209bUgP8000001`2LZ]h010000000Y:[N0:BZgP00
00020:BZgP8000007@3oool00`000000oooo0?ooo`0c0?ooo`00:03oool2000004P0oooo00<00000
09B^kP2D[^h00P2D[^h8000000@0U:[V00<0000009BZiP2DZ^H01@2DZ^H00`000000U:GV09BUiP07
09BUiP040000002LYMh00000000000L0W:[N00<0000009bUgP2LYMh0102LYMh2000000@0W:[N00D0
00000:BZgP2TZ]h0Y:[N000000040:BZgP800000703oool00`000000oooo0?ooo`0b0?ooo`009@3o
ool3000004/0oooo1000000408^ZkP040000002;YNH0RjGV08^UiPH000001P2DZ^H00`000000U:GV
09BUiP0709BUiP040000002LYMh0W:GN09bUgP<00000102LZ]h00`000000W:GN09bUgP0609bUgP80
00000P2LZ]h01@000000Y:[N0:BZgP2TZ]h0000000H0Y:[N00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0b0?ooo`008`3oool2000004l0oooo00<0000008^ZkP2;Z^h0102;Z^h00`000000
RjGV08^UiP0508^UiP030000002DYNH0000000<000000P2DZ^H00`000000U:GV09BUiP0709BUiP03
0000002LYMh0W:GN00@0W:GN0P0000000`2LZ]h0000009bUgP0:09bUgP800000102TZ]h00`000000
Y:[N0:BZgP050:BZgP8000006P3oool00`000000oooo0?ooo`0a0?ooo`00803oool300000540oooo
00<0000008^ZkP2;Z^h01@2;Z^h00`000000RjGV08^UiP0408^UiP030000002DYNH0U:GV00<0U:GV
1@00000609BUiP030000002LYMh0W:GN00L0W:GN0P00000;09bUgP040000002TYMh0000000000080
Y:[N00<000000:BZgP2TZ]h01`2TZ]h00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0300
oooo000N0?ooo`800000E@3oool00`000000Rj[^08^ZkP0408^ZkP030000002;YNH0RjGV00D0RjGV
00<0000009BUiP2DYNH0102DYNH00`000000U:GV09BUiP0400000080U:GV00<0000009bUgP2LYMh0
202LYMh3000000T0W:GN00L000000:BUgP2TYMh0Y:GN0000002TZ]h0000000P0Y:[N00<000000:BZ
gP0000006@3oool00`000000oooo0?ooo`0`0?ooo`00703oool2000005P0oooo2`00000308^UiP03
0000002DYNH0U:GV00@0U:GV00<0000009BUiP2DYNH0102DYNH4000000P0W:GN00@0000009bUgP2L
YMh0W:GN0P00000609bUgP030000002TYMh0Y:GN00<0Y:GN0P0000060:BZgP8000000`2TZ]h20000
01P0oooo00<000000?ooo`3oool0;`3oool001`0oooo0P00001I0?ooo`0300000023YNh0PjG^00<0
PjG^00@0000008^UiP2;YNH0RjGV1`00000409BUiP030000002DYNH0U:GV00D0U:GV00<0000009BQ
gP0000000P00000509bUgP030000002LYMh0W:GN00<0W:GN0P00000309bUgP030000002TYMh0Y:GN
00D0Y:GN0P0000040:BZgP030000002TZ]h0Y:[N00D0Y:[N00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0^0?ooo`00703oool00`000000oooo0000001H0?ooo`0300000023YNh0PjG^00@0
PjG^00<0000008^UiP2;YNH00`2;YNH010000000Rj7V08^QiP2;XNH6000000H0U:GV00<0000009BQ
gP2DXMh00P2DXMh30000000309bUgP000000W:GN00L0W:GN0P0000000`2LYMh000000:BUgP060:BU
gP060000002TYMh000000000002TZ]h000002@2TZ]h00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo02h0oooo000L0?ooo`80000000<0oooo0000003oool0E`3oool00`000000PjG^08>UkP03
08>UkP030000002;YNH0RjGV00@0RjGV00<0000008^QiP2;XNH0102;XNH010000000Rj7V00000000
000309BUiP030000002DXMh0U:7N00H0U:7N0P00000:09bUgP030000002TYMh0Y:GN00H0Y:GN00D0
00000:BUgP2TYMh0Y:GN0000000;0:BZgP030000003oool0oooo01D0oooo00<000000?ooo`3oool0
;@3oool001/0oooo0P0000030?ooo`030000003oool0oooo05H0oooo2P00000208^UiP030000002;
XNH0Rj7V00@0Rj7V00@0000008^QiP2;XNH0Rj7V0P0000000`2DYNH0000009BQgP0809BQgP<00000
1`2LYMh00`000000W:GN000000070:BUgP060000002TYMh0Y:GN0000002TYMh000002`2TZ]h20000
01H0oooo00<000000?ooo`3oool0;03oool001/0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`1F0?ooo`0300000023YNh0PjG^0080PjG^00@0000008>QiP23XNH0Pj7V1@00000408^Q
iP030000002;XNH0Rj7V00<0Rj7V0`00000709BQgP050000002LXMh0W:7N09bQgP0000001P2LYMh0
0`000000W:GN09bUgP02000000D0Y:GN00<000000:BUgP0000000`2TYMh00`000000Y:[N0:BZgP0:
0:BZgP030000003oool0oooo01<0oooo00<000000?ooo`3oool0;03oool001/0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`1G0?ooo`0300000023YNh0PjG^0080PjG^00<0000008>Q
iP23XNH00`23XNH00`000000PigV000000020000000308^QiP000000Rj7V00D0Rj7V00@0000009BM
gP00000000001@2DXMh00`000000W:7N09bQgP0209bQgP8000000`2LYMh00`000000W:GN09bUgP03
09bUgP030000002TYMh0Y:GN0080Y:GN00<000000:BUgP000000102TYMh00`000000Y:[N0:BZgP0:
0:BZgP030000003oool0oooo01<0oooo00<000000?ooo`3oool0:`3oool001@0oooo0P0000050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0E`3oool30000000308>UkP000000Pj7V
00@0Pj7V00<0000008>MiP23WNH00P23WNH3000000D0Rj7V00@0000009BMgP2DWMh0U9gN0`000000
0`2DXMh000000000000;000000D0W:GN00@000000:BUgP2TYMh0Y:GN0P0000060:BUgP800000202T
Z]h2000000030:BZgP000000oooo01@0oooo00<000000?ooo`3oool0:P3oool001<0oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo05L0oooo00<00000
07^QkP0000001000000308>QiP0300000023WNH0PigV0080PigV00<0000008^MgP00000030000006
0;g>iP030000002mc^h0_Lk^00@0_Lk^2P0000090:BUgP030000002TZ]h0Y:[N00@0Y:[N00<00000
0:BZgP2TZ]h00P2TZ]h00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02T0oooo000C0?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1F0?oo
o`030000001kXNh0Nj7^0080Nj7^00<0000007^MiP000000300000030;g:iP030000002mc^H0_LkV
00T0_LkV00<000000;g>kP2mc^h02P2mc^h010000000_M;^0;gBkP2md^h6000000D0Y:GN00<00000
0:BZgP2TZ]h00P2TZ]h00`000000Y:[N0:BZgP040:BZgP030000003oool0oooo0180oooo00<00000
0?ooo`3oool0:@3oool001@0oooo0P0000050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0EP3oool30000000407^QkP000000NigV07^MiPD000002P2mb^H00`000000_LkV0;g>iP09
0;g>iP030000002mc^h0_Lk^00X0_Lk^00D000000;gBkP2md^h0_M;^000000050;gBkP@000000P2T
YMh010000000Y:[N0000000000080:BZgP030000003oool0oooo0180oooo00<000000?ooo`3oool0
:03oool001/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1F0?ooo`030000001c
WNh0000000<0000000<0_LKV0000002mb^H0302mb^H00`000000_LkV0;g>iP090;g>iP030000002m
c^h0_Lk^00T0_Lk^00<000000;gBkP2md^h00`2md^h00`000000_M;^0;gBkP030;gBkP030000002d
d^h0]=;^00@000002P2TZ]h00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02L0oooo000K
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0E03oool4000000@0_LKV00<00000
0;g:iP2mb^H02P2mb^H00`000000_LkV0;g>iP0:0;g>iP030000002mc^h0_Lk^00P0_Lk^00<00000
0;gBkP2md^h0102md^h00`000000_M;^0;gBkP020;gBkP030000002dd^h0]=;^00@0]=;^10000008
0:BZgP030000003oool0oooo0180oooo00<000000?ooo`3oool09`3oool001/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`1@0?ooo`<00000202ma^H00`000000_L[V0;g:iP0:0;g:
iP030000002mc^H0_LkV00T0_LkV00<000000;g>kP2mc^h0202mc^h00`000000_M;^0;gBkP050;gB
kP050000002md^h0_M;^0;gBkP0000002`2dd^h2000000L0Y:[N00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0V0?ooo`006`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
04`0oooo0`00000;0;g6iP030000002mb^H0_L[V00X0_L[V00<000000;g>iP2mc^H00`2mc^H;0000
00H0_Lk^00<000000;gBkP2md^h01@2md^h010000000_M;^0;gBkP00000<0;CBkP040000002dd_H0
0000000000H0Y:[N00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0U0?ooo`006P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04T0oooo0P0000000`2ma]h000000;g6iP0<
0;g6iP030000002mb^H0_L[V00L0_L[V200000060;g>iP030000002md^h0_M;^0080_M;^2P000004
0;gBkP030000002md^h0000000`0]=;^00<000000;CBmP2dd_H00P2dd_H00`000000Y:[N0:BZgP03
0:BZgP8000004`3oool00`000000oooo0?ooo`0U0?ooo`006P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo04D0oooo0`0000040;g6gP030000002ma^H0_LKV00X0_LKV00<000000;g:
iP2mb^H00`2mb^H400000080aLkV00<000000;g>iP2mc^H0202mc^H00`000000_M;^0;gBkP070;gB
kP030000002me^h0_MK^00<0_MK^1`00000:0;CBkP8000001P2dd_H2000000030:BZgP0000000000
0080[:[N00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0T0?ooo`006P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0480oooo0`0000070;g6gP030000002ma^H0_LKV00X0
_LKV00<000000;g:iP0000000`0000060<G>iP030000002mc^H0_LkV00P0_LkV00<000000;gBkP2m
d^h01`2md^h00`000000_MK^0;gFkP070;gFkP030000002me^h0_MK^00<000001P2dd^h00`000000
]=;f0;CBmP080;CBmP8000000`2/Z]h00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02<0
oooo000J0?ooo`800000403oool00`000000oooo0?ooo`0o0?ooo`8000002`2ma]h00`000000_LKV
0;g6iP080;g6iP<000002P35c^H00`000000_LkV0;g>iP080;g>iP030000002md^h0_M;^00H0_M;^
00<000000;gFkP2me^h01`2me^h2000000D0_MK^0`0000020;CBkP030000002dd_H0]=;f00X0]=;f
0P0000030:bZgP030000003oool0oooo0140oooo00<000000?ooo`3oool08`3oool001X0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0k0?ooo`<000003@2ma]h00`000000_LKV0;g6
iP040;g6iP@0000000<0aL[V00000035c^H02P35c^H00`000000_LkV0;g>iP080;g>iP030000002m
d^h0_M;^00H0_M;^00<000000;gFkP2me^h01`2me^h2000000P0_MK^0`00000:0;CBmP8000000P2/
d_H2000000030:bZgP000000oooo01<0oooo00<000000?ooo`3oool08P3oool001X0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0h0?ooo`8000000P2m`]h00`000000_LKN0;g6gP0<
0;g6gP030000002ma^H0000000<000001@35b^H00`000000aLkV0<G>iP090<G>iP030000002mc^H0
_LkV00L0_LkV00<000000;gBkP2md^h00P2md^h9000000D0_MK^00<000000;gFkP0000001`2me^h2
00000080]=Kf0P0000060;CBmP8000001P2/d_H00`000000[:[N0000000D0?ooo`030000003oool0
oooo0240oooo000J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0=@3oool20000
00@0_L;N00<000000;g6gP2ma]h02`2ma]h3000000T0aL[V00<000000<G>iP35c^H02@35c^H00`00
0000_LkV0;g>iP020;g>iPX000000`35e^h00`000000_M[^0;gJkP030;gJkPH0000000<0_MK^0000
002me^h01@2me^h00`000000]=Kf0;CFmP040;CFmP8000000P2dd_H2000000T0[=;f00<000000:bZ
gP0000004`3oool00`000000oooo0?ooo`0Q0?ooo`006P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0380oooo0P0000070;g2gP030000002ma]h0_LKN00P0_LKN0P0000000`35a]h0
00000<G:iP0:0<G:iP0300000035c^H0aLkV00H0aLkV1`0000050<GBiP0300000035e^h0aMK^00D0
aMK^00<000000;gJkP2mf^h01P2mf^h00`000000_M[f0;gJmP0400000080_MK^0P0000090;CFmP80
0000302/d_H2000001@0oooo00<000000?ooo`3oool0803oool001X0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0_0?ooo`8000002@2m`]h00`000000_LKN0;g6gP050;g6gP<00000
1035a]h00`000000aL[V0<G:iP080<G:iP0300000035c^H0aLkV00H000000P35c^H00`000000aM;V
0<GBiP060<GBiP0300000035e^h0aMK^00D0aMK^00<000000;gJkP2mf^h01P2mf^h00`000000_M[f
0;gJmP020;gJmP030000002mf_H0_M[f00<000002@2de_H2000000030:cFmP000000000000/0[=;f
0P00000D0?ooo`030000003oool0oooo01l0oooo000I0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0;03oool2000000`0_L;N00<000000;g6gP2ma]h00P2ma]h2000000L0aLKN00<0
00000<G:iP35b^H01`35b^H4000000P0aLkV00<000000<GBiP35d^H01P35d^H00`000000aMK^0<GF
kP050<GFkP030000002mf^h0_M[^00H0_M[^00<000000;gJmP2mf_H00P2mf_H010000000_M[f0;gJ
mP0000020;CNmP8000001P2de_H00`000000[=Kf0:cFmP030:cFmP030000002/d_H0[=;f00D0[=;f
0`0000000`2/Z]h000000000000C0?ooo`030000003oool0oooo01l0oooo000I0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0:P3oool00`000000_L;N0;g2gP0<0;g2gP030000002m
a]h0_LKN008000002@35a]h00`000000aL[V0<G:iP030<G:iP@0000000<0aL[N00000035c^H02035
c^H00`000000aM;V0<GBiP060<GBiP0400000035e^h0aMK^0<GFkPP000001@2mf^h00`000000_M[f
0;gJmP030;gJmP<000001@2dg_H200000080]=Kf0P0000070:cFmP8000000P2/d_H3000000@0[:[N
0`00000C0?ooo`030000003oool0oooo01h0oooo000I0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool09`3oool2000000030;fngP000000_L;N00d0_L;N0P00000<0<G6gP0300000035
b^H00000008000001@35b]h00`000000aLkV0<G>iP070<G>iP0300000035d^H0aM;V0080aM;V2000
00040<GJkP0400000035g^h0aMk^0<GNkPL00000102mf_H00`000000]=kf0;CNmP070;CNmP800000
2P2/e_H3000000@0[:[N0`0000000`2/[]h000000000000D0?ooo`030000003oool0oooo01d0oooo
000I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09@3oool00`000000_KkN0;fn
gP020;fngP030000002m`]h0_L;N00T0_L;N0P0000000`2m`]h000000<G6gP0:0<G6gP<000002035
b]h00`000000aLkV0<G>iP060<G>iPH000001035d^H00`000000aM[^0<GJkP040<GJkP0300000035
g^h0aMk^00D0aMk^00@000000;gNmP2mg_H0_Mkf1@0000070;CNmP8000000P2/g_H2000000H0[=Kf
0P000000102/e_H0[:[E0000002/Z]h3000000D0[:kN0P00000C0?ooo`030000003oool0oooo01d0
oooo000I0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool08`3oool00`000000_KkN
0;fngP040;fngP030000002m`]h0_L;N00H0_L;N0P0000030;g2gP0300000035a]h0aLKN00L0aLKN
0P0000000`35a]h000000<G:gP090<G:gP0300000035c^H0aLkV0080aLkV0`0000000`35c^H00000
0<GBiP060<GBiP0300000035f^h0aM[^00D0aM[^00<000000<GNkP35g^h01035g^h00`000000_Mkf
0;gNmP030;gNmP80000000<0]>;f0000000000000P0000020;CNmP8000001P2/g_H200000080[=Kf
0P0000030:bZe@<00000202/[]h3000001<0oooo00<000000?ooo`3oool0703oool001T0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0Q0?ooo`8000001`2m_]h00`000000_L;N0;g2
gP050;g2gP030000002m`]h0_L;N00@0_L;N00<000000<G6gP35a]h01035a]h2000000@0aLKN00<0
00000<G:gP35b]h01`35b]h00`000000aLkV00000002000000@0aLkV00<000000<GBiP35d^H01@35
d^H00`000000aM[^0<GJkP040<GJkP0300000035g^h0aMk^00@0aMk^00<000000;gNmP2mg_H00`2m
g_H01@000000]>;f0;CRmP2dh_H0000000<0]>;f0P0000090:cNmP<0000000<0[:[E000000000000
0P0000000`2/Z]D000000:b^gP090:b^gP800000503oool00`000000oooo0?ooo`0K0?ooo`006@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01l0oooo00<000000;fngP2m_]h0202m
_]h00`000000_L;N0;g2gP020;g2gP800000202m`]h010000000aLKN0<G6gP35a]h2000000H0aLKN
00<000000<G:gP35b]h01P35b]h3000000L0aLkV00<000000<GBiP35d^H00`35d^HH00000080]>;f
00@000000;CRmP00000000000P2/h_l2000000<0[=kf10000000102/YMD000000000000000060:bZ
e@030000002/[]h0[:kN00L0[:kN00<000000:CBmP0000004`3oool00`000000oooo0?ooo`0K0?oo
o`006@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0oooo00<000000;fngP2m
_]h02P2m_]h010000000_L;N00000000000:0;g2gP0400000035a]h00000000000P0aLKN00<00000
0<G:gP35b]h00`35b]h3000000030<G:gP000000aLkV00L0aLkV00<000000<GBiP0000000`000000
0`3=e^H000000<gJiP050<gJiP0300000035h^h0aN;^00<0aN;^00<000000<GVmP35i_H00P35i_H2
000000<0_NKf100000060:cRo`<0000000<0[:GE0000000000000P0000000`2/Z]D000000:bZe@06
0:bZe@030000002/[]h0[:kN00L0[:kN00<000000:CBmP000000503oool00`000000oooo0?ooo`0J
0?ooo`00603oool2000001l0oooo00<000000?ooo`3oool06P3oool2000000h0_KkN00<000000;g2
gP2m`]h02`2m`]h00`000000aLKN0<G6gP090<G6gP0300000035b]h00000008000001035b]h00`00
0000aLkV0<G>iP040<G>iP@000001@3=e^H00`000000cM[V0<gJiP030<gJiP0300000035h^h0aN;^
00<0aN;^00<000000<GVmP35i_H00P35i_H00`000000_NKf0;gVmP030;gVmPD000000`2/h_l20000
00040:CNo`0000000000000000H0[:[E00<000000:bZe@2/Z]D01@2/Z]D00`000000[:kN0:b^gP07
0:b^gP030000002Td_H0000001@0oooo00<000000?ooo`3oool06@3oool001P0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0H0?ooo`030000002m_]h0_KkN00`0_KkN0P0000000`2m
_]h000000;g2gP090;g2gP80000000<0aL;N00000035a]h02035a]h3000000P0aL[N00<000000<G>
iP0000000`0000020<gBiP030000003=e^H0cMKV00<0cMKV00<000000<gJiP3=f^H0400000030;gV
mP8000000P2/i_l00`000000[>Ko0:cVo`06000000030:bUe@000000[:[E00H0[:[E00<000000:bZ
e@2/Z]D01@2/Z]D00`000000[:kN0:b^gP070:b^gP030000002Td_H0000001D0oooo00<000000?oo
o`3oool0603oool001P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0F0?ooo`03
0000002m_]h0000000`0_KkN00<000000;fngP2m_]h00P2m_]h00`000000_L;N0;g2gP050;g2gP80
00001035`]h00`000000aLKN0<G6gP040<G6gP80000000<0aLKN00000035b]h01`35b]h3000000H0
cM;V00<000000<gFiP3=e^H00P3=e^H4000000<0cMkV00<000000<gVkP3=i^h00P3=i^h00`000000
aN[f0<GZmP020<GZmP030000002mk_H0_Nkf00@000000`2/i_l6000000D0[:GE00<000000:bZe@2/
Z]D0102/Z]D00`000000[:[E0:bZe@060:bZe@030000002/[]h0[:kN00L0[:kN0`00000D0?ooo`03
0000003oool0oooo01P0oooo000H0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
503oool01@000000_KkN0;fngP2m_]h0000000T0_KkN0P0000060;fngP030000002m`]h0_L;N0080
_L;N0P0000060<G2gP0300000035a]h0aLKN0080aLKN0P0000040<G6gP0300000035b]h0aL[N00<0
aL[N0P0000000`3=c]h000000<gBiP060<gBiP030000003=e^H000000080000000<0cM[V0000003=
g^H0103=g^H00`000000cNK^0<gVkP020<gVkP0500000035j_H0aN[f0<GZmP0000000`2mk_H20000
0080[>ko1P0000000`2/YLd000000:bUe@050:bUe@030000002/Z]D0[:[E00D0[:[E00<000000:bZ
e@2/Z]D01@2/Z]D00`000000[:kN0:b^gP050:b^gP<0000000<0Y<kf0000003oool0503oool00`00
0000oooo0?ooo`0G0?ooo`00603oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0180
oooo00<000000;fngP2m_]h00`2m_]h2000000H0_KkN00<000000;fngP2m_]h01`2m_]h010000000
_L;N0000000000090<G2gP0400000035a]h00000000000H0aLKN00@000000<G:gP35b]h0aL[N0P00
00030<g>gP030000003=d^H0cM;V00@0cM;V0`0000040<gJiP030000003=g^H0cMkV0080cMkV00<0
00000<gVkP3=i^h0300000020:c^o`D00000102/YLd00`000000[:GE0:bUe@030:bUe@030000002/
Z]D0[:[E00D0[:[E00<000000:bZe@2/Z]D01P2/Z]D00`000000[:kN0:b^gP0400000080[:kN00<0
00000:C>mP0000005P3oool00`000000oooo0?ooo`0F0?ooo`00603oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0100oooo00<000000;fngP2m_]h01P2m_]h00`000000_KkN0;fngP02
0;fngP030000002m_]h0_KkN00T0_KkN00<000000<G2gP35`]h02P35`]h00`000000aLKN0<G6gP07
0<G6gP<000001P3=c]h010000000cM;V0<gBiP3=d^H2000000030<gBgP000000cM[V00<0cM[V00<0
00000<gNiP3=g^H01P0000000`3=j^h000000<gbkP020<gbkP030000002mm_H0_OKf0080000000<0
Y?;f0000000000000P0000020:bQc@800000102/YLd00`000000[:GE0:bUe@040:bUe@030000002/
Z]D0[:[E00D0[:[E00@000000:bZe@2/Z]D0[:[E1`0000070:b^gP8000005P3oool00`000000oooo
0?ooo`0F0?ooo`00603oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00h0oooo00<0
00000;fngP2m_]h0202m_]h010000000_KkN00000000000;0;fngP0300000035_]h0000000T0aL;N
0P0000000`35`]h000000<G6gP070<G6gP030000003=c]h0cLkN00H0cLkN00@000000<gBiP000000
00000`3=d]h010000000cM[V0<gJiP3=f^H400000080eN;V00<000000<gZkP0000003@0000000`2/
WLd000000:bQc@030:bQc@030000002/YLd0[:G=00<0[:G=00<000000:bUe@2/YMD00`2/YMD00`00
0000[:[E0:bZe@040:bZe@D00000102/[]D00`000000[:kN0:b^gP070:b^gP8000005`3oool00`00
0000oooo0?ooo`0E0?ooo`00603oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0
oooo00<000000;fngP2m_]h02P2m_]h00`000000_KkN0;fngP0:0;fngP0500000035_]h0aKkN0<Fn
gP0000001P35`]h2000000<0aL;N00<000000<G6gP35a]h01035a]h3000000L0cLkN0`0000040<gB
gP030000003=f^H000000080000000@0eM[V0000003Eh^H0eN;V100000000`3Ek^H000000<gfkP02
0<gfkPH0000000<0[9W50000002/WLd00P2/WLd010000000[:7=0:bQc@2/XLd2000000@0[:G=00<0
00000:bUe@2/YMD0102/YMD00`000000[:[E00000003000000030:bZe@000000[:kE00H0[:kE00<0
00000:b^gP2/[]h01`2/[]h2000001P0oooo00<000000?ooo`3oool0503oool001P0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0;0?ooo`030000002m_]h0_KkN00X0_KkN00@00000
0;fngP0000000000202m_]h2000000D0aKkN00<000000<G2gP35`]h00P35`]h00`000000aL;N0<G2
gP040<G2gP0400000035a]h0aLKN0<G6gP8000000`35a]h00`000000cLkN0<g>gP020<g>gP800000
00<0cLkN0000003=d]h00`3=d]h3000000@0eM[V0`0000000`3Ei^H000000=G^iP020=G^iPL00000
00D0[9W50000002/VLD0[9W5000000030:bMc@030000002/XLd0[:7=0080[:7=00<000000:bUc@2/
YLd00`2/YLd00`000000[:GE0:bUe@05000000D0[:[E00<000000:b^e@2/[]D01P2/[]D00`000000
[:kN0:b^gP060:b^gP800000603oool00`000000oooo0?ooo`0D0?ooo`00603oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo00T0oooo00<000000;fngP2m_]h02P2m_]h00`000000_KkN
0;fngP020;fngP030000002m_]h0_KkN00@0_KkN00<000000<FngP35_]h01P35_]h010000000aL;N
0000000000070<G2gP0400000035a]h00000000000D0aLKN00<000000<g>gP3=c]h00P0000030<g>
gP030000003=d]h000000080000000<0eM;N0000003Ef^H00`3Ef^H200000080eNKV00<000000=G^
iP0000001P0000001@2/UKd000000:bIa@2/VLD0000000<0[9W500@000000:bMc@2/WLd00000102/
XLd010000000[:G=0:bUc@2/YLd5000000<0[:[E00<000000:bZe@2/Z]D01@2/Z]D00`000000[:kE
0:b^e@050:b^e@030000002/[]h0[:kN00L0[:kN00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0C0?ooo`00603oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00L0oooo00<0
00000;fngP2m_]h02P2m_]h00`000000_KkN0;fngP040;fngP030000002m_]h0_KkN0080_KkN00<0
00000<FngP35_]h02035_]h00`000000aL;N0<G2gP080<G2gP0300000035a]h0aLKN00H0aLKN0P00
00040<g>gP<00000103Ed]h00`000000eM[V00000002000000030=GJgP000000eNKV00<000000P3N
l^H5000000030:bE_@000000[9W50080[9W500@000000:bIa@2/VLD000000`2/WLd00`000000[:7=
0:bQc@0500000080]:G=00<000000:bZe@2/Z]D00`2/Z]D00`000000[:[E0:bZe@050:bZe@030000
002/[]D0[:kE00D0[:kE00<000000:b^gP2/[]h01`2/[]h00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0180oooo000G0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01@3o
ool010000000_K[N0000000000090;fngP030000002m_]h0_KkN00H0_KkN0P0000000`2m_]h00000
0<FngP080<FngP80000000<0aKkE00000035`]h01@35`]h2000000030<G2gP000000aLKN00D0aLKN
0`0000030<g>gP80000000<0cLkN0000003Ed]h0103Ed]h2000000<0eM[N0`0000000`3Ni]h00000
0=kbiP04000000030;B=]000000000000080[9Fm00D000000:bIa@2/VLD000000:bIa@0800000003
0;BUc@000000000000@0]:G=00<000000:bZe@2/Z]D00`2/Z]D00`000000[:[E0:bZe@050:bZe@03
0000002/[]D0[:kE00D0[:kE00<000000:b^gP2/[]h01`2/[]h00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo0180oooo000G0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
0`3oool00`000000_K[N0;fjgP020;fjgP030000002m_]h0_KkN00D0_KkN00<000000;fngP2m_]h0
2@2m_]h00`000000aKkN0<FngP070<FngP0500000035_]D0aKkE0<Fne@0000001035`]h2000000@0
aL;N00@000000<G6gP35a]h0aLKN0P0000030<g:gP<000000`3=c]h010000000eM;N0=GBgP3Ed]h3
000000<0eM[N0P0000020=kVgP@0000000<0g_o=0000002dSJ`00P0000000`2/TKd0000000000005
000000030;BQa@000000]:7=0080]:7=00@000000;BUc@2dYLd0]:G=0P0000040;BUc@030000002/
Z]D0[:[E00@0[:[E00<000000:bZe@2/Z]D0102/Z]D00`000000[:kE0:b^e@060:b^e@030000002/
[]h0[:kN00L0[:kN00<000000?ooo`3oool05`3oool2000001<0oooo000G0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool00P3oool00`000000_K[N0;fjgP030;fjgP800000102m_]h0
0`000000_KkN0;fngP090;fngP030000002m^]D0000000L0aKkN00<000000<Fne@35_]D00`35_]D0
10000000aL;N0000000000060<G2gP0400000035a]h00000000000D0cL[N00<000000<g>gP3=c]h0
103=c]h3000000<0eMKN0`0000001@3Ng]h00000000000000000g^KN00X0000000D0]9Vm0000002d
WLD0]9g5000000020;BQa@050000002dXLd0]:7=0;BQc@0000000`2dYLd2000000D0]:G=00<00000
0:bZe@2/Z]D00`2/Z]D00`000000[:[E0:bZe@050:bZe@030000002/[]D0[:kE00D0[:kE00<00000
0:b^gP2/[]h00P2/[]h6000001H0oooo0`0000000`3oool000000?ooo`0B0?ooo`005`3oool00`00
0000oooo0?ooo`0/0?ooo`040000003oool0oooo000000P0_K[N0P0000000`2m_]h000000;fngP0:
0;fngP040000002m^]D0_K[E0;fje@8000000`35_]h2000000L0aKkE00<000000<G2gP35`]h01`35
`]h00`000000cL[N0<g:gP030<g:gP<000001P3=c]h00`000000eMKN0=GFgP020=GFgP8000000P3N
g]h200000080g^KN00<000000>Kbe@0000001P000000102mVKd000000;BI_@0000020;BMa@040000
002dXLD0]:75000000@0]:7=00H000000;BUc@2dYLd000000;BUc@0000040;BUc@030000002/Z]D0
[:[E00<0[:[E00<000000:bZe@2/Z]D01@2/Z]D010000000[:kE0:b^e@2/[]D9000000D0];;N00<0
00000?ooo`3oool04@3oool3000000@0oooo00<000000?ooo`3oool04@3oool001L0oooo0P00000^
0?ooo`8000002`2m^]h00`000000_KkN0;fngP090;fngP030000002m^]D0_K[E00@0_K[E00<00000
0<FngP0000002035_]D00`000000aKkE000000060<G2gP80000000<0cL;E0000003=b]h00P3=b]h0
1@000000cL[E0<g:e@3=b]D0000000<0cLkN0`0000020=GFgP80000000D0eMKE0000000000000000
0=kNe@09000000050<FI[000000000000;fI_@0000000P2dVKd010000000]9g50;BMa@0000020;BQ
a@050000002dXLd0]:7=0;BQc@0000000P2dYLd00`000000]:G=000000040;BUc@030000002/Z]D0
[:[E00l00000102d[]D00`000000];;N0;BbgP070;BbgP030000003oool0oooo00h0oooo0`000007
0?ooo`030000003oool0oooo0140oooo000G0?ooo`030000003oool0oooo02d0oooo00<000000;fj
gP2m^]h02@2m^]h010000000_K[N0000000000080;fngP030000002m^]D0_K[E00H0_K[E00<00000
0<Fne@35_]D01P35_]D01@000000aKkE0<Fne@35_]D0000000@0aL;N00H000000<g2e@3=`]D0cL;E
0000003=b]h2000000@0cL[E00@000000<g>gP00000000000`3Ec]D2000000<0eMKE00D000000=kN
e@3Ng]D0g]kE000000020>KVe@T0000000D0_IVm0000002dVKd0]9Vm000000020;BMa@050000002d
XLD0]:750000002dXLd03`0000030;B^e@030000002d[]D0]:kE00D0]:kE00<000000;B^e@2d[]D0
1@2d[]D00`000000];;N0;BbgP070;BbgP030000003oool0oooo00/0oooo0`00000:0?ooo`030000
003oool0oooo0140oooo000G0?ooo`030000003oool0oooo02d0oooo00<000000;fjgP2m^]h02@2m
^]h010000000_K[N0;fjgP2m^]h2000000D0_KkN00<000000;fje@2m^]D01P2m^]D00`000000aK[E
000000060<Fne@0300000035_]D0aKkE00<0aKkE00@000000<G2gP00000000001@3=`]D00`000000
cL[E0<g:e@040<g:e@8000000`3Ec]D300000080eMKE0`0000000`3Ng]D000000000000900000003
0<fU]0000000000000`000000P2dYLd01P000000]:[=0;BZc@000000]:[=000000@0]:[=00<00000
0;B^e@2d[]D00`2d[]D00`000000]:kE0;B^e@050;B^e@030000002d[]D0]:kE00D0]:kE00<00000
0;BbgP2d/]h01`2d/]h00`000000oooo0?ooo`080?ooo`<000003@3oool00`000000oooo0?ooo`0A
0?ooo`005`3oool00`000000oooo0?ooo`0/0?ooo`030000002m^]h0_K[N00T0_K[N00<000000;fj
gP2m^]h0102m^]h200000080_KkN00<000000;fje@2m^]D01P2m^]D010000000aK[E0<Fje@35^]D2
000000<0aKkE00<000000<Fne@35_]D01@35_]D00`000000cL;E0<g2e@040<g2e@030000003=a]D0
000000<0cL[E0P0000000`3=b]D000000=G>e@02000000<0eLkE0P0000020=kFe@8000000P3Nf]D0
0`000000i^;=00000002000000050>k:_@000000eJjd0000003=YK@00P0000001@35XKd000000;fQ
_@2mXKd000000080_JG500@000000;fUa@2mYLD000000`2dYLd01P000000]:[=0;BZc@000000]:[=
000000@0]:[=00<000000;B^e@2d[]D00`2d[]D00`000000]:kE0;B^e@050;B^e@030000002d[]D0
]:kE00D0]:kE00<000000;BbgP2d/]h01`2d/]h00`000000oooo0?ooo`050?ooo`<000004@3oool0
0`000000oooo0?ooo`0@0?ooo`005`3oool00`000000oooo0?ooo`0[0?ooo`8000002P2m^]h00`00
0000_K[N0;fjgP070;fjgP800000202m^]D00`000000aK[E0<Fje@040<Fje@0300000035_]D00000
00L0aKkE00<000000<Fne@0000000`3=`]D200000080cLKE00@000000<g:e@0000000000103=b]D0
0`000000eLkE0=G>e@030=G>e@030000003Ne]D0g]KE008000000P3Nf]D;000000040<FQ]0000000
aJ6m00000080_J6m00@000000;fUa@2mYLD000000P2mYLD01@000000]:G=0;BUc@2dYLd000000080
]:[=00<000000;BZc@000000102dZ/d00`000000]:kE0;B^e@030;B^e@030000002d[]D0]:kE00D0
]:kE00<000000;B^e@2d[]D01@2d[]D00`000000];;N0;BbgP070;BbgP030000003oool0oooo0080
oooo0`00000D0?ooo`030000003oool0oooo0100oooo000F0?ooo`030000003oool0oooo02/0oooo
00<000000;BfgP2d]]h00P0000070;fjgP030000002m^]h0_K[N00P0_K[N00@000000;fje@000000
00001@2m^]D00`000000aK[E0<Fje@060<Fje@0300000035_]D0aKkE00@0aKkE0P0000030<Fne@03
0000003=`]D0000000D0cLKE00<000000<g:e@3=b]D00`3=b]D2000000<0eLkE1@0000001`3Nd]D0
00000=kJe@000000i][=0000003Vf/d00P000000103^b[d000000000003E][d4000000040<FQ_@00
0000_J6m00000080_JG500D000000;fUa@2mYLD0_JG5000000030;BUc@060000002dZ/d0]:[=0000
002dZ/d00000102dZ/d00`000000]:kE0;B^e@040;B^e@030000002d[]D0]:kE00@0]:kE00<00000
0;B^e@2d[]D01@2d[]D00`000000];;N0;BbgP070;BbgP030000003oool0oooo008000005`3oool0
0`000000oooo0?ooo`0@0?ooo`005P3oool00`000000oooo0?ooo`0[0?ooo`030000002d]]h0];KN
0080];KN0P0000050;fjgP030000002m^]h0_K[N00L0_K[N00<000000;fje@2m^]D00P2m^]D20000
0080_K[E00<000000<Fje@35^]D01P35^]D00`000000aK[E000000040<Fne@0300000035_]D0aKkE
00@0aKkE00<000000<g6e@3=a]D00`3=a]D00`000000cLKE000000020<g:e@8000000P3Eb]D30000
0080eLkE00@000000=kBe@3Nd]D0g];E10000000103Vd/d000000000003Vb/D2000000050=Ff_@00
0000eK:m0000003=[[d01P0000000`2mYLD000000;fUa@020;fUa@050000002dYLd0]:G=0;BUc@00
00000P2dZ/d00`000000]:[=000000040;BZc@030000002d[]D0]:kE00@0]:kE00<000000;B^e@2d
[]D0102d[]D00`000000]:kE0;B^e@050;B^e@030000002d/]h0];;N00L0];;N0`00000I0?ooo`03
0000003oool0oooo0100oooo000F0?ooo`030000003oool0oooo02X0oooo00<000000;BfgP2d]]h0
1@2d]]h200000080_K[N00<000000;fjgP2m^]h01`2m^]h00`000000_K[E0;fje@050;fje@800000
2035^]D010000000aK[E0<Fje@35^]D2000000030<Fne@000000aKkE00D0aKkE00<000000<fne@00
00000P3=a]D200000080cLKE00<000000<g:e@000000103Eb]D00`000000eLkE0=G>e@0300000005
0=kBe@00000000000=kBc@0000000P3Vd/d2000000050>K:a@000000g/:m0000003E][d00P000002
0<f^_@0600000035Z[d000000<FZa@000000_J[53@0000000`2dZ/d000000;BZc@030;BZc@030000
002d[]D0]:kE00@0]:kE00<000000;B^e@2d[]D0102d[]D00`000000]:kE0;B^e@050;B^e@030000
002d/]h0];;N00L0];;N00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0@0?ooo`005P3o
ool00`000000oooo0?ooo`0Z0?ooo`030000002d]]h0];KN00L0];KN0`0000090;fjgP030000002m
^]D0_K[E00D0_K[E00<000000;fje@0000001P35^]D00`000000aK[E0<Fje@040<Fje@0300000035
_]D0aKkE00@0aKkE00H000000<fne@3=_]D000000<g6e@0000050<g6e@040000003Eb]D0eL[E0=G:
e@<0000000<0eLkE0000003Ec]D00P3Ec]D00`000000g];=0=kBc@02000000050>KBc@0000000000
0000003Vb/D00P0000001P3E^[d00000000000000000cJjm00000080aJZm00<000000<FZa@000000
0P2mZ/D01@000000_J[50;fZa@2mZ/D0000000<0_J[=00<000000;f^c@2m[/d08P0000050;BbgP03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0403oool001H0oooo00<000000?ooo`3oool0
:@3oool00`000000];KN0;BfgP080;BfgP030000002m]]D0_KKE008000001P2m^]h00`000000_K[E
0;fje@060;fje@030000002m^]D0_K[E008000000`35^]D00`000000aK[E0<Fje@040<Fje@030000
0035^]D0000000@0aKkE00<000000<fne@3=_]D00P3=_]D00`000000cLKE0<g6e@030<g6e@050000
003=a]D000000=G:e@0000000`3Eb]D010000000eLkE0=G>e@3Ec]D20000000>0=kBc@000000g/k=
0=k>c@000000i/k50000003Nb/D000000=k2_@000000eKZm0000003E][d3000000040<FZ_@000000
aJ[5000000<0_J[500D000000;fZa@2mZ/D0_J[5000000030;fZc@060000002m[/d0_Jk=0000002m
[/d00000102d[]D00`000000]:kE0;B^e@040;B^e@030000002d/]D0];;E00@0];;E00<000000;Bb
e@2d/]D01@2d/]D00`000000];;N0;BbgP020;BbgPH000006`3oool00`000000oooo0?ooo`0@0?oo
o`005P3oool00`000000oooo0?ooo`0X0?ooo`030000002d]]h0];KN00T0];KN00<000000;ffe@2m
]]D00P2m]]D300000080_K[N00<000000;fje@2m^]D01P2m^]D00`000000_K[E0;fje@030;fje@03
00000035^]D0000000H0aK[E00@000000<Fje@35^]D0aK[E0P0000000`35_]D000000<fne@030<fn
e@030000003=_]D0000000<0cLKE00D000000<g6e@3=a]D0cLKE000000030=G:e@050000003Eb/d0
00000=G>e@0000000P3Nc/d03P000000g/k=0=k>c@000000g/[=0000003Nb/D000000=k2a@000000
eKZm0000003E][d000000P3=//D3000000030<FZa@000000_J[50080_J[500@000000;fZa@2mZ/D0
0000102mZ/d01P000000_Jk=0;f^c@000000_Jk=000000@0]:kE00<000000;B^e@2d[]D0102d[]D0
0`000000];;E0;Bbe@040;Bbe@030000002d/]D0];;E00D0];;E00<000000;BbgP2d/]h01`2d/]h0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0100oooo000F0?ooo`030000003oool0oooo
02P0oooo00<000000;BfgP2d]]h0202d]]h00`000000_KKE0;ffe@060;ffe@<000001`2m^]D00`00
0000_K[E0;fje@050;fje@8000001@35^]D00`000000aK[E0<Fje@040<Fje@030000003=_]D0cKkE
0080cKkE00L000000<fne@3=_]D0cKkE0000003=a]D0000000<0cLKE00<000000=G6c@0000000P3E
b]D010000000eL[=0=G:c@0000020=k>c@80000000<0g/k=0000003Nb/d00P000000103Nb/D00000
0000003E_/D2000000040=Ff_@000000cK;500000080cK;5200000000`2mZ/D000000;fZc@020;fZ
c@070000002m[/d0_Jk=0;f^c@000000_Jk=000000040;B^e@030000002d[]D0]:kE00@0]:kE00<0
00000;Bbe@2d/]D0102d/]D00`000000];;E0;Bbe@050;Bbe@030000002d/]h0];;N00L0];;N00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0@0?ooo`005P3oool00`000000oooo0?ooo`0W
0?ooo`030000002d]]h0];KN00T0];KN00<000000;ffe@2m]]D01P2m]]D00`000000_KKE0;ffe@02
000000@0_K[E00<000000;fje@2m^]D01@2m^]D00`000000_KKE0;ffe@0200000080aK[E00<00000
0<Fje@35^]D01035^]D00`000000aK[=000000030<fne@030000003=_]D0cKkE0080cKkE00D00000
0<g6e@3=a]D0cLKE000000020=G6c@030000003Eb]D000000080eL[=0P0000001@3Nc/d000000=k:
c@3Nb/d000000080g/[=00T000000=k:a@000000g/;50000003E_/D000000=Fja@0000000P3=//D0
0`000000cK;5000000020<F^a@0600000035[/D0aJk50<F^a@000000aJk=0`0000020;fZc@040000
002m[/d0_Jk=0;f^c@800000102d[]D00`000000]:kE0;B^e@050;B^e@030000002d/]D0];;E00@0
];;E00<000000;Bbe@2d/]D01@2d/]D00`000000];;N0;BbgP060;BbgP030000003oool0oooo01X0
oooo00<000000?ooo`3oool0403oool001H0oooo00<000000?ooo`3oool09`3oool00`000000];KN
0;BfgP080;BfgP030000002m]]D0_KKE00L0_KKE00<000000;ffe@2m]]D00P2m]]D200000080_K[E
00<000000;fje@2m^]D01@2m^]D00`000000_KKE0;ffe@020;ffe@8000001P35^]D01`000000aK[=
0<Fjc@35^/d000000<fne@000000103=_]D01@000000cL;=0000003=a]D0000000@0eLK=00@00000
0=G:c@3Eb/d000000P3Eb/d00`000000g/[=0=k:c@02000000080=k:c@000000g/[50000003Na/D0
00000=Fna@0000020=Fja@<000000P3=//D010000000aJk50<F^a@0000020<F^a@0600000035[/d0
aJk=0<F^c@000000_K;=1@0000000`2m[/d00000000000040;B^e@030000002d[]D0]:kE00@0]:kE
00<000000;Bbe@2d/]D0102d/]D00`000000];;E0;Bbe@060;Bbe@030000002d/]h0];;N00H0];;N
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0@0?ooo`005@3oool00`000000oooo0?oo
o`0W0?ooo`8000002P2d]]h00`000000_KKE0;ffe@060;ffe@030000002m]]D0_KKE00D0_KKE0P00
00070;fje@030000002m]]D0_KKE00<0_KKE00<000000<Ffc@0000001035^]D00`000000aK[=0<Fj
c@030<Fjc@030000003=_]D0cKkE0080cKkE00D000000<g2c@3=`/d0cL;=000000030=G6c@<00000
00@0eL[=0000003Eb/d0eL[=0P0000001`3Nb/d000000=k:c@3Nb/d000000=k:a@0000000P3Na/D2
00000080eK[500<000000<fja@3=^/D0100000000`35[/D000000<F^a@020<F^a@0400000035[/d0
aJk=000000@0_K;=00<000000;fbc@2m//d01@0000020;B^e@030000002d[]D0]:kE00@0]:kE00<0
00000;Bbe@2d/]D0102d/]D00`000000];;E0;Bbe@050;Bbe@030000002d/]h0];;N00L0];;N00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0?0?ooo`005@3oool2000002P0oooo00<00000
0;BfgP0000000P0000060;BfgP030000002m]]D0_KKE00L0_KKE00<000000;ffe@2m]]D01P2m]]D3
000000@0_K[E00<000000;ffe@2m]]D0102m]]D00`000000aKK=0<Ffc@02000000030<Fje@000000
aK[=00@0aK[=00H000000<fjc@00000000000<fne@0000030<g2c@050000003=`/d000000=G6c@00
00000`3Ea/d01`000000eL[=0=G:c@3Eb/d000000=G:c@0000000P3Nb/d00`000000g/K=00000002
0=k6a@080000003E`/D000000000003E^/D000000<fja@0000020<ffa@030000003=]/D000000080
000000<0aJk500000035[/d00P35[/d01@000000_K;=0;fbc@2m//d0000000@0_K;=0P0000020;fb
e@H000000`2d[]D00`000000];;E0;Bbe@040;Bbe@030000002d/]D0];;E00D0];;E00<000000;Bb
gP2d/]h01`2d/]h00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00l0oooo000E0?ooo`03
0000003oool0oooo02H0oooo00<000000;BfgP2d]]h00`2d]]h400000080];KN00<000000;ffe@2m
]]D01P2m]]D00`000000_KKE0;ffe@060;ffe@040000002m]]D0_KKE0;ffe@8000000P2m^]D00`00
0000_KKE0;ffe@030;ffe@0300000035]/d0aKK=00<0aKK=00<000000<Fjc@35^/d00`35^/d00`00
0000cK[=0<fjc@020<fjc@050000003=`/d0cL;=0<g2c@0000000`3=`/d02P000000eLK=0=G6c@3E
a/d000000=G6c@000000eL[=0000003Eb/d2000000070=k:c@000000g/K=0000003Ea/d000000=k6
a@0200000080eKk500H000000<fja@3=^/D000000<ffa@0000030<ffa@0300000035]/d000000080
000000<0aJk=0000002m//d00`2m//d00`000000_K;=0;fbc@020;fbc@030000002m/]D0_K;E00<0
_K;E00@000000;fbe@2m/]D0_K;E1`0000030;Bbe@030000002d/]D0];;E00D0];;E00<000000;Bb
gP2d/]h01`2d/]h00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00l0oooo000E0?ooo`03
0000003oool0oooo02H0oooo00<000000;BfgP2d]]h01`2d]]h3000000L0_KKE00<000000;ffe@2m
]]D01`2m]]D00`000000_KKE0;ffe@030;ffe@<00000102m]]D00`000000aKK=0<Ffc@030<Ffc@04
00000035]/d0000000000080aK[=00<000000<fjc@3=^/d00P3=^/d01@000000cK[=0000003=`/d0
000000<0cL;=00D000000=G2c@000000eLK=000000030=G6c@030000003Eb/d000000080eLK=00@0
00000=k6c@3Na/d000000P3Ea/d01P000000eL;50000003E_/D000000=Fna@8000000P3=]/D01000
0000cKK50<ffa@0000030<Ffc@0400000035]/d00000000000@0_K;=00<000000;fbc@2m//d00P2m
//d00`000000_K;E0;fbe@020;fbe@030000002m/]D0_K;E00D0_K;E00@000000;Bbe@2d/]D0];;E
1`0000040;Bbe@030000002d/]h0];;N00H0];;N00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0?0?ooo`005@3oool00`000000oooo0?ooo`0V0?ooo`030000002d]]h0];KN00P0];KN00<0
00000;Bbe@0000000`0000030;ffe@030000002m]]D0_KKE00H0_KKE00<000000;ffe@2m]]D0102m
]]D00`000000_K;E0;fbe@0200000080_KKE00<000000<Ffc@35]/d00P35]/d00`000000aKK=0<Ff
c@020<Ffc@800000103=^/d01@000000cK[=0<fjc@3=^/d0000000<0cL;=00D000000=G2c@3E`/d0
eL;=000000020=G6c@80000000H0eLK=0000003Ea/d0eLK=0000003Ea/d200000080eLK=00<00000
0=G2c@0000000P3E_/D00`000000eKk50=Fna@03000000<0cKK500@000000<Ffc@35]/d000000`35
]/d3000000030;fbc@000000_K;=00@0_K;=00<000000;fbe@2m/]D00P2m/]D00`000000_K;E0;fb
e@040;fbe@030000002d/]D0];;E00D0];;E00@000000;Bfe@2d]]D0];KE2@0000040;BbgP030000
003oool0oooo01`0oooo00<000000?ooo`3oool03`3oool001D0oooo00<000000?ooo`3oool09P3o
ool00`000000];KN0;BfgP070;BfgP030000002d/]D0];;E00@0];;E100000080;ffe@030000002m
]]D0_KKE00@0_KKE00<000000;fbe@2m/]D00P2m/]D2000000D0aKK=00<000000<Ffc@35]/d00P35
]/d01P000000aKK=000000000000cK[=000000<0cK[=00D000000<fnc@000000cL;=000000030=G2
c@80000000@0eLK=0000003Ea/d0eLK=0P000000103Ea/d000000=G6c@3Ea/d2000000050=G6c@00
0000eL;=0000003E`/d00P0000020=Fna@030000003=^/d0cK[=00@000000`35]/d010000000aKK=
0<Ffc@0000030<Ffc@@000000P2m//d2000000@0_K;E00<000000;fbe@2m/]D0102m/]D00`000000
];;E0;Bbe@040;Bbe@030000002d]]D0];KE00H0];KE00<000000;BfgP2d]]h00P2d]]h5000001h0
oooo00<000000?ooo`3oool03`3oool001D0oooo00<000000?ooo`3oool09@3oool00`000000];KN
0;BfgP080;BfgP030000002d/]D0];;E00H0];;E00@000000;Bbe@00000000001@2m]]D00`000000
_KKE0;ffe@040;ffe@030000002m/]D0_K;E00@0_K;E0`0000020<Ffc@0300000035]/d0aKK=0080
aKK=00<000000<Ffc@35]/d00P35]/d00`000000cK[=0<fjc@020<fjc@040000003=_/d0cKk=0000
00<0eL;=00@000000=G2c@3E`/d000000`3Ea/d00`000000eLK=000000030=G6c@050000003Ea/d0
00000=G2c@0000000P3E`/d01`000000eL;=0000003E_/D000000<fjc@0000000`3=^/d200000003
0<Ffc@000000aKK=0080aKK=00<000000<Ffc@35]/d00P35]/d00`000000_KKE0;ffe@0500000080
_K;E00<000000;fbe@2m/]D0102m/]D00`000000];;E0;Bbe@050;Bbe@030000002d]]D0];KE00D0
];KE00<000000;BfgP2d]]h01`2d]]h00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00l0
oooo000E0?ooo`030000003oool0oooo02D0oooo00<000000;BfgP2d]]h0202d]]h00`000000];;E
0;Bbe@060;Bbe@040000002d/]D0];;E0;Bbe@<000000P2m]]D00`000000_KKE0;ffe@040;ffe@03
0000002m/]D0_K;E00<0_K;E00@000000;fbc@2m//d0_K;=0P0000050<Ffc@0600000035]/d0aKK=
0<Ffc@000000cKK=0P0000002@3=^/d000000<fnc@3=_/d000000<fnc@000000eL;=000000020=G2
c@0?0000003E`/d000000=G6c@000000eLK=0000003Ea/d000000=G6c@000000eLK=0000003Ea/d0
000000<0eL;=00@000000=G2c@3E`/d000000P3=^/d010000000cK[=0<fjc@0000020<fjc@800000
0`35]/d01@000000aKK=0<Ffc@35]/d0000000D0_KKE00<000000;ffe@000000100000050;fbe@03
0000002d/]D0];;E00D0];;E00<000000;Bfe@2d]]D01@2d]]D00`000000];KN0;BfgP060;BfgP03
0000003oool0oooo01d0oooo00<000000?ooo`3oool03`3oool001D0oooo00<000000?ooo`3oool0
9@3oool00`000000];KN0;BfgP070;BfgP030000002d/]D0];;E00H0];;E00<000000;Bbe@2d/]D0
1@2d/]D3000000D0_KKE00<000000;fbe@2m/]D0102m/]D00`000000_K;=0;fbc@020;fbc@<00000
0P35]/d00`000000aKK=0<Ffc@020<Ffc@050000003=]/d0cKK=0<ffc@0000000`3=_/d010000000
cKk=0<fnc@0000030=G2c@060000003E`/d0eL;=0000003Ea/d000000`3Ea/d02@000000eLK=0000
003Ea/d000000=G6c@000000eL;=000000020=G2c@040000003=_/d00000000000<0cK[=00D00000
0<fjc@3=^/d000000<Fjc@03000000@0aKK=00<000000;ffe@2m]]D00P2m]]D010000000_KKE0;ff
e@0000020;ffe@030000002m]]D000000080000000<0_K;E0000002d/]D01P2d/]D00`000000];KE
0;Bfe@060;Bfe@030000002d]]h0];KN00H0];KN00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0?0?ooo`005@3oool00`000000oooo0?ooo`0U0?ooo`030000002d]]h0];KN00L0];KN00<0
00000;Bbe@2d/]D01P2d/]D00`000000];;E0;Bbe@060;Bbe@030000002m/]D00000008000000P2m
]]D00`000000_K;E0;fbe@030;fbe@030000002m//d0_K;=0080_K;=00@000000<Fbc@35//d0aK;=
0P0000040<Ffc@090000003=]/d0cKK=0<ffc@000000cKK50000003=_/d000000080cKk=00D00000
0=Fnc@000000eL;=000000020=G2c@030000003Ea/d0000000<0eLK=00<000000=G6c@0000000P3E
a/d010000000eLK=0=G6c@0000030=G2c@070000003=_/d000000<fnc@000000cK[=000000030<fj
c@0400000035^/d0aK[=0<Fjc@8000000P35]/d00`000000_KKE0;ffe@030;ffe@060000002m]]D0
_KKE0000002m]]D000001@2m]]D3000000H0];;E00<000000;Bfe@2d]]D01@2d]]D00`000000];KN
0;BfgP070;BfgP030000003oool0oooo01d0oooo00<000000?ooo`3oool03`3oool001@0oooo00<0
00000?ooo`3oool09@3oool00`000000];KN0;BfgP080;BfgP030000002d/]D0];;E00H0];;E00<0
00000;Bbe@2d/]D01@2d/]D00`000000_K;E0;fbe@030;fbe@@00000102m/]D00`000000_K;=0;fb
c@020;fbc@0300000035//d0aK;=0080aK;=0`0000020<Ffc@050000003=]/d0cKK=0<ffc@000000
0P3=]/D01@000000cKk=0<fnc@3=_/d000000080eKk=00/000000=G2c@3E`/d000000=G6c@000000
eLK=0000003Ea/d000000=G6c@02000000090=G6c@000000eLK=0=G6c@000000eL;=0000003E`/d0
00000080cKk=00@000000<fnc@3=_/d000000`3=^/d01@000000aK[=0<Fjc@35^/d000000080aK[E
0`0000040;ffe@070000002m]]D0_KKE0;ffe@000000_KKE000000060;ffe@030000002m]]D00000
00<0000000<0];;E0000002d]]D01`2d]]D00`000000];KN0;BfgP070;BfgP030000003oool0oooo
01d0oooo00<000000?ooo`3oool03`3oool001@0oooo00<000000?ooo`3oool09@3oool5000000D0
];KN00<000000;Bbe@2d/]D01`2d/]D00`000000];;E0;Bbe@050;Bbe@030000002m/]D0_K;E00@0
_K;E00<000000;f^c@2m[/d0100000040;fbc@0400000035//d0aK;=0<Fbc@h0000000@0cK[50000
003=_/d000000P3E_/d010000000eL;50000000000020=G6c@040000003Ea/d0eLK=00000080eLK=
00<000000=G6c@0000000`3Ea/d010000000eL;=0=G2c@0000020<fnc@050000003=_/d0cKk=0000
003=_/d00P0000000`3=^/d000000<Fjc@020<Fjc@0600000035^]D0aK[E0<Fje@000000aK[E0P00
00020;ffe@040000002m]]D0_KKE0;ffe@8000001P2m]]D00`000000_KKE0;ffe@040;ffe@<00000
1`2d]]D00`000000];KN0;BfgP060;BfgP030000003oool0oooo01l0oooo00<000000?ooo`3oool0
3P3oool001@0oooo00<000000?ooo`3oool09@3oool00`000000];;N0;BbgP020;BbgPP000001P2d
/]D00`000000];;E0;Bbe@050;Bbe@030000002m/]D0_K;E00@0_K;E00<000000;f^c@2m[/d03@00
000708^bkP030000002D/^h0U;;^00@0U;;^2P000000103Ea/d000000=G6c@3Ea/d2000000080=G6
c@000000eLK=0000003Ea/d000000=G6c@0000020=G2c@040000003E`/d00000000000<0cKk=00D0
00000<fnc@3=_/d0cKk=000000030<Fjc@0500000035^]D0aK[E0<Fje@0000001035^]D3000000<0
_KKE0P0000060;ffe@030000002m]]D0_KKE00@0_KKE00<000000;ffgP2m]]h0100000020;Bfe@03
0000002d]]h0];KN00L0];KN00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0>0?ooo`00
503oool00`000000oooo0?ooo`0U0?ooo`030000002d/]h0];;N00L0];;N00<000000;Bbe@2d/]D0
100000020;Bbe@030000002d/]D0];;E00D0];;E00<000000;fbe@2m/]D01`00000708^fmP030000
002;/^h0Rk;^00/0Rk;^00<0000009BbkP2D/^h02P2D/^h00`000000U:k^09B^kP0400000080eLK=
00<000000=G6c@0000000`3Ea/d010000000eL;=0=G2c@0000020=G2c@050000003=`/d000000<fn
c@0000000`3=_/d01P000000cKkE000000000000aK[=000000<0aK[E00<000000<Fje@35^]D00P35
^]D00`000000_K[E0;fje@02000000030;ffe@000000_KKE00D0_KKE00<000000;ffe@2m]]D01@2m
]]D00`000000_KKN0;ffgP040;ffgPD000001`2d]]h00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00h0oooo000D0?ooo`030000003oool0oooo02D0oooo00<000000;BbgP2d/]h01`2d/]h0
0`000000];;E0;Bbe@040;Bbe@H000000`2d/]D400000080RkKf00<0000008^fmP2;]_H02P2;]_H0
0`000000Rk;^08^bkP0:08^bkP030000002D/^h0U;;^00X0U;;^00<0000009B^kP2D[^h0102D[^h5
00000080eLK=00@000000=G6c@00000000000P3E`/d01@000000cL;=0<g2c@3=`/d0000000<0cKk=
00<000000<fne@3=_]D00P3=_]D200000080aK[E00<000000<Fje@35^]D00`35^]D00`000000_K[E
0;fje@020;fje@<000001@2m]]D00`000000_KKE0;ffe@040;ffe@030000002m]]h0_KKN00H0_KKN
00@000000;BjgP2d^]h0];[N100000020;BfgP030000003oool0oooo0200oooo00<000000?ooo`3o
ool03P3oool001@0oooo00<000000?ooo`3oool09@3oool00`000000];;N0;BbgP070;BbgP030000
002d/]D0];;E00H0];;E00@000000;B^e@2d[]D0]:kE0`00000708^fmP030000002;]_H0RkKf00T0
RkKf00<0000008^bkP2;/^h02`2;/^h00`000000U;;^09BbkP0909BbkP030000002D[^h0U:k^00T0
U:k^1P0000000`3E`/d000000<g2c@020<g2c@050000003=`]D000000<fnc@000000103=_]D00`00
0000aKkE0<Fne@02000000D0aK[E00<000000;fje@2m^]D00`2m^]D2000000060;fje@0000000000
0000002m]]D000001`2m]]D00`000000_KKN0;ffgP060;ffgP030000002d^]h0];[N00D0];[N0`00
000R0?ooo`030000003oool0oooo00h0oooo000D0?ooo`<000009@3oool00`000000];;N0;BbgP07
0;BbgP030000002d/]D0];;E00H0];;E1000000;08^fmP8000002P2;]_H00`000000Rk;^08^bkP0:
08^bkP030000002D/^h0U;;^00X0U;;^00<0000009B^kP2D[^h02P2D[^h00`000000U:kV00000003
00000080cL;=00D000000<g2e@3=`]D0cL;E000000040<fne@0700000035_]D0aKkE0<Fne@000000
aKkE000000030<Fje@030000002m^]D0_K[E00@0_K[E0P0000040;fje@<000001@2m]]D00`000000
_KKN0;ffgP060;ffgP030000002d^]h0];[N00L0];[N00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0>0?ooo`00503oool00`000000oooo0?ooo`0T0?ooo`030000002d/]h0];;N00P0];;N
00<000000;Bbe@2d/]D01@2d/]D200000080Rk[f0P00000<08^fmP030000002;]_H0RkKf00P0RkKf
00<0000008^bkP2;/^h02P2;/^h00`000000U;;^09BbkP0909BbkP030000002D[^h0U:k^00X0U:k^
00<0000009B^iP2D[^H00`2D[^H300000080cL;E00H000000<g2e@00000000000<fne@0000030<Fn
e@0400000035_]D0aKkE0<Fne@80000000<0aK[E0000002m^]D0102m^]D00`000000_K[E00000004
0;fje@030000002m^]h0_K[N00<000000P2m]]D00`000000_KKN0;ffgP060;ffgP030000002d^]h0
];[N00L0];[N00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0>0?ooo`00503oool00`00
0000oooo0?ooo`0T0?ooo`030000002d/]h0];;N00L0];;N00<000000;Bbe@2d/]D0102d/]D20000
00H0Rk[f00<0000008^fmP2;]_H02P2;]_H00`000000RkKf08^fmP0308^fmQL000001P2D/^h00`00
0000U:k^09B^kP0:09B^kP030000002D[^H0U:kV00H0U:kV100000020<g2e@0300000035_]D0aKkE
0080aKkE00<000000<Fne@35_]D00`35_]D2000000@0_K[E00@000000;fje@2m^]D00000102m^]D0
0`000000_K[N0;fjgP030;fjgP<000001`2m]]h00`000000];[N0;BjgP070;BjgP030000003oool0
oooo0280oooo00<000000?ooo`3oool03P3oool000`0oooo0P0000050?ooo`030000003oool0oooo
02D0oooo00<000000;BbgP2d/]h01`2d/]h00`000000];;E0;Bbe@020;Bbe@8000002@2;^_H20000
00T0RkKf1`00000608>bmP030000002;[^h0Rjk^00P0Rjk^00<0000008^^kP2;[^h00`2;[^h90000
00X0U:k^00<0000009B^iP2D[^H02P2D[^H5000000030<Fne@000000aKkE00@0aKkE00<000000<Fn
e@35_]D00P0000020;fje@040000002m^]D0_K[E000000<0_K[E00<000000;fjgP2m^]h0102m^]h0
0`000000_K[N0;fjgP02000000@0_KKN00<000000;BjgP2d^]h01`2d^]h00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00h0oooo000=0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool09@3oool00`000000];;N0;BbgP070;BbgP030000002d/]D0];;E008000003@2;^_H20000
00<0RkKf1000000308>fmP0300000023/_H0Pk;f00P0Pk;f00<0000008^^kP2;[^h0202;[^h00`00
0000Rjk^08^^kP0808^^kP030000002;[^h0Rjk^00@000001P2D[^h00`000000U:kV09B^iP0;09B^
iP030000002L[^H00000008000001@35_]D00`000000aKkE0<Fne@030<Fne@8000000`2m^]D01000
0000_K[E0;fje@0000070;fjgP030000002m^]h0_K[N0080_K[N0P0000020;ffgP030000002d^]h0
];[N00L0];[N00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0>0?ooo`002`3oool20000
00H0oooo00<000000?ooo`3oool09@3oool5000000D0];;N0`00000208^nmP800000302;^_H40000
00P0PkKf00<0000008>bmP23/_H01`23/_H00`000000Rjk^08^^kP0808^^kP030000002;[^h0Rjk^
00P0Rjk^00<0000008^^kP2;[^h0102;[^h400000080U:k^00<0000009B^iP2D[^H02P2D[^H00`00
0000W:kV09b^iP0309b^iP8000000`35_]D00`000000aKkE0<Fne@030<Fne@080000002m_]h00000
0000002m^]D000000;fje@0000070;fjgP030000002m^]h0_K[N00D0_K[N0`0000080;BjgP030000
003oool0oooo02@0oooo00<000000?ooo`3oool03P3oool000/0oooo0P0000060?ooo`030000003o
ool0oooo02D0oooo00<000000:b^gP2/[]h00P2/[]h6000000H0Rkkf0P00000708^jmP<000000P23
^_H00`000000PkKf08>fmP0808>fmP0300000023/_H0Pk;f00L0Pk;f00<0000008^^kP2;[^h0202;
[^h00`000000Rjk^08^^kP0708^^kP030000002;[^h0Rjk^00P0Rjk^1000000;09B^iP030000002L
[^H0W:kV00D0W:kV0`0000050<Fne@030000002m_]h0_KkN0080_KkN0P0000000`2m^]D000000;fj
gP060;fjgP030000002m^]h0_K[N00D0_K[N00<000000;fjgP2m^]h00P0000050;BjgP030000003o
ool0oooo02H0oooo00<000000?ooo`3oool03@3oool001<0oooo00<000000?ooo`3oool09@3oool0
0`000000[:kN0:b^gP040:b^gP8000002P2;__H2000000<0Rk[f0P00000608>jmP0300000023]_H0
PkKf00P0PkKf00<0000008>bmP23/_H01`23/_H00`000000Rjk^08^^kP0708^^kP030000002;[^h0
Rjk^00P0Rjk^00<0000008^^kP2;[^h02@2;[^h00`000000U:[V00000002000000P0U:kV00<00000
09b^iP2L[^H0202L[^H300000080aKkE00<000000;fngP2m_]h00`2m_]h2000000L0_K[N00<00000
0;fjgP2m^]h01P2m^]h00`000000_K[N0;fjgP020;fjgP<000000P2d^]h00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00d0oooo000C0?ooo`030000003oool0oooo02D0oooo00<000000:b^
gP2/[]h00`2/[]h00`000000Rkkf08^nmP0<08^nmP<000002@23^_H2000000L0PkKf6@00000708^^
kP030000002;[^h0Rjk^00T0Rjk^00<0000009BZiP2DZ^H00P2DZ^H3000000D0U:kV00<0000009b^
iP2L[^H02`2L[^H2000000H0_KkN00@000000;fngP0000000000102m^]h00`000000_K[N0;fjgP06
0;fjgP030000002m^]h0_K[N00H0_K[N0P00000Y0?ooo`030000003oool0oooo00d0oooo000C0?oo
o`030000003oool0oooo02D0oooo00<000000:b^gP2/[]h00P2/[]h00`000000Rl;o08_2o`020000
00X0Rkkf0P0000000`23^_l000000000000:08>jmP0300000023]_H0PkKf00@000000`23/_H00`00
0000Pjkf08>^mP0708>^mP0300000023[^h0Pjk^00H0Pjk^00<0000008^ZkP2;Z^h01@00000208^^
kP030000002;[^h0Rjk^00T0Rjk^00<0000009BZiP2DZ^H01@2DZ^H30000000309B^iP000000W:kV
00d0W:kV00@0000009b^iP00000000000`2m_]h2000000<0_KkN0P0000020;fjgP030000002m^]h0
_K[N00D0_K[N00<000000;fjgP2m^]h01`2m^]h00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00d0oooo000C0?ooo`030000003oool0oooo02D0oooo00D000000:b^gP2/[]h0[:kN00000005
08_2o`<000001P2;__H00`000000Pk[o08>jo`0308>jo`8000002023^_H3000000P0Pk;f00<00000
08>^mP23[_H01`23[_H00`000000Pjk^08>^kP0608>^kP030000002;Z^h0Rj[^00@0Rj[^1@000008
08^^kP030000002DZ^H0U:[V00T0U:[V0`00000=09b^iP040000002L[^H0W:kV09b^iP<0000000<0
_KkN0000002m_]h0102m_]h2000000L0_K[N00<000000;fjgP2m^]h01`2m^]h00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo00d0oooo000C0?ooo`030000003oool0oooo02D0oooo00@00000
0:b^gP2/[]h000002@2;`_l200000080Rkkf0P00000808>jo`8000000P23^_H400000080NkKf0P00
000808>bmP0300000023[_H0Pjkf00H0Pjkf00<0000008>^kP23[^h01P23[^h00`000000Rj[^08^Z
kP0608^ZkP030000002;Z^h0Rj[^00H000000P2;[^h00`000000U:[V09BZiP0:09BZiP030000002D
Z^H00000008000002@2L[^H00`000000W:kV09b^iP0409b^iP030000002m_]h0000000D0_KkN00@0
00000;fngP00000000001@2m^]h00`000000_K[N0;fjgP070;fjgP030000003oool0oooo02T0oooo
00<000000?ooo`3oool03@3oool00180oooo00<000000?ooo`3oool09P3oool00`000000[:kN0000
000<08_2o`8000003023^_l2000000P0NkKf00<0000008>bmP23/_H01P23/_H00`000000Pjkf08>^
mP0608>^mP0300000023[^h0Pjk^00H0Pjk^00<0000008^ZkP2;Z^h01P2;Z^h00`000000Rj[^08^Z
kP0508^ZkP@000002P2DZ^H00`000000U:[V09BZiP0309BZiP<000001@2L[^H00`000000W:kV09b^
iP0609b^iP800000102m_]h00`000000_KkN0;fngP020;fngP8000000P2m^]h00`000000_K[N0;fj
gP070;fjgP030000003oool0oooo02X0oooo00<000000?ooo`3oool03@3oool00180oooo00<00000
0?ooo`3oool09P3oool3000000`0Rl;o00<0000008>no`23__l00P00000708>jo`8000000P1k^_l2
000000L0NkKf0P00000408>bmQL000001P2;Z^h00`000000Rj[^08^ZkP0708^ZkP030000002;Z^H0
0000008000001`2DZ^H00`000000U:[V09BZiP0609BZiP<000000P2L[^H00`000000W:kV09b^iP07
09b^iPD000001`2m_]h2000000T0_K[N00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0=
0?ooo`004P3oool00`000000oooo0?ooo`0V0?ooo`80000000@0RlKo00000000000000001`2;`_l2
000000D0Pkko0`00000208>jo`8000001P1k^_l2000000@0NkKf1`00000407^^mP030000001k[_H0
Njkf00H0Njkf00<0000007^ZkP1kZ^h01@1kZ^h00`000000PjG^0000000400000080Rj[^00<00000
08^ZkP2;Z^h01P2;Z^h00`000000Rj[V08^ZiP0208^ZiP8000001@2DZ^H00`000000U:[V09BZiP09
09BZiP8000002P2L[^H00`000000W:kV09b^iP02000000L0_KkN00@000000;fngP00000000001P2m
^]h00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00d0oooo000B0?ooo`030000003oool0
oooo02H0oooo00<0000008_6o`2;a_l00`2;a_l400000080Rl;o00<0000008>no`23__l02023__l2
000000X0Nk[o1000000407>bo`8000001P1k[_H2000000H0Njkf00<0000007^ZkP1kZ^h01@1kZ^h0
0`000000PjG^08>UkP0408>UkPD000001P2;Z^h00`000000Rj[V08^ZiP0408^ZiP<0000000<0U:[V
0000002DZ^H02`2DZ^H010000000W:[V00000000000809b^iP030000002L[^H0W:kV0080W:kV00<0
00000;fngP2m_]h00`2m_]h00`000000_KkN0;fngP020;fngP800000102m^]h00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00d0oooo000B0?ooo`8000009`3oool00`000000RlKo08_6o`07
08_6o`@000002023__l200000080Nkko0P00000607^jo`80000000<0LkKo0000000000001P1c/_l2
000000H0Njkf00<0000007^^mP1k[_H0101k[_H00`000000Nj[^07^ZkP0507^ZkP0300000023YNh0
PjG^00D0PjG^00<0000008>UkP23YNh01000000208^ZkP030000002;Z^H0Rj[V00L0Rj[V0`00000;
09BZiP040000002LZ^H0W:[V09bZiP8000001P2L[^H01P000000W:kV09b^iP2L[^H0000009b^iP80
00000P2m_]h00`000000_KkN0;fngP050;fngP80000000<0_K[N0000003oool0;P3oool00`000000
oooo0?ooo`0=0?ooo`004P3oool00`000000oooo0?ooo`0V0?ooo`030000002;a_l0RlKo00P0RlKo
00<0000008?2o`23`_l01000000308>no`030000001k__l0Nkko00@0Nkko0P00000207^jo`800000
1@1c]_l00`000000Lk;o07>bo`0407>boa<000000`1kZ^h00`000000PjG^08>UkP0508>UkP030000
0023YNh0PjG^00@0PjG^1000000908^ZiP040000002DYNH00000000000P0U:[V00<0000009bZiP2L
Z^H0102LZ^H2000000@0W:kV00@0000009b^iP2L[^H00000102L[^H2000000X0_KkN00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0<0?ooo`004P3oool00`000000oooo0?ooo`0U0?ooo`03
0000002;a_l0RlKo00P0RlKo00<0000008?2o`23`_l01@23`_l3000000T0Nkko0P00000807>fo`80
00000P1c/_l200000080JZko00<0000007>^mP1c[_H0101c[_H00`000000Lj[f07>ZmP0407>ZmP03
0000001kYNh0NjG^00H000001P23YNh00`000000PjG^08>UkP0508>UkP040000002;YNH000000000
00H0Rj[V00<0000009BUiP2DYNH00P2DYNH3000000@0U:[V00<0000009bZiP2LZ^H01`2LZ^H20000
00<0W:kV0P00000709b^iP030000002m_]h0_KkN00H0_KkN00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0<0?ooo`004P3oool00`000000oooo0?ooo`0U0?ooo`D000001P2;a_l00`000000
Pl;o08?2o`0608?2o`0300000023`_l0Pl;o00@000000`1k__l200000080Lkko0`00000407>fo`@0
00001@1Z[_l2000000@0Ljkf00<0000007>ZmP1cZ_H0101cZ_H00`000000NjG^07^UkP0407^UkP03
0000001kYNh0000000<000000P23YNh00`000000PjG^08>UkP0508>UkP040000002;YNH0RjGV08^U
iP800000102;Z^H00`000000U:GV09BUiP0509BUiP8000000P2DZ^H00`000000W:[V09bZiP0909bZ
iP80000000<0W:kV0000002L[^H0202L[^H2000000D0_KkN00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0<0?ooo`004P3oool00`000000oooo0?ooo`0U0?ooo`030000002Da_l0U<Ko0080
U<Ko2P00000508?2o`0300000023`_l0Pl;o00@0Pl;o0`00000707>no`@00000101Z/_l2000000D0
JZko00<0000007>^mP1c[_H00P1c[_H00`000000Lj[f07>ZmP0407>ZmP030000001kYNh0NjG^00@0
NjG^00<0000007^UkP1kYNh00P1kYNh4000000H0PjG^00<0000008^UiP2;YNH00`2;YNH200000003
08^ZiP000000U:GV00T0U:GV0P00000>09bZiP8000002`2L[^H200000080_KkN00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0<0?ooo`004P3oool00`000000oooo0?ooo`0U0?ooo`030000
002Da_l0U<Ko00L0U<Ko00<0000008_:o`2;b_l00P2;b_l6000000L0Pl;o00<0000007?2o`1c`_l0
0`00000207>no`8000000P1Z^_l3000000<0J[;o5`00000207^UkP030000001kYNh0NjG^00@0NjG^
00<0000008>QkP0000000`00000208>UkP030000002;YNH0RjGV00D0RjGV0`00000:09BUiP<00000
2`2LZ^H010000000W:[V00000000000<09b^iP800000=@3oool00`000000oooo0?ooo`0<0?ooo`00
4@3oool00`000000oooo0?ooo`0U0?ooo`030000002Da_l0U<Ko00P0U<Ko00<0000008_:o`2;b_l0
1P2;b_l00`000000Pl[o00000003000000<0Pl;o00<0000007?2o`1c`_l00`1c`_l2000000L0J[[o
0`00000305Z^o`030000001RZ_l0HZ[o0080HZ[o0P00000306ZUmP030000001ZYOH0JZGf00@0JZGf
00<0000007>QkP1cXNh01@00000407^UkP0300000023XNh0Pj7^00<0Pj7^1000000708^UiP040000
002DXNH00000000000L0U:GV00@0000009BUiP2DYNH0U:GV0P00000809bZiP060000002LZ^H0W:[V
0000002LZ^H000003@2L[^H00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00`0oooo000A
0?ooo`030000003oool0oooo02D0oooo00<0000009C6o`2Da_l0202Da_l00`000000Rl[o08_:o`06
08_:o`0300000023b_l0Pl[o00<0Pl[o1@00000407?2o`040000001Z__l0J[ko06Zno`D000000`1J
/_l200000080FZko0P00000306:Zo`@0000000<0JZGf000000000000101ZYOH00`000000Lj7^07>Q
kP0307>QkP030000001cWNh0000000<0000000<0NjG^00000023XNh01@23XNh010000000Pj7V0000
0000000508^UiP040000002DXNH0U:7V09BQiP<00000102DYNH00`000000U:GV09BUiP0309BUiP03
0000002LZ^H0W:[V00D0W:[V00@0000009bZiP2LZ^H000000P2LZ^H00`000000W:kV09b^iP0809b^
iP80000000<0Y:kV0000003oool0<P3oool00`000000oooo0?ooo`0<0?ooo`004@3oool00`000000
oooo0?ooo`0U0?ooo`H000001@2Da_l00`000000Rl[o08_:o`0508_:o`0300000023b_l0Pl[o00H0
Pl[o00<0000007_6o`1ka_l01P00000406Zno`030000001J^_l0F[[o008000000`1J/_l7000000<0
DZGf00<0000005ZQmP0000002000000307>QkP030000001cWNh0Lig^00<0Lig^0`00000508>QkP04
00000023XNH0Pj7V08>QiP<0000000<0RjGV0000002DXNH01P2DXNH20000000309BUiP000000U:GV
00H0U:GV0P00000409bZiP050000002LZ^H0W:[V09bZiP0000000`2LZ^H2000000L0W:kV00<00000
0:B^iP2T[^H00P2T[^H00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00`0oooo000A0?oo
o`030000003oool0oooo02D0oooo00<0000009C:o`2Db_l00`2Db_lI000000<0NlKo00<0000006[6
o`1Za_l01000000505Zjo`<000000P1:Z_l20000000304ZUo`000000000000@0DZGf00@0000005ZQ
mP1JXOH0FZ7f0P00000306:MmP@0000000<0Lj7^0000001cWNh0101cWNh00`000000NigV00000003
0000000308>QkP000000Pj7V00D0Pj7V0P00000909BQiP8000002@2DYNH20000000309bZiP000000
W:[V00<0W:[V00<0000009bZiP2LZ^H00`2LZ^H00`000000W:kV09b^iP0309b^iP030000002T[^H0
Y:kV00@0Y:kV00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0<0?ooo`004@3oool00`00
0000oooo0?ooo`0V0?ooo`030000002Db_l0U<[o00L0U<[o00<0000008_>o`2;c_l01@2;c_l00`00
0000Rlko08_>o`0508_>o`040000001kc_l0Nlko07_>o`T000000`1J__l3000000<0@Jkf50000000
101RWOH0000006ZMkP1ZWNh5000000<0Lig^00<0000007^MiP1kWNH00P1kWNH3000000H0Pj7V0`00
000709BQiP040000002DXMh00000000000T0U:GV00<0000009bZiP2LZ^H00`2LZ^H00`000000W:[V
09bZiP0409bZiP80000000<0W:kV000000000000202T[^H00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo00`0oooo000A0?ooo`030000003oool0oooo02H0oooo00<0000009C:o`2Db_l01`2D
b_l00`000000Rlko08_>o`0608_>o`030000002;c_l0Rlko00D0Rlko00<0000007_>o`1kc_l00`1k
c_l00`000000Ll[o07?:o`0207?:o`030000001Ja_l0F/Ko00<000000`0i/_H30000008089g^1000
00000`0iWOH000000000000204ZMmP8000000`1BVOH00`000000FYWf0000000300000080JYg^00<0
000007>IkP1cVNh01000000507^MiP0400000023WNH00000000000@0Pj7V00<0000008^MiP2;WNH0
0P00000509BQiP050000002DXMh0U:7N09BQgP0000001`2DYNH010000000W:GN00000000000309bZ
iP030000002LZ^H0W:[V00H0W:[V00<000000:B^iP2T[^H02@2T[^H2000002h0oooo00<000000?oo
o`3oool0303oool00140oooo00<000000?ooo`3oool09`3oool00`000000U<[o09C:o`0709C:o`04
0000002;c_l0Rlko08_>oa/0000000<0J/ko0000000000001`0000000`2LTLD000000000000:0000
000305:ImP000000FYWf00<0FYWf1000000507>IkP<000000`1kWNH010000000PigV08>MiP23WNH2
0000000308>QiP000000RigV00@0RigV0P00000209BQiP030000002DXMh0U:7N00<0U:7N0P000004
09BUiP030000002LYMh0W:GN0080W:GN00@0000009bZiP2LZ^H000001`2LZ^H00`000000Y:[N0000
000<0:B^iP030000003oool0oooo02`0oooo00<000000?ooo`3oool02`3oool00140oooo00<00000
0?ooo`3oool09`3oool>000000D0U=;o00<0000008_Bo`2;d_l01@2;d_l00`000000Pm;o08?Bo`03
08?Bo`040000001kd_l0Nm;o07_Bo`D000000P1kf_l400000080Y9G=00<0000009bAa@0000000P00
00000`2DQLD00775000000040000000303VAmP000000000000@0000000@0FYWf0000001RVNh0HYW^
1000000307>IkP060000001cVNH000000000001kWNH000001@23WNH2000000L0RigV0P00000809BQ
gP80000000<0U:GV0000002LYMh01@2LYMh3000000D0W:[V0P0000030:BZgP030000002T[^H0Y:kV
00X0Y:kV00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0;0?ooo`004@3oool00`000000
oooo0?ooo`0X0?ooo`030000002Lc_l0W<ko00L0W<ko00<0000009CBo`2Dd_l01@2Dd_l00`000000
Rm;o08_Bo`0508_Bo`0400000023d_l0Pm;o08?Bo`H000000P23f_l50000000408_Ro`2TVLd0Y9W=
00000080Y9G=0`000000102DSLd0000009B5a@2DQLD4000000030125iP000000000000X0000000<0
HYW^0000001RUNh01000000307>IiP<000001@23WNH3000000H0RigV0`00000809BQgP030000002L
YMh0W:GN00L0W:GN00<0000009bZiP2LZ^H00P2LZ^H00`000000Y:[N0:BZgP040:BZgP030000002T
[^H0Y:kV00X0Y:kV00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0;0?ooo`00403oool0
0`000000oooo0?ooo`0Y0?ooo`030000002Lc_l0W<ko00L0W<ko00<0000009CBo`2Dd_l01P2Dd_l0
0`000000Rm;o08_Bo`0208_Bo`H000001@2Df_l300000080U>;o0P2TWMD00`000000Y9W=0:BIc@04
00000080W97=00L0000009B=c@2DSLd0000009B5a@000000Rgfm00H0000000<088W^000000000000
0`0000000`1:TNh0000005:AkP0400000080HYG^0`00000207>IiP030000001kUNH0000000800000
00<0PigV0000002;VMh00P2;VMh2000000<0RigV00D0000009BMgP2DWMh0U9gN0000000609BQgP03
0000002LXMh0000000P0W:GN0`0000000`2LZ^H000000:BZgP070:BZgP030000002T[^H0Y:kV00T0
Y:kV0P00000[0?ooo`030000003oool0oooo00/0oooo000@0?ooo`<00000:P3oool00`000000W<ko
09c>o`0709c>o`030000002Dd_l0U=;o0080U=;o2000000409CFo`8000000P2Df_l300000080W=ko
00<000000:BMe@2TWMD00P2TWMD3000000<0W9G=00@0000009bAc@2LTLd000000P2DSLd01`000000
U8G5000000000000NgW50000001ZJKd01`0000000`0aRNh000000000000200000080DY7^00X00000
05Z=kP000000000006:EkP000000JY7V0000001cVNH00000101kUNH200000080RiWN6000000409bU
gP040000002LYMh0W:GN000000X0Y:[N00<000000:B^iP2T[^H01P2T[^H200000080Y:kN00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0;0?ooo`00403oool00`000000oooo0?ooo`0[0?oo
o`030000002Lc_l0W<ko00D0W<ko1P00000509cBo`030000002De_l0U=Ko00D0U=Ko1000000209cN
o`80Y:7E00<000000:BMe@2TWMD00P00000209bMe@050000002LULd0W9G=09bEc@0000000`2LTLd0
10000000U8g=00000000000208>1c@040000001kNLD0000006YY_@d0000000@0DY7^0000001JSNh0
FXg^0`00000206ZAiPT000000`2me^h00`000000_M[^0;gJkP0:0;gJkP030000002mf_H0_M[f00D0
_M[f2@00000:0:BZgP030000002T[^H0Y:kV00<0Y:kV0P0000050:B^gP030000003oool0oooo02L0
oooo00<000000?ooo`3oool02`3oool00100oooo00<000000?ooo`3oool0:`3oool010000000W<ko
09c>o`2Lc_l4000000<0W=;o00<0000009cBo`2Ld_l01P2Ld_l200000080U=Ko0`00000209cJo`80
0000102TXMD3000000@0W9gE00<0000009bEc@2LULd00P2LULd01@000000W97=09bAc@2LTLd00000
0080RhW=00P0000008>1c@23PLd0000007]ia@000000FVW503UEa@H0000000D0887^000000000000
000004Z9kP0300000080FXg^1@00000:0;gFkP030000002mf^h0_M[^00/0_M[^00<000000;gJmP2m
f_H02@2mf_H2000000<0]=kf1P0000050:BZgP030000002T[^H0Y:kV008000001`2T[]h00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00/0oooo000@0?ooo`030000003oool0oooo02`0oooo
0`00000809cBo`030000002Ld_l0W=;o00D0W=;o1000000409cJo`80Y:GE00<000000:BQe@2TXMD0
0P00000209bQe@030000002LWMD0W9gE00<0W9gE00H0000009bEc@2LULd0W9G=0000002LTLd20000
000409BAe@000000RhW=000000<0Ph7=00<0000006Yec@0000004@0000000`2md^h000000;gFkP0<
0;gFkP030000002mf^h0_M[^00X0_M[^00<000000;gJmP2mf_H02P2mf_H00`000000]=kf0;CNmP08
0;CNmPD0000000<0Y:[N0000000000002P2T[]h00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00/0oooo000@0?ooo`030000003oool0oooo02d0oooo00<0000009cBo`2Ld_l0202Ld_l00`00
0000W=;o09cBo`04000000<0Y=Ko0P0000050:BUe@<000001@2LXMD00`000000W9gE09bMe@0309bM
e@050000002LULd0W9G=09bEc@0000000`2DTMD01`000000RhW=08^9c@000000Ph7=0000001kPLd0
0P0000001@1JJLD0000002UIc@00000003Rm00P000001@2md^h00`000000_MK^0;gFkP0;0;gFkP03
0000002mf^h0_M[^00T0_M[^00<000000;gJmP2mf_H02`2mf_H00`000000]=kf0;CNmP090;CNmP80
00000P2/g_H3000000/0Y:kN00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0;0?ooo`00
403oool00`000000oooo0?ooo`0^0?ooo`8000001`2Ld_l4000000D0Y=Ko0`2TZ]h00`000000Y:GE
0:BUe@0300000080Y:7E00<0000009bQe@2LXMD00`2LXMD00`000000W9gE09bMe@0309bMe@060000
002LULd000000000002DUMD000000`2DTMD010000000RhW=00000000000207^1c@040000001ZMLd0
000004YYe@P00000202md^h00`000000_MK^0;gFkP0;0;gFkP030000002mf^h0_M[^00T0_M[^00<0
00000;gJmP2mf_H02P2mf_H2000000X0]=kf00<000000:cNmP2/g_H01@2/g_H4000000P0Y:kN00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0;0?ooo`00403oool00`000000oooo0?ooo`0`
0?ooo`030000002Ld_l0W=;o00@00000102Td_l2000000H0Y:[N0`0000060:BQe@030000002LXMD0
W:7E00<0W:7E00<0000009bMe@2LWMD00P2LWMD2000000@0U9GE00D0000009BAe@2DTMD0U97E0000
000208>9e@030000001kPLd0Nh7=00<0000000@0BVWE0000000000000000302md^h00`000000_MK^
0;gFkP0:0;gFkP030000002mf^h0_M[^00<0_M[^300000070;gJmP030000002dg_H0000000T0]=kf
00<000000:cNmP2/g_H02P2/g_H3000000D0Y:kN00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0;0?ooo`00403oool00`000000oooo0?ooo`0a0?ooo`8000001`2Td_l30:BZgP040000002T
Z]h0Y:[N0:BZgP8000000P2TYMh00`000000Y:7E0:BQe@040:BQe@030000002LXMD0W:7E00@0W:7E
00@0000009bMe@00000000000P2DVMD00`000000U9GE09BEe@0209BEe@050000002DTMD0000008>=
e@0000000P23RMD20000000607^1c@00000000000000002mc^H000003@2md^h00`000000_MK^0;gF
kP070;gFkPT000001P2mf^h00`000000_Mkf0;gNmP030;gNmP/000001P2dg_H2000000/0[=kf0P00
00030:cNo`800000102T[]h00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00X0oooo000?
0?ooo`030000003oool0oooo03<0oooo0P0000030:CBo`H0Y:[N00@000000:BZgP00000000001@2T
YMh00`000000Y:7E0:BQe@040:BQe@030000002LXMD0W:7E00<0W:7E0P00000509BIe@030000002D
UMD0U9GE0080U9GE00H0000008>=e@23SMD0PhgE00000023RMD3000000D0_LkV00<000000;gBkP2m
d^h02P2md^h010000000_MK^0;gFkP2me^h6000000<0_MK^00<000000;gJkP2mf^h0202mf^h00`00
0000_Mkf0;gNmP090;gNmP060000002dh_H0]>;f0;CRmP000000]>;f200000090:cNmP8000001`2/
g_l3000000030:B^gP000000000002D0oooo00<000000?ooo`3oool02P3oool000l0oooo00<00000
0?ooo`3oool0=@3oool00`000000Y:[N0:BZgP060:BZgP800000202TYMh00`000000Y:7E0:BQe@04
0:BQe@030000002LXMD0W:7E008000000P2LWMh00`000000U9WE09BIe@0209BIe@080000002DUMD0
U9GE09BEe@000000RiGE00000023SMD3000000P0_LkV00<000000;gBkP2md^h02@2md^h5000000T0
_MK^00<000000;gJkP2mf^h0202mf^h00`000000_Mkf0;gNmP080;gNmP030000002dh_H0]>;f0080
]>;f00<000000;CRmP2dh_H00P2dh_H2000000<0]>;o100000030:cNmP800000302/g_l3000002D0
oooo00<000000?ooo`3oool02P3oool000l0oooo00<000000?ooo`3oool0=P3oool00`000000Y:[N
0:BZgP020:BZgP<000000P2TZ]h00`000000Y:GN0:BUgP050:BUgP030000002TXMD0Y:7E00D0Y:7E
0P00000509bMgP030000002DVMD0U9WE0080U9WE00@0000009BEe@000000RiGE0`00000;0;g>iP03
0000002md^h0_M;^00H0_M;^0`0000000`35d^h000000;gFkP0;0;gFkP030000002mf^h0_M[^00L0
_M[^00<000000;gNmP2mg_H0202mg_H00`000000]>;f0;CRmP030;CRmP050000002dh_H0]>;f0;CR
mP0000002@2dh_l4000000/0[=ko0P0000020:CNo`800000903oool00`000000oooo0?ooo`0:0?oo
o`003`3oool00`000000oooo0?ooo`0f0?ooo`030000002TZ]h0Y:[N008000001@2TZ]h00`000000
Y:GN0:BUgP060:BUgP030000002TXMD0Y:7E0080Y:7E0P0000000`2LXMh0000009bMgP0509bMgP03
0000002DVMD0U9WE0080U9WE0`00000>0;g>iP030000002md^h0_M;^00<0_M;^0`0000040<GBkP03
0000002me^h0_MK^00T0_MK^00<000000;gJkP2mf^h0202mf^h00`000000_Mkf0;gNmP070;gNmP03
0000002dh_H0]>;f00@0]>;f00@000000;CRmP00000000002P2dh_l200000080[>;o0P0000070:cN
o`8000001@2Tg_l00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00X0oooo000?0?ooo`03
0000003oool0oooo03L0oooo0P0000080:BZgP030000002TYMh0Y:GN00H0Y:GN00@000000:BQe@00
00000000102LXMh00`000000W9gN09bMgP0409bMgP040000002DVMD0000000000080_L[V00<00000
0;g>iP2mc^H03@2mc^H00`000000_M;^00000002000000L0aM;^00<000000;gFkP2me^h02@2me^h0
0`000000_M[^0;gJkP020;gJkQX000002@2dh_l2000000H0[>;o0P0000030:cNo`800000202Tg_l0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00X0oooo000?0?ooo`030000003oool0oooo
03P0oooo00<000000:BZgP2TZ]h01`2TZ]h00`000000Y:GN0:BUgP060:BUgP030000002LXMh0W:7N
00D0W:7N00<0000009bMgP2LWMh00`2LWMh2000000@0_L[V00<000000;g>iP2mc^H0302mc^H30000
00/0aM;^00<000000;gFkP2me^h01P2me^h7000000D0aMk^00<000000;gRmP2mh_H01P2mh_H00`00
0000_NKf0;gVmP060;gVmP030000002di_l0]>Ko00@000000`2dh_l2000000X0[>;o0`0000070:CN
o`@0[;;N0P00000Q0?ooo`030000003oool0oooo00X0oooo000?0?ooo`030000003oool0oooo03T0
oooo00<000000:BZgP2TZ]h01`2TZ]h00`000000Y:GN0:BUgP030:BUgP80000000<0W:GN0000002L
XMh01P2LXMh00`000000W9gN00000002000000L0_L[V00<000000;g>iP2mc^H0202mc^H300000003
0<G>iP000000aM;^00/0aM;^00<000000;gFkP2me^h01P0000020<GJkP0300000035g^h0aMk^00H0
aMk^00<000000;gRmP2mh_H01P2mh_H00`000000_NKf0;gVmP050;gVmP80000000<0]>Ko0000002d
i_l0102di_l4000000P0[>;o0`00000209cRo`8000000`2Tg_l70:bbgP<00000803oool00`000000
oooo0?ooo`0:0?ooo`003`3oool00`000000oooo0?ooo`0j0?ooo`030000002TZ]h0Y:[N00H0Y:[N
00<000000:BUgP2TYMh00P2TYMh00`000000W:GN09bUgP0209bUgP030000002LXMh0W:7N00@0W:7N
0P00000;0;g:iP030000002mc^H0_LkV00<0_LkV100000040<G>iP0300000035d^h0aM;^00T0aM;^
100000070<GJkP0300000035g^h0aMk^00L0aMk^00<000000;gRmP2mh_H01@2mh_H00`000000_NKf
0;gVmP050;gVmP050000002di_l0]>Ko0;CVo`000000102di_l2000000<0Y>Ko0`0000030:cRo`80
00001`2Lh_l00`000000[;;N0:bbgP080:bbgP030000002Lf_l0000001l0oooo00<000000?ooo`3o
ool02P3oool000l0oooo00<000000?ooo`3oool0>`3oool00`000000Y:[N0:BZgP060:BZgP040000
002TYMh00000000000H0W:GN00@0000009bQgP2LXMh0W:7N0P00000=0;g:iP030000002mc^H0_LkV
00<000002035c^H00`000000aM;^0<GBkP060<GBkP<0000000<0aMKV00000035f^h02035f^h00`00
0000aMk^0<GNkP060<GNkP040000002mh_H0_N;f0;gRmQ00000000@0]>Ko0000002di_l0]>Ko0P00
00080:CVo`<000001`2Lh_l20:b^gP030000002//]h0[;;N00T0[;;N0P00000O0?ooo`030000003o
ool0oooo00X0oooo000?0?ooo`800000?@3oool00`000000Y:[N0:BZgP050:BZgP8000002@2LYMh3
00000100_L[V0P00000<0<G>iP0300000035d^h0aM;^0080aM;^0`0000040<GFiP0300000035f^h0
aM[^00H0aM[^00<000000<GNkP35g^h00P35g^h9000000<0aNKf00<000000;gZmP2mj_H01@2mj_H0
0`000000]>[o0;CZo`020;CZo`D000001`2Ti_l200000080W>Ko0P00000309cRo`H0[:kN00<00000
0:bbgP2//]h0202//]h00`000000W=[o0000000N0?ooo`030000003oool0oooo00X0oooo000>0?oo
o`030000003oool0oooo03h0oooo00<000000:BZgP2TZ]h00P2TZ]h200000080W:[N00<0000009bU
gP2LYMh01@2LYMh2000000030;g6iP000000_L[V00`0_L[V0P0000000`35c^H000000<G>iP0<0<G>
iP0300000035d^h00000008000001`35e^H00`000000aM[^0<GJkP050<GJkPH000001@35h^h00`00
0000aNKf0<GVmP040<GVmP030000002mj_H0_N[f00@0_N[f00<000000;CZo`2dj_l0102dj_l20000
0080Y>[o0P0000030:CVo`8000001P2Li_l00`000000[:kN0:b^gP060:b^gP030000002//]h0[;;N
00P0[;;N0`00000O0?ooo`030000003oool0oooo00T0oooo000>0?ooo`030000003oool0oooo03l0
oooo00@000000:BZgP00000000001@2LZ]h2000000<0W:GN0P0000040;g6iP030000002mb^H0_L[V
00P0_L[V0P0000040<G>iP0300000035c^H0aLkV00T0aLkV0`00000:0<GFiP0300000035f^h0aM[^
0080aM[^0`0000000`35f^h000000<GRkP070<GRkP0300000035i_H0aNKf00@0aNKf00<000000;gZ
mP2mj_H0102mj_H00`000000]>[o0;CZo`030;CZo`<000001@2Tj_l3000000<0W>Ko1@2/Z]h00`00
0000[:kN0:b^gP070:b^gP030000002//]h0[;;N00<0[;;N10000000102//]h0000000000000000N
0?ooo`030000003oool0oooo00T0oooo000>0?ooo`030000003oool0oooo0400oooo00<0000009bZ
gP2LZ]h01`2LZ]h3000000L0_LKV00<000000;g:iP2mb^H01@2mb^H2000000H0aLkV00<000000<G>
iP35c^H01P35c^H3000000030<GBiP000000aMKV00X0aMKV00<000000<GJkP0000000P0000040<GJ
kP0300000035h^h0aN;^00H0aN;^00<000000<GVmP35i_H04P000000102Tj_l000000:CZo`2Tj_l3
00000080U>Ko0`0000070:bZgP030000002/[]h0[:kN00H0[:kN00<000000:bbgP2//]h00`000006
0:bbgP8000007P3oool00`000000oooo0?ooo`090?ooo`003P3oool00`000000oooo0?ooo`110?oo
o`030000002LZ]h0W:[N00H0W:[N00<000000;g6iP2ma^H0202ma^H00`000000_L[V0;g:iP020;g:
iP8000002@35c^H00`000000aLkV0<G>iP030<G>iP8000001@35d^H00`000000aMKV0<GFiP070<GF
iP<000001P35f^h00`000000aN;^0<GRkP040<GRkPH000000P35j^h00`000000_Nkf0;g^mP030;g^
mP800000102dl_H200000080Y>kf1000000309CVo`@0[:[E00<000000:bZgP2/Z]h01@2/Z]h00`00
0000[:kN0:b^gP050:b^gP@000002@2//]h00`000000U=Ko0000000M0?ooo`030000003oool0oooo
00T0oooo000>0?ooo`030000003oool0oooo0480oooo00<0000009bZgP2LZ]h00`2LZ]h2000000`0
_LKV00@000000;g:iP00000000002`35c^H00`000000aLkV0<G>iP03000000L0aM;V00<000000<GF
iP35e^H00`35e^H4000000030<GFiP000000aM[^00H0aM[^00<000000<GRkP35h^h0100000020<gV
kP0300000035j^h0aN[^0080aN[^00<000000;g^mP2mk_H00`2mk_H00`000000]?;f0;CbmP020;Cb
mP8000000`2Tk_H30000000308_ZmP000000000000L0[:[E00<000000:bZgP2/Z]h01@2/Z]h00`00
0000[:kN0:b^gP0400000080[:kN00<000000:bbgP2//]h0202//]h00`000000U=Ko0000000M0?oo
o`030000003oool0oooo00T0oooo000>0?ooo`030000003oool0oooo04<0oooo00<0000009bZgP2L
Z]h00P00000?0;g6iP0300000035c^H0aLkV00`0aLkV0P00000;0<GBiP0300000035e^H000000080
00001@35e^H00`000000aM[^0<GJkP030<GJkPD000001@3=i^h010000000aN[^0<GZkP35j^hC0000
000308_ZmP000000Y:GE0080Y:GE00<000000:bZe@2/Z]D0102/Z]D00`000000[:[N0:bZgP040:bZ
gP@000001`2/[]h00`000000[;;N0:bbgP080:bbgP030000002De_l0000001`0oooo00<000000?oo
o`3oool02@3oool000h0oooo00<000000?ooo`3oool0A03oool2000000l0_LKV0P0000000`2mb^H0
00000<G>iP090<G>iP8000000P35c^H00`000000aM;V0<GBiP080<GBiP<000002035e^H00`000000
aM[^0000000300000080cMkV00<000000<gVkP3=i^h01@3=i^h5000000@0aO;f0P0000030;CfmP80
000000<0W?;f0000000000000`2TXMD00`000000Y:GE000000030:BUe@030000002/Z]D0[:[E00D0
[:[E00<000000:bZgP0000000`0000000`2/[]h000000:b^gP080:b^gP030000002//]h0[;;N00P0
[;;N0`00000L0?ooo`030000003oool0oooo00T0oooo000>0?ooo`030000003oool0oooo04<0oooo
0P0000000`2ma^H000000000000;0;g6iP800000102mb^H00`000000aLkV0<G>iP050<G>iP800000
1035c^H00`000000aM;V0<GBiP060<GBiP80000000<0aM;V00000035e^H01`35e^H3000000H0cMkV
00<000000<gVkP3=i^h00`3=i^h3000000<0cNk^00<000000<GbmP000000300000040:BQe@800000
102TYMD010000000[:[E0:bZe@2/Z]D5000000H0[:kN00<000000:b^gP2/[]h01P2/[]h00`000000
[;;N0:bbgP090:bbgP800000703oool00`000000oooo0?ooo`090?ooo`003P3oool00`000000oooo
0?ooo`120?ooo`030000002ma^H0_LKV00<0_LKV00<000000;g6iP2ma^H01P2ma^H2000000L0_L[V
00<000000<G>iP35c^H00P35c^H2000000L0aLkV00<000000<GBiP35d^H00P35d^H3000000<0aM;V
00<000000<GFiP35e^H00`35e^H3000000030<gJiP000000cMkV00H0cMkV00<000000<gVkP000000
100000030<g^kP@0000000<0aOK^0000002dn^h00P2dn^h4000000<0Y9g=00<000000:BQe@2TXMD0
0P2TXMD200000080Y:GE1P0000030:bZe@030000002/[]h0[:kN00D0[:kN00<000000:b^gP2/[]h0
1`2/[]h00`000000[;;N0:bbgP080:bbgP800000703oool00`000000oooo0?ooo`090?ooo`003@3o
ool00`000000oooo0?ooo`120?ooo`030000002ma^H0_LKV00D0_LKV00<000000;g6iP2ma^H00`2m
a^H2000000X0_L[V00@000000<G>iP00000000002@35c^H00`000000aM;V0<GBiP02000000L0aM;V
00<000000<GFiP0000000P0000040<gJiP030000003=g^H0cMkV00<0cMkV100000040<gVkPD00000
1035m^h500000080Y9W=00<000000:BMc@2TWLd00P2TWLd00`000000Y:7E0:BQe@05000000<0[:[E
00<000000:bZe@2/Z]D0102/Z]D00`000000[:kN0:b^gP040:b^gP030000002/[]h0[:kN00L0[:kN
00<000000:bbgP2//]h0202//]h00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00T0oooo
000=0?ooo`030000003oool0oooo0400oooo0P0000090;g6iP80000000<0_LKV0000000000003@2m
b^H00`000000aLkV0<G>iP0:0<G>iP8000002035d^H3000000L0cM[V00<000000<gNiP0000000`00
00020<gNiP040000003=i^h0cNK^0<gVkP<000000`3=l^h00`000000aOK^0000000400000080Y9G5
00H000000:BIc@2TVLd0Y9W=0000002TWLd500000080[:G=00<000000:bZe@2/Z]D0102/Z]D00`00
0000[:[E0:bZe@030:bZe@030000002/[]h0[:kN00D0[:kN00<000000:b^gP2/[]h01P2/[]h00`00
0000[;;N0:bbgP090:bbgP030000003oool0oooo01X0oooo00<000000?ooo`3oool02@3oool000d0
oooo00<000000?ooo`3oool0?`3oool00`000000_LKV0;g6iP0;0;g6iP030000002mb^H0_L[V00/0
_L[V0P0000000`35b]h000000<G>iP080<G>iP80000000<0aLkV00000035d^H01@35d^H200000003
0<gBiP000000cM[V00H0cM[V0`0000050<gNiP030000003=i^h000000080000000@0eN[V0000003=
l^h0cO;^1`0000000`2TTKd000000:BEa@020:BEa@030000002TVLd00000008000000P2/XLd00`00
0000[:G=0:bUc@020:bUc@8000001@2/Z]D00`000000[:[E0:bZe@030:bZe@030000002/[]h0[:kN
00D0[:kN00<000000:b^gP2/[]h01`2/[]h00`000000[;;N0:bbgP030:bbgPH000007@3oool00`00
0000oooo0?ooo`080?ooo`003@3oool00`000000oooo0?ooo`0n0?ooo`030000002ma^H0_LKV00/0
_LKV00<000000;g6gP0000002P2mb^H2000000@0aL[N00<000000<G>iP35c^H01035c^H2000000<0
aLkV00<000000<GBiP35d^H00P35d^H2000000@0cM;V00<000000<gJiP3=f^H00P3=f^H200000003
0<gJiP000000cMkV00@0cMkV0`0000030=GZiP050000003=l^h000000000003Em^H01@0000000`2T
SKd0000000000005000000030:bMa@000000[:7=00<0[:7=00@000000:bUc@2/YLd0[:G=0P000005
0:bZe@030000002/Z]D0[:[E00<0[:[E00<000000:b^gP2/[]h01P2/[]h00`000000[:kN0:b^gP02
0:b^gPX000001@2/]]h00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo000=0?oo
o`030000003oool0oooo03`0oooo0P00000=0;g6iP050000002ma]h0_LKN0;g6gP000000202mb^H0
0`000000aL[N0<G:gP040<G:gP0300000035c^H0aLkV0080aLkV0P0000060<G>iP0400000035d^H0
0000000000H0cM;V00<000000<gJiP3=f^H00P0000030<gJiP040000003=g^H0cMkV0<gNiP800000
00<0eN;V0000003Ej^H00P3Ej^H3000000040=GfiP00000000000<gogPH0000000D0]9Vm0000002/
VLD0[9W5000000030:bMa@050000002/XLd0[:7=0:bQc@0000000`2/YLd2000000D0[:[E00<00000
0:bZe@2/Z]D0102/Z]D010000000[:kN0:b^gP2/[]h9000000@0[;;N00<000000:bfgP2/]]h0202/
]]h00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00P0oooo000=0?ooo`030000003oool0
oooo03/0oooo00<000000;g6iP2ma^H0302ma^H00`000000_LKN0;g6gP030;g6gP800000102mb^H2
000000P0aL[N00@000000<G>iP00000000002@35c^H00`000000cM;V0<gBiP060<gBiP<000001P3=
f^H3000000<0eN;V00D000000=GZiP00000000000=GZiP03000000030=kfgP000000000000800000
00H0_I6d0000002dUKd000000;BI_@0000020:bIa@050000002/WLD0[9g50:bMa@0000000`2/XLd0
10000000[:G=0:bUc@2/YLd2000000H0[:[E00<000000:bZe@2/Z]D01`0000040:bbgP030000002/
/]h0[;;N00H0[;;N00<000000:bfgP2/]]h0202/]]h00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00P0oooo000=0?ooo`030000003oool0oooo03X0oooo00@000000;g2iP00000000002P2m
a^H2000000P0_LKN00@000000;g:iP00000000002`35b]h00`000000aLkV0<G>iP070<G>iP<00000
1P3=d^H2000000030<gBgP000000cM[V00D0cM[V0P0000040=GRiP<0000000D0eN[V000000000000
00000=kfgP02000000080=Goe@00000000000000002mTK@000000;BE_@0000020;BI_@040000002/
VLD0[9W500000080[9g500<000000:bQc@2/XLd00P2/XLd01P000000[:G=0:bUc@000000[:G=0000
0080[:[E1P0000030;B^e@030000002//]h0[;;N00D0[;;N00<000000:bbgP2//]h01P2//]h00`00
0000[;KN0:bfgP080:bfgP030000003oool0oooo01/0oooo00<000000?ooo`3oool0203oool000d0
oooo0P00000j0?ooo`030000002m`^H0_L;V0080_L;V0P0000070;g6iP030000002ma]h0_LKN00T0
_LKN00<000000<G:gP35b]h02@35b]h2000000030<G:gP000000aLkV00D0aLkV0P0000030<g>gP04
0000003=d^H0cM;V0<gBiP8000000`3=d]h00`000000cM[V0<gJiP020<gJiP80000000@0eM[N0000
003Eh^H0eN;V0P0000001@3Eh]h00000000000000000g^kN00<0000000<0i_KN0000000000000P00
00001@2mUJ`000000000002dUKd000000080]9Vm00@000000:bIa@2/VLD000000`2/WLD00`000000
[:7=00000009000000<0]:kE00<000000;B^e@2d[]D00`2d[]D00`000000[;;N0:bbgP050:bbgP03
0000002//]h0[;;N00H0[;;N00<000000:bfgP2/]]h0202/]]h00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00P0oooo000=0?ooo`030000003oool0oooo03P0oooo00<000000;g2iP2m`^H0
1@2m`^H2000000@0_LKV00<000000;g6gP2ma]h02@2ma]h00`000000_LKN000000090<G:gP030000
0035b]h0aL[N0080aL[N00<000000<G>iP35c^H00P35c^H00`000000cLkN0<g>gP030<g>gP040000
003=d^H00000000000H0cM;N00@000000<gJiP00000000000`3Ef]h3000000<0eN;N00H000000=k^
gP3Nk]h0g^kN0000003Vm]hF00000080]:G=00H000000;BZc@2dZ/d000000;BZc@0000050;B^e@03
0000002d[]D0]:kE00<0]:kE00<000000:bbgP2//]h01@2//]h00`000000[;;N0:bbgP070:bbgP03
0000002/]]h0[;KN00P0[;KN00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`00
303oool00`000000oooo0?ooo`0h0?ooo`030000002m`^H0_L;V00P0_L;V0P0000000`2ma^H00000
0;g6gP0:0;g6gP050000002ma]h0_LKN0;g6gP0000001`35b]h00`000000aL[N0<G:gP040<G:gP04
00000035c^H00000000000L0cLkN00<000000<gBgP3=d]h01P3=d]h2000000@0eM[N0P0000030=GR
gP<0000000<0g^kN000000000000200000001@3=XK@000000000002mWKd000000080_J6m00@00000
0;BQa@2dXLD000000`2dYLd01@000000]:G=0;BUc@2dYLd000000080]:[=00<000000;BZc@000000
1@2d[]D00`000000]:kE0;B^e@030;B^e@030000002//]h0[;;N00H0[;;N00<000000:bbgP2//]h0
1P2//]h00`000000[;KN0:bfgP080:bfgP030000003oool0oooo01X0oooo00<000000?ooo`3oool0
203oool000`0oooo00<000000?ooo`3oool0=`3oool00`000000_L;V0;g2iP0;0;g2iP030000002m
a]h0_LKN00P0_LKN0P0000050;g6gP8000000`35b]h2000000P0aL[N00<000000<g>gP3=c]h01@3=
c]h2000000030<g>gP000000cM;N00@0cM;N0`0000030=GJgP80000000<0eM[N0000003Eh]h00P00
00020=kRgP80000000<0i^[N0000003Vm]D01`0000001@3=XK@000000000002mWKd000000080_J6m
00@000000;BQa@2dXLD000000`2dYLd01@000000]:G=0;BUc@2dYLd000000080]:[=00<000000;BZ
c@0000001@2d[]D00`000000]:kE0;B^e@040;B^e@030000002//]h0[;;N00D0[;;N00<000000:bb
gP2//]h01P2//]h00`000000[;KN0:bfgP080:bfgP030000003oool0oooo01X0oooo00<000000?oo
o`3oool0203oool000`0oooo00<000000?ooo`3oool0=P3oool00`000000_L;V0;g2iP0;0;g2iP04
0000002m`]h00000000000L0_LKN00<000000;g6gP2ma]h01`2ma]h00`000000aL[N000000080<G:
gP80000000<0aL[N0000003=c]h0103=c]h01@000000cLkN0<g>gP3=c]h0000000@0cM;N00@00000
0=GFgP3Ee]h0eMKN0`0000040=GJgP030000003Nh]h0g^;N0080g^;N00<000000>KZgP0000002P00
00001035WK@000000;fM_@0000020;fQ_@040000002dXLD0]:75000000<0]:G=00D000000;BUc@2d
YLd0]:G=000000020;BZc@040000002dZ/d0]:[=000000@0]:kE00<000000;B^e@2d[]D0102d[]D0
0`000000[;;N0:bbgP050:bbgP030000002//]h0[;;N00H0[;;N00<000000:bfgP2/]]h0202/]]h0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo000<0?ooo`030000003oool0oooo
03D0oooo00<000000;g2iP2m`^H02`2m`^H00`000000_L;N0;g2gP020;g2gP800000102ma]h00`00
0000_LKN0;g6gP090;g6gP0300000035b]h0aL[N00H0aL[N00D000000<G:gP35b]h0aL[N00000004
0<g>gP030000003=c]h0cLkN00<0cLkN00@000000<gBgP0000000000103Ee]h00`000000eM[N0=GJ
gP020=GJgP<000000P3Nh]h4000000040>KZe@00000000000>kVa@@0000000<0g[Jd000000000000
1@0000001@2mXKd000000;BQa@2dXLD0000000<0]:G=00D000000;BUc@2dYLd0]:G=000000020;BZ
c@040000002dZ/d0]:[=000000@0]:kE00<000000;B^e@2d[]D0102d[]D00`000000[;;N0:bbgP05
0:bbgP030000002//]h0[;;N0080[;;N4000000L0?ooo`030000003oool0oooo00P0oooo000<0?oo
o`030000003oool0oooo03@0oooo00<000000;g2iP2m`^H02`2m`^H00`000000_L;N0;g2gP050;g2
gP80000000<0_LKN0000002ma]h02@2ma]h2000000030<G6gP000000000000D0aL[N00<000000<G:
gP35b]h00`35b]h010000000cLkN0000000000070<g>gP030000003Ee]h0eMKN0080eMKN0`000003
0=GJgP030000003Nf]h0g][N00<000000P3Nh]h01`000000i^[E000000000000k^K50000003^g/D0
100000001`3E[[@000000<fZ_@000000aJZm00000035Z/D0:`0000040;BfgP030000002d]]h0];KN
00P0];KN00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`070?ooo`00303oool00`000000
oooo0?ooo`0c0?ooo`800000302m`^H00`000000_L;N0;g2gP080;g2gP030000002ma]h0_LKN00P0
_LKN00<000000<G6gP35a]h00`35a]h2000000030<G:gP000000000000L0aL[N00<000000<g>gP3=
c]h01@3=c]h3000000<0eMKN00@000000=GFgP3Ee]h0eMKN0`0000030=kJgP030000003Nh]h0g^;N
00H0000000<0k^K50000000000000P000000203N][@000000=F^]0000000cJZm00000035Z[d00000
0P35Z/D010000000_J[50;fZa@0000030;fZc@050000002m[/d0_Jk=0;f^c@0000000P2d[]D01000
0000]:kE0;B^e@0000040;B^e@030000002d/]D0];;E00@0];;E00<000000;BbgP2d/]h01@2d/]h0
0`000000];KN0;BfgP060;BfgP030000002d]]h0];KN00P0];KN00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`070?ooo`00303oool00`000000oooo0?ooo`0b0?ooo`030000002d_]h0];kN
008000002@2m`^H00`000000_L;N0;g2gP080;g2gP040000002m`]h00000000000L0_LKN00<00000
0<G6gP35a]h01P35a]h00`000000aL[N0<G:gP060<G:gP030000003=b]h0000000@0cLkN0P000003
0<g>gP<00000103Ee]h010000000g][N0=kJgP3Nf]h3000000040=kRgP000000i^;E0>KRe@800000
0P3^g/d3000000090>K6_@00000000000=F^]0000000cJZm00000035Z[d0000000<0aJ[500@00000
0;fZa@2mZ/D000000`2mZ/d01@000000_Jk=0;f^c@2m[/d0000000<0]:kE00<000000;B^e@000000
102d[]D00`000000];;E0;Bbe@040;Bbe@030000002d/]h0];;N00D0];;N00<000000;BfgP2d]]h0
1P2d]]h00`000000];KN0;BfgP080;BfgP030000003oool0oooo01/0oooo00<000000?ooo`3oool0
1`3oool000`0oooo00<000000?ooo`3oool0<P3oool00`000000];kN0;BngP020;BngP<000001@2m
`^H00`000000_L;N0;g2gP080;g2gP030000002m`]h0_L;N0080_L;N00<000000;g6gP2ma]h00P2m
a]h2000000P0aLKN00<000000<G2gP0000001@35b]h2000000<0cL[N00@000000<g>gP0000000000
1@3=c]h00`000000eMKN0=GFgP020=GFgP<0000000<0g][N0000000000000`3Nf]D00`000000i^;E
0000000200000080k]k=0P000000103^d[d000000000003N_[d5000000050<FZ_@000000aJ[50<FZ
a@0000000`2mZ/D010000000_J[=0;fZc@0000040;f^c@070000002d[]D0]:kE0;B^e@000000]:kE
000000040;B^e@030000002d/]D0];;E00@0];;E00<000000;BbgP2d/]h01@2d/]h00`000000];KN
0;BfgP060;BfgP030000002d]]h0];KN00P0];KN00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`070?ooo`00303oool00`000000oooo0?ooo`0a0?ooo`030000002d_]h0];kN00H0];kN0P00
00020;g2iP030000002m`]h0_L;N00P0_L;N00<000000;g2gP2m`]h0102m`]h2000000030;g6gP00
0000aLKN00P0aLKN00D000000<G2gP35`]h0aL;N000000030<G:gP030000003=b]h0cL[N00@0cL[N
00<000000<g>gP3=c]h0103=c]h010000000eLkE0000003Ee]h2000000<0eMKE00@000000=kJe@3N
f]D0g][E10000000103Vg/d000000000003^g/d2000000090>K>a@000000i/Jm0000003N_[d00000
0=Ff_@000000cK:m00L000000P2mZ/D010000000_J[=0;fZc@0000040;f^c@040000002d[]D0]:kE
0;B^e@8000001@2d[]D00`000000];;E0;Bbe@040;Bbe@030000002d/]h0];;N00D0];;N00<00000
0;BfgP2d]]h01P2d]]h00`000000];KN0;BfgP080;BfgP030000003oool0oooo01/0oooo00<00000
0?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool0<03oool00`000000];kN0;BngP090;Bn
gP8000002`2m`]h00`000000_L;N0;g2gP060;g2gP0300000035a]h0aLKN00H0aLKN0P0000050<G2
gP0300000035b]h0000000H0cL[N00<000000<g:e@0000000`3=c]h2000000<0eLkE00@000000=GF
e@3Ee]D0eMKE0`0000000`3Nf]D00000000000020=kJe@030000003Vg/d000000080i][=00P00000
0>KFa@00000000000=k:a@000000g[jm00000080eKJm00D000000<fb_@000000cK;5000000020<F^
a@0300000035[/d0000000L000000P2m[/d010000000]:kE0;B^e@2d[]D2000000D0]:kE00<00000
0;Bbe@2d/]D0102d/]D00`000000];;N0;BbgP050;BbgP030000002d]]h0];KN00H0];KN00<00000
0;BfgP2d]]h01`2d]]h00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo000;0?oo
o`030000003oool0oooo0340oooo00<000000;BngP2d_]h02@2d_]h010000000_KkN000000000008
0;g2gP030000002m`]h0_L;N00H0_L;N00@000000<FngP00000000001@35a]h00`000000aL;N0<G2
gP060<G2gP030000003=b]h0cL[N00<0cL[N0P0000030<g:e@030000003=c]h0000000@0eLkE00D0
00000=G>e@000000eMKE000000030=kBe@070000003Nf]D0g][E0=kJe@000000g]KE000000020>KJ
c@040000003Vd/d000000>K>a@80000000L0g/;5000000000000eKJm0000003=/[d000000080cK;5
00@000000<F^a@35[/D000000`35[/d010000000_K;=0;fbc@0000020;fbc@X000000`2d[]D00`00
0000];;E0;Bbe@040;Bbe@030000002d/]h0];;N00D0];;N00<000000;BfgP2d]]h01P2d]]h00`00
0000];KN0;BfgP070;BfgP030000003oool0oooo01`0oooo00<000000?ooo`3oool01`3oool000/0
oooo00<000000?ooo`3oool0<03oool00`000000];kN0;BngP090;BngP030000002m_]h0_KkN0080
_KkN0P0000050;g2gP030000002m`]h0_L;N00H0_L;N00<000000<FngP35_]h00P35_]h200000080
aLKN00<000000<G2gP35`]h01P35`]h00`000000aL;E000000030<g:gP030000003=b]D0cL[E00@0
cL[E00@000000=G>e@3Ec]D0eLkE0P0000030=G>e@0:0000003Nd]D0g];E0=kBe@000000g];E0000
003Nf]D000000=kFe@80000000P0i][=0000003Vd/d000000>K>a@000000g/[500000080g/;50`00
0000103=/[d000000<fba@0000020<F^a@0500000035[/d0aJk=0<F^c@0000000`2m//d00`000000
_K;=0;fbc@020;fbc@040000002m/]D0_K;E0;fbe@8000000P2m/]D7000000<0];;E00<000000;Bb
gP2d/]h01@2d/]h00`000000];KN0;BfgP060;BfgP030000002d]]h0];KN00L0];KN00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`070?ooo`002`3oool00`000000oooo0?ooo`0_0?ooo`03
0000002d_]h0];kN00X0];kN00<000000;fngP2m_]h0102m_]h200000080_L;N00<000000;g2gP2m
`]h01P2m`]h00`000000aKkN0<FngP050<FngP8000001`35`]h2000000<0aL;E00<000000<g:gP00
00001P3=b]D01@000000cL[E0000003Ec]D0000000@0eLkE0P0000020=kBe@050000003Nd]D0g];E
0=kBe@0000000P3Ne]D02@000000g]K=0000003Vd/d000000>K>a@000000g/[5000000020=k2a@03
0000003E_/D0eKk500H0000000<0aJk500000035[/d00P35[/d01@000000_K;=0;fbc@2m//d00000
00<0_K;=00<000000;fbe@2m/]D00P2m/]D00`000000_K;E0;fbe@040;fbe@040000002d]]D0];KE
0;BfeA000000102d]]h00`000000];KN0;BfgP070;BfgP030000003oool0oooo01`0oooo00<00000
0?ooo`3oool01`3oool000/0oooo00<000000?ooo`3oool0;P3oool00`000000];kN0;BngP0:0;Bn
gP030000002m_]h0_KkN00L0_KkN0`0000080;g2gP0300000035_]h0aKkN00D0aKkN00@000000<Fn
e@00000000001035`]h00`000000aL;E0<G2e@040<G2e@030000003=b]D0cL[E00<0cL[E0P000003
0<g:e@040000003Ec]D0eLkE0=G>e@8000000P3Ec]D2000000<0g];E0P0000001P3Ne]D000000=kF
c@000000g];=00000080i/k500P000000=k:a@00000000000=k2a@000000eKk500000080eK[500@0
00000<ffa@000000cKK=0`0000000`35[/d000000;fbc@020;fbc@030000002m//d0_K;=0080_K;=
00<000000;fbe@2m/]D00P2m/]D00`000000_K;E0;fbe@030;fbe@030000002d]]D0];KE00D0];KE
00<000000;BfgP2d]]h01@2d]]h00`000000];[N0;BjgP020;BjgPl000007P3oool00`000000oooo
0?ooo`070?ooo`002`3oool00`000000oooo0?ooo`0^0?ooo`030000002d_]h0];kN00T0];kN00<0
00000;fngP2m_]h0202m_]h00`000000_KkN0;fngP02000000D0_L;N00<000000<FngP35_]h01@35
_]h00`000000aKkE0<Fne@020<Fne@80000000<0aL;N00000035`]D01@35`]D010000000cL;E0000
000000020<g:e@030000003=b]D0cL[E0080cL[E00D000000=G:e@000000eLkE000000040=G>e@05
0000003Nd]D0g];E0=kBe@0000000P3Nd/d010000000g]K=0000003Nd/d2000000040>K>a@000000
g/[500000080g/K500P000000=Fna@3E_/D000000=Fja@000000cKK5000000<0cKK=00<000000<Ff
c@0000000P0000020;fbc@030000002m//d0_K;=0080_K;=00<000000;fbe@2m/]D00P2m/]D00`00
0000_K;E0;fbe@030;fbe@030000002d]]D0];KE00@0];KE00<000000;BfgP2d]]h01@2d]]h00`00
0000];[N0;BjgP070;BjgP030000002d^]h0];[N00L0];[N00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`070?ooo`002`3oool00`000000oooo0?ooo`0]0?ooo`8000002P2d_]h00`000000
_KkN0;fngP090;fngP030000002m_]h0_KkN0080_KkN0P0000020;g2gP0300000035_]h0aKkN00D0
aKkN00<000000<Fne@35_]D01@35_]D00`000000aL;E0<G2e@040<G2e@030000003=`]D0cL;E0080
cL;E0P0000030<g:e@8000000`3Eb]D010000000eLkE0=G>e@3Ec]D2000000050=G>e@000000g];E
0000003Nd/d00P0000001`3Nd/d000000=kBc@3Nd/d000000=k>c@0000000P3Nb/D010000000g/K5
0000003E`/D200000080eK[500<000000<ffa@0000000P3=]/d01P000000aKK=0<Ffc@35]/d00000
0<Ffc@@000000P2m//d00`000000_K;E0;fbe@030;fbe@030000002m/]D0_K;E00<0_K;E00<00000
0;Bfe@2d]]D0102d]]D00`000000];KN0;BfgP050;BfgP030000002d^]h0];[N00H0];[N00<00000
0;BjgP2d^]h01`2d^]h00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo000;0?oo
o`<00000;@3oool00`000000];[N00000002000000L0];kN00<000000;fngP2m_]h0202m_]h00`00
0000_KkN0;fngP050;fngP8000002035_]h00`000000aKkE0<Fne@040<Fne@0300000035_]D00000
00@0aL;E00<000000<g2e@3=`]D00`3=`]D01@000000cL;E0000003=b]D0000000@0eL[E00D00000
0=G:e@000000eLkE000000040=G>e@030000003Nd/d000000080g];=0P0000001@3Nd/d000000=k>
c@000000g/[=0080000000H0g/K50000003E`/D0eL;50000003E_/D2000000030<ffa@000000cKK=
0080cKK=00@000000<Ffc@35]/d000001035]/d00`000000aKKE0000000400000080_K;E0P000005
0;fbe@030000002d]]D0];KE00@0];KE00<000000;BfgP2d]]h01@2d]]h00`000000];[N0;BjgP06
0;BjgP030000002d^]h0];[N00L0];[N00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`06
0?ooo`002`3oool00`000000oooo0?ooo`0/0?ooo`030000002d^]h0];[N00<0];[N100000020;Bn
gP030000002m_]h0_KkN00P0_KkN00<000000;fngP2m_]h01P2m_]h010000000_K[E000000000005
0<FngP0300000035_]D0aKkE00@0aKkE00@000000<Fne@35_]D0aKkE0P0000000`35`]D000000<g2
e@040<g2e@050000003=`]D0cL;E0<g2e@000000103Eb]D01@000000eL[E0=G:e@3Eb]D0000000<0
eLkE0P0000000`3Nc/d000000=kBc@020=kBc@050000003Nc/d000000=k>c@0000000P3Nb/d00`00
0000g/[=000000030=G2a@040000003E_/D000000<fnc@<0000000<0cKK=00000035]/d00P35]/d0
1@000000aKK=0<Ffc@35]/d0000000@0aKKE00<000000;ffe@2m]]D01@0000030;fbe@030000002d
]]D0];KE00D0];KE00<000000;BfgP2d]]h0102d]]h00`000000];[N0;BjgP070;BjgP030000002d
^]h0];[N00L0];[N00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`000P000002
0?ooo`8000001@3oool00`000000oooo0?ooo`0/0?ooo`030000002d^]h0];[N00L0];[N0`000009
0;fngP030000002m_]h0_KkN00L0_KkN00@000000;fje@2m^]D0_K[E0P0000020<FngP0300000035
_]D0aKkE00D0aKkE00<000000<Fne@35_]D00`35_]D00`000000cL;E0<g2e@030<g2e@070000003=
`]D0cL;E0<g2e@000000cL;E000000030=G:e@080000003Eb]D0eL[E0000003Eb/d000000=G>e@00
00020=k>c@090000003Nc/d000000=kBc@000000g/k=0000003Nc/d0000000<0g/[=00H000000=k:
c@00000000000=G2a@0000020=Fna@050000003=_/d0cKk=0000003=_/d00`0000000`35]/d00000
0<Ffc@030<Ffc@0500000035]]D0aKKE0<Ffe@0000001@2m]]D2000000030;fje@000000000000D0
00000`2d]]D00`000000];KN0;BfgP050;BfgP030000002d^]h0];[N00H0];[N00<000000;BjgP2d
^]h0202d^]h00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00001P000000oooo
0?ooo`000000oooo000000@0oooo00<000000?ooo`3oool0;03oool00`000000];[N0;BjgP090;Bj
gP030000002d^]h00000008000001P2m_]h00`000000_KkN0;fngP060;fngP030000002m^]D0_K[E
00@0_K[E0`0000060<Fne@0300000035_]D0aKkE00<0aKkE00@000000<Fne@00000000000P3=`]D0
1@000000cL;E0<g2e@3=`]D0000000<0cL;E00<000000=G:e@0000000P3Eb]D01@000000eL[=0=G:
c@3Eb/d0000000<0g/k=00@000000=k>c@3Nc/d000000P3Nc/d2000000060=k:c@000000g/[=0000
003Nb/d000000P3Ea/d010000000eKk50=Fna@0000020<fnc@040000003=_/d0cKk=00000080cK[=
0`0000020<Ffc@0300000035]]D0aKKE0080aKKE00<000000;ffe@2m]]D00P2m]]D3000000@0_K[E
00@000000;fjgP2m^]h0_K[N1`0000030;BfgP030000002d^]h0];[N00L0];[N00<000000;BjgP2d
^]h01`2d^]h00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0oooo00001P000000oooo
0?ooo`000000oooo000000@0oooo00<000000?ooo`3oool0;03oool00`000000];[N0;BjgP080;Bj
gP030000002d^]h0];[N00<0];[N0`0000020;fngP030000002m_]h0_KkN00H0_KkN00<000000;fj
e@2m^]D01@2m^]D00`000000_K[E0;fje@0300000080aKkE00<000000<Fne@35_]D00`35_]D00`00
0000aKkE0<Fne@020<Fne@800000103=`]D00`000000cL;E0<g2e@020<g2e@040000003Eb]D0eL[E
000000<0eL[=00D000000=G:c@000000g/k=000000020=k>c@80000000@0g/k=0000003Nc/d00000
0P3Nb/d01`000000g/[=0=k:c@000000eLK=0000003E`/d00`0000020<fnc@040000003=_/d0cKk=
00000080cK[=00<000000<Fje@35^]D00`0000040<Ffe@030000002m]]D0000000<000000P2m^]D0
10000000_K[E0;fje@0000070;fjgP040000002m^]h0_K[N0;fjgPH000001`2d^]h00`000000];[N
0;BjgP070;BjgP030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool0008000000P3o
ool2000000@0oooo00<000000?ooo`3oool0:`3oool00`000000];[N0;BjgP090;BjgP030000002d
^]h0];[N00H0];[N0`0000070;fngP030000002m^]D0_K[E00H0_K[E00<000000;fje@2m^]D00`2m
^]D3000000D0aKkE00<000000<Fne@35_]D00P35_]D01P000000cKk=000000000000cL;E000000@0
cL;E00@000000=G6c@00000000000`3Eb/d01@000000eL[=0=G:c@3Eb/d000000080g/k=00H00000
0=k>c@3Nc/d000000=k>c@0000020=k:c@040000003Nb/d0000000000080eLK=00<000000=G2c@00
00000P3E`/d200000080cKk=00D000000<fjc@3=^/d0cK[=000000040<Fje@<0000000@0aKKE0000
0000000000000`2m]]D01`000000_K[E0;fje@2m^]D000000;fje@0000001P2m^]h00`000000_K[N
0;fjgP050;fjgP030000002d^]h0];[N00@000000P2d^]h00`000000];[N0;BjgP080;BjgP030000
003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool000X0oooo00<000000?ooo`3oool0:`3o
ool00`000000];[N0;BjgP080;BjgP030000002d^]h0];[N00P0];[N00<000000;fjgP0000000`00
00030;fngP030000002m^]D0_K[E00D0_K[E00<000000;fje@2m^]D0102m^]D00`000000aK[E0<Fj
e@0200000080aKkE00<000000<Fne@35_]D00P35_]D00`000000cKk=0<fnc@020<fnc@030000003=
`]D0cL;E0080cL;E00P000000=G6c@3Ea/d000000=G6c@000000eL[=000000<0eL[=0P0000001`3N
c/d000000=k>c@3Nc/d000000=k>c@0000000`3Nb/d01P000000g/[=000000000000eLK=00000080
eL;=00P000000=G2c@3E`/d000000<g2c@000000cKk=00000080cK[=00<000000<Fje@35^]D00P35
^]D800000080_KKE00<000000;fje@2m^]D00`2m^]D00`000000_K[N0;fjgP050;fjgP030000002m
^]h0_K[N00@0_K[N00<000000;BjgP2d^]h01@2d^]h7000000D0];[N00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`060?ooo`002P3oool00`000000oooo0?ooo`0Z0?ooo`030000002d^]h0
];[N00T0];[N00<000000;BjgP2d^]h01`2d^]h00`000000_K[N0;fjgP040;fjgP@000001P2m^]D0
0`000000_K[E0;fje@050;fje@0300000035^]D0aK[E0080aK[E0P0000050<Fne@060000003=_/d0
cKk=0<fnc@000000cKk=0P0000000`3=`]D000000=G6c@020=G6c@040000003Ea/d0eLK=000000<0
eL[=00@000000=k:c@3Nb/d000000P3Nc/d02@000000g/k=0000003Nc/d000000=k:c@000000g/[=
000000020=G:c@040000003E`/d0eL;=000000<0eL;=00<000000<g2c@3=`/d00P0000020<fjc@03
00000035^]D0aK[E00<000000`35^]D010000000aKkE0<Fne@35_]D4000000@0_K[E0P0000050;fj
gP030000002m^]h0_K[N00D0_K[N00<000000;BjgP2d^]h01`2d^]h00`000000];kN0;BngP020;Bn
gPH000008P3oool00`000000oooo0?ooo`060?ooo`002P3oool00`000000oooo0?ooo`0Z0?ooo`03
0000002d^]h0];[N00P0];[N00<000000;BjgP2d^]h0202d^]h00`000000_K[N0;fjgP060;fjgP03
0000002m]]D0000000<000000P2m^]D00`000000_K[E0;fje@040;fje@0300000035^]D0aK[E00<0
aK[E00@000000<Fjc@00000000000P35_]D01@000000cKk=0<fnc@3=_/d0000000@0cKk=00D00000
0=G6c@3Ea/d0eLK=000000020=G6c@050000003Ea/d000000=G:c@0000000P3Nb/d010000000g/[=
0000000000020=k>c@060000003Nc/d0g/k=0000003Nb/d000000P3Eb/d010000000eL[=00000000
00030=G2c@040000003=`/d0cL;=00000080cL;E1@0000000`35^]D000000<Fje@030<Fje@030000
0035_]D0aKkE0080aKkE00<000000;fne@2m_]D00P0000001@2m^]D000000;fjgP2m^]h0000000@0
_K[N00<000000;fjgP2m^]h01@2m^]h00`000000];[N0;BjgP060;BjgP030000002d_]h0];kN00P0
];kN00<000000?ooo`3oool0803oool00`000000oooo0?ooo`060?ooo`002P3oool00`000000oooo
0?ooo`0Y0?ooo`<000002@2d^]h00`000000];[N0;BjgP070;BjgP030000002m^]h0_K[N00H0_K[N
00<000000;ffe@2m]]D0102m]]D3000000D0_K[E00<000000<Fje@35^]D01035^]D010000000aK[=
0<Fjc@35^/d2000000@0cKk=00H000000<fnc@3=_/d0cKk=0000003=_/d2000000050=G6c@000000
eLK=0=G6c@0000000P3Ea/d010000000g/[=0=k:c@0000020=k:c@80000000L0g/k=0000003Nc/d0
g/k=0000003Nc/d0000000<0eL[=00@000000=G:c@000000eLK=0P000000103E`/d000000<g2c@3=
`/d4000000030<g2e@00000000000080aK[E00D000000<Fje@35^]D0aK[E000000050<Fne@030000
002m_]D0_KkE0080_KkE1@0000030;fjgP030000002m^]h0_K[N00D0_K[N00<000000;BjgP2d^]h0
1`2d^]h00`000000];kN0;BngP070;BngP030000003oool0oooo0240oooo00<000000?ooo`3oool0
1P3oool000X0oooo00<000000?ooo`3oool0:@3oool00`000000];[N0;BjgP0600000080];[N00<0
00000;BjgP2d^]h0202d^]h00`000000_K[N0;fjgP060;fjgP030000002m]]D0_KKE00D0_KKE00<0
00000;ffe@0000000P0000020;fje@0300000035^]D0aK[E00<0aK[E00<000000<Fjc@35^/d00P35
^/d01P000000aK[=000000000000cKk=000000<0cKk=00<000000<fnc@3=_/d00P3=_/d010000000
eLK=0=G6c@0000020=G6c@040000003Ea/d0000000000080g/[=00@000000=k>c@3Nc/d000000P3N
c/d01`000000g/k=0000003Nc/d000000=G:c@0000000P3Eb/d010000000eLK=0=G6c@3Ea/d50000
0080cL;E00@000000<g2e@3=`]D0cL;E0`0000030<Fje@0300000035_]D0aKkE0080aKkE00<00000
0;fne@2m_]D00`2m_]D00`000000_KkN0;fngP020;fngPD000001P2m^]h00`000000];[N0;BjgP06
0;BjgP030000002d_]h0];kN00P0];kN00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`05
0?ooo`002P3oool00`000000oooo0?ooo`0Y0?ooo`030000002d^]h0];[N00H0];[N1@0000070;Bj
gP030000002m^]h0_K[N00L0_K[N00<000000;ffe@2m]]D0102m]]D00`000000_KKE0;ffe@030;ff
e@<000001035^]D00`000000aK[=0<Fjc@020<Fjc@0300000035^/d0aK[=0080aK[=00<000000<fn
c@3=_/d00P3=_/d01P000000cKk=0<fnc@3=_/d000000=Fnc@8000000`3Ea/d01P000000eLK=0000
00000000g/[=00000080g/k=00@000000=k>c@00000000000P3Nc/d010000000g/k=0=k>c@000002
0=G:c@030000003Ea/d0eLK=00D000000`3=`]D00`000000cL;E0<g2e@020<g2e@0300000035`]D0
aL;E00<000001035_]D00`000000_KkE0;fne@040;fne@030000002m_]h0_KkN00<0_KkN0P000002
0;fngP@0000000<0_K[N0000002d^]h0202d^]h00`000000];kN0;BngP070;BngP030000003oool0
oooo02<0oooo00<000000?ooo`3oool01@3oool000T0oooo00<000000?ooo`3oool0:@3oool00`00
0000];[N0;BjgP090;BjgP030000002d]]h0];KN00@000000`2d^]h00`000000_K[N0;fjgP060;fj
gP030000002m]]D0_KKE00D0_KKE00<000000;ffe@2m]]D0102m]]D010000000_KKE000000000002
0<Fje@0300000035^/d0aK[=0080aK[=00H000000<Fjc@35^/d0aK[=0000003=^/d2000000030<fn
c@000000cKk=0080cKk=00P000000=Fnc@3E_/d000000=G2c@000000eLK=00000080eLK=00<00000
0=k:c@0000000P3Nc/d00`000000g/k=0=k>c@02000000060=k>c@000000g/k=0=k>c@000000eLk=
1P0000020=G6e@060000003=a]D000000000003=`]D000000`3=`]D00`000000aL;E0<G2e@020<G2
e@0400000035`]D0000000000080aKkE00<000000;fne@2m_]D00`2m_]D00`000000_KkN0;fngP05
0;fngP030000002m_]h0_KkN00@0_KkN0`0000070;BjgP030000002d_]h0];kN00P0];kN00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`0Y0?oo
o`030000002d^]h0];[N00T0];[N00<000000;BfgP2d]]h0102d]]h5000000L0_K[N00<000000;ff
e@2m]]D0102m]]D00`000000_KKE0;ffe@040;ffe@030000002m]]D0_KKE0080_KKE0`0000030<Fj
c@0300000035^/d0aK[=0080aK[=00@000000<fjc@3=^/d0cK[=0P0000020<fnc@050000003E_/d0
eKk=0=Fnc@0000000P3E`/d01`000000eLK=0=G6c@000000g/[=0000003Nb/d00P0000020=k>c@04
0000003Nc/d0g/k=00000080g/k=10000000103Eb]D000000=G6c@0000020=G6e@030000003=a]D0
cLKE0080cLKE00<000000<g2e@3=`]D00P3=`]D00`000000aL;E0<G2e@020<G2e@0400000035`]D0
aL;E0<G2e@<00000102m_]D00`000000_KkN0;fngP050;fngP030000002m_]h0000000D0_KkN00<0
00000;fngP2m_]h00P0000050;BjgP030000002d_]h0];kN00L0];kN00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`0Y0?ooo`030000002d^]h0
];[N00P0];[N00<000000;BfgP2d]]h01`2d]]h00`000000];KN0;BfgP0400000080_K[N00<00000
0;ffe@2m]]D01@2m]]D00`000000_KKE0;ffe@040;ffe@030000002m]]D0_KKE00<0_KKE00<00000
0<Fbc@0000000P0000040<Fjc@030000003=^/d0cK[=0080cK[=00<000000<fjc@0000000P000002
0=Fnc@050000003E`/d0eL;=0000003Ea/d00P0000020=k:c@060000003Nb/d000000000003Nc/d0
00000P3Nc/d500000080eLk=00@000000=G:e@3Eb]D000000P3Ea]D00`000000cLKE0<g6e@020<g6
e@060000003=a]D000000000003=`]D000001035`]D00`000000aL;E0<G2e@020<G2e@0300000035
`]h0aL;N008000000P2m_]D00`000000_KkN0;fngP040;fngP050000002m_]h0_KkN0;fngP000000
102m_]h00`000000_KkN0;fngP020;fngP<0000000<0];[N0000002d_]h02@2d_]h00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo00D0oooo00090?ooo`030000003oool0oooo02T0oooo00<0
00000;BjgP2d^]h0202d^]h00`000000];KN0;BfgP070;BfgP030000002d]]h0];KN00@0];KN1P00
00030;ffe@030000002m]]D0_KKE00@0_KKE00<000000;ffe@2m]]D00`2m]]D00`000000aK;=0<Fb
c@020<Fbc@<000000P35^/d01@000000cK[=0<fjc@3=^/d000000080cK[=00<000000<fja@3=^/D0
0P0000030=G2c@060000003Ea/d000000000003Nb/d000000P3Nb/d010000000g/k=0000003Nc/d3
000000060=k>c@000000g/kE0000003Ec/d000000P3Eb]D010000000eL[E0000000000040<g6e@03
0000003=a]D0cLKE0080cLKE00<000000<G2e@35`]D00P35`]D00`000000aL;E0<G2e@030<G2e@03
00000035`]h0aL;N0080aL;N0`0000050;fngP030000002m_]h0_KkN00<0_KkN00@000000;fngP2m
_]h00000202m_]h4000000L0];kN00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?oo
o`002@3oool00`000000oooo0?ooo`0Y0?ooo`030000002d^]h0];[N00P0];[N00<000000;BfgP2d
]]h01P2d]]h00`000000];KN0;BfgP070;BfgP040000002d/]D0];;E0;Bbe@D000001@2m]]D00`00
0000_KKE0;ffe@030;ffe@0500000035//d0aK;=0<Fbc@0000000`35//d3000000<0cK[=00@00000
0<fjc@3=^/d000000P3=^/D01@000000eKk50000003E`/d000000080eLK=00<000000=k6c@000000
0P3Nb/d5000000040=k>c@000000g/k=000000<0g/kE00@000000=G:e@3Eb]D000000P3Eb]D01P00
0000cL[E000000000000cLKE000000@0cLKE00@000000<g6e@00000000000P35`]D00`000000aL;E
0<G2e@020<G2e@0300000035`]h0aL;N00<0aL;N00<000000;g2gP2m`]h00`0000020;fngP030000
002m_]h0_KkN00@0_KkN00<000000;fngP000000202m_]h010000000];kV0;BniP2d_^H4000000<0
];kN00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo
0?ooo`0X0?ooo`030000002d^]h0];[N00T0];[N00<000000;BfgP2d]]h01P2d]]h00`000000];KN
0;BfgP060;BfgP030000002d/]D0];;E00D0];;E00<000000;fbe@0000000P0000000`2m]]D00000
0;ffe@040;ffe@0300000035//d0aK;=0080aK;=00<000000<Fbc@35//d00P35//d00`000000aK;5
0000000200000080cK[=00D000000<fja@3=^/D0cK[5000000020=Fna@070000003Ea/d0eLK=0000
003Na/d000000=k:c@03000000070=k>c@000000g];=0=kBc@000000g/k=000000030=k>e@800000
00D0eL[E0000003Eb]D0eL[E000000040<g:e@030000003=a]D0cLKE0080cLKE00<000000<g6e@3=
a]D00P3=a]D2000000@0aL;E00<000000<G2gP35`]h00`35`]h00`000000_L;N0;g2gP040;g2gP<0
00001`2m_]h00`000000_KkN0;fngP070;fngP030000002d_^H0];kV00D0];kV0`00000X0?ooo`03
0000003oool0oooo00D0oooo00090?ooo`800000:@3oool00`000000];[N0;BjgP080;BjgP030000
002d]]h0];KN00L0];KN00<000000;BfgP2d]]h01P2d]]h00`000000];;E0;Bbe@040;Bbe@030000
002m/]D0_K;E00<0_K;E100000030;ffe@0300000035//d0aK;=0080aK;=00D000000<Fbc@35//d0
aK;=000000030<Fba@050000003=//D000000<fjc@0000000P3=^/D01@000000eKk50=Fna@000000
eKk500P0000000L0g/k=0000003Nd/d0g];=0000003Nd]D0000000<0g/kE00@000000=GBe@3Ed]D0
00000`3Eb]D01P000000cL[E0<g:e@3=b]D000000<g:gP80000000<0cLKE0000003=a]D0103=a]D0
10000000aLKN0000000000020<G2e@0300000035`]h0aL;N00<0aL;N00<000000;g2gP2m`]h0102m
`]h00`000000_L;N0;g2gP02000000@0_KkN00<000000;fngP0000001`2m_]h00`000000];kV0;Bn
iP070;BniP030000003oool0oooo02L0oooo00<000000?ooo`3oool01@3oool000T0oooo00<00000
0?ooo`3oool0:03oool6000000D0];[N00<000000;BfgP2d]]h01`2d]]h00`000000];KN0;BfgP05
0;BfgP030000002d/]D0];;E00D0];;E00<000000;fbe@2m/]D0102m/]D00`000000_Jk=0;f^c@05
00000080aK;=00<000000<Fbc@35//d00P35//d01@000000aK;50<Fba@35//D000000080cK;50P00
00020<fja@030000003E_/D0eKk500D000000`3Nb/d00`000000g/k=000000020=kBc@070000003N
d]D000000=kFe@000000g/kE000000020=GBe@050000003Ed]D000000=G:e@0000000`3=b]D00`00
0000cL[N0<g:gP020<g:gP030000003=a]D0cLKE00<0cLKE00<000000<G6gP35a]h00P35a]h20000
00D0aL;N00<000000;g2gP2m`]h0102m`]h00`000000_L;N0;g2gP030;g2gP8000000P2m_]h01000
0000_KkN0;fngP0000050;fngP030000002d_^H0];kV00L0];kV00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`050?ooo`002@3oool00`000000oooo0?ooo`0X0?ooo`030000002/]]h0[;KN
00<0[;KN200000060;BfgP030000002d]]h0];KN00H0];KN00<000000;Bbe@2d/]D01@2d/]D00`00
0000_K;E0;fbe@030;fbe@030000002m[/d0_Jk=00<0_Jk=00<000000;f^c@2m[/d0100000020<Fb
c@0500000035//D0aK;50<Fba@0000000`3=//D00`000000cK;500000005000000030=Fna@000000
g/K50080000000D0g/[=0000003Nc/d000000=kBc@0200000080g];E00@000000=kFe@3Ne]D00000
0P3Ed]D01@000000eM;E0=GBe@3Ed]D0000000@0cL[E00L000000<g:gP3=b]h0cL[N0000003=b]h0
000000<0cLKE00<000000<G6gP35a]h00`35a]h010000000aLKN0000000000020<G2gP030000002m
`]h0_L;N00@0_L;N00<000000;g2gP2m`]h01P2m`]h300000080_KkN00<000000;fngP2m_]h00P2m
_]h00`000000];kV0;BniP080;BniP030000003oool0oooo02P0oooo00<000000?ooo`3oool01@3o
ool000T0oooo00<000000?ooo`3oool0:03oool00`000000[;KN0:bfgP080:bfgP030000002d/]h0
];;N00@000000P2d]]h00`000000];KN0;BfgP050;BfgP030000002d/]D0];;E00H0];;E00<00000
0;fbe@2m/]D00`2m/]D00`000000_Jk=0;f^c@020;f^c@030000002m[/d0_Jk=00<0_Jk=00<00000
0;f^c@0000000`0000020<Fba@050000003=//D0cK;50000003=//D01@0000020=Fna@030000003N
a/D000000080g/[500<000000=k>c@0000000P3Nd/d2000000030=kBe@000000g]KE00<0000000<0
eM;E0000003Ed]D00P3Ed]D01P000000eM;N000000000000cL[E000000<0cL[N00L000000<g:gP3=
b]h0cL[N0000003=a]D0000000@0aLKN0P0000040<G6gP8000001`2m`]h00`000000_L;N0;g2gP06
0;g2gP030000002m`^H0_L;V0080000000<0_KkN0000002m_]h00P2m_]h00`000000];kV0;BniP07
0;BniP030000003oool0oooo02X0oooo00<000000?ooo`3oool0103oool000P0oooo00<000000?oo
o`3oool0:@3oool00`000000[;KN0:bfgP080:bfgP030000002d/]h0];;N00@0];;N3P0000040;Bb
e@030000002m/]D0_K;E00@0_K;E00<000000;f^c@2m[/d00P2m[/d00`000000_Jk=0;f^c@020;f^
c@030000002m[/d0_Jk=0080_Jk=00<000000<FZa@0000001P000000103=//D000000<ffa@3=]/D3
00000080g/K500D000000=k:a@000000g/k=000000020=kBc@060000003Ne]D0g]KE0000003Ne]D0
00000`3Ne]D01@000000eM;E0=GBe@3Ed]D0000000@0eM;N00D000000<g:gP3=b]h0cL[N00000005
0<g:gP0300000035a]h0aLKN0080aLKN00<000000<G6gP35a]h01035a]h010000000aLKN00000000
00040;g2gP030000002m`]h0_L;N00H0_L;N00<000000;g2iP2m`^H00`2m`^H3000000030;fngP00
0000];kV00P0];kV00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`040?ooo`00203oool0
0`000000oooo0?ooo`0Y0?ooo`030000002/]]h0[;KN00P0[;KN00<000000;BbgP2d/]h01P2d/]h0
0`000000];;N0;BbgP050;BbgP040000002d[]D0]:kE0;B^e@L000000`2m/]D00`000000_Jk=0;f^
c@030;f^c@030000002m[/d0_Jk=0080_Jk=00D000000;f^c@2m[/d0_Jk=000000020<FZa@H00000
0P3=//D00`000000cKK5000000020=Fja@<0000000<0g/[50000003Nc/d00P0000000`3Nd/d00000
0=kFe@02000000040=kJe@000000g]KE0=kFe@80000000@0eMKN0000003Ed]D00000103Ed]h01@00
0000cM;N0000003=b]h0000000@0cL[N0P0000001@35b]h0000000000035a]h0000000H0aLKN00<0
00000<G6gP35a]h00P35a]h2000000030;g2gP000000_L;N00L0_L;N00<000000;g2iP2m`^H01P2m
`^H3000000P0];kV00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`040?ooo`00203oool0
0`000000oooo0?ooo`0Y0?ooo`030000002/]]h0[;KN00P0[;KN00<000000;BbgP2d/]h01P2d/]h0
0`000000];;N0;BbgP050;BbgP030000002d[]D0]:kE00D0]:kE00<000000;B^e@2d[]D01P000002
0;f^c@030000002m[/d0_Jk=00<0_Jk=00<000000;f^c@2m[/d01@0000030<FZa@0400000035[[d0
000000000080cKK500L000000=Fja@000000g/;50000003Na/D000000080g/k=00D000000>KFc@00
0000g]KE000000020=kJe@80000000<0g]KE0000003Ee]h00`3Ee]h010000000eM;N0=GBgP3Ed]h2
000000<0cM;N00<000000<g:gP3=b]h00P3=b]h00`000000aL[N0<G:gP030<G:gP0300000035a]h0
aLKN00@0aLKN00<000000<G6gP35a]h01@35a]h00`000000_L;N0;g2gP060;g2gP030000002m`^H0
_L;V00L0_L;V00<000000;g2iP0000000P0000060;BniP030000003oool0oooo02`0oooo00<00000
0?ooo`3oool0103oool000P0oooo00<000000?ooo`3oool0:@3oool00`000000[;KN0:bfgP080:bf
gP030000002d/]h0];;N00H0];;N00<000000;BbgP2d/]h01@2d/]h00`000000]:kE0;B^e@050;B^
e@030000002d[]D0]:kE00<0]:kE00<000000;BZc@2dZ/d01@0000020;f^c@D000000`35Z/D01000
0000aJ[50<FZa@0000030<F^_@<000000P3E^/D00`000000g/;500000002000000060=k>c@000000
i]K=0000003Vf]D000000P3Nf]D010000000g][E0=kJe@0000030=GFgP80000000@0eMKN0000003E
d]h00000103=d]h010000000cM;N0000003=b]h2000000D0aL[N00<000000<G:gP0000001035a]h0
0`000000aLKN0<G6gP050<G6gP040000002ma^H00000000000D0_L;N00<000000;g2iP2m`^H01`2m
`^H01P000000_L;V0;g2iP2m`^H000000;g2iP<000000P2d_^H00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo00@0oooo00080?ooo`030000003oool0oooo02T0oooo00<000000:bfgP2/]]h0
1`2/]]h00`000000];;N0;BbgP070;BbgP030000002d/]h0];;N00D0];;N00<000000;B^e@2d[]D0
102d[]D8000000@0]:[=00<000000;BZc@000000200000000`35Z/D000000<FZa@020<FZa@040000
0035[[d0aJjm00000080cJjm0`0000002@3N`/D000000=k6a@000000i];50000003Ve/d000000>KJ
e@02000000090=kJe@000000g][E0=kJe@000000g]kN0000003Ee]h0000000@0eMKN00@000000<gB
gP3=d]h0cM;N0P0000030<gBgP0300000035b]h0aL[N00<0aL[N0P0000030<G:gP80000000<0aLKN
00000035a]h01P35a]h00`000000_LKV0;g6iP020;g6iP8000000P2m`]h00`000000_L;V0;g2iP07
0;g2iP030000002m`^H0_L;V00<0_L;V00@000000;g2iP2m`^H0_L;V0P00000`0?ooo`030000003o
ool0oooo00@0oooo00080?ooo`030000003oool0oooo02T0oooo00<000000:bfgP2/]]h01`2/]]h0
0`000000];;N0;BbgP070;BbgP030000002d/]h0];;N00@0];;N2000000707^fo`040000002dZ/d0
]:[=0;BZc@<000000`2dZ/d01P000000_JG50;fUa@2mYLD000000;fUa@<0000000<0aJ[500000035
[[d00P35[[d00`000000cJjm000000020=Fb_@80000000P0g/K50000003Vd/D000000>KJc@000000
i][E00000080g]kE00@000000=kJe@3Nf]D000000`3Ng]h010000000eMKN0=GFgP3Ee]h200000004
0=GFgP000000cM;N000000@0cM;N00<000000<gBgP0000000`35b]h00`000000aL[N0<G:gP050<G:
gP0300000035a]h0aLKN00D0aLKN00<000000;g6iP2ma^H01@2ma^H3000000P0_L;V00<000000;g2
iP2m`^H01@2m`^H010000000_L;V0;g2iP00000a0?ooo`030000003oool0oooo00@0oooo00080?oo
o`030000003oool0oooo02T0oooo00<000000:bfgP2/]]h01`2/]]h00`000000];;N0;BbgP070;Bb
gPL000000`1c^_l2000000X0NkKo100000000`2dZ/d000000;BZc@030;BZc@050000002mYLD0_JG5
0;fUa@0000000P2mYLD00`000000_J6m0000000400000080cJjm00@000000=Fb_@000000g[Zm0P00
00001P3Vd/D000000>KJc@000000i^;=00000080g]kE0P0000000`3Nf]D000000=kNgP020=kNgP80
000000<0eMKN000000000000103Ee]h00`000000cM;N0<gBgP020<gBgP070000003=d]h0cM;N0<gB
gP000000aL[N000000070<G:gP0400000035b^H00000000000@0aLKN00<000000;g6iP2ma^H01P2m
a^H00`000000_LKV0;g6iP02000000D0_L;V00<000000;g2iP2m`^H01`2m`^H200000380oooo00<0
00000?ooo`3oool0103oool000P0oooo00<000000?ooo`3oool0:@3oool00`000000[;KN0:bfgP07
0:bfgP030000002d/]h0];;N00@0];;N1000000;07>jo`030000001k]_l0NkKo00@0NkKo0`000002
07^fo`80000000<0]:[=0000002dZ/d00P2dZ/d01@000000_JG50;fUa@2mYLD0000000<0_JG500@0
00000;fQ_@2mXKd000000P35XKd300000080eK:m0`0000001@3Vd/D000000>KJc@000000i^;=0080
000000D0g]kE0000003Nh]h0g^;N000000020=kNgP8000000P3Eg]h00`000000eMKN0=GFgP020=GF
gP80000000D0cMKV0000003=d]h0cM;N000000050<gBgP0300000035b]h0aL[N00@0aL[N0P000004
0<G:iP80000000<0aLKN0000002ma^H01`2ma^H00`000000_LKV0;g6iP030;g6iP8000000P2m`^H0
0`000000_L;V0;g2iP080;g2iP800000<P3oool00`000000oooo0?ooo`040?ooo`00203oool00`00
0000oooo0?ooo`0Y0?oooa4000000P1c__l2000000`0Lk[o0P000000101k]_l00000000000000007
07^fo`8000000`2dZ/d01@000000_JG50;fUa@2mYLD000000080_JG500D000000;fQ_@2mXKd0_J6m
000000020<FQ_@0300000035YK@000000080000000H0g[Zm00000000000000000>kNa@0000020>KR
c@040000003Vi]D000000=kRgP<0000000<0g]kN0000003Eg]h00P3Eg]h2000000<0eMKN00L00000
0<gFiP3=e^H0cMKV0000003=d]h0000000@0cM;N0P0000000`35c^H000000<G:gP030<G:gP030000
0035b^H0aL[V00H0aL[V00<000000;g6iP2ma^H01@2ma^H2000000P0_LKV0P00000:0;g2iP040000
003oool0oooo00000340oooo00<000000?ooo`3oool0103oool000L0oooo00<000000?ooo`3oool0
:P3oool00`000000[;;N0:bbgP070:bbgP040000002//]h00000000000L0Lkko0P00000907>jo`D0
00001@1k]_l?000000050;fUa@000000_J6m0;fQ_@0000000P35XKd00`000000aJFd0<FU]0020000
00040=Fb]000000000000>KBa@<0000000<0i^;=0000000000000`0000030=kVgP030000003Eg]h0
eMkN008000000P3Eg^H3000000@0cMKV0P0000040<gBgP0300000035c^H0aLkV0080aLkV0P000000
0`35b]h000000<G:iP060<G:iP80000000<0_L[V000000000000102ma^H00`000000_LKV0;g6iP08
0;g6iP040000002ma^H00000000000L0_L;V00D000000?ooo`3oool0oooo0000000a0?ooo`030000
003oool0oooo00@0oooo00070?ooo`030000003oool0oooo02X0oooo00<000000:bbgP2//]h01`2/
/]h2000000/0Lkko0P00000407>jo`<000000`1c^_l7000000H0LkKo00@000000;BQc@2dXLd00000
0`2dWLD00`000000]9g500000005000000070<FQ_@000000aJFd0000003=Z[@000000=Fb]0030000
00030>kNa@000000k^[=008000000P3Nk]h00`000000g^KN0=kVgP03000000030=GNgP000000eMkV
00<0eMkV00<000000<gFiP3=e^H00P3=e^H200000080cMKV00@000000<gBgP00000000001`35c^H0
0`000000aL[V0<G:iP040<G:iP8000001@2mb^H2000000030;g6iP000000_LKV00P0_LKV0P000004
0;g6iP800000102m`^H00`000000oooo0?ooo`030?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool00`3oool000L0oooo00<000000?ooo`3oool0:`3oool00`000000[;;N0:bbgP040:bb
gP8000000P1c`_l2000000/0Lkko100000000`1c^_l0000000000003000000<0J[Ko00<0000007>f
o`1c]_l0201c]_l00`000000]:7=000000030;BMa@040000002dWLD0]9g500000080]9Vm00<00000
0;fI]0000000100000001`3E/[@000000>K2]0000000m^K50000003^j/d00P0000001P3Nk]h00000
000000000000g^KN000000<0eNKV00@000000=GNiP3Eg^H0eMkV0P0000000`3=g^H000000<gFiP02
000000D0cMKV00<000000<G>iP35c^H01@35c^H2000000030<G>iP000000aL[V00<0aL[V00<00000
0;g:iP2mb^H01`2mb^H00`000000_LKV0;g6iP070;g6iP030000002ma^H0_LKV00H0_LKV0P000000
0`2m`^H000000?ooo`060?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00`3oool0
00L0oooo00<000000?ooo`3oool0:`3oool00`000000[;;N0:bbgP020:bbgP8000001P1c`_l30000
00D0Lkko0`0000000`1c__l0000000000002000000T0J[Ko00<0000007>fo`1c]_l0201c]_l20000
00<0]9g500@000000;BMa@2dWLD000000P2dVKd01@000000_IVd0;fI]0000000_IVd00`000000P3N
k^H200000080eNKV0`0000000`3Eg^H00000000000040<gNiP030000003=e^H0cMKV00<0cMKV0`00
00050<G>iP8000001035c^H010000000aL[V0000000000080;g:iP80000000<0_L[V0000002ma^H0
1P2ma^H00`000000_LKV0;g6iP090;g6iP030000003oool0oooo00L0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`030?ooo`001`3oool00`000000oooo0?ooo`0[0?ooo`030000002/
/]h0[;;N008000002`1c`_l900000080J[[o0P00000:06Zfo`8000002@1c]_l01@000000]9g50;BM
a@2dWLD000000080]9g500@000000;BI_@2dVKd000000P2mVK@00`000000_IVd0000000200000004
0>Jj[000000000000>kfa@80000000<0g_KN0000003Nk^H00P000000103Ek^H00000000000000002
0=GViP800000103=g^H3000000<0cMKV0P0000030<GFiP0500000035c^H0aLkV0<G>iP0000001`35
c^H00`000000_L[V0;g:iP070;g:iP030000002mb^H0_L[V0080_L[V0P0000030;g6iP8000002`2m
a^H00`000000oooo0?ooo`090?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool00`3o
ool000L0oooo00<000000?ooo`3oool0:`3oool00`000000[;;N0000000;07?2o`<0000000@0Ll;o
0000000000000000201Z^_l2000000X0J[Ko00<0000007>fo`1c]_l01`1c]_l010000000]9g50;BM
a@0000020;BMa@070000002dVKd0]9Vm0000002mVK@000000;fI]002000000030=FU[00000000000
00P000000P3Ek^H200000080eNKV0P000000103=h^h000000<gNiP3=g^H2000000<0cM[V0`000005
0<GFiP0400000035c^H00000000000H0aLkV0P0000000`35c^H000000;g:iP050;g:iP8000001`2m
b^H00`000000_LKV0000000;0;g6iP8000003@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00<0oooo00070?ooo`800000;03oool200000080LlKo1000000207?2o`@000000P1c`_l2
000000<0J[ko0`00000706Zjo`8000001@1Z]_lM000000030>Jj[0000000000000H0000000@0eNkV
000000000000eNk^0`0000030<gRkP<000001@3=f^H00`000000aMKV0<GFiP060<GFiP0300000035
c^H0aLkV00@0aLkV0P0000040<G>iP030000002mb^H0_L[V0080_L[V00<000000;g:iP2mb^H0202m
b^H00`000000_LKV0;g6iP090;g6iP030000003oool0oooo00h0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`030?ooo`001`3oool00`000000oooo0?ooo`0[0?ooo`030000001ca_l0
LlKo00@0LlKo1@00000207?2o`800000201Z__l3000000@0J[[o1`00000506:bo`800000201Z/_l2
00000080[9Fm00L000000:bA_@2/TKd000000:b=]0000000]8V/00T000000P3Em^H2000000<0eNk^
00<000000<gRkP3=h^h00P3=h^h2000000D0cM[V0`0000060<GFiP80000000<0aM;V00000035c^H0
0`35c^H00`000000aLkV0<G>iP050<G>iP040000002mb^H00000000000T0_L[V0P0000000`2mb^H0
0000000000080;g6iP030000003oool0oooo0100oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`030?ooo`001`3oool00`000000oooo0?ooo`0Z0?ooo`040000001ca_l0LlKo07?6o`@0
00001@1ca_l2000000d0J[ko1000000506:fo`8000001`1R/_l00`000000J[;o06Zbo`0606Zbo`80
000000P0[9Fm0000002/TKd0[96m0000002/SK@000000;B9[0H0000000<0cOoN0000003Em^H00`00
00020=G^kP<000000P3=h^h2000000030<gRkP000000cM[V0080cM[V0P0000030<GJkP0400000035
e^H0aMKV0<GFiP8000001035d^H010000000aLkV0000000000090<G>iP030000002mb^H0_L[V00P0
_L[V00<000000;g:iP2mb^H00`2mb^H2000000@0_LKV0P00000D0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool00`3oool000H0oooo00<000000?ooo`3oool0:P3oool5000000T0LlKo
00@0000006[2o`1Z`_l0J/;o1000000406Zno`<000000`1J^_l2000000H0H[Ko0P00000606:bo`80
0000201Z/_l020000000[9Fm0000002/TKd000000:b=]0000000]8V/2@0000020<gfkP<000000P3=
j^h3000000@0cN;^0`0000050<GJkP0400000035e^H00000000000L0aM;V00<000000<G>iP35c^H0
1`35c^H2000000030;g>iP000000_L[V00H0_L[V0P0000080;g:iP80000000<0_LKV0000003oool0
5P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00<0oooo00060?ooo`030000003o
ool0oooo02P0oooo100000000`1cb_l0000000000004000000@0LlKo00<0000006[2o`1Z`_l01P1Z
`_l4000000P0F[[o0P00000406:foal0000000<0aOoV0000000000000P3=m^h2000000<0cN[^0P00
00050<gRkP8000001`35f^h2000000H0aM;V0P0000020<GBkP0300000035c^H0aLkV00@0aLkV0P00
00040;g>iP800000102mb^H00`000000_L[V0;g:iP0:0;g:iP030000003oool0oooo01L0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`030?ooo`001P3oool00`000000oooo0?ooo`0U
0?ooo`<000000P3oool00`000000Ll[o07?:o`0607?:o`H00000201Z`_l010000000F[ko05Zno`1J
__l4000000@0F[[o1@00000405:bo`8000001@1J[_l2000000L0FZ[o00H0000009b5_@000000W7fd
0000002LNJ`:000000030<GbkP00000000000080000000<0aN[^0000003=h^h0100000000`35g^h0
00000<GJkP030<GJkP<000000P35f^h010000000aM;V0<GBiP35d^H2000000@0aM;^00<000000<G>
iP35c^H00P35c^H2000000P0_LkV00@000000;g:iP00000000002`2mb^H2000001X0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`030?ooo`001P3oool00`000000oooo0?ooo`0Q0?oo
o`@00000103oool00`000000Ll[o07?:o`0907?:o`040000001Za_l0J/Ko06[6o`@000000`1Z`_l0
0`000000F[ko05Zno`0605Zno`@00000101B/_l2000000D0D[;o0P00000505Z^o`8000001P1JZ_l2
0000000309am]0000000W7V/00@0000000<0_O[^0000000000000P35l^h3000000<0aN[^0`000006
0<GNkP0400000035f^h00000000000D0aM[^00@000000<GBiP00000000001`35d^h010000000aLkV
00000000000;0;g>iP030000002mb^H0_L[V00X0_L[V00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00060?ooo`030000003oool0oooo01h0oooo
0`0000080?ooo`H000001P1cb_l00`000000J/Ko06[6o`0506[6o`L000001@1J__l200000080B[Ko
1000000205:bo`800000101B/_l=00000080FZ[o0P0000000`2LOK@000000000000200000080_OKf
100000001035k_H000000<GZkP35j^h2000000030<GVmP000000aMk^00D0aMk^0`0000070<GJkP80
00002P35d^h00`000000_LkV0;g>iP080;g>iP8000000P2mc^H00`000000_L[V0;g:iP070;g:iP80
00007`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo00060?ooo`030000
003oool0oooo01X0oooo1000000;0?ooo`030000001kc_l0Nlko00<0Nlko2P00000606[6o`030000
001J`_l0F/;o0080F/;o1@00000804Zfo`P000000`11Z_l2000000D0BZGo00<0000005:UmP1BYOH0
1P0000000`2L@580000000000003000000<0aNkf00@000000<GZkP00000000000`35i_H010000000
aMk^0<GNkP35g^h3000000030<GNkP000000aM[^00D0aM[^0P0000000`2me^h000000<GBkP060<GB
kP8000000P2md^h00`000000_LkV0;g>iP050;g>iP8000001@2mc^H00`000000_L[V0;g:iP040;g:
iP8000008P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo00060?ooo`03
0000003oool0oooo01L0oooo0`00000?0?ooo`030000001kc_l0Nlko00P0Nlko00<0000007?:o`1c
b_l00P1cb_l9000000D0F/;o00<0000004Zno`1:__l00P1:__l5000000<0>Jkf0`000000100iZ_H0
0000000000000003046Zo`800000101:YOl2000000@0DZGf1@0000000`2dl_H000000<G^mP020<G^
mP<000001@35i_H010000000aMk^0000000000040<GNkP0300000035f^h0aM[^0080aM[^0P000003
0;gFkP0300000035d^h0aM;^0080aM;^0`0000040;gBkP030000002mc^H0_LkV00<0_LkV0P000008
0;g>iP030000002mb^H0_L[V0080_L[V00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0080oooo00060?ooo`030000003oool0oooo01<0oooo1000000C0?oo
o`030000001kc_l0Nlko00L0Nlko00<0000007?:o`1cb_l01`1cb_l010000000H/[o06;:o`1Rb_l8
000000@0B[ko00<0000003VbmP0i/_H00`00000303V^mQ<0000000<0DZGf0000000000000`000000
1P35k_H00000000000000000_N[f000000@0aNKf100000070<GNkP0400000035f^h00000000000H0
_MK^00@000000<GBkP0000000000202md^h00`000000_LkV0;g>iP02000000/0_LkV00@000000;g:
iP00000000009`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0080oooo00060?oo
o`030000003oool0oooo0100oooo0`00000G0?ooo`030000001kc_l0Nlko00P0Nlko00<0000007?:
o`1cb_l01P1cb_l00`000000H/[o06;:o`0506;:o`040000001B`_l0D/;o05;2o`@000001P0i/_H3
000000<08:7^0P00000202VQkP8000000P0aWOH2000000<0>Igf00<0000004ZMmP1:WOH01`000003
0;gZmP0300000035i_H0000000<000000P2mh_H00`000000aMk^0<GNkP040<GNkP@000001`2me^h3
000000/0_M;^0P00000>0;g>iP030000003oool0oooo02P0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`020?ooo`001P3oool00`000000oooo0?ooo`0<0?ooo`@000006P3oool[0000
00806:GN400000000`0iWOH000000000000404ZMmP80000000<0_N[f0000000000000`0000060;gR
mP0300000035g^h0aMk^00@000000P2mf^h00`000000_MK^0;gFkP040;gFkP8000000P2me^h00`00
0000_M;^0;gBkP060;gBkP8000000P2md^h00`000000_LkV0;g>iP090;g>iP800000;@3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo0080oooo00050?ooo`030000003oool0oooo00X0
oooo0`00000O0?ooo`0300000023d_l0Pm;o00P0Pm;o00<0000007?Bo`1cd_l01P1cd_l00`000000
J/ko06[>o`0206[>o`h000000P1Bb^h6000000<0W9WE100000000`0@TNH0000000000002022EkPL0
00000P1:WOH2000000<0_NKf00<000000;gRmP2mh_H00`2mh_H5000000H0_M[^00@000000;gFkP2m
e^h0_MK^0`0000040;gFkP030000002md^h0_M;^00@0_M;^0P0000050;gBkP030000002mc^H0_LkV
00D0_LkV0`00000`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00P3oool000D0
oooo00<000000?ooo`3oool01P3oool400000280oooo00<0000008?Bo`23d_l02023d_l00`000000
Lm;o07?Bo`0307?Bo`P000001@1ce_l2000000<0H];o1P0000000`1Re_H0000009bMe@0309bMe@03
0000002LVMD0W9WE0080W9WE00<0000009bAc@2LTLd03`0000020;gVmP030000002mh_H0_N;f00@0
00000P2mg_H00`000000_M[^0;gJkP060;gJkP040000002me^h00000000000P0_MK^00@000000;gB
kP2md^h0_M;^0P0000070;gBkP030000002mc^H0_LkV00<0_LkV0P00000d0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool00P3oool000D0oooo00<000000?ooo`3oool00`3oool30000
02L0oooo00<0000008?Bo`23d_l00`23d_l:000000D0NmKo0P00000507?Fo`H000001@1cf_l20000
00H0W9gE00D0000009bIe@2LVMD0W9WE0000000309bAc@<0000000@0RhW=00000000000028GV1@00
000203VEmPD000001P2mg_H00`000000_M[^0;gJkP040;gJkP@000002P2me^h010000000_M;^0000
0000000:0;gBkP030000002mc^H0_LkV00800000=`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0080oooo00050?ooo`030000003oool0000000<00000:`3oool5000000H0PmKo00<0
000007_Fo`1ke_l01`1ke_l6000000D0Pm[o0`00000509bQgP030000002LWMD0W9gE00<0W9gE00<0
000009bIe@2LVMD00P2LVMD300000080Ri7E00<0000008^9c@2;RLd02@0000000`0iUOH000000000
00070;gNmP030000002mf^h0_M[^00D000000P2mf^h00`000000_MK^0;gFkP080;gFkP<000003@2m
d^h2000003X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`001@3oool2
00000300oooo00<0000008?Fo`23e_l02023e_l2000000<0NmKo1000000308_Jo`8000001@23f_l4
09bUgP030000002LXMh0W:7N00<0W:7N00<0000009bMe@2LWMD00`2LWMD00`000000W9WE09bIe@02
000000@0Ri7E00D0000008^9c@2;RLd0000008>1a@0:000000D0_Mkf1@0000070;gJkP030000002m
e^h0_MK^00@0_MK^100000020;gBkP030000002md^h0_M;^00P0_M;^0P00000m0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool00@3oool000H0oooo00<000000?ooo`3oool0;`3oool2
000000P0PmKo1@00000908_Jo`8000001`2LYMh00`000000W:7N09bQgP0309bQgP030000002LWMD0
W9gE00<0W9gE0`00000209BEe@030000002;TMD0Ri7E0080Ri7E00@0000008^9c@2;RLd000000P1c
OLd00`000000JW7=0000000200000003001miP000000000000D000000P2mg_H00`000000_M[^0;gJ
kP080;gJkP030000002me^h0000000<000001`2md^h00`000000_M;^0;gBkP040;gBkP<00000@03o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0040oooo00070?ooo`800000<@3oool0
10000000PmKo08?Fo`23e_l4000000@0Rm[o0P00000608_Jo`@0W:[N00<0000009bUgP2LYMh01@2L
YMh00`000000W:7N09bQgP0309bQgP030000002LWMD0W9gE008000000P2DWMh01@000000U9GE09BE
e@2DUMD0000000<0Ri7E00X0000008^9c@000000NhGE0000001cOLd0000006Yac@000000DV751P00
00050;gNmP030000002mf^h0_M[^00L0_M[^0`00000;0;gBkP030000002md^h0_M;^0080_M;^0P00
00140?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00@3oool000T0oooo0P00000`
0?ooo`<000002P2;f_l2000000T0W:[N00<0000009bUgP2LYMh01@2LYMh00`000000W:7N09bQgP02
09bQgP<000001@2DWMh010000000U9GE09BEe@00000408^Ae@0:0000001kQMD0NhGE07^5e@000000
Lgg=0000001ZLLd0000003UMc@L000000`2mg_H00`000000_M[^0;gJkP030;gJkP@0000000<0_MK^
0000002md^h0302md^h010000000_M;^0000000000170?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool00@3oool000X0oooo00<000000?ooo`3oool0;`3oool2000000P0Rm[o102L[^H0
0`000000W:[N09bZgP0609bZgP030000002LYMh0W:GN00D0W:GN00<0000009bQgP2LXMh00P000002
09BQgP030000002DWMh0U9gN00<0U9gN00H0000009BEe@2DUMD0U9GE0000002;TMD20000000308>=
e@000000NhGE0080NhGE00H0000007=mc@000000DVgE0000000iGLd700000080_Mkf00<000000;gJ
kP0000000`0000050;gFkP030000002md^h0_M;^00X0_M;^0`00001:0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool00@3oool000/0oooo0P00000a0?ooo`8000000P2;f_l00`3oool0
000009b^iP0609b^iP030000002LZ]h0W:[N00H0W:[N00<0000009bUgP2LYMh0102LYMh3000000D0
U:7N00<0000009BMgP2DWMh00`2DWMh00`000000U9GE09BEe@02000000@0PhgE00P0000007^5e@1k
QMD0NhGE0000001RNMD00000059]e@<0000000<004S50000000000001P0000090;gFkP030000002m
d^h0_M;^00L0_M;^0`00001>0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00@3o
ool000d0oooo00<000000?ooo`3oool0<03oool2000000X0W:kV00<0000009bZgP2LZ]h01P2LZ]h0
0`000000W:GN09bUgP0300000080W:GN00<0000009BQgP2DXMh00`2DXMh00`000000U9gN09BMgP04
09BMgP8000000P2;UMh00`000000PhgE08>=e@0208>=e@070000001kQMD0000006Z5gP000000HWWE
00000002059]e@80000000<004S50000000000001000000;0;gFkP030000002md^h0_M;^0080_M;^
1000001B0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00@3oool000h0oooo00<0
00000?ooo`3oool0<@3oool00`000000W:kV09b^iP0709b^iP030000002LZ]h0W:[N00H0W:[N0`00
000609bUgP030000002DXMh0U:7N00<0U:7N00@0000009BMgP2DWMh0U9gN0P0000000`2;VMh00000
08^EgP0208^EgP8000000`23SMD020000000JXGN06Z5gP1ZQMh00000069ie@000000DVgE2@00000;
0;gFkP030000002md^h0000000800000E`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo0040oooo000?0?ooo`80000000<0oooo0000003oool0;`3oool00`000000W:kV09b^iP0709b^
iP030000002LZ]h0W:[N00<0W:[N0P00000209bZiP030000002LYMh0W:GN00D0W:GN00<0000009BQ
gP2DXMh00`2DXMh00`000000U9gN0000000408^IgP030000002;UMh0RiGN0080RiGN00D0000008>=
e@000000NhgN0000000306Z5gP030000001RNMD000000080@FgE0P0000000`00C<d0000000000003
000000L0_MK^1@00001K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00@3oool0
0140oooo0P00000a0?ooo`030000002L[^H0W:kV00L0W:kV00<0000009bZgP2LZ]h00P00000509bZ
iP030000002LYMh0W:GN00D0W:GN00<0000009BQgP2DXMh00P2DXMh2000000H0RiWN0P00000308^E
gP040000001kSMh0NhgN07^=gP8000000P1ZQMh00`000000DWWN00000002045]e@h00000H@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0040oooo000A0?ooo`800000<@3oool00`00
0000W:kV09b^iP0709b^iP<00000202LZ^H00`000000W:GN09bUgP0509bUgP040000002DXMh00000
00000080RigN0P00000608^IgP050000002;UMh0000007^AgP000000101kSMh01@000000JXGN0000
00000000DWWN00@0000000<065gE0000000000001000001W0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool00@3oool001<0oooo0P00000`0?ooo`030000002L[^H0W:kV00<0W:kV0`00
000209b^iP030000002LZ^H0W:[V00L0W:[V00<0000009bUgP2LYMh01@2LYMh00`000000RigN08^M
gP0408^MgP030000002;VMh0RiWN00@0RiWN00@0000007^AgP1kTMh0Ni7N0P00000307^=gP030000
001RQMh0HXGN0080000000L0DWWN0000000aKMh0000001QMe@000000053=00@00000IP3oool00`00
0000oooo0?ooo`0D0?ooo`4000000@3oool10?ooo`005@3oool00`000000oooo0?ooo`0^0?ooo`03
0000002L[^H0W:kV008000001P2L[^H00`000000W:[V09bZiP0709bZiP030000002LYMh0W:GN0080
W:GN0P0000000`2DYNH0000008^MgP0508^MgP030000002;VMh0RiWN0080RiWN00<0000008>IiP00
0000101kTMh01@000000NhgN0000001ZSNH0000000<0HXGN0`000002035]gP0300000008HMD00000
00D00000I@3oool00`000000oooo0?ooo`0C0?ooo`4000000@3oool10?ooo`005P3oool00`000000
oooo0?ooo`0^0?ooo`8000002@2L[^H00`000000W:[V09bZiP0709bZiP040000002LYMh000000000
00@0U:GV00<0000008^MgP2;WMh0102;WMh20000000308^IgP000000PiWV0080PiWV00<0000007^A
gP1kTMh00P1kTMh010000000JXgV06Z=iP1ZSNH200000080HXGN00<00000045iiP0000000`000000
0`08HMD0000000000003000006H0oooo00<000000?ooo`3oool04P3oool100000040oooo0@3oool0
01L0oooo0`00000^0?ooo`030000002L[^H0W:kV00P0W:kV0P00000709bZiP8000001`2DYNH20000
00H0RigN00<0000008>IiP23VNH00`23VNH200000080Ni7N0`00000306Z=iP030000001RQMh00000
0080000000<0@GWV0000000PKMh02000001U0?ooo`030000003oool0oooo0140oooo0@0000010?oo
o`40oooo000I0?ooo`030000003oool0oooo02d0oooo0P00000:09b^iP030000002LZ^H0W:[V0080
W:[V0P00000209BZiP030000002DYNH0U:GV00H0U:GV00@0000008^MgP2;WMh0RigN0P0000000`2;
WNH0000008>IiP0508>IiP8000000`1cTNH01@000000JXgV06Z=iP1ZSNH0000000<0DXGV10000000
0`0PKMh00000001Qe@05000006D0oooo00<000000?ooo`3oool0403oool100000040oooo0@3oool0
01X0oooo00<000000?ooo`3oool0;P3oool00`000000W:kV09b^iP0809b^iP040000002LZ^H00000
000000D0U:[V0P00000709BUiP030000002;WMh0000000@0RigV00<0000008>IiP23VNH01023VNH0
0`000000Li7V07>AiP0207>AiP80000000@0JXgV00000000000000000`1BQNH00`000000<GWV0000
0008000006D0oooo00<000000?ooo`3oool03`3oool100000040oooo0@3oool001/0oooo0P00000_
0?ooo`030000002L[^H0W:kV00P0W:kV00<0000009BZiP2DZ^H01`2DZ^H00`000000U:GV09BUiP05
09BUiP030000002;WNH0RigV00@0RigV0P00000308>IiP040000001kVNH00000000000@0Li7V00@0
000006:=iP1RSNH0HXgV0P0000001@1BQNH00000000000000000<GWV00P00000I@3oool00`000000
oooo0?ooo`0>0?ooo`4000000@3oool10?ooo`007@3oool010000000oooo0?ooo`00000/0?ooo`03
0000002L[^H0W:kV00D0W:kV0P0000000`2DZ^H0000009BZiP0809BZiP030000002DYNH0U:GV0080
U:GV0P0000000`2;YNH000000000000608^MiP0300000023VNH0000000@0NiWV00@0000007>AiP1c
TNH0Li7V0`00000306:=iP8000000P11QNH200000003021iiP000000000000<0000000<005350000
003oool0I03oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool10?ooo`007P3oool00`000000
oooo0000000]0?ooo`800000102L[^H00`000000U:[V09BZiP0209BZiP800000202DZ^H200000003
09BUiP000000RjGV00@0RjGV00<0000008^MiP2;WNH0102;WNH00`000000NiWV07^IiP0407^IiP<0
00000`1ZUNh010000000HXgV06:=iP1RSNH300000080@HGV0P000000100PNNH0000000000000KMh3
000006D0oooo00<000000?ooo`3oool0303oool100000040oooo0@3oool001l0oooo0P00000_0?oo
o`040000002L[^H00000000000L0U:[V00<0000009BZiP2DZ^H01`2DZ^H00`000000RjGV08^UiP05
08^UiP8000000`2;WNH010000000PigV00000000000607^IiP8000000`1ZUNh3000000<0DXg^00@0
00000465iP000000>HG^2000001U0?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`40oooo
000P0?ooo`800000;`3oool00`000000U:[V09BZiP0809BZiP030000002DZ^H0U:[V00D0U:[V00@0
000008^ZiP00000000001`2;YNH20000000308^MiP000000PigV0080PigV0P00000407^IiP040000
001cVNh00000000000<0JYG^0P00000405:=kP8000000P0iQNh8000006@0oooo00<000000?ooo`3o
ool02P3oool100000040oooo0@3oool00280oooo00<000000?ooo`3oool0;@3oool2000000T0U:[V
0P00000309BZiP800000102;Z^H2000000L0RjGV00<0000008>MiP23WNH01023WNH20000000307^I
iP000000LiW^00<0LiW^0P0000000`1ZUNh0000005ZEkP0500000003046=kP000000000000800000
00<0:H7^0000000000001000001S0?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`008`3o
ool00`000000oooo0?ooo`0^0?ooo`030000002DZ^H0U:[V00P0U:[V00<0000009BZiP000000202;
Z^H2000000@0RjGV00@0000008>UkP00000000001P23WNH3000000D0LiW^0`00000405ZEkP800000
0`11SNh30000000302V1kP000000000000<00000H`3oool00`000000oooo0?ooo`0:0?ooo`400000
0@3oool002@0oooo0P0000000`3oool000000?ooo`0/0?ooo`030000002DZ^H0U:[V00P0U:[V0P00
000:08^ZiP80000000<0RjGV00000023YNh00`23YNh2000000@0PigV00<0000007^QkP1kXNh00P00
000407>IkP040000001ZVNh00000000000<0FYG^0`000002046=kP030000000iSNh0000000H00000
H`3oool00`000000oooo0?ooo`090?ooo`4000000@3oool002H0oooo0P00000^0?ooo`8000001`2D
Z^H00`000000U:[^09BZkP02000000X0Rj[V00<0000008>UkP23YNh01@23YNh200000080PigV00<0
000007^QkP1kXNh00P1kXNh30000000307>IkP000000JYW^0080JYW^0P000000101JUNh0000005:E
kP1BUNh200000003046=kP000000>Hg^0080>Hg^1@00001S0?ooo`030000003oool0oooo00P0oooo
0@0000010?ooo`009`3oool00`000000oooo0?ooo`0^0?ooo`030000002DZ^H0U:[V0080U:[V0P00
000509BZkP8000001`2;Z^H010000000Rj[^00000000000708>UkP<000001`1kXNh3000000@0JYW^
0`00000305:EkP<00000100iSNh4000006<0oooo00<000000?ooo`3oool01`3oool100000040oooo
000X0?ooo`800000;`3oool20000000309BZiP000000U:[^00P0U:[^0P00000508^ZiP040000002;
Z^h0Rj[^08^ZkP8000001P23YNh010000000NjG^00000000000607^QkP040000001ZXNh000000000
00<0JYW^00@0000005ZMmP00000000000`1BUNh600000080:Hg^0P00001S0?ooo`030000003oool0
oooo00H0oooo0@0000010?ooo`007`3oool3000000P0oooo00<000000?ooo`3oool0;P3oool00`00
0000U:[^09BZkP0:09BZkP8000000P2;Z^H00`000000Rj[^08^ZkP0408^ZkP8000001023YNh01000
0000NjG^07^UkP1kYNh2000000@0Nj7^00@0000006ZQkP1ZXNh0JZ7^0`000000101ZVNh0000005ZM
mP1JWOH4000000@0@IGf0`00000202V=kP030000003oool0oooo0640oooo00<000000?ooo`3oool0
1@3oool100000040oooo000K0?ooo`<000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo02h0oooo0P00000<09BZkP8000002@2;Z^h20000000308>UkP000000NjG^00D0NjG^0P00
00000`1kXNh0000006ZQkP0606ZQkP<00000101JWOH3000000@0@IGf1@00001S0?ooo`030000003o
ool0oooo00@0oooo0@0000010?ooo`008@3oool00`000000oooo0?ooo`080?ooo`<00000;`3oool2
000000X0U:[^00@0000008^^kP00000000002@2;Z^h3000000L0NjG^0`00000706ZQkP040000001R
XOH00000000000<0FYgf00<0000005:MmP0000001000000303VEmP800000H`3oool00`000000oooo
0?ooo`030?ooo`4000000@3oool001l0oooo0`00000<0?ooo`030000003oool0oooo02l0oooo0P00
000709BZkP030000002;[^h0Rjk^0080Rjk^0P00000708^ZkP0300000023Z^h0Pj[^008000001P1k
YNh00`000000LjGf00000002000000@0JZ7^00@0000006:QmP1RXOH0HZ7f0`0000000`1JWOH00000
05:MmP0305:MmPD0000000<0>IGf000000000000HP3oool00`000000oooo0?ooo`020?ooo`400000
0@3oool002l0oooo00<000000?ooo`3oool0<03oool2000000D0U:[^00<0000008^^kP2;[^h0102;
[^h2000000D0Rj[^00<0000008>ZkP23Z^h00P23Z^h3000000<0NjG^00<0000007>UmP1cYOH00P1c
YOH30000000306ZQkP000000HZ7f00D0HZ7f0`00000505:MmP030000001:WOH0BYgf00@00000HP3o
ool01@000000oooo0?ooo`3oool000000040oooo000`0?ooo`800000<P3oool200000080U:[^00<0
000008^^kP2;[^h01`2;[^h200000080Rj[^00<0000008>ZkP23Z^h01P23Z^h20000000307^UkP00
0000LjGf00H0LjGf1000000606:QmPD0000000<0DYgf0000001:WOH01@1:WOH00`000000oooo0?oo
o`1O0?ooo`030000003oool0oooo0080oooo0@0000000380oooo00<000000?ooo`3oool0<@3oool3
000000/0Rjk^0`00000:08>ZkP<000001`1cYOH00`000000JZGf06ZUmP050000000306:QmP000000
FZGf00<0FZGf1P00000304ZMmP030000003oool0oooo05l0oooo00@000000?ooo`3oool0oooo0@00
000003<0oooo0P00000d0?ooo`8000002P2;[^h00`000000Pjk^00000002000000P0Pj[^00<00000
07^ZmP0000000P00000407>UmP030000001ZYOH0JZGf00D0JZGf1@00000405ZUmP030000001BYOH0
DZGf00D00000H@3oool00`000000oooo0?ooo`0100000000=03oool2000003@0oooo0`00000708^^
kP0300000023[^h0Pjk^00<0Pjk^0`00000508>ZkP030000001kZ_H0Nj[f0080Nj[f100000000`1c
YOH0000006ZUmP0706ZUmP030000001RZ_H0HZ[f00@0000000<0FZGf0000001BYOH01@1BYOH00`00
0000oooo0?ooo`1O0?ooo`4000000@3oool100000000=P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo00<00000102;[^h00`000000Pjk^08>^kP0608>^kP<0000000<0Pj[^0000001k
Z_H0201kZ_H4000000H0JZGf00<0000006:ZmP1RZ_H0101RZ_H6000000<0DZGf00<000000?ooo`3o
ool0G`3oool200000000=`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00<0oooo
0P0000000`2;[^h0000008>^kP0;08>^kP<000002@1kZ_H00`000000Ljkf07>^mP0500000080JZGf
00<0000006:ZmP1RZ_H01@1RZ_H010000000FZ[o05ZZo`1JZ_l5000005l0oooo0`00000003P0oooo
00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`050?ooo`<000003023[^h00`000000
Pjkf00000003000000D0Nj[f00<0000007>^mP1c[_H01@1c[_H5000000H0HZ[f00<0000005ZZo`1J
Z_l01@1JZ_l00`000000oooo0?ooo`1D0?ooo`040000003oool0oooo0?ooo`@000000`3oool003T0
oooo0`00000^0?ooo`030000003oool0oooo00P0oooo0`00000908>^kP0300000023[_H0Pjkf00<0
Pjkf100000000`1kZ_H0000007>^mP0807>^mP030000001Z[_H0JZkf00D0000000<0HZ[f0000001J
Z_l01`1JZ_l00`000000oooo0?ooo`1C0?ooo`@000001`3oool003/0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0;0?ooo`@000001023[^h00`000000Pjkf08>^mP0808>^mP<00000
2@1c[_H00`000000JZkf06Z^mP0406Z^mPL00000101JZ_l00`000000oooo0?ooo`180?ooo`030000
003oool0oooo00<0oooo1000000;0?ooo`00?03oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00l0oooo0`0000000`23[^h0000008>^mP0:08>^mP030000001k/_H0000000<000001@1c
[_H00`000000JZkf06Z^mP0706Z^mP040000001Z/_l0J[;o06Zbo`H00000B@3oool00`000000oooo
00000003000000l0oooo000m0?ooo`800000:`3oool00`000000oooo0?ooo`0B0?ooo`@000002@23
[_H00`000000Nk;f07^bmP0307^bmP@000000P1c[_H00`000000JZkf06Z^mP0706Z^mP030000001Z
/_l0J[;o00H0J[;o00<000000?ooo`3oool0@`3oool5000001<0oooo000o0?ooo`030000003oool0
000002P0oooo00<000000?ooo`3oool05P3oool4000000H0Pjkf00<0000007^bmP1k/_H01P1k/_H8
000000D0JZkf00<0000006Zbo`1Z/_l01P1Z/_l2000003/0oooo00@000000?ooo`3oool0oooo1000
000H0?ooo`00@03oool2000002P0oooo00<000000?ooo`3oool06P3oool400000080Pjkf00<00000
07^bmP1k/_H0201k/_H00`000000Lk;f07>bmP0307>bmP`00000101Z/_l00`000000oooo0?ooo`0h
0?ooo`@00000703oool00440oooo0P00000W0?ooo`030000003oool0oooo01h0oooo1P00000807^b
mP030000001c/_H0Lk;f00T0Lk;f00<0000007>fo`1c]_l00P1c]_l6000002l0oooo00<000000?oo
o`3oool00`3oool400000200oooo00130?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0903oool600000080Nk;f00<0000007>bmP1c/_H02@1c/_H00`000000LkKo07>fo`0807>fo`03
0000003oool0oooo02`0oooo00<000000?ooo`0000000`00000T0?ooo`00>@3oool2000000T0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Z0?ooo`L00000201c/_H00`000000LkKo
07>fo`0807>fo`800000:P3oool4000002P0oooo000h0?ooo`030000003oool0000000X0oooo0P00
00000`3oool000000?ooo`0P0?ooo`030000003oool0oooo0340oooo1P00000207>bmP030000001c
]_l0LkKo00X0LkKo00<000000?ooo`3oool07P3oool010000000oooo0?ooo`3oool5000002`0oooo
000h0?ooo`030000003oool0000000`0oooo0P00000Q0?ooo`030000003oool0oooo03L0oooo4@00
000O0?ooo`@00000<@3oool003T0oooo0P00000=0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`030?ooo`@00000=@3oool004T0oooo0P00000O0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`0000000`00000i0?ooo`00B`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo05/0oooo1000000m0?ooo`00C03oool00`000000oooo
0000000K0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool01@0000110?ooo`00C@3o
ool2000001/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`060?ooo`@000006P3o
ool3000002T0oooo001?0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`020?ooo`@000007`3oool00`000000oooo0?ooo`0X0?ooo`00D03oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo04X0oooo1@00000T0?ooo`030000003oool0oooo
02L0oooo001A0?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3oool0A`3oool40000
02H0oooo0`00000Y0?ooo`00DP3oool3000001@0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`04000005H0oooo001D0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
?P3oool5000005X0oooo001E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=P3o
ool010000000oooo0?ooo`3oool4000005l0oooo001F0?ooo`8000004@3oool00`000000oooo0?oo
o`0f0?ooo`@00000H`3oool005P0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo00<0oooo1000001W0?ooo`00F@3oool2000000h0oooo00<000000?oo
o`3oool0;03oool00`000000oooo00000003000006/0oooo001J0?ooo`8000003@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo1@00000K0?ooo`800000DP3oool005`0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00@00000
7`3oool00`000000oooo0000001B0?ooo`00DP3oool3000000P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0Q0?ooo`@000008`3oool00`000000oooo0000001B0?ooo`00D`3oool0
0`000000oooo0?ooo`080?ooo`<00000203oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0080oooo1000000X0?ooo`800000DP3oool005@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01P0oooo1@0000200?ooo`00DP3oool3000000`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0
oooo100000240?ooo`00HP3oool2000000D0oooo00<000000?ooo`3oool03`3oool6000008P0oooo
001T0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0303oool4000008d0oooo001U
0?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@00000T@3oool0
06H0oooo0P0000000`3oool000000?ooo`050?ooo`@00000U@3oool006P0oooo0P0000020?ooo`@0
00007P3oool3000007P0oooo001Y0?ooo`<000007P3oool300000080oooo00<000000?ooo`3oool0
M`3oool00900oooo00<000000?ooo`3oool0MP3oool008h0oooo0`00001h0?ooo`00o`3oool:0?oo
o`00o`3oool:0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 264.812}, {358.438, 0}} -> {0.108612, -0.00999892, \
0.00279769, 0.00279769}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(With[{\[CurlyEpsilon] = 10\^\(-12\)}, \ \n\t
        Show[Graphics3D[{EdgeForm[], 
              SurfaceColor[Hue[0.03], Hue[0.18], 1.39], 
              Table[Cases[\t
                  Apply[ParametricPlot3D[{r\ Cos[\[CurlyPhi]], 
                          r\ Sin[\[CurlyPhi]], 
                          Re[ArcTan[
                                r\ \[ExponentialE]\^\(\[ImaginaryI]\ \
\[CurlyPhi]\)] + k\ \[Pi]]}, \ \ \ ##, PlotPoints \[Rule] {16, 32}, 
                        DisplayFunction \[Rule] 
                          Identity] &, \n\t\t\t\t\t\tFlatten[
                      Table[{{r, j + \[CurlyEpsilon], 
                            j + 1 - \[CurlyEpsilon]}, {\[CurlyPhi], 
                            l\ \ \[Pi]/2 + \[CurlyEpsilon], \((l + 2)\) \[Pi]/
                                  2 - \[CurlyEpsilon]}}, {j, 0, 
                          1}, {l, \(-1\), 1, 2}], 1], {1}], _Polygon, 
                  Infinity], {k, \(-2\), 2}]}], 
          BoxRatios \[Rule] {1, 1, 2}]];\)\)], "Input",
  FontSize->12],

7 .48969 L .35482 .48047 L .926 .845 0 r
F
.56586 .4667 m .56852 .46997 L .54969 .47843 L 1 1 0 r
F
.58323 .45427 m .56852 .46997 L .56586 .4667 L F
.54793 .4751 m .54969 .47843 L .53048 .484 L .989 .99 0 r
F
.56586 .4667 m .54969 .47843 L .54793 .4751 L 1 1 0 r
F
.52965 .48041 m .53048 .484 L .51108 .48719 L .888 .932 0 r
F
.54793 .4751 m .53048 .484 L .52965 .48041 L .989 .99 0 r
F
.30969 .48327 m .28333 .47255 L .29073 .46954 L .973 .841 0 r
F
.31645 .47985 m .30969 .48327 L .29073 .46954 L .965 .838 0 r
F
.51118 .48334 m .51108 .48719 L .49169 .48837 L .844 .899 0 r
F
.52965 .48041 m .51108 .48719 L .51118 .48334 L .888 .932 0 r
F
.42792 .49027 m .40409 .48894 L .40865 .48483 L .902 .861 0 r
F
.43164 .48603 m .42792 .49027 L .40865 .48483 L .88 .853 0 r
F
.45081 .48982 m .42792 .49027 L .43164 .48603 L .886 .87 0 r
F
.40409 .48894 m .37962 .48572 L .38498 .4818 L .915 .852 0 r
F
.40865 .48483 m .40409 .48894 L .38498 .4818 L .898 .846 0 r
F
.45367 .48558 m .45081 .48982 L .43164 .48603 L .857 .859 0 r
F
.4725 .48777 m .45081 .48982 L .45367 .48558 L .863 .877 0 r
F
.49273 .48434 m .49169 .48837 L .4725 .48777 L .826 .876 0 r
F
.51118 .48334 m .49169 .48837 L .49273 .48434 L .844 .899 0 r
F
.34872 .48416 m .32323 .47647 L .33002 .47313 L .948 .841 0 r
F
.35482 .48047 m .34872 .48416 L .33002 .47313 L .937 .838 0 r
F
.59541 .43236 m .59985 .4379 L .58323 .45427 L 1 1 0 r
F
.37962 .48572 m .35482 .48047 L .36093 .47684 L .926 .845 0 r
F
.38498 .4818 m .37962 .48572 L .36093 .47684 L .913 .84 0 r
F
.57968 .45136 m .58323 .45427 L .56586 .4667 L 1 1 0 r
F
.59541 .43236 m .58323 .45427 L .57968 .45136 L F
.31645 .47985 m .29073 .46954 L .29815 .46657 L .965 .838 0 r
F
.32323 .47647 m .31645 .47985 L .29815 .46657 L .957 .835 0 r
F
.47445 .48365 m .4725 .48777 L .45367 .48558 L .822 .859 0 r
F
.49273 .48434 m .4725 .48777 L .47445 .48365 L .826 .876 0 r
F
.5632 .46438 m .56586 .4667 L .54793 .4751 L 1 .978 0 r
F
.57968 .45136 m .56586 .4667 L .5632 .46438 L 1 1 0 r
F
.54618 .47243 m .54793 .4751 L .52965 .48041 L .824 .873 0 r
F
.5632 .46438 m .54793 .4751 L .54618 .47243 L 1 .978 0 r
F
.52881 .47725 m .52965 .48041 L .51118 .48334 L .768 .852 0 r
F
.54618 .47243 m .52965 .48041 L .52881 .47725 L .824 .873 0 r
F
.43164 .48603 m .40865 .48483 L .41323 .48079 L .88 .853 0 r
F
.43538 .4819 m .43164 .48603 L .41323 .48079 L .855 .843 0 r
F
.45367 .48558 m .43164 .48603 L .43538 .4819 L .857 .859 0 r
F
.40865 .48483 m .38498 .4818 L .39035 .47796 L .898 .846 0 r
F
.41323 .48079 m .40865 .48483 L .39035 .47796 L .879 .839 0 r
F
.51128 .47979 m .51118 .48334 L .49273 .48434 L .758 .848 0 r
F
.52881 .47725 m .51118 .48334 L .51128 .47979 L .768 .852 0 r
F
.35482 .48047 m .33002 .47313 L .33683 .46985 L .937 .838 0 r
F
.36093 .47684 m .35482 .48047 L .33683 .46985 L .926 .833 0 r
F
.59096 .42681 m .59541 .43236 L .57968 .45136 L 1 .998 0 r
F
.45653 .48146 m .45367 .48558 L .43538 .4819 L .823 .844 0 r
F
.47445 .48365 m .45367 .48558 L .45653 .48146 L .822 .859 0 r
F
.38498 .4818 m .36093 .47684 L .36706 .47326 L .913 .84 0 r
F
.39035 .47796 m .38498 .4818 L .36706 .47326 L .897 .834 0 r
F
.32323 .47647 m .29815 .46657 L .30558 .46364 L .957 .835 0 r
F
.33002 .47313 m .32323 .47647 L .30558 .46364 L .948 .832 0 r
F
.49376 .48053 m .49273 .48434 L .47445 .48365 L .764 .842 0 r
F
.51128 .47979 m .49273 .48434 L .49376 .48053 L .758 .848 0 r
F
.29073 .46954 m .28333 .47255 L .26585 .45694 L .974 .833 0 r
F
.57613 .45042 m .57968 .45136 L .5632 .46438 L 1 .949 0 r
F
.59096 .42681 m .57968 .45136 L .57613 .45042 L 1 .998 0 r
F
.47641 .47971 m .47445 .48365 L .45653 .48146 L .774 .834 0 r
F
.49376 .48053 m .47445 .48365 L .47641 .47971 L .764 .842 0 r
F
.36093 .47684 m .33683
}, Open  ]],

Cell[CellGroupData[{

 r
F
.36706 .47326 m .36093 .47684 L .34366 .46661 L .913 .828 0 r
F
.58649 .42124 m .59096 .42681 L .57613 .45042 L 1 .976 0 r
F
.41323 .48079 m .39035 .47796 L .39575 .47419 L .879 .839 0 r
F
.41782 .47684 m .41323 .48079 L .39575 .47419 L .857 .831 0 r
F
.43538 .4819 m .41323 .48079 L .41782 .47684 L .855 .843 0 r
F
.56054 .46346 m .5632 .46438 L .54618 .47243 L .644 .532 0 r
F
.57613 .45042 m .56312 .46436 L .56888 .45648 L 1 .949 0 r
F
.56888 .45648 m .56312 .46436 L .56054 .46346 L F
.57261 .45368 m .57613 .45042 L .57032 .45528 L 0 0 0 r
F
.57261 .45368 m .57032 .45528 L .56054 .46346 L F
.57613 .45042 m .5632 .46438 L .56312 .46436 L 1 .949 0 r
F
.57508 .45195 m .57261 .45368 L .56914 .46384 L 0 0 0 r
F
.58649 .42124 m .58231 .433 L .57261 .45368 L 1 .976 0 r
F
.58231 .433 m .57613 .45042 L .57261 .45368 L F
.58227 .43759 m .57261 .45368 L .57508 .45195 L 0 0 0 r
F
.58227 .43759 m .58649 .42124 L .57499 .44812 L F
.58035 .44079 m .57499 .44812 L .57261 .45368 L F
.58227 .43759 m .57499 .44812 L .58035 .44079 L F
.43914 .47788 ,

43538 .4819 L .41782 .47684 L .828 .831 0 r
F
.45653 .48146 m .43538 .4819 L .43914 .47788 L .823 .844 0 r
F
.29073 .46954 m .26585 .45694 L .27385 .45443 L .974 .833 0 r
F
.29815 .46657 m .29073 .46954 L .27385 .45443 L .966 .83 0 r
F
.33002 .47313 m .30558 .46364 L .31303 .46075 L .948 .832 0 r
F
.33683 .46985 m .33002 .47313 L .31303 .46075 L .938 .828 0 r
F
.54442 .47057 m .54618 .47243 L .52881 .47725 L .59 .603 0 r
F
.56054 .46346 m .54618 .47243 L .54442 .47057 L .644 .532 0 r
F
.52798 .47459 m .52881 .47725 L .51128 .47979 L .616 .712 0 r
F
.54442 .47057 m .52881 .47725 L .52798 .47459 L .59 .603 0 r
F
.39035 .47796 m .36706 .47326 L .3732 .46975 L .897 .834 0 r
F
.39575 .47419 m .39035 .47796 L .3732 .46975 L .88 .827 0 r
F
.51138 .47658 m .51128 .47979 L .49376 .48053 L .656 .771 0 r
F
.52798 .47459 m .51128 .47979 L .51138 .47658 L .616 .712 0 r
F
.45941 .47749 m .45653 .48146 L .43914 .47788 L .785 .826 0 r
F
.47641 .47971 m .45653 .48146 L .45941 .47749 L .774 .834 0 r
F
.4948 .47696 m .49376 .48053 L .47641 .47971 L .692 .796 0 r
F
.51138 .47658 m .49376 .48053 L .4948 .47696 L .656 .771 0 r
F
.29815 .46657 m .27385 .45443 L .28186 .45196 L .966 .83 0 r
F
.30558 .46364 m .29815 .46657 L .28186 .45196 L .959 .827 0 r
F
.36706 .47326 m .34366 .46661 L .3505 .46343 L .913 .828 0 r
F
.3732 .46975 m .36706 .47326 L .3505 .46343 L .899 .823 0 r
F
.33683 .46985 m .31303 .46075 L .3205 .45791 L .938 .828 0 r
F
.34366 .46661 m .33683 .46985 L .3205 .45791 L .927 .823 0 r
F
.47838 .47596 m .47641 .47971 L .45941 .47749 L .72 .803 0 r
F
.4948 .47696 m .47641 .47971 L .47838 .47596 L .692 .796 0 r
F
.41782 .47684 m .39575 .47419 L .40116 .4705 L .857 .831 0 r
F
.42243 .473 m .41782 .47684 L .40116 .4705 L .834 .82 0 r
F
.43914 .47788 m .41782 .47684 L .42243 .473 L .828 .831 0 r
F
.4429 .47398 m .43914 .47788 L .42243 .473 L .797 .817 0 r
F
.45941 .47749 m .43914 .47788 L .4429 .47398 L .785 .826 0 r
F
.39575 .47419 m .3732 .46975 L .37936 .46632 L .88 .827 0 r
F
.40116 .4705 m .39575 .47419 L .37936 .46632 L .862 .819 0 r
F
.30558 .46364 m .28186 .45196 L .28989 .44952 L .959 .827 0 r
F
.31303 .46075 m .30558 .46364 L .28989 .44952 L .95 .823 0 r
F
.55787 .46437 m .54442 .47057 L .54265 .46959 L .334 .144 0 r
F
.55787 .46437 m .56054 .46346 L .54723 .46933 L F
.55787 .46437 m .54723 .46933 L .5474 .46919 L F
.55521 .46709 m .55787 .46437 L .54365 .46925 L .071 0 0 r
F
.54407 .46931 m .54365 .46925 L .54265 .46959 L F
.55521 .46709 m .54365 .46925 L .54407 .46931 L F
.54879 .46812 m .54265 .46959 L .54089 .4694 L F
.54836 .46845 m .54265 .46959 L .54879 .46812 L F
.5474 .46919 m .54723 .46933 L .54442 .47057 L .334 .144 0 r
F
.54265 .46959 m .54442 .47057 L .52798 .47459 L .439 .212 0 r
F
.54265 .46959 m .52798 .47459 L .52714 .47245 L F
.54089 .4694 m .52714 .47245 L .5263 .47076 L .233 .135 0 r
F
.54089 .4694 m .54265 .46959 L .52714 .47245 L F
.55112 .4703 m .54089 .4694 L .53911 .46961 L .286 0 0 r
F
.55254 .47038 m .55045 .47021 L .55112 .4703 L F
.55045 .47021 m .54089 .4694 L .55112 .4703 L F
.55521 .46709 m .54836 .46845 L .54879 .46812 L .071 0 0 r
F
.57261 .45368 m .56054 .46346 L .55787 .46437 L 0 0 0 r
F
.46229 .47368 m .45941 .47749 L .4429 .47398 L .743 .803 0 r
F
.47838 .47596 m .45941 .47749 L .46229 .47368 L .72 .803 0 r
F
.52714 .47245 m .52798 .47459 L .51138 .47658 L .501 .51 0 r
F
.51148 .47371 m .51138 .47658 L .4948 .47696 L .549 .668 0 r
F
.52714 .47245 m .51138 .47658 L .51148 .47371 L .501 .51 0 r
F
.34366 .46661 m .3205 .45791 L .32798 .45513 L .927 .823 0 r
F
.3505 .46343 m .34366 .46661 L .32798 .45513 L .916 .819 0 r
F
.3732 .46975 m .3505 .46343 L .35736 .46031 L .899 .823 0 r
F
.37936 .46632 m .3732 .46975 L .35736 .46031 L .884 .816 0 r
F
.49584 .47365 m .4948 .47696 L .47838 .47596 L .613 .736 0 r
F
.51148 .47371 m .4948 .47696 L .49584 .47365 L .549 .668 0 r
F
.27385 .45443 m .26585 .45694 L .2507 .44004 L .977 .825 0 r
F
.42243 .473 m .40116 .4705 L .40658 .46691 L .834 .82 0 r
F
.42705 .46926 m .42243 .473 L .40658 .46691 L .808 .808 0 r
F
.4429 .47398 m .42243 .473 L .42705 .46926 L .797 .817 0 r
F
.31303 .46075 m .28989 .44952 L .29793 .44713 L .95 .823 0 r
F
.3205 .45791 m .31303 .46075 L .29793 .44713 L .941 .819 0 r
F
.40116 .4705 m .37936 .46632 L .38554 .46296 L .862 .819 0 r
F
.40658 .46691 m .40116 .4705 L .38554 .46296 L .841 .81 0 r
F
.48036 .4724 m .47838 .47596 L .46229 .47368 L .661 .765 0 r
F
.49584 .47365 m .47838 .47596 L .48036 .4724 L .613 .736 0 r
F
.44668 .47022 m .4429 .47398 L .42705 .46926 L .762 .799 0 r
F
.46229 .47368 m .4429 .47398 L .44668 .47022 L .743 .803 0 r
F
.3505 .46343 m .32798 .45513 L .33548 .4524 L .916 .819 0 r
F
.35736 .46031 m .3505 .46343 L .33548 .4524 L .903 .813 0 r
F
.27385 .45443 m .2507 .44004 L .25922 .43807 L .977 .825 0 r
F
.28186 .45196 m .27385 .45443 L .25922 .43807 L .97 .822 0 r
F
.37936 .46632 m .35736 .46031 L .36424 .45727 L .884 .816 0 r
F
.38554 .46296 m .37936 .46632 L .36424 .45727 L .867 .809 0 r
F
.46519 .47002 m .46229 .47368 L .44668 .47022 L .697 .775 0 r
F
.48036 .4724 m .46229 .47368 L .46519 .47002 L .661 .765 0 r
F
.3205 .45791 m .29793 .44713 L .30599 .44479 L .941 .819 0 r
F
.32798 .45513 m .3205 .45791 L .30599 .44479 L .931 .815 0 r
F
.5263 .47076 m .52714 .47245 L .51148 .47371 L .404 .297 0 r
F
.51158 .47115 m .51148 .47371 L .49584 .47365 L .479 .549 0 r
F
.5263 .47076 m .51148 .47371 L .51158 .47115 L .404 .297 0 r
F
.56914 .46384 m .57261 .45368 L .55787 .46437 L .291 0 0 r
F
.42705 .46926 m .40658 .46691 L .41202 .46341 L .808 .808 0 r
F
.43169 .46564 m .42705 .46926 L .41202 .46341 L .779 .793 0 r
F
.44668 .47022 m .42705 .46926 L .43169 .46564 L .762 .799 0 r
F
.28186 .45196 m .25922 .43807 L .26776 .43613 L .97 .822 0 r
F
.28989 .44952 m .28186 .45196 L .26776 .43613 L .963 .819 0 r
F
.49689 .47057 m .49584 .47365 L .48036 .4724 L .537 .667 0 r
F
.51158 .47115 m .49584 .47365 L .49689 .47057 L .479 .549 0 r
F
.40658 .46691 m .38554 .46296 L .39173 .45968 L .841 .81 0 r
F
.41202 .46341 m .40658 .46691 L .39173 .45968 L .818 .799 0 r
F
.56914 .46384 m .55787 .46437 L .55521 .46709 L .291 0 0 r
F
.35736 .46031 m .33548 .4524 L .343 .44973 L .903 .813 0 r
F
.36424 .45727 m .35736 .46031 L .343 .44973 L .889 .807 0 r
F
.45047 .46659 m .44668 .47022 L .43169 .46564 L .725 .778 0 r
F
.46519 .47002 m .44668 .47022 L .45047 .46659 L .697 .775 0 r
F
.48234 .46903 m .48036 .4724 L .46519 .47002 L .601 .72 0 r
F
.49689 .47057 m .48036 .4724 L .48234 .46903 L .537 .667 0 r
F
.38554 .46296 m .36424 .45727 L .37113 .4543 L .867 .809 0 r
F
.39173 .45968 m .38554 .46296 L .37113 .4543 L .849 .801 0 r
F
.32798 .45513 m .30599 .44479 L .31406 .44251 L .931 .815 0 r
F
.33548 .4524 m .32798 .45513 L .31406 .44251 L .92 .81 0 r
F
.28989 .44952 m .26776 .43613 L .27632 .43424 L .963 .819 0 r
F
.29793 .44713 m .28989 .44952 L .27632 .43424 L .955 .815 0 r
F
.46809 .46653 m .46519 .47002 L .45047 .46659 L .65 .743 0 r
F
.48234 .46903 m .46519 .47002 L .46809 .46653 L .601 .72 0 r
F
.53859 .70616 m .53942 .71132 L .51001 .7147 L 1 .964 0 r
F
.56682 .70052 m .53942 .71132 L .53859 .70616 L 1 .974 0 r
F
.56682 .70052 m .56857 .70572 L .53942 .71132 L F
.36424 .45727 m .343 .44973 L .35053 .44714 L .889 .807 0 r
F
.37113 .4543 m .36424 .45727 L .35053 .44714 L .874 .8 0 r
F
.41202 .46341 m .39173 .45968 L .39794 .4565 L .818 .799 0 r
F
.41748 .46002 m .41202 .46341 L .39794 .4565 L .793 .786 0 r
F
.43169 .46564 m .41202 .46341 L .41748 .46002 L .779 .793 0 r
F
.51011 .70959 m .51001 .7147 L .48061 .71587 L 1 .949 0 r
F
.53859 .70616 m .51001 .7147 L .51011 .70959 L 1 .964 0 r
F
.59454 .69271 m .56857 .70572 L .56682 .70052 L 1 .974 0 r
F
.59454 .69271 m .5972 .69795 L .56857 .70572 L F
.43634 .46215 m .43169 .46564 L .41748 .46002 L .748 .776 0 r
F
.45047 .46659 m .43169 .46564 L .43634 .46215 L .725 .778 0 r
F
.33548 .4524 m .31406 .44251 L .32215 .44028 L .92 .81 0 r
F
.343 .44973 m .33548 .4524 L .32215 .44028 L .908 .804 0 r
F
.29793 .44713 m .27632 .43424 L .28488 .4324 L .955 .815 0 r
F
.30599 .44479 m .29793 .44713 L .28488 .4324 L .946 .811 0 r
F
.51169 .46883 m .51158 .47115 L .49689 .47057 L .423 .437 0 r
F
.52545 .46937 m .51158 .47115 L .51169 .46883 L .306 .161 0 r
F
.52545 .46937 m .5263 .47076 L .51158 .47115 L F
.39173 .45968 m .37113 .4543 L .37804 .45141 L .849 .801 0 r
F
.39794 .4565 m .39173 .45968 L .37804 .45141 L .828 .791 0 r
F
.53911 .46961 m .54089 .4694 L .54034 .46945 L 0 0 0 r
F
.53911 .46961 m .54034 .46945 L .5263 .47076 L F
.53911 .46961 m .5263 .47076 L .52545 .46937 L F
.53786 .46977 m .53911 .46961 L .53732 .46964 L .352 0 0 r
F
.54983 .47252 m .53911 .46961 L .53786 .46977 L F
.49794 .46769 m .49689 .47057 L .48234 .46903 L .479 .595 0 r
F
.51169 .46883 m .49689 .47057 L .49794 .46769 L .423 .437 0 r
F
.45427 .46311 m .45047 .46659 L .43634 .46215 L .686 .753 0 r
F
.46809 .46653 m .45047 .46659 L .45427 .46311 L .65 .743 0 r
F
.48164 .71084 m .48061 .71587 L .45147 .71488 L 1 .932 0 r
F
.51011 .70959 m .48061 .71587 L .48164 .71084 L 1 .949 0 r
F
.62151 .68285 m .5972 .69795 L .59454 .69271 L 1 .964 0 r
F
.62151 .68285 m .62506 .6881 L .5972 .69795 L F
.25922 .43807 m .2507 .44004 L .23805 .422 L .982 .819 0 r
F
.55254 .47038 m .55521 .46709 L .54089 .4694 L .286 0 0 r
F
.48433 .46584 m .48234 .46903 L .46809 .46653 L .544 .671 0 r
F
.49794 .46769 m .48234 .46903 L .48433 .46584 L .479 .595 0 r
F
.37113 .4543 m .35053 .44714 L .35808 .44461 L .874 .8 0 r
F
.37804 .45141 m .37113 .4543 L .35808 .44461 L .857 .792 0 r
F
.30599 .44479 m .28488 .4324 L .29346 .4306 L .946 .811 0 r
F
.31406 .44251 m .30599 .44479 L .29346 .4306 L .936 .807 0 r
F
.56564 .47496 m .55521 .46709 L .55254 .47038 L .53 .021 0 r
F
.56564 .47496 m .56914 .46384 L .55521 .46709 L F
.343 .44973 m .32215 .44028 L .33026 .43812 L .908 .804 0 r
F
.35053 .44714 m .343 .44973 L .33026 .43812 L .895 .798 0 r
F
.53776 .70105 m .53859 .70616 L .51011 .70959 L 1 .969 0 r
F
.56506 .69537 m .53859 .70616 L .53776 .70105 L 1 .981 0 r
F
.56506 .69537 m .56682 .70052 L .53859 .70616 L F
.47101 .4632 m .46809 .46653 L .45427 .46311 L .602 .708 0 r
F
.48433 .46584 m .46809 .46653 L .47101 .4632 L .544 .671 0 r
F
.41748 .46002 m .39794 .4565 L .40417 .45342 L .793 .786 0 r
F
.42295 .45675 m .41748 .46002 L .40417 .45342 L .767 .772 0 r
F
.43634 .46215 m .41748 .46002 L .42295 .45675 L .748 .776 0 r
F
.25922 .43807 m .23805 .422 L .24703 .4206 L .982 .819 0 r
F
.26776 .43613 m .25922 .43807 L .24703 .4206 L .975 .816 0 r
F
.59187 .68752 m .56682 .70052 L .56506 .69537 L 1 .983 0 r
F
.59187 .68752 m .59454 .69271 L .56682 .70052 L F
.45342 .70995 m .45147 .71488 L .42286 .71178 L .99 .914 0 r
F
.48164 .71084 m .45147 .71488 L .45342 .70995 L 1 .932 0 r
F
.51021 .70454 m .51011 .70959 L .48164 .71084 L 1 .952 0 r
F
.53776 .70105 m .51011 .70959 L .51021 .70454 L 1 .969 0 r
F
.44101 .45879 m .43634 .46215 L .42295 .45675 L .715 .756 0 r
F
.45427 .46311 m .43634 .46215 L .44101 .45879 L .686 .753 0 r
F
.64748 .67112 m .62506 .6881 L .62151 .68285 L 1 .944 0 r
F
.64748 .67112 m .6519 .67637 L .62506 .6881 L F
.39794 .4565 m .37804 .45141 L .38497 .44861 L .828 .791 0 r
F
.40417 .45342 m .39794 .4565 L .38497 .44861 L .806 .78 0 r
F
.5785 .49884 m .56914 .46384 L .56564 .47496 L 1 .113 0 r
F
.5785 .49884 m .58279 .48196 L .56914 .46384 L F
.61794 .67761 m .59454 .69271 L .59187 .68752 L 1 .972 0 r
F
.61794 .67761 m .62151 .68285 L .59454 .69271 L F
.31406 .44251 m .29346 .4306 L .30206 .42886 L .936 .807 0 r
F
.32215 .44028 m .31406 .44251 L .30206 .42886 L .926 .802 0 r
F
.48267 .70586 m .48164 .71084 L .45342 .70995 L 1 .932 0 r
F
.51021 .70454 m .48164 .71084 L .48267 .70586 L 1 .952 0 r
F
.26776 .43613 m .24703 .4206 L .25602 .41924 L .975 .816 0 r
F
.27632 .43424 m .26776 .43613 L .25602 .41924 L .968 .812 0 r
F
.45809 .45977 m .45427 .46311 L .44101 .45879 L .646 .726 0 r
F
.47101 .4632 m .45427 .46311 L .45809 .45977 L .602 .708 0 r
F
.37804 .45141 m .35808 .44461 L .36564 .44217 L .857 .792 0 r
F
.38497 .44861 m .37804 .45141 L .36564 .44217 L .839 .783 0 r
F
.35053 .44714 m .33026 .43812 L .33838 .43602 L .895 .798 0 r
F
.35808 .44461 m .35053 .44714 L .33838 .43602 L .881 .791 0 r
F
.51179 .46664 m .51169 .46883 L .49794 .46769 L .374 .357 0 r
F
.5246 .46805 m .51169 .46883 L .51179 .46664 L .236 .131 0 r
F
.5246 .46805 m .52545 .46937 L .51169 .46883 L F
.49899 .46497 m .49794 .46769 L .48433 .46584 L .445 .53 0 r
F
.51179 .46664 m .49794 .46769 L .49899 .46497 L .374 .357 0 r
F
.53732 .46964 m .53911 .46961 L .53695 .46957 L .025 0 0 r
F
.53732 .46964 m .53695 .46957 L .52545 .46937 L F
.5377 .46972 m .53732 .46964 L .53552 .46902 L .289 0 0 r
F
.54711 .47275 m .54983 .47252 L .54306 .47097 L F
.54711 .47275 m .54306 .47097 L .53732 .46964 L F
.55841 .47891 m .54983 .47252 L .54711 .47275 L .52 0 0 r
F
.55149 .47468 m .54711 .47275 L .54435 .47126 L 0 .053 0 r
F
.55473 .47623 m .54711 .47275 L .55149 .47468 L F
.54711 .47275 m .53732 .46964 L .5377 .46972 L .289 0 0 r
F
.53732 .46964 m .52545 .46937 L .5246 .46805 L .025 0 0 r
F
.48633 .46279 m .48433 .46584 L .47101 .4632 L .495 .623 0 r
F
.49899 .46497 m .48433 .46584 L .48633 .46279 L .445 .53 0 r
F
.42295 .45675 m .40417 .45342 L .41042 .45046 L .767 .772 0 r
F
.42844 .4536 m .42295 .45675 L .41042 .45046 L .738 .756 0 r
F
.44101 .45879 m .42295 .45675 L .42844 .4536 L .715 .756 0 r
F
.27632 .43424 m .25602 .41924 L .26503 .41793 L .968 .812 0 r
F
.28488 .4324 m .27632 .43424 L .26503 .41793 L .961 .808 0 r
F
.53692 .69603 m .53776 .70105 L .51021 .70454 L 1 .974 0 r
F
.5633 .69029 m .53776 .70105 L .53692 .69603 L 1 .989 0 r
F
.5633 .69029 m .56506 .69537 L .53776 .70105 L F
.42572 .70701 m .42286 .71178 L .39503 .70666 L .967 .898 0 r
F
.45342 .70995 m .42286 .71178 L .42572 .70701 L .99 .914 0 r
F
.67222 .65778 m .6519 .67637 L .64748 .67112 L 1 .918 0 r
F
.67222 .65778 m .67748 .66298 L .6519 .67637 L F
.64305 .66585 m .62151 .68285 L .61794 .67761 L 1 .949 0 r
F
.64305 .66585 m .64748 .67112 L .62151 .68285 L F
.40417 .45342 m .38497 .44861 L .39191 .44591 L .806 .78 0 r
F
.41042 .45046 m .40417 .45342 L .39191 .44591 L .783 .767 0 r
F
.32215 .44028 m .30206 .42886 L .31066 .42718 L .926 .802 0 r
F
.33026 .43812 m .32215 .44028 L .31066 .42718 L .915 .796 0 r
F
.58919 .68238 m .56506 .69537 L .5633 .69029 L 1 .992 0 r
F
.58919 .68238 m .59187 .68752 L .56506 .69537 L F
.54983 .47252 m .55254 .47038 L .53911 .46961 L .352 0 0 r
F
.45538 .70508 m .45342 .70995 L .42572 .70701 L .98 .914 0 r
F
.48267 .70586 m .45342 .70995 L .45538 .70508 L 1 .932 0 r
F
.47394 .46001 m .47101 .4632 L .45809 .45977 L .557 .671 0 r
F
.48633 .46279 m .47101 .4632 L .47394 .46001 L .495 .623 0 r
F
.51031 .69956 m .51021 .70454 L .48267 .70586 L 1 .954 0 r
F
.53692 .69603 m .51021 .70454 L .51031 .69956 L 1 .974 0 r
F
.44569 .45556 m .44101 .45879 L .42844 .4536 L .681 .735 0 r
F
.45809 .45977 m .44101 .45879 L .44569 .45556 L .646 .726 0 r
F
.35808 .44461 m .33838 .43602 L .34651 .434 L .881 .791 0 r
F
.36564 .44217 m .35808 .44461 L .34651 .434 L .865 .784 0 r
F
.38497 .44861 m .36564 .44217 L .37322 .43982 L .839 .783 0 r
F
.39191 .44591 m .38497 .44861 L .37322 .43982 L .819 .773 0 r
F
.61437 .67239 m .59187 .68752 L .58919 .68238 L 1 .98 0 r
F
.61437 .67239 m .61794 .67761 L .59187 .68752 L F
.28488 .4324 m .26503 .41793 L .27404 .41667 L .961 .808 0 r
F
.29346 .4306 m .28488 .4324 L .27404 .41667 L .952 .804 0 r
F
.4837 .70095 m .48267 .70586 L .45538 .70508 L .999 .932 0 r
F
.51031 .69956 m .48267 .70586 L .4837 .70095 L 1 .954 0 r
F
.46192 .45658 m .45809 .45977 L .44569 .45556 L .607 .697 0 r
F
.47394 .46001 m .45809 .45977 L .46192 .45658 L .557 .671 0 r
F
.33026 .43812 m .31066 .42718 L .31929 .42557 L .915 .796 0 r
F
.33838 .43602 m .33026 .43812 L .31929 .42557 L .903 .79 0 r
F
.56205 .47931 m .55254 .47038 L .54983 .47252 L .677 .019 0 r
F
.56205 .47931 m .56564 .47496 L .55254 .47038 L F
.66695 .65254 m .64748 .67112 L .64305 .66585 L 1 .92 0 r
F
.66695 .65254 m .67222 .65778 L .64748 .67112 L F
.50005 .46231 m .49899 .46497 L .48633 .46279 L .417 .483 0 r
F
.51189 .46445 m .49899 .46497 L .50005 .46231 L .341 .319 0 r
F
.51189 .46445 m .51179 .46664 L .49899 .46497 L F
.41042 .45046 m .39191 .44591 L .39888 .44332 L .783 .767 0 r
F
.41668 .4476 m .41042 .45046 L .39888 .44332 L .757 .753 0 r
F
.42844 .4536 m .41042 .45046 L .41668 .4476 L .738 .756 0 r
F
.6386 .66057 m .61794 .67761 L .61437 .67239 L 1 .954 0 r
F
.6386 .66057 m .64305 .66585 L .61794 .67761 L F
.43395 .45058 m .42844 .4536 L .41668 .4476 L .708 .737 0 r
F
.44569 .45556 m .42844 .4536 L .43395 .45058 L .681 .735 0 r
F
.52375 .46653 m .51179 .46664 L .51189 .46445 L .209 .125 0 r
F
.52375 .46653 m .5246 .46805 L .51179 .46664 L F
.42572 .70701 m .39503 .70666 L .39877 .70208 L .967 .898 0 r
F
.42858 .70228 m .42572 .70701 L .39877 .70208 L .957 .896 0 r
F
.45538 .70508 m .42572 .70701 L .42858 .70228 L .98 .914 0 r
F
.29346 .4306 m .27404 .41667 L .28306 .41546 L .952 .804 0 r
F
.30206 .42886 m .29346 .4306 L .28306 .41546 L .943 .799 0 r
F
.36564 .44217 m .34651 .434 L .35467 .43207 L .865 .784 0 r
F
.37322 .43982 m .36564 .44217 L .35467 .43207 L .849 .775 0 r
F
.53609 .69109 m .53692 .69603 L .51031 .69956 L 1 .979 0 r
F
.56153 .6853 m .53692 .69603 L .53609 .69109 L 1 .997 0 r
F
.56153 .6853 m .5633 .69029 L .53692 .69603 L F
.48834 .45986 m .48633 .46279 L .47394 .46001 L .462 .58 0 r
F
.50005 .46231 m .48633 .46279 L .48834 .45986 L .417 .483 0 r
F
.5865 .6773 m .5633 .69029 L .56153 .6853 L 1 1 0 r
F
.5865 .6773 m .58919 .68238 L .5633 .69029 L F
.45734 .70027 m .45538 .70508 L .42858 .70228 L .968 .912 0 r
F
.4837 .70095 m .45538 .70508 L .45734 .70027 L .999 .932 0 r
F
.39877 .70208 m .39503 .70666 L .36823 .69959 L .951 .883 0 r
F
.69551 .6431 m .67748 .66298 L .67222 .65778 L 1 .891 0 r
F
.69551 .6431 m .70156 .64816 L .67748 .66298 L F
.53552 .46902 m .5246 .46805 L .52375 .46653 L 0 .101 0 r
F
.53552 .46902 m .53732 .46964 L .5246 .46805 L F
.24703 .4206 m .23805 .422 L .22808 .40296 L .989 .814 0 r
F
.51041 .69467 m .51031 .69956 L .4837 .70095 L 1 .956 0 r
F
.53609 .69109 m .51031 .69956 L .51041 .69467 L 1 .979 0 r
F
.39191 .44591 m .37322 .43982 L .38082 .43757 L .819 .773 0 r
F
.39888 .44332 m .39191 .44591 L .38082 .43757 L .797 .761 0 r
F
.45039 .45247 m .44569 .45556 L .43395 .45058 L .646 .711 0 r
F
.46192 .45658 m .44569 .45556 L .45039 .45247 L .607 .697 0 r
F
.33838 .43602 m .31929 .42557 L .32792 .42403 L .903 .79 0 r
F
.34651 .434 m .33838 .43602 L .32792 .42403 L .889 .783 0 r
F
.47688 .45695 m .47394 .46001 L .46192 .45658 L .518 .635 0 r
F
.48834 .45986 m .47394 .46001 L .47688 .45695 L .462 .58 0 r
F
.61078 .6672 m .58919 .68238 L .5865 .6773 L 1 .99 0 r
F
.61078 .6672 m .61437 .67239 L .58919 .68238 L F
.30206 .42886 m .28306 .41546 L .2921 .41431 L .943 .799 0 r
F
.31066 .42718 m .30206 .42886 L .2921 .41431 L .933 .794 0 r
F
.48474 .69612 m .4837 .70095 L .45734 .70027 L .986 .932 0 r
F
.51041 .69467 m .4837 .70095 L .48474 .69612 L 1 .956 0 r
F
.24703 .4206 m .22808 .40296 L .23743 .40217 L .989 .814 0 r
F
.25602 .41924 m .24703 .4206 L .23743 .40217 L .982 .81 0 r
F
.66166 .64724 m .64305 .66585 L .6386 .66057 L 1 .921 0 r
F
.66166 .64724 m .66695 .65254 L .64305 .66585 L F
.46576 .45351 m .46192 .45658 L .45039 .45247 L .57 .667 0 r
F
.47688 .45695 m .46192 .45658 L .46576 .45351 L .518 .635 0 r
F
.37322 .43982 m .35467 .43207 L .36283 .43022 L .849 .775 0 r
F
.38082 .43757 m .37322 .43982 L .36283 .43022 L .83 .766 0 r
F
.41668 .4476 m .39888 .44332 L .40586 .44085 L .757 .753 0 r
F
.42296 .44488 m .41668 .4476 L .40586 .44085 L .73 .737 0 r
F
.43395 .45058 m .41668 .4476 L .42296 .44488 L .708 .737 0 r
F
.63413 .65527 m .61437 .67239 L .61078 .6672 L 1 .96 0 r
F
.63413 .65527 m .6386 .66057 L .61437 .67239 L F
.57392 .49327 m .56564 .47496 L .56205 .47931 L .796 .063 0 r
F
.57392 .49327 m .5785 .49884 L .56564 .47496 L F
.34651 .434 m .32792 .42403 L .33657 .42256 L .889 .783 0 r
F
.35467 .43207 m .34651 .434 L .33657 .42256 L .875 .776 0 r
F
.43947 .4477 m .43395 .45058 L .42296 .44488 L .677 .717 0 r
F
.45039 .45247 m .43395 .45058 L .43947 .4477 L .646 .711 0 r
F
.68944 .63797 m .67222 .65778 L .66695 .65254 L 1 .889 0 r
F
.68944 .63797 m .69551 .6431 L .67222 .65778 L F
.42858 .70228 m .39877 .70208 L .40252 .69753 L .957 .896 0 r
F
.43145 .6976 m .42858 .70228 L .40252 .69753 L .945 .894 0 r
F
.45734 .70027 m .42858 .70228 L .43145 .6976 L .968 .912 0 r
F
.25602 .41924 m .23743 .40217 L .24679 .40143 L .982 .81 0 r
F
.26503 .41793 m .25602 .41924 L .24679 .40143 L .976 .806 0 r
F
.39888 .44332 m .38082 .43757 L .38844 .43542 L .797 .761 0 r
F
.40586 .44085 m .39888 .44332 L .38844 .43542 L .774 .748 0 r
F
.31066 .42718 m .2921 .41431 L .30114 .41323 L .933 .794 0 r
F
.31929 .42557 m .31066 .42718 L .30114 .41323 L .923 .789 0 r
F
.53525 .68627 m .53609 .69109 L .51041 .69467 L 1 .983 0 r
F
.55976 .68043 m .53609 .69109 L .53525 .68627 L 1 1 0 r
F
.55976 .68043 m .56153 .6853 L .53609 .69109 L F
.39877 .70208 m .36823 .69959 L .37283 .69525 L .951 .883 0 r
F
.40252 .69753 m .39877 .70208 L .37283 .69525 L .941 .881 0 r
F
.58381 .67233 m .56153 .6853 L .55976 .68043 L 1 1 0 r
F
.58381 .67233 m .5865 .6773 L .56153 .6853 L F
.4593 .69552 m .45734 .70027 L .43145 .6976 L .954 .91 0 r
F
.48474 .69612 m .45734 .70027 L .4593 .69552 L .986 .932 0 r
F
.50111 .45964 m .50005 .46231 L .48834 .45986 L .398 .455 0 r
F
.51199 .46211 m .50005 .46231 L .50111 .45964 L .328 .317 0 r
F
.51199 .46211 m .51189 .46445 L .50005 .46231 L F
.51051 .68989 m .51041 .69467 L .48474 .69612 L 1 .956 0 r
F
.53525 .68627 m .51041 .69467 L .51051 .68989 L 1 .983 0 r
F
.45511 .44951 m .45039 .45247 L .43947 .4477 L .612 .685 0 r
F
.46576 .45351 m .45039 .45247 L .45511 .44951 L .57 .667 0 r
F
.49036 .45698 m .48834 .45986 L .47688 .45695 L .443 .546 0 r
F
.50111 .45964 m .48834 .45986 L .49036 .45698 L .398 .455 0 r
F
.52289 .46462 m .51189 .46445 L .51199 .46211 L .22 .151 0 r
F
.52289 .46462 m .52375 .46653 L .51189 .46445 L F
.60718 .66207 m .5865 .6773 L .58381 .67233 L 1 1 0 r
F
.60718 .66207 m .61078 .6672 L .5865 .6773 L F
.55841 .47891 m .56205 .47931 L .54983 .47252 L .52 0 0 r
F
.26503 .41793 m .24679 .40143 L .25616 .40074 L .976 .806 0 r
F
.27404 .41667 m .26503 .41793 L .25616 .40074 L .968 .802 0 r
F
.38082 .43757 m .36283 .43022 L .37102 .42847 L .83 .766 0 r
F
.38844 .43542 m .38082 .43757 L .37102 .42847 L .81 .755 0 r
F
.47983 .45398 m .47688 .45695 L .46576 .45351 L .487 .603 0 r
F
.49036 .45698 m .47688 .45695 L .47983 .45398 L .443 .546 0 r
F
.35467 .43207 m .33657 .42256 L .34523 .42118 L .875 .776 0 r
F
.36283 .43022 m .35467 .43207 L .34523 .42118 L .859 .768 0 r
F
.65636 .64188 m .6386 .66057 L .63413 .65527 L 1 .922 0 r
F
.65636 .64188 m .66166 .64724 L .6386 .66057 L F
.31929 .42557 m .30114 .41323 L .3102 .41221 L .923 .789 0 r
F
.32792 .42403 m .31929 .42557 L .3102 .41221 L .911 .783 0 r
F
.37283 .69525 m .36823 .69959 L .34272 .69067 L .941 .871 0 r
F
.71712 .62732 m .70156 .64816 L .69551 .6431 L 1 .866 0 r
F
.71712 .62732 m .72392 .63215 L .70156 .64816 L F
.53371 .46751 m .52375 .46653 L .52289 .46462 L .065 .105 0 r
F
.53371 .46751 m .53552 .46902 L .52375 .46653 L F
.48578 .69138 m .48474 .69612 L .4593 .69552 L .969 .93 0 r
F
.51051 .68989 m .48474 .69612 L .48578 .69138 L 1 .956 0 r
F
.68335 .63275 m .66695 .65254 L .66166 .64724 L 1 .887 0 r
F
.68335 .63275 m .68944 .63797 L .66695 .65254 L F
.42296 .44488 m .40586 .44085 L .41286 .43849 L .73 .737 0 r
F
.42927 .44228 m .42296 .44488 L .41286 .43849 L .702 .719 0 r
F
.43947 .4477 m .42296 .44488 L .42927 .44228 L .677 .717 0 r
F
.62966 .64995 m .61078 .6672 L .60718 .66207 L 1 .966 0 r
F
.62966 .64995 m .63413 .65527 L .61078 .6672 L F
.27404 .41667 m .25616 .40074 L .26553 .4001 L .968 .802 0 r
F
.28306 .41546 m .27404 .41667 L .26553 .4001 L .96 .798 0 r
F
.40586 .44085 m .38844 .43542 L .39608 .43339 L .774 .748 0 r
F
.41286 .43849 m .40586 .44085 L .39608 .43339 L .749 .734 0 r
F
.46962 .45056 m .46576 .45351 L .45511 .44951 L .537 .638 0 r
F
.47983 .45398 m .46576 .45351 L .46962 .45056 L .487 .603 0 r
F
.44501 .44495 m .43947 .4477 L .42927 .44228 L .645 .695 0 r
F
.45511 .44951 m .43947 .4477 L .44501 .44495 L .612 .685 0 r
F
.43145 .6976 m .40252 .69753 L .40629 .69304 L .945 .894 0 r
F
.43434 .69299 m .43145 .6976 L .40629 .69304 L .931 .891 0 r
F
.4593 .69552 m .43145 .6976 L .43434 .69299 L .954 .91 0 r
F
.40252 .69753 m .37283 .69525 L .37745 .69095 L .941 .881 0 r
F
.40629 .69304 m .40252 .69753 L .37745 .69095 L .929 .878 0 r
F
.32792 .42403 m .3102 .41221 L .31927 .41126 L .911 .783 0 r
F
.33657 .42256 m .32792 .42403 L .31927 .41126 L .898 .776 0 r
F
.54435 .47126 m .53552 .46902 L .53371 .46751 L 0 .08 0 r
F
.54435 .47126 m .54711 .47275 L .53552 .46902 L F
.5344 .68159 m .53525 .68627 L .51051 .68989 L 1 .987 0 r
F
.55798 .67569 m .53525 .68627 L .5344 .68159 L 1 1 0 r
F
.55798 .67569 m .55976 .68043 L .53525 .68627 L F
.5811 .66747 m .55976 .68043 L .55798 .67569 L F
.5811 .66747 m .58381 .67233 L .55976 .68043 L F
.36283 .43022 m .34523 .42118 L .35391 .41989 L .859 .768 0 r
F
.37102 .42847 m .36283 .43022 L .35391 .41989 L .841 .759 0 r
F
.46128 .69086 m .4593 .69552 L .43434 .69299 L .937 .906 0 r
F
.48578 .69138 m .4593 .69552 L .46128 .69086 L .969 .93 0 r
F
.38844 .43542 m .37102 .42847 L .37922 .42683 L .81 .755 0 r
F
.39608 .43339 m .38844 .43542 L .37922 .42683 L .789 .743 0 r
F
.28306 .41546 m .26553 .4001 L .27492 .39951 L .96 .798 0 r
F
.2921 .41431 m .28306 .41546 L .27492 .39951 L .952 .793 0 r
F
.71031 .6224 m .69551 .6431 L .68944 .63797 L 1 .862 0 r
F
.71031 .6224 m .71712 .62732 L .69551 .6431 L F
.51061 .68523 m .51051 .68989 L .48578 .69138 L .996 .955 0 r
F
.5344 .68159 m .51051 .68989 L .51061 .68523 L 1 .987 0 r
F
.60357 .657 m .58381 .67233 L .5811 .66747 L 1 1 0 r
F
.60357 .657 m .60718 .66207 L .58381 .67233 L F
.45984 .44668 m .45511 .44951 L .44501 .44495 L .579 .659 0 r
F
.46962 .45056 m .45511 .44951 L .45984 .44668 L .537 .638 0 r
F
.65104 .63644 m .63413 .65527 L .62966 .64995 L 1 .922 0 r
F
.65104 .63644 m .65636 .64188 L .63413 .65527 L F
.37283 .69525 m .34272 .69067 L .34814 .68662 L .941 .871 0 r
F
.37745 .69095 m .37283 .69525 L .34814 .68662 L .931 .868 0 r
F
.67725 .62744 m .66166 .64724 L .65636 .64188 L 1 .883 0 r
F
.67725 .62744 m .68335 .63275 L .66166 .64724 L F
.50218 .45688 m .50111 .45964 L .49036 .45698 L .389 .445 0 r
F
.5121 .45953 m .50111 .45964 L .50218 .45688 L .332 .339 0 r
F
.5121 .45953 m .51199 .46211 L .50111 .45964 L F
.49238 .4541 m .49036 .45698 L .47983 .45398 L .43 .522 0 r
F
.50218 .45688 m .49036 .45698 L .49238 .4541 L .389 .445 0 r
F
.33657 .42256 m .31927 .41126 L .32836 .4104 L .898 .776 0 r
F
.34523 .42118 m .33657 .42256 L .32836 .4104 L .884 .769 0 r
F
.2921 .41431 m .27492 .39951 L .28431 .39899 L .952 .793 0 r
F
.30114 .41323 m .2921 .41431 L .28431 .39899 L .942 .788 0 r
F
.52203 .46222 m .51199 .46211 L .5121 .45953 L .254 .216 0 r
F
.52203 .46222 m .52289 .46462 L .51199 .46211 L F
.48682 .68675 m .48578 .69138 L .46128 .69086 L .949 .926 0 r
F
.51061 .68523 m .48578 .69138 L .48682 .68675 L .996 .955 0 r
F
.62517 .64462 m .60718 .66207 L .60357 .657 L 1 .973 0 r
F
.62517 .64462 m .62966 .64995 L .60718 .66207 L F
.42927 .44228 m .41286 .43849 L .41988 .43627 L .702 .719 0 r
F
.43559 .43982 m .42927 .44228 L .41988 .43627 L .673 .7 0 r
F
.44501 .44495 m .42927 .44228 L .43559 .43982 L .645 .695 0 r
F
.41286 .43849 m .39608 .43339 L .40373 .43147 L .749 .734 0 r
F
.41988 .43627 m .41286 .43849 L .40373 .43147 L .723 .718 0 r
F
.56934 .48768 m .57392 .49327 L .56205 .47931 L 0 0 0 r
F
.56934 .48768 m .56205 .47931 L .55841 .47891 L F
.48279 .45106 m .47983 .45398 L .46962 .45056 L .464 .575 0 r
F
.49238 .4541 m .47983 .45398 L .48279 .45106 L .43 .522 0 r
F
.37102 .42847 m .35391 .41989 L .3626 .4187 L .841 .759 0 r
F
.37922 .42683 m .37102 .42847 L .3626 .4187 L .823 .749 0 r
F
.55473 .47623 m .55841 .47891 L .54711 .47275 L 0 .053 0 r
F
.45058 .44233 m .44501 .44495 L .43559 .43982 L .615 .672 0 r
F
.45984 .44668 m .44501 .44495 L .45058 .44233 L .579 .659 0 r
F
.23743 .40217 m .22808 .40296 L .22092 .38309 L .997 .809 0 r
F
.53189 .46515 m .52289 .46462 L .52203 .46222 L .158 .114 0 r
F
.53189 .46515 m .53371 .46751 L .52289 .46462 L F
.39608 .43339 m .37922 .42683 L .38744 .4253 L .789 .743 0 r
F
.40373 .43147 m .39608 .43339 L .38744 .4253 L .766 .73 0 r
F
.70347 .61738 m .68944 .63797 L .68335 .63275 L 1 .857 0 r
F
.70347 .61738 m .71031 .6224 L .68944 .63797 L F
.43434 .69299 m .40629 .69304 L .41007 .68861 L .931 .891 0 r
F
.43723 .68844 m .43434 .69299 L .41007 .68861 L .915 .887 0 r
F
.46128 .69086 m .43434 .69299 L .43723 .68844 L .937 .906 0 r
F
.47349 .4477 m .46962 .45056 L .45984 .44668 L .51 .61 0 r
F
.48279 .45106 m .46962 .45056 L .47349 .4477 L .464 .575 0 r
F
.40629 .69304 m .37745 .69095 L .38208 .68669 L .929 .878 0 r
F
.41007 .68861 m .40629 .69304 L .38208 .68669 L .916 .875 0 r
F
.30114 .41323 m .28431 .39899 L .29371 .39853 L .942 .788 0 r
F
.3102 .41221 m .30114 .41323 L .29371 .39853 L .932 .782 0 r
F
.34523 .42118 m .32836 .4104 L .33745 .40962 L .884 .769 0 r
F
.35391 .41989 m .34523 .42118 L .33745 .40962 L .869 .76 0 r
F
.55619 .67114 m .55798 .67569 L .5344 .68159 L 1 1 0 r
F
.57839 .66278 m .55798 .67569 L .55619 .67114 L F
.57839 .66278 m .5811 .66747 L .55798 .67569 L F
.34814 .68662 m .34272 .69067 L .31873 .67999 L .934 .859 0 r
F
.53356 .67707 m .5344 .68159 L .51061 .68523 L 1 .987 0 r
F
.55619 .67114 m .5344 .68159 L .53356 .67707 L 1 1 0 r
F
.6457 .63089 m .62966 .64995 L .62517 .64462 L 1 .921 0 r
F
.6457 .63089 m .65104 .63644 L .62966 .64995 L F
.67113 .622 m .65636 .64188 L .65104 .63644 L 1 .878 0 r
F
.67113 .622 m .67725 .62744 L .65636 .64188 L F
.46326 .68629 m .46128 .69086 L .43723 .68844 L .917 .901 0 r
F
.48682 .68675 m .46128 .69086 L .46326 .68629 L .949 .926 0 r
F
.23743 .40217 m .22092 .38309 L .23056 .38295 L .997 .809 0 r
F
.24679 .40143 m .23743 .40217 L .23056 .38295 L .991 .805 0 r
F
.73686 .6106 m .72392 .63215 L .71712 .62732 L 1 .846 0 r
F
.73686 .6106 m .74435 .61512 L .72392 .63215 L F
.59995 .65203 m .5811 .66747 L .57839 .66278 L 1 1 0 r
F
.59995 .65203 m .60357 .657 L .5811 .66747 L F
.37745 .69095 m .34814 .68662 L .35359 .6826 L .931 .868 0 r
F
.38208 .68669 m .37745 .69095 L .35359 .6826 L .92 .864 0 r
F
.51071 .68071 m .51061 .68523 L .48682 .68675 L .971 .95 0 r
F
.53356 .67707 m .51061 .68523 L .51071 .68071 L 1 .987 0 r
F
.46459 .44396 m .45984 .44668 L .45058 .44233 L .55 .634 0 r
F
.47349 .4477 m .45984 .44668 L .46459 .44396 L .51 .61 0 r
F
.54158 .46853 m .53371 .46751 L .53189 .46515 L .061 .094 0 r
F
.54158 .46853 m .54435 .47126 L .53371 .46751 L F
.37922 .42683 m .3626 .4187 L .37131 .41762 L .823 .749 0 r
F
.38744 .4253 m .37922 .42683 L .37131 .41762 L .802 .737 0 r
F
.3102 .41221 m .29371 .39853 L .30312 .39815 L .932 .782 0 r
F
.31927 .41126 m .3102 .41221 L .30312 .39815 L .921 .776 0 r
F
.41988 .43627 m .40373 .43147 L .4114 .42969 L .723 .718 0 r
F
.42692 .43418 m .41988 .43627 L .4114 .42969 L .696 .701 0 r
F
.43559 .43982 m .41988 .43627 L .42692 .43418 L .673 .7 0 r
F
.24679 .40143 m .23056 .38295 L .24019 .38285 L .991 .805 0 r
F
.25616 .40074 m .24679 .40143 L .24019 .38285 L .985 .801 0 r
F
.62067 .63927 m .60357 .657 L .59995 .65203 L 1 .981 0 r
F
.62067 .63927 m .62517 .64462 L .60357 .657 L F
.44193 .4375 m .43559 .43982 L .42692 .43418 L .643 .679 0 r
F
.45058 .44233 m .43559 .43982 L .44193 .4375 L .615 .672 0 r
F
.69662 .61225 m .68335 .63275 L .67725 .62744 L 1 .851 0 r
F
.69662 .61225 m .70347 .61738 L .68335 .63275 L F
.35391 .41989 m .33745 .40962 L .34656 .40894 L .869 .76 0 r
F
.3626 .4187 m .35391 .41989 L .34656 .40894 L .852 .752 0 r
F
.40373 .43147 m .38744 .4253 L .39567 .42389 L .766 .73 0 r
F
.4114 .42969 m .40373 .43147 L .39567 .42389 L .741 .716 0 r
F
.48787 .68224 m .48682 .68675 L .46326 .68629 L .923 .919 0 r
F
.51071 .68071 m .48682 .68675 L .48787 .68224 L .971 .95 0 r
F
.49442 .45116 m .49238 .4541 L .48279 .45106 L .422 .507 0 r
F
.50326 .45396 m .49238 .4541 L .49442 .45116 L .388 .447 0 r
F
.50326 .45396 m .50218 .45688 L .49238 .4541 L F
.5122 .45664 m .50218 .45688 L .50326 .45396 L .345 .371 0 r
F
.5122 .45664 m .5121 .45953 L .50218 .45688 L F
.72935 .606 m .71712 .62732 L .71031 .6224 L 1 .84 0 r
F
.72935 .606 m .73686 .6106 L .71712 .62732 L F
.25616 .40074 m .24019 .38285 L .24984 .38281 L .985 .801 0 r
F
.26553 .4001 m .25616 .40074 L .24984 .38281 L .978 .797 0 r
F
.48577 .44816 m .48279 .45106 L .47349 .4477 L .45 .553 0 r
F
.49442 .45116 m .48279 .45106 L .48577 .44816 L .422 .507 0 r
F
.31927 .41126 m .30312 .39815 L .31254 .39784 L .921 .776 0 r
F
.32836 .4104 m .31927 .41126 L .31254 .39784 L .908 .769 0 r
F
.45616 .43984 m .45058 .44233 L .44193 .4375 L .585 .649 0 r
F
.46459 .44396 m .45058 .44233 L .45616 .43984 L .55 .634 0 r
F
.52116 .4593 m .5121 .45953 L .5122 .45664 L .293 .286 0 r
F
.52116 .4593 m .52203 .46222 L .5121 .45953 L F
.66499 .61641 m .65104 .63644 L .6457 .63089 L 1 .871 0 r
F
.66499 .61641 m .67113 .622 L .65104 .63644 L F
.41007 .68861 m .38208 .68669 L .38672 .68248 L .916 .875 0 r
F
.41386 .68424 m .41007 .68861 L .38672 .68248 L .901 .87 0 r
F
.43723 .68844 m .41007 .68861 L .41386 .68424 L .915 .887 0 r
F
.44013 .68398 m .43723 .68844 L .41386 .68424 L .897 .881 0 r
F
.46326 .68629 m .43723 .68844 L .44013 .68398 L .917 .901 0 r
F
.34814 .68662 m .31873 .67999 L .32494 .67628 L .934 .859 0 r
F
.35359 .6826 m .34814 .68662 L .32494 .67628 L .925 .856 0 r
F
.64035 .62522 m .62517 .64462 L .62067 .63927 L 1 .918 0 r
F
.64035 .62522 m .6457 .63089 L .62517 .64462 L F
.59085 .5222 m .58333 .527 L .5785 .49884 L .26 .044 0 r
F
.58528 .50659 m .5785 .49884 L .57392 .49327 L 0 0 0 r
F
.58528 .50659 m .59085 .5222 L .5785 .49884 L F
.56473 .48207 m .55841 .47891 L .55473 .47623 L 0 .039 0 r
F
.56473 .48207 m .56934 .48768 L .55841 .47891 L F
.38744 .4253 m .37131 .41762 L .38004 .41665 L .802 .737 0 r
F
.39567 .42389 m .38744 .4253 L .38004 .41665 L .78 .725 0 r
F
.47739 .4449 m .47349 .4477 L .46459 .44396 L .488 .586 0 r
F
.48577 .44816 m .47349 .4477 L .47739 .4449 L .45 .553 0 r
F
.26553 .4001 m .24984 .38281 L .25949 .38282 L .978 .797 0 r
F
.27492 .39951 m .26553 .4001 L .25949 .38282 L .97 .792 0 r
F
.55102 .47241 m .54435 .47126 L .54158 .46853 L .002 .078 0 r
F
.55102 .47241 m .55473 .47623 L .54435 .47126 L F
.5544 .66684 m .55619 .67114 L .53356 .67707 L 1 1 0 r
F
.57568 .65833 m .55619 .67114 L .5544 .66684 L F
.57568 .65833 m .57839 .66278 L .55619 .67114 L F
.3626 .4187 m .34656 .40894 L .35567 .40836 L .852 .752 0 r
F
.37131 .41762 m .3626 .4187 L .35567 .40836 L .834 .742 0 r
F
.53005 .46205 m .52203 .46222 L .52116 .4593 L .236 .206 0 r
F
.53005 .46205 m .53189 .46515 L .52203 .46222 L F
.46524 .68183 m .46326 .68629 L .44013 .68398 L .893 .894 0 r
F
.48787 .68224 m .46326 .68629 L .46524 .68183 L .923 .919 0 r
F
.53271 .67278 m .53356 .67707 L .51071 .68071 L 1 .983 0 r
F
.5544 .66684 m .53356 .67707 L .53271 .67278 L 1 1 0 r
F
.38208 .68669 m .35359 .6826 L .35904 .67863 L .92 .864 0 r
F
.38672 .68248 m .38208 .68669 L .35904 .67863 L .907 .861 0 r
F
.68975 .60697 m .67725 .62744 L .67113 .622 L 1 .843 0 r
F
.68975 .60697 m .69662 .61225 L .67725 .62744 L F
.59632 .64721 m .57839 .66278 L .57568 .65833 L 1 1 0 r
F
.59632 .64721 m .59995 .65203 L .57839 .66278 L F
.32836 .4104 m .31254 .39784 L .32197 .39762 L .908 .769 0 r
F
.33745 .40962 m .32836 .4104 L .32197 .39762 L .895 .761 0 r
F
.42692 .43418 m .4114 .42969 L .41909 .42804 L .696 .701 0 r
F
.43398 .43223 m .42692 .43418 L .41909 .42804 L .667 .682 0 r
F
.44193 .4375 m .42692 .43418 L .43398 .43223 L .643 .679 0 r
F
.72183 .60129 m .71031 .6224 L .70347 .61738 L 1 .834 0 r
F
.72183 .60129 m .72935 .606 L .71031 .6224 L F
.51082 .67638 m .51071 .68071 L .48787 .68224 L .937 .941 0 r
F
.53271 .67278 m .51071 .68071 L .51082 .67638 L 1 .983 0 r
F
.4114 .42969 m .39567 .42389 L .40393 .42261 L .741 .716 0 r
F
.41909 .42804 m .4114 .42969 L .40393 .42261 L .715 .7 0 r
F
.27492 .39951 m .25949 .38282 L .26914 .38289 L .97 .792 0 r
F
.28431 .39899 m .27492 .39951 L .26914 .38289 L .962 .787 0 r
F
.46936 .44135 m .46459 .44396 L .45616 .43984 L .526 .609 0 r
F
.47739 .4449 m .46459 .44396 L .46936 .44135 L .488 .586 0 r
F
.61615 .6339 m .59995 .65203 L .59632 .64721 L 1 .989 0 r
F
.61615 .6339 m .62067 .63927 L .59995 .65203 L F
.44829 .43532 m .44193 .4375 L .43398 .43223 L .614 .658 0 r
F
.45616 .43984 m .44193 .4375 L .44829 .43532 L .585 .649 0 r
F
.65883 .61062 m .6457 .63089 L .64035 .62522 L 1 .862 0 r
F
.65883 .61062 m .66499 .61641 L .6457 .63089 L F
.53879 .46495 m .53189 .46515 L .53005 .46205 L .185 .146 0 r
F
.53879 .46495 m .54158 .46853 L .53189 .46515 L F
.48892 .67788 m .48787 .68224 L .46524 .68183 L .892 .908 0 r
F
.51082 .67638 m .48787 .68224 L .48892 .67788 L .937 .941 0 r
F
.39567 .42389 m .38004 .41665 L .38878 .41581 L .78 .725 0 r
F
.40393 .42261 m .39567 .42389 L .38878 .41581 L .756 .712 0 r
F
.28431 .39899 m .26914 .38289 L .2788 .38302 L .962 .787 0 r
F
.29371 .39853 m .28431 .39899 L .2788 .38302 L .953 .782 0 r
F
.33745 .40962 m .32197 .39762 L .33141 .39749 L .895 .761 0 r
F
.34656 .40894 m .33745 .40962 L .33141 .39749 L .88 .753 0 r
F
.37131 .41762 m .35567 .40836 L .36481 .40788 L .834 .742 0 r
F
.38004 .41665 m .37131 .41762 L .36481 .40788 L .814 .731 0 r
F
.63498 .61937 m .62067 .63927 L .61615 .6339 L 1 .912 0 r
F
.63498 .61937 m .64035 .62522 L .62067 .63927 L F
.57976 .49581 m .57392 .49327 L .56934 .48768 L 0 .024 0 r
F
.57976 .49581 m .58528 .50659 L .57392 .49327 L F
.35359 .6826 m .32494 .67628 L .33116 .6726 L .925 .856 0 r
F
.35904 .67863 m .35359 .6826 L .33116 .6726 L .914 .853 0 r
F
.41386 .68424 m .38672 .68248 L .39138 .67834 L .901 .87 0 r
F
.41766 .67994 m .41386 .68424 L .39138 .67834 L .884 .864 0 r
F
.44013 .68398 m .41386 .68424 L .41766 .67994 L .897 .881 0 r
F
.68286 .60152 m .67113 .622 L .66499 .61641 L 1 .833 0 r
F
.68286 .60152 m .68975 .60697 L .67113 .622 L F
.46176 .43747 m .45616 .43984 L .44829 .43532 L .558 .625 0 r
F
.46936 .44135 m .45616 .43984 L .46176 .43747 L .526 .609 0 r
F
.44304 .67961 m .44013 .68398 L .41766 .67994 L .875 .874 0 r
F
.46524 .68183 m .44013 .68398 L .44304 .67961 L .893 .894 0 r
F
.32494 .67628 m .31873 .67999 L .29649 .66766 L .931 .849 0 r
F
.49646 .44813 m .49442 .45116 L .48577 .44816 L .42 .501 0 r
F
.50434 .45083 m .49442 .45116 L .49646 .44813 L .394 .455 0 r
F
.50434 .45083 m .50326 .45396 L .49442 .45116 L F
.71428 .59647 m .70347 .61738 L .69662 .61225 L 1 .827 0 r
F
.71428 .59647 m .72183 .60129 L .70347 .61738 L F
.5123 .45341 m .50326 .45396 L .50434 .45083 L .363 .402 0 r
F
.5123 .45341 m .5122 .45664 L .50326 .45396 L F
.48876 .44525 m .48577 .44816 L .47739 .4449 L .442 .537 0 r
F
.49646 .44813 m .48577 .44816 L .48876 .44525 L .42 .501 0 r
F
.75453 .59308 m .74435 .61512 L .73686 .6106 L 1 .83 0 r
F
.75453 .59308 m .76265 .59719 L .74435 .61512 L F
.29371 .39853 m .2788 .38302 L .28846 .38323 L .953 .782 0 r
F
.30312 .39815 m .29371 .39853 L .28846 .38323 L .943 .776 0 r
F
.38672 .68248 m .35904 .67863 L .36451 .67471 L .907 .861 0 r
F
.39138 .67834 m .38672 .68248 L .36451 .67471 L .893 .856 0 r
F
.52029 .45591 m .5122 .45664 L .5123 .45341 L .329 .346 0 r
F
.52029 .45591 m .52116 .4593 L .5122 .45664 L F
.41909 .42804 m .40393 .42261 L .4122 .42148 L .715 .7 0 r
F
.42681 .42655 m .41909 .42804 L .4122 .42148 L .687 .682 0 r
F
.43398 .43223 m .41909 .42804 L .42681 .42655 L .667 .682 0 r
F
.56012 .47645 m .55473 .47623 L .55102 .47241 L .024 .069 0 r
F
.56012 .47645 m .56473 .48207 L .55473 .47623 L F
.44106 .43043 m .43398 .43223 L .42681 .42655 L .639 .662 0 r
F
.44829 .43532 m .43398 .43223 L .44106 .43043 L .614 .658 0 r
F
.34656 .40894 m .33141 .39749 L .34085 .39745 L .88 .753 0 r
F
.35567 .40836 m .34656 .40894 L .34085 .39745 L .864 .744 0 r
F
.59085 .5222 m .59652 .54481 L .58333 .527 L .26 .044 0 r
F
.55261 .66285 m .5544 .66684 L .53271 .67278 L 1 1 0 r
F
.57295 .6542 m .5544 .66684 L .55261 .66285 L F
.57295 .6542 m .57568 .65833 L .5544 .66684 L F
.48129 .44215 m .47739 .4449 L .46936 .44135 L .473 .566 0 r
F
.48876 .44525 m .47739 .4449 L .48129 .44215 L .442 .537 0 r
F
.46724 .67748 m .46524 .68183 L .44304 .67961 L .865 .883 0 r
F
.48892 .67788 m .46524 .68183 L .46724 .67748 L .892 .908 0 r
F
.59268 .6426 m .57568 .65833 L .57295 .6542 L 1 1 0 r
F
.59268 .6426 m .59632 .64721 L .57568 .65833 L F
.53186 .66875 m .53271 .67278 L .51082 .67638 L .963 .968 0 r
F
.55261 .66285 m .53271 .67278 L .53186 .66875 L 1 1 0 r
F
.38004 .41665 m .36481 .40788 L .37395 .40753 L .814 .731 0 r
F
.38878 .41581 m .38004 .41665 L .37395 .40753 L .793 .719 0 r
F
.65265 .60456 m .64035 .62522 L .63498 .61937 L 1 .848 0 r
F
.65265 .60456 m .65883 .61062 L .64035 .62522 L F
.5473 .46795 m .54158 .46853 L .53879 .46495 L .156 .113 0 r
F
.5473 .46795 m .55102 .47241 L .54158 .46853 L F
.61162 .62852 m .59632 .64721 L .59268 .6426 L 1 .998 0 r
F
.61162 .62852 m .61615 .6339 L .59632 .64721 L F
.30312 .39815 m .28846 .38323 L .29814 .38351 L .943 .776 0 r
F
.31254 .39784 m .30312 .39815 L .29814 .38351 L .932 .769 0 r
F
.40393 .42261 m .38878 .41581 L .39753 .4151 L .756 .712 0 r
F
.4122 .42148 m .40393 .42261 L .39753 .4151 L .731 .697 0 r
F
.45467 .43328 m .44829 .43532 L .44106 .43043 L .586 .635 0 r
F
.46176 .43747 m .44829 .43532 L .45467 .43328 L .558 .625 0 r
F
.52821 .45837 m .52116 .4593 L .52029 .45591 L .295 .291 0 r
F
.52821 .45837 m .53005 .46205 L .52116 .4593 L F
.51092 .67226 m .51082 .67638 L .48892 .67788 L .892 .924 0 r
F
.53186 .66875 m .51082 .67638 L .51092 .67226 L .963 .968 0 r
F
.67595 .59586 m .66499 .61641 L .65883 .61062 L 1 .821 0 r
F
.67595 .59586 m .68286 .60152 L .66499 .61641 L F
.47414 .43881 m .46936 .44135 L .46176 .43747 L .505 .587 0 r
F
.48129 .44215 m .46936 .44135 L .47414 .43881 L .473 .566 0 r
F
.70672 .59151 m .69662 .61225 L .68975 .60697 L 1 .818 0 r
F
.70672 .59151 m .71428 .59647 L .69662 .61225 L F
.74639 .58889 m .73686 .6106 L .72935 .606 L 1 .824 0 r
F
.74639 .58889 m .75453 .59308 L .73686 .6106 L F
.62959 .61327 m .61615 .6339 L .61162 .62852 L 1 .902 0 r
F
.62959 .61327 m .63498 .61937 L .61615 .6339 L F
.57427 .48731 m .56934 .48768 L .56473 .48207 L .015 .052 0 r
F
.57427 .48731 m .57976 .49581 L .56934 .48768 L F
.23056 .38295 m .22092 .38309 L .21669 .36256 L 1 .805 0 r
F
.35904 .67863 m .33116 .6726 L .3374 .66897 L .914 .853 0 r
F
.36451 .67471 m .35904 .67863 L .3374 .66897 L .903 .849 0 r
F
.35567 .40836 m .34085 .39745 L .35031 .39753 L .864 .744 0 r
F
.36481 .40788 m .35567 .40836 L .35031 .39753 L .846 .735 0 r
F
.32494 .67628 m .29649 .66766 L .30344 .66434 L .931 .849 0 r
F
.33116 .6726 m .32494 .67628 L .30344 .66434 L .922 .846 0 r
F
.31254 .39784 m .29814 .38351 L .30781 .38388 L .932 .769 0 r
F
.32197 .39762 m .31254 .39784 L .30781 .38388 L .92 .762 0 r
F
.48998 .67369 m .48892 .67788 L .46724 .67748 L .852 .892 0 r
F
.51092 .67226 m .48892 .67788 L .48998 .67369 L .892 .924 0 r
F
.41766 .67994 m .39138 .67834 L .39605 .67426 L .884 .864 0 r
F
.42147 .67572 m .41766 .67994 L .39605 .67426 L .865 .857 0 r
F
.44304 .67961 m .41766 .67994 L .42147 .67572 L .875 .874 0 r
F
.23056 .38295 m .21669 .36256 L .22651 .36309 L 1 .805 0 r
F
.24019 .38285 m .23056 .38295 L .22651 .36309 L 1 .801 0 r
F
.53599 .46079 m .53005 .46205 L .52821 .45837 L .267 .245 0 r
F
.53599 .46079 m .53879 .46495 L .53005 .46205 L F
.38878 .41581 m .37395 .40753 L .38311 .40731 L .793 .719 0 r
F
.39753 .4151 m .38878 .41581 L .38311 .40731 L .77 .706 0 r
F
.46738 .43521 m .46176 .43747 L .45467 .43328 L .535 .603 0 r
F
.47414 .43881 m .46176 .43747 L .46738 .43521 L .505 .587 0 r
F
.44596 .67534 m .44304 .67961 L .42147 .67572 L .85 .864 0 r
F
.46724 .67748 m .44304 .67961 L .44596 .67534 L .865 .883 0 r
F
.42681 .42655 m .4122 .42148 L .42049 .42049 L .687 .682 0 r
F
.43454 .4252 m .42681 .42655 L .42049 .42049 L .659 .664 0 r
F
.44106 .43043 m .42681 .42655 L .43454 .4252 L .639 .662 0 r
F
.39138 .67834 m .36451 .67471 L .37 .67085 L .893 .856 0 r
F
.39605 .67426 m .39138 .67834 L .37 .67085 L .878 .85 0 r
F
.64645 .59816 m .63498 .61937 L .62959 .61327 L 1 .829 0 r
F
.64645 .59816 m .65265 .60456 L .63498 .61937 L F
.24019 .38285 m .22651 .36309 L .23633 .36366 L 1 .801 0 r
F
.24984 .38281 m .24019 .38285 L .23633 .36366 L .996 .797 0 r
F
.44816 .42878 m .44106 .43043 L .43454 .4252 L .61 .641 0 r
F
.45467 .43328 m .44106 .43043 L .44816 .42878 L .586 .635 0 r
F
.73823 .5846 m .72935 .606 L .72183 .60129 L 1 .817 0 r
F
.73823 .5846 m .74639 .58889 L .72935 .606 L F
.69914 .58638 m .68975 .60697 L .68286 .60152 L 1 .807 0 r
F
.69914 .58638 m .70672 .59151 L .68975 .60697 L F
.32197 .39762 m .30781 .38388 L .3175 .38434 L .92 .762 0 r
F
.33141 .39749 m .32197 .39762 L .3175 .38434 L .906 .754 0 r
F
.4122 .42148 m .39753 .4151 L .4063 .41453 L .731 .697 0 r
F
.42049 .42049 m .4122 .42148 L .4063 .41453 L .704 .68 0 r
F
.66902 .58993 m .65883 .61062 L .65265 .60456 L 1 .805 0 r
F
.66902 .58993 m .67595 .59586 L .65883 .61062 L F
.36481 .40788 m .35031 .39753 L .35978 .39772 L .846 .735 0 r
F
.37395 .40753 m .36481 .40788 L .35978 .39772 L .826 .724 0 r
F
.49852 .44496 m .49646 .44813 L .48876 .44525 L .422 .499 0 r
F
.50542 .44749 m .49646 .44813 L .49852 .44496 L .403 .466 0 r
F
.50542 .44749 m .50434 .45083 L .49646 .44813 L F
.51241 .44987 m .50434 .45083 L .50542 .44749 L .382 .429 0 r
F
.51241 .44987 m .5123 .45341 L .50434 .45083 L F
.49176 .44227 m .48876 .44525 L .48129 .44215 L .439 .527 0 r
F
.49852 .44496 m .48876 .44525 L .49176 .44227 L .422 .499 0 r
F
.55549 .47081 m .55102 .47241 L .5473 .46795 L .167 .11 0 r
F
.55549 .47081 m .56012 .47645 L .55102 .47241 L F
.24984 .38281 m .23633 .36366 L .24616 .36429 L .996 .797 0 r
F
.25949 .38282 m .24984 .38281 L .24616 .36429 L .989 .792 0 r
F
.46924 .67328 m .46724 .67748 L .44596 .67534 L .831 .869 0 r
F
.48998 .67369 m .46724 .67748 L .46924 .67328 L .852 .892 0 r
F
.57022 .65053 m .57295 .6542 L .55261 .66285 L 1 1 0 r
F
.58904 .63835 m .57295 .6542 L .57022 .65053 L F
.58904 .63835 m .59268 .6426 L .57295 .6542 L F
.55081 .65927 m .55261 .66285 L .53186 .66875 L F
.57022 .65053 m .55261 .66285 L .55081 .65927 L F
.60707 .62312 m .59268 .6426 L .58904 .63835 L F
.60707 .62312 m .61162 .62852 L .59268 .6426 L F
.51941 .45212 m .5123 .45341 L .51241 .44987 L .36 .391 0 r
F
.51941 .45212 m .52029 .45591 L .5123 .45341 L F
.48522 .4394 m .48129 .44215 L .47414 .43881 L .464 .55 0 r
F
.49176 .44227 m .48129 .44215 L .48522 .4394 L .439 .527 0 r
F
.53101 .66504 m .53186 .66875 L .51092 .67226 L .895 .936 0 r
F
.55081 .65927 m .53186 .66875 L .53101 .66504 L 1 1 0 r
F
.46107 .43137 m .45467 .43328 L .44816 .42878 L .56 .613 0 r
F
.46738 .43521 m .45467 .43328 L .46107 .43137 L .535 .603 0 r
F
.62418 .60679 m .61162 .62852 L .60707 .62312 L 1 .885 0 r
F
.62418 .60679 m .62959 .61327 L .61162 .62852 L F
.56877 .47993 m .56473 .48207 L .56012 .47645 L .134 .072 0 r
F
.56877 .47993 m .57427 .48731 L .56473 .48207 L F
.33141 .39749 m .3175 .38434 L .32718 .38489 L .906 .754 0 r
F
.34085 .39745 m .33141 .39749 L .32718 .38489 L .891 .746 0 r
F
.25949 .38282 m .24616 .36429 L .25599 .36498 L .989 .792 0 r
F
.26914 .38289 m .25949 .38282 L .25599 .36498 L .982 .787 0 r
F
.54356 .4631 m .53879 .46495 L .53599 .46079 L .252 .216 0 r
F
.54356 .4631 m .5473 .46795 L .53879 .46495 L F
.36451 .67471 m .3374 .66897 L .34366 .66539 L .903 .849 0 r
F
.37 .67085 m .36451 .67471 L .34366 .66539 L .89 .844 0 r
F
.33116 .6726 m .30344 .66434 L .3104 .66105 L .922 .846 0 r
F
.3374 .66897 m .33116 .6726 L .3104 .66105 L .912 .842 0 r
F
.39753 .4151 m .38311 .40731 L .39229 .40722 L .77 .706 0 r
F
.4063 .41453 m .39753 .4151 L .39229 .40722 L .745 .692 0 r
F
.51102 .66839 m .51092 .67226 L .48998 .67369 L .833 .894 0 r
F
.53101 .66504 m .51092 .67226 L .51102 .66839 L .895 .936 0 r
F
.73006 .58019 m .72183 .60129 L .71428 .59647 L 1 .81 0 r
F
.73006 .58019 m .73823 .5846 L .72183 .60129 L F
.47895 .43633 m .47414 .43881 L .46738 .43521 L .49 .568 0 r
F
.48522 .4394 m .47414 .43881 L .47895 .43633 L .464 .55 0 r
F
.37395 .40753 m .35978 .39772 L .36926 .39803 L .826 .724 0 r
F
.38311 .40731 m .37395 .40753 L .36926 .39803 L .805 .712 0 r
F
.69154 .58105 m .68286 .60152 L .67595 .59586 L 1 .794 0 r
F
.69154 .58105 m .69914 .58638 L .68286 .60152 L F
.52635 .45424 m .52029 .45591 L .51941 .45212 L .339 .354 0 r
F
.52635 .45424 m .52821 .45837 L .52029 .45591 L F
.26914 .38289 m .25599 .36498 L .26582 .36573 L .982 .787 0 r
F
.2788 .38302 m .26914 .38289 L .26582 .36573 L .974 .782 0 r
F
.66207 .58367 m .65265 .60456 L .64645 .59816 L 1 .784 0 r
F
.66207 .58367 m .66902 .58993 L .65265 .60456 L F
.64023 .59127 m .62959 .61327 L .62418 .60679 L 1 .803 0 r
F
.64023 .59127 m .64645 .59816 L .62959 .61327 L F
.43454 .4252 m .42049 .42049 L .4288 .41965 L .659 .664 0 r
F
.44229 .424 m .43454 .4252 L .4288 .41965 L .631 .644 0 r
F
.44816 .42878 m .43454 .4252 L .44229 .424 L .61 .641 0 r
F
.42147 .67572 m .39605 .67426 L .40073 .67025 L .865 .857 0 r
F
.4253 .67159 m .42147 .67572 L .40073 .67025 L .843 .848 0 r
F
.44596 .67534 m .42147 .67572 L .4253 .67159 L .85 .864 0 r
F
.42049 .42049 m .4063 .41453 L .41509 .41411 L .704 .68 0 r
F
.4288 .41965 m .42049 .42049 L .41509 .41411 L .676 .663 0 r
F
.34085 .39745 m .32718 .38489 L .33688 .38555 L .891 .746 0 r
F
.35031 .39753 m .34085 .39745 L .33688 .38555 L .875 .737 0 r
F
.49103 .6697 m .48998 .67369 L .46924 .67328 L .803 .868 0 r
F
.51102 .66839 m .48998 .67369 L .49103 .6697 L .833 .894 0 r
F
.39605 .67426 m .37 .67085 L .37551 .66704 L .878 .85 0 r
F
.40073 .67025 m .39605 .67426 L .37551 .66704 L .861 .844 0 r
F
.2788 .38302 m .26582 .36573 L .27565 .36655 L .974 .782 0 r
F
.28846 .38323 m .2788 .38302 L .27565 .36655 L .965 .776 0 r
F
.44889 .67119 m .44596 .67534 L .4253 .67159 L .822 .852 0 r
F
.46924 .67328 m .44596 .67534 L .44889 .67119 L .831 .869 0 r
F
.45528 .42728 m .44816 .42878 L .44229 .424 L .583 .62 0 r
F
.46107 .43137 m .44816 .42878 L .45528 .42728 L .56 .613 0 r
F
.47303 .43305 m .46738 .43521 L .46107 .43137 L .515 .582 0 r
F
.47895 .43633 m .46738 .43521 L .47303 .43305 L .49 .568 0 r
F
.30344 .66434 m .29649 .66766 L .27624 .65379 L .931 .841 0 r
F
.53317 .45622 m .52821 .45837 L .52635 .45424 L .323 .322 0 r
F
.53317 .45622 m .53599 .46079 L .52821 .45837 L F
.59589 .5113 m .59085 .5222 L .58528 .50659 L .483 .225 0 r
F
.58954 .50001 m .58528 .50659 L .57976 .49581 L .311 .129 0 r
F
.58954 .50001 m .59589 .5113 L .58528 .50659 L F
.72188 .57566 m .71428 .59647 L .70672 .59151 L 1 .801 0 r
F
.72188 .57566 m .73006 .58019 L .71428 .59647 L F
.4063 .41453 m .39229 .40722 L .40147 .40727 L .745 .692 0 r
F
.41509 .41411 m .4063 .41453 L .40147 .40727 L .718 .677 0 r
F
.38311 .40731 m .36926 .39803 L .37875 .39847 L .805 .712 0 r
F
.39229 .40722 m .38311 .40731 L .37875 .39847 L .782 .7 0 r
F
.76993 .57487 m .76265 .59719 L .75453 .59308 L 1 .819 0 r
F
.76993 .57487 m .77861 .5785 L .76265 .59719 L F
.68392 .57549 m .67595 .59586 L .66902 .58993 L 1 .779 0 r
F
.68392 .57549 m .69154 .58105 L .67595 .59586 L F
.28846 .38323 m .27565 .36655 L .28548 .36745 L .965 .776 0 r
F
.29814 .38351 m .28846 .38323 L .28548 .36745 L .955 .77 0 r
F
.35031 .39753 m .33688 .38555 L .34658 .38632 L .875 .737 0 r
F
.35978 .39772 m .35031 .39753 L .34658 .38632 L .857 .727 0 r
F
.60226 .52456 m .59652 .54481 L .59085 .5222 L .923 .404 0 r
F
.59589 .5113 m .60226 .52456 L .59085 .5222 L .483 .225 0 r
F
.55084 .46515 m .5473 .46795 L .54356 .4631 L .257 .211 0 r
F
.55084 .46515 m .55549 .47081 L .5473 .46795 L F
.61875 .5997 m .60707 .62312 L .60252 .61771 L 1 .855 0 r
F
.61875 .5997 m .62418 .60679 L .60707 .62312 L F
.60252 .61771 m .60707 .62312 L .58904 .63835 L 1 1 0 r
F
.56327 .47316 m .56012 .47645 L .55549 .47081 L .222 .147 0 r
F
.56327 .47316 m .56877 .47993 L .56012 .47645 L F
.3374 .66897 m .3104 .66105 L .31738 .65781 L .912 .842 0 r
F
.34366 .66539 m .3374 .66897 L .31738 .65781 L .902 .838 0 r
F
.65509 .57696 m .64645 .59816 L .64023 .59127 L 1 .759 0 r
F
.65509 .57696 m .66207 .58367 L .64645 .59816 L F
.58322 .49045 m .57976 .49581 L .57427 .48731 L .269 .128 0 r
F
.58322 .49045 m .58954 .50001 L .57976 .49581 L F
.58538 .63467 m .58904 .63835 L .57022 .65053 L 1 1 0 r
F
.60252 .61771 m .58904 .63835 L .58538 .63467 L F
.47124 .66923 m .46924 .67328 L .44889 .67119 L .791 .85 0 r
F
.49103 .6697 m .46924 .67328 L .47124 .66923 L .803 .868 0 r
F
.37 .67085 m .34366 .66539 L .34994 .66186 L .89 .844 0 r
F
.37551 .66704 m .37 .67085 L .34994 .66186 L .876 .838 0 r
F
.50058 .44166 m .49852 .44496 L .49176 .44227 L .425 .499 0 r
F
.50651 .44392 m .49852 .44496 L .50058 .44166 L .412 .476 0 r
F
.50651 .44392 m .50542 .44749 L .49852 .44496 L F
.4675 .42958 m .46107 .43137 L .45528 .42728 L .537 .592 0 r
F
.47303 .43305 m .46107 .43137 L .4675 .42958 L .515 .582 0 r
F
.63398 .58367 m .62418 .60679 L .61875 .5997 L 1 .767 0 r
F
.63398 .58367 m .64023 .59127 L .62418 .60679 L F
.56748 .64755 m .57022 .65053 L .55081 .65927 L 1 1 0 r
F
.58538 .63467 m .57022 .65053 L .56748 .64755 L F
.49478 .43923 m .49176 .44227 L .48522 .4394 L .44 .52 0 r
F
.50058 .44166 m .49176 .44227 L .49478 .43923 L .425 .499 0 r
F
.51252 .44604 m .50542 .44749 L .50651 .44392 L .398 .451 0 r
F
.51252 .44604 m .51241 .44987 L .50542 .44749 L F
.29814 .38351 m .28548 .36745 L .29532 .36843 L .955 .77 0 r
F
.30781 .38388 m .29814 .38351 L .29532 .36843 L .944 .763 0 r
F
.549 .65624 m .55081 .65927 L .53101 .66504 L .9 .933 0 r
F
.56748 .64755 m .55081 .65927 L .549 .65624 L 1 1 0 r
F
.48916 .43664 m .48522 .4394 L .47895 .43633 L .459 .537 0 r
F
.49478 .43923 m .48522 .4394 L .48916 .43664 L .44 .52 0 r
F
.53015 .66173 m .53101 .66504 L .51102 .66839 L .796 .873 0 r
F
.549 .65624 m .53101 .66504 L .53015 .66173 L .9 .933 0 r
F
.4288 .41965 m .41509 .41411 L .4239 .41385 L .676 .663 0 r
F
.43713 .41898 m .4288 .41965 L .4239 .41385 L .647 .645 0 r
F
.44229 .424 m .4288 .41965 L .43713 .41898 L .631 .644 0 r
F
.71367 .57098 m .70672 .59151 L .69914 .58638 L 1 .79 0 r
F
.71367 .57098 m .72188 .57566 L .70672 .59151 L F
.53981 .458 m .53599 .46079 L .53317 .45622 L .314 .301 0 r
F
.53981 .458 m .54356 .4631 L .53599 .46079 L F
.76123 .57116 m .75453 .59308 L .74639 .58889 L 1 .813 0 r
F
.76123 .57116 m .76993 .57487 L .75453 .59308 L F
.51853 .44799 m .51241 .44987 L .51252 .44604 L .384 .425 0 r
F
.51853 .44799 m .51941 .45212 L .51241 .44987 L F
.45007 .42297 m .44229 .424 L .43713 .41898 L .602 .624 0 r
F
.45528 .42728 m .44229 .424 L .45007 .42297 L .583 .62 0 r
F
.35978 .39772 m .34658 .38632 L .35629 .38721 L .857 .727 0 r
F
.36926 .39803 m .35978 .39772 L .35629 .38721 L .838 .716 0 r
F
.39229 .40722 m .37875 .39847 L .38825 .39905 L .782 .7 0 r
F
.40147 .40727 m .39229 .40722 L .38825 .39905 L .757 .686 0 r
F
.30344 .66434 m .27624 .65379 L .28387 .65091 L .931 .841 0 r
F
.3104 .66105 m .30344 .66434 L .28387 .65091 L .922 .837 0 r
F
.30781 .38388 m .29532 .36843 L .30516 .3695 L .944 .763 0 r
F
.3175 .38434 m .30781 .38388 L .30516 .3695 L .932 .755 0 r
F
.67628 .56964 m .66902 .58993 L .66207 .58367 L 1 .76 0 r
F
.67628 .56964 m .68392 .57549 L .66902 .58993 L F
.51112 .66481 m .51102 .66839 L .49103 .6697 L .756 .847 0 r
F
.53015 .66173 m .51102 .66839 L .51112 .66481 L .796 .873 0 r
F
.48378 .43389 m .47895 .43633 L .47303 .43305 L .479 .552 0 r
F
.48916 .43664 m .47895 .43633 L .48378 .43389 L .459 .537 0 r
F
.41509 .41411 m .40147 .40727 L .41068 .40748 L .718 .677 0 r
F
.4239 .41385 m .41509 .41411 L .41068 .40748 L .69 .66 0 r
F
.4253 .67159 m .40073 .67025 L .40543 .66632 L .843 .848 0 r
F
.42913 .66756 m .4253 .67159 L .40543 .66632 L .819 .838 0 r
F
.44889 .67119 m .4253 .67159 L .42913 .66756 L .822 .852 0 r
F
.5769 .48212 m .57427 .48731 L .56877 .47993 L .276 .17 0 r
F
.5769 .48212 m .58322 .49045 L .57427 .48731 L F
.64809 .56969 m .64023 .59127 L .63398 .58367 L 1 .727 0 r
F
.64809 .56969 m .65509 .57696 L .64023 .59127 L F
.52449 .44977 m .51941 .45212 L .51853 .44799 L .372 .4 0 r
F
.52449 .44977 m .52635 .45424 L .51941 .45212 L F
.46243 .42592 m .45528 .42728 L .45007 .42297 L .557 .599 0 r
F
.4675 .42958 m .45528 .42728 L .46243 .42592 L .537 .592 0 r
F
.40073 .67025 m .37551 .66704 L .38103 .6633 L .861 .844 0 r
F
.40543 .66632 m .40073 .67025 L .38103 .6633 L .842 .836 0 r
F
.3175 .38434 m .30516 .3695 L .315 .37067 L .932 .755 0 r
F
.32718 .38489 m .3175 .38434 L .315 .37067 L .919 .747 0 r
F
.61328 .59154 m .61875 .5997 L .60252 .61771 L 1 .804 0 r
F
.6277 .57504 m .61875 .5997 L .61328 .59154 L 1 .718 0 r
F
.6277 .57504 m .63398 .58367 L .61875 .5997 L F
.45183 .66717 m .44889 .67119 L .42913 .66756 L .789 .836 0 r
F
.47124 .66923 m .44889 .67119 L .45183 .66717 L .791 .85 0 r
F
.75252 .56735 m .74639 .58889 L .73823 .5846 L 1 .806 0 r
F
.75252 .56735 m .76123 .57116 L .74639 .58889 L F
.36926 .39803 m .35629 .38721 L .36601 .38823 L .838 .716 0 r
F
.37875 .39847 m .36926 .39803 L .36601 .38823 L .816 .705 0 r
F
.4921 .66592 m .49103 .6697 L .47124 .66923 L .744 .834 0 r
F
.51112 .66481 m .49103 .6697 L .4921 .66592 L .756 .847 0 r
F
.47869 .43097 m .47303 .43305 L .4675 .42958 L .498 .564 0 r
F
.48378 .43389 m .47303 .43305 L .47869 .43097 L .479 .552 0 r
F
.60226 .52456 m .60865 .53902 L .59652 .54481 L .923 .404 0 r
F
.59652 .54481 m .58876 .60137 L .58387 .57275 L 1 .52 0 r
F
.59652 .54481 m .6022 .5666 L .58876 .60137 L F
.60865 .53902 m .6022 .5666 L .59652 .54481 L 1 .515 0 r
F
.70545 .56613 m .69914 .58638 L .69154 .58105 L 1 .778 0 r
F
.70545 .56613 m .71367 .57098 L .69914 .58638 L F
.34366 .66539 m .31738 .65781 L .32437 .65462 L .902 .838 0 r
F
.34994 .66186 m .34366 .66539 L .32437 .65462 L .89 .834 0 r
F
.61328 .59154 m .60252 .61771 L .59794 .61228 L 1 .804 0 r
F
.59794 .61228 m .60252 .61771 L .58538 .63467 L 1 1 0 r
F
.55776 .46675 m .55549 .47081 L .55084 .46515 L .287 .235 0 r
F
.55776 .46675 m .56327 .47316 L .55549 .47081 L F
.66862 .56343 m .66207 .58367 L .65509 .57696 L 1 .738 0 r
F
.66862 .56343 m .67628 .56964 L .66207 .58367 L F
.53035 .45136 m .52635 .45424 L .52449 .44977 L .362 .378 0 r
F
.53035 .45136 m .53317 .45622 L .52635 .45424 L F
.40147 .40727 m .38825 .39905 L .39776 .39978 L .757 .686 0 r
F
.41068 .40748 m .40147 .40727 L .39776 .39978 L .73 .671 0 r
F
.54618 .45948 m .54356 .4631 L .53981 .458 L .317 .295 0 r
F
.54618 .45948 m .55084 .46515 L .54356 .4631 L F
.32718 .38489 m .315 .37067 L .32484 .37194 L .919 .747 0 r
F
.33688 .38555 m .32718 .38489 L .32484 .37194 L .904 .739 0 r
F
.37551 .66704 m .34994 .66186 L .35623 .65839 L .876 .838 0 r
F
.38103 .6633 m .37551 .66704 L .35623 .65839 L .86 .832 0 r
F
.43713 .41898 m .4239 .41385 L .43273 .41374 L .647 .645 0 r
F
.44548 .41846 m .43713 .41898 L .43273 .41374 L .618 .625 0 r
F
.45007 .42297 m .43713 .41898 L .44548 .41846 L .602 .624 0 r
F
.64107 .56171 m .63398 .58367 L .6277 .57504 L 1 .689 0 r
F
.64107 .56171 m .64809 .56969 L .63398 .58367 L F
.47395 .4279 m .4675 .42958 L .46243 .42592 L .517 .572 0 r
F
.47869 .43097 m .4675 .42958 L .47395 .4279 L .498 .564 0 r
F
.58173 .63205 m .58538 .63467 L .56748 .64755 L 1 1 0 r
F
.59794 .61228 m .58538 .63467 L .58173 .63205 L F
.4239 .41385 m .41068 .40748 L .4199 .40784 L .69 .66 0 r
F
.43273 .41374 m .4239 .41385 L .4199 .40784 L .661 .643 0 r
F
.57057 .47462 m .56877 .47993 L .56327 .47316 L .303 .227 0 r
F
.57057 .47462 m .5769 .48212 L .56877 .47993 L F
.3104 .66105 m .28387 .65091 L .29151 .64806 L .922 .837 0 r
F
.31738 .65781 m .3104 .66105 L .29151 .64806 L .913 .833 0 r
F
.37875 .39847 m .36601 .38823 L .37574 .38939 L .816 .705 0 r
F
.38825 .39905 m .37875 .39847 L .37574 .38939 L .793 .692 0 r
F
.22651 .36309 m .21669 .36256 L .21547 .34155 L 1 .803 0 r
F
.7438 .56345 m .73823 .5846 L .73006 .58019 L 1 .799 0 r
F
.7438 .56345 m .75252 .56735 L .73823 .5846 L F
.45787 .42208 m .45007 .42297 L .44548 .41846 L .575 .603 0 r
F
.46243 .42592 m .45007 .42297 L .45787 .42208 L .557 .599 0 r
F
.47326 .66536 m .47124 .66923 L .45183 .66717 L .745 .824 0 r
F
.4921 .66592 m .47124 .66923 L .47326 .66536 L .744 .834 0 r
F
.69721 .56107 m .69154 .58105 L .68392 .57549 L 1 .764 0 r
F
.69721 .56107 m .70545 .56613 L .69154 .58105 L F
.60778 .58127 m .61328 .59154 L .59794 .61228 L 1 .723 0 r
F
.62139 .56494 m .61328 .59154 L .60778 .58127 L 1 .657 0 r
F
.62139 .56494 m .6277 .57504 L .61328 .59154 L F
.33688 .38555 m .32484 .37194 L .33469 .37332 L .904 .739 0 r
F
.34658 .38632 m .33688 .38555 L .33469 .37332 L .887 .729 0 r
F
.22651 .36309 m .21547 .34155 L .22538 .34276 L 1 .803 0 r
F
.23633 .36366 m .22651 .36309 L .22538 .34276 L 1 .798 0 r
F
.56474 .64558 m .56748 .64755 L .549 .65624 L .912 .884 0 r
F
.58173 .63205 m .56748 .64755 L .56474 .64558 L 1 1 0 r
F
.50265 .4382 m .50058 .44166 L .49478 .43923 L .43 .501 0 r
F
.50761 .44016 m .50058 .44166 L .50265 .4382 L .422 .485 0 r
F
.50761 .44016 m .50651 .44392 L .50058 .44166 L F
.49781 .4361 m .49478 .43923 L .48916 .43664 L .443 .515 0 r
F
.50265 .4382 m .49478 .43923 L .49781 .4361 L .43 .501 0 r
F
.66094 .55682 m .65509 .57696 L .64809 .56969 L 1 .712 0 r
F
.66094 .55682 m .66862 .56343 L .65509 .57696 L F
.53604 .45272 m .53317 .45622 L .53035 .45136 L .357 .364 0 r
F
.53604 .45272 m .53981 .458 L .53317 .45622 L F
.51262 .44196 m .50651 .44392 L .50761 .44016 L .413 .468 0 r
F
.51262 .44196 m .51252 .44604 L .50651 .44392 L F
.5472 .6539 m .549 .65624 L .53015 .66173 L .712 .761 0 r
F
.56474 .64558 m .549 .65624 L .5472 .6539 L .912 .884 0 r
F
.23633 .36366 m .22538 .34276 L .23529 .34402 L 1 .798 0 r
F
.24616 .36429 m .23633 .36366 L .23529 .34402 L 1 .794 0 r
F
.63402 .55286 m .6277 .57504 L .62139 .56494 L 1 .644 0 r
F
.63402 .55286 m .64107 .56171 L .6277 .57504 L F
.49311 .43385 m .48916 .43664 L .48378 .43389 L .457 .528 0 r
F
.49781 .4361 m .48916 .43664 L .49311 .43385 L .443 .515 0 r
F
.60565 .51059 m .60226 .52456 L .59589 .5113 L .732 .412 0 r
F
.59856 .50041 m .59589 .5113 L .58954 .50001 L .548 .35 0 r
F
.59856 .50041 m .60565 .51059 L .59589 .5113 L F
.5293 .65889 m .53015 .66173 L .51112 .66481 L .663 .757 0 r
F
.5472 .6539 m .53015 .66173 L .5293 .65889 L .712 .761 0 r
F
.41068 .40748 m .39776 .39978 L .40729 .40066 L .73 .671 0 r
F
.4199 .40784 m .41068 .40748 L .40729 .40066 L .702 .655 0 r
F
.61275 .52144 m .60865 .53902 L .60226 .52456 L .92 .48 0 r
F
.60565 .51059 m .61275 .52144 L .60226 .52456 L .732 .412 0 r
F
.6022 .5666 m .59336 .60683 L .58876 .60137 L 1 .61 0 r
F
.6022 .5666 m .60778 .58127 L .59336 .60683 L F
.61503 .55291 m .60778 .58127 L .6022 .5666 L 1 .588 0 r
F
.60865 .53902 m .61503 .55291 L .6022 .5666 L 1 .515 0 r
F
.51764 .44359 m .51252 .44604 L .51262 .44196 L .404 .451 0 r
F
.51764 .44359 m .51853 .44799 L .51252 .44604 L F
.24616 .36429 m .23529 .34402 L .2452 .34534 L 1 .794 0 r
F
.25599 .36498 m .24616 .36429 L .2452 .34534 L 1 .789 0 r
F
.34658 .38632 m .33469 .37332 L .34454 .37483 L .887 .729 0 r
F
.35629 .38721 m .34658 .38632 L .34454 .37483 L .869 .719 0 r
F
.42913 .66756 m .40543 .66632 L .41015 .66248 L .819 .838 0 r
F
.43298 .66364 m .42913 .66756 L .41015 .66248 L .791 .824 0 r
F
.45183 .66717 m .42913 .66756 L .43298 .66364 L .789 .836 0 r
F
.4696 .42469 m .46243 .42592 L .45787 .42208 L .534 .579 0 r
F
.47395 .4279 m .46243 .42592 L .4696 .42469 L .517 .572 0 r
F
.40543 .66632 m .38103 .6633 L .38656 .65964 L .842 .836 0 r
F
.41015 .66248 m .40543 .66632 L .38656 .65964 L .82 .826 0 r
F
.60778 .58127 m .59794 .61228 L .59336 .60683 L 1 .723 0 r
F
.61503 .55291 m .62139 .56494 L .60778 .58127 L 1 .588 0 r
F
.59147 .49112 m .58954 .50001 L .58322 .49045 L .429 .314 0 r
F
.59147 .49112 m .59856 .50041 L .58954 .50001 L F
.73506 .55944 m .73006 .58019 L .72188 .57566 L 1 .79 0 r
F
.73506 .55944 m .7438 .56345 L .73006 .58019 L F
.48862 .43146 m .48378 .43389 L .47869 .43097 L .472 .539 0 r
F
.49311 .43385 m .48378 .43389 L .48862 .43146 L .457 .528 0 r
F
.38825 .39905 m .37574 .38939 L .38547 .39069 L .793 .692 0 r
F
.39776 .39978 m .38825 .39905 L .38547 .39069 L .767 .679 0 r
F
.51123 .66155 m .51112 .66481 L .4921 .66592 L .662 .774 0 r
F
.5293 .65889 m .51112 .66481 L .51123 .66155 L .663 .757 0 r
F
.61275 .52144 m .61986 .53247 L .60865 .53902 L .92 .48 0 r
F
.61986 .53247 m .61503 .55291 L .60865 .53902 L 1 .541 0 r
F
.34994 .66186 m .32437 .65462 L .33138 .65148 L .89 .834 0 r
F
.35623 .65839 m .34994 .66186 L .33138 .65148 L .877 .828 0 r
F
.25599 .36498 m .2452 .34534 L .25511 .34672 L 1 .789 0 r
F
.26582 .36573 m .25599 .36498 L .25511 .34672 L .996 .783 0 r
F
.62695 .54308 m .62139 .56494 L .61503 .55291 L 1 .595 0 r
F
.62695 .54308 m .63402 .55286 L .62139 .56494 L F
.68896 .55578 m .68392 .57549 L .67628 .56964 L 1 .748 0 r
F
.68896 .55578 m .69721 .56107 L .68392 .57549 L F
.59336 .60683 m .59794 .61228 L .58173 .63205 L 1 1 0 r
F
.55224 .46055 m .55084 .46515 L .54618 .45948 L .333 .308 0 r
F
.55224 .46055 m .55776 .46675 L .55084 .46515 L F
.52262 .44504 m .51853 .44799 L .51764 .44359 L .396 .434 0 r
F
.52262 .44504 m .52449 .44977 L .51853 .44799 L F
.61986 .53247 m .62695 .54308 L .61503 .55291 L 1 .541 0 r
F
.65324 .54972 m .64809 .56969 L .64107 .56171 L 1 .682 0 r
F
.65324 .54972 m .66094 .55682 L .64809 .56969 L F
.26582 .36573 m .25511 .34672 L .26502 .34818 L .996 .783 0 r
F
.27565 .36655 m .26582 .36573 L .26502 .34818 L .988 .778 0 r
F
.56425 .46768 m .56327 .47316 L .55776 .46675 L .332 .286 0 r
F
.56425 .46768 m .57057 .47462 L .56327 .47316 L F
.45478 .66329 m .45183 .66717 L .43298 .66364 L .751 .816 0 r
F
.47326 .66536 m .45183 .66717 L .45478 .66329 L .745 .824 0 r
F
.43273 .41374 m .4199 .40784 L .42913 .40836 L .661 .643 0 r
F
.44158 .41381 m .43273 .41374 L .42913 .40836 L .631 .624 0 r
F
.44548 .41846 m .43273 .41374 L .44158 .41381 L .618 .625 0 r
F
.45386 .41811 m .44548 .41846 L .44158 .41381 L .589 .605 0 r
F
.45787 .42208 m .44548 .41846 L .45386 .41811 L .575 .603 0 r
F
.48438 .42895 m .47869 .43097 L .47395 .4279 L .486 .548 0 r
F
.48862 .43146 m .47869 .43097 L .48438 .42895 L .472 .539 0 r
F
.35629 .38721 m .34454 .37483 L .3544 .37647 L .869 .719 0 r
F
.36601 .38823 m .35629 .38721 L .3544 .37647 L .849 .708 0 r
F
.38103 .6633 m .35623 .65839 L .36254 .65498 L .86 .832 0 r
F
.38656 .65964 m .38103 .6633 L .36254 .65498 L .843 .825 0 r
F
.58439 .48268 m .58322 .49045 L .5769 .48212 L .387 .308 0 r
F
.58439 .48268 m .59147 .49112 L .58322 .49045 L F
.31738 .65781 m .29151 .64806 L .29916 .64526 L .913 .833 0 r
F
.32437 .65462 m .31738 .65781 L .29916 .64526 L .903 .829 0 r
F
.49316 .66239 m .4921 .66592 L .47326 .66536 L .675 .786 0 r
F
.51123 .66155 m .4921 .66592 L .49316 .66239 L .662 .774 0 r
F
.54151 .45379 m .53981 .458 L .53604 .45272 L .358 .359 0 r
F
.54151 .45379 m .54618 .45948 L .53981 .458 L F
.27565 .36655 m .26502 .34818 L .27492 .3497 L .988 .778 0 r
F
.28548 .36745 m .27565 .36655 L .27492 .3497 L .979 .771 0 r
F
.28387 .65091 m .27624 .65379 L .25819 .63851 L .933 .833 0 r
F
.7263 .55529 m .72188 .57566 L .71367 .57098 L 1 .78 0 r
F
.7263 .55529 m .73506 .55944 L .72188 .57566 L F
.52751 .44629 m .52449 .44977 L .52262 .44504 L .39 .42 0 r
F
.52751 .44629 m .53035 .45136 L .52449 .44977 L F
.4199 .40784 m .40729 .40066 L .41683 .40169 L .702 .655 0 r
F
.42913 .40836 m .4199 .40784 L .41683 .40169 L .672 .639 0 r
F
.46569 .42135 m .45787 .42208 L .45386 .41811 L .549 .583 0 r
F
.4696 .42469 m .45787 .42208 L .46569 .42135 L .534 .579 0 r
F
.39776 .39978 m .38547 .39069 L .39522 .39214 L .767 .679 0 r
F
.40729 .40066 m .39776 .39978 L .39522 .39214 L .74 .664 0 r
F
.68068 .55022 m .67628 .56964 L .66862 .56343 L 1 .729 0 r
F
.68068 .55022 m .68896 .55578 L .67628 .56964 L F
.28548 .36745 m .27492 .3497 L .28482 .35131 L .979 .771 0 r
F
.29532 .36843 m .28548 .36745 L .28482 .35131 L .97 .764 0 r
F
.64552 .54208 m .64107 .56171 L .63402 .55286 L 1 .648 0 r
F
.64552 .54208 m .65324 .54972 L .64107 .56171 L F
.48042 .42632 m .47395 .4279 L .4696 .42469 L .5 .555 0 r
F
.48438 .42895 m .47395 .4279 L .48042 .42632 L .486 .548 0 r
F
.36601 .38823 m .3544 .37647 L .36426 .37824 L .849 .708 0 r
F
.37574 .38939 m .36601 .38823 L .36426 .37824 L .827 .696 0 r
F
.78289 .55604 m .77861 .5785 L .76993 .57487 L 1 .811 0 r
F
.78289 .55604 m .79205 .55913 L .77861 .5785 L F
.29532 .36843 m .28482 .35131 L .29473 .35302 L .97 .764 0 r
F
.30516 .3695 m .29532 .36843 L .29473 .35302 L .959 .757 0 r
F
.57808 .63153 m .57877 .63441 L .56474 .64558 L 1 .836 0 r
F
.57808 .63153 m .56474 .64558 L .56466 .64556 L F
.5706 .63784 m .56466 .64556 L .562 .64509 L F
.57808 .63153 m .56466 .64556 L .5706 .63784 L F
.57446 .63548 m .57808 .63153 L .57209 .63659 L 0 0 0 r
F
.57446 .63548 m .57209 .63659 L .562 .64509 L F
.57701 .63429 m .57446 .63548 L .57088 .64677 L F
.57736 .62855 m .57745 .62891 L .57446 .63548 L 1 .986 0 r
F
.57745 .62891 m .57808 .63153 L .57446 .63548 L F
.58876 .60137 m .57808 .63153 L .57736 .62855 L F
.57808 .63153 m .58173 .63205 L .57877 .63441 L 1 .836 0 r
F
.59336 .60683 m .58173 .63205 L .57808 .63153 L 1 1 0 r
F
.58876 .60137 m .59336 .60683 L .57808 .63153 L 1 .986 0 r
F
.58442 .6192 m .57446 .63548 L .57701 .63429 L 0 0 0 r
F
.58442 .6192 m .58876 .60137 L .57691 .62963 L F
.58243 .62244 m .57691 .62963 L .57446 .63548 L F
.58442 .6192 m .57691 .62963 L .58243 .62244 L F
.57731 .47497 m .5769 .48212 L .57057 .47462 L .378 .323 0 r
F
.57731 .47497 m .58439 .48268 L .5769 .48212 L F
.47528 .66168 m .47326 .66536 L .45478 .66329 L .692 .791 0 r
F
.49316 .66239 m .47326 .66536 L .47528 .66168 L .675 .786 0 r
F
.63778 .53389 m .63402 .55286 L .62695 .54308 L 1 .612 0 r
F
.63778 .53389 m .64552 .54208 L .63402 .55286 L F
.71753 .551 m .71367 .57098 L .70545 .56613 L 1 .769 0 r
F
.71753 .551 m .7263 .55529 L .71367 .57098 L F
.30516 .3695 m .29473 .35302 L .30463 .35481 L .959 .757 0 r
F
.315 .37067 m .30516 .3695 L .30463 .35481 L .947 .749 0 r
F
.53226 .44731 m .53035 .45136 L .52751 .44629 L .387 .41 0 r
F
.53226 .44731 m .53604 .45272 L .53035 .45136 L F
.67239 .54435 m .66862 .56343 L .66094 .55682 L 1 .708 0 r
F
.67239 .54435 m .68068 .55022 L .66862 .56343 L F
.35623 .65839 m .33138 .65148 L .33841 .64839 L .877 .828 0 r
F
.36254 .65498 m .35623 .65839 L .33841 .64839 L .863 .822 0 r
F
.44158 .41381 m .42913 .40836 L .43839 .40904 L .631 .624 0 r
F
.45044 .41403 m .44158 .41381 L .43839 .40904 L .601 .605 0 r
F
.45386 .41811 m .44158 .41381 L .45044 .41403 L .589 .605 0 r
F
.55791 .46112 m .55776 .46675 L .55224 .46055 L .36 .339 0 r
F
.55791 .46112 m .56425 .46768 L .55776 .46675 L F
.4768 .42358 m .4696 .42469 L .46569 .42135 L .513 .56 0 r
F
.48042 .42632 m .4696 .42469 L .4768 .42358 L .5 .555 0 r
F
.37574 .38939 m .36426 .37824 L .37412 .38015 L .827 .696 0 r
F
.38547 .39069 m .37574 .38939 L .37412 .38015 L .803 .683 0 r
F
.40729 .40066 m .39522 .39214 L .40497 .39373 L .74 .664 0 r
F
.41683 .40169 m .40729 .40066 L .40497 .39373 L .711 .649 0 r
F
.50474 .43461 m .50265 .4382 L .49781 .4361 L .439 .503 0 r
F
.50871 .43621 m .50265 .4382 L .50474 .43461 L .431 .493 0 r
F
.50871 .43621 m .50761 .44016 L .50265 .4382 L F
.5467 .4545 m .54618 .45948 L .54151 .45379 L .367 .366 0 r
F
.5467 .4545 m .55224 .46055 L .54618 .45948 L F
.41015 .66248 m .38656 .65964 L .39212 .65605 L .82 .826 0 r
F
.41488 .65873 m .41015 .66248 L .39212 .65605 L .796 .815 0 r
F
.43298 .66364 m .41015 .66248 L .41488 .65873 L .791 .824 0 r
F
.50085 .43287 m .49781 .4361 L .49311 .43385 L .448 .512 0 r
F
.50474 .43461 m .49781 .4361 L .50085 .43287 L .439 .503 0 r
F
.63003 .52521 m .62695 .54308 L .61986 .53247 L .999 .574 0 r
F
.63003 .52521 m .63778 .53389 L .62695 .54308 L F
.77371 .55287 m .76993 .57487 L .76123 .57116 L 1 .805 0 r
F
.77371 .55287 m .78289 .55604 L .76993 .57487 L F
.562 .64509 m .56474 .64558 L .5472 .6539 L .593 .34 0 r
F
.43685 .65984 m .43298 .66364 L .41488 .65873 L .76 .808 0 r
F
.45478 .66329 m .43298 .66364 L .43685 .65984 L .751 .816 0 r
F
.51273 .43767 m .50761 .44016 L .50871 .43621 L .424 .482 0 r
F
.51273 .43767 m .51262 .44196 L .50761 .44016 L F
.315 .37067 m .30463 .35481 L .31453 .35672 L .947 .749 0 r
F
.32484 .37194 m .315 .37067 L .31453 .35672 L .933 .74 0 r
F
.46225 .41792 m .45386 .41811 L .45044 .41403 L .561 .585 0 r
F
.46569 .42135 m .45386 .41811 L .46225 .41792 L .549 .583 0 r
F
.28387 .65091 m .25819 .63851 L .26643 .63611 L .933 .833 0 r
F
.29151 .64806 m .28387 .65091 L .26643 .63611 L .925 .829 0 r
F
.49709 .43101 m .49311 .43385 L .48862 .43146 L .457 .521 0 r
F
.50085 .43287 m .49311 .43385 L .49709 .43101 L .448 .512 0 r
F
.42913 .40836 m .41683 .40169 L .42638 .40288 L .672 .639 0 r
F
.43839 .40904 m .42913 .40836 L .42638 .40288 L .641 .621 0 r
F
.32437 .65462 m .29916 .64526 L .30684 .64251 L .903 .829 0 r
F
.33138 .65148 m .32437 .65462 L .30684 .64251 L .892 .825 0 r
F
.62226 .5162 m .61986 .53247 L .61275 .52144 L .912 .534 0 r
F
.62226 .5162 m .63003 .52521 L .61986 .53247 L F
.54539 .65243 m .5472 .6539 L .5293 .65889 L .536 .424 0 r
F
.562 .64509 m .5472 .6539 L .54539 .65243 L .593 .34 0 r
F
.61449 .50711 m .61275 .52144 L .60565 .51059 L .803 .495 0 r
F
.61449 .50711 m .62226 .5162 L .61275 .52144 L F
.51675 .43898 m .51262 .44196 L .51273 .43767 L .419 .47 0 r
F
.51675 .43898 m .51764 .44359 L .51262 .44196 L F
.52844 .65658 m .5293 .65889 L .51123 .66155 L .533 .573 0 r
F
.54539 .65243 m .5293 .65889 L .52844 .65658 L .536 .424 0 r
F
.49349 .42904 m .48862 .43146 L .48438 .42895 L .467 .528 0 r
F
.49709 .43101 m .48862 .43146 L .49349 .42904 L .457 .521 0 r
F
.60672 .49821 m .60565 .51059 L .59856 .50041 L .686 .457 0 r
F
.60672 .49821 m .61449 .50711 L .60565 .51059 L F
.38656 .65964 m .36254 .65498 L .36887 .65164 L .843 .825 0 r
F
.39212 .65605 m .38656 .65964 L .36887 .65164 L .824 .816 0 r
F
.32484 .37194 m .31453 .35672 L .32442 .35874 L .933 .74 0 r
F
.33469 .37332 m .32484 .37194 L .32442 .35874 L .918 .731 0 r
F
.70875 .54654 m .70545 .56613 L .69721 .56107 L 1 .757 0 r
F
.70875 .54654 m .71753 .551 L .70545 .56613 L F
.57023 .46781 m .57057 .47462 L .56425 .46768 L .382 .35 0 r
F
.57023 .46781 m .57731 .47497 L .57057 .47462 L F
.66408 .53814 m .66094 .55682 L .65324 .54972 L 1 .684 0 r
F
.66408 .53814 m .67239 .54435 L .66094 .55682 L F
.51133 .65866 m .51123 .66155 L .49316 .66239 L .558 .671 0 r
F
.52844 .65658 m .51123 .66155 L .51133 .65866 L .533 .573 0 r
F
.38547 .39069 m .37412 .38015 L .38399 .38222 L .803 .683 0 r
F
.39522 .39214 m .38547 .39069 L .38399 .38222 L .776 .67 0 r
F
.53682 .44808 m .53604 .45272 L .53226 .44731 L .387 .406 0 r
F
.53682 .44808 m .54151 .45379 L .53604 .45272 L F
.52074 .44011 m .51764 .44359 L .51675 .43898 L .414 .46 0 r
F
.52074 .44011 m .52262 .44504 L .51764 .44359 L F
.45774 .65956 m .45478 .66329 L .43685 .65984 L .709 .791 0 r
F
.47528 .66168 m .45478 .66329 L .45774 .65956 L .692 .791 0 r
F
.76452 .54963 m .76123 .57116 L .75252 .56735 L 1 .799 0 r
F
.76452 .54963 m .77371 .55287 L .76123 .57116 L F
.59895 .4897 m .59856 .50041 L .59147 .49112 L .581 .428 0 r
F
.59895 .4897 m .60672 .49821 L .59856 .50041 L F
.47354 .42076 m .46569 .42135 L .46225 .41792 L .525 .564 0 r
F
.4768 .42358 m .46569 .42135 L .47354 .42076 L .513 .56 0 r
F
.49009 .42697 m .48438 .42895 L .48042 .42632 L .477 .534 0 r
F
.49349 .42904 m .48438 .42895 L .49009 .42697 L .467 .528 0 r
F
.33469 .37332 m .32442 .35874 L .33432 .36089 L .918 .731 0 r
F
.34454 .37483 m .33469 .37332 L .33432 .36089 L .901 .721 0 r
F
.41683 .40169 m .40497 .39373 L .41474 .39548 L .711 .649 0 r
F
.42638 .40288 m .41683 .40169 L .41474 .39548 L .68 .633 0 r
F
.49423 .65912 m .49316 .66239 L .47528 .66168 L .598 .723 0 r
F
.51133 .65866 m .49316 .66239 L .49423 .65912 L .558 .671 0 r
F
.65576 .53156 m .65324 .54972 L .64552 .54208 L 1 .659 0 r
F
.65576 .53156 m .66408 .53814 L .65324 .54972 L F
.59118 .48168 m .59147 .49112 L .58439 .48268 L .503 .41 0 r
F
.59118 .48168 m .59895 .4897 L .59147 .49112 L F
.52466 .44106 m .52262 .44504 L .52074 .44011 L .41 .45 0 r
F
.52466 .44106 m .52751 .44629 L .52262 .44504 L F
.69995 .54189 m .69721 .56107 L .68896 .55578 L 1 .743 0 r
F
.69995 .54189 m .70875 .54654 L .69721 .56107 L F
.34454 .37483 m .33432 .36089 L .34422 .36317 L .901 .721 0 r
F
.3544 .37647 m .34454 .37483 L .34422 .36317 L .882 .71 0 r
F
.48692 .42481 m .48042 .42632 L .4768 .42358 L .487 .539 0 r
F
.49009 .42697 m .48042 .42632 L .48692 .42481 L .477 .534 0 r
F
.45044 .41403 m .43839 .40904 L .44766 .40988 L .601 .605 0 r
F
.45933 .41442 m .45044 .41403 L .44766 .40988 L .572 .586 0 r
F
.46225 .41792 m .45044 .41403 L .45933 .41442 L .561 .585 0 r
F
.55156 .45481 m .55224 .46055 L .5467 .4545 L .383 .384 0 r
F
.55156 .45481 m .55791 .46112 L .55224 .46055 L F
.39522 .39214 m .38399 .38222 L .39387 .38443 L .776 .67 0 r
F
.40497 .39373 m .39522 .39214 L .39387 .38443 L .748 .656 0 r
F
.43839 .40904 m .42638 .40288 L .43595 .40422 L .641 .621 0 r
F
.44766 .40988 m .43839 .40904 L .43595 .40422 L .61 .603 0 r
F
.75532 .54629 m .75252 .56735 L .7438 .56345 L 1 .792 0 r
F
.75532 .54629 m .76452 .54963 L .75252 .56735 L F
.29151 .64806 m .26643 .63611 L .27468 .63375 L .925 .829 0 r
F
.29916 .64526 m .29151 .64806 L .27468 .63375 L .917 .826 0 r
F
.36254 .65498 m .33841 .64839 L .34546 .64537 L .863 .822 0 r
F
.36887 .65164 m .36254 .65498 L .34546 .64537 L .847 .815 0 r
F
.56314 .46108 m .56425 .46768 L .55791 .46112 L .391 .38 0 r
F
.56314 .46108 m .57023 .46781 L .56425 .46768 L F
.64742 .5246 m .64552 .54208 L .63778 .53389 L 1 .631 0 r
F
.64742 .5246 m .65576 .53156 L .64552 .54208 L F
.54115 .44854 m .54151 .45379 L .53682 .44808 L .392 .409 0 r
F
.54115 .44854 m .5467 .4545 L .54151 .45379 L F
.33138 .65148 m .30684 .64251 L .31453 .6398 L .892 .825 0 r
F
.33841 .64839 m .33138 .65148 L .31453 .6398 L .88 .819 0 r
F
.47068 .41787 m .46225 .41792 L .45933 .41442 L .536 .566 0 r
F
.47354 .42076 m .46225 .41792 L .47068 .41787 L .525 .564 0 r
F
.3544 .37647 m .34422 .36317 L .35412 .36558 L .882 .71 0 r
F
.36426 .37824 m .3544 .37647 L .35412 .36558 L .861 .698 0 r
F
.58342 .47416 m .58439 .48268 L .57731 .47497 L .457 .406 0 r
F
.58342 .47416 m .59118 .48168 L .58439 .48268 L F
.52846 .44181 m .52751 .44629 L .52466 .44106 L .408 .444 0 r
F
.52846 .44181 m .53226 .44731 L .52751 .44629 L F
.47731 .65819 m .47528 .66168 L .45774 .65956 L .633 .749 0 r
F
.49423 .65912 m .47528 .66168 L .47731 .65819 L .598 .723 0 r
F
.48402 .42258 m .4768 .42358 L .47354 .42076 L .496 .544 0 r
F
.48692 .42481 m .4768 .42358 L .48402 .42258 L .487 .539 0 r
F
.69113 .53702 m .68896 .55578 L .68068 .55022 L 1 .727 0 r
F
.69113 .53702 m .69995 .54189 L .68896 .55578 L F
.42638 .40288 m .41474 .39548 L .42451 .39737 L .68 .633 0 r
F
.43595 .40422 m .42638 .40288 L .42451 .39737 L .648 .616 0 r
F
.41488 .65873 m .39212 .65605 L .39769 .65256 L .796 .815 0 r
F
.41962 .6551 m .41488 .65873 L .39769 .65256 L .77 .801 0 r
F
.43685 .65984 m .41488 .65873 L .41962 .6551 L .76 .808 0 r
F
.74611 .54285 m .7438 .56345 L .73506 .55944 L 1 .784 0 r
F
.74611 .54285 m .75532 .54629 L .7438 .56345 L F
.63906 .51731 m .63778 .53389 L .63003 .52521 L .962 .603 0 r
F
.63906 .51731 m .64742 .5246 L .63778 .53389 L F
.40497 .39373 m .39387 .38443 L .40375 .38678 L .748 .656 0 r
F
.41474 .39548 m .40497 .39373 L .40375 .38678 L .717 .641 0 r
F
.44072 .65617 m .43685 .65984 L .41962 .6551 L .725 .789 0 r
F
.45774 .65956 m .43685 .65984 L .44072 .65617 L .709 .791 0 r
F
.36426 .37824 m .35412 .36558 L .36402 .36815 L .861 .698 0 r
F
.37412 .38015 m .36426 .37824 L .36402 .36815 L .837 .686 0 r
F
.39212 .65605 m .36887 .65164 L .37521 .64837 L .824 .816 0 r
F
.39769 .65256 m .39212 .65605 L .37521 .64837 L .803 .806 0 r
F
.50683 .43089 m .50474 .43461 L .50085 .43287 L .448 .505 0 r
F
.50981 .43212 m .50474 .43461 L .50683 .43089 L .442 .499 0 r
F
.50981 .43212 m .50871 .43621 L .50474 .43461 L F
.50391 .42956 m .50085 .43287 L .49709 .43101 L .453 .511 0 r
F
.50683 .43089 m .50085 .43287 L .50391 .42956 L .448 .505 0 r
F
.6307 .50974 m .63003 .52521 L .62226 .5162 L .901 .574 0 r
F
.6307 .50974 m .63906 .51731 L .63003 .52521 L F
.51283 .43322 m .50871 .43621 L .50981 .43212 L .437 .492 0 r
F
.51283 .43322 m .51273 .43767 L .50871 .43621 L F
.50108 .42813 m .49709 .43101 L .49349 .42904 L .459 .516 0 r
F
.50391 .42956 m .49709 .43101 L .50108 .42813 L .453 .511 0 r
F
.68231 .53192 m .68068 .55022 L .67239 .54435 L 1 .71 0 r
F
.68231 .53192 m .69113 .53702 L .68068 .55022 L F
.57565 .4671 m .57731 .47497 L .57023 .46781 L .434 .411 0 r
F
.57565 .4671 m .58342 .47416 L .57731 .47497 L F
.53212 .44235 m .53226 .44731 L .52846 .44181 L .408 .441 0 r
F
.53212 .44235 m .53682 .44808 L .53226 .44731 L F
.48141 .42029 m .47354 .42076 L .47068 .41787 L .505 .547 0 r
F
.48402 .42258 m .47354 .42076 L .48141 .42029 L .496 .544 0 r
F
.44766 .40988 m .43595 .40422 L .44554 .40572 L .61 .603 0 r
F
.45695 .41088 m .44766 .40988 L .44554 .40572 L .58 .584 0 r
F
.45933 .41442 m .44766 .40988 L .45695 .41088 L .572 .586 0 r
F
.62233 .50202 m .62226 .5162 L .61449 .50711 L .827 .546 0 r
F
.62233 .50202 m .6307 .50974 L .62226 .5162 L F
.51586 .4342 m .51273 .43767 L .51283 .43322 L .432 .485 0 r
F
.51586 .4342 m .51675 .43898 L .51273 .43767 L F
.37412 .38015 m .36402 .36815 L .37392 .37087 L .837 .686 0 r
F
.38399 .38222 m .37412 .38015 L .37392 .37087 L .811 .673 0 r
F
.49837 .42662 m .49349 .42904 L .49009 .42697 L .465 .52 0 r
F
.50108 .42813 m .49349 .42904 L .49837 .42662 L .459 .516 0 r
F
.73688 .5393 m .73506 .55944 L .7263 .55529 L 1 .775 0 r
F
.73688 .5393 m .74611 .54285 L .73506 .55944 L F
.46824 .41495 m .45933 .41442 L .45695 .41088 L .544 .567 0 r
F
.47068 .41787 m .45933 .41442 L .46824 .41495 L .536 .566 0 r
F
.29916 .64526 m .27468 .63375 L .28295 .63143 L .917 .826 0 r
F
.30684 .64251 m .29916 .64526 L .28295 .63143 L .907 .821 0 r
F
.55604 .45467 m .55791 .46112 L .55156 .45481 L .402 .41 0 r
F
.55604 .45467 m .56314 .46108 L .55791 .46112 L F
.54519 .44869 m .5467 .4545 L .54115 .44854 L .401 .42 0 r
F
.54519 .44869 m .55156 .45481 L .5467 .4545 L F
.55926 .64656 m .562 .64509 L .54829 .65115 L 0 0 0 r
F
.54846 .65113 m .54829 .65115 L .54539 .65243 L F
.55926 .64656 m .54829 .65115 L .54846 .65113 L F
.55926 .64656 m .54539 .65243 L .54357 .6519 L F
.5499 .65096 m .54357 .6519 L .54175 .65221 L .144 0 0 r
F
.55652 .64995 m .54946 .65102 L .5499 .65096 L F
.54946 .65102 m .54357 .6519 L .5499 .65096 L F
.57446 .63548 m .562 .64509 L .55926 .64656 L 0 0 0 r
F
.41474 .39548 m .40375 .38678 L .41364 .38928 L .717 .641 0 r
F
.42451 .39737 m .41474 .39548 L .41364 .38928 L .685 .625 0 r
F
.61395 .4943 m .61449 .50711 L .60672 .49821 L .747 .519 0 r
F
.61395 .4943 m .62233 .50202 L .61449 .50711 L F
.43595 .40422 m .42451 .39737 L .4343 .39941 L .648 .616 0 r
F
.44554 .40572 m .43595 .40422 L .4343 .39941 L .616 .599 0 r
F
.46071 .65601 m .45774 .65956 L .44072 .65617 L .663 .762 0 r
F
.47731 .65819 m .45774 .65956 L .46071 .65601 L .633 .749 0 r
F
.54357 .6519 m .54539 .65243 L .52844 .65658 L .356 .149 0 r
F
.22538 .34276 m .21547 .34155 L .21733 .32023 L 1 .801 0 r
F
.51886 .43503 m .51675 .43898 L .51586 .4342 L .428 .478 0 r
F
.51886 .43503 m .52074 .44011 L .51675 .43898 L F
.52757 .65482 m .52844 .65658 L .51133 .65866 L .441 .339 0 r
F
.54357 .6519 m .52844 .65658 L .52757 .65482 L .356 .149 0 r
F
.49582 .42503 m .49009 .42697 L .48692 .42481 L .471 .524 0 r
F
.49837 .42662 m .49009 .42697 L .49582 .42503 L .465 .52 0 r
F
.22538 .34276 m .21733 .32023 L .22723 .32214 L 1 .801 0 r
F
.23529 .34402 m .22538 .34276 L .22723 .32214 L 1 .797 0 r
F
.23529 .34402 m .22723 .32214 L .23713 .3241 L F
.2452 .34534 m .23529 .34402 L .23713 .3241 L 1 .792 0 r
F
.2452 .34534 m .23713 .3241 L .24702 .32612 L F
.25511 .34672 m .2452 .34534 L .24702 .32612 L 1 .786 0 r
F
.67346 .52656 m .67239 .54435 L .66408 .53814 L 1 .691 0 r
F
.67346 .52656 m .68231 .53192 L .67239 .54435 L F
.51143 .65613 m .51133 .65866 L .49423 .65912 L .486 .54 0 r
F
.52757 .65482 m .51133 .65866 L .51143 .65613 L .441 .339 0 r
F
.25511 .34672 m .24702 .32612 L .2569 .3282 L 1 .786 0 r
F
.26502 .34818 m .25511 .34672 L .2569 .3282 L 1 .781 0 r
F
.60557 .48671 m .60672 .49821 L .59895 .4897 L .666 .496 0 r
F
.60557 .48671 m .61395 .4943 L .60672 .49821 L F
.33841 .64839 m .31453 .6398 L .32223 .63716 L .88 .819 0 r
F
.34546 .64537 m .33841 .64839 L .32223 .63716 L .867 .813 0 r
F
.38399 .38222 m .37392 .37087 L .38383 .37373 L .811 .673 0 r
F
.39387 .38443 m .38399 .38222 L .38383 .37373 L .783 .66 0 r
F
.36887 .65164 m .34546 .64537 L .35253 .64241 L .847 .815 0 r
F
.37521 .64837 m .36887 .65164 L .35253 .64241 L .83 .807 0 r
F
.26502 .34818 m .2569 .3282 L .26678 .33037 L 1 .781 0 r
F
.27492 .3497 m .26502 .34818 L .26678 .33037 L 1 .774 0 r
F
.72764 .53563 m .7263 .55529 L .71753 .551 L 1 .765 0 r
F
.72764 .53563 m .73688 .5393 L .7263 .55529 L F
.27492 .3497 m .26678 .33037 L .27666 .33262 L 1 .774 0 r
F
.28482 .35131 m .27492 .3497 L .27666 .33262 L .996 .767 0 r
F
.47912 .41797 m .47068 .41787 L .46824 .41495 L .513 .549 0 r
F
.48141 .42029 m .47068 .41787 L .47912 .41797 L .505 .547 0 r
F
.5218 .43572 m .52074 .44011 L .51886 .43503 L .426 .473 0 r
F
.5218 .43572 m .52466 .44106 L .52074 .44011 L F
.53558 .44265 m .53682 .44808 L .53212 .44235 L .411 .443 0 r
F
.53558 .44265 m .54115 .44854 L .53682 .44808 L F
.56787 .46042 m .57023 .46781 L .56314 .46108 L .427 .424 0 r
F
.56787 .46042 m .57565 .4671 L .57023 .46781 L F
.49344 .42337 m .48692 .42481 L .48402 .42258 L .477 .527 0 r
F
.49582 .42503 m .48692 .42481 L .49344 .42337 L .471 .524 0 r
F
.28482 .35131 m .27666 .33262 L .28653 .33495 L .996 .767 0 r
F
.29473 .35302 m .28482 .35131 L .28653 .33495 L .987 .76 0 r
F
.4953 .65611 m .49423 .65912 L .47731 .65819 L .521 .646 0 r
F
.51143 .65613 m .49423 .65912 L .4953 .65611 L .486 .54 0 r
F
.5972 .47936 m .59895 .4897 L .59118 .48168 L .595 .478 0 r
F
.5972 .47936 m .60557 .48671 L .59895 .4897 L F
.29473 .35302 m .28653 .33495 L .29639 .33739 L .987 .76 0 r
F
.30463 .35481 m .29473 .35302 L .29639 .33739 L .976 .752 0 r
F
.66461 .52093 m .66408 .53814 L .65576 .53156 L 1 .67 0 r
F
.66461 .52093 m .67346 .52656 L .66408 .53814 L F
.26643 .63611 m .25819 .63851 L .24253 .62194 L .938 .826 0 r
F
.42451 .39737 m .41364 .38928 L .42354 .39192 L .685 .625 0 r
F
.4343 .39941 m .42451 .39737 L .42354 .39192 L .652 .609 0 r
F
.30463 .35481 m .29639 .33739 L .30625 .33994 L .976 .752 0 r
F
.31453 .35672 m .30463 .35481 L .30625 .33994 L .963 .743 0 r
F
.39387 .38443 m .38383 .37373 L .39373 .37675 L .783 .66 0 r
F
.40375 .38678 m .39387 .38443 L .39373 .37675 L .753 .645 0 r
F
.52466 .43624 m .52466 .44106 L .5218 .43572 L .424 .469 0 r
F
.52466 .43624 m .52846 .44181 L .52466 .44106 L F
.49126 .42167 m .48402 .42258 L .48141 .42029 L .483 .53 0 r
F
.49344 .42337 m .48402 .42258 L .49126 .42167 L .477 .527 0 r
F
.45695 .41088 m .44554 .40572 L .45514 .40735 L .58 .584 0 r
F
.46627 .41202 m .45695 .41088 L .45514 .40735 L .551 .566 0 r
F
.46824 .41495 m .45695 .41088 L .46627 .41202 L .544 .567 0 r
F
.31453 .35672 m .30625 .33994 L .31611 .34261 L .963 .743 0 r
F
.32442 .35874 m .31453 .35672 L .31611 .34261 L .949 .733 0 r
F
.41962 .6551 m .39769 .65256 L .40327 .64916 L .77 .801 0 r
F
.42438 .65158 m .41962 .6551 L .40327 .64916 L .741 .785 0 r
F
.44072 .65617 m .41962 .6551 L .42438 .65158 L .725 .789 0 r
F
.7184 .53181 m .71753 .551 L .70875 .54654 L 1 .754 0 r
F
.7184 .53181 m .72764 .53563 L .71753 .551 L F
.44554 .40572 m .4343 .39941 L .4441 .40158 L .616 .599 0 r
F
.45514 .40735 m .44554 .40572 L .4441 .40158 L .585 .581 0 r
F
.58882 .4723 m .59118 .48168 L .58342 .47416 L .539 .467 0 r
F
.58882 .4723 m .5972 .47936 L .59118 .48168 L F
.54892 .44849 m .55156 .45481 L .54519 .44869 L .413 .436 0 r
F
.54892 .44849 m .55604 .45467 L .55156 .45481 L F
.65574 .51501 m .65576 .53156 L .64742 .5246 L .975 .649 0 r
F
.65574 .51501 m .66461 .52093 L .65576 .53156 L F
.32442 .35874 m .31611 .34261 L .32596 .3454 L .949 .733 0 r
F
.33432 .36089 m .32442 .35874 L .32596 .3454 L .933 .723 0 r
F
.30684 .64251 m .28295 .63143 L .29124 .62917 L .907 .821 0 r
F
.31453 .6398 m .30684 .64251 L .29124 .62917 L .897 .817 0 r
F
.39769 .65256 m .37521 .64837 L .38158 .6452 L .803 .806 0 r
F
.40327 .64916 m .39769 .65256 L .38158 .6452 L .78 .794 0 r
F
.47934 .65492 m .47731 .65819 L .46071 .65601 L .572 .7 0 r
F
.4953 .65611 m .47731 .65819 L .47934 .65492 L .521 .646 0 r
F
.47718 .41563 m .46824 .41495 L .46627 .41202 L .519 .549 0 r
F
.47912 .41797 m .46824 .41495 L .47718 .41563 L .513 .549 0 r
F
.44461 .65265 m .44072 .65617 L .42438 .65158 L .688 .766 0 r
F
.46071 .65601 m .44072 .65617 L .44461 .65265 L .663 .762 0 r
F
.53882 .44269 m .54115 .44854 L .53558 .44265 L .416 .449 0 r
F
.53882 .44269 m .54519 .44869 L .54115 .44854 L F
.56009 .45405 m .56314 .46108 L .55604 .45467 L .427 .439 0 r
F
.56009 .45405 m .56787 .46042 L .56314 .46108 L F
.33432 .36089 m .32596 .3454 L .3358 .34834 L .933 .723 0 r
F
.34422 .36317 m .33432 .36089 L .3358 .34834 L .916 .712 0 r
F
.79325 .53671 m .79205 .55913 L .78289 .55604 L 1 .806 0 r
F
.79325 .53671 m .80282 .53922 L .79205 .55913 L F
.40375 .38678 m .39373 .37675 L .40364 .37991 L .753 .645 0 r
F
.41364 .38928 m .40375 .38678 L .40364 .37991 L .721 .63 0 r
F
.48931 .41993 m .48141 .42029 L .47912 .41797 L .488 .532 0 r
F
.49126 .42167 m .48141 .42029 L .48931 .41993 L .483 .53 0 r
F
.5274 .4366 m .52846 .44181 L .52466 .43624 L .424 .467 0 r
F
.5274 .4366 m .53212 .44235 L .52846 .44181 L F
.64686 .50884 m .64742 .5246 L .63906 .51731 L .936 .626 0 r
F
.64686 .50884 m .65574 .51501 L .64742 .5246 L F
.70913 .52784 m .70875 .54654 L .69995 .54189 L 1 .742 0 r
F
.70913 .52784 m .7184 .53181 L .70875 .54654 L F
.58044 .46556 m .58342 .47416 L .57565 .4671 L .5 .462 0 r
F
.58044 .46556 m .58882 .4723 L .58342 .47416 L F
.4343 .39941 m .42354 .39192 L .43345 .39467 L .652 .609 0 r
F
.4441 .40158 m .4343 .39941 L .43345 .39467 L .619 .593 0 r
F
.34422 .36317 m .3358 .34834 L .34564 .35143 L .916 .712 0 r
F
.35412 .36558 m .34422 .36317 L .34564 .35143 L .895 .7 0 r
F
.34546 .64537 m .32223 .63716 L .32996 .63457 L .867 .813 0 r
F
.35253 .64241 m .34546 .64537 L .32996 .63457 L .853 .807 0 r
F
.50698 .42618 m .50391 .42956 L .50108 .42813 L .458 .509 0 r
F
.50893 .42708 m .50391 .42956 L .50698 .42618 L .455 .506 0 r
F
.50893 .42708 m .50683 .43089 L .50391 .42956 L F
.51092 .4279 m .50683 .43089 L .50893 .42708 L .452 .503 0 r
F
.51092 .4279 m .50981 .43212 L .50683 .43089 L F
.63797 .50244 m .63906 .51731 L .6307 .50974 L .889 .604 0 r
F
.63797 .50244 m .64686 .50884 L .63906 .51731 L F
.35412 .36558 m .34564 .35143 L .35548 .35467 L .895 .7 0 r
F
.36402 .36815 m .35412 .36558 L .35548 .35467 L .873 .688 0 r
F
.26643 .63611 m .24253 .62194 L .25132 .62007 L .938 .826 0 r
F
.27468 .63375 m .26643 .63611 L .25132 .62007 L .93 .823 0 r
F
.50509 .42521 m .50108 .42813 L .49837 .42662 L .461 .512 0 r
F
.50698 .42618 m .50108 .42813 L .50509 .42521 L .458 .509 0 r
F
.51294 .42864 m .50981 .43212 L .51092 .4279 L .449 .499 0 r
F
.51294 .42864 m .51283 .43322 L .50981 .43212 L F
.78368 .53414 m .78289 .55604 L .77371 .55287 L 1 .801 0 r
F
.78368 .53414 m .79325 .53671 L .78289 .55604 L F
.37521 .64837 m .35253 .64241 L .35961 .63953 L .83 .807 0 r
F
.38158 .6452 m .37521 .64837 L .35961 .63953 L .812 .798 0 r
F
.41364 .38928 m .40364 .37991 L .41356 .38319 L .721 .63 0 r
F
.42354 .39192 m .41364 .38928 L .41356 .38319 L .687 .615 0 r
F
.50328 .42418 m .49837 .42662 L .49582 .42503 L .464 .514 0 r
F
.50509 .42521 m .49837 .42662 L .50328 .42418 L .461 .512 0 r
F
.51496 .42929 m .51283 .43322 L .51294 .42864 L .447 .495 0 r
F
.51496 .42929 m .51586 .4342 L .51283 .43322 L F
.48759 .41818 m .47912 .41797 L .47718 .41563 L .494 .533 0 r
F
.48931 .41993 m .47912 .41797 L .48759 .41818 L .488 .532 0 r
F
.45514 .40735 m .4441 .40158 L .45392 .40387 L .585 .581 0 r
F
.46476 .40911 m .45514 .40735 L .45392 .40387 L .555 .564 0 r
F
.46627 .41202 m .45514 .40735 L .46476 .40911 L .551 .566 0 r
F
.69986 .52369 m .69995 .54189 L .69113 .53702 L 1 .729 0 r
F
.69986 .52369 m .70913 .52784 L .69995 .54189 L F
.62907 .49586 m .6307 .50974 L .62233 .50202 L .835 .582 0 r
F
.62907 .49586 m .63797 .50244 L .6307 .50974 L F
.53 .43678 m .53212 .44235 L .5274 .4366 L .426 .467 0 r
F
.53 .43678 m .53558 .44265 L .53212 .44235 L F
.36402 .36815 m .35548 .35467 L .36532 .35807 L .873 .688 0 r
F
.37392 .37087 m .36402 .36815 L .36532 .35807 L .847 .675 0 r
F
.4756 .41329 m .46627 .41202 L .46476 .40911 L .524 .549 0 r
F
.47718 .41563 m .46627 .41202 L .4756 .41329 L .519 .549 0 r
F
.57206 .45913 m .57565 .4671 L .56787 .46042 L .476 .463 0 r
F
.57206 .45913 m .58044 .46556 L .57565 .4671 L F
.4637 .65262 m .46071 .65601 L .44461 .65265 L .614 .727 0 r
F
.47934 .65492 m .46071 .65601 L .4637 .65262 L .572 .7 0 r
F
.50158 .4231 m .49582 .42503 L .49344 .42337 L .467 .516 0 r
F
.50328 .42418 m .49582 .42503 L .50158 .4231 L .464 .514 0 r
F
.51697 .42984 m .51586 .4342 L .51496 .42929 L .444 .492 0 r
F
.51697 .42984 m .51886 .43503 L .51586 .4342 L F
.5418 .44248 m .54519 .44869 L .53882 .44269 L .425 .458 0 r
F
.5418 .44248 m .54892 .44849 L .54519 .44869 L F
.55229 .44794 m .55604 .45467 L .54892 .44849 L .432 .455 0 r
F
.55229 .44794 m .56009 .45405 L .55604 .45467 L F
.62017 .4892 m .62233 .50202 L .61395 .4943 L .775 .561 0 r
F
.62017 .4892 m .62907 .49586 L .62233 .50202 L F
.77409 .53149 m .77371 .55287 L .76452 .54963 L 1 .795 0 r
F
.77409 .53149 m .78368 .53414 L .77371 .55287 L F
.4441 .40158 m .43345 .39467 L .44337 .39754 L .619 .593 0 r
F
.45392 .40387 m .4441 .40158 L .44337 .39754 L .587 .576 0 r
F
.37392 .37087 m .36532 .35807 L .37516 .36163 L .847 .675 0 r
F
.38383 .37373 m .37392 .37087 L .37516 .36163 L .819 .661 0 r
F
.31453 .6398 m .29124 .62917 L .29954 .62695 L .897 .817 0 r
F
.32223 .63716 m .31453 .6398 L .29954 .62695 L .886 .812 0 r
F
.49999 .42198 m .49344 .42337 L .49126 .42167 L .47 .517 0 r
F
.50158 .4231 m .49344 .42337 L .49999 .42198 L .467 .516 0 r
F
.51893 .43028 m .51886 .43503 L .51697 .42984 L .442 .488 0 r
F
.51893 .43028 m .5218 .43572 L .51886 .43503 L F
.69058 .51935 m .69113 .53702 L .68231 .53192 L 1 .715 0 r
F
.69058 .51935 m .69986 .52369 L .69113 .53702 L F
.61127 .48254 m .61395 .4943 L .60557 .48671 L .712 .541 0 r
F
.61127 .48254 m .62017 .4892 L .61395 .4943 L F
.42354 .39192 m .41356 .38319 L .42348 .38659 L .687 .615 0 r
F
.43345 .39467 m .42354 .39192 L .42348 .38659 L .652 .6 0 r
F
.52671 .65355 m .52757 .65482 L .51143 .65613 L .325 .153 0 r
F
.54175 .65221 m .52757 .65482 L .52671 .65355 L .131 .121 0 r
F
.54175 .65221 m .54357 .6519 L .52916 .65453 L F
.54175 .65221 m .52916 .65453 L .52986 .6544 L F
.53992 .65295 m .54175 .65221 L .52671 .65355 L .045 0 0 r
F
.53786 .6529 m .52671 .65355 L .52584 .65259 L F
.53992 .65295 m .53685 .65309 L .53786 .6529 L F
.53685 .65309 m .52671 .65355 L .53786 .6529 L F
.52986 .6544 m .52916 .65453 L .52757 .65482 L .131 .121 0 r
F
.51154 .65393 m .51143 .65613 L .4953 .65611 L .422 .402 0 r
F
.52671 .65355 m .51143 .65613 L .51154 .65393 L .325 .153 0 r
F
.48613 .41642 m .47718 .41563 L .4756 .41329 L .498 .534 0 r
F
.48759 .41818 m .47718 .41563 L .48613 .41642 L .494 .533 0 r
F
.57088 .64677 m .57446 .63548 L .55926 .64656 L .316 0 0 r
F
.53243 .43678 m .53558 .44265 L .53 .43678 L .431 .471 0 r
F
.53243 .43678 m .53882 .44269 L .53558 .44265 L F
.38383 .37373 m .37516 .36163 L .38499 .36535 L .819 .661 0 r
F
.39373 .37675 m .38383 .37373 L .38499 .36535 L .789 .647 0 r
F
.60237 .47596 m .60557 .48671 L .5972 .47936 L .652 .524 0 r
F
.60237 .47596 m .61127 .48254 L .60557 .48671 L F
.49853 .42083 m .49126 .42167 L .48931 .41993 L .473 .519 0 r
F
.49999 .42198 m .49126 .42167 L .49853 .42083 L .47 .517 0 r
F
.55652 .64995 m .55926 .64656 L .54357 .6519 L .144 0 0 r
F
.56367 .45296 m .56787 .46042 L .56009 .45405 L .463 .468 0 r
F
.56367 .45296 m .57206 .45913 L .56787 .46042 L F
.52084 .43062 m .5218 .43572 L .51893 .43028 L .441 .486 0 r
F
.52084 .43062 m .52466 .43624 L .5218 .43572 L F
.7645 .52876 m .76452 .54963 L .75532 .54629 L 1 .788 0 r
F
.7645 .52876 m .77409 .53149 L .76452 .54963 L F
.42438 .65158 m .40327 .64916 L .40888 .64588 L .741 .785 0 r
F
.42916 .64819 m .42438 .65158 L .40888 .64588 L .709 .767 0 r
F
.44461 .65265 m .42438 .65158 L .42916 .64819 L .688 .766 0 r
F
.27468 .63375 m .25132 .62007 L .26012 .61824 L .93 .823 0 r
F
.28295 .63143 m .27468 .63375 L .26012 .61824 L .922 .819 0 r
F
.68128 .51481 m .68231 .53192 L .67346 .52656 L .997 .699 0 r
F
.68128 .51481 m .69058 .51935 L .68231 .53192 L F
.49638 .65336 m .4953 .65611 L .47934 .65492 L .472 .561 0 r
F
.51154 .65393 m .4953 .65611 L .49638 .65336 L .422 .402 0 r
F
.40327 .64916 m .38158 .6452 L .38796 .64211 L .78 .794 0 r
F
.40888 .64588 m .40327 .64916 L .38796 .64211 L .755 .781 0 r
F
.57088 .64677 m .55926 .64656 L .55652 .64995 L .316 0 0 r
F
.46476 .40911 m .45392 .40387 L .46375 .40627 L .555 .564 0 r
F
.4744 .41099 m .46476 .40911 L .46375 .40627 L .528 .548 0 r
F
.4756 .41329 m .46476 .40911 L .4744 .41099 L .524 .549 0 r
F
.59346 .46952 m .5972 .47936 L .58882 .4723 L .598 .511 0 r
F
.59346 .46952 m .60237 .47596 L .5972 .47936 L F
.39373 .37675 m .38499 .36535 L .39483 .36922 L .789 .647 0 r
F
.40364 .37991 m .39373 .37675 L .39483 .36922 L .755 .633 0 r
F
.43345 .39467 m .42348 .38659 L .43341 .39008 L .652 .6 0 r
F
.44337 .39754 m .43345 .39467 L .43341 .39008 L .618 .584 0 r
F
.49723 .41966 m .48931 .41993 L .48759 .41818 L .476 .52 0 r
F
.49853 .42083 m .48931 .41993 L .49723 .41966 L .473 .519 0 r
F
.35253 .64241 m .32996 .63457 L .3377 .63206 L .853 .807 0 r
F
.35961 .63953 m .35253 .64241 L .3377 .63206 L .838 .799 0 r
F
.45392 .40387 m .44337 .39754 L .4533 .40049 L .587 .576 0 r
F
.46375 .40627 m .45392 .40387 L .4533 .40049 L .556 .56 0 r
F
.52267 .43084 m .52466 .43624 L .52084 .43062 L .44 .485 0 r
F
.52267 .43084 m .5274 .4366 L .52466 .43624 L F
.54449 .442 m .54892 .44849 L .5418 .44248 L .439 .47 0 r
F
.54449 .442 m .55229 .44794 L .54892 .44849 L F
.7549 .52595 m .75532 .54629 L .74611 .54285 L 1 .781 0 r
F
.7549 .52595 m .7645 .52876 L .75532 .54629 L F
.67197 .51006 m .67346 .52656 L .66461 .52093 L .975 .682 0 r
F
.67197 .51006 m .68128 .51481 L .67346 .52656 L F
.44852 .64927 m .44461 .65265 L .42916 .64819 L .648 .74 0 r
F
.4637 .65262 m .44461 .65265 L .44852 .64927 L .614 .727 0 r
F
.48495 .41468 m .4756 .41329 L .4744 .41099 L .502 .534 0 r
F
.48613 .41642 m .4756 .41329 L .48495 .41468 L .498 .534 0 r
F
.58456 .46328 m .58882 .4723 L .58044 .46556 L .554 .502 0 r
F
.58456 .46328 m .59346 .46952 L .58882 .4723 L F
.53466 .43659 m .53882 .44269 L .53243 .43678 L .437 .476 0 r
F
.53466 .43659 m .5418 .44248 L .53882 .44269 L F
.40364 .37991 m .39483 .36922 L .40466 .37321 L .755 .633 0 r
F
.41356 .38319 m .40364 .37991 L .40466 .37321 L .72 .618 0 r
F
.48138 .65185 m .47934 .65492 L .4637 .65262 L .514 .644 0 r
F
.49638 .65336 m .47934 .65492 L .48138 .65185 L .472 .561 0 r
F
.55527 .44702 m .56009 .45405 L .55229 .44794 L .457 .475 0 r
F
.55527 .44702 m .56367 .45296 L .56009 .45405 L F
.38158 .6452 m .35961 .63953 L .36671 .63673 L .812 .798 0 r
F
.38796 .64211 m .38158 .6452 L .36671 .63673 L .791 .788 0 r
F
.49609 .41848 m .48759 .41818 L .48613 .41642 L .479 .521 0 r
F
.49723 .41966 m .48759 .41818 L .49609 .41848 L .476 .52 0 r
F
.5244 .43094 m .5274 .4366 L .52267 .43084 L .442 .485 0 r
F
.5244 .43094 m .53 .43678 L .5274 .4366 L F
.66266 .50508 m .66461 .52093 L .65574 .51501 L .947 .664 0 r
F
.66266 .50508 m .67197 .51006 L .66461 .52093 L F
.32223 .63716 m .29954 .62695 L .30786 .62479 L .886 .812 0 r
F
.32996 .63457 m .32223 .63716 L .30786 .62479 L .874 .806 0 r
F
.74529 .52303 m .74611 .54285 L .73688 .5393 L 1 .773 0 r
F
.74529 .52303 m .7549 .52595 L .74611 .54285 L F
.44337 .39754 m .43341 .39008 L .44335 .39365 L .618 .584 0 r
F
.4533 .40049 m .44337 .39754 L .44335 .39365 L .585 .569 0 r
F
.57565 .45724 m .58044 .46556 L .57206 .45913 L .521 .496 0 r
F
.57565 .45724 m .58456 .46328 L .58044 .46556 L F
.41356 .38319 m .40466 .37321 L .4145 .37731 L .72 .618 0 r
F
.42348 .38659 m .41356 .38319 L .4145 .37731 L .684 .603 0 r
F
.65333 .49989 m .65574 .51501 L .64686 .50884 L .915 .646 0 r
F
.65333 .49989 m .66266 .50508 L .65574 .51501 L F
.51006 .42274 m .50698 .42618 L .50509 .42521 L .462 .508 0 r
F
.51104 .42319 m .50698 .42618 L .51006 .42274 L .461 .507 0 r
F
.51104 .42319 m .50893 .42708 L .50698 .42618 L F
.51204 .42361 m .50893 .42708 L .51104 .42319 L .459 .506 0 r
F
.51204 .42361 m .51092 .4279 L .50893 .42708 L F
.28295 .63143 m .26012 .61824 L .26893 .61645 L .922 .819 0 r
F
.29124 .62917 m .28295 .63143 L .26893 .61645 L .913 .815 0 r
F
.46375 .40627 m .4533 .40049 L .46325 .40352 L .556 .56 0 r
F
.4736 .40875 m .46375 .40627 L .46325 .40352 L .528 .545 0 r
F
.4744 .41099 m .46375 .40627 L .4736 .40875 L .528 .548 0 r
F
.50911 .42224 m .50509 .42521 L .50328 .42418 L .463 .509 0 r
F
.51006 .42274 m .50509 .42521 L .50911 .42224 L .462 .508 0 r
F
.51305 .42398 m .51092 .4279 L .51204 .42361 L .458 .504 0 r
F
.51305 .42398 m .51294 .42864 L .51092 .4279 L F
.49512 .41731 m .48613 .41642 L .48495 .41468 L .482 .521 0 r
F
.49609 .41848 m .48613 .41642 L .49512 .41731 L .479 .521 0 r
F
.48406 .41297 m .4744 .41099 L .4736 .40875 L .504 .533 0 r
F
.48495 .41468 m .4744 .41099 L .48406 .41297 L .502 .534 0 r
F
.50821 .42172 m .50328 .42418 L .50158 .4231 L .463 .51 0 r
F
.50911 .42224 m .50328 .42418 L .50821 .42172 L .463 .509 0 r
F
.51406 .4243 m .51294 .42864 L .51305 .42398 L .457 .502 0 r
F
.51406 .4243 m .51496 .42929 L .51294 .42864 L F
.73567 .52001 m .73688 .5393 L .72764 .53563 L 1 .764 0 r
F
.73567 .52001 m .74529 .52303 L .73688 .5393 L F
.52602 .43092 m .53 .43678 L .5244 .43094 L .444 .487 0 r
F
.52602 .43092 m .53243 .43678 L .53 .43678 L F
.644 .49449 m .64686 .50884 L .63797 .50244 L .877 .627 0 r
F
.644 .49449 m .65333 .49989 L .64686 .50884 L F
.53668 .43621 m .5418 .44248 L .53466 .43659 L .446 .483 0 r
F
.53668 .43621 m .54449 .442 L .5418 .44248 L F
.50736 .42118 m .50158 .4231 L .49999 .42198 L .464 .51 0 r
F
.50821 .42172 m .50158 .4231 L .50736 .42118 L .463 .51 0 r
F
.54687 .44126 m .55229 .44794 L .54449 .442 L .456 .484 0 r
F
.54687 .44126 m .55527 .44702 L .55229 .44794 L F
.56674 .4514 m .57206 .45913 L .56367 .45296 L .498 .494 0 r
F
.56674 .4514 m .57565 .45724 L .57206 .45913 L F
.51507 .42457 m .51496 .42929 L .51406 .4243 L .455 .5 0 r
F
.51507 .42457 m .51697 .42984 L .51496 .42929 L F
.46669 .64941 m .4637 .65262 L .44852 .64927 L .564 .687 0 r
F
.48138 .65185 m .4637 .65262 L .46669 .64941 L .514 .644 0 r
F
.42348 .38659 m .4145 .37731 L .42435 .38149 L .684 .603 0 r
F
.43341 .39008 m .42348 .38659 L .42435 .38149 L .647 .588 0 r
F
.63467 .48893 m .63797 .50244 L .62907 .49586 L .834 .609 0 r
F
.63467 .48893 m .644 .49449 L .63797 .50244 L F
.4533 .40049 m .44335 .39365 L .4533 .39726 L .585 .569 0 r
F
.46325 .40352 m .4533 .40049 L .4533 .39726 L .554 .555 0 r
F
.50656 .42061 m .49999 .42198 L .49853 .42083 L .465 .511 0 r
F
.50736 .42118 m .49999 .42198 L .50656 .42061 L .464 .51 0 r
F
.51605 .42479 m .51697 .42984 L .51507 .42457 L .454 .499 0 r
F
.51605 .42479 m .51893 .43028 L .51697 .42984 L F
.31611 .34261 m .31004 .32498 L .31974 .32842 L .983 .737 0 r
F
.31611 .34261 m .30625 .33994 L .31004 .32498 L F
.32596 .3454 m .31611 .34261 L .31974 .32842 L .969 .727 0 r
F
.30625 .33994 m .30032 .32167 L .31004 .32498 L .996 .747 0 r
F
.30625 .33994 m .29639 .33739 L .30032 .32167 L F
.32596 .3454 m .31974 .32842 L .32944 .33202 L .969 .727 0 r
F
.3358 .34834 m .32596 .3454 L .32944 .33202 L .952 .715 0 r
F
.53938 .89649 m .54024 .90145 L .50992 .90498 L 1 .967 0 r
F
.56849 .89072 m .54024 .90145 L .53938 .89649 L 1 .981 0 r
F
.56849 .89072 m .57029 .89573 L .54024 .90145 L F
.29639 .33739 m .2906 .31848 L .30032 .32167 L 1 .756 0 r
F
.29639 .33739 m .28653 .33495 L .2906 .31848 L F
.72604 .51687 m .72764 .53563 L .7184 .53181 L 1 .755 0 r
F
.72604 .51687 m .73567 .52001 L .72764 .53563 L F
.3358 .34834 m .32944 .33202 L .33913 .33578 L .952 .715 0 r
F
.34564 .35143 m .3358 .34834 L .33913 .33578 L .932 .703 0 r
F
.62533 .48324 m .62907 .49586 L .62017 .4892 L .787 .591 0 r
F
.62533 .48324 m .63467 .48893 L .62907 .49586 L F
.28653 .33495 m .28087 .31541 L .2906 .31848 L 1 .764 0 r
F
.28653 .33495 m .27666 .33262 L .28087 .31541 L F
.49433 .41615 m .48495 .41468 L .48406 .41297 L .484 .521 0 r
F
.49512 .41731 m .48495 .41468 L .49433 .41615 L .482 .521 0 r
F
.34564 .35143 m .33913 .33578 L .34881 .33971 L .932 .703 0 r
F
.35548 .35467 m .34564 .35143 L .34881 .33971 L .91 .69 0 r
F
.35961 .63953 m .3377 .63206 L .34546 .62961 L .838 .799 0 r
F
.36671 .63673 m .35961 .63953 L .34546 .62961 L .821 .791 0 r
F
.50583 .42003 m .49853 .42083 L .49723 .41966 L .466 .511 0 r
F
.50656 .42061 m .49853 .42083 L .50583 .42003 L .465 .511 0 r
F
.27666 .33262 m .27113 .31244 L .28087 .31541 L 1 .772 0 r
F
.27666 .33262 m .26678 .33037 L .27113 .31244 L F
.517 .42495 m .51893 .43028 L .51605 .42479 L .453 .498 0 r
F
.517 .42495 m .52084 .43062 L .51893 .43028 L F
.52751 .43078 m .53243 .43678 L .52602 .43092 L .448 .49 0 r
F
.52751 .43078 m .53466 .43659 L .53243 .43678 L F
.40888 .64588 m .38796 .64211 L .39436 .63912 L .755 .781 0 r
F
.4145 .6427 m .40888 .64588 L .39436 .63912 L .728 .765 0 r
F
.42916 .64819 m .40888 .64588 L .4145 .6427 L .709 .767 0 r
F
.35548 .35467 m .34881 .33971 L .35849 .34382 L .91 .69 0 r
F
.36532 .35807 m .35548 .35467 L .35849 .34382 L .885 .676 0 r
F
.61598 .47749 m .62017 .4892 L .61127 .48254 L .736 .573 0 r
F
.61598 .47749 m .62533 .48324 L .62017 .4892 L F
.43341 .39008 m .42435 .38149 L .43419 .38572 L .647 .588 0 r
F
.44335 .39365 m .43341 .39008 L .43419 .38572 L .612 .574 0 r
F
.26678 .33037 m .26138 .30956 L .27113 .31244 L 1 .779 0 r
F
.26678 .33037 m .2569 .3282 L .26138 .30956 L F
.51002 .90008 m .50992 .90498 L .4796 .90633 L 1 .947 0 r
F
.53938 .89649 m .50992 .90498 L .51002 .90008 L 1 .967 0 r
F
.55782 .44575 m .56367 .45296 L .55527 .44702 L .482 .495 0 r
F
.55782 .44575 m .56674 .4514 L .56367 .45296 L F
.59708 .88279 m .57029 .89573 L .56849 .89072 L 1 .985 0 r
F
.59708 .88279 m .59982 .88785 L .57029 .89573 L F
.43395 .64493 m .42916 .64819 L .4145 .6427 L .675 .746 0 r
F
.44852 .64927 m .42916 .64819 L .43395 .64493 L .648 .74 0 r
F
.36532 .35807 m .35849 .34382 L .36816 .3481 L .885 .676 0 r
F
.37516 .36163 m .36532 .35807 L .36816 .3481 L .857 .662 0 r
F
.2569 .3282 m .25163 .30677 L .26138 .30956 L 1 .785 0 r
F
.2569 .3282 m .24702 .32612 L .25163 .30677 L F
.60664 .47171 m .61127 .48254 L .60237 .47596 L .686 .558 0 r
F
.60664 .47171 m .61598 .47749 L .61127 .48254 L F
.4736 .40875 m .46325 .40352 L .4732 .4066 L .528 .545 0 r
F
.48347 .41131 m .4736 .40875 L .4732 .4066 L .505 .532 0 r
F
.48406 .41297 m .4736 .40875 L .48347 .41131 L .504 .533 0 r
F
.50518 .41944 m .49723 .41966 L .49609 .41848 L .468 .511 0 r
F
.50583 .42003 m .49723 .41966 L .50518 .41944 L .466 .511 0 r
F
.7164 .51359 m .7184 .53181 L .70913 .52784 L 1 .744 0 r
F
.7164 .51359 m .72604 .51687 L .7184 .53181 L F
.51792 .42506 m .52084 .43062 L .517 .42495 L .453 .497 0 r
F
.51792 .42506 m .52267 .43084 L .52084 .43062 L F
.24702 .32612 m .24186 .30405 L .25163 .30677 L 1 .791 0 r
F
.24702 .32612 m .23713 .3241 L .24186 .30405 L F
.37516 .36163 m .36816 .3481 L .37782 .35256 L .857 .662 0 r
F
.38499 .36535 m .37516 .36163 L .37782 .35256 L .826 .647 0 r
F
.32996 .63457 m .30786 .62479 L .3162 .6227 L .874 .806 0 r
F
.3377 .63206 m .32996 .63457 L .3162 .6227 L .861 .799 0 r
F
.46325 .40352 m .4533 .39726 L .46325 .40091 L .554 .555 0 r
F
.4732 .4066 m .46325 .40352 L .46325 .40091 L .527 .541 0 r
F
.5973 .46598 m .60237 .47596 L .59346 .46952 L .637 .544 0 r
F
.5973 .46598 m .60664 .47171 L .60237 .47596 L F
.53845 .43565 m .54449 .442 L .53668 .43621 L .457 .492 0 r
F
.53845 .43565 m .54687 .44126 L .54449 .442 L F
.23713 .3241 m .23208 .30139 L .24186 .30405 L 1 .796 0 r
F
.23713 .3241 m .22723 .32214 L .23208 .30139 L F
.29124 .62917 m .26893 .61645 L .27776 .61472 L .913 .815 0 r
F
.29954 .62695 m .29124 .62917 L .27776 .61472 L .904 .81 0 r
F
.51164 .65199 m .51154 .65393 L .49638 .65336 L .357 .285 0 r
F
.52584 .65259 m .51154 .65393 L .51164 .65199 L .215 .131 0 r
F
.52584 .65259 m .52671 .65355 L .51154 .65393 L F
.38796 .64211 m .36671 .63673 L .37383 .63402 L .791 .788 0 r
F
.39436 .63912 m .38796 .64211 L .37383 .63402 L .769 .776 0 r
F
.38499 .36535 m .37782 .35256 L .38748 .35719 L .826 .647 0 r
F
.39483 .36922 m .38499 .36535 L .38748 .35719 L .791 .632 0 r
F
.49374 .41502 m .48406 .41297 L .48347 .41131 L .486 .521 0 r
F
.49433 .41615 m .48406 .41297 L .49374 .41502 L .484 .521 0 r
F
.44335 .39365 m .43419 .38572 L .44405 .38998 L .612 .574 0 r
F
.4533 .39726 m .44335 .39365 L .44405 .38998 L .578 .56 0 r
F
.50461 .41885 m .49609 .41848 L .49512 .41731 L .469 .512 0 r
F
.50518 .41944 m .49609 .41848 L .50461 .41885 L .468 .511 0 r
F
.22723 .32214 m .2223 .2988 L .23208 .30139 L 1 .801 0 r
F
.22723 .32214 m .21733 .32023 L .2223 .2988 L F
.51879 .4251 m .52267 .43084 L .51792 .42506 L .453 .497 0 r
F
.51879 .4251 m .5244 .43094 L .52267 .43084 L F
.58795 .46034 m .59346 .46952 L .58456 .46328 L .593 .532 0 r
F
.58795 .46034 m .5973 .46598 L .59346 .46952 L F
.52885 .43051 m .53466 .43659 L .52751 .43078 L .453 .494 0 r
F
.52885 .43051 m .53668 .43621 L .53466 .43659 L F
.70675 .51018 m .70913 .52784 L .69986 .52369 L 1 .733 0 r
F
.70675 .51018 m .7164 .51359 L .70913 .52784 L F
.49746 .65083 m .49638 .65336 L .48138 .65185 L .43 .477 0 r
F
.51164 .65199 m .49638 .65336 L .49746 .65083 L .357 .285 0 r
F
.5489 .44026 m .55527 .44702 L .54687 .44126 L .473 .497 0 r
F
.5489 .44026 m .55782 .44575 L .55527 .44702 L F
.39483 .36922 m .38748 .35719 L .39714 .36195 L .791 .632 0 r
F
.40466 .37321 m .39483 .36922 L .39714 .36195 L .754 .617 0 r
F
.45243 .64605 m .44852 .64927 L .43395 .64493 L .606 .71 0 r
F
.46669 .64941 m .44852 .64927 L .45243 .64605 L .564 .687 0 r
F
.48066 .9015 m .4796 .90633 L .44955 .90553 L .968 .927 0 r
F
.51002 .90008 m .4796 .90633 L .48066 .9015 L 1 .947 0 r
F
.57861 .45481 m .58456 .46328 L .57565 .45724 L .557 .523 0 r
F
.57861 .45481 m .58795 .46034 L .58456 .46328 L F
.62489 .87282 m .59982 .88785 L .59708 .88279 L 1 .978 0 r
F
.62489 .87282 m .62855 .87792 L .59982 .88785 L F
.50412 .41826 m .49512 .41731 L .49433 .41615 L .47 .512 0 r
F
.50461 .41885 m .49512 .41731 L .50412 .41826 L .469 .512 0 r
F
.5196 .42508 m .5244 .43094 L .51879 .4251 L .454 .498 0 r
F
.5196 .42508 m .52602 .43092 L .5244 .43094 L F
.25132 .62007 m .24253 .62194 L .22945 .60423 L .944 .821 0 r
F
.40466 .37321 m .39714 .36195 L .4068 .36682 L .754 .617 0 r
F
.4145 .37731 m .40466 .37321 L .4068 .36682 L .715 .602 0 r
F
.6971 .5066 m .69986 .52369 L .69058 .51935 L .986 .72 0 r
F
.6971 .5066 m .70675 .51018 L .69986 .52369 L F
.4533 .39726 m .44405 .38998 L .4539 .39424 L .578 .56 0 r
F
.46325 .40091 m .4533 .39726 L .4539 .39424 L .548 .547 0 r
F
.55377 .65396 m .54175 .65221 L .53992 .65295 L .337 0 0 r
F
.55377 .65396 m .55652 .64995 L .54175 .65221 L F
.4732 .4066 m .46325 .40091 L .47321 .40457 L .527 .541 0 r
F
.48317 .40973 m .4732 .4066 L .47321 .40457 L .504 .529 0 r
F
.48347 .41131 m .4732 .4066 L .48317 .40973 L .505 .532 0 r
F
.48344 .64897 m .48138 .65185 L .46669 .64941 L .471 .585 0 r
F
.49746 .65083 m .48138 .65185 L .48344 .64897 L .43 .477 0 r
F
.56927 .44942 m .57565 .45724 L .56674 .4514 L .527 .516 0 r
F
.56927 .44942 m .57861 .45481 L .57565 .45724 L F
.49335 .41393 m .48347 .41131 L .48317 .40973 L .486 .521 0 r
F
.49374 .41502 m .48347 .41131 L .49335 .41393 L F
.4145 .37731 m .4068 .36682 L .41646 .37175 L .715 .602 0 r
F
.42435 .38149 m .4145 .37731 L .41646 .37175 L .676 .587 0 r
F
.50373 .41769 m .49433 .41615 L .49374 .41502 L .471 .512 0 r
F
.50412 .41826 m .49433 .41615 L .50373 .41769 L .47 .512 0 r
F
.53003 .43013 m .53668 .43621 L .52885 .43051 L .459 .498 0 r
F
.53003 .43013 m .53845 .43565 L .53668 .43621 L F
.68744 .50286 m .69058 .51935 L .68128 .51481 L .969 .707 0 r
F
.68744 .50286 m .6971 .5066 L .69058 .51935 L F
.53998 .4349 m .54687 .44126 L .53845 .43565 L .468 .5 0 r
F
.53998 .4349 m .5489 .44026 L .54687 .44126 L F
.52034 .42501 m .52602 .43092 L .5196 .42508 L .456 .499 0 r
F
.52034 .42501 m .52751 .43078 L .52602 .43092 L F
.55992 .44416 m .56674 .4514 L .55782 .44575 L .505 .511 0 r
F
.55992 .44416 m .56927 .44942 L .56674 .4514 L F
.42435 .38149 m .41646 .37175 L .42612 .37672 L .676 .587 0 r
F
.43419 .38572 m .42435 .38149 L .42612 .37672 L .637 .573 0 r
F
.46325 .40091 m .4539 .39424 L .46377 .39848 L .548 .547 0 r
F
.47321 .40457 m .46325 .40091 L .46377 .39848 L .522 .536 0 r
F
.36671 .63673 m .34546 .62961 L .35324 .62725 L .821 .791 0 r
F
.37383 .63402 m .36671 .63673 L .35324 .62725 L .802 .781 0 r
F
.67777 .49893 m .68128 .51481 L .67197 .51006 L .949 .693 0 r
F
.67777 .49893 m .68744 .50286 L .68128 .51481 L F
.51316 .41926 m .51006 .42274 L .50911 .42224 L .463 .507 0 r
F
.51316 .41926 m .51104 .42319 L .51006 .42274 L F
.51316 .41926 m .51204 .42361 L .51104 .42319 L F
.51316 .41926 m .50911 .42224 L .50821 .42172 L F
.51316 .41926 m .51305 .42398 L .51204 .42361 L .462 .506 0 r
F
.29954 .62695 m .27776 .61472 L .2866 .61304 L .904 .81 0 r
F
.30786 .62479 m .29954 .62695 L .2866 .61304 L .893 .805 0 r
F
.50344 .41712 m .49374 .41502 L .49335 .41393 L .472 .513 0 r
F
.50373 .41769 m .49374 .41502 L .50344 .41712 L .471 .512 0 r
F
.51316 .41926 m .50821 .42172 L .50736 .42118 L .463 .507 0 r
F
.51316 .41926 m .51406 .4243 L .51305 .42398 L .462 .506 0 r
F
.56728 .65909 m .55652 .64995 L .55377 .65396 L .561 .025 0 r
F
.56728 .65909 m .57088 .64677 L .55652 .64995 L F
.3377 .63206 m .3162 .6227 L .32455 .62068 L .861 .799 0 r
F
.34546 .62961 m .3377 .63206 L .32455 .62068 L .846 .792 0 r
F
.52101 .42487 m .52751 .43078 L .52034 .42501 L .458 .501 0 r
F
.52101 .42487 m .52885 .43051 L .52751 .43078 L F
.80088 .51699 m .80282 .53922 L .79325 .53671 L 1 .804 0 r
F
.80088 .51699 m .81076 .51887 L .80282 .53922 L F
.51316 .41926 m .50736 .42118 L .50656 .42061 L .463 .507 0 r
F
.51316 .41926 m .51507 .42457 L .51406 .4243 L .461 .505 0 r
F
.43419 .38572 m .42612 .37672 L .43579 .38169 L .637 .573 0 r
F
.44405 .38998 m .43419 .38572 L .43579 .38169 L .6 .56 0 r
F
.6681 .49483 m .67197 .51006 L .66266 .50508 L .925 .678 0 r
F
.6681 .49483 m .67777 .49893 L .67197 .51006 L F
.48317 .40973 m .47321 .40457 L .48319 .40824 L .504 .529 0 r
F
.49315 .41289 m .48317 .40973 L .48319 .40824 L .486 .52 0 r
F
.49335 .41393 m .48317 .40973 L .49315 .41289 L .486 .521 0 r
F
.55057 .43902 m .55782 .44575 L .5489 .44026 L .489 .509 0 r
F
.55057 .43902 m .55992 .44416 L .55782 .44575 L F
.51316 .41926 m .50656 .42061 L .50583 .42003 L .463 .507 0 r
F
.51316 .41926 m .51605 .42479 L .51507 .42457 L .461 .505 0 r
F
.53853 .89159 m .53938 .89649 L .51002 .90008 L 1 .97 0 r
F
.56668 .88576 m .53938 .89649 L .53853 .89159 L 1 .987 0 r
F
.56668 .88576 m .56849 .89072 L .53938 .89649 L F
.46969 .64637 m .46669 .64941 L .45243 .64605 L .518 .645 0 r
F
.48344 .64897 m .46669 .64941 L .46969 .64637 L .471 .585 0 r
F
.4145 .6427 m .39436 .63912 L .40077 .63625 L .728 .765 0 r
F
.42013 .63965 m .4145 .6427 L .40077 .63625 L .699 .748 0 r
F
.43395 .64493 m .4145 .6427 L .42013 .63965 L .675 .746 0 r
F
.25132 .62007 m .22945 .60423 L .23871 .60292 L .944 .821 0 r
F
.26012 .61824 m .25132 .62007 L .23871 .60292 L .937 .817 0 r
F
.53104 .42963 m .53845 .43565 L .53003 .43013 L .465 .503 0 r
F
.53104 .42963 m .53998 .4349 L .53845 .43565 L F
.51316 .41926 m .50583 .42003 L .50518 .41944 L .463 .507 0 r
F
.51316 .41926 m .517 .42495 L .51605 .42479 L .461 .504 0 r
F
.65841 .49054 m .66266 .50508 L .65333 .49989 L .897 .662 0 r
F
.65841 .49054 m .6681 .49483 L .66266 .50508 L F
.47321 .40457 m .46377 .39848 L .47363 .40269 L .522 .536 0 r
F
.48319 .40824 m .47321 .40457 L .47363 .40269 L .5 .526 0 r
F
.44405 .38998 m .43579 .38169 L .44545 .38661 L .6 .56 0 r
F
.4539 .39424 m .44405 .38998 L .44545 .38661 L .567 .548 0 r
F
.791 .51504 m .79325 .53671 L .78368 .53414 L 1 .799 0 r
F
.791 .51504 m .80088 .51699 L .79325 .53671 L F
.50324 .41658 m .49335 .41393 L .49315 .41289 L .473 .513 0 r
F
.50344 .41712 m .49335 .41393 L .50324 .41658 L .472 .513 0 r
F
.51316 .41926 m .50518 .41944 L .50461 .41885 L .464 .507 0 r
F
.59433 .87777 m .56849 .89072 L .56668 .88576 L 1 .993 0 r
F
.59433 .87777 m .59708 .88279 L .56849 .89072 L F
.51316 .41926 m .51792 .42506 L .517 .42495 L .46 .504 0 r
F
.45156 .90081 m .44955 .90553 L .42004 .90265 L .936 .908 0 r
F
.48066 .9015 m .44955 .90553 L .45156 .90081 L .968 .927 0 r
F
.64873 .48607 m .65333 .49989 L .644 .49449 L .866 .646 0 r
F
.64873 .48607 m .65841 .49054 L .65333 .49989 L F
.51012 .89524 m .51002 .90008 L .48066 .9015 L 1 .949 0 r
F
.53853 .89159 m .51002 .90008 L .51012 .89524 L 1 .97 0 r
F
.5216 .42468 m .52885 .43051 L .52101 .42487 L .461 .503 0 r
F
.5216 .42468 m .53003 .43013 L .52885 .43051 L F
.43876 .64182 m .43395 .64493 L .42013 .63965 L .64 .722 0 r
F
.45243 .64605 m .43395 .64493 L .43876 .64182 L .606 .71 0 r
F
.65168 .86102 m .62855 .87792 L .62489 .87282 L 1 .959 0 r
F
.65168 .86102 m .65623 .86614 L .62855 .87792 L F
.54122 .43398 m .5489 .44026 L .53998 .4349 L .478 .508 0 r
F
.54122 .43398 m .55057 .43902 L .5489 .44026 L F
.39436 .63912 m .37383 .63402 L .38097 .63141 L .769 .776 0 r
F
.40077 .63625 m .39436 .63912 L .38097 .63141 L .745 .762 0 r
F
.51316 .41926 m .50461 .41885 L .50412 .41826 L .464 .507 0 r
F
.63904 .48143 m .644 .49449 L .63467 .48893 L .83 .63 0 r
F
.63904 .48143 m .64873 .48607 L .644 .49449 L F
.51316 .41926 m .51879 .4251 L .51792 .42506 L .46 .504 0 r
F
.62935 .47665 m .63467 .48893 L .62533 .48324 L .791 .614 0 r
F
.62935 .47665 m .63904 .48143 L .63467 .48893 L F
.4539 .39424 m .44545 .38661 L .45512 .39148 L .567 .548 0 r
F
.46377 .39848 m .4539 .39424 L .45512 .39148 L .538 .538 0 r
F
.61966 .47177 m .62533 .48324 L .61598 .47749 L .749 .598 0 r
F
.61966 .47177 m .62935 .47665 L .62533 .48324 L F
.78111 .51303 m .78368 .53414 L .77409 .53149 L 1 .793 0 r
F
.78111 .51303 m .791 .51504 L .78368 .53414 L F
.51316 .41926 m .50412 .41826 L .50373 .41769 L .464 .507 0 r
F
.51316 .41926 m .5196 .42508 L .51879 .4251 L .461 .504 0 r
F
.60997 .46682 m .61598 .47749 L .60664 .47171 L .705 .582 0 r
F
.60997 .46682 m .61966 .47177 L .61598 .47749 L F
.48319 .40824 m .47363 .40269 L .48351 .40687 L .5 .526 0 r
F
.49317 .41192 m .48319 .40824 L .48351 .40687 L .484 .518 0 r
F
.49315 .41289 m .48319 .40824 L .49317 .41192 L .486 .52 0 r
F
.60028 .46183 m .60664 .47171 L .5973 .46598 L .662 .568 0 r
F
.60028 .46183 m .60997 .46682 L .60664 .47171 L F
.50315 .41607 m .49315 .41289 L .49317 .41192 L .473 .512 0 r
F
.50324 .41658 m .49315 .41289 L .50315 .41607 L .473 .513 0 r
F
.59059 .45686 m .5973 .46598 L .58795 .46034 L .62 .555 0 r
F
.59059 .45686 m .60028 .46183 L .5973 .46598 L F
.5221 .42443 m .53003 .43013 L .5216 .42468 L .464 .505 0 r
F
.5221 .42443 m .53104 .42963 L .53003 .43013 L F
.51316 .41926 m .50373 .41769 L .50344 .41712 L .465 .508 0 r
F
.58091 .45192 m .58795 .46034 L .57861 .45481 L .583 .544 0 r
F
.58091 .45192 m .59059 .45686 L .58795 .46034 L F
.53187 .42903 m .53998 .4349 L .53104 .42963 L .471 .507 0 r
F
.53187 .42903 m .54122 .43398 L .53998 .4349 L F
.46377 .39848 m .45512 .39148 L .46479 .39626 L .538 .538 0 r
F
.47363 .40269 m .46377 .39848 L .46479 .39626 L .514 .528 0 r
F
.51316 .41926 m .52034 .42501 L .5196 .42508 L .461 .505 0 r
F
.58056 .68481 m .57088 .64677 L .56728 .65909 L 1 .121 0 r
F
.58056 .68481 m .58497 .66638 L .57088 .64677 L F
.57122 .44705 m .57861 .45481 L .56927 .44942 L .55 .534 0 r
F
.57122 .44705 m .58091 .45192 L .57861 .45481 L F
.77121 .51095 m .77409 .53149 L .7645 .52876 L 1 .787 0 r
F
.77121 .51095 m .78111 .51303 L .77409 .53149 L F
.62122 .86774 m .59708 .88279 L .59433 .87777 L 1 .986 0 r
F
.62122 .86774 m .62489 .87282 L .59708 .88279 L F
.51316 .41926 m .50344 .41712 L .50324 .41658 L .465 .508 0 r
F
.56154 .44226 m .56927 .44942 L .55992 .44416 L .524 .526 0 r
F
.56154 .44226 m .57122 .44705 L .56927 .44942 L F
.51316 .41926 m .52101 .42487 L .52034 .42501 L .462 .505 0 r
F
.30786 .62479 m .2866 .61304 L .29545 .61142 L .893 .805 0 r
F
.3162 .6227 m .30786 .62479 L .29545 .61142 L .882 .799 0 r
F
.48172 .89673 m .48066 .9015 L .45156 .90081 L .957 .926 0 r
F
.51012 .89524 m .48066 .9015 L .48172 .89673 L 1 .949 0 r
F
.47363 .40269 m .46479 .39626 L .47446 .40098 L .514 .528 0 r
F
.48351 .40687 m .47363 .40269 L .47446 .40098 L .495 .521 0 r
F
.26012 .61824 m .23871 .60292 L .24797 .60166 L .937 .817 0 r
F
.26893 .61645 m .26012 .61824 L .24797 .60166 L .93 .813 0 r
F
.45637 .64299 m .45243 .64605 L .43876 .64182 L .565 .678 0 r
F
.46969 .64637 m .45243 .64605 L .45637 .64299 L .518 .645 0 r
F
.49317 .41192 m .48351 .40687 L .49339 .41101 L .484 .518 0 r
F
.50316 .41559 m .49317 .41192 L .49339 .41101 L .472 .512 0 r
F
.50315 .41607 m .49317 .41192 L .50316 .41559 L .473 .512 0 r
F
.55186 .43754 m .55992 .44416 L .55057 .43902 L .503 .52 0 r
F
.55186 .43754 m .56154 .44226 L .55992 .44416 L F
.37782 .35256 m .36816 .3481 L .37251 .33835 L .867 .646 0 r
F
.36816 .3481 m .36311 .33312 L .37251 .33835 L .9 .662 0 r
F
.36816 .3481 m .35849 .34382 L .36311 .33312 L F
.51316 .41926 m .50324 .41658 L .50315 .41607 L .465 .508 0 r
F
.37782 .35256 m .37251 .33835 L .3819 .34378 L .867 .646 0 r
F
.38748 .35719 m .37782 .35256 L .3819 .34378 L .831 .63 0 r
F
.76131 .50879 m .7645 .52876 L .7549 .52595 L 1 .781 0 r
F
.76131 .50879 m .77121 .51095 L .7645 .52876 L F
.35849 .34382 m .3537 .32809 L .36311 .33312 L .928 .678 0 r
F
.35849 .34382 m .34881 .33971 L .3537 .32809 L F
.51316 .41926 m .5216 .42468 L .52101 .42487 L .462 .506 0 r
F
.52252 .42413 m .53104 .42963 L .5221 .42443 L .466 .507 0 r
F
.52252 .42413 m .53187 .42903 L .53104 .42963 L F
.38748 .35719 m .3819 .34378 L .39128 .34937 L .831 .63 0 r
F
.39714 .36195 m .38748 .35719 L .39128 .34937 L .791 .614 0 r
F
.34881 .33971 m .34429 .32327 L .3537 .32809 L .953 .693 0 r
F
.34881 .33971 m .33913 .33578 L .34429 .32327 L F
.37383 .63402 m .35324 .62725 L .36103 .62498 L .802 .781 0 r
F
.38097 .63141 m .37383 .63402 L .36103 .62498 L .782 .771 0 r
F
.34546 .62961 m .32455 .62068 L .33291 .61872 L .846 .792 0 r
F
.35324 .62725 m .34546 .62961 L .33291 .61872 L .831 .784 0 r
F
.39714 .36195 m .39128 .34937 L .40066 .35508 L .791 .614 0 r
F
.4068 .36682 m .39714 .36195 L .40066 .35508 L .748 .598 0 r
F
.54219 .4329 m .55057 .43902 L .54122 .43398 L .487 .515 0 r
F
.54219 .4329 m .55186 .43754 L .55057 .43902 L F
.51175 .6502 m .51164 .65199 L .49746 .65083 L .301 .213 0 r
F
.52496 .65172 m .51164 .65199 L .51175 .6502 L .139 .121 0 r
F
.52496 .65172 m .52584 .65259 L .51164 .65199 L F
.48351 .40687 m .47446 .40098 L .48413 .40562 L .495 .521 0 r
F
.49339 .41101 m .48351 .40687 L .48413 .40562 L .481 .515 0 r
F
.33913 .33578 m .33486 .31866 L .34429 .32327 L .974 .707 0 r
F
.33913 .33578 m .32944 .33202 L .33486 .31866 L F
.49855 .64845 m .49746 .65083 L .48344 .64897 L .39 .407 0 r
F
.51175 .6502 m .49746 .65083 L .49855 .64845 L .301 .213 0 r
F
.4068 .36682 m .40066 .35508 L .41004 .36086 L .748 .598 0 r
F
.41646 .37175 m .4068 .36682 L .41004 .36086 L .704 .582 0 r
F
.51316 .41926 m .50315 .41607 L .50316 .41559 L .465 .508 0 r
F
.51316 .41926 m .5221 .42443 L .5216 .42468 L .463 .506 0 r
F
.32944 .33202 m .32542 .31425 L .33486 .31866 L .992 .72 0 r
F
.32944 .33202 m .31974 .32842 L .32542 .31425 L F
.41646 .37175 m .41004 .36086 L .41942 .36666 L .704 .582 0 r
F
.42612 .37672 m .41646 .37175 L .41942 .36666 L .66 .568 0 r
F
.75141 .50654 m .7549 .52595 L .74529 .52303 L 1 .774 0 r
F
.75141 .50654 m .76131 .50879 L .7549 .52595 L F
.53251 .42831 m .54122 .43398 L .53187 .42903 L .476 .512 0 r
F
.53251 .42831 m .54219 .4329 L .54122 .43398 L F
.42612 .37672 m .41942 .36666 L .4288 .37241 L .66 .568 0 r
F
.43579 .38169 m .42612 .37672 L .4288 .37241 L .619 .555 0 r
F
.53808 .65351 m .53992 .65295 L .52584 .65259 L .126 0 0 r
F
.53808 .65351 m .52584 .65259 L .52496 .65172 L F
.49339 .41101 m .48413 .40562 L .49381 .4102 L .481 .515 0 r
F
.50327 .41514 m .49339 .41101 L .49381 .4102 L .471 .511 0 r
F
.50316 .41559 m .49339 .41101 L .50327 .41514 L .472 .512 0 r
F
.31974 .32842 m .31597 .31001 L .32542 .31425 L 1 .732 0 r
F
.31974 .32842 m .31004 .32498 L .31597 .31001 L F
.51316 .41926 m .50316 .41559 L .50327 .41514 L .465 .508 0 r
F
.51316 .41926 m .52252 .42413 L .5221 .42443 L .464 .507 0 r
F
.43579 .38169 m .4288 .37241 L .43818 .37807 L .619 .555 0 r
F
.44545 .38661 m .43579 .38169 L .43818 .37807 L .581 .543 0 r
F
.52283 .42377 m .53187 .42903 L .52252 .42413 L .469 .509 0 r
F
.52283 .42377 m .53251 .42831 L .53187 .42903 L F
.4855 .64626 m .48344 .64897 L .46969 .64637 L .441 .53 0 r
F
.49855 .64845 m .48344 .64897 L .4855 .64626 L .39 .407 0 r
F
.74149 .50419 m .74529 .52303 L .73567 .52001 L 1 .766 0 r
F
.74149 .50419 m .75141 .50654 L .74529 .52303 L F
.44545 .38661 m .43818 .37807 L .44756 .38362 L .581 .543 0 r
F
.45512 .39148 m .44545 .38661 L .44756 .38362 L .549 .533 0 r
F
.31004 .32498 m .30651 .30593 L .31597 .31001 L 1 .743 0 r
F
.31004 .32498 m .30032 .32167 L .30651 .30593 L F
.50327 .41514 m .49381 .4102 L .50348 .41474 L .471 .511 0 r
F
.51316 .41926 m .50327 .41514 L .50348 .41474 L .465 .508 0 r
F
.45512 .39148 m .44756 .38362 L .45693 .38903 L .549 .533 0 r
F
.46479 .39626 m .45512 .39148 L .45693 .38903 L .523 .526 0 r
F
.51316 .41926 m .52283 .42377 L .52252 .42413 L .465 .507 0 r
F
.46479 .39626 m .45693 .38903 L .46631 .39431 L .523 .526 0 r
F
.47446 .40098 m .46479 .39626 L .46631 .39431 L .503 .519 0 r
F
.47446 .40098 m .46631 .39431 L .47569 .39947 L F
.48413 .40562 m .47446 .40098 L .47569 .39947 L .487 .515 0 r
F
.30032 .32167 m .29704 .302 L .30651 .30593 L 1 .753 0 r
F
.30032 .32167 m .2906 .31848 L .29704 .302 L F
.73158 .50175 m .73567 .52001 L .72604 .51687 L .999 .757 0 r
F
.73158 .50175 m .74149 .50419 L .73567 .52001 L F
.42013 .63965 m .40077 .63625 L .40721 .63349 L .699 .748 0 r
F
.42579 .63674 m .42013 .63965 L .40721 .63349 L .668 .728 0 r
F
.43876 .64182 m .42013 .63965 L .42579 .63674 L .64 .722 0 r
F
.48413 .40562 m .47569 .39947 L .48506 .40452 L .487 .515 0 r
F
.49381 .4102 m .48413 .40562 L .48506 .40452 L .476 .511 0 r
F
.26893 .61645 m .24797 .60166 L .25725 .60045 L .93 .813 0 r
F
.27776 .61472 m .26893 .61645 L .25725 .60045 L .921 .808 0 r
F
.49381 .4102 m .48506 .40452 L .49443 .40948 L .476 .511 0 r
F
.50348 .41474 m .49381 .4102 L .49443 .40948 L .469 .509 0 r
F
.53767 .88677 m .53853 .89159 L .51012 .89524 L 1 .974 0 r
F
.56486 .88088 m .53853 .89159 L .53767 .88677 L 1 .994 0 r
F
.56486 .88088 m .56668 .88576 L .53853 .89159 L F
.42298 .89808 m .42004 .90265 L .39134 .89778 L .913 .891 0 r
F
.45156 .90081 m .42004 .90265 L .42298 .89808 L .936 .908 0 r
F
.50348 .41474 m .49443 .40948 L .5038 .41438 L .469 .509 0 r
F
.51316 .41926 m .50348 .41474 L .5038 .41438 L .465 .507 0 r
F
.51316 .41926 m .5038 .41438 L .5042 .41408 L .464 .507 0 r
F
.51316 .41926 m .52305 .42337 L .52283 .42377 L .465 .508 0 r
F
.51316 .41926 m .5042 .41408 L .5047 .41383 L .463 .506 0 r
F
.51316 .41926 m .52317 .42293 L .52305 .42337 L .465 .508 0 r
F
.51316 .41926 m .5047 .41383 L .50529 .41363 L .462 .506 0 r
F
.51316 .41926 m .52318 .42245 L .52317 .42293 L .465 .508 0 r
F
.51316 .41926 m .50529 .41363 L .50596 .41349 L .462 .505 0 r
F
.51316 .41926 m .52309 .42194 L .52318 .42245 L .465 .508 0 r
F
.51316 .41926 m .50596 .41349 L .5067 .41341 L .461 .505 0 r
F
.51316 .41926 m .5229 .42139 L .52309 .42194 L .465 .508 0 r
F
.51316 .41926 m .5067 .41341 L .50751 .4134 L .461 .504 0 r
F
.51316 .41926 m .52261 .42083 L .5229 .42139 L .465 .508 0 r
F
.51316 .41926 m .50751 .4134 L .50838 .41344 L .46 .504 0 r
F
.51316 .41926 m .52222 .42025 L .52261 .42083 L .464 .507 0 r
F
.6772 .84765 m .65623 .86614 L .65168 .86102 L 1 .933 0 r
F
.6772 .84765 m .68261 .85274 L .65623 .86614 L F
.51316 .41926 m .50838 .41344 L .5093 .41354 L .46 .504 0 r
F
.51316 .41926 m .52173 .41966 L .52222 .42025 L .464 .507 0 r
F
.51316 .41926 m .5093 .41354 L .51026 .4137 L .461 .504 0 r
F
.51316 .41926 m .52116 .41907 L .52173 .41966 L .464 .507 0 r
F
.51316 .41926 m .51026 .4137 L .51124 .41392 L .461 .505 0 r
F
.51316 .41926 m .52051 .41848 L .52116 .41907 L .463 .507 0 r
F
.51316 .41926 m .51124 .41392 L .51225 .41419 L .461 .505 0 r
F
.51316 .41926 m .51978 .4179 L .52051 .41848 L .463 .507 0 r
F
.51316 .41926 m .51225 .41419 L .51327 .41452 L .462 .506 0 r
F
.51316 .41926 m .51898 .41733 L .51978 .4179 L .463 .507 0 r
F
.51316 .41926 m .51327 .41452 L .51428 .41489 L .462 .506 0 r
F
.51316 .41926 m .51813 .41678 L .51898 .41733 L .463 .507 0 r
F
.51316 .41926 m .51428 .41489 L .51529 .41531 L F
.51316 .41926 m .51722 .41626 L .51813 .41678 L F
.51316 .41926 m .51529 .41531 L .51627 .41576 L F
.51316 .41926 m .51627 .41576 L .51722 .41626 L F
.64711 .85589 m .62489 .87282 L .62122 .86774 L 1 .965 0 r
F
.64711 .85589 m .65168 .86102 L .62489 .87282 L F
.52305 .42337 m .53251 .42831 L .52283 .42377 L .471 .511 0 r
F
.40077 .63625 m .38097 .63141 L .38812 .6289 L .745 .762 0 r
F
.40721 .63349 m .40077 .63625 L .38812 .6289 L .719 .747 0 r
F
.53295 .42751 m .54219 .4329 L .53251 .42831 L .481 .515 0 r
F
.52305 .42337 m .53295 .42751 L .53251 .42831 L .471 .511 0 r
F
.54285 .43167 m .55186 .43754 L .54219 .4329 L .495 .521 0 r
F
.53295 .42751 m .54285 .43167 L .54219 .4329 L .481 .515 0 r
F
.3162 .6227 m .29545 .61142 L .30432 .60986 L .882 .799 0 r
F
.32455 .62068 m .3162 .6227 L .30432 .60986 L .87 .793 0 r
F
.2906 .31848 m .28755 .2982 L .29704 .302 L 1 .763 0 r
F
.2906 .31848 m .28087 .31541 L .28755 .2982 L F
.72166 .49918 m .72604 .51687 L .7164 .51359 L .988 .748 0 r
F
.72166 .49918 m .73158 .50175 L .72604 .51687 L F
.55276 .43586 m .56154 .44226 L .55186 .43754 L .514 .528 0 r
F
.54285 .43167 m .55276 .43586 L .55186 .43754 L .495 .521 0 r
F
.59157 .87281 m .56668 .88576 L .56486 .88088 L 1 1 0 r
F
.59157 .87281 m .59433 .87777 L .56668 .88576 L F
.55098 .65675 m .53992 .65295 L .53808 .65351 L .407 0 0 r
F
.55098 .65675 m .55377 .65396 L .53992 .65295 L F
.56267 .44009 m .57122 .44705 L .56154 .44226 L .538 .538 0 r
F
.55276 .43586 m .56267 .44009 L .56154 .44226 L .514 .528 0 r
F
.45357 .89614 m .45156 .90081 L .42298 .89808 L .924 .905 0 r
F
.48172 .89673 m .45156 .90081 L .45357 .89614 L .957 .926 0 r
F
.5038 .41438 m .49524 .40886 L .5042 .41408 L .466 .507 0 r
F
.5038 .41438 m .49443 .40948 L .49524 .40886 L F
.57259 .44435 m .58091 .45192 L .57122 .44705 L .567 .548 0 r
F
.56267 .44009 m .57259 .44435 L .57122 .44705 L .538 .538 0 r
F
.52317 .42293 m .53295 .42751 L .52305 .42337 L .472 .512 0 r
F
.47271 .64348 m .46969 .64637 L .45637 .64299 L .477 .601 0 r
F
.4855 .64626 m .46969 .64637 L .47271 .64348 L .441 .53 0 r
F
.51022 .89047 m .51012 .89524 L .48172 .89673 L .989 .949 0 r
F
.53767 .88677 m .51012 .89524 L .51022 .89047 L 1 .974 0 r
F
.44358 .63885 m .43876 .64182 L .42579 .63674 L .604 .696 0 r
F
.45637 .64299 m .43876 .64182 L .44358 .63885 L .565 .678 0 r
F
.71173 .4965 m .7164 .51359 L .70675 .51018 L .976 .738 0 r
F
.71173 .4965 m .72166 .49918 L .7164 .51359 L F
.58251 .44864 m .59059 .45686 L .58091 .45192 L .6 .56 0 r
F
.57259 .44435 m .58251 .44864 L .58091 .45192 L .567 .548 0 r
F
.28087 .31541 m .27805 .29452 L .28755 .2982 L 1 .771 0 r
F
.28087 .31541 m .27113 .31244 L .27805 .29452 L F
.49443 .40948 m .48627 .40357 L .49524 .40886 L .471 .507 0 r
F
.49443 .40948 m .48506 .40452 L .48627 .40357 L F
.59244 .45293 m .60028 .46183 L .59059 .45686 L .637 .573 0 r
F
.58251 .44864 m .59244 .45293 L .59059 .45686 L .6 .56 0 r
F
.5042 .41408 m .49624 .40835 L .5047 .41383 L .464 .505 0 r
F
.5042 .41408 m .49524 .40886 L .49624 .40835 L F
.52317 .42293 m .53318 .42661 L .53295 .42751 L .472 .512 0 r
F
.52318 .42245 m .53318 .42661 L .52317 .42293 L .473 .512 0 r
F
.7018 .49368 m .70675 .51018 L .6971 .5066 L .962 .727 0 r
F
.7018 .49368 m .71173 .4965 L .70675 .51018 L F
.53318 .42661 m .54285 .43167 L .53295 .42751 L .484 .518 0 r
F
.60238 .4572 m .60997 .46682 L .60028 .46183 L .676 .587 0 r
F
.59244 .45293 m .60238 .4572 L .60028 .46183 L .637 .573 0 r
F
.35324 .62725 m .33291 .61872 L .3413 .61685 L .831 .784 0 r
F
.36103 .62498 m .35324 .62725 L .3413 .61685 L .814 .775 0 r
F
.48506 .40452 m .4773 .39818 L .48627 .40357 L .478 .508 0 r
F
.48506 .40452 m .47569 .39947 L .4773 .39818 L F
.27113 .31244 m .26854 .29094 L .27805 .29452 L 1 .779 0 r
F
.27113 .31244 m .26138 .30956 L .26854 .29094 L F
.61231 .46142 m .61966 .47177 L .60997 .46682 L .715 .602 0 r
F
.60238 .4572 m .61231 .46142 L .60997 .46682 L .676 .587 0 r
F
.69186 .49071 m .6971 .5066 L .68744 .50286 L .946 .715 0 r
F
.69186 .49071 m .7018 .49368 L .6971 .5066 L F
.5047 .41383 m .49741 .40796 L .50529 .41363 L .461 .503 0 r
F
.5047 .41383 m .49624 .40835 L .49741 .40796 L F
.52318 .42245 m .53321 .42564 L .53318 .42661 L .473 .512 0 r
F
.52309 .42194 m .53321 .42564 L .52318 .42245 L .473 .513 0 r
F
.62226 .46556 m .62935 .47665 L .61966 .47177 L .753 .617 0 r
F
.61231 .46142 m .62226 .46556 L .61966 .47177 L .715 .602 0 r
F
.38097 .63141 m .36103 .62498 L .36884 .6228 L .782 .771 0 r
F
.38812 .6289 m .38097 .63141 L .36884 .6228 L .761 .759 0 r
F
.61753 .86268 m .59433 .87777 L .59157 .87281 L 1 .995 0 r
F
.61753 .86268 m .62122 .86774 L .59433 .87777 L F
.68192 .48759 m .68744 .50286 L .67777 .49893 L .927 .703 0 r
F
.68192 .48759 m .69186 .49071 L .68744 .50286 L F
.54321 .4303 m .55276 .43586 L .54285 .43167 L .5 .526 0 r
F
.53318 .42661 m .54321 .4303 L .54285 .43167 L .484 .518 0 r
F
.47569 .39947 m .46832 .39266 L .4773 .39818 L .489 .509 0 r
F
.47569 .39947 m .46631 .39431 L .46832 .39266 L F
.6322 .4696 m .63904 .48143 L .62935 .47665 L .79 .632 0 r
F
.62226 .46556 m .6322 .4696 L .62935 .47665 L .753 .617 0 r
F
.67198 .48432 m .67777 .49893 L .6681 .49483 L .906 .69 0 r
F
.67198 .48432 m .68192 .48759 L .67777 .49893 L F
.64215 .47351 m .64873 .48607 L .63904 .48143 L .824 .647 0 r
F
.6322 .4696 m .64215 .47351 L .63904 .48143 L .79 .632 0 r
F
.49524 .40886 m .48777 .40281 L .49624 .40835 L .465 .503 0 r
F
.49524 .40886 m .48627 .40357 L .48777 .40281 L F
.50529 .41363 m .49875 .40769 L .50596 .41349 L .458 .501 0 r
F
.50529 .41363 m .49741 .40796 L .49875 .40769 L F
.66204 .48087 m .6681 .49483 L .65841 .49054 L .882 .676 0 r
F
.66204 .48087 m .67198 .48432 L .6681 .49483 L F
.26138 .30956 m .25902 .28745 L .26854 .29094 L 1 .786 0 r
F
.26138 .30956 m .25163 .30677 L .25902 .28745 L F
.65209 .47727 m .65841 .49054 L .64873 .48607 L .854 .661 0 r
F
.64215 .47351 m .65209 .47727 L .64873 .48607 L .824 .647 0 r
F
.52309 .42194 m .53304 .4246 L .53321 .42564 L .473 .513 0 r
F
.5229 .42139 m .53304 .4246 L .52309 .42194 L .472 .513 0 r
F
.65209 .47727 m .66204 .48087 L .65841 .49054 L .854 .661 0 r
F
.27776 .61472 m .25725 .60045 L .26654 .59929 L .921 .808 0 r
F
.2866 .61304 m .27776 .61472 L .26654 .59929 L .912 .804 0 r
F
.46631 .39431 m .45933 .38696 L .46832 .39266 L .504 .511 0 r
F
.46631 .39431 m .45693 .38903 L .45933 .38696 L F
.53321 .42564 m .54321 .4303 L .53318 .42661 L .486 .52 0 r
F
.48278 .89204 m .48172 .89673 L .45357 .89614 L .944 .924 0 r
F
.51022 .89047 m .48172 .89673 L .48278 .89204 L .989 .949 0 r
F
.55325 .434 m .56267 .44009 L .55276 .43586 L .522 .536 0 r
F
.54321 .4303 m .55325 .434 L .55276 .43586 L .5 .526 0 r
F
.50596 .41349 m .50023 .40754 L .5067 .41341 L .456 .499 0 r
F
.50596 .41349 m .49875 .40769 L .50023 .40754 L F
.45693 .38903 m .45034 .38108 L .45933 .38696 L .526 .515 0 r
F
.45693 .38903 m .44756 .38362 L .45034 .38108 L F
.5229 .42139 m .53266 .42351 L .53304 .4246 L .472 .513 0 r
F
.52261 .42083 m .53266 .42351 L .5229 .42139 L .471 .512 0 r
F
.46031 .64008 m .45637 .64299 L .44358 .63885 L .526 .643 0 r
F
.47271 .64348 m .45637 .64299 L .46031 .64008 L .477 .601 0 r
F
.25163 .30677 m .24948 .28404 L .25902 .28745 L 1 .792 0 r
F
.25163 .30677 m .24186 .30405 L .24948 .28404 L F
.44756 .38362 m .44135 .37498 L .45034 .38108 L .554 .522 0 r
F
.44756 .38362 m .43818 .37807 L .44135 .37498 L F
.32455 .62068 m .30432 .60986 L .31321 .60837 L .87 .793 0 r
F
.33291 .61872 m .32455 .62068 L .31321 .60837 L .856 .786 0 r
F
.5067 .41341 m .50185 .40751 L .50751 .4134 L .454 .498 0 r
F
.5067 .41341 m .50023 .40754 L .50185 .40751 L F
.56329 .43769 m .57259 .44435 L .56267 .44009 L .548 .547 0 r
F
.55325 .434 m .56329 .43769 L .56267 .44009 L .522 .536 0 r
F
.48627 .40357 m .47928 .39714 L .48777 .40281 L .467 .5 0 r
F
.48627 .40357 m .4773 .39818 L .47928 .39714 L F
.43818 .37807 m .43235 .36868 L .44135 .37498 L .591 .531 0 r
F
.43818 .37807 m .4288 .37241 L .43235 .36868 L F
.52261 .42083 m .53208 .42238 L .53266 .42351 L .471 .512 0 r
F
.52222 .42025 m .53208 .42238 L .52261 .42083 L .47 .512 0 r
F
.49624 .40835 m .48952 .40222 L .49741 .40796 L .459 .498 0 r
F
.49624 .40835 m .48777 .40281 L .48952 .40222 L F
.56359 .6642 m .55377 .65396 L .55098 .65675 L .736 .025 0 r
F
.56359 .6642 m .56728 .65909 L .55377 .65396 L F
.4288 .37241 m .42336 .36218 L .43235 .36868 L .634 .543 0 r
F
.4288 .37241 m .41942 .36666 L .42336 .36218 L F
.53321 .42564 m .54326 .42882 L .54321 .4303 L .486 .52 0 r
F
.53304 .4246 m .54326 .42882 L .53321 .42564 L .486 .521 0 r
F
.41942 .36666 m .41436 .35554 L .42336 .36218 L .683 .557 0 r
F
.41942 .36666 m .41004 .36086 L .41436 .35554 L F
.54326 .42882 m .55325 .434 L .54321 .4303 L .504 .529 0 r
F
.41004 .36086 m .40536 .3488 L .41436 .35554 L .734 .573 0 r
F
.41004 .36086 m .40066 .35508 L .40536 .3488 L F
.50751 .4134 m .50359 .4076 L .50838 .41344 L .453 .497 0 r
F
.50751 .4134 m .50185 .40751 L .50359 .4076 L F
.52222 .42025 m .5313 .42122 L .53208 .42238 L .47 .512 0 r
F
.52173 .41966 m .5313 .42122 L .52222 .42025 L .469 .512 0 r
F
.24186 .30405 m .23993 .2807 L .24948 .28404 L 1 .798 0 r
F
.24186 .30405 m .23208 .30139 L .23993 .2807 L F
.40066 .35508 m .39636 .34207 L .40536 .3488 L .785 .59 0 r
F
.40066 .35508 m .39128 .34937 L .39636 .34207 L F
.57335 .44137 m .58251 .44864 L .57259 .44435 L .578 .56 0 r
F
.56329 .43769 m .57335 .44137 L .57259 .44435 L .548 .547 0 r
F
.39128 .34937 m .38735 .33542 L .39636 .34207 L .833 .608 0 r
F
.39128 .34937 m .3819 .34378 L .38735 .33542 L F
.67177 .84251 m .65168 .86102 L .64711 .85589 L 1 .935 0 r
F
.67177 .84251 m .6772 .84765 L .65168 .86102 L F
.50838 .41344 m .50543 .40782 L .5093 .41354 L .453 .497 0 r
F
.50838 .41344 m .50359 .4076 L .50543 .40782 L F
.3819 .34378 m .37834 .32893 L .38735 .33542 L .877 .627 0 r
F
.3819 .34378 m .37251 .33835 L .37834 .32893 L F
.52173 .41966 m .53034 .42004 L .5313 .42122 L .469 .512 0 r
F
.52116 .41907 m .53034 .42004 L .52173 .41966 L .467 .511 0 r
F
.4773 .39818 m .47079 .39133 L .47928 .39714 L .472 .496 0 r
F
.4773 .39818 m .46832 .39266 L .47079 .39133 L F
.49741 .40796 m .49152 .40182 L .49875 .40769 L .453 .494 0 r
F
.49741 .40796 m .48952 .40222 L .49152 .40182 L F
.37251 .33835 m .36932 .32265 L .37834 .32893 L .916 .646 0 r
F
.37251 .33835 m .36311 .33312 L .36932 .32265 L F
.49964 .64616 m .49855 .64845 L .4855 .64626 L .359 .36 0 r
F
.51185 .6484 m .49855 .64845 L .49964 .64616 L .266 .186 0 r
F
.51185 .6484 m .51175 .6502 L .49855 .64845 L F
.40721 .63349 m .38812 .6289 L .3953 .6265 L .719 .747 0 r
F
.41366 .63086 m .40721 .63349 L .3953 .6265 L .692 .73 0 r
F
.42579 .63674 m .40721 .63349 L .41366 .63086 L .668 .728 0 r
F
.64253 .85073 m .62122 .86774 L .61753 .86268 L 1 .97 0 r
F
.64253 .85073 m .64711 .85589 L .62122 .86774 L F
.43147 .63396 m .42579 .63674 L .41366 .63086 L .636 .706 0 r
F
.44358 .63885 m .42579 .63674 L .43147 .63396 L .604 .696 0 r
F
.5093 .41354 m .50734 .40815 L .51026 .4137 L .453 .498 0 r
F
.5093 .41354 m .50543 .40782 L .50734 .40815 L F
.52116 .41907 m .5292 .41885 L .53034 .42004 L .467 .511 0 r
F
.52051 .41848 m .5292 .41885 L .52116 .41907 L .466 .511 0 r
F
.53304 .4246 m .54301 .42724 L .54326 .42882 L .486 .521 0 r
F
.53266 .42351 m .54301 .42724 L .53304 .4246 L .485 .521 0 r
F
.23208 .30139 m .23037 .27743 L .23993 .2807 L 1 .803 0 r
F
.23208 .30139 m .2223 .2988 L .23037 .27743 L F
.58341 .44503 m .59244 .45293 L .58251 .44864 L .611 .574 0 r
F
.57335 .44137 m .58341 .44503 L .58251 .44864 L .578 .56 0 r
F
.52408 .65063 m .51175 .6502 L .51185 .6484 L .112 .116 0 r
F
.52408 .65063 m .52496 .65172 L .51175 .6502 L F
.42298 .89808 m .39134 .89778 L .39519 .89339 L .913 .891 0 r
F
.42593 .89355 m .42298 .89808 L .39519 .89339 L .901 .887 0 r
F
.45357 .89614 m .42298 .89808 L .42593 .89355 L .924 .905 0 r
F
.2866 .61304 m .26654 .59929 L .27584 .59818 L .912 .804 0 r
F
.29545 .61142 m .2866 .61304 L .27584 .59818 L .902 .798 0 r
F
.55332 .43198 m .56329 .43769 L .55325 .434 L .526 .541 0 r
F
.54326 .42882 m .55332 .43198 L .55325 .434 L .504 .529 0 r
F
.36311 .33312 m .36029 .31663 L .36932 .32265 L .949 .664 0 r
F
.36311 .33312 m .3537 .32809 L .36029 .31663 L F
.51026 .4137 m .50932 .40859 L .51124 .41392 L .454 .499 0 r
F
.51026 .4137 m .50734 .40815 L .50932 .40859 L F
.36103 .62498 m .3413 .61685 L .3497 .61507 L .814 .775 0 r
F
.36884 .6228 m .36103 .62498 L .3497 .61507 L .795 .765 0 r
F
.52051 .41848 m .52789 .41767 L .5292 .41885 L .466 .511 0 r
F
.51978 .4179 m .52789 .41767 L .52051 .41848 L .465 .511 0 r
F
.48777 .40281 m .48162 .39636 L .48952 .40222 L .457 .491 0 r
F
.48777 .40281 m .47928 .39714 L .48162 .39636 L F
.53681 .88205 m .53767 .88677 L .51022 .89047 L 1 .977 0 r
F
.56304 .8761 m .53767 .88677 L .53681 .88205 L 1 1 0 r
F
.56304 .8761 m .56486 .88088 L .53767 .88677 L F
.48756 .64365 m .4855 .64626 L .47271 .64348 L .415 .484 0 r
F
.49964 .64616 m .4855 .64626 L .48756 .64365 L .359 .36 0 r
F
.51124 .41392 m .51134 .40914 L .51225 .41419 L .455 .5 0 r
F
.51124 .41392 m .50932 .40859 L .51134 .40914 L F
.51978 .4179 m .52643 .41651 L .52789 .41767 L .465 .511 0 r
F
.51898 .41733 m .52643 .41651 L .51978 .4179 L .464 .51 0 r
F
.46832 .39266 m .46229 .38531 L .47079 .39133 L .481 .494 0 r
F
.46832 .39266 m .45933 .38696 L .46229 .38531 L F
.54301 .42724 m .55332 .43198 L .54326 .42882 L .505 .532 0 r
F
.5888 .86793 m .56486 .88088 L .56304 .8761 L 1 1 0 r
F
.5888 .86793 m .59157 .87281 L .56486 .88088 L F
.3537 .32809 m .35124 .31087 L .36029 .31663 L .977 .682 0 r
F
.3537 .32809 m .34429 .32327 L .35124 .31087 L F
.59348 .44864 m .60238 .4572 L .59244 .45293 L .647 .588 0 r
F
.58341 .44503 m .59348 .44864 L .59244 .45293 L .611 .574 0 r
F
.51225 .41419 m .51338 .40979 L .51327 .41452 L .457 .502 0 r
F
.51225 .41419 m .51134 .40914 L .51338 .40979 L F
.51898 .41733 m .52483 .41538 L .52643 .41651 L .464 .51 0 r
F
.51813 .41678 m .52483 .41538 L .51898 .41733 L .463 .51 0 r
F
.49875 .40769 m .49375 .40161 L .50023 .40754 L .448 .49 0 r
F
.49875 .40769 m .49152 .40182 L .49375 .40161 L F
.45559 .89154 m .45357 .89614 L .42593 .89355 L .91 .902 0 r
F
.48278 .89204 m .45357 .89614 L .45559 .89154 L .944 .924 0 r
F
.51327 .41452 m .51541 .41054 L .51428 .41489 L .458 .504 0 r
F
.51327 .41452 m .51338 .40979 L .51541 .41054 L F
.51813 .41678 m .52312 .41429 L .52483 .41538 L .463 .51 0 r
F
.51722 .41626 m .52312 .41429 L .51813 .41678 L .463 .509 0 r
F
.39519 .89339 m .39134 .89778 L .36369 .89099 L .897 .876 0 r
F
.53266 .42351 m .54244 .42559 L .54301 .42724 L .485 .521 0 r
F
.53208 .42238 m .54244 .42559 L .53266 .42351 L .484 .521 0 r
F
.70123 .83298 m .68261 .85274 L .6772 .84765 L 1 .905 0 r
F
.70123 .83298 m .70746 .83796 L .68261 .85274 L F
.51428 .41489 m .51742 .41137 L .51529 .41531 L .459 .506 0 r
F
.51428 .41489 m .51541 .41054 L .51742 .41137 L F
.51722 .41626 m .5213 .41326 L .52312 .41429 L .463 .509 0 r
F
.51627 .41576 m .5213 .41326 L .51722 .41626 L .462 .508 0 r
F
.53622 .65337 m .53808 .65351 L .53427 .65299 L .116 0 0 r
F
.53622 .65337 m .53427 .65299 L .52496 .65172 L F
.53827 .65377 m .53622 .65337 L .53436 .6523 L 0 .066 0 r
F
.54817 .6575 m .53808 .65351 L .53622 .65337 L .369 0 0 r
F
.54534 .65643 m .53622 .65337 L .53827 .65377 L 0 .066 0 r
F
.53622 .65337 m .52496 .65172 L .52408 .65063 L .116 0 0 r
F
.51529 .41531 m .51939 .41228 L .51627 .41576 L .461 .507 0 r
F
.51529 .41531 m .51742 .41137 L .51939 .41228 L F
.51627 .41576 m .51939 .41228 L .5213 .41326 L .462 .508 0 r
F
.23871 .60292 m .22945 .60423 L .21913 .58553 L .953 .816 0 r
F
.51033 .8858 m .51022 .89047 L .48278 .89204 L .975 .948 0 r
F
.53681 .88205 m .51022 .89047 L .51033 .8858 L 1 .977 0 r
F
.38812 .6289 m .36884 .6228 L .37668 .62072 L .761 .759 0 r
F
.3953 .6265 m .38812 .6289 L .37668 .62072 L .737 .745 0 r
F
.44842 .63602 m .44358 .63885 L .43147 .63396 L .568 .668 0 r
F
.46031 .64008 m .44358 .63885 L .44842 .63602 L .526 .643 0 r
F
.34429 .32327 m .34218 .30537 L .35124 .31087 L 1 .698 0 r
F
.34429 .32327 m .33486 .31866 L .34218 .30537 L F
.5634 .4351 m .57335 .44137 L .56329 .43769 L .553 .554 0 r
F
.55332 .43198 m .5634 .4351 L .56329 .43769 L .526 .541 0 r
F
.60356 .45219 m .61231 .46142 L .60238 .4572 L .683 .602 0 r
F
.59348 .44864 m .60356 .45219 L .60238 .4572 L .647 .588 0 r
F
.45933 .38696 m .45378 .37906 L .46229 .38531 L .496 .493 0 r
F
.45933 .38696 m .45034 .38108 L .45378 .37906 L F
.33291 .61872 m .31321 .60837 L .32211 .60696 L .856 .786 0 r
F
.3413 .61685 m .33291 .61872 L .32211 .60696 L .842 .778 0 r
F
.47574 .64073 m .47271 .64348 L .46031 .64008 L .452 .561 0 r
F
.48756 .64365 m .47271 .64348 L .47574 .64073 L .415 .484 0 r
F
.50023 .40754 m .49618 .40158 L .50185 .40751 L .444 .487 0 r
F
.50023 .40754 m .49375 .40161 L .49618 .40158 L F
.47928 .39714 m .4737 .39034 L .48162 .39636 L .455 .483 0 r
F
.47928 .39714 m .47079 .39133 L .4737 .39034 L F
.33486 .31866 m .33311 .30012 L .34218 .30537 L 1 .714 0 r
F
.33486 .31866 m .32542 .31425 L .33311 .30012 L F
.48952 .40222 m .48428 .39584 L .49152 .40182 L .446 .483 0 r
F
.48952 .40222 m .48162 .39636 L .48428 .39584 L F
.61384 .85766 m .59157 .87281 L .5888 .86793 L 1 1 0 r
F
.61384 .85766 m .61753 .86268 L .59157 .87281 L F
.53208 .42238 m .54157 .42387 L .54244 .42559 L .484 .521 0 r
F
.5313 .42122 m .54157 .42387 L .53208 .42238 L .482 .521 0 r
F
.61365 .45564 m .62226 .46556 L .61231 .46142 L .719 .617 0 r
F
.60356 .45219 m .61365 .45564 L .61231 .46142 L .683 .602 0 r
F
.54301 .42724 m .55299 .42983 L .55332 .43198 L .505 .532 0 r
F
.54244 .42559 m .55299 .42983 L .54301 .42724 L .504 .533 0 r
F
.45034 .38108 m .44527 .37253 L .45378 .37906 L .518 .495 0 r
F
.45034 .38108 m .44135 .37498 L .44527 .37253 L F
.55299 .42983 m .5634 .4351 L .55332 .43198 L .528 .545 0 r
F
.57349 .43817 m .58341 .44503 L .57335 .44137 L .584 .569 0 r
F
.5634 .4351 m .57349 .43817 L .57335 .44137 L .553 .554 0 r
F
.32542 .31425 m .32402 .29508 L .33311 .30012 L 1 .728 0 r
F
.32542 .31425 m .31597 .31001 L .32402 .29508 L F
.29545 .61142 m .27584 .59818 L .28516 .59714 L .902 .798 0 r
F
.30432 .60986 m .29545 .61142 L .28516 .59714 L .892 .793 0 r
F
.62374 .45899 m .6322 .4696 L .62226 .46556 L .753 .632 0 r
F
.61365 .45564 m .62374 .45899 L .62226 .46556 L .719 .617 0 r
F
.50185 .40751 m .49878 .40175 L .50359 .4076 L .442 .485 0 r
F
.50185 .40751 m .49618 .40158 L .49878 .40175 L F
.5313 .42122 m .54041 .42212 L .54157 .42387 L .482 .521 0 r
F
.53034 .42004 m .54041 .42212 L .5313 .42122 L .479 .52 0 r
F
.48385 .88743 m .48278 .89204 L .45559 .89154 L .927 .921 0 r
F
.51033 .8858 m .48278 .89204 L .48385 .88743 L .975 .948 0 r
F
.44135 .37498 m .43675 .36569 L .44527 .37253 L .55 .5 0 r
F
.44135 .37498 m .43235 .36868 L .43675 .36569 L F
.23871 .60292 m .21913 .58553 L .22876 .58482 L .953 .816 0 r
F
.24797 .60166 m .23871 .60292 L .22876 .58482 L .946 .812 0 r
F
.54817 .6575 m .55098 .65675 L .53808 .65351 L .369 0 0 r
F
.63384 .46221 m .64215 .47351 L .6322 .4696 L .786 .647 0 r
F
.62374 .45899 m .63384 .46221 L .6322 .4696 L .753 .632 0 r
F
.80566 .49701 m .81076 .51887 L .80088 .51699 L 1 .804 0 r
F
.80566 .49701 m .81576 .49825 L .81076 .51887 L F
.47079 .39133 m .46578 .38412 L .4737 .39034 L .456 .475 0 r
F
.47079 .39133 m .46229 .38531 L .46578 .38412 L F
.31597 .31001 m .31491 .29025 L .32402 .29508 L 1 .741 0 r
F
.31597 .31001 m .30651 .30593 L .31491 .29025 L F
.49152 .40182 m .48725 .39559 L .49375 .40161 L .437 .476 0 r
F
.49152 .40182 m .48428 .39584 L .48725 .39559 L F
.43235 .36868 m .42823 .35852 L .43675 .36569 L .594 .509 0 r
F
.43235 .36868 m .42336 .36218 L .42823 .35852 L F
.66632 .83732 m .64711 .85589 L .64253 .85073 L 1 .936 0 r
F
.66632 .83732 m .67177 .84251 L .64711 .85589 L F
.50359 .4076 m .50154 .4021 L .50543 .40782 L .44 .485 0 r
F
.50359 .4076 m .49878 .40175 L .50154 .4021 L F
.79556 .49572 m .80088 .51699 L .791 .51504 L 1 .799 0 r
F
.79556 .49572 m .80566 .49701 L .80088 .51699 L F
.53034 .42004 m .53897 .42035 L .54041 .42212 L .479 .52 0 r
F
.5292 .41885 m .53897 .42035 L .53034 .42004 L .476 .52 0 r
F
.46427 .6373 m .46031 .64008 L .44842 .63602 L .491 .609 0 r
F
.47574 .64073 m .46031 .64008 L .46427 .6373 L .452 .561 0 r
F
.58359 .44118 m .59348 .44864 L .58341 .44503 L .617 .584 0 r
F
.57349 .43817 m .58359 .44118 L .58341 .44503 L .584 .569 0 r
F
.36884 .6228 m .3497 .61507 L .35812 .61339 L .795 .765 0 r
F
.37668 .62072 m .36884 .6228 L .35812 .61339 L .775 .754 0 r
F
.54244 .42559 m .55224 .42759 L .55299 .42983 L .504 .533 0 r
F
.54157 .42387 m .55224 .42759 L .54244 .42559 L .502 .534 0 r
F
.64394 .46529 m .65209 .47727 L .64215 .47351 L .816 .661 0 r
F
.63384 .46221 m .64394 .46529 L .64215 .47351 L .786 .647 0 r
F
.78546 .49437 m .791 .51504 L .78111 .51303 L 1 .794 0 r
F
.78546 .49437 m .79556 .49572 L .791 .51504 L F
.48162 .39636 m .47703 .38972 L .48428 .39584 L .439 .47 0 r
F
.48162 .39636 m .4737 .39034 L .47703 .38972 L F
.42336 .36218 m .41971 .35105 L .42823 .35852 L .647 .523 0 r
F
.42336 .36218 m .41436 .35554 L .41971 .35105 L F
.56299 .43236 m .57349 .43817 L .5634 .4351 L .555 .56 0 r
F
.55299 .42983 m .56299 .43236 L .5634 .4351 L .528 .545 0 r
F
.65405 .46822 m .66204 .48087 L .65209 .47727 L .843 .674 0 r
F
.64394 .46529 m .65405 .46822 L .65209 .47727 L .816 .661 0 r
F
.41366 .63086 m .3953 .6265 L .40249 .62423 L .692 .73 0 r
F
.42014 .62836 m .41366 .63086 L .40249 .62423 L .663 .711 0 r
F
.43147 .63396 m .41366 .63086 L .42014 .62836 L .636 .706 0 r
F
.63793 .84557 m .61753 .86268 L .61384 .85766 L 1 .977 0 r
F
.63793 .84557 m .64253 .85073 L .61753 .86268 L F
.77536 .49296 m .78111 .51303 L .77121 .51095 L 1 .788 0 r
F
.77536 .49296 m .78546 .49437 L .78111 .51303 L F
.50543 .40782 m .50442 .40261 L .50734 .40815 L .441 .486 0 r
F
.50543 .40782 m .50154 .4021 L .50442 .40261 L F
.30651 .30593 m .30579 .28559 L .31491 .29025 L 1 .753 0 r
F
.30651 .30593 m .29704 .302 L .30579 .28559 L F
.5292 .41885 m .53726 .41857 L .53897 .42035 L .476 .52 0 r
F
.52789 .41767 m .53726 .41857 L .5292 .41885 L .473 .519 0 r
F
.57584 .67936 m .56728 .65909 L .56359 .6642 L .821 .068 0 r
F
.57584 .67936 m .58056 .68481 L .56728 .65909 L F
.55224 .42759 m .56299 .43236 L .55299 .42983 L .527 .548 0 r
F
.41436 .35554 m .41119 .34334 L .41971 .35105 L .707 .54 0 r
F
.41436 .35554 m .40536 .3488 L .41119 .34334 L F
.76525 .49147 m .77121 .51095 L .76131 .50879 L 1 .782 0 r
F
.76525 .49147 m .77536 .49296 L .77121 .51095 L F
.3413 .61685 m .32211 .60696 L .33102 .60564 L .842 .778 0 r
F
.3497 .61507 m .3413 .61685 L .33102 .60564 L .826 .769 0 r
F
.65405 .46822 m .66415 .471 L .66204 .48087 L .843 .674 0 r
F
.66415 .471 m .67198 .48432 L .66204 .48087 L .868 .688 0 r
F
.43716 .63132 m .43147 .63396 L .42014 .62836 L .603 .682 0 r
F
.44842 .63602 m .43147 .63396 L .43716 .63132 L .568 .668 0 r
F
.69498 .82793 m .6772 .84765 L .67177 .84251 L 1 .904 0 r
F
.69498 .82793 m .70123 .83298 L .6772 .84765 L F
.46229 .38531 m .45784 .37764 L .46578 .38412 L .461 .467 0 r
F
.46229 .38531 m .45378 .37906 L .45784 .37764 L F
.75515 .48991 m .76131 .50879 L .75141 .50654 L .995 .776 0 r
F
.75515 .48991 m .76525 .49147 L .76131 .50879 L F
.5937 .4441 m .60356 .45219 L .59348 .44864 L .651 .599 0 r
F
.58359 .44118 m .5937 .4441 L .59348 .44864 L .617 .584 0 r
F
.40536 .3488 m .40267 .33549 L .41119 .34334 L .77 .56 0 r
F
.40536 .3488 m .39636 .34207 L .40267 .33549 L F
.67426 .47363 m .68192 .48759 L .67198 .48432 L .89 .7 0 r
F
.66415 .471 m .67426 .47363 L .67198 .48432 L .868 .688 0 r
F
.42593 .89355 m .39519 .89339 L .39905 .88905 L .901 .887 0 r
F
.42889 .88909 m .42593 .89355 L .39905 .88905 L .886 .883 0 r
F
.45559 .89154 m .42593 .89355 L .42889 .88909 L .91 .902 0 r
F
.24797 .60166 m .22876 .58482 L .23841 .58417 L .946 .812 0 r
F
.25725 .60045 m .24797 .60166 L .23841 .58417 L .939 .808 0 r
F
.49375 .40161 m .49049 .39561 L .49618 .40158 L .43 .47 0 r
F
.49375 .40161 m .48725 .39559 L .49049 .39561 L F
.50734 .40815 m .50739 .4033 L .50932 .40859 L .442 .488 0 r
F
.50734 .40815 m .50442 .40261 L .50739 .4033 L F
.74504 .48826 m .75141 .50654 L .74149 .50419 L .987 .768 0 r
F
.74504 .48826 m .75515 .48991 L .75141 .50654 L F
.52789 .41767 m .5353 .41682 L .53726 .41857 L .473 .519 0 r
F
.52643 .41651 m .5353 .41682 L .52789 .41767 L .47 .517 0 r
F
.3953 .6265 m .37668 .62072 L .38453 .61876 L .737 .745 0 r
F
.40249 .62423 m .3953 .6265 L .38453 .61876 L .712 .73 0 r
F
.30432 .60986 m .28516 .59714 L .29448 .59616 L .892 .793 0 r
F
.31321 .60837 m .30432 .60986 L .29448 .59616 L .88 .786 0 r
F
.68438 .47611 m .69186 .49071 L .68192 .48759 L .909 .712 0 r
F
.67426 .47363 m .68438 .47611 L .68192 .48759 L .89 .7 0 r
F
.54157 .42387 m .55109 .42528 L .55224 .42759 L .502 .534 0 r
F
.54041 .42212 m .55109 .42528 L .54157 .42387 L .498 .534 0 r
F
.73493 .48651 m .74149 .50419 L .73158 .50175 L .978 .761 0 r
F
.73493 .48651 m .74504 .48826 L .74149 .50419 L F
.39636 .34207 m .39414 .32764 L .40267 .33549 L .831 .581 0 r
F
.39636 .34207 m .38735 .33542 L .39414 .32764 L F
.69449 .47844 m .7018 .49368 L .69186 .49071 L .927 .723 0 r
F
.68438 .47611 m .69449 .47844 L .69186 .49071 L .909 .712 0 r
F
.29704 .302 m .29665 .28108 L .30579 .28559 L 1 .763 0 r
F
.29704 .302 m .28755 .2982 L .29665 .28108 L F
.72482 .48467 m .73158 .50175 L .72166 .49918 L .967 .752 0 r
F
.72482 .48467 m .73493 .48651 L .73158 .50175 L F
.53594 .87745 m .53681 .88205 L .51033 .8858 L 1 .978 0 r
F
.56122 .87143 m .53681 .88205 L .53594 .87745 L 1 1 0 r
F
.56122 .87143 m .56304 .8761 L .53681 .88205 L F
.7046 .48064 m .71173 .4965 L .7018 .49368 L .942 .734 0 r
F
.69449 .47844 m .7046 .48064 L .7018 .49368 L .927 .723 0 r
F
.71471 .48271 m .72166 .49918 L .71173 .4965 L .955 .743 0 r
F
.71471 .48271 m .72482 .48467 L .72166 .49918 L F
.7046 .48064 m .71471 .48271 L .71173 .4965 L .942 .734 0 r
F
.39519 .89339 m .36369 .89099 L .36843 .88683 L .897 .876 0 r
F
.39905 .88905 m .39519 .89339 L .36843 .88683 L .885 .872 0 r
F
.50932 .40859 m .51042 .40413 L .51134 .40914 L .444 .492 0 r
F
.50932 .40859 m .50739 .4033 L .51042 .40413 L F
.58603 .86314 m .56304 .8761 L .56122 .87143 L 1 1 0 r
F
.58603 .86314 m .5888 .86793 L .56304 .8761 L F
.52643 .41651 m .53311 .41509 L .5353 .41682 L .47 .517 0 r
F
.52483 .41538 m .53311 .41509 L .52643 .41651 L .467 .516 0 r
F
.573 .4348 m .58359 .44118 L .57349 .43817 L .586 .576 0 r
F
.56299 .43236 m .573 .4348 L .57349 .43817 L .555 .56 0 r
F
.38735 .33542 m .38561 .31993 L .39414 .32764 L .887 .604 0 r
F
.38735 .33542 m .37834 .32893 L .38561 .31993 L F
.45761 .88702 m .45559 .89154 L .42889 .88909 L .893 .897 0 r
F
.48385 .88743 m .45559 .89154 L .45761 .88702 L .927 .921 0 r
F
.60382 .44692 m .61365 .45564 L .60356 .45219 L .685 .615 0 r
F
.5937 .4441 m .60382 .44692 L .60356 .45219 L .651 .599 0 r
F
.51134 .40914 m .51349 .40512 L .51338 .40979 L .447 .495 0 r
F
.51134 .40914 m .51042 .40413 L .51349 .40512 L F
.45378 .37906 m .4499 .37082 L .45784 .37764 L .473 .461 0 r
F
.45378 .37906 m .44527 .37253 L .4499 .37082 L F
.4737 .39034 m .46976 .38341 L .47703 .38972 L .431 .454 0 r
F
.4737 .39034 m .46578 .38412 L .46976 .38341 L F
.52483 .41538 m .53071 .41342 L .53311 .41509 L .467 .516 0 r
F
.52312 .41429 m .53071 .41342 L .52483 .41538 L .464 .514 0 r
F
.48428 .39584 m .48073 .38946 L .48725 .39559 L .425 .458 0 r
F
.48428 .39584 m .47703 .38972 L .48073 .38946 L F
.50074 .64385 m .49964 .64616 L .48756 .64365 L .339 .338 0 r
F
.51196 .64644 m .49964 .64616 L .50074 .64385 L .254 .192 0 r
F
.51196 .64644 m .51185 .6484 L .49964 .64616 L F
.51043 .88125 m .51033 .8858 L .48385 .88743 L .957 .945 0 r
F
.53594 .87745 m .51033 .8858 L .51043 .88125 L 1 .978 0 r
F
.37834 .32893 m .37706 .31247 L .38561 .31993 L .935 .626 0 r
F
.37834 .32893 m .36932 .32265 L .37706 .31247 L F
.45328 .63334 m .44842 .63602 L .43716 .63132 L .534 .639 0 r
F
.46427 .6373 m .44842 .63602 L .45328 .63334 L .491 .609 0 r
F
.49618 .40158 m .49396 .39588 L .49878 .40175 L .426 .467 0 r
F
.49618 .40158 m .49049 .39561 L .49396 .39588 L F
.28755 .2982 m .2875 .2767 L .29665 .28108 L 1 .773 0 r
F
.28755 .2982 m .27805 .29452 L .2875 .2767 L F
.51338 .40979 m .51655 .40623 L .51541 .41054 L .45 .499 0 r
F
.51338 .40979 m .51349 .40512 L .51655 .40623 L F
.52312 .41429 m .52813 .4118 L .53071 .41342 L .464 .514 0 r
F
.5213 .41326 m .52813 .4118 L .52312 .41429 L .461 .512 0 r
F
.55224 .42759 m .56206 .42951 L .56299 .43236 L .527 .548 0 r
F
.55109 .42528 m .56206 .42951 L .55224 .42759 L .524 .549 0 r
F
.48964 .64111 m .48756 .64365 L .47574 .64073 L .395 .45 0 r
F
.50074 .64385 m .48756 .64365 L .48964 .64111 L .339 .338 0 r
F
.54041 .42212 m .54955 .42293 L .55109 .42528 L .498 .534 0 r
F
.53897 .42035 m .54955 .42293 L .54041 .42212 L .493 .533 0 r
F
.5232 .64914 m .51185 .6484 L .51196 .64644 L .13 .114 0 r
F
.5232 .64914 m .52408 .65063 L .51185 .6484 L F
.51541 .41054 m .51957 .40747 L .51742 .41137 L .453 .503 0 r
F
.51541 .41054 m .51655 .40623 L .51957 .40747 L F
.5213 .41326 m .52539 .41027 L .52813 .4118 L .461 .512 0 r
F
.51939 .41228 m .52539 .41027 L .5213 .41326 L .458 .509 0 r
F
.56206 .42951 m .573 .4348 L .56299 .43236 L .554 .564 0 r
F
.61013 .85269 m .5888 .86793 L .58603 .86314 L 1 1 0 r
F
.61013 .85269 m .61384 .85766 L .5888 .86793 L F
.51742 .41137 m .52253 .40882 L .51939 .41228 L .455 .506 0 r
F
.51742 .41137 m .51957 .40747 L .52253 .40882 L F
.51939 .41228 m .52253 .40882 L .52539 .41027 L .458 .509 0 r
F
.36932 .32265 m .36851 .30534 L .37706 .31247 L .975 .649 0 r
F
.36932 .32265 m .36029 .31663 L .36851 .30534 L F
.55983 .66427 m .55098 .65675 L .54817 .6575 L .575 0 0 r
F
.55983 .66427 m .56359 .6642 L .55098 .65675 L F
.25725 .60045 m .23841 .58417 L .24807 .58356 L .939 .808 0 r
F
.26654 .59929 m .25725 .60045 L .24807 .58356 L .931 .803 0 r
F
.61395 .44962 m .62374 .45899 L .61365 .45564 L .718 .63 0 r
F
.60382 .44692 m .61395 .44962 L .61365 .45564 L .685 .615 0 r
F
.44527 .37253 m .44195 .36361 L .4499 .37082 L .495 .46 0 r
F
.44527 .37253 m .43675 .36569 L .44195 .36361 L F
.37668 .62072 m .35812 .61339 L .36655 .6118 L .775 .754 0 r
F
.38453 .61876 m .37668 .62072 L .36655 .6118 L .754 .742 0 r
F
.58304 .43715 m .5937 .4441 L .58359 .44118 L .617 .592 0 r
F
.573 .4348 m .58304 .43715 L .58359 .44118 L .586 .576 0 r
F
.27805 .29452 m .27834 .27244 L .2875 .2767 L 1 .781 0 r
F
.27805 .29452 m .26854 .29094 L .27834 .27244 L F
.47878 .63808 m .47574 .64073 L .46427 .6373 L .433 .526 0 r
F
.48964 .64111 m .47574 .64073 L .47878 .63808 L .395 .45 0 r
F
.36029 .31663 m .35993 .29856 L .36851 .30534 L 1 .67 0 r
F
.36029 .31663 m .35124 .31087 L .35993 .29856 L F
.3497 .61507 m .33102 .60564 L .33995 .6044 L .826 .769 0 r
F
.35812 .61339 m .3497 .61507 L .33995 .6044 L .808 .76 0 r
F
.66086 .83206 m .64253 .85073 L .63793 .84557 L 1 .938 0 r
F
.66086 .83206 m .66632 .83732 L .64253 .85073 L F
.49878 .40175 m .49764 .39639 L .50154 .4021 L .424 .467 0 r
F
.49878 .40175 m .49396 .39588 L .49764 .39639 L F
.31321 .60837 m .29448 .59616 L .30382 .59526 L .88 .786 0 r
F
.32211 .60696 m .31321 .60837 L .30382 .59526 L .867 .779 0 r
F
.36843 .88683 m .36369 .89099 L .33736 .88237 L .886 .863 0 r
F
.53897 .42035 m .54763 .42056 L .54955 .42293 L .493 .533 0 r
F
.53726 .41857 m .54763 .42056 L .53897 .42035 L .488 .531 0 r
F
.72354 .81727 m .70746 .83796 L .70123 .83298 L 1 .879 0 r
F
.72354 .81727 m .73055 .82204 L .70746 .83796 L F
.53436 .6523 m .52408 .65063 L .5232 .64914 L 0 .094 0 r
F
.53436 .6523 m .53622 .65337 L .52408 .65063 L F
.48492 .88292 m .48385 .88743 L .45761 .88702 L .907 .915 0 r
F
.51043 .88125 m .48385 .88743 L .48492 .88292 L .957 .945 0 r
F
.46578 .38412 m .46248 .37684 L .46976 .38341 L .425 .438 0 r
F
.46578 .38412 m .45784 .37764 L .46248 .37684 L F
.62409 .45218 m .63384 .46221 L .62374 .45899 L .75 .644 0 r
F
.61395 .44962 m .62409 .45218 L .62374 .45899 L .718 .63 0 r
F
.48725 .39559 m .48478 .38956 L .49049 .39561 L .416 .448 0 r
F
.48725 .39559 m .48073 .38946 L .48478 .38956 L F
.43675 .36569 m .43399 .35592 L .44195 .36361 L .533 .464 0 r
F
.43675 .36569 m .42823 .35852 L .43399 .35592 L F
.55109 .42528 m .56063 .42658 L .56206 .42951 L .524 .549 0 r
F
.54955 .42293 m .56063 .42658 L .55109 .42528 L .519 .549 0 r
F
.68871 .8228 m .67177 .84251 L .66632 .83732 L 1 .901 0 r
F
.68871 .8228 m .69498 .82793 L .67177 .84251 L F
.35124 .31087 m .35134 .29213 L .35993 .29856 L 1 .691 0 r
F
.35124 .31087 m .34218 .30537 L .35134 .29213 L F
.26854 .29094 m .26915 .26829 L .27834 .27244 L 1 .789 0 r
F
.26854 .29094 m .25902 .28745 L .26915 .26829 L F
.42014 .62836 m .40249 .62423 L .40971 .62209 L .663 .711 0 r
F
.42663 .626 m .42014 .62836 L .40971 .62209 L .632 .691 0 r
F
.43716 .63132 m .42014 .62836 L .42663 .626 L .603 .682 0 r
F
.47703 .38972 m .4742 .38318 L .48073 .38946 L .413 .435 0 r
F
.47703 .38972 m .46976 .38341 L .4742 .38318 L F
.63332 .84038 m .61384 .85766 L .61013 .85269 L 1 .984 0 r
F
.63332 .84038 m .63793 .84557 L .61384 .85766 L F
.50154 .4021 m .50148 .39713 L .50442 .40261 L .424 .469 0 r
F
.50154 .4021 m .49764 .39639 L .50148 .39713 L F
.5719 .43131 m .58304 .43715 L .573 .4348 L .583 .581 0 r
F
.56206 .42951 m .5719 .43131 L .573 .4348 L .554 .564 0 r
F
.53726 .41857 m .54535 .41821 L .54763 .42056 L .488 .531 0 r
F
.5353 .41682 m .54535 .41821 L .53726 .41857 L .482 .529 0 r
F
.26654 .59929 m .24807 .58356 L .25773 .58301 L .931 .803 0 r
F
.27584 .59818 m .26654 .59929 L .25773 .58301 L .922 .798 0 r
F
.59308 .43937 m .60382 .44692 L .5937 .4441 L .65 .608 0 r
F
.58304 .43715 m .59308 .43937 L .5937 .4441 L .617 .592 0 r
F
.63424 .45461 m .64394 .46529 L .63384 .46221 L .779 .659 0 r
F
.62409 .45218 m .63424 .45461 L .63384 .46221 L .75 .644 0 r
F
.40249 .62423 m .38453 .61876 L .3924 .61692 L .712 .73 0 r
F
.40971 .62209 m .40249 .62423 L .3924 .61692 L .685 .713 0 r
F
.42823 .35852 m .42604 .34772 L .43399 .35592 L .588 .475 0 r
F
.42823 .35852 m .41971 .35105 L .42604 .34772 L F
.56063 .42658 m .5719 .43131 L .56206 .42951 L .55 .566 0 r
F
.46825 .63465 m .46427 .6373 L .45328 .63334 L .462 .576 0 r
F
.47878 .63808 m .46427 .6373 L .46825 .63465 L .433 .526 0 r
F
.34218 .30537 m .34273 .28603 L .35134 .29213 L 1 .709 0 r
F
.34218 .30537 m .33311 .30012 L .34273 .28603 L F
.44287 .62883 m .43716 .63132 L .42663 .626 L .571 .657 0 r
F
.45328 .63334 m .43716 .63132 L .44287 .62883 L .534 .639 0 r
F
.25902 .28745 m .25995 .26422 L .26915 .26829 L 1 .795 0 r
F
.25902 .28745 m .24948 .28404 L .25995 .26422 L F
.42889 .88909 m .39905 .88905 L .40293 .88476 L .886 .883 0 r
F
.43186 .88469 m .42889 .88909 L .40293 .88476 L .87 .877 0 r
F
.45761 .88702 m .42889 .88909 L .43186 .88469 L .893 .897 0 r
F
.50442 .40261 m .50545 .39807 L .50739 .4033 L .426 .473 0 r
F
.50442 .40261 m .50148 .39713 L .50545 .39807 L F
.45784 .37764 m .45519 .36994 L .46248 .37684 L .423 .421 0 r
F
.45784 .37764 m .4499 .37082 L .45519 .36994 L F
.5353 .41682 m .54273 .41588 L .54535 .41821 L .482 .529 0 r
F
.53311 .41509 m .54273 .41588 L .5353 .41682 L .477 .527 0 r
F
.41971 .35105 m .41809 .33903 L .42604 .34772 L .659 .494 0 r
F
.41971 .35105 m .41119 .34334 L .41809 .33903 L F
.6444 .45689 m .65405 .46822 L .64394 .46529 L .807 .672 0 r
F
.63424 .45461 m .6444 .45689 L .64394 .46529 L .779 .659 0 r
F
.49049 .39561 m .48913 .38999 L .49396 .39588 L .411 .442 0 r
F
.49049 .39561 m .48478 .38956 L .48913 .38999 L F
.54955 .42293 m .55871 .42362 L .56063 .42658 L .519 .549 0 r
F
.54763 .42056 m .55871 .42362 L .54955 .42293 L .512 .548 0 r
F
.39905 .88905 m .36843 .88683 L .37318 .88272 L .885 .872 0 r
F
.40293 .88476 m .39905 .88905 L .37318 .88272 L .871 .867 0 r
F
.32211 .60696 m .30382 .59526 L .31317 .59444 L .867 .779 0 r
F
.33102 .60564 m .32211 .60696 L .31317 .59444 L .853 .772 0 r
F
.55222 .65835 m .55284 .65893 L .54534 .65643 L 0 .069 0 r
F
.54534 .65643 m .54817 .6575 L .53744 .65379 L 0 .066 0 r
F
.55604 .66192 m .55983 .66427 L .54817 .6575 L 0 .04 0 r
F
.55604 .66192 m .54817 .6575 L .54534 .65643 L F
.55284 .65893 m .55604 .66192 L .54534 .65643 L 0 .069 0 r
F
.54534 .65643 m .53744 .65379 L .53622 .65337 L 0 .066 0 r
F
.53507 .87301 m .53594 .87745 L .51043 .88125 L 1 .977 0 r
F
.55939 .86692 m .53594 .87745 L .53507 .87301 L 1 1 0 r
F
.55939 .86692 m .56122 .87143 L .53594 .87745 L F
.60314 .44147 m .61395 .44962 L .60382 .44692 L .682 .624 0 r
F
.59308 .43937 m .60314 .44147 L .60382 .44692 L .65 .608 0 r
F
.41119 .34334 m .41014 .32994 L .41809 .33903 L .739 .517 0 r
F
.41119 .34334 m .40267 .33549 L .41014 .32994 L F
.58324 .85849 m .56122 .87143 L .55939 .86692 L 1 1 0 r
F
.58324 .85849 m .58603 .86314 L .56122 .87143 L F
.33311 .30012 m .33411 .28021 L .34273 .28603 L 1 .726 0 r
F
.33311 .30012 m .32402 .29508 L .33411 .28021 L F
.50739 .4033 m .5095 .39921 L .51042 .40413 L .429 .478 0 r
F
.50739 .4033 m .50545 .39807 L .5095 .39921 L F
.53311 .41509 m .53981 .41361 L .54273 .41588 L .477 .527 0 r
F
.53071 .41342 m .53981 .41361 L .53311 .41509 L .471 .524 0 r
F
.35812 .61339 m .33995 .6044 L .3489 .60326 L .808 .76 0 r
F
.36655 .6118 m .35812 .61339 L .3489 .60326 L .789 .749 0 r
F
.45965 .88258 m .45761 .88702 L .43186 .88469 L .873 .89 0 r
F
.48492 .88292 m .45761 .88702 L .45965 .88258 L .907 .915 0 r
F
.65456 .45902 m .66415 .471 L .65405 .46822 L .832 .685 0 r
F
.6444 .45689 m .65456 .45902 L .65405 .46822 L .807 .672 0 r
F
.38453 .61876 m .36655 .6118 L .37501 .61034 L .754 .742 0 r
F
.3924 .61692 m .38453 .61876 L .37501 .61034 L .73 .728 0 r
F
.58176 .433 m .59308 .43937 L .58304 .43715 L .614 .598 0 r
F
.5719 .43131 m .58176 .433 L .58304 .43715 L .583 .581 0 r
F
.27584 .59818 m .25773 .58301 L .26741 .58252 L .922 .798 0 r
F
.28516 .59714 m .27584 .59818 L .26741 .58252 L .913 .793 0 r
F
.24948 .28404 m .25074 .26022 L .25995 .26422 L 1 .802 0 r
F
.24948 .28404 m .23993 .2807 L .25074 .26022 L F
.40267 .33549 m .40219 .32066 L .41014 .32994 L .821 .544 0 r
F
.40267 .33549 m .39414 .32764 L .40219 .32066 L F
.46976 .38341 m .46766 .37669 L .4742 .38318 L .401 .408 0 r
F
.46976 .38341 m .46248 .37684 L .46766 .37669 L F
.48073 .38946 m .47906 .38342 L .48478 .38956 L .401 .419 0 r
F
.48073 .38946 m .4742 .38318 L .47906 .38342 L F
.71652 .81241 m .70123 .83298 L .69498 .82793 L 1 .875 0 r
F
.71652 .81241 m .72354 .81727 L .70123 .83298 L F
.51053 .87682 m .51043 .88125 L .48492 .88292 L .933 .939 0 r
F
.53507 .87301 m .51043 .88125 L .51053 .87682 L 1 .977 0 r
F
.51042 .40413 m .5136 .40053 L .51349 .40512 L .433 .485 0 r
F
.51042 .40413 m .5095 .39921 L .5136 .40053 L F
.53071 .41342 m .53661 .41141 L .53981 .41361 L .471 .524 0 r
F
.52813 .4118 m .53661 .41141 L .53071 .41342 L .465 .52 0 r
F
.60642 .84779 m .58603 .86314 L .58324 .85849 L 1 1 0 r
F
.60642 .84779 m .61013 .85269 L .58603 .86314 L F
.4499 .37082 m .44789 .36258 L .45519 .36994 L .429 .408 0 r
F
.4499 .37082 m .44195 .36361 L .44789 .36258 L F
.56063 .42658 m .57019 .42776 L .5719 .43131 L .55 .566 0 r
F
.55871 .42362 m .57019 .42776 L .56063 .42658 L .543 .566 0 r
F
.45816 .63079 m .45328 .63334 L .44287 .62883 L .502 .609 0 r
F
.46825 .63465 m .45328 .63334 L .45816 .63079 L .462 .576 0 r
F
.65456 .45902 m .66473 .46101 L .66415 .471 L .832 .685 0 r
F
.66473 .46101 m .67426 .47363 L .66415 .471 L .855 .698 0 r
F
.65538 .82671 m .63793 .84557 L .63332 .84038 L 1 .938 0 r
F
.65538 .82671 m .66086 .83206 L .63793 .84557 L F
.49396 .39588 m .49373 .39072 L .49764 .39639 L .408 .441 0 r
F
.49396 .39588 m .48913 .38999 L .49373 .39072 L F
.39414 .32764 m .39424 .31145 L .40219 .32066 L .896 .573 0 r
F
.39414 .32764 m .38561 .31993 L .39424 .31145 L F
.32402 .29508 m .32546 .27464 L .33411 .28021 L 1 .741 0 r
F
.32402 .29508 m .31491 .29025 L .32546 .27464 L F
.57019 .42776 m .58176 .433 L .5719 .43131 L .578 .584 0 r
F
.54763 .42056 m .55631 .42066 L .55871 .42362 L .512 .548 0 r
F
.54535 .41821 m .55631 .42066 L .54763 .42056 L .504 .546 0 r
F
.51349 .40512 m .51768 .40201 L .51655 .40623 L .438 .492 0 r
F
.51349 .40512 m .5136 .40053 L .51768 .40201 L F
.52813 .4118 m .53316 .4093 L .53661 .41141 L .465 .52 0 r
F
.52539 .41027 m .53316 .4093 L .52813 .4118 L .459 .516 0 r
F
.61322 .44343 m .62409 .45218 L .61395 .44962 L .714 .64 0 r
F
.60314 .44147 m .61322 .44343 L .61395 .44962 L .682 .624 0 r
F
.36843 .88683 m .33736 .88237 L .34295 .8785 L .886 .863 0 r
F
.37318 .88272 m .36843 .88683 L .34295 .8785 L .875 .859 0 r
F
.68242 .81755 m .66632 .83732 L .66086 .83206 L 1 .898 0 r
F
.68242 .81755 m .68871 .8228 L .66632 .83732 L F
.23993 .2807 m .24151 .2563 L .25074 .26022 L 1 .807 0 r
F
.23993 .2807 m .23037 .27743 L .24151 .2563 L F
.51655 .40623 m .52173 .40364 L .51957 .40747 L .443 .499 0 r
F
.51655 .40623 m .51768 .40201 L .52173 .40364 L F
.52539 .41027 m .52951 .4073 L .53316 .4093 L .459 .516 0 r
F
.52253 .40882 m .52951 .4073 L .52539 .41027 L .454 .511 0 r
F
.67491 .46285 m .68438 .47611 L .67426 .47363 L .875 .71 0 r
F
.66473 .46101 m .67491 .46285 L .67426 .47363 L .855 .698 0 r
F
.38561 .31993 m .38627 .30255 L .39424 .31145 L .96 .603 0 r
F
.38561 .31993 m .37706 .31247 L .38627 .30255 L F
.50184 .64145 m .50074 .64385 L .48964 .64111 L .331 .336 0 r
F
.51206 .64423 m .50074 .64385 L .50184 .64145 L .263 .223 0 r
F
.51206 .64423 m .51196 .64644 L .50074 .64385 L F
.51957 .40747 m .52568 .4054 L .52253 .40882 L .448 .505 0 r
F
.51957 .40747 m .52173 .40364 L .52568 .4054 L F
.52253 .40882 m .52568 .4054 L .52951 .4073 L .454 .511 0 r
F
.49173 .63857 m .48964 .64111 L .47878 .63808 L .381 .429 0 r
F
.50184 .64145 m .48964 .64111 L .49173 .63857 L .331 .336 0 r
F
.33102 .60564 m .31317 .59444 L .32253 .5937 L .853 .772 0 r
F
.33995 .6044 m .33102 .60564 L .32253 .5937 L .838 .763 0 r
F
.68509 .46456 m .69449 .47844 L .68438 .47611 L .893 .721 0 r
F
.67491 .46285 m .68509 .46456 L .68438 .47611 L .875 .71 0 r
F
.28516 .59714 m .26741 .58252 L .27709 .58209 L .913 .793 0 r
F
.29448 .59616 m .28516 .59714 L .27709 .58209 L .903 .787 0 r
F
.59164 .43454 m .60314 .44147 L .59308 .43937 L .646 .615 0 r
F
.58176 .433 m .59164 .43454 L .59308 .43937 L .614 .598 0 r
F
.44195 .36361 m .44059 .35465 L .44789 .36258 L .449 .401 0 r
F
.44195 .36361 m .43399 .35592 L .44059 .35465 L F
.52231 .64711 m .51196 .64644 L .51206 .64423 L .173 .119 0 r
F
.52231 .64711 m .5232 .64914 L .51196 .64644 L F
.31491 .29025 m .3168 .26928 L .32546 .27464 L 1 .755 0 r
F
.31491 .29025 m .30579 .28559 L .3168 .26928 L F
.48599 .87852 m .48492 .88292 L .45965 .88258 L .883 .907 0 r
F
.51053 .87682 m .48492 .88292 L .48599 .87852 L .933 .939 0 r
F
.6287 .83518 m .61013 .85269 L .60642 .84779 L 1 .991 0 r
F
.6287 .83518 m .63332 .84038 L .61013 .85269 L F
.42663 .626 m .40971 .62209 L .41694 .62009 L .632 .691 0 r
F
.43315 .62379 m .42663 .626 L .41694 .62009 L .602 .668 0 r
F
.44287 .62883 m .42663 .626 L .43315 .62379 L .571 .657 0 r
F
.37706 .31247 m .37829 .29411 L .38627 .30255 L 1 .631 0 r
F
.37706 .31247 m .36851 .30534 L .37829 .29411 L F
.40971 .62209 m .3924 .61692 L .40029 .61521 L .685 .713 0 r
F
.41694 .62009 m .40971 .62209 L .40029 .61521 L .657 .695 0 r
F
.49764 .39639 m .49854 .39172 L .50148 .39713 L .408 .444 0 r
F
.49764 .39639 m .49373 .39072 L .49854 .39172 L F
.54535 .41821 m .55346 .41773 L .55631 .42066 L .504 .546 0 r
F
.54273 .41588 m .55346 .41773 L .54535 .41821 L .496 .543 0 r
F
.57111 .67389 m .56359 .6642 L .55983 .66427 L .585 .019 0 r
F
.57111 .67389 m .57584 .67936 L .56359 .6642 L F
.48183 .63548 m .47878 .63808 L .46825 .63465 L .417 .498 0 r
F
.49173 .63857 m .47878 .63808 L .48183 .63548 L .381 .429 0 r
F
.6233 .44524 m .63424 .45461 L .62409 .45218 L .743 .655 0 r
F
.61322 .44343 m .6233 .44524 L .62409 .45218 L .714 .64 0 r
F
.69527 .46613 m .7046 .48064 L .69449 .47844 L .91 .731 0 r
F
.68509 .46456 m .69527 .46613 L .69449 .47844 L .893 .721 0 r
F
.46248 .37684 m .4611 .36992 L .46766 .37669 L .389 .378 0 r
F
.46248 .37684 m .45519 .36994 L .4611 .36992 L F
.48478 .38956 m .48427 .38408 L .48913 .38999 L .392 .409 0 r
F
.48478 .38956 m .47906 .38342 L .48427 .38408 L F
.55871 .42362 m .56789 .42418 L .57019 .42776 L .543 .566 0 r
F
.55631 .42066 m .56789 .42418 L .55871 .42362 L .535 .566 0 r
F
.36655 .6118 m .3489 .60326 L .35786 .60223 L .789 .749 0 r
F
.37501 .61034 m .36655 .6118 L .35786 .60223 L .769 .737 0 r
F
.70546 .46758 m .71471 .48271 L .7046 .48064 L .925 .74 0 r
F
.69527 .46613 m .70546 .46758 L .7046 .48064 L .91 .731 0 r
F
.36851 .30534 m .37029 .2862 L .37829 .29411 L 1 .659 0 r
F
.36851 .30534 m .35993 .29856 L .37029 .2862 L F
.4742 .38318 m .47332 .37715 L .47906 .38342 L .382 .382 0 r
F
.4742 .38318 m .46766 .37669 L .47332 .37715 L F
.43399 .35592 m .43329 .34597 L .44059 .35465 L .493 .405 0 r
F
.43399 .35592 m .42604 .34772 L .43329 .34597 L F
.57978 .42879 m .59164 .43454 L .58176 .433 L .608 .602 0 r
F
.57019 .42776 m .57978 .42879 L .58176 .433 L .578 .584 0 r
F
.44861 .62649 m .44287 .62883 L .43315 .62379 L .539 .631 0 r
F
.45816 .63079 m .44287 .62883 L .44861 .62649 L .502 .609 0 r
F
.30579 .28559 m .30811 .26411 L .3168 .26928 L 1 .767 0 r
F
.30579 .28559 m .29665 .28108 L .30811 .26411 L F
.22876 .58482 m .21913 .58553 L .21169 .566 L .963 .812 0 r
F
.71565 .46891 m .72482 .48467 L .71471 .48271 L .938 .749 0 r
F
.70546 .46758 m .71565 .46891 L .71471 .48271 L .925 .74 0 r
F
.53248 .65031 m .5232 .64914 L .52231 .64711 L .066 .101 0 r
F
.53248 .65031 m .53436 .6523 L .5232 .64914 L F
.3924 .61692 m .37501 .61034 L .38348 .60899 L .73 .728 0 r
F
.40029 .61521 m .3924 .61692 L .38348 .60899 L .705 .712 0 r
F
.70948 .80744 m .69498 .82793 L .68871 .8228 L 1 .87 0 r
F
.70948 .80744 m .71652 .81241 L .69498 .82793 L F
.56789 .42418 m .57978 .42879 L .57019 .42776 L .57 .585 0 r
F
.54273 .41588 m .55019 .41485 L .55346 .41773 L .496 .543 0 r
F
.53981 .41361 m .55019 .41485 L .54273 .41588 L .486 .539 0 r
F
.50148 .39713 m .50351 .39296 L .50545 .39807 L .41 .451 0 r
F
.50148 .39713 m .49854 .39172 L .50351 .39296 L F
.43186 .88469 m .40293 .88476 L .40682 .88054 L .87 .877 0 r
F
.43484 .88037 m .43186 .88469 L .40682 .88054 L .852 .871 0 r
F
.45965 .88258 m .43186 .88469 L .43484 .88037 L .873 .89 0 r
F
.47225 .6321 m .46825 .63465 L .45816 .63079 L .444 .547 0 r
F
.48183 .63548 m .46825 .63465 L .47225 .6321 L .417 .498 0 r
F
.40293 .88476 m .37318 .88272 L .37795 .87866 L .871 .867 0 r
F
.40682 .88054 m .40293 .88476 L .37795 .87866 L .856 .862 0 r
F
.6334 .44691 m .6444 .45689 L .63424 .45461 L .771 .669 0 r
F
.6233 .44524 m .6334 .44691 L .63424 .45461 L .743 .655 0 r
F
.72584 .47014 m .73493 .48651 L .72482 .48467 L .949 .758 0 r
F
.71565 .46891 m .72584 .47014 L .72482 .48467 L .938 .749 0 r
F
.60153 .43594 m .61322 .44343 L .60314 .44147 L .677 .632 0 r
F
.59164 .43454 m .60153 .43594 L .60314 .44147 L .646 .615 0 r
F
.29448 .59616 m .27709 .58209 L .28679 .58173 L .903 .787 0 r
F
.30382 .59526 m .29448 .59616 L .28679 .58173 L .892 .781 0 r
F
.35993 .29856 m .36227 .27881 L .37029 .2862 L 1 .684 0 r
F
.35993 .29856 m .35134 .29213 L .36227 .27881 L F
.73604 .47126 m .74504 .48826 L .73493 .48651 L .96 .765 0 r
F
.72584 .47014 m .73604 .47126 L .73493 .48651 L .949 .758 0 r
F
.42604 .34772 m .42599 .33643 L .43329 .34597 L .569 .423 0 r
F
.42604 .34772 m .41809 .33903 L .42599 .33643 L F
.33995 .6044 m .32253 .5937 L .33191 .59305 L .838 .763 0 r
F
.3489 .60326 m .33995 .6044 L .33191 .59305 L .821 .754 0 r
F
.74624 .4723 m .75515 .48991 L .74504 .48826 L .969 .772 0 r
F
.73604 .47126 m .74624 .4723 L .74504 .48826 L .96 .765 0 r
F
.55755 .86261 m .55939 .86692 L .53507 .87301 L 1 1 0 r
F
.58045 .85402 m .55939 .86692 L .55755 .86261 L F
.58045 .85402 m .58324 .85849 L .55939 .86692 L F
.34295 .8785 m .33736 .88237 L .31259 .87202 L .881 .852 0 r
F
.5342 .86874 m .53507 .87301 L .51053 .87682 L .978 .971 0 r
F
.55755 .86261 m .53507 .87301 L .5342 .86874 L 1 1 0 r
F
.53981 .41361 m .54654 .41206 L .55019 .41485 L .486 .539 0 r
F
.53661 .41141 m .54654 .41206 L .53981 .41361 L .477 .534 0 r
F
.45519 .36994 m .45453 .36273 L .4611 .36992 L .378 .346 0 r
F
.45519 .36994 m .44789 .36258 L .45453 .36273 L F
.64988 .82126 m .63332 .84038 L .6287 .83518 L 1 .937 0 r
F
.64988 .82126 m .65538 .82671 L .63332 .84038 L F
.48913 .38999 m .4898 .3851 L .49373 .39072 L .387 .406 0 r
F
.48913 .38999 m .48427 .38408 L .4898 .3851 L F
.50545 .39807 m .50858 .39442 L .5095 .39921 L .414 .46 0 r
F
.50545 .39807 m .50351 .39296 L .50858 .39442 L F
.55631 .42066 m .56502 .42062 L .56789 .42418 L .535 .566 0 r
F
.55346 .41773 m .56502 .42062 L .55631 .42066 L .524 .563 0 r
F
.67611 .81218 m .66086 .83206 L .65538 .82671 L 1 .893 0 r
F
.67611 .81218 m .68242 .81755 L .66086 .83206 L F
.75644 .47324 m .76525 .49147 L .75515 .48991 L .977 .779 0 r
F
.74624 .4723 m .75644 .47324 L .75515 .48991 L .969 .772 0 r
F
.29665 .28108 m .29941 .25909 L .30811 .26411 L 1 .777 0 r
F
.29665 .28108 m .2875 .2767 L .29941 .25909 L F
.46168 .87825 m .45965 .88258 L .43484 .88037 L .85 .881 0 r
F
.48599 .87852 m .45965 .88258 L .46168 .87825 L .883 .907 0 r
F
.22876 .58482 m .21169 .566 L .22162 .56592 L .963 .812 0 r
F
.23841 .58417 m .22876 .58482 L .22162 .56592 L .957 .808 0 r
F
.74393 .80067 m .73055 .82204 L .72354 .81727 L 1 .857 0 r
F
.74393 .80067 m .75165 .80514 L .73055 .82204 L F
.76665 .47411 m .77536 .49296 L .76525 .49147 L .985 .785 0 r
F
.75644 .47324 m .76665 .47411 L .76525 .49147 L .977 .779 0 r
F
.64351 .44842 m .65456 .45902 L .6444 .45689 L .797 .682 0 r
F
.6334 .44691 m .64351 .44842 L .6444 .45689 L .771 .669 0 r
F
.41809 .33903 m .41871 .32599 L .42599 .33643 L .674 .453 0 r
F
.41809 .33903 m .41014 .32994 L .41871 .32599 L F
.60269 .843 m .58324 .85849 L .58045 .85402 L 1 1 0 r
F
.60269 .843 m .60642 .84779 L .58324 .85849 L F
.77685 .47491 m .78546 .49437 L .77536 .49296 L .991 .79 0 r
F
.76665 .47411 m .77685 .47491 L .77536 .49296 L .985 .785 0 r
F
.35134 .29213 m .35422 .27186 L .36227 .27881 L 1 .707 0 r
F
.35134 .29213 m .34273 .28603 L .35422 .27186 L F
.78706 .47565 m .79556 .49572 L .78546 .49437 L .997 .796 0 r
F
.77685 .47491 m .78706 .47565 L .78546 .49437 L .991 .79 0 r
F
.37318 .88272 m .34295 .8785 L .34855 .87467 L .875 .859 0 r
F
.37795 .87866 m .37318 .88272 L .34855 .87467 L .862 .854 0 r
F
.51064 .87256 m .51053 .87682 L .48599 .87852 L .902 .928 0 r
F
.5342 .86874 m .51053 .87682 L .51064 .87256 L .978 .971 0 r
F
.79727 .47632 m .80566 .49701 L .79556 .49572 L 1 .8 0 r
F
.78706 .47565 m .79727 .47632 L .79556 .49572 L .997 .796 0 r
F
.80749 .47693 m .81576 .49825 L .80566 .49701 L 1 .805 0 r
F
.79727 .47632 m .80749 .47693 L .80566 .49701 L 1 .8 0 r
F
.53661 .41141 m .54253 .40937 L .54654 .41206 L .477 .534 0 r
F
.53316 .4093 m .54253 .40937 L .53661 .41141 L .467 .528 0 r
F
.5095 .39921 m .51371 .39607 L .5136 .40053 L .419 .471 0 r
F
.5095 .39921 m .50858 .39442 L .51371 .39607 L F
.80749 .47693 m .8177 .4775 L .81576 .49825 L 1 .805 0 r
F
.46306 .62837 m .45816 .63079 L .44861 .62649 L .476 .581 0 r
F
.47225 .6321 m .45816 .63079 L .46306 .62837 L .444 .547 0 r
F
.58938 .42967 m .60153 .43594 L .59164 .43454 L .638 .62 0 r
F
.57978 .42879 m .58938 .42967 L .59164 .43454 L .608 .602 0 r
F
.41014 .32994 m .41143 .31488 L .41871 .32599 L .793 .492 0 r
F
.41014 .32994 m .40219 .32066 L .41143 .31488 L F
.61144 .43718 m .6233 .44524 L .61322 .44343 L .707 .648 0 r
F
.60153 .43594 m .61144 .43718 L .61322 .44343 L .677 .632 0 r
F
.54248 .65404 m .53436 .6523 L .53248 .65031 L 0 .085 0 r
F
.54248 .65404 m .54534 .65643 L .53436 .6523 L F
.37501 .61034 m .35786 .60223 L .36684 .60131 L .769 .737 0 r
F
.38348 .60899 m .37501 .61034 L .36684 .60131 L .747 .724 0 r
F
.30382 .59526 m .28679 .58173 L .29649 .58145 L .892 .781 0 r
F
.31317 .59444 m .30382 .59526 L .29649 .58145 L .879 .773 0 r
F
.47906 .38342 m .47941 .37815 L .48427 .38408 L .367 .365 0 r
F
.47906 .38342 m .47332 .37715 L .47941 .37815 L F
.46766 .37669 m .46757 .37071 L .47332 .37715 L .358 .337 0 r
F
.46766 .37669 m .4611 .36992 L .46757 .37071 L F
.56789 .42418 m .5771 .42459 L .57978 .42879 L .57 .585 0 r
F
.56502 .42062 m .5771 .42459 L .56789 .42418 L .56 .585 0 r
F
.2875 .2767 m .29069 .2542 L .29941 .25909 L 1 .787 0 r
F
.2875 .2767 m .27834 .27244 L .29069 .2542 L F
.41694 .62009 m .40029 .61521 L .4082 .61364 L .657 .695 0 r
F
.4242 .61824 m .41694 .62009 L .4082 .61364 L .628 .674 0 r
F
.43315 .62379 m .41694 .62009 L .4242 .61824 L .602 .668 0 r
F
.23841 .58417 m .22162 .56592 L .23156 .5659 L .957 .808 0 r
F
.24807 .58356 m .23841 .58417 L .23156 .5659 L .95 .804 0 r
F
.53316 .4093 m .53822 .40679 L .54253 .40937 L .467 .528 0 r
F
.52951 .4073 m .53822 .40679 L .53316 .4093 L .458 .521 0 r
F
.65362 .44979 m .66473 .46101 L .65456 .45902 L .821 .695 0 r
F
.64351 .44842 m .65362 .44979 L .65456 .45902 L .797 .682 0 r
F
.5136 .40053 m .51883 .3979 L .51768 .40201 L .425 .482 0 r
F
.5136 .40053 m .51371 .39607 L .51883 .3979 L F
.40219 .32066 m .40415 .30359 L .41143 .31488 L .905 .533 0 r
F
.40219 .32066 m .39424 .31145 L .40415 .30359 L F
.5771 .42459 m .58938 .42967 L .57978 .42879 L .599 .604 0 r
F
.62406 .82997 m .60642 .84779 L .60269 .843 L 1 1 0 r
F
.62406 .82997 m .6287 .83518 L .60642 .84779 L F
.55346 .41773 m .5616 .41712 L .56502 .42062 L .524 .563 0 r
F
.55019 .41485 m .5616 .41712 L .55346 .41773 L .512 .56 0 r
F
.43968 .62173 m .43315 .62379 L .4242 .61824 L .571 .644 0 r
F
.44861 .62649 m .43315 .62379 L .43968 .62173 L .539 .631 0 r
F
.49373 .39072 m .49558 .38643 L .49854 .39172 L .387 .41 0 r
F
.49373 .39072 m .4898 .3851 L .49558 .38643 L F
.44789 .36258 m .44796 .35495 L .45453 .36273 L .373 .317 0 r
F
.44789 .36258 m .44059 .35465 L .44796 .35495 L F
.34273 .28603 m .34616 .2653 L .35422 .27186 L 1 .728 0 r
F
.34273 .28603 m .33411 .28021 L .34616 .2653 L F
.70241 .80236 m .68871 .8228 L .68242 .81755 L 1 .864 0 r
F
.70241 .80236 m .70948 .80744 L .68871 .8228 L F
.52951 .4073 m .53364 .40435 L .53822 .40679 L .458 .521 0 r
F
.52568 .4054 m .53364 .40435 L .52951 .4073 L .448 .513 0 r
F
.51768 .40201 m .52389 .39989 L .52173 .40364 L .431 .493 0 r
F
.51768 .40201 m .51883 .3979 L .52389 .39989 L F
.39424 .31145 m .39686 .29271 L .40415 .30359 L .995 .573 0 r
F
.39424 .31145 m .38627 .30255 L .39686 .29271 L F
.52568 .4054 m .52885 .40205 L .53364 .40435 L .448 .513 0 r
F
.52173 .40364 m .52885 .40205 L .52568 .4054 L .439 .503 0 r
F
.3489 .60326 m .33191 .59305 L .3413 .59251 L .821 .754 0 r
F
.35786 .60223 m .3489 .60326 L .3413 .59251 L .803 .744 0 r
F
.52173 .40364 m .52389 .39989 L .52885 .40205 L .439 .503 0 r
F
.40029 .61521 m .38348 .60899 L .39197 .60777 L .705 .712 0 r
F
.4082 .61364 m .40029 .61521 L .39197 .60777 L .679 .696 0 r
F
.48707 .87426 m .48599 .87852 L .46168 .87825 L .852 .894 0 r
F
.51064 .87256 m .48599 .87852 L .48707 .87426 L .902 .928 0 r
F
.49383 .63598 m .49173 .63857 L .48183 .63548 L .374 .421 0 r
F
.50295 .63887 m .49173 .63857 L .49383 .63598 L .333 .348 0 r
F
.50295 .63887 m .50184 .64145 L .49173 .63857 L F
.65362 .44979 m .66375 .45101 L .66473 .46101 L .821 .695 0 r
F
.66375 .45101 m .67491 .46285 L .66473 .46101 L .842 .707 0 r
F
.51217 .64169 m .50184 .64145 L .50295 .63887 L .282 .265 0 r
F
.51217 .64169 m .51206 .64423 L .50184 .64145 L F
.62137 .43827 m .6334 .44691 L .6233 .44524 L .735 .663 0 r
F
.61144 .43718 m .62137 .43827 L .6233 .44524 L .707 .648 0 r
F
.38627 .30255 m .38955 .28262 L .39686 .29271 L 1 .612 0 r
F
.38627 .30255 m .37829 .29411 L .38955 .28262 L F
.27834 .27244 m .28195 .24942 L .29069 .2542 L 1 .795 0 r
F
.27834 .27244 m .26915 .26829 L .28195 .24942 L F
.73619 .79611 m .72354 .81727 L .71652 .81241 L 1 .852 0 r
F
.73619 .79611 m .74393 .80067 L .72354 .81727 L F
.24807 .58356 m .23156 .5659 L .24151 .56593 L .95 .804 0 r
F
.25773 .58301 m .24807 .58356 L .24151 .56593 L .943 .799 0 r
F
.4849 .63291 m .48183 .63548 L .47225 .6321 L .406 .478 0 r
F
.49383 .63598 m .48183 .63548 L .4849 .63291 L .374 .421 0 r
F
.31317 .59444 m .29649 .58145 L .3062 .58126 L .879 .773 0 r
F
.32253 .5937 m .31317 .59444 L .3062 .58126 L .866 .766 0 r
F
.59901 .43039 m .61144 .43718 L .60153 .43594 L .668 .637 0 r
F
.58938 .42967 m .59901 .43039 L .60153 .43594 L .638 .62 0 r
F
.45436 .62428 m .44861 .62649 L .43968 .62173 L .51 .604 0 r
F
.46306 .62837 m .44861 .62649 L .45436 .62428 L .476 .581 0 r
F
.33411 .28021 m .33807 .25907 L .34616 .2653 L 1 .746 0 r
F
.33411 .28021 m .32546 .27464 L .33807 .25907 L F
.55019 .41485 m .55768 .41371 L .5616 .41712 L .512 .56 0 r
F
.54654 .41206 m .55768 .41371 L .55019 .41485 L .499 .554 0 r
F
.52141 .64455 m .51206 .64423 L .51217 .64169 L .223 .183 0 r
F
.52141 .64455 m .52231 .64711 L .51206 .64423 L F
.66978 .80664 m .65538 .82671 L .64988 .82126 L 1 .886 0 r
F
.66978 .80664 m .67611 .81218 L .65538 .82671 L F
.49854 .39172 m .50155 .38801 L .50351 .39296 L .39 .421 0 r
F
.49854 .39172 m .49558 .38643 L .50155 .38801 L F
.40682 .88054 m .37795 .87866 L .38273 .87466 L .856 .862 0 r
F
.41072 .87638 m .40682 .88054 L .38273 .87466 L .839 .855 0 r
F
.43484 .88037 m .40682 .88054 L .41072 .87638 L .852 .871 0 r
F
.43783 .87613 m .43484 .88037 L .41072 .87638 L .83 .862 0 r
F
.46168 .87825 m .43484 .88037 L .43783 .87613 L .85 .881 0 r
F
.44059 .35465 m .44138 .34632 L .44796 .35495 L .38 .3 0 r
F
.44059 .35465 m .43329 .34597 L .44138 .34632 L F
.67389 .45209 m .68509 .46456 L .67491 .46285 L .862 .718 0 r
F
.66375 .45101 m .67389 .45209 L .67491 .46285 L .842 .707 0 r
F
.56502 .42062 m .57375 .42043 L .5771 .42459 L .56 .585 0 r
F
.5616 .41712 m .57375 .42043 L .56502 .42062 L .547 .582 0 r
F
.34295 .8785 m .31259 .87202 L .31899 .86848 L .881 .852 0 r
F
.34855 .87467 m .34295 .8785 L .31899 .86848 L .87 .848 0 r
F
.64436 .81567 m .6287 .83518 L .62406 .82997 L 1 .934 0 r
F
.64436 .81567 m .64988 .82126 L .6287 .83518 L F
.48427 .38408 m .48586 .37957 L .4898 .3851 L .358 .359 0 r
F
.48427 .38408 m .47941 .37815 L .48586 .37957 L F
.4218 .26808 m .43119 .22754 L .43613 .23371 L 1 .611 0 r
F
.42739 .29008 m .43613 .23371 L .44078 .26214 L 1 .518 0 r
F
.42739 .29008 m .4218 .26808 L .43613 .23371 L F
.59331 .71007 m .58554 .71431 L .58056 .68481 L .244 .042 0 r
F
.58756 .69391 m .59331 .71007 L .58056 .68481 L 0 0 0 r
F
.58756 .69391 m .58056 .68481 L .57584 .67936 L F
.37829 .29411 m .38222 .27343 L .38955 .28262 L 1 .649 0 r
F
.37829 .29411 m .37029 .2862 L .38222 .27343 L F
.4611 .36992 m .4618 .36402 L .46757 .37071 L .329 .282 0 r
F
.4611 .36992 m .45453 .36273 L .4618 .36402 L F
.56636 .6684 m .57111 .67389 L .55983 .66427 L 0 .029 0 r
F
.56636 .6684 m .55983 .66427 L .55604 .66192 L F
.38348 .60899 m .36684 .60131 L .37583 .60051 L .747 .724 0 r
F
.39197 .60777 m .38348 .60899 L .37583 .60051 L .723 .71 0 r
F
.47626 .62962 m .47225 .6321 L .46306 .62837 L .431 .522 0 r
F
.4849 .63291 m .47225 .6321 L .47626 .62962 L .406 .478 0 r
F
.25773 .58301 m .24151 .56593 L .25146 .56602 L .943 .799 0 r
F
.26741 .58252 m .25773 .58301 L .25146 .56602 L .934 .794 0 r
F
.26915 .26829 m .2732 .24473 L .28195 .24942 L 1 .802 0 r
F
.26915 .26829 m .25995 .26422 L .2732 .24473 L F
.58633 .42483 m .59901 .43039 L .58938 .42967 L .628 .623 0 r
F
.5771 .42459 m .58633 .42483 L .58938 .42967 L .599 .604 0 r
F
.63131 .4392 m .64351 .44842 L .6334 .44691 L .762 .677 0 r
F
.62137 .43827 m .63131 .4392 L .6334 .44691 L .735 .663 0 r
F
.47332 .37715 m .47452 .3722 L .47941 .37815 L .332 .307 0 r
F
.47332 .37715 m .46757 .37071 L .47452 .3722 L F
.57375 .42043 m .58633 .42483 L .5771 .42459 L .587 .604 0 r
F
.55222 .65835 m .54534 .65643 L .54248 .65404 L 0 .069 0 r
F
.5557 .85856 m .55755 .86261 L .5342 .86874 L 1 1 0 r
F
.57765 .84979 m .55755 .86261 L .5557 .85856 L F
.57765 .84979 m .58045 .85402 L .55755 .86261 L F
.54654 .41206 m .55329 .41041 L .55768 .41371 L .499 .554 0 r
F
.54253 .40937 m .55329 .41041 L .54654 .41206 L .486 .547 0 r
F
.68403 .45305 m .69527 .46613 L .68509 .46456 L .879 .728 0 r
F
.67389 .45209 m .68403 .45305 L .68509 .46456 L .862 .718 0 r
F
.35786 .60223 m .3413 .59251 L .3507 .59208 L .803 .744 0 r
F
.36684 .60131 m .35786 .60223 L .3507 .59208 L .784 .732 0 r
F
.53059 .64754 m .52231 .64711 L .52141 .64455 L .159 .12 0 r
F
.53059 .64754 m .53248 .65031 L .52231 .64711 L F
.46373 .87403 m .46168 .87825 L .43783 .87613 L .822 .869 0 r
F
.48707 .87426 m .46168 .87825 L .46373 .87403 L .852 .894 0 r
F
.53333 .86471 m .5342 .86874 L .51064 .87256 L .939 .957 0 r
F
.5557 .85856 m .5342 .86874 L .53333 .86471 L 1 1 0 r
F
.37795 .87866 m .34855 .87467 L .35417 .87088 L .862 .854 0 r
F
.38273 .87466 m .37795 .87866 L .35417 .87088 L .848 .848 0 r
F
.32546 .27464 m .32996 .25309 L .33807 .25907 L 1 .762 0 r
F
.32546 .27464 m .3168 .26928 L .32996 .25309 L F
.50351 .39296 m .50765 .3898 L .50858 .39442 L .397 .435 0 r
F
.50351 .39296 m .50155 .38801 L .50765 .3898 L F
.43329 .34597 m .43481 .33643 L .44138 .34632 L .414 .304 0 r
F
.43329 .34597 m .42599 .33643 L .43481 .33643 L F
.69533 .79712 m .68242 .81755 L .67611 .81218 L 1 .856 0 r
F
.69533 .79712 m .70241 .80236 L .68242 .81755 L F
.37029 .2862 m .37485 .26507 L .38222 .27343 L 1 .682 0 r
F
.37029 .2862 m .36227 .27881 L .37485 .26507 L F
.59895 .83837 m .58045 .85402 L .57765 .84979 L 1 1 0 r
F
.59895 .83837 m .60269 .843 L .58045 .85402 L F
.32253 .5937 m .3062 .58126 L .31592 .58115 L .866 .766 0 r
F
.33191 .59305 m .32253 .5937 L .31592 .58115 L .851 .757 0 r
F
.4242 .61824 m .4082 .61364 L .41613 .61221 L .628 .674 0 r
F
.43148 .61654 m .4242 .61824 L .41613 .61221 L .598 .653 0 r
F
.43968 .62173 m .4242 .61824 L .43148 .61654 L .571 .644 0 r
F
.60865 .43095 m .62137 .43827 L .61144 .43718 L .697 .654 0 r
F
.59901 .43039 m .60865 .43095 L .61144 .43718 L .668 .637 0 r
F
.69418 .45387 m .70546 .46758 L .69527 .46613 L .895 .738 0 r
F
.68403 .45305 m .69418 .45387 L .69527 .46613 L .879 .728 0 r
F
.72843 .79144 m .71652 .81241 L .70948 .80744 L 1 .845 0 r
F
.72843 .79144 m .73619 .79611 L .71652 .81241 L F
.51074 .86849 m .51064 .87256 L .48707 .87426 L .861 .91 0 r
F
.53333 .86471 m .51064 .87256 L .51074 .86849 L .939 .957 0 r
F
.4082 .61364 m .39197 .60777 L .40048 .60669 L .679 .696 0 r
F
.41613 .61221 m .4082 .61364 L .40048 .60669 L .651 .677 0 r
F
.54253 .40937 m .54848 .40725 L .55329 .41041 L .486 .547 0 r
F
.53822 .40679 m .54848 .40725 L .54253 .40937 L .472 .539 0 r
F
.5616 .41712 m .56977 .41636 L .57375 .42043 L .547 .582 0 r
F
.55768 .41371 m .56977 .41636 L .5616 .41712 L .532 .578 0 r
F
.26741 .58252 m .25146 .56602 L .26142 .56617 L .934 .794 0 r
F
.27709 .58209 m .26741 .58252 L .26142 .56617 L .925 .788 0 r
F
.42599 .33643 m .42826 .3248 L .43481 .33643 L .529 .341 0 r
F
.42599 .33643 m .41871 .32599 L .42826 .3248 L F
.46797 .62606 m .46306 .62837 L .45436 .62428 L .454 .555 0 r
F
.47626 .62962 m .46306 .62837 L .46797 .62606 L .431 .522 0 r
F
.25995 .26422 m .26442 .24012 L .2732 .24473 L 1 .808 0 r
F
.25995 .26422 m .25074 .26022 L .26442 .24012 L F
.6194 .82473 m .60269 .843 L .59895 .83837 L 1 1 0 r
F
.6194 .82473 m .62406 .82997 L .60269 .843 L F
.50858 .39442 m .51382 .39178 L .51371 .39607 L .405 .452 0 r
F
.50858 .39442 m .50765 .3898 L .51382 .39178 L F
.4898 .3851 m .49261 .38131 L .49558 .38643 L .357 .364 0 r
F
.4898 .3851 m .48586 .37957 L .49261 .38131 L F
.64126 .43998 m .65362 .44979 L .64351 .44842 L .786 .691 0 r
F
.63131 .4392 m .64126 .43998 L .64351 .44842 L .762 .677 0 r
F
.44624 .61981 m .43968 .62173 L .43148 .61654 L .542 .62 0 r
F
.45436 .62428 m .43968 .62173 L .44624 .61981 L .51 .604 0 r
F
.36227 .27881 m .36747 .25738 L .37485 .26507 L 1 .711 0 r
F
.36227 .27881 m .35422 .27186 L .36747 .25738 L F
.45453 .36273 m .45602 .35693 L .4618 .36402 L .297 .221 0 r
F
.45453 .36273 m .44796 .35495 L .45602 .35693 L F
.3168 .26928 m .32183 .24733 L .32996 .25309 L 1 .775 0 r
F
.3168 .26928 m .30811 .26411 L .32183 .24733 L F
.70434 .45459 m .71565 .46891 L .70546 .46758 L .909 .747 0 r
F
.69418 .45387 m .70434 .45459 L .70546 .46758 L .895 .738 0 r
F
.41871 .32599 m .42174 .31121 L .42826 .3248 L .716 .405 0 r
F
.41871 .32599 m .41143 .31488 L .42174 .31121 L F
.53822 .40679 m .54329 .40425 L .54848 .40725 L .472 .539 0 r
F
.53364 .40435 m .54329 .40425 L .53822 .40679 L .457 .528 0 r
F
.66344 .80089 m .64988 .82126 L .64436 .81567 L 1 .876 0 r
F
.66344 .80089 m .66978 .80664 L .64988 .82126 L F
.51371 .39607 m .51998 .39394 L .51883 .3979 L .413 .469 0 r
F
.51371 .39607 m .51382 .39178 L .51998 .39394 L F
.41143 .31488 m .41524 .29644 L .42174 .31121 L .91 .477 0 r
F
.41143 .31488 m .40415 .30359 L .41524 .29644 L F
.5396 .65075 m .53248 .65031 L .53059 .64754 L .106 .095 0 r
F
.5396 .65075 m .54248 .65404 L .53248 .65031 L F
.40415 .30359 m .40873 .28225 L .41524 .29644 L 1 .54 0 r
F
.40415 .30359 m .39686 .29271 L .40873 .28225 L F
.59558 .42491 m .60865 .43095 L .59901 .43039 L .657 .641 0 r
F
.58633 .42483 m .59558 .42491 L .59901 .43039 L .628 .623 0 r
F
.48816 .87016 m .48707 .87426 L .46373 .87403 L .815 .877 0 r
F
.51074 .86849 m .48707 .87426 L .48816 .87016 L .861 .91 0 r
F
.53364 .40435 m .53779 .40142 L .54329 .40425 L .457 .528 0 r
F
.52885 .40205 m .53779 .40142 L .53364 .40435 L .443 .516 0 r
F
.57375 .42043 m .58251 .42007 L .58633 .42483 L .587 .604 0 r
F
.56977 .41636 m .58251 .42007 L .57375 .42043 L .572 .602 0 r
F
.39197 .60777 m .37583 .60051 L .38484 .59985 L .723 .71 0 r
F
.40048 .60669 m .39197 .60777 L .38484 .59985 L .697 .694 0 r
F
.27709 .58209 m .26142 .56617 L .27138 .56639 L .925 .788 0 r
F
.28679 .58173 m .27709 .58209 L .27138 .56639 L .916 .782 0 r
F
.71451 .45519 m .72584 .47014 L .71565 .46891 L .922 .755 0 r
F
.70434 .45459 m .71451 .45519 L .71565 .46891 L .909 .747 0 r
F
.33191 .59305 m .31592 .58115 L .32566 .58114 L .851 .757 0 r
F
.3413 .59251 m .33191 .59305 L .32566 .58114 L .835 .748 0 r
F
.36684 .60131 m .3507 .59208 L .36012 .59176 L .784 .732 0 r
F
.37583 .60051 m .36684 .60131 L .36012 .59176 L .762 .72 0 r
F
.51883 .3979 m .52607 .39626 L .52389 .39989 L .422 .486 0 r
F
.51883 .3979 m .51998 .39394 L .52607 .39626 L F
.25074 .26022 m .25563 .23559 L .26442 .24012 L 1 .814 0 r
F
.25074 .26022 m .24151 .2563 L .25563 .23559 L F
.39686 .29271 m .40219 .26988 L .40873 .28225 L 1 .595 0 r
F
.39686 .29271 m .38955 .28262 L .40219 .26988 L F
.52885 .40205 m .53203 .39875 L .53779 .40142 L .443 .516 0 r
F
.52389 .39989 m .53203 .39875 L .52885 .40205 L .431 .502 0 r
F
.63883 .8099 m .62406 .82997 L .6194 .82473 L 1 .929 0 r
F
.63883 .8099 m .64436 .81567 L .62406 .82997 L F
.47941 .37815 m .4819 .37418 L .48586 .37957 L .317 .295 0 r
F
.47941 .37815 m .47452 .3722 L .4819 .37418 L F
.41611 .25308 m .42623 .22136 L .43119 .22754 L 1 .724 0 r
F
.4218 .26808 m .41611 .25308 L .43119 .22754 L 1 .611 0 r
F
.58187 .68289 m .57584 .67936 L .57111 .67389 L 0 .017 0 r
F
.58187 .68289 m .58756 .69391 L .57584 .67936 L F
.34855 .87467 m .31899 .86848 L .3254 .86498 L .87 .848 0 r
F
.35417 .87088 m .34855 .87467 L .3254 .86498 L .858 .843 0 r
F
.52389 .39989 m .52607 .39626 L .53203 .39875 L .431 .502 0 r
F
.61831 .43134 m .63131 .4392 L .62137 .43827 L .725 .67 0 r
F
.60865 .43095 m .61831 .43134 L .62137 .43827 L .697 .654 0 r
F
.65123 .44061 m .66375 .45101 L .65362 .44979 L .809 .703 0 r
F
.64126 .43998 m .65123 .44061 L .65362 .44979 L .786 .691 0 r
F
.55768 .41371 m .56519 .41243 L .56977 .41636 L .532 .578 0 r
F
.55329 .41041 m .56519 .41243 L .55768 .41371 L .516 .572 0 r
F
.46757 .37071 m .46963 .36624 L .47452 .3722 L .284 .232 0 r
F
.46757 .37071 m .4618 .36402 L .46963 .36624 L F
.58251 .42007 m .59558 .42491 L .58633 .42483 L .615 .624 0 r
F
.35422 .27186 m .36005 .25021 L .36747 .25738 L 1 .736 0 r
F
.35422 .27186 m .34616 .2653 L .36005 .25021 L F
.41072 .87638 m .38273 .87466 L .38753 .87072 L .839 .855 0 r
F
.41464 .8723 m .41072 .87638 L .38753 .87072 L .819 .846 0 r
F
.43783 .87613 m .41072 .87638 L .41464 .8723 L .83 .862 0 r
F
.68823 .7917 m .67611 .81218 L .66978 .80664 L 1 .846 0 r
F
.68823 .7917 m .69533 .79712 L .67611 .81218 L F
.46014 .6222 m .45436 .62428 L .44624 .61981 L .485 .579 0 r
F
.46797 .62606 m .45436 .62428 L .46014 .6222 L .454 .555 0 r
F
.49558 .38643 m .49959 .38328 L .50155 .38801 L .363 .38 0 r
F
.49558 .38643 m .49261 .38131 L .49959 .38328 L F
.72468 .4557 m .73604 .47126 L .72584 .47014 L .934 .763 0 r
F
.71451 .45519 m .72468 .4557 L .72584 .47014 L .922 .755 0 r
F
.44082 .872 m .43783 .87613 L .41464 .8723 L .805 .851 0 r
F
.46373 .87403 m .43783 .87613 L .44082 .872 L .822 .869 0 r
F
.30811 .26411 m .31368 .24174 L .32183 .24733 L 1 .787 0 r
F
.30811 .26411 m .29941 .25909 L .31368 .24174 L F
.31899 .86848 m .31259 .87202 L .28963 .86005 L .879 .843 0 r
F
.49594 .63328 m .49383 .63598 L .4849 .63291 L .374 .421 0 r
F
.50406 .63609 m .49383 .63598 L .49594 .63328 L .342 .367 0 r
F
.50406 .63609 m .50295 .63887 L .49383 .63598 L F
.72065 .78665 m .70948 .80744 L .70241 .80236 L 1 .838 0 r
F
.72065 .78665 m .72843 .79144 L .70948 .80744 L F
.38955 .28262 m .3956 .25938 L .40219 .26988 L 1 .645 0 r
F
.38955 .28262 m .38222 .27343 L .3956 .25938 L F
.51228 .6388 m .50295 .63887 L .50406 .63609 L .307 .309 0 r
F
.51228 .6388 m .51217 .64169 L .50295 .63887 L F
.44796 .35495 m .45024 .34919 L .45602 .35693 L .267 .16 0 r
F
.44796 .35495 m .44138 .34632 L .45024 .34919 L F
.48798 .63032 m .4849 .63291 L .47626 .62962 L .4 .466 0 r
F
.49594 .63328 m .4849 .63291 L .48798 .63032 L .374 .421 0 r
F
.76218 .78333 m .75165 .80514 L .74393 .80067 L 1 .84 0 r
F
.76218 .78333 m .77055 .78741 L .75165 .80514 L F
.28679 .58173 m .27138 .56639 L .28135 .56669 L .916 .782 0 r
F
.29649 .58145 m .28679 .58173 L .28135 .56669 L .905 .775 0 r
F
.73486 .45611 m .74624 .4723 L .73604 .47126 L .944 .77 0 r
F
.72468 .4557 m .73486 .45611 L .73604 .47126 L .934 .763 0 r
F
.38273 .87466 m .35417 .87088 L .35981 .86715 L .848 .848 0 r
F
.38753 .87072 m .38273 .87466 L .35981 .86715 L .832 .842 0 r
F
.52051 .64148 m .51217 .64169 L .51228 .6388 L .268 .251 0 r
F
.52051 .64148 m .52141 .64455 L .51217 .64169 L F
.65123 .44061 m .66121 .4411 L .66375 .45101 L .809 .703 0 r
F
.66121 .4411 m .67389 .45209 L .66375 .45101 L .83 .715 0 r
F
.55329 .41041 m .56007 .40865 L .56519 .41243 L .516 .572 0 r
F
.54848 .40725 m .56007 .40865 L .55329 .41041 L .498 .563 0 r
F
.41613 .61221 m .40048 .60669 L .40901 .60577 L .651 .677 0 r
F
.42408 .61095 m .41613 .61221 L .40901 .60577 L .622 .657 0 r
F
.43148 .61654 m .41613 .61221 L .42408 .61095 L .598 .653 0 r
F
.5616 .66289 m .55604 .66192 L .55222 .65835 L 0 .061 0 r
F
.5616 .66289 m .56636 .6684 L .55604 .66192 L F
.43878 .61499 m .43148 .61654 L .42408 .61095 L .569 .63 0 r
F
.44624 .61981 m .43148 .61654 L .43878 .61499 L .542 .62 0 r
F
.3413 .59251 m .32566 .58114 L .3354 .58124 L .835 .748 0 r
F
.3507 .59208 m .3413 .59251 L .3354 .58124 L .817 .738 0 r
F
.59331 .71007 m .59917 .73369 L .58554 .71431 L .244 .042 0 r
F
.38222 .27343 m .38899 .25029 L .3956 .25938 L 1 .689 0 r
F
.38222 .27343 m .37485 .26507 L .38899 .25029 L F
.55386 .85484 m .5557 .85856 L .53333 .86471 L 1 1 0 r
F
.57484 .84592 m .5557 .85856 L .55386 .85484 L F
.57484 .84592 m .57765 .84979 L .5557 .85856 L F
.48028 .62718 m .47626 .62962 L .46797 .62606 L .421 .503 0 r
F
.48798 .63032 m .47626 .62962 L .48028 .62718 L .4 .466 0 r
F
.74505 .45644 m .75644 .47324 L .74624 .4723 L .954 .777 0 r
F
.73486 .45611 m .74505 .45644 L .74624 .4723 L .944 .77 0 r
F
.34616 .2653 m .35261 .24345 L .36005 .25021 L 1 .758 0 r
F
.34616 .2653 m .33807 .25907 L .35261 .24345 L F
.46578 .86994 m .46373 .87403 L .44082 .872 L .789 .853 0 r
F
.48816 .87016 m .46373 .87403 L .46578 .86994 L .815 .877 0 r
F
.5952 .83397 m .57765 .84979 L .57484 .84592 L 1 1 0 r
F
.5952 .83397 m .59895 .83837 L .57765 .84979 L F
.62799 .43158 m .64126 .43998 L .63131 .4392 L .751 .685 0 r
F
.61831 .43134 m .62799 .43158 L .63131 .4392 L .725 .67 0 r
F
.56977 .41636 m .57796 .41545 L .58251 .42007 L .572 .602 0 r
F
.56519 .41243 m .57796 .41545 L .56977 .41636 L .555 .598 0 r
F
.60486 .42482 m .61831 .43134 L .60865 .43095 L .685 .659 0 r
F
.59558 .42491 m .60486 .42482 L .60865 .43095 L .657 .641 0 r
F
.50155 .38801 m .50672 .38542 L .50765 .3898 L .373 .402 0 r
F
.50155 .38801 m .49959 .38328 L .50672 .38542 L F
.53245 .86096 m .53333 .86471 L .51074 .86849 L .882 .929 0 r
F
.55386 .85484 m .53333 .86471 L .53245 .86096 L 1 1 0 r
F
.29941 .25909 m .30551 .23629 L .31368 .24174 L 1 .797 0 r
F
.29941 .25909 m .29069 .2542 L .30551 .23629 L F
.37583 .60051 m .36012 .59176 L .36955 .59157 L .762 .72 0 r
F
.38484 .59985 m .37583 .60051 L .36955 .59157 L .739 .706 0 r
F
.65707 .79487 m .64436 .81567 L .63883 .8099 L 1 .861 0 r
F
.65707 .79487 m .66344 .80089 L .64436 .81567 L F
.54838 .65411 m .54248 .65404 L .5396 .65075 L .08 .086 0 r
F
.54838 .65411 m .55222 .65835 L .54248 .65404 L F
.75524 .45668 m .76665 .47411 L .75644 .47324 L .962 .783 0 r
F
.74505 .45644 m .75524 .45668 L .75644 .47324 L .954 .777 0 r
F
.61473 .81948 m .59895 .83837 L .5952 .83397 L 1 1 0 r
F
.61473 .81948 m .6194 .82473 L .59895 .83837 L F
.48586 .37957 m .48963 .37646 L .49261 .38131 L .315 .302 0 r
F
.48586 .37957 m .4819 .37418 L .48963 .37646 L F
.29649 .58145 m .28135 .56669 L .29132 .56707 L .905 .775 0 r
F
.3062 .58126 m .29649 .58145 L .29132 .56707 L .893 .768 0 r
F
.40048 .60669 m .38484 .59985 L .39387 .59933 L .697 .694 0 r
F
.40901 .60577 m .40048 .60669 L .39387 .59933 L .67 .677 0 r
F
.44138 .34632 m .44446 .34029 L .45024 .34919 L .254 .116 0 r
F
.44138 .34632 m .43481 .33643 L .44446 .34029 L F
.45282 .61805 m .44624 .61981 L .43878 .61499 L .514 .595 0 r
F
.46014 .6222 m .44624 .61981 L .45282 .61805 L .485 .579 0 r
F
.52868 .64416 m .52141 .64455 L .52051 .64148 L .231 .201 0 r
F
.52868 .64416 m .53059 .64754 L .52141 .64455 L F
.6712 .44145 m .68403 .45305 L .67389 .45209 L .849 .726 0 r
F
.66121 .4411 m .6712 .44145 L .67389 .45209 L .83 .715 0 r
F
.51085 .86465 m .51074 .86849 L .48816 .87016 L .808 .881 0 r
F
.53245 .86096 m .51074 .86849 L .51085 .86465 L .882 .929 0 r
F
.54848 .40725 m .55445 .40506 L .56007 .40865 L .498 .563 0 r
F
.54329 .40425 m .55445 .40506 L .54848 .40725 L .479 .552 0 r
F
.58251 .42007 m .59129 .41955 L .59558 .42491 L .615 .624 0 r
F
.57796 .41545 m .59129 .41955 L .58251 .42007 L .599 .623 0 r
F
.59129 .41955 m .60486 .42482 L .59558 .42491 L .643 .643 0 r
F
.4618 .36402 m .46471 .36025 L .46963 .36624 L .218 .142 0 r
F
.4618 .36402 m .45602 .35693 L .46471 .36025 L F
.68111 .78606 m .66978 .80664 L .66344 .80089 L 1 .832 0 r
F
.68111 .78606 m .68823 .7917 L .66978 .80664 L F
.76544 .45686 m .77685 .47491 L .76665 .47411 L .97 .789 0 r
F
.75524 .45668 m .76544 .45686 L .76665 .47411 L .962 .783 0 r
F
.47291 .62383 m .46797 .62606 L .46014 .6222 L .439 .532 0 r
F
.48028 .62718 m .46797 .62606 L .47291 .62383 L .421 .503 0 r
F
.71286 .7817 m .70241 .80236 L .69533 .79712 L 1 .829 0 r
F
.71286 .7817 m .72065 .78665 L .70241 .80236 L F
.37485 .26507 m .38233 .24217 L .38899 .25029 L 1 .726 0 r
F
.37485 .26507 m .36747 .25738 L .38233 .24217 L F
.75379 .77916 m .74393 .80067 L .73619 .79611 L 1 .834 0 r
F
.75379 .77916 m .76218 .78333 L .74393 .80067 L F
.40873 .28225 m .41611 .25308 L .4218 .26808 L 1 .589 0 r
F
.40873 .28225 m .40219 .26988 L .41611 .25308 L F
.41524 .29644 m .40873 .28225 L .4218 .26808 L 1 .513 0 r
F
.50765 .3898 m .51393 .38771 L .51382 .39178 L .386 .428 0 r
F
.50765 .3898 m .50672 .38542 L .51393 .38771 L F
.63327 .80385 m .6194 .82473 L .61473 .81948 L 1 .918 0 r
F
.63327 .80385 m .63883 .8099 L .6194 .82473 L F
.47452 .3722 m .47793 .36901 L .4819 .37418 L .257 .211 0 r
F
.47452 .3722 m .46963 .36624 L .47793 .36901 L F
.41033 .24233 m .42126 .21515 L .42623 .22136 L 1 .802 0 r
F
.41611 .25308 m .41033 .24233 L .42623 .22136 L 1 .724 0 r
F
.57621 .67429 m .57111 .67389 L .56636 .6684 L 0 .045 0 r
F
.57621 .67429 m .58187 .68289 L .57111 .67389 L F
.22162 .56592 m .21169 .566 L .20727 .5458 L .976 .809 0 r
F
.33807 .25907 m .34515 .23699 L .35261 .24345 L 1 .775 0 r
F
.33807 .25907 m .32996 .25309 L .34515 .23699 L F
.40219 .26988 m .41033 .24233 L .41611 .25308 L 1 .658 0 r
F
.40219 .26988 m .3956 .25938 L .41033 .24233 L F
.77565 .45696 m .78706 .47565 L .77685 .47491 L .977 .794 0 r
F
.76544 .45686 m .77565 .45696 L .77685 .47491 L .97 .789 0 r
F
.35417 .87088 m .3254 .86498 L .33183 .86152 L .858 .843 0 r
F
.35981 .86715 m .35417 .87088 L .33183 .86152 L .845 .838 0 r
F
.41524 .29644 m .4218 .26808 L .42739 .29008 L 1 .513 0 r
F
.42174 .31121 m .41524 .29644 L .42739 .29008 L .908 .397 0 r
F
.3507 .59208 m .3354 .58124 L .34515 .58145 L .817 .738 0 r
F
.36012 .59176 m .3507 .59208 L .34515 .58145 L .798 .727 0 r
F
.63768 .43166 m .65123 .44061 L .64126 .43998 L .775 .698 0 r
F
.62799 .43158 m .63768 .43166 L .64126 .43998 L .751 .685 0 r
F
.54329 .40425 m .54839 .40168 L .55445 .40506 L .479 .552 0 r
F
.53779 .40142 m .54839 .40168 L .54329 .40425 L .459 .538 0 r
F
.29069 .2542 m .29731 .23096 L .30551 .23629 L 1 .805 0 r
F
.29069 .2542 m .28195 .24942 L .29731 .23096 L F
.31899 .86848 m .28963 .86005 L .29679 .85688 L .879 .843 0 r
F
.3254 .86498 m .31899 .86848 L .29679 .85688 L .869 .839 0 r
F
.43481 .33643 m .43869 .32908 L .44446 .34029 L .293 .113 0 r
F
.43481 .33643 m .42826 .3248 L .43869 .32908 L F
.3062 .58126 m .29132 .56707 L .3013 .56753 L .893 .768 0 r
F
.31592 .58115 m .3062 .58126 L .3013 .56753 L .88 .76 0 r
F
.56519 .41243 m .57273 .411 L .57796 .41545 L .555 .598 0 r
F
.56007 .40865 m .57273 .411 L .56519 .41243 L .535 .591 0 r
F
.6812 .44168 m .69418 .45387 L .68403 .45305 L .866 .736 0 r
F
.6712 .44145 m .6812 .44168 L .68403 .45305 L .849 .726 0 r
F
.78586 .457 m .79727 .47632 L .78706 .47565 L .983 .799 0 r
F
.77565 .45696 m .78586 .457 L .78706 .47565 L .977 .794 0 r
F
.51382 .39178 m .52113 .39015 L .51998 .39394 L .4 .453 0 r
F
.51382 .39178 m .51393 .38771 L .52113 .39015 L F
.48924 .86624 m .48816 .87016 L .46578 .86994 L .769 .851 0 r
F
.51085 .86465 m .48816 .87016 L .48924 .86624 L .808 .881 0 r
F
.42174 .31121 m .42739 .29008 L .43299 .31303 L .908 .397 0 r
F
.42826 .3248 m .42174 .31121 L .43299 .31303 L .453 .209 0 r
F
.61415 .42456 m .62799 .43158 L .61831 .43134 L .712 .675 0 r
F
.60486 .42482 m .61415 .42456 L .61831 .43134 L .685 .659 0 r
F
.41464 .8723 m .38753 .87072 L .39234 .86685 L .819 .846 0 r
F
.41857 .8683 m .41464 .8723 L .39234 .86685 L .797 .836 0 r
F
.44082 .872 m .41464 .8723 L .41857 .8683 L .805 .851 0 r
F
.22162 .56592 m .20727 .5458 L .2174 .54638 L .976 .809 0 r
F
.23156 .5659 m .22162 .56592 L .2174 .54638 L .97 .805 0 r
F
.42826 .3248 m .43299 .31303 L .43869 .32908 L .453 .209 0 r
F
.53779 .40142 m .54196 .39849 L .54839 .40168 L .459 .538 0 r
F
.53203 .39875 m .54196 .39849 L .53779 .40142 L .44 .521 0 r
F
.3956 .25938 m .40452 .23359 L .41033 .24233 L 1 .718 0 r
F
.3956 .25938 m .38899 .25029 L .40452 .23359 L F
.53671 .64684 m .53059 .64754 L .52868 .64416 L .202 .164 0 r
F
.53671 .64684 m .5396 .65075 L .53059 .64754 L F
.79608 .45699 m .80749 .47693 L .79727 .47632 L .989 .803 0 r
F
.78586 .457 m .79608 .45699 L .79727 .47632 L .983 .799 0 r
F
.38484 .59985 m .36955 .59157 L .37899 .59151 L .739 .706 0 r
F
.39387 .59933 m .38484 .59985 L .37899 .59151 L .714 .691 0 r
F
.46593 .62024 m .46014 .6222 L .45282 .61805 L .463 .554 0 r
F
.47291 .62383 m .46014 .6222 L .46593 .62024 L .439 .532 0 r
F
.51998 .39394 m .52826 .39274 L .52607 .39626 L .413 .478 0 r
F
.51998 .39394 m .52113 .39015 L .52826 .39274 L F
.49261 .38131 m .49762 .37887 L .49959 .38328 L .325 .326 0 r
F
.49261 .38131 m .48963 .37646 L .49762 .37887 L F
.44383 .86797 m .44082 .872 L .41857 .8683 L .777 .837 0 r
F
.46578 .86994 m .44082 .872 L .44383 .86797 L .789 .853 0 r
F
.36747 .25738 m .37565 .2347 L .38233 .24217 L 1 .757 0 r
F
.36747 .25738 m .36005 .25021 L .37565 .2347 L F
.53203 .39875 m .53522 .39552 L .54196 .39849 L .44 .521 0 r
F
.52607 .39626 m .53522 .39552 L .53203 .39875 L .426 .501 0 r
F
.42408 .61095 m .40901 .60577 L .41756 .605 L .622 .657 0 r
F
.43205 .60984 m .42408 .61095 L .41756 .605 L .592 .636 0 r
F
.43878 .61499 m .42408 .61095 L .43205 .60984 L .569 .63 0 r
F
.52607 .39626 m .52826 .39274 L .53522 .39552 L .426 .501 0 r
F
.8063 .45692 m .8177 .4775 L .80749 .47693 L .994 .807 0 r
F
.79608 .45699 m .8063 .45692 L .80749 .47693 L .989 .803 0 r
F
.38753 .87072 m .35981 .86715 L .36547 .86348 L .832 .842 0 r
F
.39234 .86685 m .38753 .87072 L .36547 .86348 L .815 .834 0 r
F
.65068 .78847 m .63883 .8099 L .63327 .80385 L 1 .842 0 r
F
.65068 .78847 m .65707 .79487 L .63883 .8099 L F
.69122 .44179 m .70434 .45459 L .69418 .45387 L .882 .745 0 r
F
.6812 .44168 m .69122 .44179 L .69418 .45387 L .866 .736 0 r
F
.23156 .5659 m .2174 .54638 L .22754 .54701 L .97 .805 0 r
F
.24151 .56593 m .23156 .5659 L .22754 .54701 L .963 .8 0 r
F
.41033 .24233 m .40452 .23359 L .42126 .21515 L 1 .802 0 r
F
.4461 .6136 m .43878 .61499 L .43205 .60984 L .54 .606 0 r
F
.45282 .61805 m .43878 .61499 L .4461 .6136 L .514 .595 0 r
F
.32996 .25309 m .33767 .23077 L .34515 .23699 L 1 .79 0 r
F
.32996 .25309 m .32183 .24733 L .33767 .23077 L F
.74538 .77489 m .73619 .79611 L .72843 .79144 L 1 .827 0 r
F
.74538 .77489 m .75379 .77916 L .73619 .79611 L F
.70504 .77658 m .69533 .79712 L .68823 .7917 L 1 .817 0 r
F
.70504 .77658 m .71286 .7817 L .69533 .79712 L F
.31592 .58115 m .3013 .56753 L .31129 .5681 L .88 .76 0 r
F
.32566 .58114 m .31592 .58115 L .31129 .5681 L .865 .751 0 r
F
.40901 .60577 m .39387 .59933 L .40292 .59896 L .67 .677 0 r
F
.41756 .605 m .40901 .60577 L .40292 .59896 L .642 .658 0 r
F
.57796 .41545 m .58618 .41437 L .59129 .41955 L .599 .623 0 r
F
.57273 .411 m .58618 .41437 L .57796 .41545 L .58 .619 0 r
F
.28195 .24942 m .2891 .22573 L .29731 .23096 L 1 .813 0 r
F
.28195 .24942 m .2732 .24473 L .2891 .22573 L F
.8063 .45692 m .81653 .4568 L .8177 .4775 L .994 .807 0 r
F
.64739 .43159 m .66121 .4411 L .65123 .44061 L .797 .711 0 r
F
.63768 .43166 m .64739 .43159 L .65123 .44061 L .775 .698 0 r
F
.67396 .78013 m .66344 .80089 L .65707 .79487 L 1 .816 0 r
F
.67396 .78013 m .68111 .78606 L .66344 .80089 L F
.36012 .59176 m .34515 .58145 L .35492 .58178 L .798 .727 0 r
F
.36955 .59157 m .36012 .59176 L .35492 .58178 L .777 .715 0 r
F
.45602 .35693 m .45978 .35425 L .46471 .36025 L .125 .071 0 r
F
.45602 .35693 m .45024 .34919 L .45978 .35425 L F
.49805 .63044 m .49594 .63328 L .48798 .63032 L .377 .425 0 r
F
.50518 .63307 m .49594 .63328 L .49805 .63044 L .355 .388 0 r
F
.50518 .63307 m .50406 .63609 L .49594 .63328 L F
.6001 .41885 m .61415 .42456 L .60486 .42482 L .671 .661 0 r
F
.59129 .41955 m .6001 .41885 L .60486 .42482 L .643 .643 0 r
F
.56007 .40865 m .56687 .40677 L .57273 .411 L .535 .591 0 r
F
.55445 .40506 m .56687 .40677 L .56007 .40865 L .513 .581 0 r
F
.51239 .63558 m .50406 .63609 L .50518 .63307 L .331 .348 0 r
F
.51239 .63558 m .51228 .6388 L .50406 .63609 L F
.49108 .62768 m .48798 .63032 L .48028 .62718 L .397 .46 0 r
F
.49805 .63044 m .48798 .63032 L .49108 .62768 L .377 .425 0 r
F
.55683 .65737 m .55222 .65835 L .54838 .65411 L .099 .08 0 r
F
.55683 .65737 m .5616 .66289 L .55222 .65835 L F
.38899 .25029 m .39867 .22586 L .40452 .23359 L 1 .765 0 r
F
.38899 .25029 m .38233 .24217 L .39867 .22586 L F
.58618 .41437 m .6001 .41885 L .59129 .41955 L .626 .643 0 r
F
.24151 .56593 m .22754 .54701 L .23767 .54771 L .963 .8 0 r
F
.25146 .56602 m .24151 .56593 L .23767 .54771 L .956 .795 0 r
F
.46784 .86599 m .46578 .86994 L .44383 .86797 L .751 .832 0 r
F
.48924 .86624 m .46578 .86994 L .46784 .86599 L .769 .851 0 r
F
.57203 .84254 m .57484 .84592 L .55386 .85484 L 1 1 0 r
F
.59144 .82994 m .57484 .84592 L .57203 .84254 L F
.59144 .82994 m .5952 .83397 L .57484 .84592 L F
.552 .85157 m .55386 .85484 L .53245 .86096 L .928 .954 0 r
F
.57203 .84254 m .55386 .85484 L .552 .85157 L 1 1 0 r
F
.70124 .44179 m .71451 .45519 L .70434 .45459 L .896 .754 0 r
F
.69122 .44179 m .70124 .44179 L .70434 .45459 L .882 .745 0 r
F
.61005 .81422 m .5952 .83397 L .59144 .82994 L 1 1 0 r
F
.61005 .81422 m .61473 .81948 L .5952 .83397 L F
.4819 .37418 m .48663 .37197 L .48963 .37646 L .254 .219 0 r
F
.4819 .37418 m .47793 .36901 L .48663 .37197 L F
.62346 .42414 m .63768 .43166 L .62799 .43158 L .738 .69 0 r
F
.61415 .42456 m .62346 .42414 L .62799 .43158 L .712 .675 0 r
F
.51961 .63799 m .51228 .6388 L .51239 .63558 L .307 .309 0 r
F
.51961 .63799 m .52051 .64148 L .51228 .6388 L F
.49959 .38328 m .50579 .38135 L .50672 .38542 L .342 .358 0 r
F
.49959 .38328 m .49762 .37887 L .50579 .38135 L F
.48433 .62476 m .48028 .62718 L .47291 .62383 L .415 .489 0 r
F
.49108 .62768 m .48028 .62718 L .48433 .62476 L .397 .46 0 r
F
.36005 .25021 m .36895 .22769 L .37565 .2347 L 1 .781 0 r
F
.36005 .25021 m .35261 .24345 L .36895 .22769 L F
.53157 .85756 m .53245 .86096 L .51085 .86465 L .801 .876 0 r
F
.552 .85157 m .53245 .86096 L .53157 .85756 L .928 .954 0 r
F
.45942 .61642 m .45282 .61805 L .4461 .6136 L .489 .571 0 r
F
.46593 .62024 m .45282 .61805 L .45942 .61642 L .463 .554 0 r
F
.6277 .79741 m .61473 .81948 L .61005 .81422 L 1 .899 0 r
F
.6277 .79741 m .63327 .80385 L .61473 .81948 L F
.46963 .36624 m .47394 .36421 L .47793 .36901 L .167 .11 0 r
F
.46963 .36624 m .46471 .36025 L .47394 .36421 L F
.40452 .23359 m .41627 .20893 L .42126 .21515 L 1 .849 0 r
F
.57054 .66689 m .56636 .6684 L .5616 .66289 L .071 .067 0 r
F
.57054 .66689 m .57621 .67429 L .56636 .6684 L F
.32566 .58114 m .31129 .5681 L .32128 .56876 L .865 .751 0 r
F
.3354 .58124 m .32566 .58114 L .32128 .56876 L .849 .742 0 r
F
.25146 .56602 m .23767 .54771 L .24781 .54846 L .956 .795 0 r
F
.26142 .56617 m .25146 .56602 L .24781 .54846 L .948 .79 0 r
F
.54452 .64945 m .5396 .65075 L .53671 .64684 L .188 .145 0 r
F
.54452 .64945 m .54838 .65411 L .5396 .65075 L F
.35981 .86715 m .33183 .86152 L .33828 .85812 L .845 .838 0 r
F
.36547 .86348 m .35981 .86715 L .33828 .85812 L .831 .831 0 r
F
.3254 .86498 m .29679 .85688 L .30396 .85376 L .869 .839 0 r
F
.33183 .86152 m .3254 .86498 L .30396 .85376 L .858 .834 0 r
F
.39387 .59933 m .37899 .59151 L .38845 .5916 L .714 .691 0 r
F
.40292 .59896 m .39387 .59933 L .38845 .5916 L .687 .675 0 r
F
.32183 .24733 m .33016 .22473 L .33767 .23077 L 1 .803 0 r
F
.32183 .24733 m .31368 .24174 L .33016 .22473 L F
.43299 .31303 m .42739 .29008 L .4402 .30722 L .219 .038 0 r
F
.55445 .40506 m .56044 .40277 L .56687 .40677 L .513 .581 0 r
F
.54839 .40168 m .56044 .40277 L .55445 .40506 L .489 .568 0 r
F
.64739 .43159 m .65712 .43138 L .66121 .4411 L .797 .711 0 r
F
.65712 .43138 m .6712 .44145 L .66121 .4411 L .818 .723 0 r
F
.2732 .24473 m .28087 .22057 L .2891 .22573 L 1 .819 0 r
F
.2732 .24473 m .26442 .24012 L .28087 .22057 L F
.40452 .23359 m .39867 .22586 L .41627 .20893 L 1 .849 0 r
F
.51095 .86107 m .51085 .86465 L .48924 .86624 L .739 .835 0 r
F
.53157 .85756 m .51085 .86465 L .51095 .86107 L .801 .876 0 r
F
.73696 .77049 m .72843 .79144 L .72065 .78665 L 1 .819 0 r
F
.73696 .77049 m .74538 .77489 L .72843 .79144 L F
.71128 .44168 m .72468 .4557 L .71451 .45519 L .909 .762 0 r
F
.70124 .44179 m .71128 .44168 L .71451 .45519 L .896 .754 0 r
F
.47787 .62166 m .47291 .62383 L .46593 .62024 L .43 .513 0 r
F
.48433 .62476 m .47291 .62383 L .47787 .62166 L .415 .489 0 r
F
.36955 .59157 m .35492 .58178 L .36469 .58224 L .777 .715 0 r
F
.37899 .59151 m .36955 .59157 L .36469 .58224 L .754 .701 0 r
F
.69721 .77125 m .68823 .7917 L .68111 .78606 L 1 .804 0 r
F
.69721 .77125 m .70504 .77658 L .68823 .7917 L F
.52677 .64031 m .52051 .64148 L .51961 .63799 L .284 .273 0 r
F
.52677 .64031 m .52868 .64416 L .52051 .64148 L F
.57273 .411 m .5803 .40942 L .58618 .41437 L .58 .619 0 r
F
.56687 .40677 m .5803 .40942 L .57273 .411 L .558 .612 0 r
F
.26142 .56617 m .24781 .54846 L .25795 .54928 L .948 .79 0 r
F
.27138 .56639 m .26142 .56617 L .25795 .54928 L .94 .784 0 r
F
.50672 .38542 m .51404 .3839 L .51393 .38771 L .363 .396 0 r
F
.50672 .38542 m .50579 .38135 L .51404 .3839 L F
.38233 .24217 m .39279 .21869 L .39867 .22586 L 1 .799 0 r
F
.38233 .24217 m .37565 .2347 L .39279 .21869 L F
.66679 .77383 m .65707 .79487 L .65068 .78847 L 1 .794 0 r
F
.66679 .77383 m .67396 .78013 L .65707 .79487 L F
.64426 .78155 m .63327 .80385 L .6277 .79741 L 1 .814 0 r
F
.64426 .78155 m .65068 .78847 L .63327 .80385 L F
.45024 .34919 m .45484 .34822 L .45978 .35425 L 0 .05 0 r
F
.45024 .34919 m .44446 .34029 L .45484 .34822 L F
.43205 .60984 m .41756 .605 L .42613 .60439 L .592 .636 0 r
F
.44005 .6089 m .43205 .60984 L .42613 .60439 L .562 .613 0 r
F
.4461 .6136 m .43205 .60984 L .44005 .6089 L .54 .606 0 r
F
.60892 .41799 m .62346 .42414 L .61415 .42456 L .698 .678 0 r
F
.6001 .41885 m .60892 .41799 L .61415 .42456 L .671 .661 0 r
F
.41857 .8683 m .39234 .86685 L .39717 .86305 L .797 .836 0 r
F
.42251 .86441 m .41857 .8683 L .39717 .86305 L .773 .824 0 r
F
.44383 .86797 m .41857 .8683 L .42251 .86441 L .777 .837 0 r
F
.54839 .40168 m .55351 .39904 L .56044 .40277 L .489 .568 0 r
F
.54196 .39849 m .55351 .39904 L .54839 .40168 L .464 .55 0 r
F
.41756 .605 m .40292 .59896 L .41198 .59874 L .642 .658 0 r
F
.42613 .60439 m .41756 .605 L .41198 .59874 L .612 .638 0 r
F
.3354 .58124 m .32128 .56876 L .33128 .56954 L .849 .742 0 r
F
.34515 .58145 m .3354 .58124 L .33128 .56954 L .832 .732 0 r
F
.35261 .24345 m .36222 .22098 L .36895 .22769 L 1 .801 0 r
F
.35261 .24345 m .34515 .23699 L .36222 .22098 L F
.72133 .44148 m .73486 .45611 L .72468 .4557 L .92 .769 0 r
F
.71128 .44168 m .72133 .44148 L .72468 .4557 L .909 .762 0 r
F
.49033 .86254 m .48924 .86624 L .46784 .86599 L .714 .815 0 r
F
.51095 .86107 m .48924 .86624 L .49033 .86254 L .739 .835 0 r
F
.63279 .42356 m .64739 .43159 L .63768 .43166 L .762 .704 0 r
F
.62346 .42414 m .63279 .42356 L .63768 .43166 L .738 .69 0 r
F
.39234 .86685 m .36547 .86348 L .37114 .85988 L .815 .834 0 r
F
.39717 .86305 m .39234 .86685 L .37114 .85988 L .795 .825 0 r
F
.66686 .43104 m .6812 .44168 L .6712 .44145 L .836 .733 0 r
F
.65712 .43138 m .66686 .43104 L .6712 .44145 L .818 .723 0 r
F
.27138 .56639 m .25795 .54928 L .26809 .55018 L .94 .784 0 r
F
.28135 .56669 m .27138 .56639 L .26809 .55018 L .93 .777 0 r
F
.58618 .41437 m .59442 .41312 L .6001 .41885 L .626 .643 0 r
F
.5803 .40942 m .59442 .41312 L .58618 .41437 L .606 .64 0 r
F
.44685 .86407 m .44383 .86797 L .42251 .86441 L .744 .819 0 r
F
.46784 .86599 m .44383 .86797 L .44685 .86407 L .751 .832 0 r
F
.45345 .61237 m .4461 .6136 L .44005 .6089 L .512 .582 0 r
F
.45942 .61642 m .4461 .6136 L .45345 .61237 L .489 .571 0 r
F
.47175 .61838 m .46593 .62024 L .45942 .61642 L .446 .533 0 r
F
.47787 .62166 m .46593 .62024 L .47175 .61838 L .43 .513 0 r
F
.29679 .85688 m .28963 .86005 L .26871 .84656 L .88 .835 0 r
F
.51393 .38771 m .52229 .38655 L .52113 .39015 L .384 .433 0 r
F
.51393 .38771 m .51404 .3839 L .52229 .38655 L F
.26442 .24012 m .27262 .21549 L .28087 .22057 L 1 .824 0 r
F
.26442 .24012 m .25563 .23559 L .27262 .21549 L F
.48963 .37646 m .49564 .37488 L .49762 .37887 L .272 .252 0 r
F
.48963 .37646 m .48663 .37197 L .49564 .37488 L F
.31368 .24174 m .32263 .21884 L .33016 .22473 L 1 .813 0 r
F
.31368 .24174 m .30551 .23629 L .32263 .21884 L F
.59442 .41312 m .60892 .41799 L .6001 .41885 L .654 .662 0 r
F
.54196 .39849 m .54615 .39556 L .55351 .39904 L .464 .55 0 r
F
.53522 .39552 m .54615 .39556 L .54196 .39849 L .44 .528 0 r
F
.53381 .64251 m .52868 .64416 L .52677 .64031 L .268 .246 0 r
F
.53381 .64251 m .53671 .64684 L .52868 .64416 L F
.59852 .69936 m .59331 .71007 L .58756 .69391 L .449 .207 0 r
F
.59197 .68776 m .58756 .69391 L .58187 .68289 L .281 .103 0 r
F
.59197 .68776 m .59852 .69936 L .58756 .69391 L F
.72852 .76596 m .72065 .78665 L .71286 .7817 L 1 .81 0 r
F
.72852 .76596 m .73696 .77049 L .72065 .78665 L F
.73139 .44119 m .74505 .45644 L .73486 .45611 L .931 .776 0 r
F
.72133 .44148 m .73139 .44119 L .73486 .45611 L .92 .769 0 r
F
.40292 .59896 m .38845 .5916 L .39793 .59184 L .687 .675 0 r
F
.41198 .59874 m .40292 .59896 L .39793 .59184 L .659 .657 0 r
F
.52113 .39015 m .53045 .38935 L .52826 .39274 L .405 .469 0 r
F
.52113 .39015 m .52229 .38655 L .53045 .38935 L F
.37899 .59151 m .36469 .58224 L .37448 .58285 L .754 .701 0 r
F
.38845 .5916 m .37899 .59151 L .37448 .58285 L .729 .687 0 r
F
.7781 .76534 m .77055 .78741 L .76218 .78333 L 1 .827 0 r
F
.7781 .76534 m .78705 .76896 L .77055 .78741 L F
.53522 .39552 m .53843 .39234 L .54615 .39556 L .44 .528 0 r
F
.52826 .39274 m .53843 .39234 L .53522 .39552 L .423 .501 0 r
F
.39867 .22586 m .41126 .20269 L .41627 .20893 L 1 .876 0 r
F
.39867 .22586 m .39279 .21869 L .41126 .20269 L F
.56687 .40677 m .5737 .40474 L .5803 .40942 L .558 .612 0 r
F
.56044 .40277 m .5737 .40474 L .56687 .40677 L .533 .602 0 r
F
.52826 .39274 m .53045 .38935 L .53843 .39234 L .423 .501 0 r
F
.68935 .76567 m .68111 .78606 L .67396 .78013 L 1 .788 0 r
F
.68935 .76567 m .69721 .77125 L .68111 .78606 L F
.28135 .56669 m .26809 .55018 L .27824 .55116 L .93 .777 0 r
F
.29132 .56707 m .28135 .56669 L .27824 .55116 L .92 .77 0 r
F
.34515 .58145 m .33128 .56954 L .34129 .57044 L .832 .732 0 r
F
.35492 .58178 m .34515 .58145 L .34129 .57044 L .812 .721 0 r
F
.60509 .71306 m .59917 .73369 L .59331 .71007 L .909 .397 0 r
F
.59852 .69936 m .60509 .71306 L .59331 .71007 L .449 .207 0 r
F
.44446 .34029 m .44988 .34218 L .45484 .34822 L 0 .02 0 r
F
.44446 .34029 m .43869 .32908 L .44988 .34218 L F
.55204 .65183 m .54838 .65411 L .54452 .64945 L .199 .147 0 r
F
.55204 .65183 m .55683 .65737 L .54838 .65411 L F
.37565 .2347 m .38689 .21184 L .39279 .21869 L 1 .824 0 r
F
.37565 .2347 m .36895 .22769 L .38689 .21184 L F
.6221 .79031 m .61005 .81422 L .60535 .80893 L 1 .867 0 r
F
.6221 .79031 m .6277 .79741 L .61005 .81422 L F
.60535 .80893 m .61005 .81422 L .59144 .82994 L 1 1 0 r
F
.46471 .36025 m .46993 .36001 L .47394 .36421 L .024 .069 0 r
F
.46471 .36025 m .45978 .35425 L .46993 .36001 L F
.56486 .66013 m .5616 .66289 L .55683 .65737 L .165 .098 0 r
F
.56486 .66013 m .57054 .66689 L .5616 .66289 L F
.33183 .86152 m .30396 .85376 L .31115 .85069 L .858 .834 0 r
F
.33828 .85812 m .33183 .86152 L .31115 .85069 L .846 .829 0 r
F
.6596 .76708 m .65068 .78847 L .64426 .78155 L 1 .768 0 r
F
.6596 .76708 m .66679 .77383 L .65068 .78847 L F
.47793 .36901 m .48362 .36805 L .48663 .37197 L .162 .118 0 r
F
.47793 .36901 m .47394 .36421 L .48362 .36805 L F
.58544 .678 m .58187 .68289 L .57621 .67429 L .229 .096 0 r
F
.58544 .678 m .59197 .68776 L .58187 .68289 L F
.43299 .31303 m .4402 .30722 L .4449 .33612 L .219 .038 0 r
F
.43869 .32908 m .43299 .31303 L .4449 .33612 L 0 0 0 r
F
.58768 .82653 m .59144 .82994 L .57203 .84254 L 1 1 0 r
F
.60535 .80893 m .59144 .82994 L .58768 .82653 L F
.67662 .43057 m .69122 .44179 L .6812 .44168 L .854 .743 0 r
F
.66686 .43104 m .67662 .43057 L .6812 .44168 L .836 .733 0 r
F
.46991 .86222 m .46784 .86599 L .44685 .86407 L .706 .804 0 r
F
.49033 .86254 m .46784 .86599 L .46991 .86222 L .714 .815 0 r
F
.74145 .44082 m .75524 .45668 L .74505 .45644 L .941 .782 0 r
F
.73139 .44119 m .74145 .44082 L .74505 .45644 L .931 .776 0 r
F
.36547 .86348 m .33828 .85812 L .34475 .85478 L .831 .831 0 r
F
.37114 .85988 m .36547 .86348 L .34475 .85478 L .815 .824 0 r
F
.34515 .23699 m .35547 .2145 L .36222 .22098 L 1 .816 0 r
F
.34515 .23699 m .33767 .23077 L .35547 .2145 L F
.50018 .62746 m .49805 .63044 L .49108 .62768 L .383 .433 0 r
F
.5063 .62982 m .49805 .63044 L .50018 .62746 L .368 .406 0 r
F
.5063 .62982 m .50518 .63307 L .49805 .63044 L F
.46605 .61493 m .45942 .61642 L .45345 .61237 L .467 .548 0 r
F
.47175 .61838 m .45942 .61642 L .46605 .61493 L .446 .533 0 r
F
.63782 .77388 m .6277 .79741 L .6221 .79031 L 1 .775 0 r
F
.63782 .77388 m .64426 .78155 L .6277 .79741 L F
.56921 .83988 m .57203 .84254 L .552 .85157 L 1 1 0 r
F
.58768 .82653 m .57203 .84254 L .56921 .83988 L F
.49419 .62496 m .49108 .62768 L .48433 .62476 L .398 .457 0 r
F
.50018 .62746 m .49108 .62768 L .49419 .62496 L .383 .433 0 r
F
.64215 .42283 m .65712 .43138 L .64739 .43159 L .784 .717 0 r
F
.63279 .42356 m .64215 .42283 L .64739 .43159 L .762 .704 0 r
F
.51249 .63204 m .50518 .63307 L .5063 .62982 L .352 .38 0 r
F
.51249 .63204 m .51239 .63558 L .50518 .63307 L F
.61777 .41696 m .63279 .42356 L .62346 .42414 L .724 .695 0 r
F
.60892 .41799 m .61777 .41696 L .62346 .42414 L .698 .678 0 r
F
.29132 .56707 m .27824 .55116 L .28839 .55222 L .92 .77 0 r
F
.3013 .56753 m .29132 .56707 L .28839 .55222 L .908 .763 0 r
F
.55014 .84888 m .552 .85157 L .53157 .85756 L .792 .843 0 r
F
.56921 .83988 m .552 .85157 L .55014 .84888 L 1 1 0 r
F
.30551 .23629 m .31509 .21306 L .32263 .21884 L 1 .821 0 r
F
.30551 .23629 m .29731 .23096 L .31509 .21306 L F
.43869 .32908 m .4449 .33612 L .44988 .34218 L 0 0 0 r
F
.49762 .37887 m .50485 .37766 L .50579 .38135 L .301 .299 0 r
F
.49762 .37887 m .49564 .37488 L .50485 .37766 L F
.48839 .62232 m .48433 .62476 L .47787 .62166 L .411 .479 0 r
F
.49419 .62496 m .48433 .62476 L .48839 .62232 L .398 .457 0 r
F
.53069 .85458 m .53157 .85756 L .51095 .86107 L .689 .78 0 r
F
.55014 .84888 m .53157 .85756 L .53069 .85458 L .792 .843 0 r
F
.42613 .60439 m .41198 .59874 L .42107 .5987 L .612 .638 0 r
F
.43472 .60396 m .42613 .60439 L .42107 .5987 L .581 .617 0 r
F
.44005 .6089 m .42613 .60439 L .43472 .60396 L .562 .613 0 r
F
.72006 .76128 m .71286 .7817 L .70504 .77658 L 1 .799 0 r
F
.72006 .76128 m .72852 .76596 L .71286 .7817 L F
.54065 .64453 m .53671 .64684 L .53381 .64251 L .26 .23 0 r
F
.54065 .64453 m .54452 .64945 L .53671 .64684 L F
.76913 .76164 m .76218 .78333 L .75379 .77916 L 1 .821 0 r
F
.76913 .76164 m .7781 .76534 L .76218 .78333 L F
.5187 .63414 m .51239 .63558 L .51249 .63204 L .337 .353 0 r
F
.5187 .63414 m .51961 .63799 L .51239 .63558 L F
.56044 .40277 m .56646 .40037 L .5737 .40474 L .533 .602 0 r
F
.55351 .39904 m .56646 .40037 L .56044 .40277 L .504 .587 0 r
F
.5803 .40942 m .58788 .40767 L .59442 .41312 L .606 .64 0 r
F
.5737 .40474 m .58788 .40767 L .5803 .40942 L .583 .634 0 r
F
.44807 .60812 m .44005 .6089 L .43472 .60396 L .533 .59 0 r
F
.45345 .61237 m .44005 .6089 L .44807 .60812 L .512 .582 0 r
F
.75153 .44037 m .76544 .45686 L .75524 .45668 L .949 .788 0 r
F
.74145 .44082 m .75153 .44037 L .75524 .45668 L .941 .782 0 r
F
.35492 .58178 m .34129 .57044 L .35131 .57147 L .812 .721 0 r
F
.36469 .58224 m .35492 .58178 L .35131 .57147 L .791 .709 0 r
F
.38845 .5916 m .37448 .58285 L .38428 .5836 L .729 .687 0 r
F
.39793 .59184 m .38845 .5916 L .38428 .5836 L .702 .671 0 r
F
.29679 .85688 m .26871 .84656 L .27656 .84382 L .88 .835 0 r
F
.30396 .85376 m .29679 .85688 L .27656 .84382 L .871 .831 0 r
F
.3013 .56753 m .28839 .55222 L .29854 .55339 L .908 .763 0 r
F
.31129 .5681 m .3013 .56753 L .29854 .55339 L .895 .755 0 r
F
.68147 .75978 m .67396 .78013 L .66679 .77383 L 1 .768 0 r
F
.68147 .75978 m .68935 .76567 L .67396 .78013 L F
.51106 .85781 m .51095 .86107 L .49033 .86254 L .654 .766 0 r
F
.53069 .85458 m .51095 .86107 L .51106 .85781 L .689 .78 0 r
F
.68639 .42999 m .70124 .44179 L .69122 .44179 L .869 .752 0 r
F
.67662 .43057 m .68639 .42999 L .69122 .44179 L .854 .743 0 r
F
.60269 .4117 m .61777 .41696 L .60892 .41799 L .681 .68 0 r
F
.59442 .41312 m .60269 .4117 L .60892 .41799 L .654 .662 0 r
F
.48284 .61954 m .47787 .62166 L .47175 .61838 L .423 .498 0 r
F
.48839 .62232 m .47787 .62166 L .48284 .61954 L .411 .479 0 r
F
.41198 .59874 m .39793 .59184 L .40742 .59225 L .659 .657 0 r
F
.42107 .5987 m .41198 .59874 L .40742 .59225 L .629 .638 0 r
F
.58788 .40767 m .60269 .4117 L .59442 .41312 L .634 .66 0 r
F
.42251 .86441 m .39717 .86305 L .40201 .85935 L .773 .824 0 r
F
.42646 .86062 m .42251 .86441 L .40201 .85935 L .745 .809 0 r
F
.44685 .86407 m .42251 .86441 L .42646 .86062 L .744 .819 0 r
F
.57892 .66955 m .57621 .67429 L .57054 .66689 L .232 .128 0 r
F
.57892 .66955 m .58544 .678 L .57621 .67429 L F
.39279 .21869 m .40624 .19642 L .41126 .20269 L 1 .892 0 r
F
.39279 .21869 m .38689 .21184 L .40624 .19642 L F
.36895 .22769 m .38098 .20521 L .38689 .21184 L 1 .841 0 r
F
.36895 .22769 m .36222 .22098 L .38098 .20521 L F
.65238 .75972 m .64426 .78155 L .63782 .77388 L 1 .734 0 r
F
.65238 .75972 m .6596 .76708 L .64426 .78155 L F
.52485 .63609 m .51961 .63799 L .5187 .63414 L .324 .329 0 r
F
.52485 .63609 m .52677 .64031 L .51961 .63799 L F
.76162 .43985 m .77565 .45696 L .76544 .45686 L .957 .793 0 r
F
.75153 .44037 m .76162 .43985 L .76544 .45686 L .949 .788 0 r
F
.46082 .6113 m .45345 .61237 L .44807 .60812 L .487 .559 0 r
F
.46605 .61493 m .45345 .61237 L .46082 .6113 L .467 .548 0 r
F
.39717 .86305 m .37114 .85988 L .37683 .85634 L .795 .825 0 r
F
.40201 .85935 m .39717 .86305 L .37683 .85634 L .773 .814 0 r
F
.50579 .38135 m .51415 .38038 L .51404 .3839 L .335 .354 0 r
F
.50579 .38135 m .50485 .37766 L .51415 .38038 L F
.33767 .23077 m .3487 .20818 L .35547 .2145 L 1 .827 0 r
F
.33767 .23077 m .33016 .22473 L .3487 .20818 L F
.64215 .42283 m .65152 .42196 L .65712 .43138 L .784 .717 0 r
F
.65152 .42196 m .66686 .43104 L .65712 .43138 L .805 .729 0 r
F
.55351 .39904 m .55865 .39632 L .56646 .40037 L .504 .587 0 r
F
.54615 .39556 m .55865 .39632 L .55351 .39904 L .474 .566 0 r
F
.31129 .5681 m .29854 .55339 L .30869 .55465 L .895 .755 0 r
F
.32128 .56876 m .31129 .5681 L .30869 .55465 L .88 .746 0 r
F
.29731 .23096 m .30752 .20737 L .31509 .21306 L 1 .828 0 r
F
.29731 .23096 m .2891 .22573 L .30752 .20737 L F
.61646 .78207 m .6221 .79031 L .60535 .80893 L 1 .814 0 r
F
.63134 .76512 m .6221 .79031 L .61646 .78207 L 1 .724 0 r
F
.63134 .76512 m .63782 .77388 L .6221 .79031 L F
.44988 .86031 m .44685 .86407 L .42646 .86062 L .707 .797 0 r
F
.46991 .86222 m .44685 .86407 L .44988 .86031 L .706 .804 0 r
F
.76015 .75784 m .75379 .77916 L .74538 .77489 L 1 .815 0 r
F
.76015 .75784 m .76913 .76164 L .75379 .77916 L F
.36469 .58224 m .35131 .57147 L .36133 .57263 L .791 .709 0 r
F
.37448 .58285 m .36469 .58224 L .36133 .57263 L .768 .695 0 r
F
.49143 .85906 m .49033 .86254 L .46991 .86222 L .648 .766 0 r
F
.51106 .85781 m .49033 .86254 L .49143 .85906 L .654 .766 0 r
F
.47759 .61661 m .47175 .61838 L .46605 .61493 L .434 .514 0 r
F
.48284 .61954 m .47175 .61838 L .47759 .61661 L .423 .498 0 r
F
.60509 .71306 m .61168 .72803 L .59917 .73369 L .909 .397 0 r
F
.59917 .73369 m .59117 .79298 L .58612 .76299 L 1 .519 0 r
F
.59917 .73369 m .60503 .75643 L .59117 .79298 L F
.61168 .72803 m .60503 .75643 L .59917 .73369 L 1 .513 0 r
F
.71158 .7564 m .70504 .77658 L .69721 .77125 L 1 .786 0 r
F
.71158 .7564 m .72006 .76128 L .70504 .77658 L F
.62664 .41577 m .64215 .42283 L .63279 .42356 L .748 .709 0 r
F
.61777 .41696 m .62664 .41577 L .63279 .42356 L .724 .695 0 r
F
.48663 .37197 m .49365 .37144 L .49564 .37488 L .195 .157 0 r
F
.48663 .37197 m .48362 .36805 L .49365 .37144 L F
.77171 .43926 m .78586 .457 L .77565 .45696 L .965 .798 0 r
F
.76162 .43985 m .77171 .43926 L .77565 .45696 L .957 .793 0 r
F
.69618 .4293 m .71128 .44168 L .70124 .44179 L .884 .761 0 r
F
.68639 .42999 m .69618 .4293 L .70124 .44179 L .869 .752 0 r
F
.33828 .85812 m .31115 .85069 L .31836 .84766 L .846 .829 0 r
F
.34475 .85478 m .33828 .85812 L .31836 .84766 L .832 .823 0 r
F
.61646 .78207 m .60535 .80893 L .60064 .80363 L 1 .814 0 r
F
.60064 .80363 m .60535 .80893 L .58768 .82653 L 1 1 0 r
F
.55918 .65376 m .55683 .65737 L .55204 .65183 L .235 .176 0 r
F
.55918 .65376 m .56486 .66013 L .55683 .65737 L F
.45978 .35425 m .4659 .35695 L .46993 .36001 L 0 .039 0 r
F
.45978 .35425 m .45484 .34822 L .4659 .35695 L F
.5737 .40474 m .58055 .40257 L .58788 .40767 L .583 .634 0 r
F
.56646 .40037 m .58055 .40257 L .5737 .40474 L .556 .624 0 r
F
.67357 .75351 m .66679 .77383 L .6596 .76708 L 1 .745 0 r
F
.67357 .75351 m .68147 .75978 L .66679 .77383 L F
.54615 .39556 m .55035 .39259 L .55865 .39632 L .474 .566 0 r
F
.53843 .39234 m .55035 .39259 L .54615 .39556 L .443 .539 0 r
F
.53089 .63786 m .52677 .64031 L .52485 .63609 L .314 .31 0 r
F
.53089 .63786 m .53381 .64251 L .52677 .64031 L F
.51404 .3839 m .52346 .38314 L .52229 .38655 L .368 .41 0 r
F
.51404 .3839 m .51415 .38038 L .52346 .38314 L F
.39793 .59184 m .38428 .5836 L .39409 .58451 L .702 .671 0 r
F
.40742 .59225 m .39793 .59184 L .39409 .58451 L .673 .654 0 r
F
.54723 .64627 m .54452 .64945 L .54065 .64453 L .266 .23 0 r
F
.54723 .64627 m .55204 .65183 L .54452 .64945 L F
.32128 .56876 m .30869 .55465 L .31884 .55603 L .88 .746 0 r
F
.33128 .56954 m .32128 .56876 L .31884 .55603 L .864 .736 0 r
F
.37114 .85988 m .34475 .85478 L .35124 .85149 L .815 .824 0 r
F
.37683 .85634 m .37114 .85988 L .35124 .85149 L .797 .816 0 r
F
.78182 .43861 m .79608 .45699 L .78586 .457 L .971 .802 0 r
F
.77171 .43926 m .78182 .43861 L .78586 .457 L .965 .798 0 r
F
.43472 .60396 m .42107 .5987 L .43017 .59883 L .581 .617 0 r
F
.44333 .6037 m .43472 .60396 L .43017 .59883 L .551 .595 0 r
F
.44807 .60812 m .43472 .60396 L .44333 .6037 L .533 .59 0 r
F
.64514 .7516 m .63782 .77388 L .63134 .76512 L 1 .694 0 r
F
.64514 .7516 m .65238 .75972 L .63782 .77388 L F
.47394 .36421 m .48059 .36497 L .48362 .36805 L .015 .08 0 r
F
.47394 .36421 m .46993 .36001 L .48059 .36497 L F
.53843 .39234 m .54166 .38918 L .55035 .39259 L .443 .539 0 r
F
.53045 .38935 m .54166 .38918 L .53843 .39234 L .422 .504 0 r
F
.52229 .38655 m .53266 .38605 L .53045 .38935 L .397 .46 0 r
F
.52229 .38655 m .52346 .38314 L .53266 .38605 L F
.4727 .61355 m .46605 .61493 L .46082 .6113 L .449 .526 0 r
F
.47759 .61661 m .46605 .61493 L .4727 .61355 L .434 .514 0 r
F
.58391 .82425 m .58768 .82653 L .56921 .83988 L 1 1 0 r
F
.60064 .80363 m .58768 .82653 L .58391 .82425 L F
.42107 .5987 m .40742 .59225 L .41693 .59282 L .629 .638 0 r
F
.43017 .59883 m .42107 .5987 L .41693 .59282 L .598 .618 0 r
F
.53045 .38935 m .53266 .38605 L .54166 .38918 L .422 .504 0 r
F
.5724 .66199 m .57054 .66689 L .56486 .66013 L .258 .178 0 r
F
.5724 .66199 m .57892 .66955 L .57054 .66689 L F
.6609 .42096 m .67662 .43057 L .66686 .43104 L .824 .74 0 r
F
.65152 .42196 m .6609 .42096 L .66686 .43104 L .805 .729 0 r
F
.30396 .85376 m .27656 .84382 L .28444 .84112 L .871 .831 0 r
F
.31115 .85069 m .30396 .85376 L .28444 .84112 L .86 .826 0 r
F
.36222 .22098 m .37504 .19871 L .38098 .20521 L 1 .854 0 r
F
.36222 .22098 m .35547 .2145 L .37504 .19871 L F
.37448 .58285 m .36133 .57263 L .37136 .57394 L .768 .695 0 r
F
.38428 .5836 m .37448 .58285 L .37136 .57394 L .742 .681 0 r
F
.2174 .54638 m .20727 .5458 L .20596 .5251 L .991 .807 0 r
F
.75115 .75393 m .74538 .77489 L .73696 .77049 L 1 .807 0 r
F
.75115 .75393 m .76015 .75784 L .74538 .77489 L F
.45611 .60752 m .44807 .60812 L .44333 .6037 L .506 .567 0 r
F
.46082 .6113 m .44807 .60812 L .45611 .60752 L .487 .559 0 r
F
.61097 .41012 m .62664 .41577 L .61777 .41696 L .707 .697 0 r
F
.60269 .4117 m .61097 .41012 L .61777 .41696 L .681 .68 0 r
F
.47199 .85863 m .46991 .86222 L .44988 .86031 L .654 .768 0 r
F
.49143 .85906 m .46991 .86222 L .47199 .85863 L .648 .766 0 r
F
.70598 .4285 m .72133 .44148 L .71128 .44168 L .897 .768 0 r
F
.69618 .4293 m .70598 .4285 L .71128 .44168 L .884 .761 0 r
F
.33016 .22473 m .3419 .20199 L .3487 .20818 L 1 .836 0 r
F
.33016 .22473 m .32263 .21884 L .3419 .20199 L F
.2891 .22573 m .29993 .20175 L .30752 .20737 L 1 .834 0 r
F
.2891 .22573 m .28087 .22057 L .29993 .20175 L F
.70308 .75132 m .69721 .77125 L .68935 .76567 L 1 .772 0 r
F
.70308 .75132 m .71158 .7564 L .69721 .77125 L F
.58788 .40767 m .5955 .40576 L .60269 .4117 L .634 .66 0 r
F
.58055 .40257 m .5955 .40576 L .58788 .40767 L .61 .655 0 r
F
.61078 .7716 m .61646 .78207 L .60064 .80363 L 1 .728 0 r
F
.62483 .75478 m .61646 .78207 L .61078 .7716 L 1 .661 0 r
F
.62483 .75478 m .63134 .76512 L .61646 .78207 L F
.79194 .43791 m .8063 .45692 L .79608 .45699 L .977 .807 0 r
F
.78182 .43861 m .79194 .43791 L .79608 .45699 L .971 .802 0 r
F
.33128 .56954 m .31884 .55603 L .329 .55753 L .864 .736 0 r
F
.34129 .57044 m .33128 .56954 L .329 .55753 L .847 .725 0 r
F
.38689 .21184 m .4012 .19014 L .40624 .19642 L 1 .901 0 r
F
.38689 .21184 m .38098 .20521 L .4012 .19014 L F
.2174 .54638 m .20596 .5251 L .21619 .52635 L .991 .807 0 r
F
.22754 .54701 m .2174 .54638 L .21619 .52635 L .985 .803 0 r
F
.56638 .83831 m .56921 .83988 L .55014 .84888 L .788 .75 0 r
F
.58391 .82425 m .56921 .83988 L .56638 .83831 L 1 1 0 r
F
.50232 .62432 m .50018 .62746 L .49419 .62496 L .39 .44 0 r
F
.50743 .62635 m .50018 .62746 L .50232 .62432 L .38 .423 0 r
F
.50743 .62635 m .5063 .62982 L .50018 .62746 L F
.5955 .40576 m .61097 .41012 L .60269 .4117 L .661 .68 0 r
F
.49732 .62215 m .49419 .62496 L .48839 .62232 L .4 .457 0 r
F
.50232 .62432 m .49419 .62496 L .49732 .62215 L .39 .44 0 r
F
.66565 .74681 m .6596 .76708 L .65238 .75972 L 1 .717 0 r
F
.66565 .74681 m .67357 .75351 L .6596 .76708 L F
.53677 .63941 m .53381 .64251 L .53089 .63786 L .309 .298 0 r
F
.53677 .63941 m .54065 .64453 L .53381 .64251 L F
.5126 .62825 m .5063 .62982 L .50743 .62635 L .37 .405 0 r
F
.5126 .62825 m .51249 .63204 L .5063 .62982 L F
.56646 .40037 m .5725 .39783 L .58055 .40257 L .556 .624 0 r
F
.55865 .39632 m .5725 .39783 L .56646 .40037 L .524 .608 0 r
F
.54828 .84694 m .55014 .84888 L .53069 .85458 L .6 .606 0 r
F
.56638 .83831 m .55014 .84888 L .54828 .84694 L .788 .75 0 r
F
.63553 .41443 m .65152 .42196 L .64215 .42283 L .771 .723 0 r
F
.62664 .41577 m .63553 .41443 L .64215 .42283 L .748 .709 0 r
F
.22754 .54701 m .21619 .52635 L .22642 .52767 L .985 .803 0 r
F
.23767 .54771 m .22754 .54701 L .22642 .52767 L .979 .798 0 r
F
.49564 .37488 m .5039 .37442 L .50485 .37766 L .247 .221 0 r
F
.49564 .37488 m .49365 .37144 L .5039 .37442 L F
.63787 .74257 m .63134 .76512 L .62483 .75478 L 1 .647 0 r
F
.63787 .74257 m .64514 .7516 L .63134 .76512 L F
.49248 .61985 m .48839 .62232 L .48284 .61954 L .41 .472 0 r
F
.49732 .62215 m .48839 .62232 L .49248 .61985 L .4 .457 0 r
F
.6086 .69909 m .60509 .71306 L .59852 .69936 L .703 .4 0 r
F
.60128 .68864 m .59852 .69936 L .59197 .68776 L .506 .329 0 r
F
.60128 .68864 m .6086 .69909 L .59852 .69936 L F
.80206 .43716 m .81653 .4568 L .8063 .45692 L .983 .811 0 r
F
.79194 .43791 m .80206 .43716 L .8063 .45692 L .977 .807 0 r
F
.52981 .8521 m .53069 .85458 L .51106 .85781 L .559 .622 0 r
F
.54828 .84694 m .53069 .85458 L .52981 .8521 L .6 .606 0 r
F
.40742 .59225 m .39409 .58451 L .40392 .58557 L .673 .654 0 r
F
.41693 .59282 m .40742 .59225 L .40392 .58557 L .643 .636 0 r
F
.61593 .71026 m .61168 .72803 L .60509 .71306 L .903 .474 0 r
F
.6086 .69909 m .61593 .71026 L .60509 .71306 L .703 .4 0 r
F
.60503 .75643 m .59591 .79832 L .59117 .79298 L 1 .611 0 r
F
.60503 .75643 m .61078 .7716 L .59591 .79832 L F
.61827 .74239 m .61078 .7716 L .60503 .75643 L 1 .589 0 r
F
.61168 .72803 m .61827 .74239 L .60503 .75643 L 1 .513 0 r
F
.51778 .63 m .51249 .63204 L .5126 .62825 L .361 .387 0 r
F
.51778 .63 m .5187 .63414 L .51249 .63204 L F
.23767 .54771 m .22642 .52767 L .23665 .52904 L .979 .798 0 r
F
.24781 .54846 m .23767 .54771 L .23665 .52904 L .972 .792 0 r
F
.34129 .57044 m .329 .55753 L .33917 .55915 L .847 .725 0 r
F
.35131 .57147 m .34129 .57044 L .33917 .55915 L .827 .714 0 r
F
.42646 .86062 m .40201 .85935 L .40687 .85574 L .745 .809 0 r
F
.43043 .85695 m .42646 .86062 L .40687 .85574 L .714 .791 0 r
F
.44988 .86031 m .42646 .86062 L .43043 .85695 L .707 .797 0 r
F
.46821 .61036 m .46082 .6113 L .45611 .60752 L .465 .537 0 r
F
.4727 .61355 m .46082 .6113 L .46821 .61036 L .449 .526 0 r
F
.71579 .42761 m .73139 .44119 L .72133 .44148 L .909 .775 0 r
F
.70598 .4285 m .71579 .42761 L .72133 .44148 L .897 .768 0 r
F
.40201 .85935 m .37683 .85634 L .38253 .85289 L .773 .814 0 r
F
.40687 .85574 m .40201 .85935 L .38253 .85289 L .749 .802 0 r
F
.61078 .7716 m .60064 .80363 L .59591 .79832 L 1 .728 0 r
F
.61827 .74239 m .62483 .75478 L .61078 .7716 L 1 .589 0 r
F
.59397 .67913 m .59197 .68776 L .58544 .678 L .392 .285 0 r
F
.59397 .67913 m .60128 .68864 L .59197 .68776 L F
.74214 .7499 m .73696 .77049 L .72852 .76596 L 1 .798 0 r
F
.74214 .7499 m .75115 .75393 L .73696 .77049 L F
.48784 .61744 m .48284 .61954 L .47759 .61661 L .419 .486 0 r
F
.49248 .61985 m .48284 .61954 L .48784 .61744 L .41 .472 0 r
F
.38428 .5836 m .37136 .57394 L .3814 .57541 L .742 .681 0 r
F
.39409 .58451 m .38428 .5836 L .3814 .57541 L .715 .666 0 r
F
.51116 .8549 m .51106 .85781 L .49143 .85906 L .559 .665 0 r
F
.52981 .8521 m .51106 .85781 L .51116 .8549 L .559 .622 0 r
F
.67031 .41984 m .68639 .42999 L .67662 .43057 L .842 .75 0 r
F
.6609 .42096 m .67031 .41984 L .67662 .43057 L .824 .74 0 r
F
.61593 .71026 m .62325 .72162 L .61168 .72803 L .903 .474 0 r
F
.62325 .72162 m .61827 .74239 L .61168 .72803 L 1 .539 0 r
F
.34475 .85478 m .31836 .84766 L .32559 .84469 L .832 .823 0 r
F
.35124 .85149 m .34475 .85478 L .32559 .84469 L .818 .816 0 r
F
.24781 .54846 m .23665 .52904 L .24687 .53048 L .972 .792 0 r
F
.25795 .54928 m .24781 .54846 L .24687 .53048 L .965 .787 0 r
F
.63057 .73253 m .62483 .75478 L .61827 .74239 L 1 .595 0 r
F
.63057 .73253 m .63787 .74257 L .62483 .75478 L F
.69456 .74598 m .68935 .76567 L .68147 .75978 L 1 .755 0 r
F
.69456 .74598 m .70308 .75132 L .68935 .76567 L F
.80206 .43716 m .8122 .43635 L .81653 .4568 L .983 .811 0 r
F
.59591 .79832 m .60064 .80363 L .58391 .82425 L 1 1 0 r
F
.55348 .64762 m .55204 .65183 L .54723 .64627 L .286 .248 0 r
F
.55348 .64762 m .55918 .65376 L .55204 .65183 L F
.45484 .34822 m .46182 .35621 L .4659 .35695 L 0 0 0 r
F
.45484 .34822 m .44988 .34218 L .46182 .35621 L F
.52292 .63159 m .5187 .63414 L .51778 .63 L .353 .371 0 r
F
.52292 .63159 m .52485 .63609 L .5187 .63414 L F
.62325 .72162 m .63057 .73253 L .61827 .74239 L 1 .539 0 r
F
.28087 .22057 m .29232 .19619 L .29993 .20175 L 1 .839 0 r
F
.28087 .22057 m .27262 .21549 L .29232 .19619 L F
.65771 .73959 m .65238 .75972 L .64514 .7516 L 1 .686 0 r
F
.65771 .73959 m .66565 .74681 L .65238 .75972 L F
.32263 .21884 m .33509 .19588 L .3419 .20199 L 1 .844 0 r
F
.32263 .21884 m .31509 .21306 L .33509 .19588 L F
.55865 .39632 m .56381 .39349 L .5725 .39783 L .524 .608 0 r
F
.55035 .39259 m .56381 .39349 L .55865 .39632 L .488 .586 0 r
F
.25795 .54928 m .24687 .53048 L .25709 .53199 L .965 .787 0 r
F
.26809 .55018 m .25795 .54928 L .25709 .53199 L .956 .78 0 r
F
.35547 .2145 m .36908 .19231 L .37504 .19871 L 1 .863 0 r
F
.35547 .2145 m .3487 .20818 L .36908 .19231 L F
.56587 .65502 m .56486 .66013 L .55918 .65376 L .289 .233 0 r
F
.56587 .65502 m .5724 .66199 L .56486 .66013 L F
.45292 .8567 m .44988 .86031 L .43043 .85695 L .666 .77 0 r
F
.47199 .85863 m .44988 .86031 L .45292 .8567 L .654 .768 0 r
F
.43017 .59883 m .41693 .59282 L .42646 .59356 L .598 .618 0 r
F
.4393 .59913 m .43017 .59883 L .42646 .59356 L .566 .596 0 r
F
.44333 .6037 m .43017 .59883 L .4393 .59913 L .551 .595 0 r
F
.45197 .60361 m .44333 .6037 L .4393 .59913 L .522 .572 0 r
F
.45611 .60752 m .44333 .6037 L .45197 .60361 L .506 .567 0 r
F
.48346 .61491 m .47759 .61661 L .4727 .61355 L .427 .498 0 r
F
.48784 .61744 m .47759 .61661 L .48346 .61491 L .419 .486 0 r
F
.35131 .57147 m .33917 .55915 L .34933 .56092 L .827 .714 0 r
F
.36133 .57263 m .35131 .57147 L .34933 .56092 L .805 .701 0 r
F
.37683 .85634 m .35124 .85149 L .35774 .84828 L .797 .816 0 r
F
.38253 .85289 m .37683 .85634 L .35774 .84828 L .778 .806 0 r
F
.50485 .37766 m .51427 .37717 L .51415 .38038 L .302 .301 0 r
F
.50485 .37766 m .5039 .37442 L .51427 .37717 L F
.58055 .40257 m .58743 .40023 L .5955 .40576 L .61 .655 0 r
F
.5725 .39783 m .58743 .40023 L .58055 .40257 L .581 .647 0 r
F
.58667 .67053 m .58544 .678 L .57892 .66955 L .357 .272 0 r
F
.58667 .67053 m .59397 .67913 L .58544 .678 L F
.31115 .85069 m .28444 .84112 L .29233 .83848 L .86 .826 0 r
F
.31836 .84766 m .31115 .85069 L .29233 .83848 L .849 .821 0 r
F
.61928 .40838 m .63553 .41443 L .62664 .41577 L .732 .713 0 r
F
.61097 .41012 m .61928 .40838 L .62664 .41577 L .707 .697 0 r
F
.49252 .85585 m .49143 .85906 L .47199 .85863 L .576 .7 0 r
F
.51116 .8549 m .49143 .85906 L .49252 .85585 L .559 .665 0 r
F
.72562 .42664 m .74145 .44082 L .73139 .44119 L .919 .782 0 r
F
.71579 .42761 m .72562 .42664 L .73139 .44119 L .909 .775 0 r
F
.54241 .64069 m .54065 .64453 L .53677 .63941 L .312 .296 0 r
F
.54241 .64069 m .54723 .64627 L .54065 .64453 L F
.26809 .55018 m .25709 .53199 L .26731 .53358 L .956 .78 0 r
F
.27824 .55116 m .26809 .55018 L .26731 .53358 L .947 .773 0 r
F
.27656 .84382 m .26871 .84656 L .25004 .83167 L .884 .829 0 r
F
.48362 .36805 m .49164 .36874 L .49365 .37144 L .081 .096 0 r
F
.48362 .36805 m .48059 .36497 L .49164 .36874 L F
.38098 .20521 m .39615 .18383 L .4012 .19014 L 1 .906 0 r
F
.38098 .20521 m .37504 .19871 L .39615 .18383 L F
.63553 .41443 m .64444 .41295 L .65152 .42196 L .771 .723 0 r
F
.64444 .41295 m .6609 .42096 L .65152 .42196 L .792 .735 0 r
F
.73311 .74574 m .72852 .76596 L .72006 .76128 L 1 .788 0 r
F
.73311 .74574 m .74214 .7499 L .72852 .76596 L F
.52797 .63299 m .52485 .63609 L .52292 .63159 L .346 .358 0 r
F
.52797 .63299 m .53089 .63786 L .52485 .63609 L F
.41693 .59282 m .40392 .58557 L .41376 .58681 L .643 .636 0 r
F
.42646 .59356 m .41693 .59282 L .41376 .58681 L .611 .616 0 r
F
.46418 .60707 m .45611 .60752 L .45197 .60361 L .48 .544 0 r
F
.46821 .61036 m .45611 .60752 L .46418 .60707 L .465 .537 0 r
F
.39409 .58451 m .3814 .57541 L .39146 .57702 L .715 .666 0 r
F
.40392 .58557 m .39409 .58451 L .39146 .57702 L .685 .649 0 r
F
.68603 .74036 m .68147 .75978 L .67357 .75351 L 1 .735 0 r
F
.68603 .74036 m .69456 .74598 L .68147 .75978 L F
.27824 .55116 m .26731 .53358 L .27753 .53527 L .947 .773 0 r
F
.28839 .55222 m .27824 .55116 L .27753 .53527 L .937 .766 0 r
F
.55035 .39259 m .55457 .38956 L .56381 .39349 L .488 .586 0 r
F
.54166 .38918 m .55457 .38956 L .55035 .39259 L .451 .555 0 r
F
.64974 .7318 m .64514 .7516 L .63787 .74257 L 1 .651 0 r
F
.64974 .7318 m .65771 .73959 L .64514 .7516 L F
.67973 .41859 m .69618 .4293 L .68639 .42999 L .858 .759 0 r
F
.67031 .41984 m .67973 .41859 L .68639 .42999 L .842 .75 0 r
F
.5955 .40576 m .60313 .40369 L .61097 .41012 L .661 .68 0 r
F
.58743 .40023 m .60313 .40369 L .5955 .40576 L .637 .677 0 r
F
.46993 .36001 m .47716 .36298 L .48059 .36497 L 0 .056 0 r
F
.46993 .36001 m .4659 .35695 L .47754 .36314 L F
.46849 .3588 m .46182 .35621 L .47446 .36306 L .483 0 0 r
F
.4659 .35695 m .4639 .35659 L .46849 .3588 L F
.4639 .35659 m .46182 .35621 L .46849 .3588 L F
.47716 .36298 m .47754 .36314 L .47777 .36327 L 0 .056 0 r
F
.47716 .36298 m .47777 .36327 L .48059 .36497 L F
.60313 .40369 m .61928 .40838 L .61097 .41012 L .688 .698 0 r
F
.47938 .61228 m .4727 .61355 L .46821 .61036 L .436 .508 0 r
F
.48346 .61491 m .4727 .61355 L .47938 .61228 L .427 .498 0 r
F
.36133 .57263 m .34933 .56092 L .3595 .56283 L .805 .701 0 r
F
.37136 .57394 m .36133 .57263 L .3595 .56283 L .781 .688 0 r
F
.51415 .38038 m .52463 .37992 L .52346 .38314 L .352 .382 0 r
F
.51415 .38038 m .51427 .37717 L .52463 .37992 L F
.79152 .74678 m .78705 .76896 L .7781 .76534 L 1 .819 0 r
F
.79152 .74678 m .80097 .74988 L .78705 .76896 L F
.28839 .55222 m .27753 .53527 L .28775 .53704 L .937 .766 0 r
F
.29854 .55339 m .28839 .55222 L .28775 .53704 L .925 .758 0 r
F
.73546 .42558 m .75153 .44037 L .74145 .44082 L .929 .788 0 r
F
.72562 .42664 m .73546 .42558 L .74145 .44082 L .919 .782 0 r
F
.58015 .82421 m .58086 .8267 L .56638 .83831 L .909 .687 0 r
F
.58015 .82421 m .56638 .83831 L .5663 .83831 L F
.57243 .83077 m .5663 .83831 L .56356 .83832 L F
.58015 .82421 m .5663 .83831 L .57243 .83077 L F
.57642 .82892 m .58015 .82421 L .57397 .82947 L 0 0 0 r
F
.57642 .82892 m .57397 .82947 L .56356 .83832 L F
.57906 .82833 m .57642 .82892 L .57274 .84146 L F
.57942 .82162 m .5795 .82193 L .57642 .82892 L 1 .995 0 r
F
.5795 .82193 m .58015 .82421 L .57642 .82892 L F
.59117 .79298 m .58015 .82421 L .57942 .82162 L F
.58015 .82421 m .58391 .82425 L .58086 .8267 L .909 .687 0 r
F
.59591 .79832 m .58391 .82425 L .58015 .82421 L 1 1 0 r
F
.59117 .79298 m .59591 .79832 L .58015 .82421 L 1 .995 0 r
F
.5867 .81246 m .57642 .82892 L .57906 .82833 L 0 0 0 r
F
.5867 .81246 m .59117 .79298 L .57895 .82276 L F
.58465 .81574 m .57895 .82276 L .57642 .82892 L F
.5867 .81246 m .57895 .82276 L .58465 .81574 L F
.54166 .38918 m .5449 .38602 L .55457 .38956 L .451 .555 0 r
F
.53266 .38605 m .5449 .38602 L .54166 .38918 L .425 .512 0 r
F
.57936 .6627 m .57892 .66955 L .5724 .66199 L .344 .282 0 r
F
.57936 .6627 m .58667 .67053 L .57892 .66955 L F
.47407 .85525 m .47199 .85863 L .45292 .8567 L .598 .723 0 r
F
.49252 .85585 m .47199 .85863 L .47407 .85525 L .576 .7 0 r
F
.52346 .38314 m .53488 .38283 L .53266 .38605 L .393 .454 0 r
F
.52346 .38314 m .52463 .37992 L .53488 .38283 L F
.64176 .72342 m .63787 .74257 L .63057 .73253 L 1 .613 0 r
F
.64176 .72342 m .64974 .7318 L .63787 .74257 L F
.31509 .21306 m .32825 .18985 L .33509 .19588 L 1 .85 0 r
F
.31509 .21306 m .30752 .20737 L .32825 .18985 L F
.53266 .38605 m .53488 .38283 L .5449 .38602 L .425 .512 0 r
F
.72406 .74142 m .72006 .76128 L .71158 .7564 L 1 .776 0 r
F
.72406 .74142 m .73311 .74574 L .72006 .76128 L F
.29854 .55339 m .28775 .53704 L .29796 .53893 L .925 .758 0 r
F
.30869 .55465 m .29854 .55339 L .29796 .53893 L .912 .749 0 r
F
.53287 .63417 m .53089 .63786 L .52797 .63299 L .344 .349 0 r
F
.53287 .63417 m .53677 .63941 L .53089 .63786 L F
.5725 .39783 m .57856 .39515 L .58743 .40023 L .581 .647 0 r
F
.56381 .39349 m .57856 .39515 L .5725 .39783 L .548 .632 0 r
F
.3487 .20818 m .3631 .18598 L .36908 .19231 L 1 .869 0 r
F
.3487 .20818 m .3419 .20199 L .3631 .18598 L F
.67748 .73441 m .67357 .75351 L .66565 .74681 L 1 .713 0 r
F
.67748 .73441 m .68603 .74036 L .67357 .75351 L F
.35124 .85149 m .32559 .84469 L .33283 .84178 L .818 .816 0 r
F
.35774 .84828 m .35124 .85149 L .33283 .84178 L .802 .808 0 r
F
.4393 .59913 m .42646 .59356 L .436 .59447 L .566 .596 0 r
F
.44844 .59961 m .4393 .59913 L .436 .59447 L .535 .574 0 r
F
.45197 .60361 m .4393 .59913 L .44844 .59961 L .522 .572 0 r
F
.55934 .64846 m .55918 .65376 L .55348 .64762 L .317 .285 0 r
F
.55934 .64846 m .56587 .65502 L .55918 .65376 L F
.47564 .60956 m .46821 .61036 L .46418 .60707 L .447 .516 0 r
F
.47938 .61228 m .46821 .61036 L .47564 .60956 L .436 .508 0 r
F
.37136 .57394 m .3595 .56283 L .36968 .56489 L .781 .688 0 r
F
.3814 .57541 m .37136 .57394 L .36968 .56489 L .755 .674 0 r
F
.40392 .58557 m .39146 .57702 L .40152 .5788 L .685 .649 0 r
F
.41376 .58681 m .40392 .58557 L .40152 .5788 L .654 .631 0 r
F
.50447 .62103 m .50232 .62432 L .49732 .62215 L .397 .447 0 r
F
.50857 .6227 m .50232 .62432 L .50447 .62103 L .391 .436 0 r
F
.50857 .6227 m .50743 .62635 L .50232 .62432 L F
.54777 .64163 m .54723 .64627 L .54241 .64069 L .324 .307 0 r
F
.54777 .64163 m .55348 .64762 L .54723 .64627 L F
.44988 .34218 m .45768 .36037 L .46182 .35621 L .796 .063 0 r
F
.44988 .34218 m .4449 .33612 L .45768 .36037 L F
.40687 .85574 m .38253 .85289 L .38825 .84953 L .749 .802 0 r
F
.41174 .85223 m .40687 .85574 L .38825 .84953 L .723 .787 0 r
F
.43043 .85695 m .40687 .85574 L .41174 .85223 L .714 .791 0 r
F
.50046 .61924 m .49732 .62215 L .49248 .61985 L .404 .458 0 r
F
.50447 .62103 m .49732 .62215 L .50046 .61924 L .397 .447 0 r
F
.63376 .71452 m .63057 .73253 L .62325 .72162 L .983 .572 0 r
F
.63376 .71452 m .64176 .72342 L .63057 .73253 L F
.78205 .74361 m .7781 .76534 L .76913 .76164 L 1 .813 0 r
F
.78205 .74361 m .79152 .74678 L .7781 .76534 L F
.56938 .83408 m .56356 .83832 L .56074 .84042 L 0 0 0 r
F
.57642 .82892 m .56356 .83832 L .56938 .83408 L F
.56356 .83832 m .56638 .83831 L .55825 .84219 L .525 .176 0 r
F
.56356 .83832 m .55825 .84219 L .54828 .84694 L F
.43441 .85341 m .43043 .85695 L .41174 .85223 L .679 .77 0 r
F
.45292 .8567 m .43043 .85695 L .43441 .85341 L .666 .77 0 r
F
.51271 .62424 m .50743 .62635 L .50857 .6227 L .385 .424 0 r
F
.51271 .62424 m .5126 .62825 L .50743 .62635 L F
.65338 .41133 m .67031 .41984 L .6609 .42096 L .812 .747 0 r
F
.64444 .41295 m .65338 .41133 L .6609 .42096 L .792 .735 0 r
F
.68917 .41724 m .70598 .4285 L .69618 .4293 L .872 .768 0 r
F
.67973 .41859 m .68917 .41724 L .69618 .4293 L .858 .759 0 r
F
.30869 .55465 m .29796 .53893 L .30818 .54092 L .912 .749 0 r
F
.31884 .55603 m .30869 .55465 L .30818 .54092 L .897 .74 0 r
F
.74531 .42445 m .76162 .43985 L .75153 .44037 L .938 .793 0 r
F
.73546 .42558 m .74531 .42445 L .75153 .44037 L .929 .788 0 r
F
.62762 .40648 m .64444 .41295 L .63553 .41443 L .756 .728 0 r
F
.61928 .40838 m .62762 .40648 L .63553 .41443 L .732 .713 0 r
F
.46063 .60369 m .45197 .60361 L .44844 .59961 L .494 .549 0 r
F
.46418 .60707 m .45197 .60361 L .46063 .60369 L .48 .544 0 r
F
.27656 .84382 m .25004 .83167 L .25854 .8294 L .884 .829 0 r
F
.28444 .84112 m .27656 .84382 L .25854 .8294 L .875 .824 0 r
F
.49657 .61734 m .49248 .61985 L .48784 .61744 L .41 .467 0 r
F
.50046 .61924 m .49248 .61985 L .49657 .61734 L .404 .458 0 r
F
.42646 .59356 m .41376 .58681 L .42362 .58821 L .611 .616 0 r
F
.436 .59447 m .42646 .59356 L .42362 .58821 L .578 .595 0 r
F
.31836 .84766 m .29233 .83848 L .30024 .83588 L .849 .821 0 r
F
.32559 .84469 m .31836 .84766 L .30024 .83588 L .837 .815 0 r
F
.62575 .70527 m .62325 .72162 L .61593 .71026 L .89 .529 0 r
F
.62575 .70527 m .63376 .71452 L .62325 .72162 L F
.49365 .37144 m .50295 .37167 L .5039 .37442 L .177 .13 0 r
F
.49365 .37144 m .49164 .36874 L .50295 .37167 L F
.54641 .84591 m .54828 .84694 L .52981 .8521 L .468 .236 0 r
F
.56356 .83832 m .54828 .84694 L .54641 .84591 L .525 .176 0 r
F
.61773 .69594 m .61593 .71026 L .6086 .69909 L .774 .486 0 r
F
.61773 .69594 m .62575 .70527 L .61593 .71026 L F
.51687 .62564 m .5126 .62825 L .51271 .62424 L .379 .413 0 r
F
.51687 .62564 m .51778 .63 L .5126 .62825 L F
.37504 .19871 m .39108 .17751 L .39615 .18383 L 1 .908 0 r
F
.37504 .19871 m .36908 .19231 L .39108 .17751 L F
.52892 .85019 m .52981 .8521 L .51116 .8549 L .476 .398 0 r
F
.54641 .84591 m .52981 .8521 L .52892 .85019 L .468 .236 0 r
F
.49286 .61534 m .48784 .61744 L .48346 .61491 L .416 .477 0 r
F
.49657 .61734 m .48784 .61744 L .49286 .61534 L .41 .467 0 r
F
.60971 .68681 m .6086 .69909 L .60128 .68864 L .647 .443 0 r
F
.60971 .68681 m .61773 .69594 L .6086 .69909 L F
.38253 .85289 m .35774 .84828 L .36426 .84514 L .778 .806 0 r
F
.38825 .84953 m .38253 .85289 L .36426 .84514 L .757 .795 0 r
F
.31884 .55603 m .30818 .54092 L .31839 .54304 L .897 .74 0 r
F
.329 .55753 m .31884 .55603 L .31839 .54304 L .881 .729 0 r
F
.715 .73691 m .71158 .7564 L .70308 .75132 L 1 .763 0 r
F
.715 .73691 m .72406 .74142 L .71158 .7564 L F
.57205 .65547 m .5724 .66199 L .56587 .65502 L .345 .305 0 r
F
.57205 .65547 m .57936 .6627 L .5724 .66199 L F
.6689 .72809 m .66565 .74681 L .65771 .73959 L 1 .688 0 r
F
.6689 .72809 m .67748 .73441 L .66565 .74681 L F
.51127 .85237 m .51116 .8549 L .49252 .85585 L .492 .533 0 r
F
.52892 .85019 m .51116 .8549 L .51127 .85237 L .476 .398 0 r
F
.58743 .40023 m .59432 .39774 L .60313 .40369 L .637 .677 0 r
F
.57856 .39515 m .59432 .39774 L .58743 .40023 L .609 .67 0 r
F
.3814 .57541 m .36968 .56489 L .37986 .56711 L .755 .674 0 r
F
.39146 .57702 m .3814 .57541 L .37986 .56711 L .726 .658 0 r
F
.53757 .6351 m .53677 .63941 L .53287 .63417 L .345 .348 0 r
F
.53757 .6351 m .54241 .64069 L .53677 .63941 L F
.52099 .62688 m .51778 .63 L .51687 .62564 L .374 .402 0 r
F
.52099 .62688 m .52292 .63159 L .51778 .63 L F
.45597 .85326 m .45292 .8567 L .43441 .85341 L .62 .737 0 r
F
.47407 .85525 m .45292 .8567 L .45597 .85326 L .598 .723 0 r
F
.77257 .74035 m .76913 .76164 L .76015 .75784 L 1 .806 0 r
F
.77257 .74035 m .78205 .74361 L .76913 .76164 L F
.56381 .39349 m .56899 .39054 L .57856 .39515 L .548 .632 0 r
F
.55457 .38956 m .56899 .39054 L .56381 .39349 L .509 .61 0 r
F
.60169 .67809 m .60128 .68864 L .59397 .67913 L .534 .407 0 r
F
.60169 .67809 m .60971 .68681 L .60128 .68864 L F
.75518 .42325 m .77171 .43926 L .76162 .43985 L .947 .798 0 r
F
.74531 .42445 m .75518 .42325 L .76162 .43985 L .938 .793 0 r
F
.47227 .60677 m .46418 .60707 L .46063 .60369 L .458 .522 0 r
F
.47564 .60956 m .46418 .60707 L .47227 .60677 L .447 .516 0 r
F
.48935 .61326 m .48346 .61491 L .47938 .61228 L .421 .485 0 r
F
.49286 .61534 m .48346 .61491 L .48935 .61326 L .416 .477 0 r
F
.61079 .40145 m .62762 .40648 L .61928 .40838 L .714 .716 0 r
F
.60313 .40369 m .61079 .40145 L .61928 .40838 L .688 .698 0 r
F
.30752 .20737 m .3214 .18386 L .32825 .18985 L 1 .854 0 r
F
.30752 .20737 m .29993 .20175 L .3214 .18386 L F
.329 .55753 m .31839 .54304 L .32861 .54529 L .881 .729 0 r
F
.33917 .55915 m .329 .55753 L .32861 .54529 L .863 .718 0 r
F
.41376 .58681 m .40152 .5788 L .41159 .58074 L .654 .631 0 r
F
.42362 .58821 m .41376 .58681 L .41159 .58074 L .621 .612 0 r
F
.59432 .39774 m .61079 .40145 L .60313 .40369 L .666 .697 0 r
F
.69863 .41579 m .71579 .42761 L .70598 .4285 L .886 .775 0 r
F
.68917 .41724 m .69863 .41579 L .70598 .4285 L .872 .768 0 r
F
.49363 .85292 m .49252 .85585 L .47407 .85525 L .506 .618 0 r
F
.51127 .85237 m .49252 .85585 L .49363 .85292 L .492 .533 0 r
F
.66031 .72138 m .65771 .73959 L .64974 .7318 L 1 .661 0 r
F
.66031 .72138 m .6689 .72809 L .65771 .73959 L F
.3419 .20199 m .3571 .17968 L .3631 .18598 L 1 .874 0 r
F
.3419 .20199 m .33509 .19588 L .3571 .17968 L F
.59368 .66989 m .59397 .67913 L .58667 .67053 L .452 .383 0 r
F
.59368 .66989 m .60169 .67809 L .59397 .67913 L F
.52503 .62795 m .52292 .63159 L .52099 .62688 L .37 .393 0 r
F
.52503 .62795 m .52797 .63299 L .52292 .63159 L F
.70592 .73221 m .70308 .75132 L .69456 .74598 L 1 .749 0 r
F
.70592 .73221 m .715 .73691 L .70308 .75132 L F
.5039 .37442 m .51438 .37425 L .51427 .37717 L .268 .238 0 r
F
.5039 .37442 m .50295 .37167 L .51438 .37425 L F
.66233 .40959 m .67973 .41859 L .67031 .41984 L .83 .757 0 r
F
.65338 .41133 m .66233 .40959 L .67031 .41984 L .812 .747 0 r
F
.33917 .55915 m .32861 .54529 L .33882 .54769 L .863 .718 0 r
F
.34933 .56092 m .33917 .55915 L .33882 .54769 L .842 .706 0 r
F
.48608 .6111 m .47938 .61228 L .47564 .60956 L .427 .492 0 r
F
.48935 .61326 m .47938 .61228 L .48608 .6111 L .421 .485 0 r
F
.48059 .36497 m .48962 .36689 L .49164 .36874 L 0 .085 0 r
F
.48059 .36497 m .47754 .36314 L .48962 .36689 L F
.44844 .59961 m .436 .59447 L .44557 .59555 L .535 .574 0 r
F
.45761 .60026 m .44844 .59961 L .44557 .59555 L .505 .552 0 r
F
.46063 .60369 m .44844 .59961 L .45761 .60026 L .494 .549 0 r
F
.55278 .64217 m .55348 .64762 L .54777 .64163 L .342 .33 0 r
F
.55278 .64217 m .55934 .64846 L .55348 .64762 L F
.39146 .57702 m .37986 .56711 L .39005 .56948 L .726 .658 0 r
F
.40152 .5788 m .39146 .57702 L .39005 .56948 L .695 .642 0 r
F
.436 .59447 m .42362 .58821 L .43349 .58977 L .578 .595 0 r
F
.44557 .59555 m .436 .59447 L .43349 .58977 L .546 .574 0 r
F
.76308 .73699 m .76015 .75784 L .75115 .75393 L 1 .799 0 r
F
.76308 .73699 m .77257 .74035 L .76015 .75784 L F
.76506 .42198 m .78182 .43861 L .77171 .43926 L .954 .803 0 r
F
.75518 .42325 m .76506 .42198 L .77171 .43926 L .947 .798 0 r
F
.28444 .84112 m .25854 .8294 L .26705 .82718 L .875 .824 0 r
F
.29233 .83848 m .28444 .84112 L .26705 .82718 L .866 .82 0 r
F
.55457 .38956 m .55882 .38643 L .56899 .39054 L .509 .61 0 r
F
.5449 .38602 m .55882 .38643 L .55457 .38956 L .466 .576 0 r
F
.62762 .40648 m .63597 .40444 L .64444 .41295 L .756 .728 0 r
F
.63597 .40444 m .65338 .41133 L .64444 .41295 L .778 .741 0 r
F
.35774 .84828 m .33283 .84178 L .3401 .83894 L .802 .808 0 r
F
.36426 .84514 m .35774 .84828 L .3401 .83894 L .785 .799 0 r
F
.4659 .35695 m .47446 .36306 L .47754 .36314 L .483 0 0 r
F
.56474 .64869 m .56587 .65502 L .55934 .64846 L .354 .333 0 r
F
.56474 .64869 m .57205 .65547 L .56587 .65502 L F
.65171 .71427 m .64974 .7318 L .64176 .72342 L .994 .631 0 r
F
.65171 .71427 m .66031 .72138 L .64974 .7318 L F
.54204 .63575 m .54241 .64069 L .53757 .6351 L .352 .354 0 r
F
.54204 .63575 m .54777 .64163 L .54241 .64069 L F
.4449 .33612 m .45343 .37169 L .45768 .36037 L 1 .085 0 r
F
.4449 .33612 m .43961 .35304 L .45343 .37169 L F
.32559 .84469 m .30024 .83588 L .30817 .83334 L .837 .815 0 r
F
.33283 .84178 m .32559 .84469 L .30817 .83334 L .824 .809 0 r
F
.46932 .60393 m .46063 .60369 L .45761 .60026 L .469 .527 0 r
F
.47227 .60677 m .46063 .60369 L .46932 .60393 L .458 .522 0 r
F
.34933 .56092 m .33882 .54769 L .34903 .55023 L .842 .706 0 r
F
.3595 .56283 m .34933 .56092 L .34903 .55023 L .819 .693 0 r
F
.58566 .66223 m .58667 .67053 L .57936 .6627 L .408 .373 0 r
F
.58566 .66223 m .59368 .66989 L .58667 .67053 L F
.52895 .62882 m .52797 .63299 L .52503 .62795 L .368 .388 0 r
F
.52895 .62882 m .53287 .63417 L .52797 .63299 L F
.36908 .19231 m .38599 .17117 L .39108 .17751 L 1 .909 0 r
F
.36908 .19231 m .3631 .18598 L .38599 .17117 L F
.47616 .85208 m .47407 .85525 L .45597 .85326 L .539 .669 0 r
F
.49363 .85292 m .47407 .85525 L .47616 .85208 L .506 .618 0 r
F
.51427 .37717 m .52581 .37683 L .52463 .37992 L .341 .356 0 r
F
.51427 .37717 m .51438 .37425 L .52581 .37683 L F
.48309 .60888 m .47564 .60956 L .47227 .60677 L .433 .498 0 r
F
.48608 .6111 m .47564 .60956 L .48309 .60888 L .427 .492 0 r
F
.69683 .72728 m .69456 .74598 L .68603 .74036 L 1 .732 0 r
F
.69683 .72728 m .70592 .73221 L .69456 .74598 L F
.57856 .39515 m .58464 .39231 L .59432 .39774 L .609 .67 0 r
F
.56899 .39054 m .58464 .39231 L .57856 .39515 L .576 .657 0 r
F
.42362 .58821 m .41159 .58074 L .42168 .58284 L .621 .612 0 r
F
.43349 .58977 m .42362 .58821 L .42168 .58284 L .587 .592 0 r
F
.7081 .41424 m .72562 .42664 L .71579 .42761 L .898 .782 0 r
F
.69863 .41579 m .7081 .41424 L .71579 .42761 L .886 .775 0 r
F
.5449 .38602 m .54815 .38281 L .55882 .38643 L .466 .576 0 r
F
.53488 .38283 m .54815 .38281 L .5449 .38602 L .432 .526 0 r
F
.41174 .85223 m .38825 .84953 L .39399 .84626 L .723 .787 0 r
F
.41663 .84884 m .41174 .85223 L .39399 .84626 L .694 .769 0 r
F
.43441 .85341 m .41174 .85223 L .41663 .84884 L .679 .77 0 r
F
.77495 .42065 m .79194 .43791 L .78182 .43861 L .961 .807 0 r
F
.76506 .42198 m .77495 .42065 L .78182 .43861 L .954 .803 0 r
F
.29993 .20175 m .31453 .17792 L .3214 .18386 L 1 .858 0 r
F
.29993 .20175 m .29232 .19619 L .31453 .17792 L F
.75357 .73353 m .75115 .75393 L .74214 .7499 L 1 .791 0 r
F
.75357 .73353 m .76308 .73699 L .75115 .75393 L F
.64309 .70679 m .64176 .72342 L .63376 .71452 L .941 .601 0 r
F
.64309 .70679 m .65171 .71427 L .64176 .72342 L F
.40152 .5788 m .39005 .56948 L .40025 .57202 L .695 .642 0 r
F
.41159 .58074 m .40152 .5788 L .40025 .57202 L .662 .624 0 r
F
.43841 .85001 m .43441 .85341 L .41663 .84884 L .642 .745 0 r
F
.45597 .85326 m .43441 .85341 L .43841 .85001 L .62 .737 0 r
F
.52463 .37992 m .53711 .37963 L .53488 .38283 L .394 .454 0 r
F
.52463 .37992 m .52581 .37683 L .53711 .37963 L F
.3595 .56283 m .34903 .55023 L .35925 .55293 L .819 .693 0 r
F
.36968 .56489 m .3595 .56283 L .35925 .55293 L .794 .679 0 r
F
.53488 .38283 m .53711 .37963 L .54815 .38281 L .432 .526 0 r
F
.38825 .84953 m .36426 .84514 L .3708 .84208 L .757 .795 0 r
F
.39399 .84626 m .38825 .84953 L .3708 .84208 L .734 .782 0 r
F
.61847 .39906 m .63597 .40444 L .62762 .40648 L .74 .731 0 r
F
.61079 .40145 m .61847 .39906 L .62762 .40648 L .714 .716 0 r
F
.50663 .61761 m .50447 .62103 L .50046 .61924 L .403 .452 0 r
F
.50971 .61889 m .50447 .62103 L .50663 .61761 L .4 .446 0 r
F
.50971 .61889 m .50857 .6227 L .50447 .62103 L F
.6713 .40772 m .68917 .41724 L .67973 .41859 L .847 .766 0 r
F
.66233 .40959 m .6713 .40772 L .67973 .41859 L .83 .757 0 r
F
.50361 .61624 m .50046 .61924 L .49657 .61734 L .407 .459 0 r
F
.50663 .61761 m .50046 .61924 L .50361 .61624 L .403 .452 0 r
F
.63446 .69903 m .63376 .71452 L .62575 .70527 L .875 .57 0 r
F
.63446 .69903 m .64309 .70679 L .63376 .71452 L F
.51282 .62006 m .50857 .6227 L .50971 .61889 L .396 .438 0 r
F
.51282 .62006 m .51271 .62424 L .50857 .6227 L F
.50069 .61478 m .49657 .61734 L .49286 .61534 L .411 .465 0 r
F
.50361 .61624 m .49657 .61734 L .50069 .61478 L .407 .459 0 r
F
.33509 .19588 m .35109 .17342 L .3571 .17968 L 1 .877 0 r
F
.33509 .19588 m .32825 .18985 L .35109 .17342 L F
.68772 .7221 m .68603 .74036 L .67748 .73441 L 1 .714 0 r
F
.68772 .7221 m .69683 .72728 L .68603 .74036 L F
.57765 .65505 m .57936 .6627 L .57205 .65547 L .394 .373 0 r
F
.57765 .65505 m .58566 .66223 L .57936 .6627 L F
.53272 .62949 m .53287 .63417 L .52895 .62882 L .369 .386 0 r
F
.53272 .62949 m .53757 .6351 L .53287 .63417 L F
.59432 .39774 m .60125 .39508 L .61079 .40145 L .666 .697 0 r
F
.58464 .39231 m .60125 .39508 L .59432 .39774 L .639 .692 0 r
F
.48039 .60661 m .47227 .60677 L .46932 .60393 L .44 .503 0 r
F
.48309 .60888 m .47227 .60677 L .48039 .60661 L .433 .498 0 r
F
.44557 .59555 m .43349 .58977 L .44338 .59149 L .546 .574 0 r
F
.45516 .5968 m .44557 .59555 L .44338 .59149 L .514 .552 0 r
F
.45761 .60026 m .44557 .59555 L .45516 .5968 L .505 .552 0 r
F
.62582 .69112 m .62575 .70527 L .61773 .69594 L .796 .538 0 r
F
.62582 .69112 m .63446 .69903 L .62575 .70527 L F
.51595 .6211 m .51271 .62424 L .51282 .62006 L .393 .431 0 r
F
.51595 .6211 m .51687 .62564 L .51271 .62424 L F
.36968 .56489 m .35925 .55293 L .36947 .55579 L .794 .679 0 r
F
.37986 .56711 m .36968 .56489 L .36947 .55579 L .766 .665 0 r
F
.4979 .61324 m .49286 .61534 L .48935 .61326 L .414 .47 0 r
F
.50069 .61478 m .49286 .61534 L .4979 .61324 L .411 .465 0 r
F
.78486 .41927 m .80206 .43716 L .79194 .43791 L .968 .811 0 r
F
.77495 .42065 m .78486 .41927 L .79194 .43791 L .961 .807 0 r
F
.60125 .39508 m .61847 .39906 L .61079 .40145 L .694 .716 0 r
F
.74405 .72995 m .74214 .7499 L .73311 .74574 L 1 .781 0 r
F
.74405 .72995 m .75357 .73353 L .74214 .7499 L F
.46681 .60107 m .45761 .60026 L .45516 .5968 L .478 .53 0 r
F
.46932 .60393 m .45761 .60026 L .46681 .60107 L .469 .527 0 r
F
.29233 .83848 m .26705 .82718 L .27557 .825 L .866 .82 0 r
F
.30024 .83588 m .29233 .83848 L .27557 .825 L .855 .815 0 r
F
.55741 .64225 m .55934 .64846 L .55278 .64217 L .365 .361 0 r
F
.55741 .64225 m .56474 .64869 L .55934 .64846 L F
.54622 .63607 m .54777 .64163 L .54204 .63575 L .363 .367 0 r
F
.54622 .63607 m .55278 .64217 L .54777 .64163 L F
.71759 .4126 m .73546 .42558 L .72562 .42664 L .909 .788 0 r
F
.7081 .41424 m .71759 .4126 L .72562 .42664 L .898 .782 0 r
F
.64435 .40225 m .66233 .40959 L .65338 .41133 L .799 .753 0 r
F
.63597 .40444 m .64435 .40225 L .65338 .41133 L .778 .741 0 r
F
.49164 .36874 m .50199 .36942 L .50295 .37167 L .098 .109 0 r
F
.49164 .36874 m .48962 .36689 L .50199 .36942 L F
.54454 .84589 m .54641 .84591 L .53219 .8494 L .259 .138 0 r
F
.5328 .84913 m .53219 .8494 L .52892 .85019 L F
.54454 .84589 m .53219 .8494 L .5328 .84913 L F
.53712 .84724 m .52803 .84887 L .52714 .84807 L 0 0 0 r
F
.54454 .84589 m .52892 .85019 L .52803 .84887 L .259 .138 0 r
F
.54267 .84677 m .54454 .84589 L .52967 .84858 L 0 0 0 r
F
.53039 .84853 m .52967 .84858 L .52803 .84887 L F
.54267 .84677 m .52967 .84858 L .53039 .84853 L F
.53599 .84773 m .52803 .84887 L .53712 .84724 L F
.54267 .84677 m .53599 .84773 L .53712 .84724 L F
.54078 .84811 m .54267 .84677 L .52714 .84807 L .141 0 0 r
F
.53866 .84804 m .52714 .84807 L .52624 .84761 L F
.54078 .84811 m .53761 .8481 L .53866 .84804 L F
.53761 .8481 m .52714 .84807 L .53866 .84804 L F
.56074 .84042 m .56356 .83832 L .54941 .84458 L 0 0 0 r
F
.54959 .84469 m .54941 .84458 L .54641 .84591 L F
.56074 .84042 m .54941 .84458 L .54959 .84469 L F
.56074 .84042 m .54641 .84591 L .54454 .84589 L F
.55108 .84555 m .54454 .84589 L .54267 .84677 L .208 0 0 r
F
.55791 .84456 m .55062 .84529 L .55108 .84555 L F
.55062 .84529 m .54454 .84589 L .55108 .84555 L F
.41159 .58074 m .40025 .57202 L .41046 .5747 L .662 .624 0 r
F
.42168 .58284 m .41159 .58074 L .41046 .5747 L .628 .605 0 r
F
.61718 .68319 m .61773 .69594 L .60971 .68681 L .709 .508 0 r
F
.61718 .68319 m .62582 .69112 L .61773 .69594 L F
.43349 .58977 m .42168 .58284 L .43178 .58508 L .587 .592 0 r
F
.44338 .59149 m .43349 .58977 L .43178 .58508 L .553 .571 0 r
F
.45904 .85 m .45597 .85326 L .43841 .85001 L .572 .698 0 r
F
.47616 .85208 m .45597 .85326 L .45904 .85 L .539 .669 0 r
F
.56899 .39054 m .57419 .38745 L .58464 .39231 L .576 .657 0 r
F
.55882 .38643 m .57419 .38745 L .56899 .39054 L .535 .637 0 r
F
.21619 .52635 m .20596 .5251 L .20783 .50408 L 1 .806 0 r
F
.51904 .62201 m .51687 .62564 L .51595 .6211 L .39 .425 0 r
F
.51904 .62201 m .52099 .62688 L .51687 .62564 L F
.52803 .84887 m .52892 .85019 L .51127 .85237 L .363 .175 0 r
F
.49527 .61164 m .48935 .61326 L .48608 .6111 L .417 .475 0 r
F
.4979 .61324 m .48935 .61326 L .49527 .61164 L .414 .47 0 r
F
.21619 .52635 m .20783 .50408 L .21805 .50602 L 1 .806 0 r
F
.22642 .52767 m .21619 .52635 L .21805 .50602 L 1 .802 0 r
F
.22642 .52767 m .21805 .50602 L .22827 .50801 L F
.23665 .52904 m .22642 .52767 L .22827 .50801 L .997 .796 0 r
F
.23665 .52904 m .22827 .50801 L .23848 .51008 L F
.24687 .53048 m .23665 .52904 L .23848 .51008 L .991 .791 0 r
F
.6786 .71664 m .67748 .73441 L .6689 .72809 L 1 .694 0 r
F
.6786 .71664 m .68772 .7221 L .67748 .73441 L F
.51138 .85022 m .51127 .85237 L .49363 .85292 L .426 .38 0 r
F
.52803 .84887 m .51127 .85237 L .51138 .85022 L .363 .175 0 r
F
.24687 .53048 m .23848 .51008 L .24868 .51221 L .991 .791 0 r
F
.25709 .53199 m .24687 .53048 L .24868 .51221 L .984 .784 0 r
F
.60853 .6754 m .60971 .68681 L .60169 .67809 L .621 .48 0 r
F
.60853 .6754 m .61718 .68319 L .60971 .68681 L F
.33283 .84178 m .30817 .83334 L .31611 .83085 L .824 .809 0 r
F
.3401 .83894 m .33283 .84178 L .31611 .83085 L .809 .802 0 r
F
.37986 .56711 m .36947 .55579 L .37968 .55881 L .766 .665 0 r
F
.39005 .56948 m .37986 .56711 L .37968 .55881 L .735 .649 0 r
F
.36426 .84514 m .3401 .83894 L .34738 .83617 L .785 .799 0 r
F
.3708 .84208 m .36426 .84514 L .34738 .83617 L .766 .789 0 r
F
.25709 .53199 m .24868 .51221 L .25888 .51443 L .984 .784 0 r
F
.26731 .53358 m .25709 .53199 L .25888 .51443 L .976 .778 0 r
F
.79477 .41784 m .8122 .43635 L .80206 .43716 L .974 .815 0 r
F
.78486 .41927 m .79477 .41784 L .80206 .43716 L .968 .811 0 r
F
.73452 .72623 m .73311 .74574 L .72406 .74142 L 1 .771 0 r
F
.73452 .72623 m .74405 .72995 L .73311 .74574 L F
.26731 .53358 m .25888 .51443 L .26907 .51673 L .976 .778 0 r
F
.27753 .53527 m .26731 .53358 L .26907 .51673 L .967 .77 0 r
F
.3631 .18598 m .38089 .1648 L .38599 .17117 L 1 .909 0 r
F
.3631 .18598 m .3571 .17968 L .38089 .1648 L F
.47803 .60432 m .46932 .60393 L .46681 .60107 L .448 .507 0 r
F
.48039 .60661 m .46932 .60393 L .47803 .60432 L .44 .503 0 r
F
.52208 .62279 m .52099 .62688 L .51904 .62201 L .387 .419 0 r
F
.52208 .62279 m .52503 .62795 L .52099 .62688 L F
.5363 .62992 m .53757 .6351 L .53272 .62949 L .373 .389 0 r
F
.5363 .62992 m .54204 .63575 L .53757 .6351 L F
.56962 .64828 m .57205 .65547 L .56474 .64869 L .389 .382 0 r
F
.56962 .64828 m .57765 .65505 L .57205 .65547 L F
.49281 .60998 m .48608 .6111 L .48309 .60888 L .421 .479 0 r
F
.49527 .61164 m .48608 .6111 L .49281 .60998 L .417 .475 0 r
F
.27753 .53527 m .26907 .51673 L .27926 .51913 L .967 .77 0 r
F
.28775 .53704 m .27753 .53527 L .27926 .51913 L .956 .762 0 r
F
.68028 .40575 m .69863 .41579 L .68917 .41724 L .862 .775 0 r
F
.6713 .40772 m .68028 .40575 L .68917 .41724 L .847 .766 0 r
F
.49473 .85027 m .49363 .85292 L .47616 .85208 L .463 .522 0 r
F
.51138 .85022 m .49363 .85292 L .49473 .85027 L .426 .38 0 r
F
.59989 .66787 m .60169 .67809 L .59368 .66989 L .544 .457 0 r
F
.59989 .66787 m .60853 .6754 L .60169 .67809 L F
.28775 .53704 m .27926 .51913 L .28944 .52164 L .956 .762 0 r
F
.29796 .53893 m .28775 .53704 L .28944 .52164 L .945 .754 0 r
F
.66946 .71089 m .6689 .72809 L .66031 .72138 L .986 .672 0 r
F
.66946 .71089 m .6786 .71664 L .6689 .72809 L F
.25854 .8294 m .25004 .83167 L .23384 .81551 L .891 .823 0 r
F
.72709 .41088 m .74531 .42445 L .73546 .42558 L .92 .794 0 r
F
.71759 .4126 m .72709 .41088 L .73546 .42558 L .909 .788 0 r
F
.42168 .58284 m .41046 .5747 L .42067 .57753 L .628 .605 0 r
F
.43178 .58508 m .42168 .58284 L .42067 .57753 L .592 .586 0 r
F
.29796 .53893 m .28944 .52164 L .29961 .52426 L .945 .754 0 r
F
.30818 .54092 m .29796 .53893 L .29961 .52426 L .932 .744 0 r
F
.39005 .56948 m .37968 .55881 L .38991 .56199 L .735 .649 0 r
F
.40025 .57202 m .39005 .56948 L .38991 .56199 L .702 .632 0 r
F
.55882 .38643 m .56308 .38318 L .57419 .38745 L .535 .637 0 r
F
.54815 .38281 m .56308 .38318 L .55882 .38643 L .488 .603 0 r
F
.52503 .6234 m .52503 .62795 L .52208 .62279 L .386 .416 0 r
F
.52503 .6234 m .52895 .62882 L .52503 .62795 L F
.49056 .60829 m .48309 .60888 L .48039 .60661 L .424 .483 0 r
F
.49281 .60998 m .48309 .60888 L .49056 .60829 L .421 .479 0 r
F
.45516 .5968 m .44338 .59149 L .45329 .59337 L .514 .552 0 r
F
.46477 .59821 m .45516 .5968 L .45329 .59337 L .485 .531 0 r
F
.46681 .60107 m .45516 .5968 L .46477 .59821 L .478 .53 0 r
F
.32825 .18985 m .34506 .16718 L .35109 .17342 L 1 .879 0 r
F
.32825 .18985 m .3214 .18386 L .34506 .16718 L F
.61847 .39906 m .62617 .39652 L .63597 .40444 L .74 .731 0 r
F
.62617 .39652 m .64435 .40225 L .63597 .40444 L .763 .746 0 r
F
.50295 .37167 m .5145 .37156 L .51438 .37425 L .242 .178 0 r
F
.50295 .37167 m .50199 .36942 L .5145 .37156 L F
.30818 .54092 m .29961 .52426 L .30979 .52701 L .932 .744 0 r
F
.31839 .54304 m .30818 .54092 L .30979 .52701 L .917 .734 0 r
F
.79477 .41784 m .80471 .41635 L .8122 .43635 L .974 .815 0 r
F
.41663 .84884 m .39399 .84626 L .39975 .84309 L .694 .769 0 r
F
.42154 .84558 m .41663 .84884 L .39975 .84309 L .662 .749 0 r
F
.43841 .85001 m .41663 .84884 L .42154 .84558 L .642 .745 0 r
F
.72498 .72236 m .72406 .74142 L .715 .73691 L 1 .76 0 r
F
.72498 .72236 m .73452 .72623 L .72406 .74142 L F
.58464 .39231 m .59075 .38931 L .60125 .39508 L .639 .692 0 r
F
.57419 .38745 m .59075 .38931 L .58464 .39231 L .607 .683 0 r
F
.44338 .59149 m .43178 .58508 L .44189 .58747 L .553 .571 0 r
F
.45329 .59337 m .44338 .59149 L .44189 .58747 L .52 .55 0 r
F
.59124 .66066 m .59368 .66989 L .58566 .66223 L .484 .44 0 r
F
.59124 .66066 m .59989 .66787 L .59368 .66989 L F
.55007 .63605 m .55278 .64217 L .54622 .63607 L .377 .387 0 r
F
.55007 .63605 m .55741 .64225 L .55278 .64217 L F
.47754 .36314 m .48759 .36594 L .48734 .36618 L .235 0 0 r
F
.47754 .36314 m .47446 .36306 L .48759 .36594 L F
.48759 .36594 m .48554 .36568 L .48783 .36571 L .031 .108 0 r
F
.48759 .36594 m .48783 .36571 L .50006 .36587 L F
.48734 .36618 m .48759 .36594 L .48962 .36689 L .235 0 0 r
F
.66031 .70484 m .66031 .72138 L .65171 .71427 L .952 .649 0 r
F
.66031 .70484 m .66946 .71089 L .66031 .72138 L F
.31839 .54304 m .30979 .52701 L .31995 .5299 L .917 .734 0 r
F
.32861 .54529 m .31839 .54304 L .31995 .5299 L .9 .723 0 r
F
.30024 .83588 m .27557 .825 L .28412 .82288 L .855 .815 0 r
F
.30817 .83334 m .30024 .83588 L .28412 .82288 L .844 .809 0 r
F
.39399 .84626 m .3708 .84208 L .37736 .83911 L .734 .782 0 r
F
.39975 .84309 m .39399 .84626 L .37736 .83911 L .708 .768 0 r
F
.65274 .39994 m .6713 .40772 L .66233 .40959 L .818 .764 0 r
F
.64435 .40225 m .65274 .39994 L .66233 .40959 L .799 .753 0 r
F
.47826 .84914 m .47616 .85208 L .45904 .85 L .487 .606 0 r
F
.49473 .85027 m .47616 .85208 L .47826 .84914 L .463 .522 0 r
F
.47603 .60202 m .46681 .60107 L .46477 .59821 L .454 .509 0 r
F
.47803 .60432 m .46681 .60107 L .47603 .60202 L .448 .507 0 r
F
.44242 .84677 m .43841 .85001 L .42154 .84558 L .602 .716 0 r
F
.45904 .85 m .43841 .85001 L .44242 .84677 L .572 .698 0 r
F
.53964 .63011 m .54204 .63575 L .5363 .62992 L .379 .397 0 r
F
.53964 .63011 m .54622 .63607 L .54204 .63575 L F
.56159 .64185 m .56474 .64869 L .55741 .64225 L .389 .395 0 r
F
.56159 .64185 m .56962 .64828 L .56474 .64869 L F
.32861 .54529 m .31995 .5299 L .33011 .53294 L .9 .723 0 r
F
.33882 .54769 m .32861 .54529 L .33011 .53294 L .88 .711 0 r
F
.80226 .72775 m .80097 .74988 L .79152 .74678 L 1 .813 0 r
F
.80226 .72775 m .81213 .73028 L .80097 .74988 L F
.40025 .57202 m .38991 .56199 L .40014 .56531 L .702 .632 0 r
F
.41046 .5747 m .40025 .57202 L .40014 .56531 L .667 .615 0 r
F
.54815 .38281 m .55142 .37951 L .56308 .38318 L .488 .603 0 r
F
.53711 .37963 m .55142 .37951 L .54815 .38281 L .446 .55 0 r
F
.46182 .35621 m .47135 .36498 L .47446 .36306 L .597 .01 0 r
F
.46182 .35621 m .45768 .36037 L .47135 .36498 L F
.48854 .60656 m .48039 .60661 L .47803 .60432 L .427 .486 0 r
F
.49056 .60829 m .48039 .60661 L .48854 .60656 L .424 .483 0 r
F
.52785 .62386 m .52895 .62882 L .52503 .6234 L .386 .415 0 r
F
.52785 .62386 m .53272 .62949 L .52895 .62882 L F
.60819 .39226 m .62617 .39652 L .61847 .39906 L .721 .734 0 r
F
.60125 .39508 m .60819 .39226 L .61847 .39906 L .694 .716 0 r
F
.65115 .69851 m .65171 .71427 L .64309 .70679 L .911 .624 0 r
F
.65115 .69851 m .66031 .70484 L .65171 .71427 L F
.59075 .38931 m .60819 .39226 L .60125 .39508 L .669 .714 0 r
F
.71542 .71833 m .715 .73691 L .70592 .73221 L 1 .747 0 r
F
.71542 .71833 m .72498 .72236 L .715 .73691 L F
.51438 .37425 m .527 .3738 L .52581 .37683 L .34 .34 0 r
F
.51438 .37425 m .5145 .37156 L .527 .3738 L F
.5826 .65378 m .58566 .66223 L .57765 .65505 L .444 .43 0 r
F
.5826 .65378 m .59124 .66066 L .58566 .66223 L F
.43178 .58508 m .42067 .57753 L .4309 .58049 L .592 .586 0 r
F
.44189 .58747 m .43178 .58508 L .4309 .58049 L .557 .566 0 r
F
.73662 .40909 m .75518 .42325 L .74531 .42445 L .929 .799 0 r
F
.72709 .41088 m .73662 .40909 L .74531 .42445 L .92 .794 0 r
F
.33882 .54769 m .33011 .53294 L .34027 .53614 L .88 .711 0 r
F
.34903 .55023 m .33882 .54769 L .34027 .53614 L .859 .698 0 r
F
.68929 .40367 m .7081 .41424 L .69863 .41579 L .876 .782 0 r
F
.68028 .40575 m .68929 .40367 L .69863 .41579 L .862 .775 0 r
F
.53711 .37963 m .53935 .37641 L .55142 .37951 L .446 .55 0 r
F
.52581 .37683 m .53935 .37641 L .53711 .37963 L .404 .466 0 r
F
.3401 .83894 m .31611 .83085 L .32408 .82844 L .809 .802 0 r
F
.34738 .83617 m .3401 .83894 L .32408 .82844 L .794 .793 0 r
F
.50678 .61317 m .50361 .61624 L .50069 .61478 L .41 .46 0 r
F
.50879 .6141 m .50361 .61624 L .50678 .61317 L .408 .456 0 r
F
.50879 .6141 m .50663 .61761 L .50361 .61624 L F
.51085 .61496 m .50663 .61761 L .50879 .6141 L .406 .453 0 r
F
.51085 .61496 m .50971 .61889 L .50663 .61761 L F
.52581 .37683 m .527 .3738 L .53935 .37641 L .404 .466 0 r
F
.64197 .69194 m .64309 .70679 L .63446 .69903 L .86 .6 0 r
F
.64197 .69194 m .65115 .69851 L .64309 .70679 L F
.34903 .55023 m .34027 .53614 L .35043 .5395 L .859 .698 0 r
F
.35925 .55293 m .34903 .55023 L .35043 .5395 L .834 .684 0 r
F
.25854 .8294 m .23384 .81551 L .2429 .81376 L .891 .823 0 r
F
.26705 .82718 m .25854 .8294 L .2429 .81376 L .882 .819 0 r
F
.50483 .61217 m .50069 .61478 L .4979 .61324 L .412 .463 0 r
F
.50678 .61317 m .50069 .61478 L .50483 .61217 L .41 .46 0 r
F
.51293 .61574 m .50971 .61889 L .51085 .61496 L .404 .449 0 r
F
.51293 .61574 m .51282 .62006 L .50971 .61889 L F
.79238 .72515 m .79152 .74678 L .78205 .74361 L 1 .807 0 r
F
.79238 .72515 m .80226 .72775 L .79152 .74678 L F
.3571 .17968 m .37577 .15842 L .38089 .1648 L 1 .908 0 r
F
.3571 .17968 m .35109 .17342 L .37577 .15842 L F
.3708 .84208 m .34738 .83617 L .35468 .83348 L .766 .789 0 r
F
.37736 .83911 m .3708 .84208 L .35468 .83348 L .745 .778 0 r
F
.41046 .5747 m .40014 .56531 L .41037 .56878 L .667 .615 0 r
F
.42067 .57753 m .41046 .5747 L .41037 .56878 L .631 .596 0 r
F
.50297 .61113 m .4979 .61324 L .49527 .61164 L .413 .465 0 r
F
.50483 .61217 m .4979 .61324 L .50297 .61113 L .412 .463 0 r
F
.51502 .61643 m .51282 .62006 L .51293 .61574 L .402 .445 0 r
F
.51502 .61643 m .51595 .6211 L .51282 .62006 L F
.48677 .60483 m .47803 .60432 L .47603 .60202 L .431 .489 0 r
F
.48854 .60656 m .47803 .60432 L .48677 .60483 L .427 .486 0 r
F
.45329 .59337 m .44189 .58747 L .45202 .58999 L .52 .55 0 r
F
.46321 .59538 m .45329 .59337 L .45202 .58999 L .489 .53 0 r
F
.46477 .59821 m .45329 .59337 L .46321 .59538 L .485 .531 0 r
F
.70586 .71411 m .70592 .73221 L .69683 .72728 L 1 .733 0 r
F
.70586 .71411 m .71542 .71833 L .70592 .73221 L F
.63279 .68519 m .63446 .69903 L .62582 .69112 L .801 .575 0 r
F
.63279 .68519 m .64197 .69194 L .63446 .69903 L F
.53054 .62414 m .53272 .62949 L .52785 .62386 L .388 .416 0 r
F
.53054 .62414 m .5363 .62992 L .53272 .62949 L F
.35925 .55293 m .35043 .5395 L .36058 .54303 L .834 .684 0 r
F
.36947 .55579 m .35925 .55293 L .36058 .54303 L .807 .669 0 r
F
.57419 .38745 m .57941 .3842 L .59075 .38931 L .607 .683 0 r
F
.56308 .38318 m .57941 .3842 L .57419 .38745 L .567 .665 0 r
F
.4744 .59975 m .46477 .59821 L .46321 .59538 L .459 .51 0 r
F
.47603 .60202 m .46477 .59821 L .4744 .59975 L .454 .509 0 r
F
.57394 .64722 m .57765 .65505 L .56962 .64828 L .421 .427 0 r
F
.57394 .64722 m .5826 .65378 L .57765 .65505 L F
.46211 .84692 m .45904 .85 L .44242 .84677 L .524 .654 0 r
F
.47826 .84914 m .45904 .85 L .46211 .84692 L .487 .606 0 r
F
.5012 .61004 m .49527 .61164 L .49281 .60998 L .415 .468 0 r
F
.50297 .61113 m .49527 .61164 L .5012 .61004 L .413 .465 0 r
F
.51709 .61703 m .51595 .6211 L .51502 .61643 L .401 .441 0 r
F
.51709 .61703 m .51904 .62201 L .51595 .6211 L F
.3214 .18386 m .339 .16095 L .34506 .16718 L 1 .881 0 r
F
.3214 .18386 m .31453 .17792 L .339 .16095 L F
.54272 .63004 m .54622 .63607 L .53964 .63011 L .387 .409 0 r
F
.54272 .63004 m .55007 .63605 L .54622 .63607 L F
.55355 .63567 m .55741 .64225 L .55007 .63605 L .393 .409 0 r
F
.55355 .63567 m .56159 .64185 L .55741 .64225 L F
.62361 .67835 m .62582 .69112 L .61718 .68319 L .736 .551 0 r
F
.62361 .67835 m .63279 .68519 L .62582 .69112 L F
.78249 .72248 m .78205 .74361 L .77257 .74035 L 1 .801 0 r
F
.78249 .72248 m .79238 .72515 L .78205 .74361 L F
.74615 .40723 m .76506 .42198 L .75518 .42325 L .938 .804 0 r
F
.73662 .40909 m .74615 .40723 L .75518 .42325 L .929 .799 0 r
F
.44189 .58747 m .4309 .58049 L .44114 .58356 L .557 .566 0 r
F
.45202 .58999 m .44189 .58747 L .44114 .58356 L .523 .546 0 r
F
.6339 .39383 m .65274 .39994 L .64435 .40225 L .786 .759 0 r
F
.62617 .39652 m .6339 .39383 L .64435 .40225 L .763 .746 0 r
F
.36947 .55579 m .36058 .54303 L .37073 .54674 L .807 .669 0 r
F
.37968 .55881 m .36947 .55579 L .37073 .54674 L .776 .653 0 r
F
.30817 .83334 m .28412 .82288 L .29268 .82081 L .844 .809 0 r
F
.31611 .83085 m .30817 .83334 L .29268 .82081 L .832 .803 0 r
F
.66116 .3975 m .68028 .40575 L .6713 .40772 L .836 .773 0 r
F
.65274 .39994 m .66116 .3975 L .6713 .40772 L .818 .764 0 r
F
.49957 .60891 m .49281 .60998 L .49056 .60829 L .417 .47 0 r
F
.5012 .61004 m .49281 .60998 L .49957 .60891 L .415 .468 0 r
F
.51912 .61753 m .51904 .62201 L .51709 .61703 L .399 .438 0 r
F
.51912 .61753 m .52208 .62279 L .51904 .62201 L F
.69627 .70969 m .69683 .72728 L .68772 .7221 L .993 .717 0 r
F
.69627 .70969 m .70586 .71411 L .69683 .72728 L F
.61442 .6715 m .61718 .68319 L .60853 .6754 L .668 .527 0 r
F
.61442 .6715 m .62361 .67835 L .61718 .68319 L F
.42067 .57753 m .41037 .56878 L .42061 .57237 L .631 .596 0 r
F
.4309 .58049 m .42067 .57753 L .42061 .57237 L .593 .578 0 r
F
.48962 .36689 m .50103 .36755 L .50199 .36942 L .035 .106 0 r
F
.48962 .36689 m .48759 .36594 L .50103 .36755 L F
.52714 .84807 m .52803 .84887 L .51138 .85022 L .23 .134 0 r
F
.69832 .4015 m .71759 .4126 L .7081 .41424 L .889 .789 0 r
F
.68929 .40367 m .69832 .4015 L .7081 .41424 L .876 .782 0 r
F
.51148 .84844 m .51138 .85022 L .49473 .85027 L .35 .239 0 r
F
.52714 .84807 m .51138 .85022 L .51148 .84844 L .23 .134 0 r
F
.48527 .60311 m .47603 .60202 L .4744 .59975 L .435 .491 0 r
F
.48677 .60483 m .47603 .60202 L .48527 .60311 L .431 .489 0 r
F
.57274 .84146 m .57642 .82892 L .56074 .84042 L .338 0 0 r
F
.53304 .62424 m .5363 .62992 L .53054 .62414 L .391 .42 0 r
F
.53304 .62424 m .53964 .63011 L .5363 .62992 L F
.37968 .55881 m .37073 .54674 L .38088 .55061 L .776 .653 0 r
F
.38991 .56199 m .37968 .55881 L .38088 .55061 L .743 .637 0 r
F
.60523 .66474 m .60853 .6754 L .59989 .66787 L .602 .506 0 r
F
.60523 .66474 m .61442 .6715 L .60853 .6754 L F
.49806 .60777 m .49056 .60829 L .48854 .60656 L .418 .472 0 r
F
.49957 .60891 m .49056 .60829 L .49806 .60777 L .417 .47 0 r
F
.55791 .84456 m .56074 .84042 L .54454 .84589 L .208 0 0 r
F
.56529 .64095 m .56962 .64828 L .56159 .64185 L .411 .428 0 r
F
.56529 .64095 m .57394 .64722 L .56962 .64828 L F
.52108 .61793 m .52208 .62279 L .51912 .61753 L .398 .436 0 r
F
.52108 .61793 m .52503 .6234 L .52208 .62279 L F
.77259 .71972 m .77257 .74035 L .76308 .73699 L 1 .794 0 r
F
.77259 .71972 m .78249 .72248 L .77257 .74035 L F
.42154 .84558 m .39975 .84309 L .40553 .84005 L .662 .749 0 r
F
.42646 .84245 m .42154 .84558 L .40553 .84005 L .628 .726 0 r
F
.44242 .84677 m .42154 .84558 L .42646 .84245 L .602 .716 0 r
F
.26705 .82718 m .2429 .81376 L .25198 .81205 L .882 .819 0 r
F
.27557 .825 m .26705 .82718 L .25198 .81205 L .873 .814 0 r
F
.59075 .38931 m .59688 .38615 L .60819 .39226 L .669 .714 0 r
F
.57941 .3842 m .59688 .38615 L .59075 .38931 L .639 .707 0 r
F
.68668 .70506 m .68772 .7221 L .6786 .71664 L .973 .701 0 r
F
.68668 .70506 m .69627 .70969 L .68772 .7221 L F
.49584 .84789 m .49473 .85027 L .47826 .84914 L .415 .422 0 r
F
.51148 .84844 m .49473 .85027 L .49584 .84789 L .35 .239 0 r
F
.39975 .84309 m .37736 .83911 L .38394 .83625 L .708 .768 0 r
F
.40553 .84005 m .39975 .84309 L .38394 .83625 L .681 .751 0 r
F
.57274 .84146 m .56074 .84042 L .55791 .84456 L .338 0 0 r
F
.56308 .38318 m .56735 .37979 L .57941 .3842 L .567 .665 0 r
F
.55142 .37951 m .56735 .37979 L .56308 .38318 L .518 .635 0 r
F
.46321 .59538 m .45202 .58999 L .46217 .59262 L .489 .53 0 r
F
.47316 .59752 m .46321 .59538 L .46217 .59262 L .463 .51 0 r
F
.4744 .59975 m .46321 .59538 L .47316 .59752 L .459 .51 0 r
F
.59604 .65814 m .59989 .66787 L .59124 .66066 L .544 .488 0 r
F
.59604 .65814 m .60523 .66474 L .59989 .66787 L F
.60819 .39226 m .61516 .38929 L .62617 .39652 L .721 .734 0 r
F
.61516 .38929 m .6339 .39383 L .62617 .39652 L .747 .75 0 r
F
.38991 .56199 m .38088 .55061 L .39103 .55464 L .743 .637 0 r
F
.40014 .56531 m .38991 .56199 L .39103 .55464 L .707 .62 0 r
F
.4309 .58049 m .42061 .57237 L .43086 .57605 L .593 .578 0 r
F
.44114 .58356 m .4309 .58049 L .43086 .57605 L .556 .559 0 r
F
.75571 .4053 m .77495 .42065 L .76506 .42198 L .946 .809 0 r
F
.74615 .40723 m .75571 .4053 L .76506 .42198 L .938 .804 0 r
F
.49672 .60661 m .48854 .60656 L .48677 .60483 L .42 .473 0 r
F
.49806 .60777 m .48854 .60656 L .49672 .60661 L .418 .472 0 r
F
.34738 .83617 m .32408 .82844 L .33206 .8261 L .794 .793 0 r
F
.35468 .83348 m .34738 .83617 L .33206 .8261 L .777 .784 0 r
F
.45202 .58999 m .44114 .58356 L .45138 .58673 L .523 .546 0 r
F
.46217 .59262 m .45202 .58999 L .45138 .58673 L .491 .526 0 r
F
.52297 .61821 m .52503 .6234 L .52108 .61793 L .398 .435 0 r
F
.52297 .61821 m .52785 .62386 L .52503 .6234 L F
.5455 .6297 m .55007 .63605 L .54272 .63004 L .397 .424 0 r
F
.5455 .6297 m .55355 .63567 L .55007 .63605 L F
.59688 .38615 m .61516 .38929 L .60819 .39226 L .699 .734 0 r
F
.76268 .71687 m .76308 .73699 L .75357 .73353 L 1 .787 0 r
F
.76268 .71687 m .77259 .71972 L .76308 .73699 L F
.67708 .70019 m .6786 .71664 L .66946 .71089 L .949 .683 0 r
F
.67708 .70019 m .68668 .70506 L .6786 .71664 L F
.35109 .17342 m .37063 .15201 L .37577 .15842 L 1 .907 0 r
F
.35109 .17342 m .34506 .16718 L .37063 .15201 L F
.44644 .84368 m .44242 .84677 L .42646 .84245 L .56 .683 0 r
F
.46211 .84692 m .44242 .84677 L .44644 .84368 L .524 .654 0 r
F
.48405 .60141 m .4744 .59975 L .47316 .59752 L .439 .492 0 r
F
.48527 .60311 m .4744 .59975 L .48405 .60141 L .435 .491 0 r
F
.58685 .65174 m .59124 .66066 L .5826 .65378 L .496 .474 0 r
F
.58685 .65174 m .59604 .65814 L .59124 .66066 L F
.53535 .62415 m .53964 .63011 L .53304 .62424 L .396 .427 0 r
F
.53535 .62415 m .54272 .63004 L .53964 .63011 L F
.40014 .56531 m .39103 .55464 L .40118 .5588 L .707 .62 0 r
F
.41037 .56878 m .40014 .56531 L .40118 .5588 L .669 .603 0 r
F
.48036 .84642 m .47826 .84914 L .46211 .84692 L .454 .537 0 r
F
.49584 .84789 m .47826 .84914 L .48036 .84642 L .415 .422 0 r
F
.55662 .63493 m .56159 .64185 L .55355 .63567 L .408 .433 0 r
F
.55662 .63493 m .56529 .64095 L .56159 .64185 L F
.37736 .83911 m .35468 .83348 L .362 .83088 L .745 .778 0 r
F
.38394 .83625 m .37736 .83911 L .362 .83088 L .723 .765 0 r
F
.50199 .36942 m .51461 .36899 L .5145 .37156 L .236 .143 0 r
F
.50199 .36942 m .50103 .36755 L .51461 .36899 L F
.49554 .60545 m .48677 .60483 L .48527 .60311 L .422 .475 0 r
F
.49672 .60661 m .48677 .60483 L .49554 .60545 L .42 .473 0 r
F
.70736 .39923 m .72709 .41088 L .71759 .4126 L .901 .795 0 r
F
.69832 .4015 m .70736 .39923 L .71759 .4126 L .889 .789 0 r
F
.52476 .61838 m .52785 .62386 L .52297 .61821 L .399 .436 0 r
F
.52476 .61838 m .53054 .62414 L .52785 .62386 L F
.6696 .39495 m .68929 .40367 L .68028 .40575 L .852 .782 0 r
F
.66116 .3975 m .6696 .39495 L .68028 .40575 L .836 .773 0 r
F
.66746 .69509 m .66946 .71089 L .66031 .70484 L .92 .664 0 r
F
.66746 .69509 m .67708 .70019 L .66946 .71089 L F
.55142 .37951 m .5547 .37609 L .56735 .37979 L .518 .635 0 r
F
.53935 .37641 m .5547 .37609 L .55142 .37951 L .464 .584 0 r
F
.31611 .83085 m .29268 .82081 L .30126 .81881 L .832 .803 0 r
F
.32408 .82844 m .31611 .83085 L .30126 .81881 L .819 .796 0 r
F
.75276 .71391 m .75357 .73353 L .74405 .72995 L 1 .778 0 r
F
.75276 .71391 m .76268 .71687 L .75357 .73353 L F
.44114 .58356 m .43086 .57605 L .44111 .57981 L .556 .559 0 r
F
.45138 .58673 m .44114 .58356 L .44111 .57981 L .521 .54 0 r
F
.64165 .39101 m .66116 .3975 L .65274 .39994 L .806 .77 0 r
F
.6339 .39383 m .64165 .39101 L .65274 .39994 L .786 .759 0 r
F
.57765 .64556 m .5826 .65378 L .57394 .64722 L .461 .464 0 r
F
.57765 .64556 m .58685 .65174 L .5826 .65378 L F
.41037 .56878 m .40118 .5588 L .41134 .56308 L .669 .603 0 r
F
.42061 .57237 m .41037 .56878 L .41134 .56308 L .629 .584 0 r
F
.76528 .40331 m .78486 .41927 L .77495 .42065 L .953 .813 0 r
F
.75571 .4053 m .76528 .40331 L .77495 .42065 L .946 .809 0 r
F
.47446 .36306 m .47135 .36498 L .48554 .36568 L .296 0 0 r
F
.48554 .36568 m .48348 .36559 L .48406 .36554 L .116 .12 0 r
F
.47446 .36306 m .48554 .36568 L .48702 .36582 L .296 0 0 r
F
.48554 .36568 m .48406 .36554 L .49908 .3641 L .116 .12 0 r
F
.48702 .36582 m .48554 .36568 L .48759 .36594 L .296 0 0 r
F
.65784 .68976 m .66031 .70484 L .65115 .69851 L .886 .644 0 r
F
.65784 .68976 m .66746 .69509 L .66031 .70484 L F
.50996 .61003 m .50678 .61317 L .50483 .61217 L .412 .46 0 r
F
.51097 .6105 m .50678 .61317 L .50996 .61003 L .411 .459 0 r
F
.51097 .6105 m .50879 .6141 L .50678 .61317 L F
.512 .61093 m .50879 .6141 L .51097 .6105 L .41 .457 0 r
F
.512 .61093 m .51085 .61496 L .50879 .6141 L F
.27557 .825 m .25198 .81205 L .26106 .81039 L .873 .814 0 r
F
.28412 .82288 m .27557 .825 L .26106 .81039 L .864 .809 0 r
F
.46217 .59262 m .45138 .58673 L .46165 .58998 L .491 .526 0 r
F
.47233 .59535 m .46217 .59262 L .46165 .58998 L .464 .508 0 r
F
.47316 .59752 m .46217 .59262 L .47233 .59535 L .463 .51 0 r
F
.50898 .60953 m .50483 .61217 L .50297 .61113 L .412 .461 0 r
F
.50996 .61003 m .50483 .61217 L .50898 .60953 L .412 .46 0 r
F
.51305 .61133 m .51085 .61496 L .512 .61093 L .41 .456 0 r
F
.51305 .61133 m .51293 .61574 L .51085 .61496 L F
.5145 .37156 m .52819 .37077 L .527 .3738 L .354 .345 0 r
F
.5145 .37156 m .51461 .36899 L .52819 .37077 L F
.49454 .6043 m .48527 .60311 L .48405 .60141 L .423 .476 0 r
F
.49554 .60545 m .48527 .60311 L .49454 .6043 L .422 .475 0 r
F
.53935 .37641 m .5416 .3731 L .5547 .37609 L .464 .584 0 r
F
.527 .3738 m .5416 .3731 L .53935 .37641 L .423 .495 0 r
F
.48313 .59975 m .47316 .59752 L .47233 .59535 L .441 .492 0 r
F
.48405 .60141 m .47316 .59752 L .48313 .59975 L .439 .492 0 r
F
.50805 .609 m .50297 .61113 L .5012 .61004 L .413 .462 0 r
F
.50898 .60953 m .50297 .61113 L .50805 .609 L .412 .461 0 r
F
.51409 .61167 m .51293 .61574 L .51305 .61133 L .409 .454 0 r
F
.51409 .61167 m .51502 .61643 L .51293 .61574 L F
.74283 .71084 m .74405 .72995 L .73452 .72623 L 1 .769 0 r
F
.74283 .71084 m .75276 .71391 L .74405 .72995 L F
.52643 .61842 m .53054 .62414 L .52476 .61838 L .401 .438 0 r
F
.52643 .61842 m .53304 .62424 L .53054 .62414 L F
.57941 .3842 m .58465 .38079 L .59688 .38615 L .639 .707 0 r
F
.56735 .37979 m .58465 .38079 L .57941 .3842 L .602 .694 0 r
F
.64821 .68421 m .65115 .69851 L .64197 .69194 L .845 .623 0 r
F
.64821 .68421 m .65784 .68976 L .65115 .69851 L F
.527 .3738 m .52819 .37077 L .5416 .3731 L .423 .495 0 r
F
.53743 .62388 m .54272 .63004 L .53535 .62415 L .402 .436 0 r
F
.53743 .62388 m .5455 .6297 L .54272 .63004 L F
.50717 .60845 m .5012 .61004 L .49957 .60891 L .413 .463 0 r
F
.50805 .609 m .5012 .61004 L .50717 .60845 L .413 .462 0 r
F
.54795 .6291 m .55355 .63567 L .5455 .6297 L .408 .439 0 r
F
.54795 .6291 m .55662 .63493 L .55355 .63567 L F
.56846 .63959 m .57394 .64722 L .56529 .64095 L .438 .458 0 r
F
.56846 .63959 m .57765 .64556 L .57394 .64722 L F
.51513 .61197 m .51502 .61643 L .51409 .61167 L .408 .452 0 r
F
.51513 .61197 m .51709 .61703 L .51502 .61643 L F
.4652 .84404 m .46211 .84692 L .44644 .84368 L .48 .605 0 r
F
.48036 .84642 m .46211 .84692 L .4652 .84404 L .454 .537 0 r
F
.42061 .57237 m .41134 .56308 L .42149 .56744 L .629 .584 0 r
F
.43086 .57605 m .42061 .57237 L .42149 .56744 L .589 .566 0 r
F
.63857 .67849 m .64197 .69194 L .63279 .68519 L .799 .602 0 r
F
.63857 .67849 m .64821 .68421 L .64197 .69194 L F
.45138 .58673 m .44111 .57981 L .45137 .58363 L .521 .54 0 r
F
.46165 .58998 m .45138 .58673 L .45137 .58363 L .49 .521 0 r
F
.50635 .60788 m .49957 .60891 L .49806 .60777 L .414 .463 0 r
F
.50717 .60845 m .49957 .60891 L .50635 .60788 L .413 .463 0 r
F
.51614 .61222 m .51709 .61703 L .51513 .61197 L .407 .45 0 r
F
.51614 .61222 m .51912 .61753 L .51709 .61703 L F
.30979 .52701 m .3035 .50949 L .31352 .51301 L .954 .739 0 r
F
.30979 .52701 m .29961 .52426 L .3035 .50949 L F
.31995 .5299 m .30979 .52701 L .31352 .51301 L .939 .728 0 r
F
.29961 .52426 m .29347 .50611 L .3035 .50949 L .968 .75 0 r
F
.29961 .52426 m .28944 .52164 L .29347 .50611 L F
.31995 .5299 m .31352 .51301 L .32353 .5167 L .939 .728 0 r
F
.33011 .53294 m .31995 .5299 L .32353 .5167 L .921 .715 0 r
F
.54022 1.09906 m .5411 1.10379 L .50981 1.10748 L 1 .961 0 r
F
.57027 1.09314 m .5411 1.10379 L .54022 1.09906 L 1 .982 0 r
F
.57027 1.09314 m .57212 1.09793 L .5411 1.10379 L F
.28944 .52164 m .28344 .50286 L .29347 .50611 L .979 .759 0 r
F
.28944 .52164 m .27926 .51913 L .28344 .50286 L F
.73289 .70764 m .73452 .72623 L .72498 .72236 L .998 .759 0 r
F
.73289 .70764 m .74283 .71084 L .73452 .72623 L F
.33011 .53294 m .32353 .5167 L .33353 .52056 L .921 .715 0 r
F
.34027 .53614 m .33011 .53294 L .33353 .52056 L .901 .702 0 r
F
.62893 .67263 m .63279 .68519 L .62361 .67835 L .747 .581 0 r
F
.62893 .67263 m .63857 .67849 L .63279 .68519 L F
.27926 .51913 m .27339 .49973 L .28344 .50286 L .989 .768 0 r
F
.27926 .51913 m .26907 .51673 L .27339 .49973 L F
.49373 .60317 m .48405 .60141 L .48313 .59975 L .424 .477 0 r
F
.49454 .6043 m .48405 .60141 L .49373 .60317 L .423 .476 0 r
F
.34027 .53614 m .33353 .52056 L .34352 .5246 L .901 .702 0 r
F
.35043 .5395 m .34027 .53614 L .34352 .5246 L .877 .688 0 r
F
.71643 .39688 m .73662 .40909 L .72709 .41088 L .912 .801 0 r
F
.70736 .39923 m .71643 .39688 L .72709 .41088 L .901 .795 0 r
F
.62214 .38616 m .64165 .39101 L .6339 .39383 L .771 .764 0 r
F
.61516 .38929 m .62214 .38616 L .6339 .39383 L .747 .75 0 r
F
.35468 .83348 m .33206 .8261 L .34006 .82383 L .777 .784 0 r
F
.362 .83088 m .35468 .83348 L .34006 .82383 L .758 .774 0 r
F
.5056 .6073 m .49806 .60777 L .49672 .60661 L .414 .464 0 r
F
.50635 .60788 m .49806 .60777 L .5056 .6073 L .414 .463 0 r
F
.26907 .51673 m .26333 .49672 L .27339 .49973 L .998 .776 0 r
F
.26907 .51673 m .25888 .51443 L .26333 .49672 L F
.51713 .61241 m .51912 .61753 L .51614 .61222 L .407 .449 0 r
F
.51713 .61241 m .52108 .61793 L .51912 .61753 L F
.52797 .61835 m .53304 .62424 L .52643 .61842 L .403 .441 0 r
F
.52797 .61835 m .53535 .62415 L .53304 .62424 L F
.77486 .40126 m .79477 .41784 L .78486 .41927 L .96 .817 0 r
F
.76528 .40331 m .77486 .40126 L .78486 .41927 L .953 .813 0 r
F
.40553 .84005 m .38394 .83625 L .39054 .83349 L .681 .751 0 r
F
.41133 .83712 m .40553 .84005 L .39054 .83349 L .651 .731 0 r
F
.42646 .84245 m .40553 .84005 L .41133 .83712 L .628 .726 0 r
F
.35043 .5395 m .34352 .5246 L .35351 .52883 L .877 .688 0 r
F
.36058 .54303 m .35043 .5395 L .35351 .52883 L .85 .673 0 r
F
.61929 .66669 m .62361 .67835 L .61442 .6715 L .692 .561 0 r
F
.61929 .66669 m .62893 .67263 L .62361 .67835 L F
.43086 .57605 m .42149 .56744 L .43166 .57186 L .589 .566 0 r
F
.44111 .57981 m .43086 .57605 L .43166 .57186 L .551 .548 0 r
F
.25888 .51443 m .25327 .4938 L .26333 .49672 L 1 .784 0 r
F
.25888 .51443 m .24868 .51221 L .25327 .4938 L F
.50992 1.10281 m .50981 1.10748 L .47852 1.10901 L .949 .937 0 r
F
.54022 1.09906 m .50981 1.10748 L .50992 1.10281 L 1 .961 0 r
F
.55926 .63383 m .56529 .64095 L .55662 .63493 L .424 .455 0 r
F
.55926 .63383 m .56846 .63959 L .56529 .64095 L F
.34506 .16718 m .36548 .14559 L .37063 .15201 L 1 .906 0 r
F
.34506 .16718 m .339 .16095 L .36548 .14559 L F
.59978 1.08509 m .57212 1.09793 L .57027 1.09314 L 1 .993 0 r
F
.59978 1.08509 m .6026 1.08995 L .57212 1.09793 L F
.4314 .83947 m .42646 .84245 L .41133 .83712 L .592 .7 0 r
F
.44644 .84368 m .42646 .84245 L .4314 .83947 L .56 .683 0 r
F
.59688 .38615 m .60303 .38282 L .61516 .38929 L .699 .734 0 r
F
.58465 .38079 m .60303 .38282 L .59688 .38615 L .672 .731 0 r
F
.36058 .54303 m .35351 .52883 L .36349 .53325 L .85 .673 0 r
F
.37073 .54674 m .36058 .54303 L .36349 .53325 L .819 .657 0 r
F
.67805 .3923 m .69832 .4015 L .68929 .40367 L .867 .79 0 r
F
.6696 .39495 m .67805 .3923 L .68929 .40367 L .852 .782 0 r
F
.24868 .51221 m .2432 .49097 L .25327 .4938 L 1 .79 0 r
F
.24868 .51221 m .23848 .51008 L .2432 .49097 L F
.60965 .66074 m .61442 .6715 L .60523 .66474 L .636 .541 0 r
F
.60965 .66074 m .61929 .66669 L .61442 .6715 L F
.47233 .59535 m .46165 .58998 L .47192 .59329 L .464 .508 0 r
F
.48251 .59816 m .47233 .59535 L .47192 .59329 L .442 .491 0 r
F
.48313 .59975 m .47233 .59535 L .48251 .59816 L .441 .492 0 r
F
.45768 .36037 m .46821 .36814 L .47135 .36498 L .456 .011 0 r
F
.45768 .36037 m .45343 .37169 L .46821 .36814 L F
.50492 .60672 m .49672 .60661 L .49554 .60545 L .415 .464 0 r
F
.5056 .6073 m .49672 .60661 L .50492 .60672 L .414 .464 0 r
F
.72295 .70429 m .72498 .72236 L .71542 .71833 L .988 .748 0 r
F
.72295 .70429 m .73289 .70764 L .72498 .72236 L F
.51807 .61254 m .52108 .61793 L .51713 .61241 L .406 .449 0 r
F
.51807 .61254 m .52297 .61821 L .52108 .61793 L F
.23848 .51008 m .23311 .48821 L .2432 .49097 L 1 .797 0 r
F
.23848 .51008 m .22827 .50801 L .23311 .48821 L F
.60303 .38282 m .62214 .38616 L .61516 .38929 L .728 .752 0 r
F
.37073 .54674 m .36349 .53325 L .37347 .53785 L .819 .657 0 r
F
.38088 .55061 m .37073 .54674 L .37347 .53785 L .785 .64 0 r
F
.32408 .82844 m .30126 .81881 L .30985 .81687 L .819 .796 0 r
F
.33206 .8261 m .32408 .82844 L .30985 .81687 L .804 .788 0 r
F
.46165 .58998 m .45137 .58363 L .46165 .58748 L .49 .521 0 r
F
.47192 .59329 m .46165 .58998 L .46165 .58748 L .462 .504 0 r
F
.6 .65484 m .60523 .66474 L .59604 .65814 L .583 .523 0 r
F
.6 .65484 m .60965 .66074 L .60523 .66474 L F
.53927 .62342 m .5455 .6297 L .53743 .62388 L .408 .446 0 r
F
.53927 .62342 m .54795 .6291 L .5455 .6297 L F
.22827 .50801 m .22302 .48553 L .23311 .48821 L 1 .802 0 r
F
.22827 .50801 m .21805 .50602 L .22302 .48553 L F
.28412 .82288 m .26106 .81039 L .27017 .80879 L .864 .809 0 r
F
.29268 .82081 m .28412 .82288 L .27017 .80879 L .853 .804 0 r
F
.51159 .84694 m .51148 .84844 L .49584 .84789 L .274 .147 0 r
F
.52624 .84761 m .51148 .84844 L .51159 .84694 L .11 .119 0 r
F
.52624 .84761 m .52714 .84807 L .51148 .84844 L F
.38394 .83625 m .362 .83088 L .36935 .82838 L .723 .765 0 r
F
.39054 .83349 m .38394 .83625 L .36935 .82838 L .699 .751 0 r
F
.38088 .55061 m .37347 .53785 L .38344 .54263 L .785 .64 0 r
F
.39103 .55464 m .38088 .55061 L .38344 .54263 L .748 .623 0 r
F
.49312 .60207 m .48313 .59975 L .48251 .59816 L .425 .478 0 r
F
.49373 .60317 m .48313 .59975 L .49312 .60207 L .424 .477 0 r
F
.64942 .38805 m .6696 .39495 L .66116 .3975 L .826 .781 0 r
F
.64165 .39101 m .64942 .38805 L .66116 .3975 L .806 .77 0 r
F
.44111 .57981 m .43166 .57186 L .44182 .5763 L .551 .548 0 r
F
.45137 .58363 m .44111 .57981 L .44182 .5763 L .516 .53 0 r
F
.56735 .37979 m .57165 .37623 L .58465 .38079 L .602 .694 0 r
F
.5547 .37609 m .57165 .37623 L .56735 .37979 L .555 .67 0 r
F
.50433 .60614 m .49554 .60545 L .49454 .6043 L .416 .465 0 r
F
.50492 .60672 m .49554 .60545 L .50433 .60614 L .415 .464 0 r
F
.21805 .50602 m .21291 .48292 L .22302 .48553 L 1 .807 0 r
F
.21805 .50602 m .20783 .50408 L .21291 .48292 L F
.51897 .61262 m .52297 .61821 L .51807 .61254 L .407 .449 0 r
F
.51897 .61262 m .52476 .61838 L .52297 .61821 L F
.59036 .64903 m .59604 .65814 L .58685 .65174 L .536 .507 0 r
F
.59036 .64903 m .6 .65484 L .59604 .65814 L F
.52935 .61816 m .53535 .62415 L .52797 .61835 L .406 .446 0 r
F
.52935 .61816 m .53743 .62388 L .53535 .62415 L F
.71299 .7008 m .71542 .71833 L .70586 .71411 L .975 .736 0 r
F
.71299 .7008 m .72295 .70429 L .71542 .71833 L F
.49696 .84575 m .49584 .84789 L .48036 .84642 L .366 .332 0 r
F
.51159 .84694 m .49584 .84789 L .49696 .84575 L .274 .147 0 r
F
.55005 .62823 m .55662 .63493 L .54795 .6291 L .418 .455 0 r
F
.55005 .62823 m .55926 .63383 L .55662 .63493 L F
.39103 .55464 m .38344 .54263 L .39341 .54756 L .748 .623 0 r
F
.40118 .5588 m .39103 .55464 L .39341 .54756 L .707 .605 0 r
F
.45048 .84077 m .44644 .84368 L .4314 .83947 L .519 .646 0 r
F
.4652 .84404 m .44644 .84368 L .45048 .84077 L .48 .605 0 r
F
.48759 .36594 m .50006 .36587 L .50103 .36755 L .031 .108 0 r
F
.78446 .39916 m .80471 .41635 L .79477 .41784 L .966 .82 0 r
F
.77486 .40126 m .78446 .39916 L .79477 .41784 L .96 .817 0 r
F
.47961 1.10442 m .47852 1.10901 L .44751 1.10843 L .904 .912 0 r
F
.50992 1.10281 m .47852 1.10901 L .47961 1.10442 L .949 .937 0 r
F
.58071 .64334 m .58685 .65174 L .57765 .64556 L .496 .493 0 r
F
.58071 .64334 m .59036 .64903 L .58685 .65174 L F
.62849 1.07503 m .6026 1.08995 L .59978 1.08509 L 1 .99 0 r
F
.62849 1.07503 m .63226 1.07995 L .6026 1.08995 L F
.50383 .60556 m .49454 .6043 L .49373 .60317 L .417 .466 0 r
F
.50433 .60614 m .49454 .6043 L .50383 .60556 L .416 .465 0 r
F
.5198 .61264 m .52476 .61838 L .51897 .61262 L .407 .45 0 r
F
.5198 .61264 m .52643 .61842 L .52476 .61838 L F
.2429 .81376 m .23384 .81551 L .2203 .79822 L .899 .819 0 r
F
.40118 .5588 m .39341 .54756 L .40338 .5526 L .707 .605 0 r
F
.41134 .56308 m .40118 .5588 L .40338 .5526 L .665 .587 0 r
F
.72551 .39446 m .74615 .40723 L .73662 .40909 L .921 .806 0 r
F
.71643 .39688 m .72551 .39446 L .73662 .40909 L .912 .801 0 r
F
.70303 .69714 m .70586 .71411 L .69627 .70969 L .959 .722 0 r
F
.70303 .69714 m .71299 .7008 L .70586 .71411 L F
.45137 .58363 m .44182 .5763 L .452 .58075 L .516 .53 0 r
F
.46165 .58748 m .45137 .58363 L .452 .58075 L .484 .514 0 r
F
.55507 .84937 m .54267 .84677 L .54078 .84811 L .38 0 0 r
F
.55507 .84937 m .55791 .84456 L .54267 .84677 L F
.47192 .59329 m .46165 .58748 L .47193 .59135 L .462 .504 0 r
F
.48221 .59664 m .47192 .59329 L .47193 .59135 L .441 .489 0 r
F
.48251 .59816 m .47192 .59329 L .48221 .59664 L .442 .491 0 r
F
.48248 .8439 m .48036 .84642 L .4652 .84404 L .419 .469 0 r
F
.49696 .84575 m .48036 .84642 L .48248 .8439 L .366 .332 0 r
F
.57107 .63779 m .57765 .64556 L .56846 .63959 L .466 .482 0 r
F
.57107 .63779 m .58071 .64334 L .57765 .64556 L F
.49271 .60102 m .48251 .59816 L .48221 .59664 L .426 .477 0 r
F
.49312 .60207 m .48251 .59816 L .49271 .60102 L .425 .478 0 r
F
.41134 .56308 m .40338 .5526 L .41335 .55771 L .665 .587 0 r
F
.42149 .56744 m .41134 .56308 L .41335 .55771 L .622 .569 0 r
F
.50343 .605 m .49373 .60317 L .49312 .60207 L .417 .466 0 r
F
.50383 .60556 m .49373 .60317 L .50343 .605 L F
.53058 .61784 m .53743 .62388 L .52935 .61816 L .41 .451 0 r
F
.53058 .61784 m .53927 .62342 L .53743 .62388 L F
.69306 .69329 m .69627 .70969 L .68668 .70506 L .941 .708 0 r
F
.69306 .69329 m .70303 .69714 L .69627 .70969 L F
.54084 .62277 m .54795 .6291 L .53927 .62342 L .415 .455 0 r
F
.54084 .62277 m .55005 .62823 L .54795 .6291 L F
.52057 .6126 m .52643 .61842 L .5198 .61264 L .408 .451 0 r
F
.52057 .6126 m .52797 .61835 L .52643 .61842 L F
.5547 .37609 m .558 .37251 L .57165 .37623 L .555 .67 0 r
F
.5416 .3731 m .558 .37251 L .5547 .37609 L .498 .625 0 r
F
.68653 .38954 m .70736 .39923 L .69832 .4015 L .881 .797 0 r
F
.67805 .3923 m .68653 .38954 L .69832 .4015 L .867 .79 0 r
F
.56142 .63238 m .56846 .63959 L .55926 .63383 L .444 .474 0 r
F
.56142 .63238 m .57107 .63779 L .56846 .63959 L F
.42149 .56744 m .41335 .55771 L .42332 .56286 L .622 .569 0 r
F
.43166 .57186 m .42149 .56744 L .42332 .56286 L .579 .551 0 r
F
.46165 .58748 m .452 .58075 L .46218 .58517 L .484 .514 0 r
F
.47193 .59135 m .46165 .58748 L .46218 .58517 L .458 .498 0 r
F
.362 .83088 m .34006 .82383 L .34808 .82166 L .758 .774 0 r
F
.36935 .82838 m .362 .83088 L .34808 .82166 L .738 .762 0 r
F
.68308 .68926 m .68668 .70506 L .67708 .70019 L .919 .693 0 r
F
.68308 .68926 m .69306 .69329 L .68668 .70506 L F
.58465 .38079 m .58991 .3772 L .60303 .38282 L .672 .731 0 r
F
.57165 .37623 m .58991 .3772 L .58465 .38079 L .64 .723 0 r
F
.62915 .38289 m .64942 .38805 L .64165 .39101 L .794 .777 0 r
F
.62214 .38616 m .62915 .38289 L .64165 .39101 L .771 .764 0 r
F
.78446 .39916 m .79408 .39701 L .80471 .41635 L .966 .82 0 r
F
.51316 .60686 m .50996 .61003 L .50898 .60953 L .413 .46 0 r
F
.51316 .60686 m .51097 .6105 L .50996 .61003 L .412 .46 0 r
F
.51316 .60686 m .512 .61093 L .51097 .6105 L .412 .459 0 r
F
.50103 .36755 m .51473 .36641 L .51461 .36899 L .265 .146 0 r
F
.50103 .36755 m .50006 .36587 L .51473 .36641 L F
.51316 .60686 m .50898 .60953 L .50805 .609 L .413 .46 0 r
F
.51316 .60686 m .51305 .61133 L .512 .61093 L .412 .459 0 r
F
.29268 .82081 m .27017 .80879 L .27929 .80724 L .853 .804 0 r
F
.30126 .81881 m .29268 .82081 L .27929 .80724 L .842 .798 0 r
F
.50313 .60445 m .49312 .60207 L .49271 .60102 L .418 .467 0 r
F
.50343 .605 m .49312 .60207 L .50313 .60445 L .417 .466 0 r
F
.51316 .60686 m .50805 .609 L .50717 .60845 L .413 .46 0 r
F
.51316 .60686 m .51409 .61167 L .51305 .61133 L .412 .458 0 r
F
.56903 .85511 m .55791 .84456 L .55507 .84937 L .591 .028 0 r
F
.56903 .85511 m .57274 .84146 L .55791 .84456 L F
.33206 .8261 m .30985 .81687 L .31847 .81501 L .804 .788 0 r
F
.34006 .82383 m .33206 .8261 L .31847 .81501 L .788 .78 0 r
F
.52126 .6125 m .52797 .61835 L .52057 .6126 L .41 .453 0 r
F
.52126 .6125 m .52935 .61816 L .52797 .61835 L F
.81018 .70836 m .81213 .73028 L .80226 .72775 L 1 .81 0 r
F
.81018 .70836 m .82037 .71028 L .81213 .73028 L F
.51316 .60686 m .50717 .60845 L .50635 .60788 L .413 .46 0 r
F
.51316 .60686 m .51513 .61197 L .51409 .61167 L .412 .458 0 r
F
.43166 .57186 m .42332 .56286 L .4333 .568 L .579 .551 0 r
F
.44182 .5763 m .43166 .57186 L .4333 .568 L .54 .534 0 r
F
.67309 .68503 m .67708 .70019 L .66746 .69509 L .894 .676 0 r
F
.67309 .68503 m .68308 .68926 L .67708 .70019 L F
.48221 .59664 m .47193 .59135 L .48222 .59523 L .441 .489 0 r
F
.49251 .60003 m .48221 .59664 L .48222 .59523 L .426 .476 0 r
F
.49271 .60102 m .48221 .59664 L .49251 .60003 L .426 .477 0 r
F
.55178 .62711 m .55926 .63383 L .55005 .62823 L .429 .469 0 r
F
.55178 .62711 m .56142 .63238 L .55926 .63383 L F
.51316 .60686 m .50635 .60788 L .5056 .6073 L .413 .46 0 r
F
.51316 .60686 m .51614 .61222 L .51513 .61197 L .411 .457 0 r
F
.53934 1.0944 m .54022 1.09906 L .50992 1.10281 L .996 .963 0 r
F
.5684 1.08841 m .54022 1.09906 L .53934 1.0944 L 1 .987 0 r
F
.5684 1.08841 m .57027 1.09314 L .54022 1.09906 L F
.5416 .3731 m .54386 .36964 L .558 .37251 L .498 .625 0 r
F
.52819 .37077 m .54386 .36964 L .5416 .3731 L .45 .541 0 r
F
.46829 .84133 m .4652 .84404 L .45048 .84077 L .453 .554 0 r
F
.48248 .8439 m .4652 .84404 L .46829 .84133 L .419 .469 0 r
F
.41133 .83712 m .39054 .83349 L .39715 .83085 L .651 .731 0 r
F
.41714 .83433 m .41133 .83712 L .39715 .83085 L .62 .71 0 r
F
.4314 .83947 m .41133 .83712 L .41714 .83433 L .592 .7 0 r
F
.2429 .81376 m .2203 .79822 L .22984 .79702 L .899 .819 0 r
F
.25198 .81205 m .2429 .81376 L .22984 .79702 L .892 .814 0 r
F
.53162 .61741 m .53927 .62342 L .53058 .61784 L .413 .457 0 r
F
.53162 .61741 m .54084 .62277 L .53927 .62342 L F
.51316 .60686 m .5056 .6073 L .50492 .60672 L .413 .46 0 r
F
.65721 .38498 m .67805 .3923 L .6696 .39495 L .843 .79 0 r
F
.64942 .38805 m .65721 .38498 L .6696 .39495 L .826 .781 0 r
F
.51316 .60686 m .51713 .61241 L .51614 .61222 L .411 .457 0 r
F
.6631 .68061 m .66746 .69509 L .65784 .68976 L .864 .659 0 r
F
.6631 .68061 m .67309 .68503 L .66746 .69509 L F
.47193 .59135 m .46218 .58517 L .47236 .58957 L .458 .498 0 r
F
.48222 .59523 m .47193 .59135 L .47236 .58957 L .438 .485 0 r
F
.73461 .39196 m .75571 .4053 L .74615 .40723 L .931 .811 0 r
F
.72551 .39446 m .73461 .39196 L .74615 .40723 L .921 .806 0 r
F
.51461 .36899 m .52938 .36763 L .52819 .37077 L .387 .384 0 r
F
.51461 .36899 m .51473 .36641 L .52938 .36763 L F
.44182 .5763 m .4333 .568 L .44327 .5731 L .54 .534 0 r
F
.452 .58075 m .44182 .5763 L .44327 .5731 L .504 .518 0 r
F
.79998 .70638 m .80226 .72775 L .79238 .72515 L 1 .804 0 r
F
.79998 .70638 m .81018 .70836 L .80226 .72775 L F
.50292 .60393 m .49271 .60102 L .49251 .60003 L .418 .467 0 r
F
.50313 .60445 m .49271 .60102 L .50292 .60393 L F
.51316 .60686 m .50492 .60672 L .50433 .60614 L .413 .46 0 r
F
.59694 1.08029 m .57027 1.09314 L .5684 1.08841 L 1 1 0 r
F
.59694 1.08029 m .59978 1.08509 L .57027 1.09314 L F
.51316 .60686 m .51807 .61254 L .51713 .61241 L .411 .457 0 r
F
.60303 .38282 m .6092 .37934 L .62214 .38616 L .728 .752 0 r
F
.58991 .3772 m .6092 .37934 L .60303 .38282 L .705 .753 0 r
F
.6092 .37934 m .62915 .38289 L .62214 .38616 L .755 .768 0 r
F
.52819 .37077 m .52938 .36763 L .54386 .36964 L .45 .541 0 r
F
.44957 1.10396 m .44751 1.10843 L .41705 1.10582 L .87 .89 0 r
F
.47961 1.10442 m .44751 1.10843 L .44957 1.10396 L .904 .912 0 r
F
.6531 .67599 m .65784 .68976 L .64821 .68421 L .83 .641 0 r
F
.6531 .67599 m .6631 .68061 L .65784 .68976 L F
.51002 1.09822 m .50992 1.10281 L .47961 1.10442 L .938 .935 0 r
F
.53934 1.0944 m .50992 1.10281 L .51002 1.09822 L .996 .963 0 r
F
.52187 .61234 m .52935 .61816 L .52126 .6125 L .411 .456 0 r
F
.52187 .61234 m .53058 .61784 L .52935 .61816 L F
.43636 .83664 m .4314 .83947 L .41714 .83433 L .556 .671 0 r
F
.45048 .84077 m .4314 .83947 L .43636 .83664 L .519 .646 0 r
F
.65614 1.06317 m .63226 1.07995 L .62849 1.07503 L 1 .973 0 r
F
.65614 1.06317 m .66084 1.06813 L .63226 1.07995 L F
.54213 .62194 m .55005 .62823 L .54084 .62277 L .421 .465 0 r
F
.54213 .62194 m .55178 .62711 L .55005 .62823 L F
.39054 .83349 m .36935 .82838 L .37671 .82598 L .699 .751 0 r
F
.39715 .83085 m .39054 .83349 L .37671 .82598 L .673 .734 0 r
F
.51316 .60686 m .50433 .60614 L .50383 .60556 L .413 .46 0 r
F
.6431 .6712 m .64821 .68421 L .63857 .67849 L .792 .623 0 r
F
.6431 .6712 m .6531 .67599 L .64821 .68421 L F
.51316 .60686 m .51897 .61262 L .51807 .61254 L .411 .457 0 r
F
.6331 .66626 m .63857 .67849 L .62893 .67263 L .749 .604 0 r
F
.6331 .66626 m .6431 .6712 L .63857 .67849 L F
.452 .58075 m .44327 .5731 L .45325 .57814 L .504 .518 0 r
F
.46218 .58517 m .452 .58075 L .45325 .57814 L .474 .503 0 r
F
.62309 .6612 m .62893 .67263 L .61929 .66669 L .703 .586 0 r
F
.62309 .6612 m .6331 .66626 L .62893 .67263 L F
.78977 .70432 m .79238 .72515 L .78249 .72248 L 1 .799 0 r
F
.78977 .70432 m .79998 .70638 L .79238 .72515 L F
.51316 .60686 m .50383 .60556 L .50343 .605 L .413 .46 0 r
F
.51316 .60686 m .5198 .61264 L .51897 .61262 L .411 .457 0 r
F
.61309 .65607 m .61929 .66669 L .60965 .66074 L .655 .567 0 r
F
.61309 .65607 m .62309 .6612 L .61929 .66669 L F
.48222 .59523 m .47236 .58957 L .48255 .59393 L .438 .485 0 r
F
.49252 .59911 m .48222 .59523 L .48255 .59393 L .424 .474 0 r
F
.49251 .60003 m .48222 .59523 L .49252 .59911 L .426 .476 0 r
F
.60309 .6509 m .60965 .66074 L .6 .65484 L .608 .549 0 r
F
.60309 .6509 m .61309 .65607 L .60965 .66074 L F
.50283 .60344 m .49251 .60003 L .49252 .59911 L .418 .467 0 r
F
.50292 .60393 m .49251 .60003 L .50283 .60344 L F
.59309 .64575 m .6 .65484 L .59036 .64903 L .563 .532 0 r
F
.59309 .64575 m .60309 .6509 L .6 .65484 L F
.47135 .36498 m .46821 .36814 L .48348 .36559 L .222 0 0 r
F
.47285 .36505 m .48348 .36559 L .48554 .36568 L F
.47351 .36509 m .48348 .36559 L .47285 .36505 L F
.47505 .367 m .48141 .36509 L .48348 .36559 L 0 0 0 r
F
.46821 .36814 m .47539 .36648 L .47505 .367 L F
.47539 .36648 m .48141 .36509 L .47505 .367 L F
.46821 .36814 m .46505 .37072 L .48034 .36546 L F
.46821 .36814 m .48034 .36546 L .47991 .36543 L F
.45343 .37169 m .46505 .37072 L .46821 .36814 L .228 0 0 r
F
.45343 .37169 m .44916 .38221 L .46505 .37072 L F
.46505 .37072 m .46189 .37143 L .47629 .36508 L .393 .152 0 r
F
.47615 .3653 m .47629 .36508 L .47933 .36374 L F
.46505 .37072 m .47629 .36508 L .47615 .3653 L F
.47991 .36543 m .48034 .36546 L .48141 .36509 L 0 0 0 r
F
.47135 .36498 m .47351 .36509 L .47285 .36505 L .222 0 0 r
F
.52239 .61212 m .53058 .61784 L .52187 .61234 L .413 .458 0 r
F
.52239 .61212 m .53162 .61741 L .53058 .61784 L F
.51316 .60686 m .50343 .605 L .50313 .60445 L .413 .46 0 r
F
.58309 .64064 m .59036 .64903 L .58071 .64334 L .523 .516 0 r
F
.58309 .64064 m .59309 .64575 L .59036 .64903 L F
.53247 .61687 m .54084 .62277 L .53162 .61741 L .417 .462 0 r
F
.53247 .61687 m .54213 .62194 L .54084 .62277 L F
.46218 .58517 m .45325 .57814 L .46323 .5831 L .474 .503 0 r
F
.47236 .58957 m .46218 .58517 L .46323 .5831 L .451 .491 0 r
F
.51316 .60686 m .52057 .6126 L .5198 .61264 L .411 .457 0 r
F
.69503 .38668 m .71643 .39688 L .70736 .39923 L .893 .803 0 r
F
.68653 .38954 m .69503 .38668 L .70736 .39923 L .881 .797 0 r
F
.58275 .88288 m .57274 .84146 L .56903 .85511 L 1 .129 0 r
F
.58275 .88288 m .5873 .86274 L .57274 .84146 L F
.57309 .63559 m .58071 .64334 L .57107 .63779 L .488 .502 0 r
F
.57309 .63559 m .58309 .64064 L .58071 .64334 L F
.77955 .7022 m .78249 .72248 L .77259 .71972 L 1 .792 0 r
F
.77955 .7022 m .78977 .70432 L .78249 .72248 L F
.57165 .37623 m .57596 .37249 L .58991 .3772 L .64 .723 0 r
F
.558 .37251 m .57596 .37249 L .57165 .37623 L .598 .706 0 r
F
.6247 1.07014 m .59978 1.08509 L .59694 1.08029 L 1 .998 0 r
F
.6247 1.07014 m .62849 1.07503 L .59978 1.08509 L F
.51316 .60686 m .50313 .60445 L .50292 .60393 L .414 .461 0 r
F
.5631 .63063 m .57107 .63779 L .56142 .63238 L .461 .491 0 r
F
.5631 .63063 m .57309 .63559 L .57107 .63779 L F
.51316 .60686 m .52126 .6125 L .52057 .6126 L .412 .458 0 r
F
.30126 .81881 m .27929 .80724 L .28842 .80576 L .842 .798 0 r
F
.30985 .81687 m .30126 .81881 L .28842 .80576 L .829 .791 0 r
F
.4807 1.09991 m .47961 1.10442 L .44957 1.10396 L .89 .909 0 r
F
.51002 1.09822 m .47961 1.10442 L .4807 1.09991 L .938 .935 0 r
F
.47236 .58957 m .46323 .5831 L .47322 .58797 L .451 .491 0 r
F
.48255 .59393 m .47236 .58957 L .47322 .58797 L .433 .48 0 r
F
.25198 .81205 m .22984 .79702 L .2394 .79587 L .892 .814 0 r
F
.26106 .81039 m .25198 .81205 L .2394 .79587 L .883 .81 0 r
F
.45454 .83802 m .45048 .84077 L .43636 .83664 L .482 .606 0 r
F
.46829 .84133 m .45048 .84077 L .45454 .83802 L .453 .554 0 r
F
.49252 .59911 m .48255 .59393 L .49275 .59826 L .424 .474 0 r
F
.50284 .60298 m .49252 .59911 L .49275 .59826 L .418 .466 0 r
F
.50283 .60344 m .49252 .59911 L .50284 .60298 L .418 .467 0 r
F
.55311 .62575 m .56142 .63238 L .55178 .62711 L .441 .481 0 r
F
.55311 .62575 m .5631 .63063 L .56142 .63238 L F
.74373 .38939 m .76528 .40331 L .75571 .4053 L .939 .815 0 r
F
.73461 .39196 m .74373 .38939 L .75571 .4053 L .931 .811 0 r
F
.37347 .53785 m .36349 .53325 L .36797 .52367 L .832 .642 0 r
F
.36349 .53325 m .35827 .5183 L .36797 .52367 L .867 .659 0 r
F
.36349 .53325 m .35351 .52883 L .35827 .5183 L F
.51316 .60686 m .50292 .60393 L .50283 .60344 L .414 .461 0 r
F
.37347 .53785 m .36797 .52367 L .37766 .52926 L .832 .642 0 r
F
.38344 .54263 m .37347 .53785 L .37766 .52926 L .793 .623 0 r
F
.76933 .69998 m .77259 .71972 L .76268 .71687 L .994 .785 0 r
F
.76933 .69998 m .77955 .7022 L .77259 .71972 L F
.35351 .52883 m .34856 .51314 L .35827 .5183 L .898 .677 0 r
F
.35351 .52883 m .34352 .5246 L .34856 .51314 L F
.51316 .60686 m .52187 .61234 L .52126 .6125 L .412 .458 0 r
F
.52282 .61185 m .53162 .61741 L .52239 .61212 L .414 .461 0 r
F
.52282 .61185 m .53247 .61687 L .53162 .61741 L F
.38344 .54263 m .37766 .52926 L .38735 .53501 L .793 .623 0 r
F
.39341 .54756 m .38344 .54263 L .38735 .53501 L .749 .604 0 r
F
.34352 .5246 m .33884 .50821 L .34856 .51314 L .924 .693 0 r
F
.34352 .5246 m .33353 .52056 L .33884 .50821 L F
.36935 .82838 m .34808 .82166 L .35612 .81958 L .738 .762 0 r
F
.37671 .82598 m .36935 .82838 L .35612 .81958 L .716 .749 0 r
F
.34006 .82383 m .31847 .81501 L .3271 .81322 L .788 .78 0 r
F
.34808 .82166 m .34006 .82383 L .3271 .81322 L .771 .77 0 r
F
.39341 .54756 m .38735 .53501 L .39704 .5409 L .749 .604 0 r
F
.40338 .5526 m .39341 .54756 L .39704 .5409 L .702 .585 0 r
F
.54312 .62095 m .55178 .62711 L .54213 .62194 L .427 .473 0 r
F
.54312 .62095 m .55311 .62575 L .55178 .62711 L F
.5117 .84559 m .51159 .84694 L .49696 .84575 L .212 .127 0 r
F
.52534 .84724 m .51159 .84694 L .5117 .84559 L .032 .108 0 r
F
.52534 .84724 m .52624 .84761 L .51159 .84694 L F
.48255 .59393 m .47322 .58797 L .4832 .59277 L .433 .48 0 r
F
.49275 .59826 m .48255 .59393 L .4832 .59277 L .422 .471 0 r
F
.33353 .52056 m .3291 .5035 L .33884 .50821 L .946 .708 0 r
F
.33353 .52056 m .32353 .5167 L .3291 .5035 L F
.49808 .84378 m .49696 .84575 L .48248 .8439 L .32 .264 0 r
F
.5117 .84559 m .49696 .84575 L .49808 .84378 L .212 .127 0 r
F
.63618 .37949 m .65721 .38498 L .64942 .38805 L .815 .788 0 r
F
.62915 .38289 m .63618 .37949 L .64942 .38805 L .794 .777 0 r
F
.40338 .5526 m .39704 .5409 L .40672 .54686 L .702 .585 0 r
F
.41335 .55771 m .40338 .5526 L .40672 .54686 L .654 .567 0 r
F
.51316 .60686 m .50283 .60344 L .50284 .60298 L .414 .461 0 r
F
.51316 .60686 m .52239 .61212 L .52187 .61234 L .413 .459 0 r
F
.32353 .5167 m .31936 .49899 L .3291 .5035 L .965 .722 0 r
F
.32353 .5167 m .31352 .51301 L .31936 .49899 L F
.41335 .55771 m .40672 .54686 L .4164 .55283 L .654 .567 0 r
F
.42332 .56286 m .41335 .55771 L .4164 .55283 L .606 .549 0 r
F
.75911 .69768 m .76268 .71687 L .75276 .71391 L .987 .778 0 r
F
.75911 .69768 m .76933 .69998 L .76268 .71687 L F
.53313 .61622 m .54213 .62194 L .53247 .61687 L .42 .467 0 r
F
.53313 .61622 m .54312 .62095 L .54213 .62194 L F
.66502 .38179 m .68653 .38954 L .67805 .3923 L .859 .798 0 r
F
.65721 .38498 m .66502 .38179 L .67805 .3923 L .843 .79 0 r
F
.42332 .56286 m .4164 .55283 L .42608 .55875 L .606 .549 0 r
F
.4333 .568 m .42332 .56286 L .42608 .55875 L .561 .532 0 r
F
.53888 .84926 m .54078 .84811 L .52624 .84761 L .22 0 0 r
F
.53888 .84926 m .52624 .84761 L .52534 .84724 L F
.49275 .59826 m .4832 .59277 L .49319 .5975 L .422 .471 0 r
F
.50295 .60257 m .49275 .59826 L .49319 .5975 L .417 .465 0 r
F
.50284 .60298 m .49275 .59826 L .50295 .60257 L .418 .466 0 r
F
.31352 .51301 m .3096 .49468 L .31936 .49899 L .982 .735 0 r
F
.31352 .51301 m .3035 .50949 L .3096 .49468 L F
.51316 .60686 m .50284 .60298 L .50295 .60257 L .414 .461 0 r
F
.51316 .60686 m .52282 .61185 L .52239 .61212 L .413 .46 0 r
F
.4333 .568 m .42608 .55875 L .43576 .56459 L .561 .532 0 r
F
.44327 .5731 m .4333 .568 L .43576 .56459 L .521 .516 0 r
F
.52314 .61153 m .53247 .61687 L .52282 .61185 L .416 .463 0 r
F
.52314 .61153 m .53313 .61622 L .53247 .61687 L F
.4846 .84156 m .48248 .8439 L .46829 .84133 L .385 .409 0 r
F
.49808 .84378 m .48248 .8439 L .4846 .84156 L .32 .264 0 r
F
.74888 .69527 m .75276 .71391 L .74283 .71084 L .979 .769 0 r
F
.74888 .69527 m .75911 .69768 L .75276 .71391 L F
.44327 .5731 m .43576 .56459 L .44544 .57029 L .521 .516 0 r
F
.45325 .57814 m .44327 .5731 L .44544 .57029 L .487 .502 0 r
F
.3035 .50949 m .29983 .49054 L .3096 .49468 L .995 .747 0 r
F
.3035 .50949 m .29347 .50611 L .29983 .49054 L F
.58991 .3772 m .59519 .37345 L .6092 .37934 L .705 .753 0 r
F
.57596 .37249 m .59519 .37345 L .58991 .3772 L .678 .749 0 r
F
.558 .37251 m .56131 .36874 L .57596 .37249 L .598 .706 0 r
F
.54386 .36964 m .56131 .36874 L .558 .37251 L .544 .671 0 r
F
.50295 .60257 m .49319 .5975 L .50317 .60219 L .417 .465 0 r
F
.51316 .60686 m .50295 .60257 L .50317 .60219 L .414 .461 0 r
F
.45325 .57814 m .44544 .57029 L .45512 .57586 L .487 .502 0 r
F
.46323 .5831 m .45325 .57814 L .45512 .57586 L .46 .49 0 r
F
.51316 .60686 m .52314 .61153 L .52282 .61185 L .413 .46 0 r
F
.46323 .5831 m .45512 .57586 L .4648 .58129 L .46 .49 0 r
F
.47322 .58797 m .46323 .5831 L .4648 .58129 L .441 .48 0 r
F
.48554 .36568 m .49908 .3641 L .50006 .36587 L .116 .12 0 r
F
.47322 .58797 m .4648 .58129 L .47448 .58658 L .441 .48 0 r
F
.4832 .59277 m .47322 .58797 L .47448 .58658 L .427 .473 0 r
F
.29347 .50611 m .29005 .48655 L .29983 .49054 L 1 .758 0 r
F
.29347 .50611 m .28344 .50286 L .29005 .48655 L F
.73864 .69275 m .74283 .71084 L .73289 .70764 L .97 .76 0 r
F
.73864 .69275 m .74888 .69527 L .74283 .71084 L F
.41714 .83433 m .39715 .83085 L .40379 .82833 L .62 .71 0 r
F
.42297 .83169 m .41714 .83433 L .40379 .82833 L .588 .686 0 r
F
.43636 .83664 m .41714 .83433 L .42297 .83169 L .556 .671 0 r
F
.70355 .38374 m .72551 .39446 L .71643 .39688 L .905 .809 0 r
F
.69503 .38668 m .70355 .38374 L .71643 .39688 L .893 .803 0 r
F
.4832 .59277 m .47448 .58658 L .48415 .59176 L .427 .473 0 r
F
.49319 .5975 m .4832 .59277 L .48415 .59176 L .42 .467 0 r
F
.26106 .81039 m .2394 .79587 L .24897 .79477 L .883 .81 0 r
F
.27017 .80879 m .26106 .81039 L .24897 .79477 L .874 .805 0 r
F
.49319 .5975 m .48415 .59176 L .49383 .59684 L .42 .467 0 r
F
.50317 .60219 m .49319 .5975 L .49383 .59684 L .416 .463 0 r
F
.61539 .3757 m .63618 .37949 L .62915 .38289 L .781 .783 0 r
F
.6092 .37934 m .61539 .3757 L .62915 .38289 L .755 .768 0 r
F
.53846 1.08983 m .53934 1.0944 L .51002 1.09822 L .988 .964 0 r
F
.56653 1.08377 m .53934 1.0944 L .53846 1.08983 L 1 .993 0 r
F
.56653 1.08377 m .5684 1.08841 L .53934 1.0944 L F
.42007 1.10148 m .41705 1.10582 L .38741 1.10123 L .846 .872 0 r
F
.44957 1.10396 m .41705 1.10582 L .42007 1.10148 L .87 .89 0 r
F
.50317 .60219 m .49383 .59684 L .50349 .60187 L .416 .463 0 r
F
.51316 .60686 m .50317 .60219 L .50349 .60187 L .413 .46 0 r
F
.51316 .60686 m .50349 .60187 L .50392 .6016 L F
.51316 .60686 m .52337 .61116 L .52314 .61153 L .414 .461 0 r
F
.51316 .60686 m .50392 .6016 L .50443 .60138 L .413 .459 0 r
F
.51316 .60686 m .52349 .61074 L .52337 .61116 L .414 .461 0 r
F
.51316 .60686 m .50443 .60138 L .50504 .60121 L .412 .458 0 r
F
.51316 .60686 m .5235 .61029 L .52349 .61074 L .414 .461 0 r
F
.51316 .60686 m .50504 .60121 L .50573 .60111 L .412 .458 0 r
F
.51316 .60686 m .52341 .60979 L .5235 .61029 L .414 .461 0 r
F
.51316 .60686 m .50573 .60111 L .5065 .60107 L .411 .457 0 r
F
.51316 .60686 m .52321 .60927 L .52341 .60979 L .414 .461 0 r
F
.51316 .60686 m .5065 .60107 L .50733 .60108 L .411 .457 0 r
F
.51316 .60686 m .52291 .60873 L .52321 .60927 L .413 .46 0 r
F
.51316 .60686 m .50733 .60108 L .50823 .60116 L .411 .457 0 r
F
.51316 .60686 m .52251 .60816 L .52291 .60873 L .413 .46 0 r
F
.6825 1.04979 m .66084 1.06813 L .65614 1.06317 L 1 .948 0 r
F
.6825 1.04979 m .68808 1.05474 L .66084 1.06813 L F
.51316 .60686 m .50823 .60116 L .50917 .60129 L .411 .457 0 r
F
.51316 .60686 m .52201 .60759 L .52251 .60816 L .413 .46 0 r
F
.51316 .60686 m .50917 .60129 L .51016 .60148 L .411 .457 0 r
F
.51316 .60686 m .52142 .607 L .52201 .60759 L .413 .46 0 r
F
.51316 .60686 m .51016 .60148 L .51118 .60173 L .411 .457 0 r
F
.51316 .60686 m .52075 .60642 L .52142 .607 L .413 .46 0 r
F
.51316 .60686 m .51118 .60173 L .51222 .60203 L .412 .458 0 r
F
.51316 .60686 m .52 .60584 L .52075 .60642 L .413 .46 0 r
F
.51316 .60686 m .51222 .60203 L .51327 .60237 L .412 .458 0 r
F
.51316 .60686 m .51917 .60526 L .52 .60584 L .413 .46 0 r
F
.51316 .60686 m .51327 .60237 L .51432 .60277 L .412 .459 0 r
F
.51316 .60686 m .51829 .60471 L .51917 .60526 L .413 .46 0 r
F
.51316 .60686 m .51432 .60277 L .51535 .6032 L .412 .459 0 r
F
.51316 .60686 m .51735 .60418 L .51829 .60471 L .413 .46 0 r
F
.51316 .60686 m .51535 .6032 L .51637 .60367 L .412 .46 0 r
F
.51316 .60686 m .51637 .60367 L .51735 .60418 L .413 .46 0 r
F
.65144 1.0582 m .62849 1.07503 L .6247 1.07014 L 1 .979 0 r
F
.65144 1.0582 m .65614 1.06317 L .62849 1.07503 L F
.52337 .61116 m .53313 .61622 L .52314 .61153 L .417 .465 0 r
F
.39715 .83085 m .37671 .82598 L .38409 .82369 L .673 .734 0 r
F
.40379 .82833 m .39715 .83085 L .38409 .82369 L .645 .716 0 r
F
.53359 .61547 m .54312 .62095 L .53313 .61622 L .422 .471 0 r
F
.52337 .61116 m .53359 .61547 L .53313 .61622 L .417 .465 0 r
F
.75287 .38676 m .77486 .40126 L .76528 .40331 L .947 .819 0 r
F
.74373 .38939 m .75287 .38676 L .76528 .40331 L .939 .815 0 r
F
.54381 .61981 m .55311 .62575 L .54312 .62095 L .433 .48 0 r
F
.53359 .61547 m .54381 .61981 L .54312 .62095 L .422 .471 0 r
F
.30985 .81687 m .28842 .80576 L .29757 .80435 L .829 .791 0 r
F
.31847 .81501 m .30985 .81687 L .29757 .80435 L .816 .783 0 r
F
.59519 .37345 m .61539 .3757 L .6092 .37934 L .737 .772 0 r
F
.28344 .50286 m .28026 .4827 L .29005 .48655 L 1 .768 0 r
F
.28344 .50286 m .27339 .49973 L .28026 .4827 L F
.7284 .69012 m .73289 .70764 L .72295 .70429 L .959 .75 0 r
F
.7284 .69012 m .73864 .69275 L .73289 .70764 L F
.55403 .62419 m .5631 .63063 L .55311 .62575 L .451 .491 0 r
F
.54381 .61981 m .55403 .62419 L .55311 .62575 L .433 .48 0 r
F
.5941 1.07554 m .5684 1.08841 L .56653 1.08377 L 1 1 0 r
F
.5941 1.07554 m .59694 1.08029 L .5684 1.08841 L F
.55221 .85289 m .54078 .84811 L .53888 .84926 L .452 0 0 r
F
.55221 .85289 m .55507 .84937 L .54078 .84811 L F
.56427 .6286 m .57309 .63559 L .5631 .63063 L .475 .504 0 r
F
.55403 .62419 m .56427 .6286 L .5631 .63063 L .451 .491 0 r
F
.45165 1.09954 m .44957 1.10396 L .42007 1.10148 L .855 .885 0 r
F
.4807 1.09991 m .44957 1.10396 L .45165 1.09954 L .89 .909 0 r
F
.50349 .60187 m .49466 .59629 L .50392 .6016 L .414 .461 0 r
F
.50349 .60187 m .49383 .59684 L .49466 .59629 L F
.57451 .63305 m .58309 .64064 L .57309 .63559 L .505 .518 0 r
F
.56427 .6286 m .57451 .63305 L .57309 .63559 L .475 .504 0 r
F
.52349 .61074 m .53359 .61547 L .52337 .61116 L .418 .466 0 r
F
.4714 .83879 m .46829 .84133 L .45454 .83802 L .427 .505 0 r
F
.4846 .84156 m .46829 .84133 L .4714 .83879 L .385 .409 0 r
F
.51013 1.09371 m .51002 1.09822 L .4807 1.09991 L .924 .932 0 r
F
.53846 1.08983 m .51002 1.09822 L .51013 1.09371 L .988 .964 0 r
F
.44134 .83396 m .43636 .83664 L .42297 .83169 L .52 .639 0 r
F
.45454 .83802 m .43636 .83664 L .44134 .83396 L .482 .606 0 r
F
.71815 .68734 m .72295 .70429 L .71299 .7008 L .946 .74 0 r
F
.71815 .68734 m .7284 .69012 L .72295 .70429 L F
.58475 .63753 m .59309 .64575 L .58309 .64064 L .54 .534 0 r
F
.57451 .63305 m .58475 .63753 L .58309 .64064 L .505 .518 0 r
F
.27339 .49973 m .27045 .47898 L .28026 .4827 L 1 .777 0 r
F
.27339 .49973 m .26333 .49672 L .27045 .47898 L F
.54386 .36964 m .54613 .366 L .56131 .36874 L .544 .671 0 r
F
.52938 .36763 m .54613 .366 L .54386 .36964 L .483 .602 0 r
F
.49383 .59684 m .48541 .59091 L .49466 .59629 L .417 .462 0 r
F
.49383 .59684 m .48415 .59176 L .48541 .59091 L F
.595 .64201 m .60309 .6509 L .59309 .64575 L .58 .551 0 r
F
.58475 .63753 m .595 .64201 L .59309 .64575 L .54 .534 0 r
F
.50392 .6016 m .49569 .59585 L .50443 .60138 L .413 .458 0 r
F
.50392 .6016 m .49466 .59629 L .49569 .59585 L F
.52349 .61074 m .53383 .61463 L .53359 .61547 L .418 .466 0 r
F
.5235 .61029 m .53383 .61463 L .52349 .61074 L .418 .467 0 r
F
.7079 .68443 m .71299 .7008 L .70303 .69714 L .932 .728 0 r
F
.7079 .68443 m .71815 .68734 L .71299 .7008 L F
.53383 .61463 m .54381 .61981 L .53359 .61547 L .424 .474 0 r
F
.50006 .36587 m .51484 .36367 L .51473 .36641 L .333 .201 0 r
F
.50006 .36587 m .49908 .3641 L .51484 .36367 L F
.60525 .64647 m .61309 .65607 L .60309 .6509 L .622 .569 0 r
F
.595 .64201 m .60525 .64647 L .60309 .6509 L .58 .551 0 r
F
.34808 .82166 m .3271 .81322 L .33574 .81153 L .771 .77 0 r
F
.35612 .81958 m .34808 .82166 L .33574 .81153 L .753 .759 0 r
F
.48415 .59176 m .47614 .58542 L .48541 .59091 L .421 .465 0 r
F
.48415 .59176 m .47448 .58658 L .47614 .58542 L F
.26333 .49672 m .26062 .47537 L .27045 .47898 L 1 .785 0 r
F
.26333 .49672 m .25327 .4938 L .26062 .47537 L F
.61551 .65087 m .62309 .6612 L .61309 .65607 L .664 .587 0 r
F
.60525 .64647 m .61551 .65087 L .61309 .65607 L .622 .569 0 r
F
.69764 .68136 m .70303 .69714 L .69306 .69329 L .914 .715 0 r
F
.69764 .68136 m .7079 .68443 L .70303 .69714 L F
.50443 .60138 m .49691 .59552 L .50504 .60121 L .411 .456 0 r
F
.50443 .60138 m .49569 .59585 L .49691 .59552 L F
.5235 .61029 m .53386 .61371 L .53383 .61463 L .418 .467 0 r
F
.52341 .60979 m .53386 .61371 L .5235 .61029 L F
.62578 .6552 m .6331 .66626 L .62309 .6612 L .706 .605 0 r
F
.61551 .65087 m .62578 .6552 L .62309 .6612 L .664 .587 0 r
F
.37671 .82598 m .35612 .81958 L .36418 .8176 L .716 .749 0 r
F
.38409 .82369 m .37671 .82598 L .36418 .8176 L .692 .735 0 r
F
.52938 .36763 m .53058 .3643 L .54613 .366 L .483 .602 0 r
F
.51473 .36641 m .53058 .3643 L .52938 .36763 L .433 .461 0 r
F
.62091 1.06527 m .59694 1.08029 L .5941 1.07554 L 1 1 0 r
F
.62091 1.06527 m .6247 1.07014 L .59694 1.08029 L F
.68738 .67813 m .69306 .69329 L .68308 .68926 L .895 .702 0 r
F
.68738 .67813 m .69764 .68136 L .69306 .69329 L F
.54418 .61852 m .55403 .62419 L .54381 .61981 L .438 .485 0 r
F
.53383 .61463 m .54418 .61852 L .54381 .61981 L .424 .474 0 r
F
.51473 .36641 m .51484 .36367 L .53058 .3643 L .433 .461 0 r
F
.47448 .58658 m .46687 .57978 L .47614 .58542 L .428 .468 0 r
F
.47448 .58658 m .4648 .58129 L .46687 .57978 L F
.63604 .65941 m .6431 .6712 L .6331 .66626 L .746 .622 0 r
F
.62578 .6552 m .63604 .65941 L .6331 .66626 L .706 .605 0 r
F
.67285 .3785 m .69503 .38668 L .68653 .38954 L .874 .805 0 r
F
.66502 .38179 m .67285 .3785 L .68653 .38954 L .859 .798 0 r
F
.64324 .37595 m .66502 .38179 L .65721 .38498 L .834 .798 0 r
F
.63618 .37949 m .64324 .37595 L .65721 .38498 L .815 .788 0 r
F
.67712 .67473 m .68308 .68926 L .67309 .68503 L .872 .687 0 r
F
.67712 .67473 m .68738 .67813 L .68308 .68926 L F
.64631 .66348 m .6531 .67599 L .6431 .6712 L .783 .639 0 r
F
.63604 .65941 m .64631 .66348 L .6431 .6712 L .746 .622 0 r
F
.49466 .59629 m .48695 .59024 L .49569 .59585 L .413 .457 0 r
F
.49466 .59629 m .48541 .59091 L .48695 .59024 L F
.50504 .60121 m .49828 .59532 L .50573 .60111 L .41 .453 0 r
F
.50504 .60121 m .49691 .59552 L .49828 .59532 L F
.66685 .67115 m .67309 .68503 L .6631 .68061 L .846 .672 0 r
F
.66685 .67115 m .67712 .67473 L .67309 .68503 L F
.25327 .4938 m .25079 .47185 L .26062 .47537 L 1 .792 0 r
F
.25327 .4938 m .2432 .49097 L .25079 .47185 L F
.65658 .6674 m .6631 .68061 L .6531 .67599 L .816 .656 0 r
F
.64631 .66348 m .65658 .6674 L .6531 .67599 L .783 .639 0 r
F
.52341 .60979 m .53368 .61272 L .53386 .61371 L .418 .467 0 r
F
.52321 .60927 m .53368 .61272 L .52341 .60979 L F
.65658 .6674 m .66685 .67115 L .6631 .68061 L .816 .656 0 r
F
.27017 .80879 m .24897 .79477 L .25856 .79372 L .874 .805 0 r
F
.27929 .80724 m .27017 .80879 L .25856 .79372 L .864 .799 0 r
F
.4648 .58129 m .45759 .57397 L .46687 .57978 L .443 .474 0 r
F
.4648 .58129 m .45512 .57586 L .45759 .57397 L F
.53386 .61371 m .54418 .61852 L .53383 .61463 L .426 .476 0 r
F
.4818 1.09547 m .4807 1.09991 L .45165 1.09954 L .874 .903 0 r
F
.51013 1.09371 m .4807 1.09991 L .4818 1.09547 L .924 .932 0 r
F
.57596 .37249 m .58029 .36857 L .59519 .37345 L .678 .749 0 r
F
.56131 .36874 m .58029 .36857 L .57596 .37249 L .644 .74 0 r
F
.76202 .38407 m .78446 .39916 L .77486 .40126 L .954 .823 0 r
F
.75287 .38676 m .76202 .38407 L .77486 .40126 L .947 .819 0 r
F
.55454 .62243 m .56427 .6286 L .55403 .62419 L .458 .498 0 r
F
.54418 .61852 m .55454 .62243 L .55403 .62419 L .438 .485 0 r
F
.71209 .38072 m .73461 .39196 L .72551 .39446 L .915 .814 0 r
F
.70355 .38374 m .71209 .38072 L .72551 .39446 L .905 .809 0 r
F
.50573 .60111 m .49982 .59524 L .5065 .60107 L .408 .451 0 r
F
.50573 .60111 m .49828 .59532 L .49982 .59524 L F
.45512 .57586 m .44831 .56795 L .45759 .57397 L .464 .482 0 r
F
.45512 .57586 m .44544 .57029 L .44831 .56795 L F
.52321 .60927 m .53329 .61167 L .53368 .61272 L .418 .467 0 r
F
.52291 .60873 m .53329 .61167 L .52321 .60927 L .417 .466 0 r
F
.45861 .83543 m .45454 .83802 L .44134 .83396 L .455 .566 0 r
F
.4714 .83879 m .45454 .83802 L .45861 .83543 L .427 .505 0 r
F
.2432 .49097 m .24094 .46842 L .25079 .47185 L 1 .799 0 r
F
.2432 .49097 m .23311 .48821 L .24094 .46842 L F
.44544 .57029 m .43903 .56171 L .44831 .56795 L .494 .492 0 r
F
.44544 .57029 m .43576 .56459 L .43903 .56171 L F
.44693 .38429 m .44916 .38221 L .45343 .37169 L 0 0 0 r
F
.44916 .38221 m .44493 .3855 L .45126 .38025 L .48 .15 0 r
F
.44916 .38221 m .45126 .38025 L .46189 .37143 L F
.43902 .39959 m .44916 .38221 L .44693 .38429 L 0 0 0 r
F
.31847 .81501 m .29757 .80435 L .30674 .80301 L .816 .783 0 r
F
.3271 .81322 m .31847 .81501 L .30674 .80301 L .801 .775 0 r
F
.5065 .60107 m .50149 .59528 L .50733 .60108 L .407 .45 0 r
F
.5065 .60107 m .49982 .59524 L .50149 .59528 L F
.56491 .62633 m .57451 .63305 L .56427 .6286 L .484 .514 0 r
F
.55454 .62243 m .56491 .62633 L .56427 .6286 L .458 .498 0 r
F
.48541 .59091 m .47819 .58451 L .48695 .59024 L .415 .455 0 r
F
.48541 .59091 m .47614 .58542 L .47819 .58451 L F
.43576 .56459 m .42974 .55525 L .43903 .56171 L .533 .506 0 r
F
.43576 .56459 m .42608 .55875 L .42974 .55525 L F
.52291 .60873 m .53269 .61057 L .53329 .61167 L .417 .466 0 r
F
.52251 .60816 m .53269 .61057 L .52291 .60873 L F
.49569 .59585 m .48876 .58975 L .49691 .59552 L .41 .451 0 r
F
.49569 .59585 m .48695 .59024 L .48876 .58975 L F
.56522 .86109 m .55507 .84937 L .55221 .85289 L .791 .031 0 r
F
.56522 .86109 m .56903 .85511 L .55507 .84937 L F
.42608 .55875 m .42046 .54858 L .42974 .55525 L .58 .522 0 r
F
.42608 .55875 m .4164 .55283 L .42046 .54858 L F
.53386 .61371 m .54423 .61712 L .54418 .61852 L .426 .476 0 r
F
.53368 .61272 m .54423 .61712 L .53386 .61371 L .426 .477 0 r
F
.4164 .55283 m .41117 .54175 L .42046 .54858 L .633 .54 0 r
F
.4164 .55283 m .40672 .54686 L .41117 .54175 L F
.54423 .61712 m .55454 .62243 L .54418 .61852 L .441 .489 0 r
F
.40672 .54686 m .40188 .53483 L .41117 .54175 L .689 .56 0 r
F
.40672 .54686 m .39704 .5409 L .40188 .53483 L F
.50733 .60108 m .50328 .59544 L .50823 .60116 L .407 .449 0 r
F
.50733 .60108 m .50149 .59528 L .50328 .59544 L F
.52251 .60816 m .53189 .60944 L .53269 .61057 L .417 .466 0 r
F
.52201 .60759 m .53189 .60944 L .52251 .60816 L .416 .465 0 r
F
.23311 .48821 m .23108 .46507 L .24094 .46842 L 1 .805 0 r
F
.23311 .48821 m .22302 .48553 L .23108 .46507 L F
.39704 .5409 m .39258 .52791 L .40188 .53483 L .745 .581 0 r
F
.39704 .5409 m .38735 .53501 L .39258 .52791 L F
.57529 .63022 m .58475 .63753 L .57451 .63305 L .515 .53 0 r
F
.56491 .62633 m .57529 .63022 L .57451 .63305 L .484 .514 0 r
F
.38735 .53501 m .38329 .52108 L .39258 .52791 L .797 .602 0 r
F
.38735 .53501 m .37766 .52926 L .38329 .52108 L F
.6769 1.04479 m .65614 1.06317 L .65144 1.0582 L 1 .95 0 r
F
.6769 1.04479 m .6825 1.04979 L .65614 1.06317 L F
.50823 .60116 m .50518 .59571 L .50917 .60129 L .406 .449 0 r
F
.50823 .60116 m .50328 .59544 L .50518 .59571 L F
.37766 .52926 m .37398 .51442 L .38329 .52108 L .845 .623 0 r
F
.37766 .52926 m .36797 .52367 L .37398 .51442 L F
.52201 .60759 m .53089 .60828 L .53189 .60944 L .416 .465 0 r
F
.52142 .607 m .53089 .60828 L .52201 .60759 L .415 .464 0 r
F
.6216 .37192 m .64324 .37595 L .63618 .37949 L .805 .796 0 r
F
.61539 .3757 m .6216 .37192 L .63618 .37949 L .781 .783 0 r
F
.47614 .58542 m .46942 .57862 L .47819 .58451 L .417 .454 0 r
F
.47614 .58542 m .46687 .57978 L .46942 .57862 L F
.59519 .37345 m .60049 .36953 L .61539 .3757 L .737 .772 0 r
F
.58029 .36857 m .60049 .36953 L .59519 .37345 L .715 .773 0 r
F
.49691 .59552 m .49082 .58946 L .49828 .59532 L .406 .446 0 r
F
.49691 .59552 m .48876 .58975 L .49082 .58946 L F
.36797 .52367 m .36467 .50799 L .37398 .51442 L .887 .644 0 r
F
.36797 .52367 m .35827 .5183 L .36467 .50799 L F
.4992 .8419 m .49808 .84378 L .4846 .84156 L .285 .223 0 r
F
.51181 .84424 m .49808 .84378 L .4992 .8419 L .175 .121 0 r
F
.51181 .84424 m .5117 .84559 L .49808 .84378 L F
.40379 .82833 m .38409 .82369 L .39149 .82153 L .645 .716 0 r
F
.41045 .82595 m .40379 .82833 L .39149 .82153 L .615 .695 0 r
F
.42297 .83169 m .40379 .82833 L .41045 .82595 L .588 .686 0 r
F
.64671 1.05321 m .6247 1.07014 L .62091 1.06527 L 1 .986 0 r
F
.64671 1.05321 m .65144 1.0582 L .6247 1.07014 L F
.42883 .82919 m .42297 .83169 L .41045 .82595 L .555 .66 0 r
F
.44134 .83396 m .42297 .83169 L .42883 .82919 L .52 .639 0 r
F
.50917 .60129 m .50715 .5961 L .51016 .60148 L .407 .449 0 r
F
.50917 .60129 m .50518 .59571 L .50715 .5961 L F
.52142 .607 m .52972 .60711 L .53089 .60828 L .415 .464 0 r
F
.52075 .60642 m .52972 .60711 L .52142 .607 L .414 .464 0 r
F
.53368 .61272 m .54397 .61561 L .54423 .61712 L .426 .477 0 r
F
.53329 .61167 m .54397 .61561 L .53368 .61272 L .425 .478 0 r
F
.22302 .48553 m .2212 .46178 L .23108 .46507 L 1 .81 0 r
F
.22302 .48553 m .21291 .48292 L .2212 .46178 L F
.58568 .63409 m .595 .64201 L .58475 .63753 L .551 .548 0 r
F
.57529 .63022 m .58568 .63409 L .58475 .63753 L .515 .53 0 r
F
.52444 .84665 m .5117 .84559 L .51181 .84424 L .006 .103 0 r
F
.52444 .84665 m .52534 .84724 L .5117 .84559 L F
.42007 1.10148 m .38741 1.10123 L .39138 1.09708 L .846 .872 0 r
F
.42311 1.0972 m .42007 1.10148 L .39138 1.09708 L .831 .866 0 r
F
.45165 1.09954 m .42007 1.10148 L .42311 1.0972 L .855 .885 0 r
F
.27929 .80724 m .25856 .79372 L .26815 .79274 L .864 .799 0 r
F
.28842 .80576 m .27929 .80724 L .26815 .79274 L .853 .793 0 r
F
.55462 .62051 m .56491 .62633 L .55454 .62243 L .462 .504 0 r
F
.54423 .61712 m .55462 .62051 L .55454 .62243 L .441 .489 0 r
F
.35827 .5183 m .35534 .50182 L .36467 .50799 L .922 .664 0 r
F
.35827 .5183 m .34856 .51314 L .35534 .50182 L F
.51016 .60148 m .5092 .5966 L .51118 .60173 L .407 .45 0 r
F
.51016 .60148 m .50715 .5961 L .5092 .5966 L F
.35612 .81958 m .33574 .81153 L .34441 .80992 L .753 .759 0 r
F
.36418 .8176 m .35612 .81958 L .34441 .80992 L .732 .747 0 r
F
.52075 .60642 m .52837 .60594 L .52972 .60711 L .414 .464 0 r
F
.52 .60584 m .52837 .60594 L .52075 .60642 L .414 .463 0 r
F
.48695 .59024 m .4806 .58386 L .48876 .58975 L .408 .445 0 r
F
.48695 .59024 m .47819 .58451 L .4806 .58386 L F
.7712 .38133 m .79408 .39701 L .78446 .39916 L .96 .826 0 r
F
.76202 .38407 m .7712 .38133 L .78446 .39916 L .954 .823 0 r
F
.60049 .36953 m .6216 .37192 L .61539 .3757 L .767 .789 0 r
F
.53757 1.08536 m .53846 1.08983 L .51013 1.09371 L .975 .964 0 r
F
.56466 1.07922 m .53846 1.08983 L .53757 1.08536 L 1 .998 0 r
F
.56466 1.07922 m .56653 1.08377 L .53846 1.08983 L F
.56131 .36874 m .56463 .36478 L .58029 .36857 L .644 .74 0 r
F
.54613 .366 m .56463 .36478 L .56131 .36874 L .599 .718 0 r
F
.48674 .83934 m .4846 .84156 L .4714 .83879 L .356 .361 0 r
F
.4992 .8419 m .4846 .84156 L .48674 .83934 L .285 .223 0 r
F
.51118 .60173 m .51128 .59721 L .51222 .60203 L .408 .452 0 r
F
.51118 .60173 m .5092 .5966 L .51128 .59721 L F
.52 .60584 m .52686 .60479 L .52837 .60594 L .414 .463 0 r
F
.51917 .60526 m .52686 .60479 L .52 .60584 L .413 .463 0 r
F
.46687 .57978 m .46064 .57251 L .46942 .57862 L .423 .454 0 r
F
.46687 .57978 m .45759 .57397 L .46064 .57251 L F
.54397 .61561 m .55462 .62051 L .54423 .61712 L .441 .491 0 r
F
.59125 1.07088 m .56653 1.08377 L .56466 1.07922 L 1 1 0 r
F
.59125 1.07088 m .5941 1.07554 L .56653 1.08377 L F
.34856 .51314 m .346 .49594 L .35534 .50182 L .952 .683 0 r
F
.34856 .51314 m .33884 .50821 L .346 .49594 L F
.59608 .6379 m .60525 .64647 L .595 .64201 L .589 .566 0 r
F
.58568 .63409 m .59608 .6379 L .595 .64201 L .551 .548 0 r
F
.51222 .60203 m .51338 .59791 L .51327 .60237 L .409 .454 0 r
F
.51222 .60203 m .51128 .59721 L .51338 .59791 L F
.51917 .60526 m .52521 .60366 L .52686 .60479 L .413 .463 0 r
F
.51829 .60471 m .52521 .60366 L .51917 .60526 L .413 .462 0 r
F
.49828 .59532 m .49312 .58935 L .49982 .59524 L .403 .441 0 r
F
.49828 .59532 m .49082 .58946 L .49312 .58935 L F
.6807 .3751 m .70355 .38374 L .69503 .38668 L .888 .812 0 r
F
.67285 .3785 m .6807 .3751 L .69503 .38668 L .874 .805 0 r
F
.45373 1.09519 m .45165 1.09954 L .42311 1.0972 L .838 .879 0 r
F
.4818 1.09547 m .45165 1.09954 L .45373 1.09519 L .874 .903 0 r
F
.51327 .60237 m .51548 .59869 L .51432 .60277 L .41 .456 0 r
F
.51327 .60237 m .51338 .59791 L .51548 .59869 L F
.51829 .60471 m .52344 .60256 L .52521 .60366 L .413 .462 0 r
F
.51735 .60418 m .52344 .60256 L .51829 .60471 L .412 .461 0 r
F
.39138 1.09708 m .38741 1.10123 L .35885 1.09477 L .829 .857 0 r
F
.53329 .61167 m .54339 .61401 L .54397 .61561 L .425 .478 0 r
F
.53269 .61057 m .54339 .61401 L .53329 .61167 L .424 .477 0 r
F
.72065 .37762 m .74373 .38939 L .73461 .39196 L .925 .819 0 r
F
.71209 .38072 m .72065 .37762 L .73461 .39196 L .915 .814 0 r
F
.70732 1.03517 m .68808 1.05474 L .6825 1.04979 L 1 .919 0 r
F
.70732 1.03517 m .71375 1.04004 L .68808 1.05474 L F
.51432 .60277 m .51756 .59956 L .51535 .6032 L .41 .457 0 r
F
.51432 .60277 m .51548 .59869 L .51756 .59956 L F
.51735 .60418 m .52156 .6015 L .52344 .60256 L .412 .461 0 r
F
.51637 .60367 m .52156 .6015 L .51735 .60418 L .412 .46 0 r
F
.53697 .84967 m .53888 .84926 L .53495 .84867 L .217 0 0 r
F
.53697 .84967 m .53495 .84867 L .52534 .84724 L F
.53909 .85071 m .53697 .84967 L .53505 .84908 L .315 0 0 r
F
.54638 .85364 m .53697 .84967 L .53909 .85071 L F
.53697 .84967 m .52534 .84724 L .52444 .84665 L .217 0 0 r
F
.51535 .6032 m .51959 .6005 L .51637 .60367 L .411 .459 0 r
F
.51535 .6032 m .51756 .59956 L .51959 .6005 L F
.51637 .60367 m .51959 .6005 L .52156 .6015 L .412 .46 0 r
F
.22984 .79702 m .2203 .79822 L .20959 .77995 L .91 .815 0 r
F
.51023 1.0893 m .51013 1.09371 L .4818 1.09547 L .906 .927 0 r
F
.53757 1.08536 m .51013 1.09371 L .51023 1.0893 L .975 .964 0 r
F
.38409 .82369 m .36418 .8176 L .37226 .81573 L .692 .735 0 r
F
.39149 .82153 m .38409 .82369 L .37226 .81573 L .667 .719 0 r
F
.44633 .83145 m .44134 .83396 L .42883 .82919 L .486 .606 0 r
F
.45861 .83543 m .44134 .83396 L .44633 .83145 L .455 .566 0 r
F
.33884 .50821 m .33664 .49034 L .346 .49594 L .977 .7 0 r
F
.33884 .50821 m .3291 .5035 L .33664 .49034 L F
.65031 .37229 m .67285 .3785 L .66502 .38179 L .852 .807 0 r
F
.64324 .37595 m .65031 .37229 L .66502 .38179 L .834 .798 0 r
F
.56502 .62386 m .57529 .63022 L .56491 .62633 L .489 .521 0 r
F
.55462 .62051 m .56502 .62386 L .56491 .62633 L .462 .504 0 r
F
.60648 .64164 m .61551 .65087 L .60525 .64647 L .628 .584 0 r
F
.59608 .6379 m .60648 .64164 L .60525 .64647 L .589 .566 0 r
F
.45759 .57397 m .45186 .56616 L .46064 .57251 L .436 .456 0 r
F
.45759 .57397 m .44831 .56795 L .45186 .56616 L F
.3271 .81322 m .30674 .80301 L .31592 .80175 L .801 .775 0 r
F
.33574 .81153 m .3271 .81322 L .31592 .80175 L .785 .766 0 r
F
.47453 .8364 m .4714 .83879 L .45861 .83543 L .402 .461 0 r
F
.48674 .83934 m .4714 .83879 L .47453 .8364 L .356 .361 0 r
F
.49982 .59524 m .49563 .58943 L .50149 .59528 L .401 .438 0 r
F
.49982 .59524 m .49312 .58935 L .49563 .58943 L F
.47819 .58451 m .47243 .5778 L .4806 .58386 L .407 .439 0 r
F
.47819 .58451 m .46942 .57862 L .47243 .5778 L F
.3291 .5035 m .32727 .48499 L .33664 .49034 L .998 .717 0 r
F
.3291 .5035 m .31936 .49899 L .32727 .48499 L F
.48876 .58975 m .48335 .58348 L .49082 .58946 L .402 .436 0 r
F
.48876 .58975 m .4806 .58386 L .48335 .58348 L F
.6171 1.06044 m .5941 1.07554 L .59125 1.07088 L 1 1 0 r
F
.6171 1.06044 m .62091 1.06527 L .5941 1.07554 L F
.53269 .61057 m .54249 .61235 L .54339 .61401 L .424 .477 0 r
F
.53189 .60944 m .54249 .61235 L .53269 .61057 L .423 .476 0 r
F
.6169 .64529 m .62578 .6552 L .61551 .65087 L .667 .602 0 r
F
.60648 .64164 m .6169 .64529 L .61551 .65087 L .628 .584 0 r
F
.54397 .61561 m .55428 .61845 L .55462 .62051 L .441 .491 0 r
F
.54339 .61401 m .55428 .61845 L .54397 .61561 L .441 .492 0 r
F
.44831 .56795 m .44307 .5595 L .45186 .56616 L .459 .462 0 r
F
.44831 .56795 m .43903 .56171 L .44307 .5595 L F
.54613 .366 m .54841 .36214 L .56463 .36478 L .599 .718 0 r
F
.53058 .3643 m .54841 .36214 L .54613 .366 L .54 .67 0 r
F
.55428 .61845 m .56502 .62386 L .55462 .62051 L .463 .508 0 r
F
.48348 .36559 m .49811 .362 L .49908 .3641 L .282 .141 0 r
F
.48348 .36559 m .48141 .36509 L .49811 .362 L F
.57544 .62716 m .58568 .63409 L .57529 .63022 L .521 .539 0 r
F
.56502 .62386 m .57544 .62716 L .57529 .63022 L .489 .521 0 r
F
.31936 .49899 m .31789 .47988 L .32727 .48499 L 1 .732 0 r
F
.31936 .49899 m .3096 .49468 L .31789 .47988 L F
.28842 .80576 m .26815 .79274 L .27776 .79182 L .853 .793 0 r
F
.29757 .80435 m .28842 .80576 L .27776 .79182 L .842 .786 0 r
F
.62732 .64882 m .63604 .65941 L .62578 .6552 L .704 .619 0 r
F
.6169 .64529 m .62732 .64882 L .62578 .6552 L .667 .602 0 r
F
.7712 .38133 m .78039 .37853 L .79408 .39701 L .96 .826 0 r
F
.50149 .59528 m .49832 .5897 L .50328 .59544 L .399 .436 0 r
F
.50149 .59528 m .49563 .58943 L .49832 .5897 L F
.53189 .60944 m .54129 .61064 L .54249 .61235 L .423 .476 0 r
F
.53089 .60828 m .54129 .61064 L .53189 .60944 L .422 .475 0 r
F
.4829 1.09112 m .4818 1.09547 L .45373 1.09519 L .854 .896 0 r
F
.51023 1.0893 m .4818 1.09547 L .4829 1.09112 L .906 .927 0 r
F
.43903 .56171 m .43428 .55252 L .44307 .5595 L .492 .472 0 r
F
.43903 .56171 m .42974 .55525 L .43428 .55252 L F
.22984 .79702 m .20959 .77995 L .21953 .77934 L .91 .815 0 r
F
.2394 .79587 m .22984 .79702 L .21953 .77934 L .903 .811 0 r
F
.54931 .85423 m .53888 .84926 L .53697 .84967 L .438 0 0 r
F
.54931 .85423 m .55221 .85289 L .53888 .84926 L F
.58029 .36857 m .58463 .36447 L .60049 .36953 L .715 .773 0 r
F
.56463 .36478 m .58463 .36447 L .58029 .36857 L .689 .771 0 r
F
.63774 .65222 m .64631 .66348 L .63604 .65941 L .74 .636 0 r
F
.62732 .64882 m .63774 .65222 L .63604 .65941 L .704 .619 0 r
F
.81516 .68873 m .82037 .71028 L .81018 .70836 L .993 .808 0 r
F
.81516 .68873 m .82558 .69001 L .82037 .71028 L F
.46942 .57862 m .46424 .57153 L .47243 .5778 L .407 .432 0 r
F
.46942 .57862 m .46064 .57251 L .46424 .57153 L F
.53058 .3643 m .53179 .36074 L .54841 .36214 L .54 .67 0 r
F
.51484 .36367 m .53179 .36074 L .53058 .3643 L .486 .566 0 r
F
.3096 .49468 m .30848 .47498 L .31789 .47988 L 1 .746 0 r
F
.3096 .49468 m .29983 .49054 L .30848 .47498 L F
.49082 .58946 m .48641 .58337 L .49312 .58935 L .396 .427 0 r
F
.49082 .58946 m .48335 .58348 L .48641 .58337 L F
.42974 .55525 m .42548 .54518 L .43428 .55252 L .539 .486 0 r
F
.42974 .55525 m .42046 .54858 L .42548 .54518 L F
.49908 .3641 m .51496 .36064 L .51484 .36367 L .423 .342 0 r
F
.49908 .3641 m .49811 .362 L .51496 .36064 L F
.67129 1.03972 m .65144 1.0582 L .64671 1.05321 L 1 .952 0 r
F
.67129 1.03972 m .6769 1.04479 L .65144 1.0582 L F
.50328 .59544 m .50116 .59014 L .50518 .59571 L .398 .435 0 r
F
.50328 .59544 m .49832 .5897 L .50116 .59014 L F
.80473 .68739 m .81018 .70836 L .79998 .70638 L .988 .803 0 r
F
.80473 .68739 m .81516 .68873 L .81018 .70836 L F
.53089 .60828 m .5398 .60891 L .54129 .61064 L .422 .475 0 r
F
.52972 .60711 m .5398 .60891 L .53089 .60828 L .42 .473 0 r
F
.46269 .83299 m .45861 .83543 L .44633 .83145 L .434 .527 0 r
F
.47453 .8364 m .45861 .83543 L .46269 .83299 L .402 .461 0 r
F
.58586 .63038 m .59608 .6379 L .58568 .63409 L .555 .558 0 r
F
.57544 .62716 m .58586 .63038 L .58568 .63409 L .521 .539 0 r
F
.36418 .8176 m .34441 .80992 L .35309 .80842 L .732 .747 0 r
F
.37226 .81573 m .36418 .8176 L .35309 .80842 L .71 .734 0 r
F
.54339 .61401 m .55351 .61629 L .55428 .61845 L .441 .492 0 r
F
.54249 .61235 m .55351 .61629 L .54339 .61401 L .438 .492 0 r
F
.64818 .65547 m .65658 .6674 L .64631 .66348 L .772 .653 0 r
F
.63774 .65222 m .64818 .65547 L .64631 .66348 L .74 .636 0 r
F
.62783 .36799 m .65031 .37229 L .64324 .37595 L .826 .807 0 r
F
.6216 .37192 m .62783 .36799 L .64324 .37595 L .805 .796 0 r
F
.51484 .36367 m .51496 .36064 L .53179 .36074 L .486 .566 0 r
F
.72922 .37445 m .75287 .38676 L .74373 .38939 L .934 .823 0 r
F
.72065 .37762 m .72922 .37445 L .74373 .38939 L .925 .819 0 r
F
.7943 .68599 m .79998 .70638 L .78977 .70432 L .983 .798 0 r
F
.7943 .68599 m .80473 .68739 L .79998 .70638 L F
.4806 .58386 m .47586 .57736 L .48335 .58348 L .397 .423 0 r
F
.4806 .58386 m .47243 .5778 L .47586 .57736 L F
.42046 .54858 m .41668 .53753 L .42548 .54518 L .597 .504 0 r
F
.42046 .54858 m .41117 .54175 L .41668 .53753 L F
.5646 .62122 m .57544 .62716 L .56502 .62386 L .491 .526 0 r
F
.55428 .61845 m .5646 .62122 L .56502 .62386 L .463 .508 0 r
F
.68857 .37162 m .71209 .38072 L .70355 .38374 L .9 .817 0 r
F
.6807 .3751 m .68857 .37162 L .70355 .38374 L .888 .812 0 r
F
.65861 .65856 m .66685 .67115 L .65658 .6674 L .802 .668 0 r
F
.64818 .65547 m .65861 .65856 L .65658 .6674 L .772 .653 0 r
F
.41045 .82595 m .39149 .82153 L .39891 .81949 L .615 .695 0 r
F
.41713 .82372 m .41045 .82595 L .39891 .81949 L .585 .673 0 r
F
.42883 .82919 m .41045 .82595 L .41713 .82372 L .555 .66 0 r
F
.64198 1.0482 m .62091 1.06527 L .6171 1.06044 L 1 .993 0 r
F
.64198 1.0482 m .64671 1.05321 L .62091 1.06527 L F
.78387 .68451 m .78977 .70432 L .77955 .7022 L .978 .792 0 r
F
.78387 .68451 m .7943 .68599 L .78977 .70432 L F
.50518 .59571 m .50414 .59075 L .50715 .5961 L .398 .436 0 r
F
.50518 .59571 m .50116 .59014 L .50414 .59075 L F
.29983 .49054 m .29906 .47027 L .30848 .47498 L 1 .758 0 r
F
.29983 .49054 m .29005 .48655 L .29906 .47027 L F
.52972 .60711 m .53804 .60716 L .5398 .60891 L .42 .473 0 r
F
.52837 .60594 m .53804 .60716 L .52972 .60711 L .418 .472 0 r
F
.57788 .87757 m .56903 .85511 L .56522 .86109 L .86 .072 0 r
F
.57788 .87757 m .58275 .88288 L .56903 .85511 L F
.55351 .61629 m .5646 .62122 L .55428 .61845 L .462 .51 0 r
F
.41117 .54175 m .40789 .52961 L .41668 .53753 L .663 .526 0 r
F
.41117 .54175 m .40188 .53483 L .40789 .52961 L F
.77344 .68296 m .77955 .7022 L .76933 .69998 L .971 .786 0 r
F
.77344 .68296 m .78387 .68451 L .77955 .7022 L F
.33574 .81153 m .31592 .80175 L .32512 .80058 L .785 .766 0 r
F
.34441 .80992 m .33574 .81153 L .32512 .80058 L .768 .756 0 r
F
.65861 .65856 m .66905 .66149 L .66685 .67115 L .802 .668 0 r
F
.66905 .66149 m .67712 .67473 L .66685 .67115 L .828 .683 0 r
F
.4347 .82684 m .42883 .82919 L .41713 .82372 L .522 .631 0 r
F
.44633 .83145 m .42883 .82919 L .4347 .82684 L .486 .606 0 r
F
.60049 .36953 m .60581 .36545 L .6216 .37192 L .767 .789 0 r
F
.58463 .36447 m .60581 .36545 L .60049 .36953 L .751 .794 0 r
F
.70088 1.03023 m .6825 1.04979 L .6769 1.04479 L 1 .918 0 r
F
.70088 1.03023 m .70732 1.03517 L .6825 1.04979 L F
.46064 .57251 m .45605 .56497 L .46424 .57153 L .41 .427 0 r
F
.46064 .57251 m .45186 .56616 L .45605 .56497 L F
.763 .68133 m .76933 .69998 L .75911 .69768 L .964 .779 0 r
F
.763 .68133 m .77344 .68296 L .76933 .69998 L F
.5963 .63352 m .60648 .64164 L .59608 .6379 L .592 .577 0 r
F
.58586 .63038 m .5963 .63352 L .59608 .6379 L .555 .558 0 r
F
.40188 .53483 m .39909 .52155 L .40789 .52961 L .732 .549 0 r
F
.40188 .53483 m .39258 .52791 L .39909 .52155 L F
.67949 .66425 m .68738 .67813 L .67712 .67473 L .852 .697 0 r
F
.66905 .66149 m .67949 .66425 L .67712 .67473 L .828 .683 0 r
F
.60581 .36545 m .62783 .36799 L .6216 .37192 L .794 .804 0 r
F
.42311 1.0972 m .39138 1.09708 L .39536 1.09297 L .831 .866 0 r
F
.42616 1.09298 m .42311 1.0972 L .39536 1.09297 L .814 .859 0 r
F
.45373 1.09519 m .42311 1.0972 L .42616 1.09298 L .838 .879 0 r
F
.2394 .79587 m .21953 .77934 L .22949 .77877 L .903 .811 0 r
F
.24897 .79477 m .2394 .79587 L .22949 .77877 L .895 .806 0 r
F
.49312 .58935 m .48975 .58353 L .49563 .58943 L .391 .42 0 r
F
.49312 .58935 m .48641 .58337 L .48975 .58353 L F
.50715 .5961 m .5072 .59152 L .5092 .5966 L .399 .438 0 r
F
.50715 .5961 m .50414 .59075 L .5072 .59152 L F
.75257 .6796 m .75911 .69768 L .74888 .69527 L .955 .771 0 r
F
.75257 .6796 m .763 .68133 L .75911 .69768 L F
.52837 .60594 m .53601 .60542 L .53804 .60716 L .418 .472 0 r
F
.52686 .60479 m .53601 .60542 L .52837 .60594 L .417 .47 0 r
F
.6574 .36852 m .6807 .3751 L .67285 .3785 L .868 .814 0 r
F
.65031 .37229 m .6574 .36852 L .67285 .3785 L .852 .807 0 r
F
.39149 .82153 m .37226 .81573 L .38036 .81398 L .667 .719 0 r
F
.39891 .81949 m .39149 .82153 L .38036 .81398 L .64 .7 0 r
F
.29757 .80435 m .27776 .79182 L .28738 .79097 L .842 .786 0 r
F
.30674 .80301 m .29757 .80435 L .28738 .79097 L .829 .779 0 r
F
.68993 .66686 m .69764 .68136 L .68738 .67813 L .873 .71 0 r
F
.67949 .66425 m .68993 .66686 L .68738 .67813 L .852 .697 0 r
F
.54249 .61235 m .55232 .61405 L .55351 .61629 L .438 .492 0 r
F
.54129 .61064 m .55232 .61405 L .54249 .61235 L .435 .491 0 r
F
.74213 .67778 m .74888 .69527 L .73864 .69275 L .946 .763 0 r
F
.74213 .67778 m .75257 .6796 L .74888 .69527 L F
.39258 .52791 m .39028 .51349 L .39909 .52155 L .798 .574 0 r
F
.39258 .52791 m .38329 .52108 L .39028 .51349 L F
.70037 .66931 m .7079 .68443 L .69764 .68136 L .892 .722 0 r
F
.68993 .66686 m .70037 .66931 L .69764 .68136 L .873 .71 0 r
F
.29005 .48655 m .28963 .46572 L .29906 .47027 L 1 .769 0 r
F
.29005 .48655 m .28026 .4827 L .28963 .46572 L F
.73169 .67585 m .73864 .69275 L .7284 .69012 L .935 .754 0 r
F
.73169 .67585 m .74213 .67778 L .73864 .69275 L F
.53668 1.08103 m .53757 1.08536 L .51023 1.0893 L .958 .96 0 r
F
.56277 1.07481 m .53757 1.08536 L .53668 1.08103 L 1 1 0 r
F
.56277 1.07481 m .56466 1.07922 L .53757 1.08536 L F
.71081 .67162 m .71815 .68734 L .7079 .68443 L .908 .734 0 r
F
.70037 .66931 m .71081 .67162 L .7079 .68443 L .892 .722 0 r
F
.72125 .6738 m .7284 .69012 L .71815 .68734 L .922 .744 0 r
F
.72125 .6738 m .73169 .67585 L .7284 .69012 L F
.71081 .67162 m .72125 .6738 L .71815 .68734 L .908 .734 0 r
F
.39138 1.09708 m .35885 1.09477 L .36374 1.09084 L .829 .857 0 r
F
.39536 1.09297 m .39138 1.09708 L .36374 1.09084 L .815 .851 0 r
F
.5092 .5966 m .51033 .59244 L .51128 .59721 L .401 .441 0 r
F
.5092 .5966 m .5072 .59152 L .51033 .59244 L F
.58839 1.06632 m .56466 1.07922 L .56277 1.07481 L 1 1 0 r
F
.58839 1.06632 m .59125 1.07088 L .56466 1.07922 L F
.43902 .39959 m .43363 .41711 L .44916 .38221 L 0 0 0 r
F
.52686 .60479 m .53375 .6037 L .53601 .60542 L .417 .47 0 r
F
.52521 .60366 m .53375 .6037 L .52686 .60479 L .415 .467 0 r
F
.57494 .62391 m .58586 .63038 L .57544 .62716 L .522 .546 0 r
F
.5646 .62122 m .57494 .62391 L .57544 .62716 L .491 .526 0 r
F
.38329 .52108 m .38147 .50558 L .39028 .51349 L .858 .599 0 r
F
.38329 .52108 m .37398 .51442 L .38147 .50558 L F
.45581 1.09093 m .45373 1.09519 L .42616 1.09298 L .819 .87 0 r
F
.4829 1.09112 m .45373 1.09519 L .45581 1.09093 L .854 .896 0 r
F
.60676 .63654 m .6169 .64529 L .60648 .64164 L .628 .596 0 r
F
.5963 .63352 m .60676 .63654 L .60648 .64164 L .592 .577 0 r
F
.56463 .36478 m .56797 .36061 L .58463 .36447 L .689 .771 0 r
F
.54841 .36214 m .56797 .36061 L .56463 .36478 L .656 .761 0 r
F
.51128 .59721 m .5135 .59349 L .51338 .59791 L .402 .445 0 r
F
.51128 .59721 m .51033 .59244 L .5135 .59349 L F
.45186 .56616 m .44785 .55806 L .45605 .56497 L .418 .424 0 r
F
.45186 .56616 m .44307 .5595 L .44785 .55806 L F
.47243 .5778 m .46835 .57103 L .47586 .57736 L .392 .408 0 r
F
.47243 .5778 m .46424 .57153 L .46835 .57103 L F
.52521 .60366 m .53128 .60202 L .53375 .6037 L .415 .467 0 r
F
.52344 .60256 m .53128 .60202 L .52521 .60366 L .413 .465 0 r
F
.48335 .58348 m .47968 .57728 L .48641 .58337 L .387 .408 0 r
F
.48335 .58348 m .47586 .57736 L .47968 .57728 L F
.50033 .84 m .4992 .8419 L .48674 .83934 L .265 .208 0 r
F
.51192 .84273 m .4992 .8419 L .50033 .84 L .165 .117 0 r
F
.51192 .84273 m .51181 .84424 L .4992 .8419 L F
.51034 1.08501 m .51023 1.0893 L .4829 1.09112 L .883 .919 0 r
F
.53668 1.08103 m .51023 1.0893 L .51034 1.08501 L .958 .96 0 r
F
.37398 .51442 m .37265 .49793 L .38147 .50558 L .91 .624 0 r
F
.37398 .51442 m .36467 .50799 L .37265 .49793 L F
.45134 .82908 m .44633 .83145 L .4347 .82684 L .457 .572 0 r
F
.46269 .83299 m .44633 .83145 L .45134 .82908 L .434 .527 0 r
F
.49563 .58943 m .49334 .58394 L .49832 .5897 L .388 .416 0 r
F
.49563 .58943 m .48975 .58353 L .49334 .58394 L F
.28026 .4827 m .28017 .46131 L .28963 .46572 L 1 .779 0 r
F
.28026 .4827 m .27045 .47898 L .28017 .46131 L F
.51338 .59791 m .51666 .59467 L .51548 .59869 L .404 .449 0 r
F
.51338 .59791 m .5135 .59349 L .51666 .59467 L F
.52344 .60256 m .52861 .6004 L .53128 .60202 L .413 .465 0 r
F
.52156 .6015 m .52861 .6004 L .52344 .60256 L .412 .463 0 r
F
.55351 .61629 m .56365 .61847 L .5646 .62122 L .462 .51 0 r
F
.55232 .61405 m .56365 .61847 L .55351 .61629 L .459 .51 0 r
F
.48888 .83719 m .48674 .83934 L .47453 .8364 L .333 .33 0 r
F
.50033 .84 m .48674 .83934 L .48888 .83719 L .265 .208 0 r
F
.54129 .61064 m .55073 .61175 L .55232 .61405 L .435 .491 0 r
F
.5398 .60891 m .55073 .61175 L .54129 .61064 L .431 .489 0 r
F
.52352 .84562 m .51181 .84424 L .51192 .84273 L .026 .103 0 r
F
.52352 .84562 m .52444 .84665 L .51181 .84424 L F
.51548 .59869 m .51978 .59596 L .51756 .59956 L .406 .453 0 r
F
.51548 .59869 m .51666 .59467 L .51978 .59596 L F
.52156 .6015 m .52579 .59884 L .52861 .6004 L .412 .463 0 r
F
.51959 .6005 m .52579 .59884 L .52156 .6015 L .41 .46 0 r
F
.56365 .61847 m .57494 .62391 L .5646 .62122 L .489 .529 0 r
F
.61328 1.05567 m .59125 1.07088 L .58839 1.06632 L 1 1 0 r
F
.61328 1.05567 m .6171 1.06044 L .59125 1.07088 L F
.73782 .37122 m .76202 .38407 L .75287 .38676 L .942 .827 0 r
F
.72922 .37445 m .73782 .37122 L .75287 .38676 L .934 .823 0 r
F
.51756 .59956 m .52283 .59735 L .51959 .6005 L .408 .457 0 r
F
.51756 .59956 m .51978 .59596 L .52283 .59735 L F
.51959 .6005 m .52283 .59735 L .52579 .59884 L .41 .46 0 r
F
.36467 .50799 m .36381 .49064 L .37265 .49793 L .953 .649 0 r
F
.36467 .50799 m .35534 .50182 L .36381 .49064 L F
.56135 .86169 m .55221 .85289 L .54931 .85423 L .619 .01 0 r
F
.56135 .86169 m .56522 .86109 L .55221 .85289 L F
.24897 .79477 m .22949 .77877 L .23945 .77826 L .895 .806 0 r
F
.25856 .79372 m .24897 .79477 L .23945 .77826 L .886 .801 0 r
F
.61722 .63944 m .62732 .64882 L .6169 .64529 L .664 .614 0 r
F
.60676 .63654 m .61722 .63944 L .6169 .64529 L .628 .596 0 r
F
.44307 .5595 m .43964 .55072 L .44785 .55806 L .439 .427 0 r
F
.44307 .5595 m .43428 .55252 L .43964 .55072 L F
.37226 .81573 m .35309 .80842 L .3618 .80703 L .71 .734 0 r
F
.38036 .81398 m .37226 .81573 L .3618 .80703 L .687 .719 0 r
F
.5853 .62649 m .5963 .63352 L .58586 .63038 L .555 .565 0 r
F
.57494 .62391 m .5853 .62649 L .58586 .63038 L .522 .546 0 r
F
.27045 .47898 m .2707 .45703 L .28017 .46131 L 1 .788 0 r
F
.27045 .47898 m .26062 .47537 L .2707 .45703 L F
.69647 .36805 m .72065 .37762 L .71209 .38072 L .911 .823 0 r
F
.68857 .37162 m .69647 .36805 L .71209 .38072 L .9 .817 0 r
F
.47766 .83411 m .47453 .8364 L .46269 .83299 L .381 .424 0 r
F
.48888 .83719 m .47453 .8364 L .47766 .83411 L .333 .33 0 r
F
.35534 .50182 m .35496 .48372 L .36381 .49064 L .988 .672 0 r
F
.35534 .50182 m .346 .49594 L .35496 .48372 L F
.34441 .80992 m .32512 .80058 L .33433 .79951 L .768 .756 0 r
F
.35309 .80842 m .34441 .80992 L .33433 .79951 L .749 .745 0 r
F
.66565 1.03459 m .64671 1.05321 L .64198 1.0482 L 1 .954 0 r
F
.66565 1.03459 m .67129 1.03972 L .64671 1.05321 L F
.49832 .5897 m .49714 .58458 L .50116 .59014 L .386 .415 0 r
F
.49832 .5897 m .49334 .58394 L .49714 .58458 L F
.30674 .80301 m .28738 .79097 L .29702 .79021 L .829 .779 0 r
F
.31592 .80175 m .30674 .80301 L .29702 .79021 L .815 .771 0 r
F
.36374 1.09084 m .35885 1.09477 L .33165 1.08652 L .82 .845 0 r
F
.5398 .60891 m .54874 .60943 L .55073 .61175 L .431 .489 0 r
F
.53804 .60716 m .54874 .60943 L .5398 .60891 L .427 .486 0 r
F
.73038 1.01956 m .71375 1.04004 L .70732 1.03517 L 1 .892 0 r
F
.73038 1.01956 m .73761 1.02425 L .71375 1.04004 L F
.53505 .84908 m .52444 .84665 L .52352 .84562 L 0 .08 0 r
F
.53505 .84908 m .53697 .84967 L .52444 .84665 L F
.63408 .36393 m .6574 .36852 L .65031 .37229 L .846 .816 0 r
F
.62783 .36799 m .63408 .36393 L .65031 .37229 L .826 .807 0 r
F
.484 1.08688 m .4829 1.09112 L .45581 1.09093 L .83 .885 0 r
F
.51034 1.08501 m .4829 1.09112 L .484 1.08688 L .883 .919 0 r
F
.46424 .57153 m .46084 .56443 L .46835 .57103 L .388 .393 0 r
F
.46424 .57153 m .45605 .56497 L .46084 .56443 L F
.54841 .36214 m .5507 .35805 L .56797 .36061 L .656 .761 0 r
F
.53179 .36074 m .5507 .35805 L .54841 .36214 L .612 .736 0 r
F
.62769 .6422 m .63774 .65222 L .62732 .64882 L .699 .631 0 r
F
.61722 .63944 m .62769 .6422 L .62732 .64882 L .664 .614 0 r
F
.48641 .58337 m .48386 .57756 L .48975 .58353 L .378 .397 0 r
F
.48641 .58337 m .47968 .57728 L .48386 .57756 L F
.43428 .55252 m .43143 .54288 L .43964 .55072 L .478 .436 0 r
F
.43428 .55252 m .42548 .54518 L .43143 .54288 L F
.55232 .61405 m .56217 .61563 L .56365 .61847 L .459 .51 0 r
F
.55073 .61175 m .56217 .61563 L .55232 .61405 L .453 .509 0 r
F
.58463 .36447 m .58899 .36019 L .60581 .36545 L .751 .794 0 r
F
.56797 .36061 m .58899 .36019 L .58463 .36447 L .732 .798 0 r
F
.69441 1.02519 m .6769 1.04479 L .67129 1.03972 L 1 .916 0 r
F
.69441 1.02519 m .70088 1.03023 L .6769 1.04479 L F
.346 .49594 m .34609 .47718 L .35496 .48372 L 1 .693 0 r
F
.346 .49594 m .33664 .49034 L .34609 .47718 L F
.26062 .47537 m .26122 .45286 L .2707 .45703 L 1 .796 0 r
F
.26062 .47537 m .25079 .47185 L .26122 .45286 L F
.41713 .82372 m .39891 .81949 L .40635 .8176 L .585 .673 0 r
F
.42383 .82163 m .41713 .82372 L .40635 .8176 L .554 .648 0 r
F
.4347 .82684 m .41713 .82372 L .42383 .82163 L .522 .631 0 r
F
.47586 .57736 m .47294 .57102 L .47968 .57728 L .376 .386 0 r
F
.47586 .57736 m .46835 .57103 L .47294 .57102 L F
.63722 1.04318 m .6171 1.06044 L .61328 1.05567 L 1 1 0 r
F
.63722 1.04318 m .64198 1.0482 L .6171 1.06044 L F
.50116 .59014 m .50111 .58545 L .50414 .59075 L .386 .416 0 r
F
.50116 .59014 m .49714 .58458 L .50111 .58545 L F
.57381 .62053 m .5853 .62649 L .57494 .62391 L .519 .549 0 r
F
.56365 .61847 m .57381 .62053 L .57494 .62391 L .489 .529 0 r
F
.66452 .36465 m .68857 .37162 L .6807 .3751 L .883 .821 0 r
F
.6574 .36852 m .66452 .36465 L .6807 .3751 L .868 .814 0 r
F
.53804 .60716 m .54639 .60711 L .54874 .60943 L .427 .486 0 r
F
.53601 .60542 m .54639 .60711 L .53804 .60716 L .424 .483 0 r
F
.25856 .79372 m .23945 .77826 L .24943 .77781 L .886 .801 0 r
F
.26815 .79274 m .25856 .79372 L .24943 .77781 L .877 .795 0 r
F
.59567 .62894 m .60676 .63654 L .5963 .63352 L .59 .585 0 r
F
.5853 .62649 m .59567 .62894 L .5963 .63352 L .555 .565 0 r
F
.63817 .64482 m .64818 .65547 L .63774 .65222 L .731 .648 0 r
F
.62769 .6422 m .63817 .64482 L .63774 .65222 L .699 .631 0 r
F
.39891 .81949 m .38036 .81398 L .38848 .81236 L .64 .7 0 r
F
.40635 .8176 m .39891 .81949 L .38848 .81236 L .611 .681 0 r
F
.42548 .54518 m .42321 .5345 L .43143 .54288 L .536 .453 0 r
F
.42548 .54518 m .41668 .53753 L .42321 .5345 L F
.56217 .61563 m .57381 .62053 L .56365 .61847 L .484 .53 0 r
F
.46679 .83069 m .46269 .83299 L .45134 .82908 L .414 .492 0 r
F
.47766 .83411 m .46269 .83299 L .46679 .83069 L .381 .424 0 r
F
.46505 .37072 m .47933 .36374 L .48141 .36509 L .393 .152 0 r
F
.44916 .38221 m .46189 .37143 L .46505 .37072 L .48 .15 0 r
F
.61114 .36121 m .63408 .36393 L .62783 .36799 L .819 .816 0 r
F
.60581 .36545 m .61114 .36121 L .62783 .36799 L .794 .804 0 r
F
.53179 .36074 m .533 .35688 L .5507 .35805 L .612 .736 0 r
F
.51496 .36064 m .533 .35688 L .53179 .36074 L .556 .676 0 r
F
.33664 .49034 m .3372 .47098 L .34609 .47718 L 1 .713 0 r
F
.33664 .49034 m .32727 .48499 L .3372 .47098 L F
.44059 .82465 m .4347 .82684 L .42383 .82163 L .491 .602 0 r
F
.45134 .82908 m .4347 .82684 L .44059 .82465 L .457 .572 0 r
F
.74644 .36792 m .7712 .38133 L .76202 .38407 L .95 .83 0 r
F
.73782 .37122 m .74644 .36792 L .76202 .38407 L .942 .827 0 r
F
.58899 .36019 m .61114 .36121 L .60581 .36545 L .783 .812 0 r
F
.25079 .47185 m .25171 .44878 L .26122 .45286 L 1 .803 0 r
F
.25079 .47185 m .24094 .46842 L .25171 .44878 L F
.42616 1.09298 m .39536 1.09297 L .39935 1.08892 L .814 .859 0 r
F
.42922 1.08883 m .42616 1.09298 L .39935 1.08892 L .796 .851 0 r
F
.45581 1.09093 m .42616 1.09298 L .42922 1.08883 L .819 .87 0 r
F
.50414 .59075 m .5052 .58651 L .5072 .59152 L .387 .42 0 r
F
.50414 .59075 m .50111 .58545 L .5052 .58651 L F
.45605 .56497 m .45331 .55746 L .46084 .56443 L .386 .379 0 r
F
.45605 .56497 m .44785 .55806 L .45331 .55746 L F
.48141 .36509 m .49712 .35939 L .49811 .362 L .466 .272 0 r
F
.48141 .36509 m .47933 .36374 L .49712 .35939 L F
.53601 .60542 m .54369 .60481 L .54639 .60711 L .424 .483 0 r
F
.53375 .6037 m .54369 .60481 L .53601 .60542 L .421 .479 0 r
F
.41668 .53753 m .415 .52559 L .42321 .5345 L .613 .477 0 r
F
.41668 .53753 m .40789 .52961 L .415 .52559 L F
.64866 .64727 m .65861 .65856 L .64818 .65547 L .761 .663 0 r
F
.63817 .64482 m .64866 .64727 L .64818 .65547 L .731 .648 0 r
F
.48975 .58353 m .48835 .57816 L .49334 .58394 L .372 .389 0 r
F
.48975 .58353 m .48386 .57756 L .48835 .57816 L F
.43363 .41711 m .44493 .3855 L .44916 .38221 L 1 .986 0 r
F
.55073 .61175 m .56018 .61274 L .56217 .61563 L .453 .509 0 r
F
.54874 .60943 m .56018 .61274 L .55073 .61175 L .447 .506 0 r
F
.51496 .36064 m .51508 .35725 L .533 .35688 L .556 .676 0 r
F
.49811 .362 m .51508 .35725 L .51496 .36064 L .511 .54 0 r
F
.39536 1.09297 m .36374 1.09084 L .36864 1.08695 L .815 .851 0 r
F
.39935 1.08892 m .39536 1.09297 L .36864 1.08695 L .8 .844 0 r
F
.31592 .80175 m .29702 .79021 L .30667 .78952 L .815 .771 0 r
F
.32512 .80058 m .31592 .80175 L .30667 .78952 L .8 .762 0 r
F
.49811 .362 m .49712 .35939 L .51508 .35725 L .511 .54 0 r
F
.54638 .85364 m .54931 .85423 L .53697 .84967 L .315 0 0 r
F
.53578 1.07685 m .53668 1.08103 L .51034 1.08501 L .933 .953 0 r
F
.56089 1.07056 m .53668 1.08103 L .53578 1.07685 L 1 1 0 r
F
.56089 1.07056 m .56277 1.07481 L .53668 1.08103 L F
.60606 .63126 m .61722 .63944 L .60676 .63654 L .624 .604 0 r
F
.59567 .62894 m .60606 .63126 L .60676 .63654 L .59 .585 0 r
F
.40789 .52961 m .4068 .51625 L .415 .52559 L .701 .505 0 r
F
.40789 .52961 m .39909 .52155 L .4068 .51625 L F
.58552 1.06191 m .56277 1.07481 L .56089 1.07056 L 1 1 0 r
F
.58552 1.06191 m .58839 1.06632 L .56277 1.07481 L F
.32727 .48499 m .32829 .46508 L .3372 .47098 L 1 .731 0 r
F
.32727 .48499 m .31789 .47988 L .32829 .46508 L F
.5072 .59152 m .50939 .58776 L .51033 .59244 L .39 .425 0 r
F
.5072 .59152 m .5052 .58651 L .50939 .58776 L F
.53375 .6037 m .54067 .60255 L .54369 .60481 L .421 .479 0 r
F
.53128 .60202 m .54067 .60255 L .53375 .6037 L .417 .475 0 r
F
.35309 .80842 m .33433 .79951 L .34356 .79854 L .749 .745 0 r
F
.3618 .80703 m .35309 .80842 L .34356 .79854 L .728 .732 0 r
F
.70438 .36439 m .72922 .37445 L .72065 .37762 L .922 .827 0 r
F
.69647 .36805 m .70438 .36439 L .72065 .37762 L .911 .823 0 r
F
.45791 1.08675 m .45581 1.09093 L .42922 1.08883 L .795 .859 0 r
F
.484 1.08688 m .45581 1.09093 L .45791 1.08675 L .83 .885 0 r
F
.65915 .64957 m .66905 .66149 L .65861 .65856 L .788 .678 0 r
F
.64866 .64727 m .65915 .64957 L .65861 .65856 L .761 .663 0 r
F
.38036 .81398 m .3618 .80703 L .37052 .80576 L .687 .719 0 r
F
.38848 .81236 m .38036 .81398 L .37052 .80576 L .662 .703 0 r
F
.58399 .62246 m .59567 .62894 L .5853 .62649 L .551 .57 0 r
F
.57381 .62053 m .58399 .62246 L .5853 .62649 L .519 .549 0 r
F
.26815 .79274 m .24943 .77781 L .25941 .77743 L .877 .795 0 r
F
.27776 .79182 m .26815 .79274 L .25941 .77743 L .867 .789 0 r
F
.24094 .46842 m .24219 .44478 L .25171 .44878 L 1 .809 0 r
F
.24094 .46842 m .23108 .46507 L .24219 .44478 L F
.39909 .52155 m .39859 .50672 L .4068 .51625 L .79 .537 0 r
F
.39909 .52155 m .39028 .51349 L .39859 .50672 L F
.46835 .57103 m .46618 .56454 L .47294 .57102 L .364 .359 0 r
F
.46835 .57103 m .46084 .56443 L .46618 .56454 L F
.47968 .57728 m .47795 .57148 L .48386 .57756 L .362 .366 0 r
F
.47968 .57728 m .47294 .57102 L .47795 .57148 L F
.72314 1.01478 m .70732 1.03517 L .70088 1.03023 L 1 .888 0 r
F
.72314 1.01478 m .73038 1.01956 L .70732 1.03517 L F
.51045 1.08087 m .51034 1.08501 L .484 1.08688 L .854 .906 0 r
F
.53578 1.07685 m .51034 1.08501 L .51045 1.08087 L .933 .953 0 r
F
.51033 .59244 m .51361 .58917 L .5135 .59349 L .393 .432 0 r
F
.51033 .59244 m .50939 .58776 L .51361 .58917 L F
.53128 .60202 m .53737 .60035 L .54067 .60255 L .417 .475 0 r
F
.52861 .6004 m .53737 .60035 L .53128 .60202 L .414 .47 0 r
F
.60945 1.05098 m .58839 1.06632 L .58552 1.06191 L 1 1 0 r
F
.60945 1.05098 m .61328 1.05567 L .58839 1.06632 L F
.56797 .36061 m .57132 .35624 L .58899 .36019 L .732 .798 0 r
F
.5507 .35805 m .57132 .35624 L .56797 .36061 L .711 .799 0 r
F
.44785 .55806 m .44577 .55002 L .45331 .55746 L .39 .369 0 r
F
.44785 .55806 m .43964 .55072 L .44577 .55002 L F
.56217 .61563 m .57205 .61707 L .57381 .62053 L .484 .53 0 r
F
.56018 .61274 m .57205 .61707 L .56217 .61563 L .477 .529 0 r
F
.45638 .82687 m .45134 .82908 L .44059 .82465 L .439 .539 0 r
F
.46679 .83069 m .45134 .82908 L .45638 .82687 L .414 .492 0 r
F
.65915 .64957 m .66966 .65171 L .66905 .66149 L .788 .678 0 r
F
.66966 .65171 m .67949 .66425 L .66905 .66149 L .812 .692 0 r
F
.66 1.02936 m .64198 1.0482 L .63722 1.04318 L 1 .955 0 r
F
.66 1.02936 m .66565 1.03459 L .64198 1.0482 L F
.49334 .58394 m .4931 .57906 L .49714 .58458 L .369 .386 0 r
F
.49334 .58394 m .48835 .57816 L .4931 .57906 L F
.39028 .51349 m .39037 .49725 L .39859 .50672 L .871 .569 0 r
F
.39028 .51349 m .38147 .50558 L .39037 .49725 L F
.31789 .47988 m .31936 .45945 L .32829 .46508 L 1 .747 0 r
F
.31789 .47988 m .30848 .47498 L .31936 .45945 L F
.57205 .61707 m .58399 .62246 L .57381 .62053 L .512 .551 0 r
F
.54874 .60943 m .55771 .60984 L .56018 .61274 L .447 .506 0 r
F
.54639 .60711 m .55771 .60984 L .54874 .60943 L .44 .503 0 r
F
.5135 .59349 m .51783 .59074 L .51666 .59467 L .396 .439 0 r
F
.5135 .59349 m .51361 .58917 L .51783 .59074 L F
.52861 .6004 m .53381 .59823 L .53737 .60035 L .414 .47 0 r
F
.52579 .59884 m .53381 .59823 L .52861 .6004 L .411 .465 0 r
F
.61646 .63343 m .62769 .6422 L .61722 .63944 L .658 .623 0 r
F
.60606 .63126 m .61646 .63343 L .61722 .63944 L .624 .604 0 r
F
.64035 .35975 m .66452 .36465 L .6574 .36852 L .865 .825 0 r
F
.63408 .36393 m .64035 .35975 L .6574 .36852 L .846 .816 0 r
F
.36374 1.09084 m .33165 1.08652 L .33741 1.08286 L .82 .845 0 r
F
.36864 1.08695 m .36374 1.09084 L .33741 1.08286 L .806 .839 0 r
F
.68793 1.02004 m .67129 1.03972 L .66565 1.03459 L 1 .913 0 r
F
.68793 1.02004 m .69441 1.02519 L .67129 1.03972 L F
.23108 .46507 m .23266 .44085 L .24219 .44478 L 1 .815 0 r
F
.23108 .46507 m .2212 .46178 L .23266 .44085 L F
.51666 .59467 m .52201 .59243 L .51978 .59596 L .4 .446 0 r
F
.51666 .59467 m .51783 .59074 L .52201 .59243 L F
.52579 .59884 m .53004 .59619 L .53381 .59823 L .411 .465 0 r
F
.52283 .59735 m .53004 .59619 L .52579 .59884 L .407 .459 0 r
F
.75508 .36456 m .78039 .37853 L .7712 .38133 L .957 .833 0 r
F
.74644 .36792 m .75508 .36456 L .7712 .38133 L .95 .83 0 r
F
.68016 .65369 m .68993 .66686 L .67949 .66425 L .834 .705 0 r
F
.66966 .65171 m .68016 .65369 L .67949 .66425 L .812 .692 0 r
F
.38147 .50558 m .38215 .48811 L .39037 .49725 L .939 .601 0 r
F
.38147 .50558 m .37265 .49793 L .38215 .48811 L F
.50147 .83801 m .50033 .84 L .48888 .83719 L .259 .214 0 r
F
.51203 .84094 m .50033 .84 L .50147 .83801 L .178 .12 0 r
F
.51203 .84094 m .51192 .84273 L .50033 .84 L F
.51978 .59596 m .52609 .59426 L .52283 .59735 L .404 .453 0 r
F
.51978 .59596 m .52201 .59243 L .52609 .59426 L F
.52283 .59735 m .52609 .59426 L .53004 .59619 L .407 .459 0 r
F
.67165 .36067 m .69647 .36805 L .68857 .37162 L .897 .827 0 r
F
.66452 .36465 m .67165 .36067 L .68857 .37162 L .883 .821 0 r
F
.49103 .83504 m .48888 .83719 L .47766 .83411 L .319 .315 0 r
F
.50147 .83801 m .48888 .83719 L .49103 .83504 L .259 .214 0 r
F
.32512 .80058 m .30667 .78952 L .31633 .78893 L .8 .762 0 r
F
.33433 .79951 m .32512 .80058 L .31633 .78893 L .783 .752 0 r
F
.69068 .65553 m .70037 .66931 L .68993 .66686 L .854 .717 0 r
F
.68016 .65369 m .69068 .65553 L .68993 .66686 L .834 .705 0 r
F
.27776 .79182 m .25941 .77743 L .26941 .77711 L .867 .789 0 r
F
.28738 .79097 m .27776 .79182 L .26941 .77711 L .855 .782 0 r
F
.59419 .62424 m .60606 .63126 L .59567 .62894 L .584 .591 0 r
F
.58399 .62246 m .59419 .62424 L .59567 .62894 L .551 .57 0 r
F
.43964 .55072 m .43823 .54196 L .44577 .55002 L .403 .367 0 r
F
.43964 .55072 m .43143 .54288 L .43823 .54196 L F
.52261 .84404 m .51192 .84273 L .51203 .84094 L .077 .105 0 r
F
.52261 .84404 m .52352 .84562 L .51192 .84273 L F
.30848 .47498 m .3104 .45405 L .31936 .45945 L 1 .761 0 r
F
.30848 .47498 m .29906 .47027 L .3104 .45405 L F
.48511 1.08276 m .484 1.08688 L .45791 1.08675 L .801 .87 0 r
F
.51045 1.08087 m .484 1.08688 L .48511 1.08276 L .854 .906 0 r
F
.63245 1.03814 m .61328 1.05567 L .60945 1.05098 L 1 1 0 r
F
.63245 1.03814 m .63722 1.04318 L .61328 1.05567 L F
.42383 .82163 m .40635 .8176 L .41382 .81586 L .554 .648 0 r
F
.43055 .81971 m .42383 .82163 L .41382 .81586 L .523 .622 0 r
F
.44059 .82465 m .42383 .82163 L .43055 .81971 L .491 .602 0 r
F
.37265 .49793 m .3739 .47948 L .38215 .48811 L .993 .631 0 r
F
.37265 .49793 m .36381 .49064 L .3739 .47948 L F
.40635 .8176 m .38848 .81236 L .39662 .81088 L .611 .681 0 r
F
.41382 .81586 m .40635 .8176 L .39662 .81088 L .582 .659 0 r
F
.49714 .58458 m .49806 .58023 L .50111 .58545 L .369 .388 0 r
F
.49714 .58458 m .4931 .57906 L .49806 .58023 L F
.54639 .60711 m .55477 .60695 L .55771 .60984 L .44 .503 0 r
F
.54369 .60481 m .55477 .60695 L .54639 .60711 L .433 .498 0 r
F
.573 .87225 m .56522 .86109 L .56135 .86169 L .644 .029 0 r
F
.573 .87225 m .57788 .87757 L .56522 .86109 L F
.48082 .8319 m .47766 .83411 L .46679 .83069 L .364 .398 0 r
F
.49103 .83504 m .47766 .83411 L .48082 .8319 L .319 .315 0 r
F
.62688 .63544 m .63817 .64482 L .62769 .6422 L .69 .64 0 r
F
.61646 .63343 m .62688 .63544 L .62769 .6422 L .658 .623 0 r
F
.7012 .65723 m .71081 .67162 L .70037 .66931 L .872 .729 0 r
F
.69068 .65553 m .7012 .65723 L .70037 .66931 L .854 .717 0 r
F
.46084 .56443 m .45941 .55775 L .46618 .56454 L .351 .329 0 r
F
.46084 .56443 m .45331 .55746 L .45941 .55775 L F
.48386 .57756 m .48333 .57237 L .48835 .57816 L .351 .353 0 r
F
.48386 .57756 m .47795 .57148 L .48333 .57237 L F
.58899 .36019 m .59336 .35574 L .61114 .36121 L .783 .812 0 r
F
.57132 .35624 m .59336 .35574 L .58899 .36019 L .773 .821 0 r
F
.56018 .61274 m .56967 .61358 L .57205 .61707 L .477 .529 0 r
F
.55771 .60984 m .56967 .61358 L .56018 .61274 L .468 .526 0 r
F
.5507 .35805 m .55299 .35372 L .57132 .35624 L .711 .799 0 r
F
.533 .35688 m .55299 .35372 L .5507 .35805 L .686 .792 0 r
F
.3618 .80703 m .34356 .79854 L .35281 .79769 L .728 .732 0 r
F
.37052 .80576 m .3618 .80703 L .35281 .79769 L .706 .719 0 r
F
.6165 .35683 m .64035 .35975 L .63408 .36393 L .842 .827 0 r
F
.61114 .36121 m .6165 .35683 L .63408 .36393 L .819 .816 0 r
F
.71232 .36066 m .73782 .37122 L .72922 .37445 L .931 .831 0 r
F
.70438 .36439 m .71232 .36066 L .72922 .37445 L .922 .827 0 r
F
.71172 .6588 m .72125 .6738 L .71081 .67162 L .887 .739 0 r
F
.7012 .65723 m .71172 .6588 L .71081 .67162 L .872 .729 0 r
F
.36381 .49064 m .36564 .4714 L .3739 .47948 L 1 .661 0 r
F
.36381 .49064 m .35496 .48372 L .36564 .4714 L F
.55743 .85971 m .54931 .85423 L .54638 .85364 L .426 0 0 r
F
.54451 .85216 m .54638 .85364 L .54343 .85165 L 0 .058 0 r
F
.55446 .85771 m .55908 .86028 L .54931 .85423 L .426 0 0 r
F
.55349 .85644 m .54906 .85469 L .54451 .85216 L 0 .058 0 r
F
.54906 .85469 m .54638 .85364 L .54451 .85216 L F
.55743 .85971 m .56135 .86169 L .55908 .86028 L .426 0 0 r
F
.55743 .85971 m .55908 .86028 L .55446 .85771 L F
.47294 .57102 m .47202 .56528 L .47795 .57148 L .341 .328 0 r
F
.47294 .57102 m .46618 .56454 L .47202 .56528 L F
.43143 .54288 m .43069 .53311 L .43823 .54196 L .442 .377 0 r
F
.43143 .54288 m .42321 .5345 L .43069 .53311 L F
.58194 .61837 m .59419 .62424 L .58399 .62246 L .543 .572 0 r
F
.57205 .61707 m .58194 .61837 L .58399 .62246 L .512 .551 0 r
F
.44651 .82262 m .44059 .82465 L .43055 .81971 L .463 .572 0 r
F
.45638 .82687 m .44059 .82465 L .44651 .82262 L .439 .539 0 r
F
.29906 .47027 m .30143 .44884 L .3104 .45405 L 1 .774 0 r
F
.29906 .47027 m .28963 .46572 L .30143 .44884 L F
.59336 .35574 m .6165 .35683 L .61114 .36121 L .813 .827 0 r
F
.21953 .77934 m .20959 .77995 L .20186 .76084 L .923 .812 0 r
F
.72224 .66025 m .73169 .67585 L .72125 .6738 L .901 .749 0 r
F
.71172 .6588 m .72224 .66025 L .72125 .6738 L .887 .739 0 r
F
.53311 .84753 m .52352 .84562 L .52261 .84404 L 0 .09 0 r
F
.53311 .84753 m .53505 .84908 L .52352 .84562 L F
.38848 .81236 m .37052 .80576 L .37926 .80463 L .662 .703 0 r
F
.39662 .81088 m .38848 .81236 L .37926 .80463 L .635 .685 0 r
F
.71587 1.00989 m .70088 1.03023 L .69441 1.02519 L 1 .883 0 r
F
.71587 1.00989 m .72314 1.01478 L .70088 1.03023 L F
.56967 .61358 m .58194 .61837 L .57205 .61707 L .503 .55 0 r
F
.54369 .60481 m .5514 .60411 L .55477 .60695 L .433 .498 0 r
F
.54067 .60255 m .5514 .60411 L .54369 .60481 L .427 .492 0 r
F
.50111 .58545 m .50319 .58163 L .5052 .58651 L .371 .394 0 r
F
.50111 .58545 m .49806 .58023 L .50319 .58163 L F
.42922 1.08883 m .39935 1.08892 L .40336 1.08494 L .796 .851 0 r
F
.43229 1.08477 m .42922 1.08883 L .40336 1.08494 L .774 .84 0 r
F
.45791 1.08675 m .42922 1.08883 L .43229 1.08477 L .795 .859 0 r
F
.47091 .8285 m .46679 .83069 L .45638 .82687 L .397 .462 0 r
F
.48082 .8319 m .46679 .83069 L .47091 .8285 L .364 .398 0 r
F
.39935 1.08892 m .36864 1.08695 L .37355 1.08312 L .8 .844 0 r
F
.40336 1.08494 m .39935 1.08892 L .37355 1.08312 L .782 .836 0 r
F
.63731 .6373 m .64866 .64727 L .63817 .64482 L .72 .657 0 r
F
.62688 .63544 m .63731 .6373 L .63817 .64482 L .69 .64 0 r
F
.73277 .66158 m .74213 .67778 L .73169 .67585 L .914 .758 0 r
F
.72224 .66025 m .73277 .66158 L .73169 .67585 L .901 .749 0 r
F
.60441 .62587 m .61646 .63343 L .60606 .63126 L .617 .61 0 r
F
.59419 .62424 m .60441 .62587 L .60606 .63126 L .584 .591 0 r
F
.28738 .79097 m .26941 .77711 L .27941 .77687 L .855 .782 0 r
F
.29702 .79021 m .28738 .79097 L .27941 .77687 L .843 .775 0 r
F
.75508 .36456 m .76374 .36115 L .78039 .37853 L .957 .833 0 r
F
.35496 .48372 m .35736 .46387 L .36564 .4714 L 1 .688 0 r
F
.35496 .48372 m .34609 .47718 L .35736 .46387 L F
.7433 .6628 m .75257 .6796 L .74213 .67778 L .925 .766 0 r
F
.73277 .66158 m .7433 .6628 L .74213 .67778 L .914 .758 0 r
F
.42321 .5345 m .42316 .52334 L .43069 .53311 L .521 .401 0 r
F
.42321 .5345 m .415 .52559 L .42316 .52334 L F
.533 .35688 m .53422 .35274 L .55299 .35372 L .686 .792 0 r
F
.51508 .35725 m .53422 .35274 L .533 .35688 L .657 .772 0 r
F
.33433 .79951 m .31633 .78893 L .32601 .78844 L .783 .752 0 r
F
.34356 .79854 m .33433 .79951 L .32601 .78844 L .765 .742 0 r
F
.75384 .66393 m .763 .68133 L .75257 .6796 L .935 .774 0 r
F
.7433 .6628 m .75384 .66393 L .75257 .6796 L .925 .766 0 r
F
.55899 1.06653 m .56089 1.07056 L .53578 1.07685 L 1 1 0 r
F
.58264 1.05769 m .56089 1.07056 L .55899 1.06653 L F
.58264 1.05769 m .58552 1.06191 L .56089 1.07056 L F
.33741 1.08286 m .33165 1.08652 L .30606 1.07657 L .815 .835 0 r
F
.53489 1.07288 m .53578 1.07685 L .51045 1.08087 L .899 .938 0 r
F
.55899 1.06653 m .53578 1.07685 L .53489 1.07288 L 1 1 0 r
F
.54067 .60255 m .54762 .60133 L .5514 .60411 L .427 .492 0 r
F
.53737 .60035 m .54762 .60133 L .54067 .60255 L .421 .485 0 r
F
.45331 .55746 m .45262 .55053 L .45941 .55775 L .341 .3 0 r
F
.45331 .55746 m .44577 .55002 L .45262 .55053 L F
.65433 1.02403 m .63722 1.04318 L .63245 1.03814 L 1 .955 0 r
F
.65433 1.02403 m .66 1.02936 L .63722 1.04318 L F
.48835 .57816 m .48904 .57361 L .4931 .57906 L .345 .348 0 r
F
.48835 .57816 m .48333 .57237 L .48904 .57361 L F
.5052 .58651 m .50843 .58322 L .50939 .58776 L .374 .403 0 r
F
.5052 .58651 m .50319 .58163 L .50843 .58322 L F
.55771 .60984 m .5667 .61009 L .56967 .61358 L .468 .526 0 r
F
.55477 .60695 m .5667 .61009 L .55771 .60984 L .457 .522 0 r
F
.68142 1.01475 m .66565 1.03459 L .66 1.02936 L 1 .908 0 r
F
.68142 1.01475 m .68793 1.02004 L .66565 1.03459 L F
.76437 .66496 m .77344 .68296 L .763 .68133 L .943 .781 0 r
F
.75384 .66393 m .76437 .66496 L .763 .68133 L .935 .774 0 r
F
.28963 .46572 m .29244 .4438 L .30143 .44884 L 1 .785 0 r
F
.28963 .46572 m .28017 .46131 L .29244 .4438 L F
.46001 1.08269 m .45791 1.08675 L .43229 1.08477 L .768 .845 0 r
F
.48511 1.08276 m .45791 1.08675 L .46001 1.08269 L .801 .87 0 r
F
.21953 .77934 m .20186 .76084 L .21211 .76084 L .923 .812 0 r
F
.22949 .77877 m .21953 .77934 L .21211 .76084 L .916 .808 0 r
F
.75146 1.00314 m .73761 1.02425 L .73038 1.01956 L 1 .869 0 r
F
.75146 1.00314 m .75942 1.00755 L .73761 1.02425 L F
.77491 .66591 m .78387 .68451 L .77344 .68296 L .951 .787 0 r
F
.76437 .66496 m .77491 .66591 L .77344 .68296 L .943 .781 0 r
F
.64664 .35545 m .67165 .36067 L .66452 .36465 L .881 .832 0 r
F
.64035 .35975 m .64664 .35545 L .66452 .36465 L .865 .825 0 r
F
.64775 .63899 m .65915 .64957 L .64866 .64727 L .748 .672 0 r
F
.63731 .6373 m .64775 .63899 L .64866 .64727 L .72 .657 0 r
F
.67881 .3566 m .70438 .36439 L .69647 .36805 L .909 .832 0 r
F
.67165 .36067 m .67881 .3566 L .69647 .36805 L .897 .827 0 r
F
.415 .52559 m .41563 .51261 L .42316 .52334 L .634 .438 0 r
F
.415 .52559 m .4068 .51625 L .41563 .51261 L F
.6056 1.0464 m .58552 1.06191 L .58264 1.05769 L 1 1 0 r
F
.6056 1.0464 m .60945 1.05098 L .58552 1.06191 L F
.78546 .66679 m .7943 .68599 L .78387 .68451 L .958 .793 0 r
F
.77491 .66591 m .78546 .66679 L .78387 .68451 L .951 .787 0 r
F
.51508 .35725 m .5152 .35347 L .53422 .35274 L .657 .772 0 r
F
.49712 .35939 m .5152 .35347 L .51508 .35725 L .625 .723 0 r
F
.34609 .47718 m .34905 .45683 L .35736 .46387 L 1 .712 0 r
F
.34609 .47718 m .3372 .47098 L .34905 .45683 L F
.796 .66759 m .80473 .68739 L .7943 .68599 L .964 .799 0 r
F
.78546 .66679 m .796 .66759 L .7943 .68599 L .958 .793 0 r
F
.36864 1.08695 m .33741 1.08286 L .34319 1.07924 L .806 .839 0 r
F
.37355 1.08312 m .36864 1.08695 L .34319 1.07924 L .792 .832 0 r
F
.51056 1.0769 m .51045 1.08087 L .48511 1.08276 L .817 .886 0 r
F
.53489 1.07288 m .51045 1.08087 L .51056 1.0769 L .899 .938 0 r
F
.80655 .66833 m .81516 .68873 L .80473 .68739 L .97 .804 0 r
F
.796 .66759 m .80655 .66833 L .80473 .68739 L .964 .799 0 r
F
.81709 .66901 m .82558 .69001 L .81516 .68873 L .975 .809 0 r
F
.80655 .66833 m .81709 .66901 L .81516 .68873 L .97 .804 0 r
F
.53737 .60035 m .54349 .59864 L .54762 .60133 L .421 .485 0 r
F
.53381 .59823 m .54349 .59864 L .53737 .60035 L .416 .477 0 r
F
.49712 .35939 m .49614 .35621 L .5152 .35347 L .625 .723 0 r
F
.47933 .36374 m .49614 .35621 L .49712 .35939 L .608 .635 0 r
F
.50939 .58776 m .51372 .585 L .51361 .58917 L .38 .413 0 r
F
.50939 .58776 m .50843 .58322 L .51372 .585 L F
.81709 .66901 m .82764 .66964 L .82558 .69001 L .975 .809 0 r
F
.47933 .36374 m .47725 .36143 L .49614 .35621 L .608 .635 0 r
F
.46189 .37143 m .47725 .36143 L .47933 .36374 L .671 .586 0 r
F
.46143 .82478 m .45638 .82687 L .44651 .82262 L .423 .508 0 r
F
.47091 .8285 m .45638 .82687 L .46143 .82478 L .397 .462 0 r
F
.57132 .35624 m .57468 .35167 L .59336 .35574 L .773 .821 0 r
F
.55299 .35372 m .57468 .35167 L .57132 .35624 L .763 .829 0 r
F
.59186 .6195 m .60441 .62587 L .59419 .62424 L .575 .594 0 r
F
.58194 .61837 m .59186 .6195 L .59419 .62424 L .543 .572 0 r
F
.4068 .51625 m .40811 .50116 L .41563 .51261 L .763 .482 0 r
F
.4068 .51625 m .39859 .50672 L .40811 .50116 L F
.61464 .62733 m .62688 .63544 L .61646 .63343 L .649 .629 0 r
F
.60441 .62587 m .61464 .62733 L .61646 .63343 L .617 .61 0 r
F
.46189 .37143 m .45873 .37017 L .47725 .36143 L .671 .586 0 r
F
.44493 .3855 m .45873 .37017 L .46189 .37143 L 1 .964 0 r
F
.54343 .85165 m .53505 .84908 L .53311 .84753 L 0 .073 0 r
F
.54343 .85165 m .54638 .85364 L .53505 .84908 L F
.37052 .80576 m .35281 .79769 L .36207 .79696 L .706 .719 0 r
F
.37926 .80463 m .37052 .80576 L .36207 .79696 L .682 .703 0 r
F
.29702 .79021 m .27941 .77687 L .28943 .77671 L .843 .775 0 r
F
.30667 .78952 m .29702 .79021 L .28943 .77671 L .83 .767 0 r
F
.47795 .57148 m .47831 .56655 L .48333 .57237 L .323 .306 0 r
F
.47795 .57148 m .47202 .56528 L .47831 .56655 L F
.46618 .56454 m .46608 .55889 L .47202 .56528 L .315 .282 0 r
F
.46618 .56454 m .45941 .55775 L .46608 .55889 L F
.72028 .35686 m .74644 .36792 L .73782 .37122 L .94 .835 0 r
F
.71232 .36066 m .72028 .35686 L .73782 .37122 L .931 .831 0 r
F
.56967 .61358 m .57918 .61426 L .58194 .61837 L .503 .55 0 r
F
.5667 .61009 m .57918 .61426 L .56967 .61358 L .492 .548 0 r
F
.28017 .46131 m .28343 .4389 L .29244 .4438 L 1 .795 0 r
F
.28017 .46131 m .2707 .45703 L .28343 .4389 L F
.41382 .81586 m .39662 .81088 L .40478 .80956 L .582 .659 0 r
F
.42131 .81427 m .41382 .81586 L .40478 .80956 L .552 .635 0 r
F
.43055 .81971 m .41382 .81586 L .42131 .81427 L .523 .622 0 r
F
.22949 .77877 m .21211 .76084 L .22237 .7609 L .916 .808 0 r
F
.23945 .77826 m .22949 .77877 L .22237 .7609 L .908 .803 0 r
F
.53381 .59823 m .53903 .59605 L .54349 .59864 L .416 .477 0 r
F
.53004 .59619 m .53903 .59605 L .53381 .59823 L .41 .468 0 r
F
.6582 .64053 m .66966 .65171 L .65915 .64957 L .774 .687 0 r
F
.64775 .63899 m .6582 .64053 L .65915 .64957 L .748 .672 0 r
F
.51361 .58917 m .51901 .58693 L .51783 .59074 L .385 .425 0 r
F
.51361 .58917 m .51372 .585 L .51901 .58693 L F
.39859 .50672 m .4006 .48953 L .40811 .50116 L .882 .528 0 r
F
.39859 .50672 m .39037 .49725 L .4006 .48953 L F
.57918 .61426 m .59186 .6195 L .58194 .61837 L .532 .573 0 r
F
.62767 1.03308 m .60945 1.05098 L .6056 1.0464 L 1 1 0 r
F
.62767 1.03308 m .63245 1.03814 L .60945 1.05098 L F
.55477 .60695 m .56318 .60665 L .5667 .61009 L .457 .522 0 r
F
.5514 .60411 m .56318 .60665 L .55477 .60695 L .446 .515 0 r
F
.43729 .81794 m .43055 .81971 L .42131 .81427 L .493 .595 0 r
F
.44651 .82262 m .43055 .81971 L .43729 .81794 L .463 .572 0 r
F
.4931 .57906 m .49501 .57514 L .49806 .58023 L .344 .35 0 r
F
.4931 .57906 m .48904 .57361 L .49501 .57514 L F
.44577 .55002 m .44583 .54268 L .45262 .55053 L .338 .275 0 r
F
.44577 .55002 m .43823 .54196 L .44583 .54268 L F
.3372 .47098 m .34071 .45019 L .34905 .45683 L 1 .734 0 r
F
.3372 .47098 m .32829 .46508 L .34071 .45019 L F
.70859 1.00487 m .69441 1.02519 L .68793 1.02004 L 1 .877 0 r
F
.70859 1.00487 m .71587 1.00989 L .69441 1.02519 L F
.53004 .59619 m .53431 .59358 L .53903 .59605 L .41 .468 0 r
F
.52609 .59426 m .53431 .59358 L .53004 .59619 L .404 .458 0 r
F
.51783 .59074 m .52424 .58901 L .52201 .59243 L .392 .436 0 r
F
.51783 .59074 m .51901 .58693 L .52424 .58901 L F
.39037 .49725 m .39307 .47832 L .4006 .48953 L .978 .571 0 r
F
.39037 .49725 m .38215 .48811 L .39307 .47832 L F
.52609 .59426 m .52936 .59123 L .53431 .59358 L .404 .458 0 r
F
.52201 .59243 m .52936 .59123 L .52609 .59426 L .398 .447 0 r
F
.34356 .79854 m .32601 .78844 L .3357 .78805 L .765 .742 0 r
F
.35281 .79769 m .34356 .79854 L .3357 .78805 L .745 .73 0 r
F
.52201 .59243 m .52424 .58901 L .52936 .59123 L .398 .447 0 r
F
.39662 .81088 m .37926 .80463 L .38802 .80363 L .635 .685 0 r
F
.40478 .80956 m .39662 .81088 L .38802 .80363 L .607 .665 0 r
F
.48622 1.07879 m .48511 1.08276 L .46001 1.08269 L .765 .85 0 r
F
.51056 1.0769 m .48511 1.08276 L .48622 1.07879 L .817 .886 0 r
F
.62187 .35231 m .64664 .35545 L .64035 .35975 L .863 .836 0 r
F
.6165 .35683 m .62187 .35231 L .64035 .35975 L .842 .827 0 r
F
.44493 .3855 m .44073 .3843 L .45873 .37017 L 1 .964 0 r
F
.42852 .41104 m .44073 .3843 L .44493 .3855 L 1 1 0 r
F
.43363 .41711 m .42852 .41104 L .44493 .3855 L 1 .986 0 r
F
.4932 .83283 m .49103 .83504 L .48082 .8319 L .314 .313 0 r
F
.50261 .83583 m .49103 .83504 L .4932 .83283 L .265 .234 0 r
F
.50261 .83583 m .50147 .83801 L .49103 .83504 L F
.6582 .64053 m .66866 .64191 L .66966 .65171 L .774 .687 0 r
F
.66866 .64191 m .68016 .65369 L .66966 .65171 L .797 .7 0 r
F
.51214 .83881 m .50147 .83801 L .50261 .83583 L .205 .156 0 r
F
.51214 .83881 m .51203 .84094 L .50147 .83801 L F
.59336 .35574 m .59776 .35112 L .6165 .35683 L .813 .827 0 r
F
.57468 .35167 m .59776 .35112 L .59336 .35574 L .809 .839 0 r
F
.62489 .62863 m .63731 .6373 L .62688 .63544 L .679 .647 0 r
F
.61464 .62733 m .62489 .62863 L .62688 .63544 L .649 .629 0 r
F
.38215 .48811 m .38552 .46797 L .39307 .47832 L 1 .613 0 r
F
.38215 .48811 m .3739 .47948 L .38552 .46797 L F
.2707 .45703 m .2744 .43411 L .28343 .4389 L 1 .803 0 r
F
.2707 .45703 m .26122 .45286 L .2744 .43411 L F
.74347 .99864 m .73038 1.01956 L .72314 1.01478 L 1 .863 0 r
F
.74347 .99864 m .75146 1.00314 L .73038 1.01956 L F
.23945 .77826 m .22237 .7609 L .23264 .76101 L .908 .803 0 r
F
.24943 .77781 m .23945 .77826 L .23264 .76101 L .9 .798 0 r
F
.59776 .35112 m .62187 .35231 L .6165 .35683 L .84 .84 0 r
F
.48398 .8297 m .48082 .8319 L .47091 .8285 L .353 .382 0 r
F
.4932 .83283 m .48082 .8319 L .48398 .8297 L .314 .313 0 r
F
.30667 .78952 m .28943 .77671 L .29945 .77664 L .83 .767 0 r
F
.31633 .78893 m .30667 .78952 L .29945 .77664 L .815 .758 0 r
F
.6018 .62046 m .61464 .62733 L .60441 .62587 L .606 .614 0 r
F
.59186 .6195 m .6018 .62046 L .60441 .62587 L .575 .594 0 r
F
.45245 .82073 m .44651 .82262 L .43729 .81794 L .442 .542 0 r
F
.46143 .82478 m .44651 .82262 L .45245 .82073 L .423 .508 0 r
F
.32829 .46508 m .33236 .4439 L .34071 .45019 L 1 .753 0 r
F
.32829 .46508 m .31936 .45945 L .33236 .4439 L F
.5514 .60411 m .55913 .60328 L .56318 .60665 L .446 .515 0 r
F
.54762 .60133 m .55913 .60328 L .5514 .60411 L .435 .507 0 r
F
.52168 .84187 m .51203 .84094 L .51214 .83881 L .137 .107 0 r
F
.52168 .84187 m .52261 .84404 L .51203 .84094 L F
.55299 .35372 m .5553 .34914 L .57468 .35167 L .763 .829 0 r
F
.53422 .35274 m .5553 .34914 L .55299 .35372 L .755 .837 0 r
F
.67489 1.00928 m .66 1.02936 L .65433 1.02403 L 1 .901 0 r
F
.67489 1.00928 m .68142 1.01475 L .66 1.02936 L F
.49806 .58023 m .50117 .57691 L .50319 .58163 L .347 .359 0 r
F
.49806 .58023 m .49501 .57514 L .50117 .57691 L F
.40336 1.08494 m .37355 1.08312 L .37848 1.07936 L .782 .836 0 r
F
.40739 1.08103 m .40336 1.08494 L .37848 1.07936 L .762 .826 0 r
F
.43229 1.08477 m .40336 1.08494 L .40739 1.08103 L .774 .84 0 r
F
.43537 1.0808 m .43229 1.08477 L .40739 1.08103 L .749 .826 0 r
F
.46001 1.08269 m .43229 1.08477 L .43537 1.0808 L .768 .845 0 r
F
.43823 .54196 m .43904 .53392 L .44583 .54268 L .349 .263 0 r
F
.43823 .54196 m .43069 .53311 L .43904 .53392 L F
.67913 .64315 m .69068 .65553 L .68016 .65369 L .818 .712 0 r
F
.66866 .64191 m .67913 .64315 L .68016 .65369 L .797 .7 0 r
F
.5667 .61009 m .57573 .61018 L .57918 .61426 L .492 .548 0 r
F
.56318 .60665 m .57573 .61018 L .5667 .61009 L .479 .543 0 r
F
.33741 1.08286 m .30606 1.07657 L .31265 1.07322 L .815 .835 0 r
F
.34319 1.07924 m .33741 1.08286 L .31265 1.07322 L .803 .83 0 r
F
.68598 .35244 m .71232 .36066 L .70438 .36439 L .92 .837 0 r
F
.67881 .3566 m .68598 .35244 L .70438 .36439 L .909 .832 0 r
F
.64864 1.01854 m .63245 1.03814 L .62767 1.03308 L 1 .952 0 r
F
.64864 1.01854 m .65433 1.02403 L .63245 1.03814 L F
.48333 .57237 m .48497 .56824 L .48904 .57361 L .312 .296 0 r
F
.48333 .57237 m .47831 .56655 L .48497 .56824 L F
.41882 .45327 m .42852 .41104 L .43363 .41711 L 1 .612 0 r
F
.42459 .47626 m .43363 .41711 L .43842 .44691 L 1 .517 0 r
F
.42459 .47626 m .41882 .45327 L .43363 .41711 L F
.59593 .91024 m .5879 .91382 L .58275 .88288 L .226 .039 0 r
F
.59 .89349 m .59593 .91024 L .58275 .88288 L 0 0 0 r
F
.59 .89349 m .58275 .88288 L .57788 .87757 L F
.3739 .47948 m .37795 .45858 L .38552 .46797 L 1 .651 0 r
F
.3739 .47948 m .36564 .4714 L .37795 .45858 L F
.45941 .55775 m .46012 .55222 L .46608 .55889 L .285 .229 0 r
F
.45941 .55775 m .45262 .55053 L .46012 .55222 L F
.5681 .8669 m .573 .87225 L .56135 .86169 L 0 .018 0 r
F
.5681 .8669 m .56135 .86169 L .55743 .85971 L F
.65295 .35105 m .67881 .3566 L .67165 .36067 L .896 .838 0 r
F
.64664 .35545 m .65295 .35105 L .67165 .36067 L .881 .832 0 r
F
.37926 .80463 m .36207 .79696 L .37136 .79636 L .682 .703 0 r
F
.38802 .80363 m .37926 .80463 L .37136 .79636 L .656 .687 0 r
F
.47505 .82638 m .47091 .8285 L .46143 .82478 L .383 .438 0 r
F
.48398 .8297 m .47091 .8285 L .47505 .82638 L .353 .382 0 r
F
.72826 .35299 m .75508 .36456 L .74644 .36792 L .948 .838 0 r
F
.72028 .35686 m .72826 .35299 L .74644 .36792 L .94 .835 0 r
F
.24943 .77781 m .23264 .76101 L .24291 .76119 L .9 .798 0 r
F
.25941 .77743 m .24943 .77781 L .24291 .76119 L .891 .792 0 r
F
.26122 .45286 m .26536 .42942 L .2744 .43411 L 1 .811 0 r
F
.26122 .45286 m .25171 .44878 L .26536 .42942 L F
.58871 .61477 m .6018 .62046 L .59186 .6195 L .562 .594 0 r
F
.57918 .61426 m .58871 .61477 L .59186 .6195 L .532 .573 0 r
F
.63516 .62976 m .64775 .63899 L .63731 .6373 L .708 .664 0 r
F
.62489 .62863 m .63516 .62976 L .63731 .6373 L .679 .647 0 r
F
.47202 .56528 m .47326 .56072 L .47831 .56655 L .285 .247 0 r
F
.47202 .56528 m .46608 .55889 L .47326 .56072 L F
.57573 .61018 m .58871 .61477 L .57918 .61426 L .519 .57 0 r
F
.55349 .85644 m .55743 .85971 L .54638 .85364 L 0 .058 0 r
F
.55709 1.06278 m .55899 1.06653 L .53489 1.07288 L .982 .986 0 r
F
.57975 1.05374 m .55899 1.06653 L .55709 1.06278 L 1 1 0 r
F
.57975 1.05374 m .58264 1.05769 L .55899 1.06653 L F
.54762 .60133 m .5546 .60001 L .55913 .60328 L .435 .507 0 r
F
.54349 .59864 m .5546 .60001 L .54762 .60133 L .427 .497 0 r
F
.68961 .64425 m .7012 .65723 L .69068 .65553 L .837 .724 0 r
F
.67913 .64315 m .68961 .64425 L .69068 .65553 L .818 .712 0 r
F
.35281 .79769 m .3357 .78805 L .3454 .78778 L .745 .73 0 r
F
.36207 .79696 m .35281 .79769 L .3454 .78778 L .724 .717 0 r
F
.53115 .84515 m .52261 .84404 L .52168 .84187 L .069 .097 0 r
F
.53115 .84515 m .53311 .84753 L .52261 .84404 L F
.46212 1.07875 m .46001 1.08269 L .43537 1.0808 L .736 .826 0 r
F
.48622 1.07879 m .46001 1.08269 L .46212 1.07875 L .765 .85 0 r
F
.53399 1.06915 m .53489 1.07288 L .51056 1.0769 L .851 .91 0 r
F
.55709 1.06278 m .53489 1.07288 L .53399 1.06915 L .982 .986 0 r
F
.37355 1.08312 m .34319 1.07924 L .34899 1.07568 L .792 .832 0 r
F
.37848 1.07936 m .37355 1.08312 L .34899 1.07568 L .776 .824 0 r
F
.31936 .45945 m .32398 .43788 L .33236 .4439 L 1 .769 0 r
F
.31936 .45945 m .3104 .45405 L .32398 .43788 L F
.50319 .58163 m .50747 .57888 L .50843 .58322 L .354 .372 0 r
F
.50319 .58163 m .50117 .57691 L .50747 .57888 L F
.43069 .53311 m .43226 .52382 L .43904 .53392 L .382 .274 0 r
F
.43069 .53311 m .42316 .52334 L .43226 .52382 L F
.70128 .99969 m .68793 1.02004 L .68142 1.01475 L 1 .869 0 r
F
.70128 .99969 m .70859 1.00487 L .68793 1.02004 L F
.36564 .4714 m .37034 .45006 L .37795 .45858 L 1 .686 0 r
F
.36564 .4714 m .35736 .46387 L .37034 .45006 L F
.60175 1.04199 m .58264 1.05769 L .57975 1.05374 L 1 1 0 r
F
.60175 1.04199 m .6056 1.0464 L .58264 1.05769 L F
.53422 .35274 m .53544 .34829 L .5553 .34914 L .755 .837 0 r
F
.5152 .35347 m .53544 .34829 L .53422 .35274 L .752 .844 0 r
F
.31633 .78893 m .29945 .77664 L .30948 .77667 L .815 .758 0 r
F
.32601 .78844 m .31633 .78893 L .30948 .77667 L .799 .749 0 r
F
.42131 .81427 m .40478 .80956 L .41296 .80839 L .552 .635 0 r
F
.42882 .81285 m .42131 .81427 L .41296 .80839 L .522 .61 0 r
F
.43729 .81794 m .42131 .81427 L .42882 .81285 L .493 .595 0 r
F
.61176 .62125 m .62489 .62863 L .61464 .62733 L .637 .634 0 r
F
.6018 .62046 m .61176 .62125 L .61464 .62733 L .606 .614 0 r
F
.70009 .64522 m .71172 .6588 L .7012 .65723 L .854 .735 0 r
F
.68961 .64425 m .70009 .64522 L .7012 .65723 L .837 .724 0 r
F
.73547 .99402 m .72314 1.01478 L .71587 1.00989 L 1 .857 0 r
F
.73547 .99402 m .74347 .99864 L .72314 1.01478 L F
.51066 1.07313 m .51056 1.0769 L .48622 1.07879 L .768 .856 0 r
F
.53399 1.06915 m .51056 1.0769 L .51066 1.07313 L .851 .91 0 r
F
.40478 .80956 m .38802 .80363 L .3968 .80278 L .607 .665 0 r
F
.41296 .80839 m .40478 .80956 L .3968 .80278 L .578 .643 0 r
F
.54349 .59864 m .54963 .59686 L .5546 .60001 L .427 .497 0 r
F
.53903 .59605 m .54963 .59686 L .54349 .59864 L .419 .486 0 r
F
.56318 .60665 m .57162 .60619 L .57573 .61018 L .479 .543 0 r
F
.55913 .60328 m .57162 .60619 L .56318 .60665 L .464 .535 0 r
F
.25941 .77743 m .24291 .76119 L .25319 .76143 L .891 .792 0 r
F
.26941 .77711 m .25941 .77743 L .25319 .76143 L .882 .786 0 r
F
.42316 .52334 m .42549 .51186 L .43226 .52382 L .486 .319 0 r
F
.42316 .52334 m .41563 .51261 L .42549 .51186 L F
.4665 .82282 m .46143 .82478 L .45245 .82073 L .408 .481 0 r
F
.47505 .82638 m .46143 .82478 L .4665 .82282 L .383 .438 0 r
F
.25171 .44878 m .25629 .42483 L .26536 .42942 L 1 .817 0 r
F
.25171 .44878 m .24219 .44478 L .25629 .42483 L F
.57468 .35167 m .57806 .34691 L .59776 .35112 L .809 .839 0 r
F
.5553 .34914 m .57806 .34691 L .57468 .35167 L .808 .853 0 r
F
.62287 1.02801 m .6056 1.0464 L .60175 1.04199 L 1 1 0 r
F
.62287 1.02801 m .62767 1.03308 L .6056 1.0464 L F
.50843 .58322 m .51384 .581 L .51372 .585 L .362 .389 0 r
F
.50843 .58322 m .50747 .57888 L .51384 .581 L F
.48904 .57361 m .49194 .57024 L .49501 .57514 L .31 .299 0 r
F
.48904 .57361 m .48497 .56824 L .49194 .57024 L F
.64544 .63073 m .6582 .64053 L .64775 .63899 L .735 .679 0 r
F
.63516 .62976 m .64544 .63073 L .64775 .63899 L .708 .664 0 r
F
.44406 .81633 m .43729 .81794 L .42882 .81285 L .466 .567 0 r
F
.45245 .82073 m .43729 .81794 L .44406 .81633 L .442 .542 0 r
F
.5152 .35347 m .51531 .34931 L .53544 .34829 L .752 .844 0 r
F
.49614 .35621 m .51531 .34931 L .5152 .35347 L .766 .851 0 r
F
.35736 .46387 m .36271 .44226 L .37034 .45006 L 1 .717 0 r
F
.35736 .46387 m .34905 .45683 L .36271 .44226 L F
.45262 .55053 m .45416 .54514 L .46012 .55222 L .251 .171 0 r
F
.45262 .55053 m .44583 .54268 L .45416 .54514 L F
.3104 .45405 m .31558 .4321 L .32398 .43788 L 1 .783 0 r
F
.3104 .45405 m .30143 .44884 L .31558 .4321 L F
.71059 .64606 m .72224 .66025 L .71172 .6588 L .869 .745 0 r
F
.70009 .64522 m .71059 .64606 L .71172 .6588 L .854 .735 0 r
F
.62726 .34767 m .65295 .35105 L .64664 .35545 L .881 .844 0 r
F
.62187 .35231 m .62726 .34767 L .64664 .35545 L .863 .836 0 r
F
.41563 .51261 m .41876 .49781 L .42549 .51186 L .685 .392 0 r
F
.41563 .51261 m .40811 .50116 L .41876 .49781 L F
.53903 .59605 m .54427 .59385 L .54963 .59686 L .419 .486 0 r
F
.53431 .59358 m .54427 .59385 L .53903 .59605 L .41 .472 0 r
F
.49614 .35621 m .49515 .35247 L .51531 .34931 L .766 .851 0 r
F
.47725 .36143 m .49515 .35247 L .49614 .35621 L .827 .876 0 r
F
.66834 1.0036 m .65433 1.02403 L .64864 1.01854 L 1 .891 0 r
F
.66834 1.0036 m .67489 1.00928 L .65433 1.02403 L F
.51372 .585 m .5202 .58328 L .51901 .58693 L .371 .406 0 r
F
.51372 .585 m .51384 .581 L .5202 .58328 L F
.40811 .50116 m .41204 .4825 L .41876 .49781 L .892 .471 0 r
F
.40811 .50116 m .4006 .48953 L .41204 .4825 L F
.47725 .36143 m .47516 .35824 L .49515 .35247 L .827 .876 0 r
F
.45873 .37017 m .47516 .35824 L .47725 .36143 L 1 .98 0 r
F
.54047 .84869 m .53311 .84753 L .53115 .84515 L .014 .087 0 r
F
.54047 .84869 m .54343 .85165 L .53311 .84753 L F
.4006 .48953 m .40532 .46782 L .41204 .4825 L 1 .538 0 r
F
.4006 .48953 m .39307 .47832 L .40532 .46782 L F
.69318 .3482 m .72028 .35686 L .71232 .36066 L .93 .841 0 r
F
.68598 .35244 m .69318 .3482 L .71232 .36066 L .92 .837 0 r
F
.59827 .6151 m .61176 .62125 L .6018 .62046 L .593 .616 0 r
F
.58871 .61477 m .59827 .6151 L .6018 .62046 L .562 .594 0 r
F
.48734 1.07499 m .48622 1.07879 L .46212 1.07875 L .722 .822 0 r
F
.51066 1.07313 m .48622 1.07879 L .48734 1.07499 L .768 .856 0 r
F
.53431 .59358 m .53859 .59098 L .54427 .59385 L .41 .472 0 r
F
.52936 .59123 m .53859 .59098 L .53431 .59358 L .401 .457 0 r
F
.73625 .34906 m .76374 .36115 L .75508 .36456 L .955 .841 0 r
F
.72826 .35299 m .73625 .34906 L .75508 .36456 L .948 .838 0 r
F
.57573 .61018 m .58477 .6101 L .58871 .61477 L .519 .57 0 r
F
.57162 .60619 m .58477 .6101 L .57573 .61018 L .503 .565 0 r
F
.38802 .80363 m .37136 .79636 L .38066 .7959 L .656 .687 0 r
F
.3968 .80278 m .38802 .80363 L .38066 .7959 L .629 .668 0 r
F
.26941 .77711 m .25319 .76143 L .26347 .76175 L .882 .786 0 r
F
.27941 .77687 m .26941 .77711 L .26347 .76175 L .871 .779 0 r
F
.72109 .64679 m .73277 .66158 L .72224 .66025 L .883 .754 0 r
F
.71059 .64606 m .72109 .64679 L .72224 .66025 L .869 .745 0 r
F
.32601 .78844 m .30948 .77667 L .31953 .7768 L .799 .749 0 r
F
.3357 .78805 m .32601 .78844 L .31953 .7768 L .782 .738 0 r
F
.36207 .79696 m .3454 .78778 L .35512 .78764 L .724 .717 0 r
F
.37136 .79636 m .36207 .79696 L .35512 .78764 L .701 .702 0 r
F
.51901 .58693 m .52649 .5857 L .52424 .58901 L .381 .424 0 r
F
.51901 .58693 m .5202 .58328 L .52649 .5857 L F
.59776 .35112 m .60216 .34634 L .62187 .35231 L .84 .84 0 r
F
.57806 .34691 m .60216 .34634 L .59776 .35112 L .841 .854 0 r
F
.45873 .37017 m .45556 .36741 L .47516 .35824 L 1 .98 0 r
F
.44073 .3843 m .45556 .36741 L .45873 .37017 L 1 1 0 r
F
.24219 .44478 m .2472 .4203 L .25629 .42483 L 1 .823 0 r
F
.24219 .44478 m .23266 .44085 L .2472 .4203 L F
.39307 .47832 m .39857 .45507 L .40532 .46782 L 1 .595 0 r
F
.39307 .47832 m .38552 .46797 L .39857 .45507 L F
.52936 .59123 m .53264 .58826 L .53859 .59098 L .401 .457 0 r
F
.52424 .58901 m .53264 .58826 L .52936 .59123 L .391 .441 0 r
F
.60216 .34634 m .62726 .34767 L .62187 .35231 L .864 .85 0 r
F
.64293 1.01286 m .62767 1.03308 L .62287 1.02801 L 1 .947 0 r
F
.64293 1.01286 m .64864 1.01854 L .62767 1.03308 L F
.42852 .41104 m .42339 .40495 L .44073 .3843 L 1 1 0 r
F
.47831 .56655 m .48088 .56303 L .48497 .56824 L .266 .23 0 r
F
.47831 .56655 m .47326 .56072 L .48088 .56303 L F
.41294 .43775 m .42339 .40495 L .42852 .41104 L 1 .729 0 r
F
.41882 .45327 m .41294 .43775 L .42852 .41104 L 1 .612 0 r
F
.58412 .88221 m .57788 .87757 L .573 .87225 L 0 .009 0 r
F
.58412 .88221 m .59 .89349 L .57788 .87757 L F
.34319 1.07924 m .31265 1.07322 L .31927 1.06993 L .803 .83 0 r
F
.34899 1.07568 m .34319 1.07924 L .31927 1.06993 L .79 .823 0 r
F
.52424 .58901 m .52649 .5857 L .53264 .58826 L .391 .441 0 r
F
.62174 .62187 m .63516 .62976 L .62489 .62863 L .667 .652 0 r
F
.61176 .62125 m .62174 .62187 L .62489 .62863 L .637 .634 0 r
F
.65574 .63155 m .66866 .64191 L .6582 .64053 L .759 .693 0 r
F
.64544 .63073 m .65574 .63155 L .6582 .64053 L .735 .679 0 r
F
.55913 .60328 m .56689 .6023 L .57162 .60619 L .464 .535 0 r
F
.5546 .60001 m .56689 .6023 L .55913 .60328 L .448 .526 0 r
F
.46608 .55889 m .4682 .55486 L .47326 .56072 L .232 .173 0 r
F
.46608 .55889 m .46012 .55222 L .4682 .55486 L F
.58477 .6101 m .59827 .6151 L .58871 .61477 L .547 .593 0 r
F
.65928 .34654 m .68598 .35244 L .67881 .3566 L .909 .843 0 r
F
.65295 .35105 m .65928 .34654 L .67881 .3566 L .896 .838 0 r
F
.34905 .45683 m .35505 .43503 L .36271 .44226 L 1 .743 0 r
F
.34905 .45683 m .34071 .45019 L .35505 .43503 L F
.40739 1.08103 m .37848 1.07936 L .38343 1.07566 L .762 .826 0 r
F
.41142 1.07721 m .40739 1.08103 L .38343 1.07566 L .74 .814 0 r
F
.43537 1.0808 m .40739 1.08103 L .41142 1.07721 L .749 .826 0 r
F
.69395 .99431 m .68142 1.01475 L .67489 1.00928 L 1 .859 0 r
F
.69395 .99431 m .70128 .99969 L .68142 1.01475 L F
.45841 .81899 m .45245 .82073 L .44406 .81633 L .427 .514 0 r
F
.4665 .82282 m .45245 .82073 L .45841 .81899 L .408 .481 0 r
F
.49501 .57514 m .49915 .57244 L .50117 .57691 L .315 .312 0 r
F
.49501 .57514 m .49194 .57024 L .49915 .57244 L F
.7316 .64741 m .7433 .6628 L .73277 .66158 L .895 .762 0 r
F
.72109 .64679 m .7316 .64741 L .73277 .66158 L .883 .754 0 r
F
.43846 1.07694 m .43537 1.0808 L .41142 1.07721 L .721 .81 0 r
F
.46212 1.07875 m .43537 1.0808 L .43846 1.07694 L .736 .826 0 r
F
.30143 .44884 m .30715 .4265 L .31558 .4321 L 1 .795 0 r
F
.30143 .44884 m .29244 .4438 L .30715 .4265 L F
.31265 1.07322 m .30606 1.07657 L .28232 1.06502 L .815 .828 0 r
F
.49537 .83052 m .4932 .83283 L .48398 .8297 L .315 .321 0 r
F
.50376 .83344 m .4932 .83283 L .49537 .83052 L .278 .262 0 r
F
.50376 .83344 m .50261 .83583 L .4932 .83283 L F
.72744 .98926 m .71587 1.00989 L .70859 1.00487 L 1 .849 0 r
F
.72744 .98926 m .73547 .99402 L .71587 1.00989 L F
.38552 .46797 m .39177 .44431 L .39857 .45507 L 1 .648 0 r
F
.38552 .46797 m .37795 .45858 L .39177 .44431 L F
.51225 .83631 m .50261 .83583 L .50376 .83344 L .237 .204 0 r
F
.51225 .83631 m .51214 .83881 L .50261 .83583 L F
.5553 .34914 m .55762 .34435 L .57806 .34691 L .808 .853 0 r
F
.53544 .34829 m .55762 .34435 L .5553 .34914 L .814 .871 0 r
F
.44583 .54268 m .44818 .53737 L .45416 .54514 L .221 .118 0 r
F
.44583 .54268 m .43904 .53392 L .44818 .53737 L F
.48716 .82749 m .48398 .8297 L .47505 .82638 L .347 .374 0 r
F
.49537 .83052 m .48398 .8297 L .48716 .82749 L .315 .321 0 r
F
.44073 .3843 m .43653 .38097 L .45556 .36741 L 1 1 0 r
F
.42339 .40495 m .43653 .38097 L .44073 .3843 L F
.77033 .98604 m .75942 1.00755 L .75146 1.00314 L 1 .85 0 r
F
.77033 .98604 m .77897 .99008 L .75942 1.00755 L F
.27941 .77687 m .26347 .76175 L .27376 .76215 L .871 .779 0 r
F
.28943 .77671 m .27941 .77687 L .27376 .76215 L .859 .771 0 r
F
.74212 .64793 m .75384 .66393 L .7433 .6628 L .907 .77 0 r
F
.7316 .64741 m .74212 .64793 L .7433 .6628 L .895 .762 0 r
F
.37848 1.07936 m .34899 1.07568 L .3548 1.07217 L .776 .824 0 r
F
.38343 1.07566 m .37848 1.07936 L .3548 1.07217 L .758 .815 0 r
F
.52075 .83918 m .51214 .83881 L .51225 .83631 L .194 .153 0 r
F
.52075 .83918 m .52168 .84187 L .51214 .83881 L F
.65574 .63155 m .66605 .63221 L .66866 .64191 L .759 .693 0 r
F
.66605 .63221 m .67913 .64315 L .66866 .64191 L .782 .707 0 r
F
.5546 .60001 m .5616 .59857 L .56689 .6023 L .448 .526 0 r
F
.54963 .59686 m .5616 .59857 L .5546 .60001 L .434 .513 0 r
F
.41296 .80839 m .3968 .80278 L .40561 .80209 L .578 .643 0 r
F
.42117 .80738 m .41296 .80839 L .40561 .80209 L .548 .62 0 r
F
.42882 .81285 m .41296 .80839 L .42117 .80738 L .522 .61 0 r
F
.56319 .86154 m .55743 .85971 L .55349 .85644 L 0 .052 0 r
F
.56319 .86154 m .5681 .8669 L .55743 .85971 L F
.43635 .8116 m .42882 .81285 L .42117 .80738 L .493 .584 0 r
F
.44406 .81633 m .42882 .81285 L .43635 .8116 L .466 .567 0 r
F
.3357 .78805 m .31953 .7768 L .32959 .77704 L .782 .738 0 r
F
.3454 .78778 m .3357 .78805 L .32959 .77704 L .763 .726 0 r
F
.59593 .91024 m .60199 .93495 L .5879 .91382 L .226 .039 0 r
F
.37795 .45858 m .38493 .43506 L .39177 .44431 L 1 .694 0 r
F
.37795 .45858 m .37034 .45006 L .38493 .43506 L F
.55518 1.05938 m .55709 1.06278 L .53399 1.06915 L .922 .951 0 r
F
.57686 1.05016 m .55709 1.06278 L .55518 1.05938 L 1 1 0 r
F
.57686 1.05016 m .57975 1.05374 L .55709 1.06278 L F
.47921 .82431 m .47505 .82638 L .4665 .82282 L .373 .42 0 r
F
.48716 .82749 m .47505 .82638 L .47921 .82431 L .347 .374 0 r
F
.75264 .64836 m .76437 .66496 L .75384 .66393 L .917 .777 0 r
F
.74212 .64793 m .75264 .64836 L .75384 .66393 L .907 .77 0 r
F
.34071 .45019 m .34736 .42821 L .35505 .43503 L 1 .766 0 r
F
.34071 .45019 m .33236 .4439 L .34736 .42821 L F
.46424 1.07496 m .46212 1.07875 L .43846 1.07694 L .699 .802 0 r
F
.48734 1.07499 m .46212 1.07875 L .46424 1.07496 L .722 .822 0 r
F
.59788 1.03784 m .57975 1.05374 L .57686 1.05016 L 1 1 0 r
F
.59788 1.03784 m .60175 1.04199 L .57975 1.05374 L F
.63174 .62231 m .64544 .63073 L .63516 .62976 L .694 .669 0 r
F
.62174 .62187 m .63174 .62231 L .63516 .62976 L .667 .652 0 r
F
.57162 .60619 m .58008 .60556 L .58477 .6101 L .503 .565 0 r
F
.56689 .6023 m .58008 .60556 L .57162 .60619 L .485 .557 0 r
F
.60785 .61525 m .62174 .62187 L .61176 .62125 L .623 .636 0 r
F
.59827 .6151 m .60785 .61525 L .61176 .62125 L .593 .616 0 r
F
.50117 .57691 m .50651 .57478 L .50747 .57888 L .326 .332 0 r
F
.50117 .57691 m .49915 .57244 L .50651 .57478 L F
.53308 1.06573 m .53399 1.06915 L .51066 1.07313 L .783 .862 0 r
F
.55518 1.05938 m .53399 1.06915 L .53308 1.06573 L .922 .951 0 r
F
.29244 .4438 m .29871 .42105 L .30715 .4265 L 1 .806 0 r
F
.29244 .4438 m .28343 .4389 L .29871 .42105 L F
.37136 .79636 m .35512 .78764 L .36485 .78763 L .701 .702 0 r
F
.38066 .7959 m .37136 .79636 L .36485 .78763 L .676 .686 0 r
F
.66177 .99762 m .64864 1.01854 L .64293 1.01286 L 1 .876 0 r
F
.66177 .99762 m .66834 1.0036 L .64864 1.01854 L F
.54953 .85245 m .54343 .85165 L .54047 .84869 L 0 .078 0 r
F
.54953 .85245 m .55349 .85644 L .54343 .85165 L F
.73625 .34906 m .74427 .34508 L .76374 .36115 L .955 .841 0 r
F
.76317 .64871 m .77491 .66591 L .76437 .66496 L .926 .784 0 r
F
.75264 .64836 m .76317 .64871 L .76437 .66496 L .917 .777 0 r
F
.61805 1.02292 m .60175 1.04199 L .59788 1.03784 L 1 1 0 r
F
.61805 1.02292 m .62287 1.02801 L .60175 1.04199 L F
.48497 .56824 m .48886 .56562 L .49194 .57024 L .262 .232 0 r
F
.48497 .56824 m .48088 .56303 L .48886 .56562 L F
.28943 .77671 m .27376 .76215 L .28406 .76264 L .859 .771 0 r
F
.29945 .77664 m .28943 .77671 L .28406 .76264 L .846 .763 0 r
F
.53544 .34829 m .53666 .34357 L .55762 .34435 L .814 .871 0 r
F
.51531 .34931 m .53666 .34357 L .53544 .34829 L .833 .893 0 r
F
.3968 .80278 m .38066 .7959 L .38997 .79559 L .629 .668 0 r
F
.40561 .80209 m .3968 .80278 L .38997 .79559 L .6 .648 0 r
F
.7004 .34388 m .72826 .35299 L .72028 .35686 L .94 .844 0 r
F
.69318 .3482 m .7004 .34388 L .72028 .35686 L .93 .841 0 r
F
.43904 .53392 m .44221 .52836 L .44818 .53737 L .212 .084 0 r
F
.43904 .53392 m .43226 .52382 L .44221 .52836 L F
.45085 .81488 m .44406 .81633 L .43635 .8116 L .443 .539 0 r
F
.45841 .81899 m .44406 .81633 L .45085 .81488 L .427 .514 0 r
F
.52919 .84211 m .52168 .84187 L .52075 .83918 L .154 .117 0 r
F
.52919 .84211 m .53115 .84515 L .52168 .84187 L F
.63267 .3429 m .65928 .34654 L .65295 .35105 L .898 .85 0 r
F
.62726 .34767 m .63267 .3429 L .65295 .35105 L .881 .844 0 r
F
.67637 .63273 m .68961 .64425 L .67913 .64315 L .802 .719 0 r
F
.66605 .63221 m .67637 .63273 L .67913 .64315 L .782 .707 0 r
F
.51077 1.06961 m .51066 1.07313 L .48734 1.07499 L .707 .81 0 r
F
.53308 1.06573 m .51066 1.07313 L .51077 1.06961 L .783 .862 0 r
F
.54963 .59686 m .5558 .59499 L .5616 .59857 L .434 .513 0 r
F
.54427 .59385 m .5558 .59499 L .54963 .59686 L .423 .497 0 r
F
.58477 .6101 m .59384 .60984 L .59827 .6151 L .547 .593 0 r
F
.58008 .60556 m .59384 .60984 L .58477 .6101 L .529 .588 0 r
F
.59384 .60984 m .60785 .61525 L .59827 .6151 L .577 .615 0 r
F
.57806 .34691 m .58144 .34197 L .60216 .34634 L .841 .854 0 r
F
.55762 .34435 m .58144 .34197 L .57806 .34691 L .848 .872 0 r
F
.46012 .55222 m .46313 .54899 L .4682 .55486 L .16 .095 0 r
F
.46012 .55222 m .45416 .54514 L .46313 .54899 L F
.6866 .9887 m .67489 1.00928 L .66834 1.0036 L 1 .845 0 r
F
.6866 .9887 m .69395 .99431 L .67489 1.00928 L F
.77371 .64897 m .78546 .66679 L .77491 .66591 L .934 .79 0 r
F
.76317 .64871 m .77371 .64897 L .77491 .66591 L .926 .784 0 r
F
.47159 .82094 m .4665 .82282 L .45841 .81899 L .395 .458 0 r
F
.47921 .82431 m .4665 .82282 L .47159 .82094 L .373 .42 0 r
F
.7194 .98435 m .70859 1.00487 L .70128 .99969 L 1 .84 0 r
F
.7194 .98435 m .72744 .98926 L .70859 1.00487 L F
.37034 .45006 m .37806 .42684 L .38493 .43506 L 1 .733 0 r
F
.37034 .45006 m .36271 .44226 L .37806 .42684 L F
.76168 .98191 m .75146 1.00314 L .74347 .99864 L 1 .844 0 r
F
.76168 .98191 m .77033 .98604 L .75146 1.00314 L F
.40532 .46782 m .41294 .43775 L .41882 .45327 L 1 .589 0 r
F
.40532 .46782 m .39857 .45507 L .41294 .43775 L F
.41204 .4825 m .40532 .46782 L .41882 .45327 L 1 .511 0 r
F
.50747 .57888 m .51395 .57724 L .51384 .581 L .339 .356 0 r
F
.50747 .57888 m .50651 .57478 L .51395 .57724 L F
.6372 1.00689 m .62287 1.02801 L .61805 1.02292 L 1 .936 0 r
F
.6372 1.00689 m .64293 1.01286 L .62287 1.02801 L F
.42339 .40495 m .41825 .39885 L .43653 .38097 L 1 1 0 r
F
.47326 .56072 m .47678 .55806 L .48088 .56303 L .199 .147 0 r
F
.47326 .56072 m .4682 .55486 L .47678 .55806 L F
.40698 .42677 m .41825 .39885 L .42339 .40495 L 1 .811 0 r
F
.41294 .43775 m .40698 .42677 L .42339 .40495 L 1 .729 0 r
F
.57827 .87352 m .573 .87225 L .5681 .8669 L 0 .037 0 r
F
.57827 .87352 m .58412 .88221 L .573 .87225 L F
.21211 .76084 m .20186 .76084 L .19724 .74105 L .938 .81 0 r
F
.33236 .4439 m .33965 .42173 L .34736 .42821 L 1 .784 0 r
F
.33236 .4439 m .32398 .43788 L .33965 .42173 L F
.39857 .45507 m .40698 .42677 L .41294 .43775 L 1 .662 0 r
F
.39857 .45507 m .39177 .44431 L .40698 .42677 L F
.78425 .64917 m .796 .66759 L .78546 .66679 L .941 .796 0 r
F
.77371 .64897 m .78425 .64917 L .78546 .66679 L .934 .79 0 r
F
.34899 1.07568 m .31927 1.06993 L .3259 1.06668 L .79 .823 0 r
F
.3548 1.07217 m .34899 1.07568 L .3259 1.06668 L .775 .816 0 r
F
.66563 .34193 m .69318 .3482 L .68598 .35244 L .921 .848 0 r
F
.65928 .34654 m .66563 .34193 L .68598 .35244 L .909 .843 0 r
F
.41204 .4825 m .41882 .45327 L .42459 .47626 L 1 .511 0 r
F
.41876 .49781 m .41204 .4825 L .42459 .47626 L .894 .389 0 r
F
.3454 .78778 m .32959 .77704 L .33965 .7774 L .763 .726 0 r
F
.35512 .78764 m .3454 .78778 L .33965 .7774 L .742 .714 0 r
F
.51531 .34931 m .51543 .34477 L .53666 .34357 L .833 .893 0 r
F
.49515 .35247 m .51543 .34477 L .51531 .34931 L .878 .927 0 r
F
.64175 .62259 m .65574 .63155 L .64544 .63073 L .72 .685 0 r
F
.63174 .62231 m .64175 .62259 L .64544 .63073 L .694 .669 0 r
F
.54427 .59385 m .54954 .5916 L .5558 .59499 L .423 .497 0 r
F
.53859 .59098 m .54954 .5916 L .54427 .59385 L .412 .479 0 r
F
.28343 .4389 m .29024 .41572 L .29871 .42105 L 1 .815 0 r
F
.28343 .4389 m .2744 .43411 L .29024 .41572 L F
.31265 1.07322 m .28232 1.06502 L .2897 1.06205 L .815 .828 0 r
F
.31927 1.06993 m .31265 1.07322 L .2897 1.06205 L .804 .822 0 r
F
.43226 .52382 m .43625 .51688 L .44221 .52836 L .261 .087 0 r
F
.43226 .52382 m .42549 .51186 L .43625 .51688 L F
.60658 .34143 m .63267 .3429 L .62726 .34767 L .885 .858 0 r
F
.60216 .34634 m .60658 .34143 L .62726 .34767 L .864 .85 0 r
F
.29945 .77664 m .28406 .76264 L .29436 .76322 L .846 .763 0 r
F
.30948 .77667 m .29945 .77664 L .29436 .76322 L .832 .754 0 r
F
.56689 .6023 m .57468 .60118 L .58008 .60556 L .485 .557 0 r
F
.5616 .59857 m .57468 .60118 L .56689 .6023 L .465 .546 0 r
F
.58144 .34197 m .60658 .34143 L .60216 .34634 L .869 .866 0 r
F
.6867 .63311 m .70009 .64522 L .68961 .64425 L .821 .73 0 r
F
.67637 .63273 m .6867 .63311 L .68961 .64425 L .802 .719 0 r
F
.7948 .6493 m .80655 .66833 L .796 .66759 L .948 .801 0 r
F
.78425 .64917 m .7948 .6493 L .796 .66759 L .941 .796 0 r
F
.51384 .581 m .52139 .57981 L .5202 .58328 L .354 .383 0 r
F
.51384 .581 m .51395 .57724 L .52139 .57981 L F
.48846 1.07139 m .48734 1.07499 L .46424 1.07496 L .671 .783 0 r
F
.51077 1.06961 m .48734 1.07499 L .48846 1.07139 L .707 .81 0 r
F
.41876 .49781 m .42459 .47626 L .43036 .50025 L .894 .389 0 r
F
.42549 .51186 m .41876 .49781 L .43036 .50025 L .419 .189 0 r
F
.61745 .61523 m .63174 .62231 L .62174 .62187 L .652 .655 0 r
F
.60785 .61525 m .61745 .61523 L .62174 .62187 L .623 .636 0 r
F
.49515 .35247 m .49416 .34822 L .51543 .34477 L .878 .927 0 r
F
.47516 .35824 m .49416 .34822 L .49515 .35247 L .98 .985 0 r
F
.41142 1.07721 m .38343 1.07566 L .38839 1.07203 L .74 .814 0 r
F
.41547 1.07348 m .41142 1.07721 L .38839 1.07203 L .716 .799 0 r
F
.43846 1.07694 m .41142 1.07721 L .41547 1.07348 L .721 .81 0 r
F
.21211 .76084 m .19724 .74105 L .2077 .7417 L .938 .81 0 r
F
.22237 .7609 m .21211 .76084 L .2077 .7417 L .931 .806 0 r
F
.42549 .51186 m .43036 .50025 L .43625 .51688 L .419 .189 0 r
F
.53859 .59098 m .5429 .58839 L .54954 .5916 L .412 .479 0 r
F
.53264 .58826 m .5429 .58839 L .53859 .59098 L .399 .458 0 r
F
.39177 .44431 m .40097 .41793 L .40698 .42677 L 1 .725 0 r
F
.39177 .44431 m .38493 .43506 L .40097 .41793 L F
.53748 .84508 m .53115 .84515 L .52919 .84211 L .124 .097 0 r
F
.53748 .84508 m .54047 .84869 L .53115 .84515 L F
.80536 .64936 m .81709 .66901 L .80655 .66833 L .954 .806 0 r
F
.7948 .6493 m .80536 .64936 L .80655 .66833 L .948 .801 0 r
F
.38066 .7959 m .36485 .78763 L .3746 .78777 L .676 .686 0 r
F
.38997 .79559 m .38066 .7959 L .3746 .78777 L .649 .669 0 r
F
.47516 .35824 m .47307 .35431 L .49416 .34822 L .98 .985 0 r
F
.45556 .36741 m .47307 .35431 L .47516 .35824 L 1 1 0 r
F
.46439 .81737 m .45841 .81899 L .45085 .81488 L .414 .489 0 r
F
.47159 .82094 m .45841 .81899 L .46439 .81737 L .395 .458 0 r
F
.5202 .58328 m .52875 .58251 L .52649 .5857 L .37 .409 0 r
F
.5202 .58328 m .52139 .57981 L .52875 .58251 L F
.49194 .57024 m .49711 .5683 L .49915 .57244 L .271 .25 0 r
F
.49194 .57024 m .48886 .56562 L .49711 .5683 L F
.44157 1.0732 m .43846 1.07694 L .41547 1.07348 L .689 .79 0 r
F
.46424 1.07496 m .43846 1.07694 L .44157 1.0732 L .699 .802 0 r
F
.36271 .44226 m .37115 .41933 L .37806 .42684 L 1 .765 0 r
F
.36271 .44226 m .35505 .43503 L .37115 .41933 L F
.53264 .58826 m .53595 .58537 L .5429 .58839 L .399 .458 0 r
F
.52649 .5857 m .53595 .58537 L .53264 .58826 L .385 .434 0 r
F
.42117 .80738 m .40561 .80209 L .41443 .80157 L .548 .62 0 r
F
.4294 .80655 m .42117 .80738 L .41443 .80157 L .518 .595 0 r
F
.43635 .8116 m .42117 .80738 L .4294 .80655 L .493 .584 0 r
F
.52649 .5857 m .52875 .58251 L .53595 .58537 L .385 .434 0 r
F
.45556 .36741 m .45239 .36359 L .47307 .35431 L 1 1 0 r
F
.43653 .38097 m .45239 .36359 L .45556 .36741 L F
.81592 .64937 m .82764 .66964 L .81709 .66901 L .96 .81 0 r
F
.80536 .64936 m .81592 .64937 L .81709 .66901 L .954 .806 0 r
F
.38343 1.07566 m .3548 1.07217 L .36063 1.06873 L .758 .815 0 r
F
.38839 1.07203 m .38343 1.07566 L .36063 1.06873 L .738 .805 0 r
F
.65518 .99124 m .64293 1.01286 L .6372 1.00689 L 1 .855 0 r
F
.65518 .99124 m .66177 .99762 L .64293 1.01286 L F
.69705 .63337 m .71059 .64606 L .70009 .64522 L .838 .741 0 r
F
.6867 .63311 m .69705 .63337 L .70009 .64522 L .821 .73 0 r
F
.22237 .7609 m .2077 .7417 L .21817 .7424 L .931 .806 0 r
F
.23264 .76101 m .22237 .7609 L .21817 .7424 L .924 .801 0 r
F
.40698 .42677 m .40097 .41793 L .41825 .39885 L 1 .811 0 r
F
.44391 .81052 m .43635 .8116 L .4294 .80655 L .466 .557 0 r
F
.45085 .81488 m .43635 .8116 L .44391 .81052 L .443 .539 0 r
F
.32398 .43788 m .33192 .4155 L .33965 .42173 L 1 .8 0 r
F
.32398 .43788 m .31558 .4321 L .33192 .4155 L F
.753 .97766 m .74347 .99864 L .73547 .99402 L 1 .837 0 r
F
.753 .97766 m .76168 .98191 L .74347 .99864 L F
.71133 .97925 m .70128 .99969 L .69395 .99431 L 1 .828 0 r
F
.71133 .97925 m .7194 .98435 L .70128 .99969 L F
.30948 .77667 m .29436 .76322 L .30467 .7639 L .832 .754 0 r
F
.31953 .7768 m .30948 .77667 L .30467 .7639 L .817 .745 0 r
F
.55762 .34435 m .55994 .33934 L .58144 .34197 L .848 .872 0 r
F
.53666 .34357 m .55994 .33934 L .55762 .34435 L .863 .894 0 r
F
.40561 .80209 m .38997 .79559 L .39931 .79545 L .6 .648 0 r
F
.41443 .80157 m .40561 .80209 L .39931 .79545 L .57 .626 0 r
F
.58008 .60556 m .58857 .60476 L .59384 .60984 L .529 .588 0 r
F
.57468 .60118 m .58857 .60476 L .58008 .60556 L .509 .58 0 r
F
.2744 .43411 m .28175 .4105 L .29024 .41572 L 1 .822 0 r
F
.2744 .43411 m .26536 .42942 L .28175 .4105 L F
.81592 .64937 m .82649 .64933 L .82764 .66964 L .96 .81 0 r
F
.65179 .62272 m .66605 .63221 L .65574 .63155 L .744 .699 0 r
F
.64175 .62259 m .65179 .62272 L .65574 .63155 L .72 .685 0 r
F
.67923 .98278 m .66834 1.0036 L .66177 .99762 L 1 .828 0 r
F
.67923 .98278 m .6866 .9887 L .66834 1.0036 L F
.70764 .33949 m .73625 .34906 L .72826 .35299 L .948 .847 0 r
F
.7004 .34388 m .70764 .33949 L .72826 .35299 L .94 .844 0 r
F
.35512 .78764 m .33965 .7774 L .34973 .7779 L .742 .714 0 r
F
.36485 .78763 m .35512 .78764 L .34973 .7779 L .719 .7 0 r
F
.45416 .54514 m .45803 .5431 L .46313 .54899 L .061 .066 0 r
F
.45416 .54514 m .44818 .53737 L .45803 .5431 L F
.49756 .82806 m .49537 .83052 L .48716 .82749 L .322 .333 0 r
F
.50492 .8308 m .49537 .83052 L .49756 .82806 L .296 .292 0 r
F
.50492 .8308 m .50376 .83344 L .49537 .83052 L F
.60294 .60941 m .61745 .61523 L .60785 .61525 L .606 .636 0 r
F
.59384 .60984 m .60294 .60941 L .60785 .61525 L .577 .615 0 r
F
.43653 .38097 m .43233 .37653 L .45239 .36359 L 1 1 0 r
F
.41825 .39885 m .43233 .37653 L .43653 .38097 L F
.5616 .59857 m .56863 .59699 L .57468 .60118 L .465 .546 0 r
F
.5558 .59499 m .56863 .59699 L .5616 .59857 L .445 .532 0 r
F
.51236 .83345 m .50376 .83344 L .50492 .8308 L .268 .251 0 r
F
.51236 .83345 m .51225 .83631 L .50376 .83344 L F
.49036 .82523 m .48716 .82749 L .47921 .82431 L .346 .373 0 r
F
.49756 .82806 m .48716 .82749 L .49036 .82523 L .322 .333 0 r
F
.55826 .85616 m .55349 .85644 L .54953 .85245 L .019 .073 0 r
F
.55826 .85616 m .56319 .86154 L .55349 .85644 L F
.38493 .43506 m .39492 .41017 L .40097 .41793 L 1 .774 0 r
F
.38493 .43506 m .37806 .42684 L .39492 .41017 L F
.58857 .60476 m .60294 .60941 L .59384 .60984 L .557 .611 0 r
F
.23264 .76101 m .21817 .7424 L .22863 .74316 L .924 .801 0 r
F
.24291 .76119 m .23264 .76101 L .22863 .74316 L .917 .795 0 r
F
.46636 1.07132 m .46424 1.07496 L .44157 1.0732 L .656 .771 0 r
F
.48846 1.07139 m .46424 1.07496 L .46636 1.07132 L .671 .783 0 r
F
.57395 1.04711 m .57686 1.05016 L .55518 1.05938 L 1 1 0 r
F
.594 1.03408 m .57686 1.05016 L .57395 1.04711 L F
.594 1.03408 m .59788 1.03784 L .57686 1.05016 L F
.55327 1.05646 m .55518 1.05938 L .53308 1.06573 L .823 .873 0 r
F
.57395 1.04711 m .55518 1.05938 L .55327 1.05646 L 1 1 0 r
F
.63809 .33802 m .66563 .34193 L .65928 .34654 L .912 .856 0 r
F
.63267 .3429 m .63809 .33802 L .65928 .34654 L .898 .85 0 r
F
.70741 .63351 m .72109 .64679 L .71059 .64606 L .853 .75 0 r
F
.69705 .63337 m .70741 .63351 L .71059 .64606 L .838 .741 0 r
F
.61322 1.01781 m .59788 1.03784 L .594 1.03408 L 1 1 0 r
F
.61322 1.01781 m .61805 1.02292 L .59788 1.03784 L F
.48088 .56303 m .48576 .56139 L .48886 .56562 L .192 .148 0 r
F
.48088 .56303 m .47678 .55806 L .48576 .56139 L F
.62707 .61503 m .64175 .62259 L .63174 .62231 L .679 .672 0 r
F
.61745 .61523 m .62707 .61503 L .63174 .62231 L .652 .655 0 r
F
.51982 .83604 m .51225 .83631 L .51236 .83345 L .241 .214 0 r
F
.51982 .83604 m .52075 .83918 L .51225 .83631 L F
.49915 .57244 m .50554 .57102 L .50651 .57478 L .288 .279 0 r
F
.49915 .57244 m .49711 .5683 L .50554 .57102 L F
.48339 .82226 m .47921 .82431 L .47159 .82094 L .367 .409 0 r
F
.49036 .82523 m .47921 .82431 L .48339 .82226 L .346 .373 0 r
F
.35505 .43503 m .36422 .41229 L .37115 .41933 L 1 .791 0 r
F
.35505 .43503 m .34736 .42821 L .36422 .41229 L F
.53218 1.06268 m .53308 1.06573 L .51077 1.06961 L .69 .78 0 r
F
.55327 1.05646 m .53308 1.06573 L .53218 1.06268 L .823 .873 0 r
F
.45766 .81359 m .45085 .81488 L .44391 .81052 L .429 .512 0 r
F
.46439 .81737 m .45085 .81488 L .45766 .81359 L .414 .489 0 r
F
.63145 1.0005 m .61805 1.02292 L .61322 1.01781 L 1 .916 0 r
F
.63145 1.0005 m .6372 1.00689 L .61805 1.02292 L F
.4682 .55486 m .47266 .55347 L .47678 .55806 L .099 .08 0 r
F
.4682 .55486 m .46313 .54899 L .47266 .55347 L F
.41825 .39885 m .41309 .39272 L .43233 .37653 L 1 1 0 r
F
.40097 .41793 m .41309 .39272 L .41825 .39885 L 1 .861 0 r
F
.57242 .86611 m .5681 .8669 L .56319 .86154 L 0 .06 0 r
F
.57242 .86611 m .57827 .87352 L .5681 .8669 L F
.672 .33724 m .7004 .34388 L .69318 .3482 L .932 .852 0 r
F
.66563 .34193 m .672 .33724 L .69318 .3482 L .921 .848 0 r
F
.31953 .7768 m .30467 .7639 L .31499 .76469 L .817 .745 0 r
F
.32959 .77704 m .31953 .7768 L .31499 .76469 L .799 .734 0 r
F
.24291 .76119 m .22863 .74316 L .2391 .74399 L .917 .795 0 r
F
.25319 .76143 m .24291 .76119 L .2391 .74399 L .908 .789 0 r
F
.54555 .84803 m .54047 .84869 L .53748 .84508 L .113 .09 0 r
F
.54555 .84803 m .54953 .85245 L .54047 .84869 L F
.3548 1.07217 m .3259 1.06668 L .33255 1.06349 L .775 .816 0 r
F
.36063 1.06873 m .3548 1.07217 L .33255 1.06349 L .759 .807 0 r
F
.31927 1.06993 m .2897 1.06205 L .2971 1.05911 L .804 .822 0 r
F
.3259 1.06668 m .31927 1.06993 L .2971 1.05911 L .791 .816 0 r
F
.38997 .79559 m .3746 .78777 L .38437 .78806 L .649 .669 0 r
F
.39931 .79545 m .38997 .79559 L .38437 .78806 L .62 .65 0 r
F
.31558 .4321 m .32416 .40947 L .33192 .4155 L 1 .813 0 r
F
.31558 .4321 m .30715 .4265 L .32416 .40947 L F
.43036 .50025 m .42459 .47626 L .4378 .495 L .2 .036 0 r
F
.5558 .59499 m .56199 .59302 L .56863 .59699 L .445 .532 0 r
F
.54954 .5916 m .56199 .59302 L .5558 .59499 L .43 .513 0 r
F
.53666 .34357 m .53789 .33859 L .55994 .33934 L .863 .894 0 r
F
.51543 .34477 m .53789 .33859 L .53666 .34357 L .896 .924 0 r
F
.65179 .62272 m .66184 .62269 L .66605 .63221 L .744 .699 0 r
F
.66184 .62269 m .67637 .63273 L .66605 .63221 L .767 .712 0 r
F
.26536 .42942 m .27324 .40537 L .28175 .4105 L 1 .829 0 r
F
.26536 .42942 m .25629 .42483 L .27324 .40537 L F
.58144 .34197 m .58484 .33687 L .60658 .34143 L .869 .866 0 r
F
.55994 .33934 m .58484 .33687 L .58144 .34197 L .881 .886 0 r
F
.40097 .41793 m .39492 .41017 L .41309 .39272 L 1 .861 0 r
F
.51088 1.06638 m .51077 1.06961 L .48846 1.07139 L .632 .742 0 r
F
.53218 1.06268 m .51077 1.06961 L .51088 1.06638 L .69 .78 0 r
F
.74431 .97329 m .73547 .99402 L .72744 .98926 L 1 .829 0 r
F
.74431 .97329 m .753 .97766 L .73547 .99402 L F
.71778 .63353 m .7316 .64741 L .72109 .64679 L .867 .759 0 r
F
.70741 .63351 m .71778 .63353 L .72109 .64679 L .853 .75 0 r
F
.47671 .81914 m .47159 .82094 L .46439 .81737 L .386 .44 0 r
F
.48339 .82226 m .47159 .82094 L .47671 .81914 L .367 .409 0 r
F
.36485 .78763 m .34973 .7779 L .35983 .77854 L .719 .7 0 r
F
.3746 .78777 m .36485 .78763 L .35983 .77854 L .694 .684 0 r
F
.70324 .97393 m .69395 .99431 L .6866 .9887 L 1 .814 0 r
F
.70324 .97393 m .71133 .97925 L .69395 .99431 L F
.52722 .83857 m .52075 .83918 L .51982 .83604 L .217 .184 0 r
F
.52722 .83857 m .52919 .84211 L .52075 .83918 L F
.61102 .33637 m .63809 .33802 L .63267 .3429 L .903 .865 0 r
F
.60658 .34143 m .61102 .33637 L .63267 .3429 L .885 .858 0 r
F
.57468 .60118 m .58249 .59989 L .58857 .60476 L .509 .58 0 r
F
.56863 .59699 m .58249 .59989 L .57468 .60118 L .486 .569 0 r
F
.25319 .76143 m .2391 .74399 L .24957 .74489 L .908 .789 0 r
F
.26347 .76175 m .25319 .76143 L .24957 .74489 L .899 .783 0 r
F
.50651 .57478 m .51407 .57376 L .51395 .57724 L .31 .314 0 r
F
.50651 .57478 m .50554 .57102 L .51407 .57376 L F
.37806 .42684 m .38885 .40299 L .39492 .41017 L 1 .81 0 r
F
.37806 .42684 m .37115 .41933 L .38885 .40299 L F
.67183 .97647 m .66177 .99762 L .65518 .99124 L 1 .805 0 r
F
.67183 .97647 m .67923 .98278 L .66177 .99762 L F
.64856 .9843 m .6372 1.00689 L .63145 1.0005 L 1 .826 0 r
F
.64856 .9843 m .65518 .99124 L .6372 1.00689 L F
.44818 .53737 m .45292 .53719 L .45803 .5431 L 0 .043 0 r
F
.44818 .53737 m .44221 .52836 L .45292 .53719 L F
.58484 .33687 m .61102 .33637 L .60658 .34143 L .893 .875 0 r
F
.4294 .80655 m .41443 .80157 L .42328 .80123 L .518 .595 0 r
F
.43765 .8059 m .4294 .80655 L .42328 .80123 L .488 .57 0 r
F
.44391 .81052 m .4294 .80655 L .43765 .8059 L .466 .557 0 r
F
.61206 .60879 m .62707 .61503 L .61745 .61523 L .634 .656 0 r
F
.60294 .60941 m .61206 .60879 L .61745 .61523 L .606 .636 0 r
F
.41547 1.07348 m .38839 1.07203 L .39337 1.06849 L .716 .799 0 r
F
.41954 1.06986 m .41547 1.07348 L .39337 1.06849 L .688 .782 0 r
F
.44157 1.0732 m .41547 1.07348 L .41954 1.06986 L .689 .79 0 r
F
.54954 .5916 m .55483 .58929 L .56199 .59302 L .43 .513 0 r
F
.5429 .58839 m .55483 .58929 L .54954 .5916 L .415 .489 0 r
F
.41443 .80157 m .39931 .79545 L .40867 .79548 L .57 .626 0 r
F
.42328 .80123 m .41443 .80157 L .40867 .79548 L .54 .603 0 r
F
.32959 .77704 m .31499 .76469 L .32531 .76561 L .799 .734 0 r
F
.33965 .7774 m .32959 .77704 L .32531 .76561 L .78 .723 0 r
F
.51543 .34477 m .51555 .33991 L .53789 .33859 L .896 .924 0 r
F
.49416 .34822 m .51555 .33991 L .51543 .34477 L .957 .966 0 r
F
.34736 .42821 m .35727 .40558 L .36422 .41229 L 1 .811 0 r
F
.34736 .42821 m .33965 .42173 L .35727 .40558 L F
.72816 .63346 m .74212 .64793 L .7316 .64741 L .879 .767 0 r
F
.71778 .63353 m .72816 .63346 L .7316 .64741 L .867 .759 0 r
F
.7149 .33504 m .74427 .34508 L .73625 .34906 L .956 .85 0 r
F
.70764 .33949 m .7149 .33504 L .73625 .34906 L .948 .847 0 r
F
.48958 1.06801 m .48846 1.07139 L .46636 1.07132 L .611 .732 0 r
F
.51088 1.06638 m .48846 1.07139 L .48958 1.06801 L .632 .742 0 r
F
.63672 .61466 m .65179 .62272 L .64175 .62259 L .705 .689 0 r
F
.62707 .61503 m .63672 .61466 L .64175 .62259 L .679 .672 0 r
F
.38839 1.07203 m .36063 1.06873 L .36648 1.06536 L .738 .805 0 r
F
.39337 1.06849 m .38839 1.07203 L .36648 1.06536 L .716 .792 0 r
F
.6719 .62252 m .6867 .63311 L .67637 .63273 L .787 .725 0 r
F
.66184 .62269 m .6719 .62252 L .67637 .63273 L .767 .712 0 r
F
.26347 .76175 m .24957 .74489 L .26004 .74587 L .899 .783 0 r
F
.27376 .76215 m .26347 .76175 L .26004 .74587 L .889 .776 0 r
F
.58857 .60476 m .59708 .60378 L .60294 .60941 L .557 .611 0 r
F
.58249 .59989 m .59708 .60378 L .58857 .60476 L .535 .604 0 r
F
.44468 1.0696 m .44157 1.0732 L .41954 1.06986 L .653 .765 0 r
F
.46636 1.07132 m .44157 1.0732 L .44468 1.0696 L .656 .771 0 r
F
.45149 .8096 m .44391 .81052 L .43765 .8059 L .443 .53 0 r
F
.45766 .81359 m .44391 .81052 L .45149 .8096 L .429 .512 0 r
F
.4704 .81587 m .46439 .81737 L .45766 .81359 L .402 .466 0 r
F
.47671 .81914 m .46439 .81737 L .4704 .81587 L .386 .44 0 r
F
.2897 1.06205 m .28232 1.06502 L .26068 1.05199 L .818 .822 0 r
F
.51395 .57724 m .52259 .57655 L .52139 .57981 L .334 .353 0 r
F
.51395 .57724 m .51407 .57376 L .52259 .57655 L F
.25629 .42483 m .26472 .4003 L .27324 .40537 L 1 .834 0 r
F
.25629 .42483 m .2472 .4203 L .26472 .4003 L F
.48886 .56562 m .49506 .56462 L .49711 .5683 L .208 .171 0 r
F
.48886 .56562 m .48576 .56139 L .49506 .56462 L F
.30715 .4265 m .31638 .40359 L .32416 .40947 L 1 .823 0 r
F
.30715 .4265 m .29871 .42105 L .31638 .40359 L F
.59708 .60378 m .61206 .60879 L .60294 .60941 L .586 .633 0 r
F
.49416 .34822 m .49316 .34354 L .51555 .33991 L .957 .966 0 r
F
.47307 .35431 m .49316 .34354 L .49416 .34822 L 1 1 0 r
F
.5429 .58839 m .54723 .5858 L .55483 .58929 L .415 .489 0 r
F
.53595 .58537 m .54723 .5858 L .5429 .58839 L .398 .461 0 r
F
.53449 .84101 m .52919 .84211 L .52722 .83857 L .201 .163 0 r
F
.53449 .84101 m .53748 .84508 L .52919 .84211 L F
.60132 .89976 m .59593 .91024 L .59 .89349 L .416 .186 0 r
F
.59456 .88784 m .59 .89349 L .58412 .88221 L .247 .078 0 r
F
.59456 .88784 m .60132 .89976 L .59 .89349 L F
.73559 .96877 m .72744 .98926 L .7194 .98435 L 1 .819 0 r
F
.73559 .96877 m .74431 .97329 L .72744 .98926 L F
.47307 .35431 m .47097 .3498 L .49316 .34354 L 1 1 0 r
F
.45239 .36359 m .47097 .3498 L .47307 .35431 L F
.73855 .63329 m .75264 .64836 L .74212 .64793 L .891 .774 0 r
F
.72816 .63346 m .73855 .63329 L .74212 .64793 L .879 .767 0 r
F
.39931 .79545 m .38437 .78806 L .39415 .78852 L .62 .65 0 r
F
.40867 .79548 m .39931 .79545 L .39415 .78852 L .59 .629 0 r
F
.52139 .57981 m .53102 .57946 L .52875 .58251 L .357 .392 0 r
F
.52139 .57981 m .52259 .57655 L .53102 .57946 L F
.3746 .78777 m .35983 .77854 L .36993 .77932 L .694 .684 0 r
F
.38437 .78806 m .3746 .78777 L .36993 .77932 L .667 .667 0 r
F
.78682 .96834 m .77897 .99008 L .77033 .98604 L 1 .836 0 r
F
.78682 .96834 m .79606 .97194 L .77897 .99008 L F
.53595 .58537 m .53926 .58253 L .54723 .5858 L .398 .461 0 r
F
.52875 .58251 m .53926 .58253 L .53595 .58537 L .379 .428 0 r
F
.45239 .36359 m .44922 .35905 L .47097 .3498 L 1 1 0 r
F
.43233 .37653 m .44922 .35905 L .45239 .36359 L F
.39492 .41017 m .40792 .38657 L .41309 .39272 L 1 .89 0 r
F
.39492 .41017 m .38885 .40299 L .40792 .38657 L F
.56863 .59699 m .57568 .59527 L .58249 .59989 L .486 .569 0 r
F
.56199 .59302 m .57568 .59527 L .56863 .59699 L .462 .553 0 r
F
.52875 .58251 m .53102 .57946 L .53926 .58253 L .379 .428 0 r
F
.69514 .96833 m .6866 .9887 L .67923 .98278 L 1 .797 0 r
F
.69514 .96833 m .70324 .97393 L .6866 .9887 L F
.64354 .33303 m .672 .33724 L .66563 .34193 L .926 .86 0 r
F
.63809 .33802 m .64354 .33303 L .66563 .34193 L .912 .856 0 r
F
.27376 .76215 m .26004 .74587 L .27052 .74694 L .889 .776 0 r
F
.28406 .76264 m .27376 .76215 L .27052 .74694 L .877 .768 0 r
F
.55994 .33934 m .56227 .33413 L .58484 .33687 L .881 .886 0 r
F
.53789 .33859 m .56227 .33413 L .55994 .33934 L .904 .91 0 r
F
.33965 .7774 m .32531 .76561 L .33565 .76665 L .78 .723 0 r
F
.34973 .7779 m .33965 .7774 L .33565 .76665 L .759 .71 0 r
F
.43233 .37653 m .42812 .37146 L .44922 .35905 L 1 1 0 r
F
.41309 .39272 m .42812 .37146 L .43233 .37653 L F
.60811 .91392 m .60199 .93495 L .59593 .91024 L .895 .39 0 r
F
.60132 .89976 m .60811 .91392 L .59593 .91024 L .416 .186 0 r
F
.44221 .52836 m .4478 .53126 L .45292 .53719 L 0 .012 0 r
F
.44221 .52836 m .43625 .51688 L .4478 .53126 L F
.55331 .85076 m .54953 .85245 L .54555 .84803 L .129 .091 0 r
F
.55331 .85076 m .55826 .85616 L .54953 .85245 L F
.37115 .41933 m .38275 .39618 L .38885 .40299 L 1 .836 0 r
F
.37115 .41933 m .36422 .41229 L .38275 .39618 L F
.67839 .33246 m .70764 .33949 L .7004 .34388 L .942 .855 0 r
F
.672 .33724 m .67839 .33246 L .7004 .34388 L .932 .852 0 r
F
.62567 .99341 m .61322 1.01781 L .60837 1.01269 L 1 .881 0 r
F
.62567 .99341 m .63145 1.0005 L .61322 1.01781 L F
.60837 1.01269 m .61322 1.01781 L .594 1.03408 L 1 1 0 r
F
.46313 .54899 m .46851 .54953 L .47266 .55347 L 0 .061 0 r
F
.46313 .54899 m .45803 .5431 L .46851 .54953 L F
.41309 .39272 m .40792 .38657 L .42812 .37146 L 1 1 0 r
F
.56656 .85938 m .56319 .86154 L .55826 .85616 L .099 .076 0 r
F
.56656 .85938 m .57242 .86611 L .56319 .86154 L F
.3259 1.06668 m .2971 1.05911 L .30452 1.05623 L .791 .816 0 r
F
.33255 1.06349 m .3259 1.06668 L .30452 1.05623 L .778 .809 0 r
F
.66441 .96967 m .65518 .99124 L .64856 .9843 L 1 .777 0 r
F
.66441 .96967 m .67183 .97647 L .65518 .99124 L F
.47678 .55806 m .48265 .55777 L .48576 .56139 L .087 .086 0 r
F
.47678 .55806 m .47266 .55347 L .48265 .55777 L F
.58782 .87787 m .58412 .88221 L .57827 .87352 L .183 .069 0 r
F
.58782 .87787 m .59456 .88784 L .58412 .88221 L F
.43625 .51688 m .44265 .52531 L .4478 .53126 L 0 0 0 r
F
.43036 .50025 m .4378 .495 L .44265 .52531 L .2 .036 0 r
F
.43625 .51688 m .43036 .50025 L .44265 .52531 L 0 0 0 r
F
.59012 1.03098 m .594 1.03408 L .57395 1.04711 L 1 1 0 r
F
.60837 1.01269 m .594 1.03408 L .59012 1.03098 L F
.68199 .62222 m .69705 .63337 L .6867 .63311 L .805 .736 0 r
F
.6719 .62252 m .68199 .62222 L .6867 .63311 L .787 .725 0 r
F
.46849 1.06787 m .46636 1.07132 L .44468 1.0696 L .607 .732 0 r
F
.48958 1.06801 m .46636 1.07132 L .46849 1.06787 L .611 .732 0 r
F
.74896 .63303 m .76317 .64871 L .75264 .64836 L .901 .781 0 r
F
.73855 .63329 m .74896 .63303 L .75264 .64836 L .891 .774 0 r
F
.36063 1.06873 m .33255 1.06349 L .33922 1.06036 L .759 .807 0 r
F
.36648 1.06536 m .36063 1.06873 L .33922 1.06036 L .741 .798 0 r
F
.33965 .42173 m .35029 .39912 L .35727 .40558 L 1 .827 0 r
F
.33965 .42173 m .33192 .4155 L .35029 .39912 L F
.49976 .82545 m .49756 .82806 L .49036 .82523 L .331 .348 0 r
F
.50608 .82791 m .49756 .82806 L .49976 .82545 L .313 .32 0 r
F
.50608 .82791 m .50492 .8308 L .49756 .82806 L F
.46451 .81243 m .45766 .81359 L .45149 .8096 L .415 .487 0 r
F
.4704 .81587 m .45766 .81359 L .46451 .81243 L .402 .466 0 r
F
.6419 .97657 m .63145 1.0005 L .62567 .99341 L 1 .785 0 r
F
.6419 .97657 m .64856 .9843 L .63145 1.0005 L F
.57105 1.04484 m .57395 1.04711 L .55327 1.05646 L .933 .914 0 r
F
.59012 1.03098 m .57395 1.04711 L .57105 1.04484 L 1 1 0 r
F
.49357 .82288 m .49036 .82523 L .48339 .82226 L .348 .376 0 r
F
.49976 .82545 m .49036 .82523 L .49357 .82288 L .331 .348 0 r
F
.64638 .61414 m .66184 .62269 L .65179 .62272 L .729 .704 0 r
F
.63672 .61466 m .64638 .61414 L .65179 .62272 L .705 .689 0 r
F
.51247 .83026 m .50492 .8308 L .50608 .82791 L .295 .292 0 r
F
.51247 .83026 m .51236 .83345 L .50492 .8308 L F
.6212 .60799 m .63672 .61466 L .62707 .61503 L .662 .674 0 r
F
.61206 .60879 m .6212 .60799 L .62707 .61503 L .634 .656 0 r
F
.28406 .76264 m .27052 .74694 L .281 .7481 L .877 .768 0 r
F
.29436 .76322 m .28406 .76264 L .281 .7481 L .865 .76 0 r
F
.55136 1.05417 m .55327 1.05646 L .53218 1.06268 L .671 .71 0 r
F
.57105 1.04484 m .55327 1.05646 L .55136 1.05417 L .933 .914 0 r
F
.29871 .42105 m .30857 .39783 L .31638 .40359 L 1 .832 0 r
F
.29871 .42105 m .29024 .41572 L .30857 .39783 L F
.49711 .5683 m .50457 .56766 L .50554 .57102 L .238 .21 0 r
F
.49711 .5683 m .49506 .56462 L .50457 .56766 L F
.48758 .82019 m .48339 .82226 L .47671 .81914 L .364 .402 0 r
F
.49357 .82288 m .48339 .82226 L .48758 .82019 L .348 .376 0 r
F
.53127 1.06009 m .53218 1.06268 L .51088 1.06638 L .577 .646 0 r
F
.55136 1.05417 m .53218 1.06268 L .53127 1.06009 L .671 .71 0 r
F
.42328 .80123 m .40867 .79548 L .41805 .79568 L .54 .603 0 r
F
.43215 .80107 m .42328 .80123 L .41805 .79568 L .509 .578 0 r
F
.43765 .8059 m .42328 .80123 L .43215 .80107 L .488 .57 0 r
F
.72686 .96408 m .7194 .98435 L .71133 .97925 L 1 .808 0 r
F
.72686 .96408 m .73559 .96877 L .7194 .98435 L F
.54156 .84331 m .53748 .84508 L .53449 .84101 L .195 .153 0 r
F
.54156 .84331 m .54555 .84803 L .53748 .84508 L F
.77756 .96466 m .77033 .98604 L .76168 .98191 L 1 .83 0 r
F
.77756 .96466 m .78682 .96834 L .77033 .98604 L F
.51888 .83251 m .51236 .83345 L .51247 .83026 L .279 .266 0 r
F
.51888 .83251 m .51982 .83604 L .51236 .83345 L F
.7149 .33504 m .72218 .33052 L .74427 .34508 L .956 .85 0 r
F
.56199 .59302 m .56821 .59093 L .57568 .59527 L .462 .553 0 r
F
.55483 .58929 m .56821 .59093 L .56199 .59302 L .439 .531 0 r
F
.58249 .59989 m .59033 .59842 L .59708 .60378 L .535 .604 0 r
F
.57568 .59527 m .59033 .59842 L .58249 .59989 L .51 .593 0 r
F
.58484 .33687 m .58825 .33161 L .61102 .33637 L .893 .875 0 r
F
.56227 .33413 m .58825 .33161 L .58484 .33687 L .909 .896 0 r
F
.44593 .80543 m .43765 .8059 L .43215 .80107 L .461 .543 0 r
F
.45149 .8096 m .43765 .8059 L .44593 .80543 L .443 .53 0 r
F
.75937 .6327 m .77371 .64897 L .76317 .64871 L .91 .788 0 r
F
.74896 .63303 m .75937 .6327 L .76317 .64871 L .901 .781 0 r
F
.34973 .7779 m .33565 .76665 L .34599 .76783 L .759 .71 0 r
F
.35983 .77854 m .34973 .7779 L .34599 .76783 L .736 .696 0 r
F
.61547 .33119 m .64354 .33303 L .63809 .33802 L .92 .87 0 r
F
.61102 .33637 m .61547 .33119 L .63809 .33802 L .903 .865 0 r
F
.38437 .78806 m .36993 .77932 L .38005 .78026 L .667 .667 0 r
F
.39415 .78852 m .38437 .78806 L .38005 .78026 L .638 .649 0 r
F
.53789 .33859 m .53913 .33337 L .56227 .33413 L .904 .91 0 r
F
.51555 .33991 m .53913 .33337 L .53789 .33859 L .944 .943 0 r
F
.2897 1.06205 m .26068 1.05199 L .26878 1.04942 L .818 .822 0 r
F
.2971 1.05911 m .2897 1.06205 L .26878 1.04942 L .808 .816 0 r
F
.29436 .76322 m .281 .7481 L .29148 .74937 L .865 .76 0 r
F
.30467 .7639 m .29436 .76322 L .29148 .74937 L .851 .751 0 r
F
.687 .96241 m .67923 .98278 L .67183 .97647 L 1 .777 0 r
F
.687 .96241 m .69514 .96833 L .67923 .98278 L F
.51099 1.06349 m .51088 1.06638 L .48958 1.06801 L .549 .646 0 r
F
.53127 1.06009 m .51088 1.06638 L .51099 1.06349 L .577 .646 0 r
F
.69208 .6218 m .70741 .63351 L .69705 .63337 L .822 .746 0 r
F
.68199 .62222 m .69208 .6218 L .69705 .63337 L .805 .736 0 r
F
.60562 .60262 m .6212 .60799 L .61206 .60879 L .614 .654 0 r
F
.59708 .60378 m .60562 .60262 L .61206 .60879 L .586 .633 0 r
F
.48185 .81738 m .47671 .81914 L .4704 .81587 L .379 .426 0 r
F
.48758 .82019 m .47671 .81914 L .48185 .81738 L .364 .402 0 r
F
.58825 .33161 m .61547 .33119 L .61102 .33637 L .914 .882 0 r
F
.40867 .79548 m .39415 .78852 L .40395 .78915 L .59 .629 0 r
F
.41805 .79568 m .40867 .79548 L .40395 .78915 L .559 .607 0 r
F
.59033 .59842 m .60562 .60262 L .59708 .60378 L .563 .627 0 r
F
.41954 1.06986 m .39337 1.06849 L .39836 1.06505 L .688 .782 0 r
F
.42362 1.06635 m .41954 1.06986 L .39836 1.06505 L .657 .762 0 r
F
.44468 1.0696 m .41954 1.06986 L .42362 1.06635 L .653 .765 0 r
F
.58109 .86931 m .57827 .87352 L .57242 .86611 L .181 .088 0 r
F
.58109 .86931 m .58782 .87787 L .57827 .87352 L F
.38885 .40299 m .40273 .3804 L .40792 .38657 L 1 .907 0 r
F
.38885 .40299 m .38275 .39618 L .40273 .3804 L F
.36422 .41229 m .37663 .38958 L .38275 .39618 L 1 .854 0 r
F
.36422 .41229 m .35727 .40558 L .37663 .38958 L F
.65696 .96223 m .64856 .9843 L .6419 .97657 L 1 .742 0 r
F
.65696 .96223 m .66441 .96967 L .64856 .9843 L F
.52524 .83464 m .51982 .83604 L .51888 .83251 L .265 .245 0 r
F
.52524 .83464 m .52722 .83857 L .51982 .83604 L F
.7698 .63228 m .78425 .64917 L .77371 .64897 L .919 .793 0 r
F
.75937 .6327 m .7698 .63228 L .77371 .64897 L .91 .788 0 r
F
.4591 .80885 m .45149 .8096 L .44593 .80543 L .427 .504 0 r
F
.46451 .81243 m .45149 .8096 L .4591 .80885 L .415 .487 0 r
F
.39337 1.06849 m .36648 1.06536 L .37235 1.06207 L .716 .792 0 r
F
.39836 1.06505 m .39337 1.06849 L .37235 1.06207 L .692 .777 0 r
F
.50554 .57102 m .51419 .57059 L .51407 .57376 L .275 .261 0 r
F
.50554 .57102 m .50457 .56766 L .51419 .57059 L F
.33192 .4155 m .34329 .39283 L .35029 .39912 L 1 .839 0 r
F
.33192 .4155 m .32416 .40947 L .34329 .39283 L F
.64638 .61414 m .65606 .61347 L .66184 .62269 L .729 .704 0 r
F
.65606 .61347 m .6719 .62252 L .66184 .62269 L .751 .717 0 r
F
.55483 .58929 m .56014 .5869 L .56821 .59093 L .439 .531 0 r
F
.54723 .5858 m .56014 .5869 L .55483 .58929 L .422 .503 0 r
F
.30467 .7639 m .29148 .74937 L .30196 .75074 L .851 .751 0 r
F
.31499 .76469 m .30467 .7639 L .30196 .75074 L .835 .741 0 r
F
.29024 .41572 m .30075 .39217 L .30857 .39783 L 1 .839 0 r
F
.29024 .41572 m .28175 .4105 L .30075 .39217 L F
.51555 .33991 m .51567 .33475 L .53913 .33337 L .944 .943 0 r
F
.49316 .34354 m .51567 .33475 L .51555 .33991 L 1 .984 0 r
F
.61985 .98511 m .62567 .99341 L .60837 1.01269 L 1 .824 0 r
F
.63522 .96767 m .62567 .99341 L .61985 .98511 L 1 .731 0 r
F
.63522 .96767 m .6419 .97657 L .62567 .99341 L F
.4478 1.06614 m .44468 1.0696 L .42362 1.06635 L .613 .735 0 r
F
.46849 1.06787 m .44468 1.0696 L .4478 1.06614 L .607 .732 0 r
F
.76829 .96087 m .76168 .98191 L .753 .97766 L 1 .823 0 r
F
.76829 .96087 m .77756 .96466 L .76168 .98191 L F
.35983 .77854 m .34599 .76783 L .35634 .76916 L .736 .696 0 r
F
.36993 .77932 m .35983 .77854 L .35634 .76916 L .711 .681 0 r
F
.49071 1.06489 m .48958 1.06801 L .46849 1.06787 L .546 .664 0 r
F
.51099 1.06349 m .48958 1.06801 L .49071 1.06489 L .549 .646 0 r
F
.47643 .81445 m .4704 .81587 L .46451 .81243 L .392 .447 0 r
F
.48185 .81738 m .4704 .81587 L .47643 .81445 L .379 .426 0 r
F
.60811 .91392 m .61492 .92945 L .60199 .93495 L .895 .39 0 r
F
.60199 .93495 m .59374 .99722 L .58851 .96575 L 1 .518 0 r
F
.60199 .93495 m .60804 .95872 L .59374 .99722 L F
.61492 .92945 m .60804 .95872 L .60199 .93495 L 1 .511 0 r
F
.71811 .9592 m .71133 .97925 L .70324 .97393 L 1 .795 0 r
F
.71811 .9592 m .72686 .96408 L .71133 .97925 L F
.63037 .60703 m .64638 .61414 L .63672 .61466 L .688 .691 0 r
F
.6212 .60799 m .63037 .60703 L .63672 .61466 L .662 .674 0 r
F
.6848 .32761 m .7149 .33504 L .70764 .33949 L .951 .858 0 r
F
.67839 .33246 m .6848 .32761 L .70764 .33949 L .942 .855 0 r
F
.649 .32795 m .67839 .33246 L .672 .33724 L .937 .864 0 r
F
.64354 .33303 m .649 .32795 L .672 .33724 L .926 .86 0 r
F
.48576 .56139 m .493 .56153 L .49506 .56462 L .117 .096 0 r
F
.48576 .56139 m .48265 .55777 L .493 .56153 L F
.78023 .6318 m .7948 .6493 L .78425 .64917 L .927 .799 0 r
F
.7698 .63228 m .78023 .6318 L .78425 .64917 L .919 .793 0 r
F
.7022 .62126 m .71778 .63353 L .70741 .63351 L .838 .756 0 r
F
.69208 .6218 m .7022 .62126 L .70741 .63351 L .822 .746 0 r
F
.33255 1.06349 m .30452 1.05623 L .31195 1.0534 L .778 .809 0 r
F
.33922 1.06036 m .33255 1.06349 L .31195 1.0534 L .763 .801 0 r
F
.61985 .98511 m .60837 1.01269 L .60351 1.00755 L 1 .824 0 r
F
.60351 1.00755 m .60837 1.01269 L .59012 1.03098 L 1 1 0 r
F
.56069 .85307 m .55826 .85616 L .55331 .85076 L .173 .117 0 r
F
.56069 .85307 m .56656 .85938 L .55826 .85616 L F
.45803 .5431 m .46434 .54681 L .46851 .54953 L 0 .029 0 r
F
.45803 .5431 m .45292 .53719 L .46434 .54681 L F
.40792 .38657 m .4239 .36601 L .42812 .37146 L 1 .998 0 r
F
.40792 .38657 m .40273 .3804 L .4239 .36601 L F
.57568 .59527 m .58276 .59339 L .59033 .59842 L .51 .593 0 r
F
.56821 .59093 m .58276 .59339 L .57568 .59527 L .482 .576 0 r
F
.49316 .34354 m .49216 .33849 L .51567 .33475 L 1 .984 0 r
F
.47097 .3498 m .49216 .33849 L .49316 .34354 L 1 1 0 r
F
.67885 .9561 m .67183 .97647 L .66441 .96967 L 1 .752 0 r
F
.67885 .9561 m .687 .96241 L .67183 .97647 L F
.54723 .5858 m .55157 .58316 L .56014 .5869 L .422 .503 0 r
F
.53926 .58253 m .55157 .58316 L .54723 .5858 L .401 .468 0 r
F
.53148 .83662 m .52722 .83857 L .52524 .83464 L .255 .229 0 r
F
.53148 .83662 m .53449 .84101 L .52722 .83857 L F
.51407 .57376 m .5238 .5735 L .52259 .57655 L .312 .318 0 r
F
.51407 .57376 m .51419 .57059 L .5238 .5735 L F
.39415 .78852 m .38005 .78026 L .39018 .78137 L .638 .649 0 r
F
.40395 .78915 m .39415 .78852 L .39018 .78137 L .607 .629 0 r
F
.54835 .84535 m .54555 .84803 L .54156 .84331 L .204 .158 0 r
F
.54835 .84535 m .55331 .85076 L .54555 .84803 L F
.42812 .37146 m .44603 .35399 L .44922 .35905 L 1 1 0 r
F
.42812 .37146 m .4239 .36601 L .44603 .35399 L F
.31499 .76469 m .30196 .75074 L .31245 .75223 L .835 .741 0 r
F
.32531 .76561 m .31499 .76469 L .31245 .75223 L .818 .73 0 r
F
.36648 1.06536 m .33922 1.06036 L .34591 1.0573 L .741 .798 0 r
F
.37235 1.06207 m .36648 1.06536 L .34591 1.0573 L .721 .787 0 r
F
.47097 .3498 m .46887 .34483 L .49216 .33849 L 1 1 0 r
F
.44922 .35905 m .46887 .34483 L .47097 .3498 L F
.44922 .35905 m .44603 .35399 L .46887 .34483 L F
.56227 .33413 m .56461 .32875 L .58825 .33161 L .909 .896 0 r
F
.53913 .33337 m .56461 .32875 L .56227 .33413 L .936 .921 0 r
F
.79068 .63125 m .80536 .64936 L .7948 .6493 L .934 .804 0 r
F
.78023 .6318 m .79068 .63125 L .7948 .6493 L .927 .799 0 r
F
.43215 .80107 m .41805 .79568 L .42745 .79607 L .509 .578 0 r
F
.44104 .8011 m .43215 .80107 L .42745 .79607 L .479 .552 0 r
F
.44593 .80543 m .43215 .80107 L .44104 .8011 L .461 .543 0 r
F
.64948 .95398 m .6419 .97657 L .63522 .96767 L 1 .699 0 r
F
.64948 .95398 m .65696 .96223 L .6419 .97657 L F
.47266 .55347 m .47952 .55504 L .48265 .55777 L 0 .071 0 r
F
.47199 .55283 m .46851 .54953 L .47952 .55504 L F
.47193 .55124 m .47636 .55365 L .47952 .55504 L 0 .044 0 r
F
.46851 .54953 m .47636 .55365 L .47193 .55124 L F
.47266 .55347 m .47199 .55283 L .47952 .55504 L 0 .071 0 r
F
.47636 .55365 m .47318 .55413 L .48051 .5559 L .322 0 0 r
F
.47952 .55504 m .47636 .55365 L .48757 .55741 L 0 .072 0 r
F
.47952 .55504 m .48757 .55741 L .48884 .55783 L F
.48265 .55777 m .47952 .55504 L .49093 .55922 L 0 .087 0 r
F
.48685 .55773 m .48884 .55783 L .49093 .55922 L 0 .072 0 r
F
.47952 .55504 m .48884 .55783 L .48685 .55773 L F
.48884 .55783 m .48674 .55741 L .49077 .55794 L 0 .093 0 r
F
.48884 .55783 m .49077 .55794 L .50062 .55923 L F
.47636 .55365 m .48051 .5559 L .48674 .55741 L .322 0 0 r
F
.53926 .58253 m .54259 .57972 L .55157 .58316 L .401 .468 0 r
F
.53102 .57946 m .54259 .57972 L .53926 .58253 L .376 .425 0 r
F
.52259 .57655 m .5333 .57652 L .53102 .57946 L .346 .374 0 r
F
.52259 .57655 m .5238 .5735 L .5333 .57652 L F
.47137 .81141 m .46451 .81243 L .4591 .80885 L .404 .465 0 r
F
.47643 .81445 m .46451 .81243 L .47137 .81141 L .392 .447 0 r
F
.58624 1.02909 m .59012 1.03098 L .57105 1.04484 L 1 1 0 r
F
.60351 1.00755 m .59012 1.03098 L .58624 1.02909 L F
.41805 .79568 m .40395 .78915 L .41377 .78995 L .559 .607 0 r
F
.42745 .79607 m .41805 .79568 L .41377 .78995 L .527 .583 0 r
F
.53102 .57946 m .5333 .57652 L .54259 .57972 L .376 .425 0 r
F
.57435 .86169 m .57242 .86611 L .56656 .85938 L .205 .127 0 r
F
.57435 .86169 m .58109 .86931 L .57242 .86611 L F
.66576 .61265 m .68199 .62222 L .6719 .62252 L .772 .73 0 r
F
.65606 .61347 m .66576 .61265 L .6719 .62252 L .751 .717 0 r
F
.2971 1.05911 m .26878 1.04942 L .27691 1.0469 L .808 .816 0 r
F
.30452 1.05623 m .2971 1.05911 L .27691 1.0469 L .796 .811 0 r
F
.35727 .40558 m .37049 .38314 L .37663 .38958 L 1 .867 0 r
F
.35727 .40558 m .35029 .39912 L .37049 .38314 L F
.36993 .77932 m .35634 .76916 L .3667 .77064 L .711 .681 0 r
F
.38005 .78026 m .36993 .77932 L .3667 .77064 L .684 .664 0 r
F
.2077 .7417 m .19724 .74105 L .19583 .72076 L .955 .81 0 r
F
.759 .95696 m .753 .97766 L .74431 .97329 L 1 .815 0 r
F
.759 .95696 m .76829 .96087 L .753 .97766 L F
.45423 .80514 m .44593 .80543 L .44104 .8011 L .438 .517 0 r
F
.4591 .80885 m .44593 .80543 L .45423 .80514 L .427 .504 0 r
F
.61419 .60129 m .63037 .60703 L .6212 .60799 L .642 .674 0 r
F
.60562 .60262 m .61419 .60129 L .6212 .60799 L .614 .654 0 r
F
.47063 1.06461 m .46849 1.06787 L .4478 1.06614 L .555 .683 0 r
F
.49071 1.06489 m .46849 1.06787 L .47063 1.06461 L .546 .664 0 r
F
.71232 .62061 m .72816 .63346 L .71778 .63353 L .852 .764 0 r
F
.7022 .62126 m .71232 .62061 L .71778 .63353 L .838 .756 0 r
F
.32416 .40947 m .33626 .38667 L .34329 .39283 L 1 .849 0 r
F
.32416 .40947 m .31638 .40359 L .33626 .38667 L F
.28175 .4105 m .2929 .38658 L .30075 .39217 L 1 .845 0 r
F
.28175 .4105 m .27324 .40537 L .2929 .38658 L F
.70933 .95409 m .70324 .97393 L .69514 .96833 L 1 .78 0 r
F
.70933 .95409 m .71811 .9592 L .70324 .97393 L F
.59033 .59842 m .5982 .59679 L .60562 .60262 L .563 .627 0 r
F
.58276 .59339 m .5982 .59679 L .59033 .59842 L .536 .617 0 r
F
.61399 .97442 m .61985 .98511 L .60351 1.00755 L 1 .734 0 r
F
.62849 .95709 m .61985 .98511 L .61399 .97442 L 1 .664 0 r
F
.62849 .95709 m .63522 .96767 L .61985 .98511 L F
.80113 .63065 m .81592 .64937 L .80536 .64936 L .94 .808 0 r
F
.79068 .63125 m .80113 .63065 L .80536 .64936 L .934 .804 0 r
F
.32531 .76561 m .31245 .75223 L .32294 .75385 L .818 .73 0 r
F
.33565 .76665 m .32531 .76561 L .32294 .75385 L .799 .718 0 r
F
.38275 .39618 m .39752 .37422 L .40273 .3804 L 1 .917 0 r
F
.38275 .39618 m .37663 .38958 L .39752 .37422 L F
.61994 .3259 m .649 .32795 L .64354 .33303 L .934 .875 0 r
F
.61547 .33119 m .61994 .3259 L .64354 .33303 L .92 .87 0 r
F
.2077 .7417 m .19583 .72076 L .2064 .72206 L .955 .81 0 r
F
.21817 .7424 m .2077 .7417 L .2064 .72206 L .949 .805 0 r
F
.56814 1.04373 m .57105 1.04484 L .55136 1.05417 L .663 .571 0 r
F
.58624 1.02909 m .57105 1.04484 L .56814 1.04373 L 1 1 0 r
F
.50196 .82267 m .49976 .82545 L .49357 .82288 L .341 .362 0 r
F
.50724 .8248 m .49976 .82545 L .50196 .82267 L .329 .343 0 r
F
.50724 .8248 m .50608 .82791 L .49976 .82545 L F
.5982 .59679 m .61419 .60129 L .60562 .60262 L .591 .649 0 r
F
.4968 .82043 m .49357 .82288 L .48758 .82019 L .352 .381 0 r
F
.50196 .82267 m .49357 .82288 L .4968 .82043 L .341 .362 0 r
F
.67067 .94931 m .66441 .96967 L .65696 .96223 L 1 .724 0 r
F
.67067 .94931 m .67885 .9561 L .66441 .96967 L F
.58825 .33161 m .59167 .32621 L .61547 .33119 L .914 .882 0 r
F
.56461 .32875 m .59167 .32621 L .58825 .33161 L .933 .903 0 r
F
.53754 .8384 m .53449 .84101 L .53148 .83662 L .251 .221 0 r
F
.53754 .8384 m .54156 .84331 L .53449 .84101 L F
.51259 .8268 m .50608 .82791 L .50724 .8248 L .318 .325 0 r
F
.51259 .8268 m .51247 .83026 L .50608 .82791 L F
.56821 .59093 m .57445 .5887 L .58276 .59339 L .482 .576 0 r
F
.56014 .5869 m .57445 .5887 L .56821 .59093 L .453 .554 0 r
F
.54944 1.05267 m .55136 1.05417 L .53127 1.06009 L .54 .413 0 r
F
.56814 1.04373 m .55136 1.05417 L .54944 1.05267 L .663 .571 0 r
F
.63956 .60591 m .65606 .61347 L .64638 .61414 L .712 .707 0 r
F
.63037 .60703 m .63956 .60591 L .64638 .61414 L .688 .691 0 r
F
.21817 .7424 m .2064 .72206 L .21696 .72343 L .949 .805 0 r
F
.22863 .74316 m .21817 .7424 L .21696 .72343 L .942 .8 0 r
F
.49506 .56462 m .50359 .56479 L .50457 .56766 L .172 .131 0 r
F
.49506 .56462 m .493 .56153 L .50359 .56479 L F
.64197 .94475 m .63522 .96767 L .62849 .95709 L 1 .65 0 r
F
.64197 .94475 m .64948 .95398 L .63522 .96767 L F
.49179 .81809 m .48758 .82019 L .48185 .81738 L .364 .399 0 r
F
.4968 .82043 m .48758 .82019 L .49179 .81809 L .352 .381 0 r
F
.61174 .90001 m .60811 .91392 L .60132 .89976 L .67 .386 0 r
F
.60418 .88926 m .60132 .89976 L .59456 .88784 L .462 .306 0 r
F
.60418 .88926 m .61174 .90001 L .60132 .89976 L F
.8116 .62998 m .82649 .64933 L .81592 .64937 L .946 .812 0 r
F
.80113 .63065 m .8116 .62998 L .81592 .64937 L .94 .808 0 r
F
.59167 .32621 m .61994 .3259 L .61547 .33119 L .932 .887 0 r
F
.53036 1.05803 m .53127 1.06009 L .51099 1.06349 L .501 .446 0 r
F
.54944 1.05267 m .53127 1.06009 L .53036 1.05803 L .54 .413 0 r
F
.40395 .78915 m .39018 .78137 L .40033 .78265 L .607 .629 0 r
F
.41377 .78995 m .40395 .78915 L .40033 .78265 L .575 .607 0 r
F
.61931 .91151 m .61492 .92945 L .60811 .91392 L .883 .468 0 r
F
.61174 .90001 m .61931 .91151 L .60811 .91392 L .67 .386 0 r
F
.60804 .95872 m .59863 1.0024 L .59374 .99722 L 1 .612 0 r
F
.60804 .95872 m .61399 .97442 L .59863 1.0024 L F
.62172 .94432 m .61399 .97442 L .60804 .95872 L 1 .59 0 r
F
.61492 .92945 m .62172 .94432 L .60804 .95872 L 1 .511 0 r
F
.53913 .33337 m .54037 .32794 L .56461 .32875 L .936 .921 0 r
F
.51567 .33475 m .54037 .32794 L .53913 .33337 L .98 .953 0 r
F
.51794 .82868 m .51247 .83026 L .51259 .8268 L .308 .308 0 r
F
.51794 .82868 m .51888 .83251 L .51247 .83026 L F
.22863 .74316 m .21696 .72343 L .22753 .72485 L .942 .8 0 r
F
.2391 .74399 m .22863 .74316 L .22753 .72485 L .935 .794 0 r
F
.33565 .76665 m .32294 .75385 L .33344 .75561 L .799 .718 0 r
F
.34599 .76783 m .33565 .76665 L .33344 .75561 L .777 .705 0 r
F
.42362 1.06635 m .39836 1.06505 L .40337 1.0617 L .657 .762 0 r
F
.42771 1.06297 m .42362 1.06635 L .40337 1.0617 L .623 .738 0 r
F
.4478 1.06614 m .42362 1.06635 L .42771 1.06297 L .613 .735 0 r
F
.46674 .80826 m .4591 .80885 L .45423 .80514 L .414 .48 0 r
F
.47137 .81141 m .4591 .80885 L .46674 .80826 L .404 .465 0 r
F
.72247 .61986 m .73855 .63329 L .72816 .63346 L .865 .772 0 r
F
.71232 .62061 m .72247 .61986 L .72816 .63346 L .852 .764 0 r
F
.39836 1.06505 m .37235 1.06207 L .37823 1.05886 L .692 .777 0 r
F
.40337 1.0617 m .39836 1.06505 L .37823 1.05886 L .666 .761 0 r
F
.61399 .97442 m .60351 1.00755 L .59863 1.0024 L 1 .734 0 r
F
.62172 .94432 m .62849 .95709 L .61399 .97442 L 1 .59 0 r
F
.59663 .87952 m .59456 .88784 L .58782 .87787 L .363 .252 0 r
F
.59663 .87952 m .60418 .88926 L .59456 .88784 L F
.69123 .32268 m .72218 .33052 L .7149 .33504 L .959 .86 0 r
F
.6848 .32761 m .69123 .32268 L .7149 .33504 L .951 .858 0 r
F
.74969 .95293 m .74431 .97329 L .73559 .96877 L 1 .806 0 r
F
.74969 .95293 m .759 .95696 L .74431 .97329 L F
.48701 .81565 m .48185 .81738 L .47643 .81445 L .374 .416 0 r
F
.49179 .81809 m .48185 .81738 L .48701 .81565 L .364 .399 0 r
F
.38005 .78026 m .3667 .77064 L .37707 .77228 L .684 .664 0 r
F
.39018 .78137 m .38005 .78026 L .37707 .77228 L .654 .646 0 r
F
.5111 1.06097 m .51099 1.06349 L .49071 1.06489 L .493 .516 0 r
F
.53036 1.05803 m .51099 1.06349 L .5111 1.06097 L .501 .446 0 r
F
.67548 .6117 m .69208 .6218 L .68199 .62222 L .791 .741 0 r
F
.66576 .61265 m .67548 .6117 L .68199 .62222 L .772 .73 0 r
F
.61931 .91151 m .62687 .92322 L .61492 .92945 L .883 .468 0 r
F
.62687 .92322 m .62172 .94432 L .61492 .92945 L 1 .536 0 r
F
.33922 1.06036 m .31195 1.0534 L .31941 1.05064 L .763 .801 0 r
F
.34591 1.0573 m .33922 1.06036 L .31941 1.05064 L .747 .793 0 r
F
.65448 .32278 m .6848 .32761 L .67839 .33246 L .948 .867 0 r
F
.649 .32795 m .65448 .32278 L .67839 .33246 L .937 .864 0 r
F
.2391 .74399 m .22753 .72485 L .23809 .72636 L .935 .794 0 r
F
.24957 .74489 m .2391 .74399 L .23809 .72636 L .927 .788 0 r
F
.63443 .93445 m .62849 .95709 L .62172 .94432 L 1 .596 0 r
F
.63443 .93445 m .64197 .94475 L .62849 .95709 L F
.70054 .94872 m .69514 .96833 L .687 .96241 L 1 .762 0 r
F
.70054 .94872 m .70933 .95409 L .69514 .96833 L F
.8116 .62998 m .82207 .62927 L .82649 .64933 L .946 .812 0 r
F
.59863 1.0024 m .60351 1.00755 L .58624 1.02909 L 1 1 0 r
F
.55481 .84701 m .55331 .85076 L .54835 .84535 L .229 .181 0 r
F
.55481 .84701 m .56069 .85307 L .55331 .85076 L F
.40273 .3804 m .41967 .36029 L .4239 .36601 L 1 .989 0 r
F
.40273 .3804 m .39752 .37422 L .41967 .36029 L F
.45292 .53719 m .46013 .54656 L .46434 .54681 L .585 .019 0 r
F
.45292 .53719 m .4478 .53126 L .46013 .54656 L F
.52324 .83042 m .51888 .83251 L .51794 .82868 L .299 .293 0 r
F
.52324 .83042 m .52524 .83464 L .51888 .83251 L F
.62687 .92322 m .63443 .93445 L .62172 .94432 L 1 .536 0 r
F
.27324 .40537 m .28503 .38106 L .2929 .38658 L 1 .85 0 r
F
.27324 .40537 m .26472 .4003 L .28503 .38106 L F
.66247 .94197 m .65696 .96223 L .64948 .95398 L 1 .69 0 r
F
.66247 .94197 m .67067 .94931 L .65696 .96223 L F
.31638 .40359 m .32922 .3806 L .33626 .38667 L 1 .856 0 r
F
.31638 .40359 m .30857 .39783 L .32922 .3806 L F
.56014 .5869 m .56547 .5844 L .57445 .5887 L .453 .554 0 r
F
.55157 .58316 m .56547 .5844 L .56014 .5869 L .431 .522 0 r
F
.24957 .74489 m .23809 .72636 L .24864 .72793 L .927 .788 0 r
F
.26004 .74587 m .24957 .74489 L .24864 .72793 L .919 .781 0 r
F
.35029 .39912 m .36433 .37679 L .37049 .38314 L 1 .876 0 r
F
.35029 .39912 m .34329 .39283 L .36433 .37679 L F
.56761 .8547 m .56656 .85938 L .56069 .85307 L .236 .175 0 r
F
.56761 .8547 m .57435 .86169 L .56656 .85938 L F
.45094 1.06285 m .4478 1.06614 L .42771 1.06297 L .569 .698 0 r
F
.47063 1.06461 m .4478 1.06614 L .45094 1.06285 L .555 .683 0 r
F
.42745 .79607 m .41377 .78995 L .42361 .79094 L .527 .583 0 r
F
.43687 .79665 m .42745 .79607 L .42361 .79094 L .495 .557 0 r
F
.44104 .8011 m .42745 .79607 L .43687 .79665 L .479 .552 0 r
F
.44996 .80131 m .44104 .8011 L .43687 .79665 L .452 .526 0 r
F
.45423 .80514 m .44104 .8011 L .44996 .80131 L .438 .517 0 r
F
.48248 .81311 m .47643 .81445 L .47137 .81141 L .384 .432 0 r
F
.48701 .81565 m .47643 .81445 L .48248 .81311 L .374 .416 0 r
F
.51567 .33475 m .51579 .32934 L .54037 .32794 L .98 .953 0 r
F
.49216 .33849 m .51579 .32934 L .51567 .33475 L 1 .991 0 r
F
.34599 .76783 m .33344 .75561 L .34394 .75752 L .777 .705 0 r
F
.35634 .76916 m .34599 .76783 L .34394 .75752 L .754 .691 0 r
F
.37235 1.06207 m .34591 1.0573 L .35262 1.05431 L .721 .787 0 r
F
.37823 1.05886 m .37235 1.06207 L .35262 1.05431 L .7 .774 0 r
F
.50457 .56766 m .5143 .56775 L .51419 .57059 L .234 .197 0 r
F
.50457 .56766 m .50359 .56479 L .5143 .56775 L F
.58276 .59339 m .58987 .59134 L .5982 .59679 L .536 .617 0 r
F
.57445 .5887 m .58987 .59134 L .58276 .59339 L .506 .601 0 r
F
.58909 .87076 m .58782 .87787 L .58109 .86931 L .321 .23 0 r
F
.58909 .87076 m .59663 .87952 L .58782 .87787 L F
.30452 1.05623 m .27691 1.0469 L .28505 1.04443 L .796 .811 0 r
F
.31195 1.0534 m .30452 1.05623 L .28505 1.04443 L .784 .804 0 r
F
.62278 .59978 m .63956 .60591 L .63037 .60703 L .669 .692 0 r
F
.61419 .60129 m .62278 .59978 L .63037 .60703 L .642 .674 0 r
F
.49185 1.06205 m .49071 1.06489 L .47063 1.06461 L .496 .578 0 r
F
.5111 1.06097 m .49071 1.06489 L .49185 1.06205 L .493 .516 0 r
F
.73262 .61902 m .74896 .63303 L .73855 .63329 L .877 .779 0 r
F
.72247 .61986 m .73262 .61902 L .73855 .63329 L .865 .772 0 r
F
.54337 .83992 m .54156 .84331 L .53754 .8384 L .256 .224 0 r
F
.54337 .83992 m .54835 .84535 L .54156 .84331 L F
.4239 .36601 m .44284 .34857 L .44603 .35399 L 1 1 0 r
F
.4239 .36601 m .41967 .36029 L .44284 .34857 L F
.26004 .74587 m .24864 .72793 L .2592 .7296 L .919 .781 0 r
F
.27052 .74694 m .26004 .74587 L .2592 .7296 L .909 .773 0 r
F
.26878 1.04942 m .26068 1.05199 L .24136 1.03758 L .825 .817 0 r
F
.48265 .55777 m .49093 .55922 L .493 .56153 L 0 .087 0 r
F
.37663 .38958 m .39229 .36801 L .39752 .37422 L 1 .921 0 r
F
.37663 .38958 m .37049 .38314 L .39229 .36801 L F
.63956 .60591 m .64877 .60464 L .65606 .61347 L .712 .707 0 r
F
.64877 .60464 m .66576 .61265 L .65606 .61347 L .735 .721 0 r
F
.74037 .94875 m .73559 .96877 L .72686 .96408 L 1 .795 0 r
F
.74037 .94875 m .74969 .95293 L .73559 .96877 L F
.49216 .33849 m .49116 .33314 L .51579 .32934 L 1 .991 0 r
F
.46887 .34483 m .49116 .33314 L .49216 .33849 L 1 1 0 r
F
.52846 .83198 m .52524 .83464 L .52324 .83042 L .293 .282 0 r
F
.52846 .83198 m .53148 .83662 L .52524 .83464 L F
.41377 .78995 m .40033 .78265 L .41049 .78411 L .575 .607 0 r
F
.42361 .79094 m .41377 .78995 L .41049 .78411 L .542 .584 0 r
F
.46257 .80501 m .45423 .80514 L .44996 .80131 L .422 .491 0 r
F
.46674 .80826 m .45423 .80514 L .46257 .80501 L .414 .48 0 r
F
.39018 .78137 m .37707 .77228 L .38745 .77409 L .654 .646 0 r
F
.40033 .78265 m .39018 .78137 L .38745 .77409 L .622 .626 0 r
F
.44603 .35399 m .46675 .3395 L .46887 .34483 L 1 1 0 r
F
.44603 .35399 m .44284 .34857 L .46675 .3395 L F
.56461 .32875 m .56696 .3232 L .59167 .32621 L .933 .903 0 r
F
.54037 .32794 m .56696 .3232 L .56461 .32875 L .962 .928 0 r
F
.69173 .94303 m .687 .96241 L .67885 .9561 L 1 .741 0 r
F
.69173 .94303 m .70054 .94872 L .687 .96241 L F
.27052 .74694 m .2592 .7296 L .26975 .73136 L .909 .773 0 r
F
.281 .7481 m .27052 .74694 L .26975 .73136 L .898 .765 0 r
F
.55157 .58316 m .55594 .58047 L .56547 .5844 L .431 .522 0 r
F
.54259 .57972 m .55594 .58047 L .55157 .58316 L .407 .481 0 r
F
.46887 .34483 m .46675 .3395 L .49116 .33314 L 1 1 0 r
F
.65424 .93403 m .64948 .95398 L .64197 .94475 L 1 .653 0 r
F
.65424 .93403 m .66247 .94197 L .64948 .95398 L F
.68522 .61063 m .7022 .62126 L .69208 .6218 L .808 .751 0 r
F
.67548 .6117 m .68522 .61063 L .69208 .6218 L .791 .741 0 r
F
.5982 .59679 m .60609 .59497 L .61419 .60129 L .591 .649 0 r
F
.58987 .59134 m .60609 .59497 L .5982 .59679 L .565 .641 0 r
F
.46851 .54953 m .46434 .54681 L .47636 .55365 L 0 .044 0 r
F
.60609 .59497 m .62278 .59978 L .61419 .60129 L .62 .671 0 r
F
.47827 .81049 m .47137 .81141 L .46674 .80826 L .394 .446 0 r
F
.48248 .81311 m .47137 .81141 L .47827 .81049 L .384 .432 0 r
F
.35634 .76916 m .34394 .75752 L .35444 .75958 L .754 .691 0 r
F
.3667 .77064 m .35634 .76916 L .35444 .75958 L .728 .675 0 r
F
.51419 .57059 m .52501 .57064 L .5238 .5735 L .291 .278 0 r
F
.51419 .57059 m .5143 .56775 L .52501 .57064 L F
.80071 .95013 m .79606 .97194 L .78682 .96834 L 1 .826 0 r
F
.80071 .95013 m .81048 .95322 L .79606 .97194 L F
.62443 .32049 m .65448 .32278 L .649 .32795 L .947 .878 0 r
F
.61994 .3259 m .62443 .32049 L .649 .32795 L .934 .875 0 r
F
.281 .7481 m .26975 .73136 L .28031 .73322 L .898 .765 0 r
F
.29148 .74937 m .281 .7481 L .28031 .73322 L .885 .756 0 r
F
.74279 .61809 m .75937 .6327 L .74896 .63303 L .887 .786 0 r
F
.73262 .61902 m .74279 .61809 L .74896 .63303 L .877 .779 0 r
F
.58236 1.02958 m .58308 1.03164 L .56814 1.04373 L .778 .507 0 r
F
.58236 1.02958 m .56814 1.04373 L .56805 1.04374 L F
.57439 1.03643 m .56805 1.04374 L .56522 1.0443 L F
.58236 1.02958 m .56805 1.04374 L .57439 1.03643 L F
.57851 1.03516 m .58236 1.02958 L .57597 1.03507 L 0 0 0 r
F
.57851 1.03516 m .57597 1.03507 L .56522 1.0443 L F
.58125 1.03526 m .57851 1.03516 L .57472 1.0491 L F
.58161 1.02745 m .5817 1.02771 L .57851 1.03516 L 1 1 0 r
F
.5817 1.02771 m .58236 1.02958 L .57851 1.03516 L F
.59374 .99722 m .58236 1.02958 L .58161 1.02745 L F
.58236 1.02958 m .58624 1.02909 L .58308 1.03164 L .778 .507 0 r
F
.59863 1.0024 m .58624 1.02909 L .58236 1.02958 L 1 1 0 r
F
.59374 .99722 m .59863 1.0024 L .58236 1.02958 L F
.58914 1.01853 m .57851 1.03516 L .58125 1.03526 L 0 0 0 r
F
.58914 1.01853 m .59374 .99722 L .58112 1.02865 L F
.58702 1.02184 m .58112 1.02865 L .57851 1.03516 L F
.58914 1.01853 m .58112 1.02865 L .58702 1.02184 L F
.54259 .57972 m .54594 .5769 L .55594 .58047 L .407 .481 0 r
F
.5333 .57652 m .54594 .5769 L .54259 .57972 L .377 .426 0 r
F
.58154 .86282 m .58109 .86931 L .57435 .86169 L .303 .234 0 r
F
.58154 .86282 m .58909 .87076 L .58109 .86931 L F
.47278 1.06158 m .47063 1.06461 L .45094 1.06285 L .503 .623 0 r
F
.49185 1.06205 m .47063 1.06461 L .47278 1.06158 L .496 .578 0 r
F
.5238 .5735 m .5356 .57365 L .5333 .57652 L .338 .357 0 r
F
.5238 .5735 m .52501 .57064 L .5356 .57365 L F
.646 .92545 m .64197 .94475 L .63443 .93445 L 1 .613 0 r
F
.646 .92545 m .65424 .93403 L .64197 .94475 L F
.30857 .39783 m .32215 .37462 L .32922 .3806 L 1 .862 0 r
F
.30857 .39783 m .30075 .39217 L .32215 .37462 L F
.5333 .57652 m .5356 .57365 L .54594 .5769 L .377 .426 0 r
F
.69123 .32268 m .69768 .31768 L .72218 .33052 L .959 .86 0 r
F
.73103 .94441 m .72686 .96408 L .71811 .9592 L 1 .783 0 r
F
.73103 .94441 m .74037 .94875 L .72686 .96408 L F
.59167 .32621 m .59511 .32067 L .61994 .3259 L .932 .887 0 r
F
.56696 .3232 m .59511 .32067 L .59167 .32621 L .953 .908 0 r
F
.29148 .74937 m .28031 .73322 L .29086 .73519 L .885 .756 0 r
F
.30196 .75074 m .29148 .74937 L .29086 .73519 L .871 .747 0 r
F
.53352 .83334 m .53148 .83662 L .52846 .83198 L .291 .276 0 r
F
.53352 .83334 m .53754 .8384 L .53148 .83662 L F
.57445 .5887 m .58071 .58632 L .58987 .59134 L .506 .601 0 r
F
.56547 .5844 m .58071 .58632 L .57445 .5887 L .473 .579 0 r
F
.34329 .39283 m .35815 .37052 L .36433 .37679 L 1 .883 0 r
F
.34329 .39283 m .33626 .38667 L .35815 .37052 L F
.59511 .32067 m .62443 .32049 L .61994 .3259 L .948 .891 0 r
F
.6829 .937 m .67885 .9561 L .67067 .94931 L 1 .718 0 r
F
.6829 .937 m .69173 .94303 L .67885 .9561 L F
.34591 1.0573 m .31941 1.05064 L .32688 1.04794 L .747 .793 0 r
F
.35262 1.05431 m .34591 1.0573 L .32688 1.04794 L .729 .783 0 r
F
.43687 .79665 m .42361 .79094 L .43346 .79211 L .495 .557 0 r
F
.44631 .79741 m .43687 .79665 L .43346 .79211 L .465 .532 0 r
F
.44996 .80131 m .43687 .79665 L .44631 .79741 L .452 .526 0 r
F
.56086 .84815 m .56069 .85307 L .55481 .84701 L .267 .222 0 r
F
.56086 .84815 m .56761 .8547 L .56069 .85307 L F
.4744 .8078 m .46674 .80826 L .46257 .80501 L .402 .457 0 r
F
.47827 .81049 m .46674 .80826 L .4744 .8078 L .394 .446 0 r
F
.3667 .77064 m .35444 .75958 L .36495 .76181 L .728 .675 0 r
F
.37707 .77228 m .3667 .77064 L .36495 .76181 L .699 .659 0 r
F
.40033 .78265 m .38745 .77409 L .39784 .77607 L .622 .626 0 r
F
.41049 .78411 m .40033 .78265 L .39784 .77607 L .589 .605 0 r
F
.50418 .81974 m .50196 .82267 L .4968 .82043 L .35 .375 0 r
F
.50842 .82148 m .50196 .82267 L .50418 .81974 L .343 .363 0 r
F
.50842 .82148 m .50724 .8248 L .50196 .82267 L F
.65998 .31752 m .69123 .32268 L .6848 .32761 L .957 .87 0 r
F
.65448 .32278 m .65998 .31752 L .6848 .32761 L .948 .867 0 r
F
.54891 .84111 m .54835 .84535 L .54337 .83992 L .271 .239 0 r
F
.54891 .84111 m .55481 .84701 L .54835 .84535 L F
.39752 .37422 m .41543 .35438 L .41967 .36029 L 1 .981 0 r
F
.39752 .37422 m .39229 .36801 L .41543 .35438 L F
.4478 .53126 m .45584 .55155 L .46013 .54656 L .821 .068 0 r
F
.4478 .53126 m .44265 .52531 L .45584 .55155 L F
.40337 1.0617 m .37823 1.05886 L .38414 1.05575 L .666 .761 0 r
F
.4084 1.05848 m .40337 1.0617 L .38414 1.05575 L .637 .741 0 r
F
.42771 1.06297 m .40337 1.0617 L .4084 1.05848 L .623 .738 0 r
F
.50004 .81789 m .4968 .82043 L .49179 .81809 L .358 .387 0 r
F
.50418 .81974 m .4968 .82043 L .50004 .81789 L .35 .375 0 r
F
.63773 .91632 m .63443 .93445 L .62687 .92322 L .965 .57 0 r
F
.63773 .91632 m .646 .92545 L .63443 .93445 L F
.79094 .94695 m .78682 .96834 L .77756 .96466 L 1 .82 0 r
F
.79094 .94695 m .80071 .95013 L .78682 .96834 L F
.56522 1.0443 m .56814 1.04373 L .55974 1.04774 L .442 .157 0 r
F
.57124 1.04052 m .56522 1.0443 L .56231 1.04711 L 0 0 0 r
F
.57851 1.03516 m .56522 1.0443 L .57124 1.04052 L F
.56522 1.0443 m .55974 1.04774 L .54944 1.05267 L .442 .157 0 r
F
.43182 1.05974 m .42771 1.06297 L .4084 1.05848 L .587 .71 0 r
F
.45094 1.06285 m .42771 1.06297 L .43182 1.05974 L .569 .698 0 r
F
.5127 .82311 m .50724 .8248 L .50842 .82148 L .336 .351 0 r
F
.5127 .82311 m .51259 .8268 L .50724 .8248 L F
.658 .60322 m .67548 .6117 L .66576 .61265 L .756 .734 0 r
F
.64877 .60464 m .658 .60322 L .66576 .61265 L .735 .721 0 r
F
.69498 .60944 m .71232 .62061 L .7022 .62126 L .824 .761 0 r
F
.68522 .61063 m .69498 .60944 L .7022 .62126 L .808 .751 0 r
F
.30196 .75074 m .29086 .73519 L .30141 .73729 L .871 .747 0 r
F
.31245 .75223 m .30196 .75074 L .30141 .73729 L .855 .736 0 r
F
.75298 .61709 m .7698 .63228 L .75937 .6327 L .897 .792 0 r
F
.74279 .61809 m .75298 .61709 L .75937 .6327 L .887 .786 0 r
F
.63139 .59812 m .64877 .60464 L .63956 .60591 L .694 .709 0 r
F
.62278 .59978 m .63139 .59812 L .63956 .60591 L .669 .692 0 r
F
.4589 .8017 m .44996 .80131 L .44631 .79741 L .43 .5 0 r
F
.46257 .80501 m .44996 .80131 L .4589 .8017 L .422 .491 0 r
F
.26878 1.04942 m .24136 1.03758 L .25012 1.03547 L .825 .817 0 r
F
.27691 1.0469 m .26878 1.04942 L .25012 1.03547 L .815 .812 0 r
F
.49603 .81595 m .49179 .81809 L .48701 .81565 L .365 .398 0 r
F
.50004 .81789 m .49179 .81809 L .49603 .81595 L .358 .387 0 r
F
.54037 .32794 m .54161 .32232 L .56696 .3232 L .962 .928 0 r
F
.51579 .32934 m .54161 .32232 L .54037 .32794 L 1 .957 0 r
F
.42361 .79094 m .41049 .78411 L .42067 .78574 L .542 .584 0 r
F
.43346 .79211 m .42361 .79094 L .42067 .78574 L .508 .56 0 r
F
.31195 1.0534 m .28505 1.04443 L .29321 1.04202 L .784 .804 0 r
F
.31941 1.05064 m .31195 1.0534 L .29321 1.04202 L .77 .797 0 r
F
.62946 .90681 m .62687 .92322 L .61931 .91151 L .866 .524 0 r
F
.62946 .90681 m .63773 .91632 L .62687 .92322 L F
.493 .56153 m .50261 .56245 L .50359 .56479 L .089 .103 0 r
F
.493 .56153 m .49093 .55922 L .50261 .56245 L F
.54751 1.05215 m .54944 1.05267 L .53036 1.05803 L .383 .152 0 r
F
.56522 1.0443 m .54944 1.05267 L .54751 1.05215 L .442 .157 0 r
F
.62118 .89722 m .61931 .91151 L .61174 .90001 L .741 .475 0 r
F
.62118 .89722 m .62946 .90681 L .61931 .91151 L F
.51699 .82462 m .51259 .8268 L .5127 .82311 L .33 .34 0 r
F
.51699 .82462 m .51794 .82868 L .51259 .8268 L F
.37049 .38314 m .38705 .36178 L .39229 .36801 L 1 .924 0 r
F
.37049 .38314 m .36433 .37679 L .38705 .36178 L F
.52944 1.05658 m .53036 1.05803 L .5111 1.06097 L .401 .215 0 r
F
.54751 1.05215 m .53036 1.05803 L .52944 1.05658 L .383 .152 0 r
F
.49219 .81393 m .48701 .81565 L .48248 .81311 L .372 .409 0 r
F
.49603 .81595 m .48701 .81565 L .49219 .81393 L .365 .398 0 r
F
.61289 .88784 m .61174 .90001 L .60418 .88926 L .604 .426 0 r
F
.61289 .88784 m .62118 .89722 L .61174 .90001 L F
.37823 1.05886 m .35262 1.05431 L .35935 1.0514 L .7 .774 0 r
F
.38414 1.05575 m .37823 1.05886 L .35935 1.0514 L .677 .76 0 r
F
.31245 .75223 m .30141 .73729 L .31196 .73951 L .855 .736 0 r
F
.32294 .75385 m .31245 .75223 L .31196 .73951 L .838 .725 0 r
F
.72167 .93987 m .71811 .9592 L .70933 .95409 L 1 .77 0 r
F
.72167 .93987 m .73103 .94441 L .71811 .9592 L F
.57399 .85551 m .57435 .86169 L .56761 .8547 L .302 .251 0 r
F
.57399 .85551 m .58154 .86282 L .57435 .86169 L F
.67404 .93057 m .67067 .94931 L .66247 .94197 L 1 .691 0 r
F
.67404 .93057 m .6829 .937 L .67067 .94931 L F
.51121 1.05885 m .5111 1.06097 L .49185 1.06205 L .429 .361 0 r
F
.52944 1.05658 m .5111 1.06097 L .51121 1.05885 L .401 .215 0 r
F
.58987 .59134 m .597 .58912 L .60609 .59497 L .565 .641 0 r
F
.58071 .58632 m .597 .58912 L .58987 .59134 L .534 .627 0 r
F
.37707 .77228 m .36495 .76181 L .37547 .7642 L .699 .659 0 r
F
.38745 .77409 m .37707 .77228 L .37547 .7642 L .668 .641 0 r
F
.53838 .83447 m .53754 .8384 L .53352 .83334 L .294 .277 0 r
F
.53838 .83447 m .54337 .83992 L .53754 .8384 L F
.52124 .82597 m .51794 .82868 L .51699 .82462 L .325 .33 0 r
F
.52124 .82597 m .52324 .83042 L .51794 .82868 L F
.41967 .36029 m .43963 .34288 L .44284 .34857 L 1 1 0 r
F
.41967 .36029 m .41543 .35438 L .43963 .34288 L F
.45409 1.05974 m .45094 1.06285 L .43182 1.05974 L .525 .655 0 r
F
.47278 1.06158 m .45094 1.06285 L .45409 1.05974 L .503 .623 0 r
F
.78115 .94368 m .77756 .96466 L .76829 .96087 L 1 .813 0 r
F
.78115 .94368 m .79094 .94695 L .77756 .96466 L F
.56547 .5844 m .57083 .58176 L .58071 .58632 L .473 .579 0 r
F
.55594 .58047 m .57083 .58176 L .56547 .5844 L .444 .546 0 r
F
.60461 .87891 m .60418 .88926 L .59663 .87952 L .483 .382 0 r
F
.60461 .87891 m .61289 .88784 L .60418 .88926 L F
.76318 .616 m .78023 .6318 L .7698 .63228 L .906 .798 0 r
F
.75298 .61709 m .76318 .616 L .7698 .63228 L .897 .792 0 r
F
.47092 .80505 m .46257 .80501 L .4589 .8017 L .409 .467 0 r
F
.4744 .8078 m .46257 .80501 L .47092 .80505 L .402 .457 0 r
F
.48857 .81183 m .48248 .81311 L .47827 .81049 L .379 .42 0 r
F
.49219 .81393 m .48248 .81311 L .48857 .81183 L .372 .409 0 r
F
.61401 .59299 m .63139 .59812 L .62278 .59978 L .647 .69 0 r
F
.60609 .59497 m .61401 .59299 L .62278 .59978 L .62 .671 0 r
F
.51579 .32934 m .51591 .32371 L .54161 .32232 L 1 .957 0 r
F
.49116 .33314 m .51591 .32371 L .51579 .32934 L 1 .991 0 r
F
.30075 .39217 m .31506 .36869 L .32215 .37462 L 1 .867 0 r
F
.30075 .39217 m .2929 .38658 L .31506 .36869 L F
.32294 .75385 m .31196 .73951 L .32251 .74188 L .838 .725 0 r
F
.33344 .75561 m .32294 .75385 L .32251 .74188 L .818 .713 0 r
F
.41049 .78411 m .39784 .77607 L .40824 .77822 L .589 .605 0 r
F
.42067 .78574 m .41049 .78411 L .40824 .77822 L .554 .583 0 r
F
.597 .58912 m .61401 .59299 L .60609 .59497 L .594 .664 0 r
F
.70475 .60815 m .72247 .61986 L .71232 .62061 L .838 .769 0 r
F
.69498 .60944 m .70475 .60815 L .71232 .62061 L .824 .761 0 r
F
.49298 1.0595 m .49185 1.06205 L .47278 1.06158 L .452 .476 0 r
F
.51121 1.05885 m .49185 1.06205 L .49298 1.0595 L .429 .361 0 r
F
.44284 .34857 m .46464 .33389 L .46675 .3395 L 1 1 0 r
F
.44284 .34857 m .43963 .34288 L .46464 .33389 L F
.66517 .92373 m .66247 .94197 L .65424 .93403 L 1 .662 0 r
F
.66517 .92373 m .67404 .93057 L .66247 .94197 L F
.33626 .38667 m .35195 .3643 L .35815 .37052 L 1 .887 0 r
F
.33626 .38667 m .32922 .3806 L .35195 .3643 L F
.59634 .87053 m .59663 .87952 L .58909 .87076 L .404 .35 0 r
F
.59634 .87053 m .60461 .87891 L .59663 .87952 L F
.52542 .82717 m .52324 .83042 L .52124 .82597 L .321 .322 0 r
F
.52542 .82717 m .52846 .83198 L .52324 .83042 L F
.7123 .93511 m .70933 .95409 L .70054 .94872 L 1 .754 0 r
F
.7123 .93511 m .72167 .93987 L .70933 .95409 L F
.62893 .31499 m .65998 .31752 L .65448 .32278 L .958 .881 0 r
F
.62443 .32049 m .62893 .31499 L .65448 .32278 L .947 .878 0 r
F
.49116 .33314 m .49016 .32752 L .51591 .32371 L 1 .991 0 r
F
.46675 .3395 m .49016 .32752 L .49116 .33314 L 1 1 0 r
F
.56696 .3232 m .56932 .3175 L .59511 .32067 L .953 .908 0 r
F
.54161 .32232 m .56932 .3175 L .56696 .3232 L .983 .931 0 r
F
.50359 .56479 m .51442 .56523 L .5143 .56775 L .19 .134 0 r
F
.50359 .56479 m .50261 .56245 L .51442 .56523 L F
.66725 .60166 m .68522 .61063 L .67548 .6117 L .776 .746 0 r
F
.658 .60322 m .66725 .60166 L .67548 .6117 L .756 .734 0 r
F
.33344 .75561 m .32251 .74188 L .33306 .7444 L .818 .713 0 r
F
.34394 .75752 m .33344 .75561 L .33306 .7444 L .796 .699 0 r
F
.48519 .80967 m .47827 .81049 L .4744 .8078 L .385 .43 0 r
F
.48857 .81183 m .47827 .81049 L .48519 .80967 L .379 .42 0 r
F
.46675 .3395 m .46464 .33389 L .49016 .32752 L 1 1 0 r
F
.44631 .79741 m .43346 .79211 L .44334 .79347 L .465 .532 0 r
F
.45578 .79836 m .44631 .79741 L .44334 .79347 L .438 .505 0 r
F
.4589 .8017 m .44631 .79741 L .45578 .79836 L .43 .5 0 r
F
.55409 .84189 m .55481 .84701 L .54891 .84111 L .293 .266 0 r
F
.55409 .84189 m .56086 .84815 L .55481 .84701 L F
.38745 .77409 m .37547 .7642 L .38599 .76676 L .668 .641 0 r
F
.39784 .77607 m .38745 .77409 L .38599 .76676 L .635 .621 0 r
F
.43346 .79211 m .42067 .78574 L .43086 .78755 L .508 .56 0 r
F
.44334 .79347 m .43346 .79211 L .43086 .78755 L .476 .534 0 r
F
.77135 .94032 m .76829 .96087 L .759 .95696 L 1 .805 0 r
F
.77135 .94032 m .78115 .94368 L .76829 .96087 L F
.77339 .61485 m .79068 .63125 L .78023 .6318 L .914 .803 0 r
F
.76318 .616 m .77339 .61485 L .78023 .6318 L .906 .798 0 r
F
.27691 1.0469 m .25012 1.03547 L .2589 1.03341 L .815 .812 0 r
F
.28505 1.04443 m .27691 1.0469 L .2589 1.03341 L .804 .806 0 r
F
.55594 .58047 m .56032 .57767 L .57083 .58176 L .444 .546 0 r
F
.54594 .5769 m .56032 .57767 L .55594 .58047 L .418 .5 0 r
F
.63139 .59812 m .64002 .59629 L .64877 .60464 L .694 .709 0 r
F
.64002 .59629 m .658 .60322 L .64877 .60464 L .718 .724 0 r
F
.35262 1.05431 m .32688 1.04794 L .33438 1.04531 L .729 .783 0 r
F
.35935 1.0514 m .35262 1.05431 L .33438 1.04531 L .71 .771 0 r
F
.46434 .54681 m .47318 .55413 L .47636 .55365 L .544 0 0 r
F
.46434 .54681 m .46013 .54656 L .47318 .55413 L F
.56644 .84869 m .56761 .8547 L .56086 .84815 L .309 .275 0 r
F
.56644 .84869 m .57399 .85551 L .56761 .8547 L F
.65628 .91646 m .65424 .93403 L .646 .92545 L .974 .631 0 r
F
.65628 .91646 m .66517 .92373 L .65424 .93403 L F
.54299 .83531 m .54337 .83992 L .53838 .83447 L .302 .286 0 r
F
.54299 .83531 m .54891 .84111 L .54337 .83992 L F
.39229 .36801 m .41117 .34833 L .41543 .35438 L 1 .973 0 r
F
.39229 .36801 m .38705 .36178 L .41117 .34833 L F
.44265 .52531 m .45144 .56419 L .45584 .55155 L 1 .093 0 r
F
.44265 .52531 m .43718 .54389 L .45144 .56419 L F
.31941 1.05064 m .29321 1.04202 L .30139 1.03967 L .77 .797 0 r
F
.32688 1.04794 m .31941 1.05064 L .30139 1.03967 L .756 .789 0 r
F
.66549 .31218 m .69768 .31768 L .69123 .32268 L .966 .872 0 r
F
.65998 .31752 m .66549 .31218 L .69123 .32268 L .957 .87 0 r
F
.46787 .80227 m .4589 .8017 L .45578 .79836 L .415 .475 0 r
F
.47092 .80505 m .4589 .8017 L .46787 .80227 L .409 .467 0 r
F
.34394 .75752 m .33306 .7444 L .34361 .74707 L .796 .699 0 r
F
.35444 .75958 m .34394 .75752 L .34361 .74707 L .771 .684 0 r
F
.58806 .86272 m .58909 .87076 L .58154 .86282 L .374 .332 0 r
F
.58806 .86272 m .59634 .87053 L .58909 .87076 L F
.59511 .32067 m .59856 .31502 L .62443 .32049 L .948 .891 0 r
F
.56932 .3175 m .59856 .31502 L .59511 .32067 L .969 .911 0 r
F
.59856 .31502 m .62893 .31499 L .62443 .32049 L .961 .894 0 r
F
.52948 .82819 m .52846 .83198 L .52542 .82717 L .32 .318 0 r
F
.52948 .82819 m .53352 .83334 L .52846 .83198 L F
.36433 .37679 m .38179 .35553 L .38705 .36178 L 1 .924 0 r
F
.36433 .37679 m .35815 .37052 L .38179 .35553 L F
.47494 1.05878 m .47278 1.06158 L .45409 1.05974 L .47 .554 0 r
F
.49298 1.0595 m .47278 1.06158 L .47494 1.05878 L .452 .476 0 r
F
.5143 .56775 m .52623 .56793 L .52501 .57064 L .274 .24 0 r
F
.5143 .56775 m .51442 .56523 L .52623 .56793 L F
.48209 .80747 m .4744 .8078 L .47092 .80505 L .392 .438 0 r
F
.48519 .80967 m .4744 .8078 L .48209 .80747 L .385 .43 0 r
F
.70291 .93012 m .70054 .94872 L .69173 .94303 L 1 .737 0 r
F
.70291 .93012 m .7123 .93511 L .70054 .94872 L F
.58071 .58632 m .587 .58377 L .597 .58912 L .534 .627 0 r
F
.57083 .58176 m .587 .58377 L .58071 .58632 L .498 .606 0 r
F
.42067 .78574 m .40824 .77822 L .41866 .78054 L .554 .583 0 r
F
.43086 .78755 m .42067 .78574 L .41866 .78054 L .519 .559 0 r
F
.71455 .60675 m .73262 .61902 L .72247 .61986 L .852 .777 0 r
F
.70475 .60815 m .71455 .60675 L .72247 .61986 L .838 .769 0 r
F
.54594 .5769 m .54931 .57404 L .56032 .57767 L .418 .5 0 r
F
.5356 .57365 m .54931 .57404 L .54594 .5769 L .384 .435 0 r
F
.4084 1.05848 m .38414 1.05575 L .39006 1.05275 L .637 .741 0 r
F
.41345 1.05538 m .4084 1.05848 L .39006 1.05275 L .605 .718 0 r
F
.43182 1.05974 m .4084 1.05848 L .41345 1.05538 L .587 .71 0 r
F
.78362 .61364 m .80113 .63065 L .79068 .63125 L .922 .807 0 r
F
.77339 .61485 m .78362 .61364 L .79068 .63125 L .914 .803 0 r
F
.2929 .38658 m .30795 .3628 L .31506 .36869 L 1 .87 0 r
F
.2929 .38658 m .28503 .38106 L .30795 .3628 L F
.76153 .93683 m .759 .95696 L .74969 .95293 L 1 .797 0 r
F
.76153 .93683 m .77135 .94032 L .759 .95696 L F
.64738 .90881 m .646 .92545 L .63773 .91632 L .918 .598 0 r
F
.64738 .90881 m .65628 .91646 L .646 .92545 L F
.39784 .77607 m .38599 .76676 L .39652 .76949 L .635 .621 0 r
F
.40824 .77822 m .39784 .77607 L .39652 .76949 L .599 .6 0 r
F
.43594 1.05665 m .43182 1.05974 L .41345 1.05538 L .549 .677 0 r
F
.45409 1.05974 m .43182 1.05974 L .43594 1.05665 L .525 .655 0 r
F
.52501 .57064 m .5379 .57082 L .5356 .57365 L .337 .348 0 r
F
.52501 .57064 m .52623 .56793 L .5379 .57082 L F
.35444 .75958 m .34361 .74707 L .35416 .74992 L .771 .684 0 r
F
.36495 .76181 m .35444 .75958 L .35416 .74992 L .744 .669 0 r
F
.5356 .57365 m .5379 .57082 L .54931 .57404 L .384 .435 0 r
F
.38414 1.05575 m .35935 1.0514 L .3661 1.04859 L .677 .76 0 r
F
.39006 1.05275 m .38414 1.05575 L .3661 1.04859 L .651 .743 0 r
F
.54161 .32232 m .54286 .31653 L .56932 .3175 L .983 .931 0 r
F
.51591 .32371 m .54286 .31653 L .54161 .32232 L 1 .959 0 r
F
.62195 .59084 m .64002 .59629 L .63139 .59812 L .674 .709 0 r
F
.61401 .59299 m .62195 .59084 L .63139 .59812 L .647 .69 0 r
F
.50641 .81667 m .50418 .81974 L .50004 .81789 L .358 .385 0 r
F
.50959 .81801 m .50418 .81974 L .50641 .81667 L .354 .378 0 r
F
.50959 .81801 m .50842 .82148 L .50418 .81974 L F
.67652 .59998 m .69498 .60944 L .68522 .61063 L .794 .757 0 r
F
.66725 .60166 m .67652 .59998 L .68522 .61063 L .776 .746 0 r
F
.5033 .81526 m .50004 .81789 L .49603 .81595 L .362 .392 0 r
F
.50641 .81667 m .50004 .81789 L .5033 .81526 L .358 .385 0 r
F
.63847 .90084 m .63773 .91632 L .62946 .90681 L .847 .564 0 r
F
.63847 .90084 m .64738 .90881 L .63773 .91632 L F
.51281 .81924 m .50842 .82148 L .50959 .81801 L .35 .37 0 r
F
.51281 .81924 m .5127 .82311 L .50842 .82148 L F
.50028 .81376 m .49603 .81595 L .49219 .81393 L .367 .398 0 r
F
.5033 .81526 m .49603 .81595 L .50028 .81376 L .362 .392 0 r
F
.32922 .3806 m .34573 .3581 L .35195 .3643 L 1 .891 0 r
F
.32922 .3806 m .32215 .37462 L .34573 .3581 L F
.6935 .92485 m .69173 .94303 L .6829 .937 L 1 .717 0 r
F
.6935 .92485 m .70291 .93012 L .69173 .94303 L F
.57978 .85542 m .58154 .86282 L .57399 .85551 L .357 .327 0 r
F
.57978 .85542 m .58806 .86272 L .58154 .86282 L F
.53337 .829 m .53352 .83334 L .52948 .82819 L .321 .318 0 r
F
.53337 .829 m .53838 .83447 L .53352 .83334 L F
.597 .58912 m .60416 .58673 L .61401 .59299 L .594 .664 0 r
F
.587 .58377 m .60416 .58673 L .597 .58912 L .563 .653 0 r
F
.47931 .80524 m .47092 .80505 L .46787 .80227 L .397 .446 0 r
F
.48209 .80747 m .47092 .80505 L .47931 .80524 L .392 .438 0 r
F
.41543 .35438 m .43642 .33697 L .43963 .34288 L 1 1 0 r
F
.41543 .35438 m .41117 .34833 L .43642 .33697 L F
.44334 .79347 m .43086 .78755 L .44108 .78954 L .476 .534 0 r
F
.45324 .795 m .44334 .79347 L .44108 .78954 L .447 .508 0 r
F
.45578 .79836 m .44334 .79347 L .45324 .795 L .438 .505 0 r
F
.62954 .89271 m .62946 .90681 L .62118 .89722 L .761 .529 0 r
F
.62954 .89271 m .63847 .90084 L .62946 .90681 L F
.51604 .82036 m .5127 .82311 L .51281 .81924 L .347 .364 0 r
F
.51604 .82036 m .51699 .82462 L .5127 .82311 L F
.36495 .76181 m .35416 .74992 L .36471 .75293 L .744 .669 0 r
F
.37547 .7642 m .36495 .76181 L .36471 .75293 L .713 .651 0 r
F
.4974 .8122 m .49219 .81393 L .48857 .81183 L .371 .405 0 r
F
.50028 .81376 m .49219 .81393 L .4974 .8122 L .367 .398 0 r
F
.79386 .61236 m .8116 .62998 L .80113 .63065 L .929 .812 0 r
F
.78362 .61364 m .79386 .61236 L .80113 .63065 L .922 .807 0 r
F
.60416 .58673 m .62195 .59084 L .61401 .59299 L .623 .686 0 r
F
.7517 .93322 m .74969 .95293 L .74037 .94875 L 1 .787 0 r
F
.7517 .93322 m .76153 .93683 L .74969 .95293 L F
.46528 .79948 m .45578 .79836 L .45324 .795 L .42 .48 0 r
F
.46787 .80227 m .45578 .79836 L .46528 .79948 L .415 .475 0 r
F
.28505 1.04443 m .2589 1.03341 L .26771 1.0314 L .804 .806 0 r
F
.29321 1.04202 m .28505 1.04443 L .26771 1.0314 L .793 .8 0 r
F
.55887 .84223 m .56086 .84815 L .55409 .84189 L .32 .301 0 r
F
.55887 .84223 m .56644 .84869 L .56086 .84815 L F
.54731 .83584 m .54891 .84111 L .54299 .83531 L .315 .303 0 r
F
.54731 .83584 m .55409 .84189 L .54891 .84111 L F
.72436 .60526 m .74279 .61809 L .73262 .61902 L .864 .784 0 r
F
.71455 .60675 m .72436 .60526 L .73262 .61902 L .852 .777 0 r
F
.64868 .59432 m .66725 .60166 L .658 .60322 L .74 .738 0 r
F
.64002 .59629 m .64868 .59432 L .658 .60322 L .718 .724 0 r
F
.49093 .55922 m .50162 .56063 L .50261 .56245 L 0 .098 0 r
F
.49093 .55922 m .48884 .55783 L .50162 .56063 L F
.56231 1.04711 m .56522 1.0443 L .54751 1.05215 L 0 0 0 r
F
.40824 .77822 m .39652 .76949 L .40706 .77238 L .599 .6 0 r
F
.41866 .78054 m .40824 .77822 L .40706 .77238 L .563 .578 0 r
F
.62062 .88457 m .62118 .89722 L .61289 .88784 L .666 .494 0 r
F
.62062 .88457 m .62954 .89271 L .62118 .89722 L F
.43086 .78755 m .41866 .78054 L .42909 .78303 L .519 .559 0 r
F
.44108 .78954 m .43086 .78755 L .42909 .78303 L .484 .534 0 r
F
.45725 1.05682 m .45409 1.05974 L .43594 1.05665 L .484 .605 0 r
F
.47494 1.05878 m .45409 1.05974 L .45725 1.05682 L .47 .554 0 r
F
.57083 .58176 m .57621 .57898 L .587 .58377 L .498 .606 0 r
F
.56032 .57767 m .57621 .57898 L .57083 .58176 L .461 .575 0 r
F
.54558 1.05271 m .54751 1.05215 L .53281 1.05575 L 0 0 0 r
F
.54558 1.05271 m .53281 1.05575 L .53344 1.05562 L F
.53344 1.05562 m .53281 1.05575 L .52944 1.05658 L F
.54558 1.05271 m .52944 1.05658 L .52853 1.05576 L F
.54365 1.05424 m .54558 1.05271 L .53021 1.05545 L .075 0 0 r
F
.53096 1.05551 m .53021 1.05545 L .52853 1.05576 L F
.54365 1.05424 m .53021 1.05545 L .53096 1.05551 L F
.53791 1.05469 m .52853 1.05576 L .5276 1.05549 L F
.53675 1.05493 m .52853 1.05576 L .53791 1.05469 L F
.5395 1.05616 m .5276 1.05549 L .52668 1.05561 L .228 0 0 r
F
.5417 1.05626 m .53842 1.05608 L .5395 1.05616 L F
.53842 1.05608 m .5276 1.05549 L .5395 1.05616 L F
.54365 1.05424 m .53675 1.05493 L .53791 1.05469 L .075 0 0 r
F
.56231 1.04711 m .54751 1.05215 L .54558 1.05271 L 0 0 0 r
F
.2064 .72206 m .19583 .72076 L .19771 .70012 L .974 .81 0 r
F
.51924 .82136 m .51699 .82462 L .51604 .82036 L .344 .357 0 r
F
.51924 .82136 m .52124 .82597 L .51699 .82462 L F
.52853 1.05576 m .52944 1.05658 L .51121 1.05885 L .268 .139 0 r
F
.49467 .81058 m .48857 .81183 L .48519 .80967 L .375 .411 0 r
F
.4974 .8122 m .48857 .81183 L .49467 .81058 L .371 .405 0 r
F
.2064 .72206 m .19771 .70012 L .20827 .70209 L .974 .81 0 r
F
.21696 .72343 m .2064 .72206 L .20827 .70209 L .969 .805 0 r
F
.21696 .72343 m .20827 .70209 L .21882 .70413 L F
.22753 .72485 m .21696 .72343 L .21882 .70413 L .963 .8 0 r
F
.51591 .32371 m .51603 .31788 L .54286 .31653 L 1 .959 0 r
F
.49016 .32752 m .51603 .31788 L .51591 .32371 L 1 .988 0 r
F
.63344 .30939 m .66549 .31218 L .65998 .31752 L .968 .883 0 r
F
.62893 .31499 m .63344 .30939 L .65998 .31752 L .958 .881 0 r
F
.22753 .72485 m .21882 .70413 L .22937 .70623 L .963 .8 0 r
F
.23809 .72636 m .22753 .72485 L .22937 .70623 L .957 .793 0 r
F
.68407 .91929 m .6829 .937 L .67404 .93057 L .991 .696 0 r
F
.68407 .91929 m .6935 .92485 L .6829 .937 L F
.51132 1.05716 m .51121 1.05885 L .49298 1.0595 L .349 .209 0 r
F
.52853 1.05576 m .51121 1.05885 L .51132 1.05716 L .268 .139 0 r
F
.23809 .72636 m .22937 .70623 L .23992 .70842 L .957 .793 0 r
F
.24864 .72793 m .23809 .72636 L .23992 .70842 L .949 .787 0 r
F
.43963 .34288 m .46251 .32804 L .46464 .33389 L 1 1 0 r
F
.43963 .34288 m .43642 .33697 L .46251 .32804 L F
.61169 .87658 m .61289 .88784 L .60461 .87891 L .572 .46 0 r
F
.61169 .87658 m .62062 .88457 L .61289 .88784 L F
.32688 1.04794 m .30139 1.03967 L .30959 1.03738 L .756 .789 0 r
F
.33438 1.04531 m .32688 1.04794 L .30959 1.03738 L .74 .779 0 r
F
.37547 .7642 m .36471 .75293 L .37527 .75612 L .713 .651 0 r
F
.38599 .76676 m .37547 .7642 L .37527 .75612 L .68 .633 0 r
F
.35935 1.0514 m .33438 1.04531 L .3419 1.04276 L .71 .771 0 r
F
.3661 1.04859 m .35935 1.0514 L .3419 1.04276 L .689 .759 0 r
F
.24864 .72793 m .23992 .70842 L .25045 .71068 L .949 .787 0 r
F
.2592 .7296 m .24864 .72793 L .25045 .71068 L .941 .78 0 r
F
.80412 .61103 m .82207 .62927 L .8116 .62998 L .935 .816 0 r
F
.79386 .61236 m .80412 .61103 L .8116 .62998 L .929 .812 0 r
F
.56932 .3175 m .57168 .31167 L .59856 .31502 L .969 .911 0 r
F
.54286 .31653 m .57168 .31167 L .56932 .3175 L 1 .933 0 r
F
.74186 .92947 m .74037 .94875 L .73103 .94441 L 1 .776 0 r
F
.74186 .92947 m .7517 .93322 L .74037 .94875 L F
.2592 .7296 m .25045 .71068 L .26098 .71305 L .941 .78 0 r
F
.26975 .73136 m .2592 .7296 L .26098 .71305 L .931 .772 0 r
F
.35815 .37052 m .37651 .34926 L .38179 .35553 L 1 .924 0 r
F
.35815 .37052 m .35195 .3643 L .37651 .34926 L F
.47687 .80299 m .46787 .80227 L .46528 .79948 L .402 .452 0 r
F
.47931 .80524 m .46787 .80227 L .47687 .80299 L .397 .446 0 r
F
.52237 .82223 m .52124 .82597 L .51924 .82136 L .341 .352 0 r
F
.52237 .82223 m .52542 .82717 L .52124 .82597 L F
.53706 .82959 m .53838 .83447 L .53337 .829 L .325 .323 0 r
F
.53706 .82959 m .54299 .83531 L .53838 .83447 L F
.38705 .36178 m .4069 .34217 L .41117 .34833 L 1 .966 0 r
F
.38705 .36178 m .38179 .35553 L .4069 .34217 L F
.57149 .84857 m .57399 .85551 L .56644 .84869 L .349 .331 0 r
F
.57149 .84857 m .57978 .85542 L .57399 .85551 L F
.49214 .80893 m .48519 .80967 L .48209 .80747 L .379 .417 0 r
F
.49467 .81058 m .48519 .80967 L .49214 .80893 L .375 .411 0 r
F
.49016 .32752 m .48915 .32169 L .51603 .31788 L 1 .988 0 r
F
.46464 .33389 m .48915 .32169 L .49016 .32752 L 1 1 0 r
F
.66549 .31218 m .67103 .30676 L .69768 .31768 L .966 .872 0 r
F
.46464 .33389 m .46251 .32804 L .48915 .32169 L 1 1 0 r
F
.26975 .73136 m .26098 .71305 L .27151 .71551 L .931 .772 0 r
F
.28031 .73322 m .26975 .73136 L .27151 .71551 L .921 .763 0 r
F
.68582 .59819 m .70475 .60815 L .69498 .60944 L .811 .766 0 r
F
.67652 .59998 m .68582 .59819 L .69498 .60944 L .794 .757 0 r
F
.49412 1.05726 m .49298 1.0595 L .47494 1.05878 L .4 .365 0 r
F
.51132 1.05716 m .49298 1.0595 L .49412 1.05726 L .349 .209 0 r
F
.60276 .86886 m .60461 .87891 L .59634 .87053 L .489 .43 0 r
F
.60276 .86886 m .61169 .87658 L .60461 .87891 L F
.28031 .73322 m .27151 .71551 L .28203 .71809 L .921 .763 0 r
F
.29086 .73519 m .28031 .73322 L .28203 .71809 L .908 .754 0 r
F
.67463 .91342 m .67404 .93057 L .66517 .92373 L .962 .673 0 r
F
.67463 .91342 m .68407 .91929 L .67404 .93057 L F
.25012 1.03547 m .24136 1.03758 L .22458 1.02193 L .833 .813 0 r
F
.73418 .60369 m .75298 .61709 L .74279 .61809 L .875 .791 0 r
F
.72436 .60526 m .73418 .60369 L .74279 .61809 L .864 .784 0 r
F
.41866 .78054 m .40706 .77238 L .41761 .77542 L .563 .578 0 r
F
.42909 .78303 m .41866 .78054 L .41761 .77542 L .525 .555 0 r
F
.29086 .73519 m .28203 .71809 L .29254 .7208 L .908 .754 0 r
F
.30141 .73729 m .29086 .73519 L .29254 .7208 L .894 .743 0 r
F
.38599 .76676 m .37527 .75612 L .38583 .75948 L .68 .633 0 r
F
.39652 .76949 m .38599 .76676 L .38583 .75948 L .644 .613 0 r
F
.60202 .30925 m .63344 .30939 L .62893 .31499 L .973 .896 0 r
F
.59856 .31502 m .60202 .30925 L .62893 .31499 L .961 .894 0 r
F
.56032 .57767 m .56473 .57475 L .57621 .57898 L .461 .575 0 r
F
.54931 .57404 m .56473 .57475 L .56032 .57767 L .433 .527 0 r
F
.57168 .31167 m .60202 .30925 L .59856 .31502 L .983 .913 0 r
F
.52542 .82295 m .52542 .82717 L .52237 .82223 L .34 .349 0 r
F
.52542 .82295 m .52948 .82819 L .52542 .82717 L F
.48981 .80725 m .48209 .80747 L .47931 .80524 L .383 .423 0 r
F
.49214 .80893 m .48209 .80747 L .48981 .80725 L .379 .417 0 r
F
.45324 .795 m .44108 .78954 L .45131 .79168 L .447 .508 0 r
F
.46317 .7967 m .45324 .795 L .45131 .79168 L .424 .483 0 r
F
.46528 .79948 m .45324 .795 L .46317 .7967 L .42 .48 0 r
F
.32215 .37462 m .33948 .35194 L .34573 .3581 L 1 .893 0 r
F
.32215 .37462 m .31506 .36869 L .33948 .35194 L F
.62195 .59084 m .62991 .58853 L .64002 .59629 L .674 .709 0 r
F
.62991 .58853 m .64868 .59432 L .64002 .59629 L .7 .725 0 r
F
.50261 .56245 m .51454 .56295 L .51442 .56523 L .155 .116 0 r
F
.50261 .56245 m .50162 .56063 L .51454 .56295 L F
.30141 .73729 m .29254 .7208 L .30305 .72364 L .894 .743 0 r
F
.31196 .73951 m .30141 .73729 L .30305 .72364 L .878 .732 0 r
F
.80412 .61103 m .81438 .60965 L .82207 .62927 L .935 .816 0 r
F
.41345 1.05538 m .39006 1.05275 L .396 1.04986 L .605 .718 0 r
F
.41851 1.05241 m .41345 1.05538 L .396 1.04986 L .572 .692 0 r
F
.43594 1.05665 m .41345 1.05538 L .41851 1.05241 L .549 .677 0 r
F
.732 .92555 m .73103 .94441 L .72167 .93987 L 1 .764 0 r
F
.732 .92555 m .74186 .92947 L .73103 .94441 L F
.587 .58377 m .59332 .58106 L .60416 .58673 L .563 .653 0 r
F
.57621 .57898 m .59332 .58106 L .587 .58377 L .528 .635 0 r
F
.44108 .78954 m .42909 .78303 L .43954 .78566 L .484 .534 0 r
F
.45131 .79168 m .44108 .78954 L .43954 .78566 L .453 .509 0 r
F
.59383 .86148 m .59634 .87053 L .58806 .86272 L .428 .407 0 r
F
.59383 .86148 m .60276 .86886 L .59634 .87053 L F
.55129 .83603 m .55409 .84189 L .54731 .83584 L .332 .326 0 r
F
.55129 .83603 m .55887 .84223 L .55409 .84189 L F
.48674 .55741 m .48462 .55771 L .48699 .55776 L .071 0 0 r
F
.48674 .55741 m .49962 .55803 L .50062 .55923 L F
.48674 .55741 m .48699 .55776 L .49962 .55803 L F
.48649 .55705 m .48674 .55741 L .48884 .55783 L .322 0 0 r
F
.47636 .55365 m .48674 .55741 L .48649 .55705 L F
.66518 .90724 m .66517 .92373 L .65628 .91646 L .926 .648 0 r
F
.66518 .90724 m .67463 .91342 L .66517 .92373 L F
.31196 .73951 m .30305 .72364 L .31355 .72663 L .878 .732 0 r
F
.32251 .74188 m .31196 .73951 L .31355 .72663 L .86 .72 0 r
F
.29321 1.04202 m .26771 1.0314 L .27652 1.02944 L .793 .8 0 r
F
.30139 1.03967 m .29321 1.04202 L .27652 1.02944 L .78 .793 0 r
F
.39006 1.05275 m .3661 1.04859 L .37287 1.04587 L .651 .743 0 r
F
.396 1.04986 m .39006 1.05275 L .37287 1.04587 L .624 .724 0 r
F
.65736 .59221 m .67652 .59998 L .66725 .60166 L .761 .75 0 r
F
.64868 .59432 m .65736 .59221 L .66725 .60166 L .74 .738 0 r
F
.4771 1.05622 m .47494 1.05878 L .45725 1.05682 L .434 .477 0 r
F
.49412 1.05726 m .47494 1.05878 L .4771 1.05622 L .4 .365 0 r
F
.4748 .80075 m .46528 .79948 L .46317 .7967 L .406 .456 0 r
F
.47687 .80299 m .46528 .79948 L .4748 .80075 L .402 .452 0 r
F
.44008 1.05373 m .43594 1.05665 L .41851 1.05241 L .51 .64 0 r
F
.45725 1.05682 m .43594 1.05665 L .44008 1.05373 L .484 .605 0 r
F
.54052 .82994 m .54299 .83531 L .53706 .82959 L .333 .333 0 r
F
.54052 .82994 m .54731 .83584 L .54299 .83531 L F
.56319 .84207 m .56644 .84869 L .55887 .84223 L .348 .34 0 r
F
.56319 .84207 m .57149 .84857 L .56644 .84869 L F
.32251 .74188 m .31355 .72663 L .32405 .72977 L .86 .72 0 r
F
.33306 .7444 m .32251 .74188 L .32405 .72977 L .839 .706 0 r
F
.81186 .93148 m .81048 .95322 L .80071 .95013 L 1 .819 0 r
F
.81186 .93148 m .82205 .93402 L .81048 .95322 L F
.39652 .76949 m .38583 .75948 L .39639 .76299 L .644 .613 0 r
F
.40706 .77238 m .39652 .76949 L .39639 .76299 L .606 .593 0 r
F
.54931 .57404 m .55269 .57108 L .56473 .57475 L .433 .527 0 r
F
.5379 .57082 m .55269 .57108 L .54931 .57404 L .398 .456 0 r
F
.46013 .54656 m .46996 .55676 L .47318 .55413 L .66 .017 0 r
F
.46013 .54656 m .45584 .55155 L .46996 .55676 L F
.48773 .80555 m .47931 .80524 L .47687 .80299 L .387 .427 0 r
F
.48981 .80725 m .47931 .80524 L .48773 .80555 L .383 .423 0 r
F
.52834 .82351 m .52948 .82819 L .52542 .82295 L .341 .349 0 r
F
.52834 .82351 m .53337 .829 L .52948 .82819 L F
.61133 .58417 m .62991 .58853 L .62195 .59084 L .652 .707 0 r
F
.60416 .58673 m .61133 .58417 L .62195 .59084 L .623 .686 0 r
F
.65572 .90075 m .65628 .91646 L .64738 .90881 L .882 .621 0 r
F
.65572 .90075 m .66518 .90724 L .65628 .91646 L F
.59332 .58106 m .61133 .58417 L .60416 .58673 L .594 .678 0 r
F
.41117 .34833 m .4332 .33089 L .43642 .33697 L 1 .998 0 r
F
.41117 .34833 m .4069 .34217 L .4332 .33089 L F
.54286 .31653 m .54411 .31058 L .57168 .31167 L 1 .933 0 r
F
.51603 .31788 m .54411 .31058 L .54286 .31653 L 1 .958 0 r
F
.72213 .92146 m .72167 .93987 L .7123 .93511 L .996 .751 0 r
F
.72213 .92146 m .732 .92555 L .72167 .93987 L F
.51442 .56523 m .52745 .5653 L .52623 .56793 L .269 .214 0 r
F
.51442 .56523 m .51454 .56295 L .52745 .5653 L F
.58489 .85446 m .58806 .86272 L .57978 .85542 L .399 .39 0 r
F
.58489 .85446 m .59383 .86148 L .58806 .86272 L F
.42909 .78303 m .41761 .77542 L .42818 .7786 L .525 .555 0 r
F
.43954 .78566 m .42909 .78303 L .42818 .7786 L .489 .53 0 r
F
.74403 .60203 m .76318 .616 L .75298 .61709 L .885 .797 0 r
F
.73418 .60369 m .74403 .60203 L .75298 .61709 L .875 .791 0 r
F
.33306 .7444 m .32405 .72977 L .33454 .73309 L .839 .706 0 r
F
.34361 .74707 m .33306 .7444 L .33454 .73309 L .816 .692 0 r
F
.69513 .59628 m .71455 .60675 L .70475 .60815 L .826 .775 0 r
F
.68582 .59819 m .69513 .59628 L .70475 .60815 L .811 .766 0 r
F
.5379 .57082 m .54022 .56796 L .55269 .57108 L .398 .456 0 r
F
.52623 .56793 m .54022 .56796 L .5379 .57082 L .346 .352 0 r
F
.33438 1.04531 m .30959 1.03738 L .31781 1.03516 L .74 .779 0 r
F
.3419 1.04276 m .33438 1.04531 L .31781 1.03516 L .722 .769 0 r
F
.50657 .81254 m .5033 .81526 L .50028 .81376 L .367 .396 0 r
F
.50865 .8135 m .5033 .81526 L .50657 .81254 L .365 .392 0 r
F
.50865 .8135 m .50641 .81667 L .5033 .81526 L F
.51078 .8144 m .50641 .81667 L .50865 .8135 L .363 .388 0 r
F
.51078 .8144 m .50959 .81801 L .50641 .81667 L F
.52623 .56793 m .52745 .5653 L .54022 .56796 L .346 .352 0 r
F
.64624 .89401 m .64738 .90881 L .63847 .90084 L .827 .594 0 r
F
.64624 .89401 m .65572 .90075 L .64738 .90881 L F
.34361 .74707 m .33454 .73309 L .34503 .73658 L .816 .692 0 r
F
.35416 .74992 m .34361 .74707 L .34503 .73658 L .789 .676 0 r
F
.25012 1.03547 m .22458 1.02193 L .23393 1.02032 L .833 .813 0 r
F
.2589 1.03341 m .25012 1.03547 L .23393 1.02032 L .824 .808 0 r
F
.50455 .81152 m .50028 .81376 L .4974 .8122 L .368 .399 0 r
F
.50657 .81254 m .50028 .81376 L .50455 .81152 L .367 .396 0 r
F
.51293 .81523 m .50959 .81801 L .51078 .8144 L .36 .384 0 r
F
.51293 .81523 m .51281 .81924 L .50959 .81801 L F
.80165 .92887 m .80071 .95013 L .79094 .94695 L 1 .813 0 r
F
.80165 .92887 m .81186 .93148 L .80071 .95013 L F
.35195 .3643 m .37121 .34297 L .37651 .34926 L 1 .923 0 r
F
.35195 .3643 m .34573 .3581 L .37121 .34297 L F
.63797 .3037 m .67103 .30676 L .66549 .31218 L .976 .885 0 r
F
.63344 .30939 m .63797 .3037 L .66549 .31218 L .968 .883 0 r
F
.3661 1.04859 m .3419 1.04276 L .34943 1.04029 L .689 .759 0 r
F
.37287 1.04587 m .3661 1.04859 L .34943 1.04029 L .667 .744 0 r
F
.40706 .77238 m .39639 .76299 L .40697 .76666 L .606 .593 0 r
F
.41761 .77542 m .40706 .77238 L .40697 .76666 L .567 .571 0 r
F
.50263 .81046 m .4974 .8122 L .49467 .81058 L .37 .402 0 r
F
.50455 .81152 m .4974 .8122 L .50263 .81046 L .368 .399 0 r
F
.51508 .81597 m .51281 .81924 L .51293 .81523 L .358 .38 0 r
F
.51508 .81597 m .51604 .82036 L .51281 .81924 L F
.4859 .80385 m .47687 .80299 L .4748 .80075 L .39 .432 0 r
F
.48773 .80555 m .47687 .80299 L .4859 .80385 L .387 .427 0 r
F
.45131 .79168 m .43954 .78566 L .45 .78843 L .453 .509 0 r
F
.46156 .79397 m .45131 .79168 L .45 .78843 L .427 .484 0 r
F
.46317 .7967 m .45131 .79168 L .46156 .79397 L .424 .483 0 r
F
.71225 .91717 m .7123 .93511 L .70291 .93012 L .983 .736 0 r
F
.71225 .91717 m .72213 .92146 L .7123 .93511 L F
.63676 .88707 m .63847 .90084 L .62954 .89271 L .764 .566 0 r
F
.63676 .88707 m .64624 .89401 L .63847 .90084 L F
.53111 .82391 m .53337 .829 L .52834 .82351 L .343 .352 0 r
F
.53111 .82391 m .53706 .82959 L .53337 .829 L F
.38179 .35553 m .40261 .33592 L .4069 .34217 L 1 .96 0 r
F
.38179 .35553 m .37651 .34926 L .40261 .33592 L F
.35416 .74992 m .34503 .73658 L .35552 .74026 L .789 .676 0 r
F
.36471 .75293 m .35416 .74992 L .35552 .74026 L .76 .66 0 r
F
.57621 .57898 m .58161 .57603 L .59332 .58106 L .528 .635 0 r
F
.56473 .57475 m .58161 .57603 L .57621 .57898 L .488 .606 0 r
F
.47311 .79855 m .46317 .7967 L .46156 .79397 L .409 .459 0 r
F
.4748 .80075 m .46317 .7967 L .47311 .79855 L .406 .456 0 r
F
.57596 .84778 m .57978 .85542 L .57149 .84857 L .383 .381 0 r
F
.57596 .84778 m .58489 .85446 L .57978 .85542 L F
.46042 1.0541 m .45725 1.05682 L .44008 1.05373 L .458 .55 0 r
F
.4771 1.05622 m .45725 1.05682 L .46042 1.0541 L .434 .477 0 r
F
.43642 .33697 m .46038 .32201 L .46251 .32804 L 1 1 0 r
F
.43642 .33697 m .4332 .33089 L .46038 .32201 L F
.50081 .80936 m .49467 .81058 L .49214 .80893 L .372 .405 0 r
F
.50263 .81046 m .49467 .81058 L .50081 .80936 L .37 .402 0 r
F
.51722 .81663 m .51604 .82036 L .51508 .81597 L .357 .377 0 r
F
.51722 .81663 m .51924 .82136 L .51604 .82036 L F
.51603 .31788 m .51615 .31188 L .54411 .31058 L 1 .958 0 r
F
.48915 .32169 m .51615 .31188 L .51603 .31788 L 1 .983 0 r
F
.31506 .36869 m .33322 .34578 L .33948 .35194 L 1 .894 0 r
F
.31506 .36869 m .30795 .3628 L .33322 .34578 L F
.5437 .83002 m .54731 .83584 L .54052 .82994 L .343 .347 0 r
F
.5437 .83002 m .55129 .83603 L .54731 .83584 L F
.55489 .83585 m .55887 .84223 L .55129 .83603 L .351 .352 0 r
F
.55489 .83585 m .56319 .84207 L .55887 .84223 L F
.62727 .88003 m .62954 .89271 L .62062 .88457 L .693 .538 0 r
F
.62727 .88003 m .63676 .88707 L .62954 .89271 L F
.79144 .92617 m .79094 .94695 L .78115 .94368 L 1 .806 0 r
F
.79144 .92617 m .80165 .92887 L .79094 .94695 L F
.75389 .6003 m .77339 .61485 L .76318 .616 L .895 .802 0 r
F
.74403 .60203 m .75389 .6003 L .76318 .616 L .885 .797 0 r
F
.43954 .78566 m .42818 .7786 L .43875 .7819 L .489 .53 0 r
F
.45 .78843 m .43954 .78566 L .43875 .7819 L .456 .506 0 r
F
.6379 .58607 m .65736 .59221 L .64868 .59432 L .724 .741 0 r
F
.62991 .58853 m .6379 .58607 L .64868 .59432 L .7 .725 0 r
F
.36471 .75293 m .35552 .74026 L .36601 .74412 L .76 .66 0 r
F
.37527 .75612 m .36471 .75293 L .36601 .74412 L .726 .642 0 r
F
.57168 .31167 m .57406 .30572 L .60202 .30925 L .983 .913 0 r
F
.54411 .31058 m .57406 .30572 L .57168 .31167 L 1 .934 0 r
F
.30139 1.03967 m .27652 1.02944 L .28536 1.02755 L .78 .793 0 r
F
.30959 1.03738 m .30139 1.03967 L .28536 1.02755 L .767 .785 0 r
F
.66607 .58997 m .68582 .59819 L .67652 .59998 L .78 .762 0 r
F
.65736 .59221 m .66607 .58997 L .67652 .59998 L .761 .75 0 r
F
.49912 .80824 m .49214 .80893 L .48981 .80725 L .375 .408 0 r
F
.50081 .80936 m .49214 .80893 L .49912 .80824 L .372 .405 0 r
F
.51931 .8172 m .51924 .82136 L .51722 .81663 L .355 .374 0 r
F
.51931 .8172 m .52237 .82223 L .51924 .82136 L F
.70235 .91267 m .70291 .93012 L .6935 .92485 L .966 .72 0 r
F
.70235 .91267 m .71225 .91717 L .70291 .93012 L F
.46251 .32804 m .48814 .31567 L .48915 .32169 L 1 1 0 r
F
.46251 .32804 m .46038 .32201 L .48814 .31567 L F
.61778 .87299 m .62062 .88457 L .61169 .87658 L .618 .51 0 r
F
.61778 .87299 m .62727 .88003 L .62062 .88457 L F
.41761 .77542 m .40697 .76666 L .41754 .77045 L .567 .571 0 r
F
.42818 .7786 m .41761 .77542 L .41754 .77045 L .528 .548 0 r
F
.48915 .32169 m .48814 .31567 L .51615 .31188 L 1 .983 0 r
F
.48884 .55783 m .50062 .55923 L .50162 .56063 L 0 .093 0 r
F
.52382 1.05546 m .51143 1.05585 L .51154 1.05485 L .001 0 0 r
F
.5276 1.05549 m .51132 1.05716 L .51143 1.05585 L .122 .121 0 r
F
.52668 1.05561 m .5276 1.05549 L .51257 1.05583 L .001 0 0 r
F
.51337 1.05582 m .51257 1.05583 L .51143 1.05585 L F
.52668 1.05561 m .51257 1.05583 L .51337 1.05582 L F
.52238 1.05568 m .51143 1.05585 L .52382 1.05546 L F
.52668 1.05561 m .52238 1.05568 L .52382 1.05546 L F
.5276 1.05549 m .52853 1.05576 L .51365 1.05697 L .122 .121 0 r
F
.5276 1.05549 m .51365 1.05697 L .5147 1.05681 L F
.52575 1.0558 m .52668 1.05561 L .51154 1.05485 L .079 0 0 r
F
.52517 1.05573 m .51154 1.05485 L .51165 1.05401 L F
.52575 1.0558 m .52471 1.05573 L .52517 1.05573 L F
.52471 1.05573 m .51154 1.05485 L .52517 1.05573 L F
.5147 1.05681 m .51365 1.05697 L .51132 1.05716 L .122 .121 0 r
F
.70446 .59427 m .72436 .60526 L .71455 .60675 L .84 .783 0 r
F
.69513 .59628 m .70446 .59427 L .71455 .60675 L .826 .775 0 r
F
.60549 .30339 m .63797 .3037 L .63344 .30939 L .983 .898 0 r
F
.60202 .30925 m .60549 .30339 L .63344 .30939 L .973 .896 0 r
F
.51143 1.05585 m .51132 1.05716 L .49412 1.05726 L .259 .135 0 r
F
.48434 .80217 m .4748 .80075 L .47311 .79855 L .393 .435 0 r
F
.4859 .80385 m .4748 .80075 L .48434 .80217 L .39 .432 0 r
F
.57472 1.0491 m .57851 1.03516 L .56231 1.04711 L .358 .004 0 r
F
.5337 .82412 m .53706 .82959 L .53111 .82391 L .347 .357 0 r
F
.5337 .82412 m .54052 .82994 L .53706 .82959 L F
.37527 .75612 m .36601 .74412 L .37649 .74815 L .726 .642 0 r
F
.38583 .75948 m .37527 .75612 L .37649 .74815 L .69 .623 0 r
F
.60828 .86605 m .61169 .87658 L .60276 .86886 L .547 .483 0 r
F
.60828 .86605 m .61778 .87299 L .61169 .87658 L F
.49756 .8071 m .48981 .80725 L .48773 .80555 L .377 .411 0 r
F
.49912 .80824 m .48981 .80725 L .49756 .8071 L .375 .408 0 r
F
.5594 1.0521 m .54558 1.05271 L .54365 1.05424 L .265 0 0 r
F
.5594 1.0521 m .56231 1.04711 L .54558 1.05271 L F
.56701 .84141 m .57149 .84857 L .56319 .84207 L .374 .378 0 r
F
.56701 .84141 m .57596 .84778 L .57149 .84857 L F
.52135 .81766 m .52237 .82223 L .51931 .8172 L .354 .372 0 r
F
.52135 .81766 m .52542 .82295 L .52237 .82223 L F
.57406 .30572 m .60549 .30339 L .60202 .30925 L .994 .914 0 r
F
.78121 .92338 m .78115 .94368 L .77135 .94032 L .996 .799 0 r
F
.78121 .92338 m .79144 .92617 L .78115 .94368 L F
.41851 1.05241 m .396 1.04986 L .40196 1.04709 L .572 .692 0 r
F
.42359 1.04959 m .41851 1.05241 L .40196 1.04709 L .538 .663 0 r
F
.44008 1.05373 m .41851 1.05241 L .42359 1.04959 L .51 .64 0 r
F
.2589 1.03341 m .23393 1.02032 L .24329 1.01875 L .824 .808 0 r
F
.26771 1.0314 m .2589 1.03341 L .24329 1.01875 L .814 .803 0 r
F
.59332 .58106 m .59965 .57817 L .61133 .58417 L .594 .678 0 r
F
.58161 .57603 m .59965 .57817 L .59332 .58106 L .561 .663 0 r
F
.69244 .90793 m .6935 .92485 L .68407 .91929 L .945 .702 0 r
F
.69244 .90793 m .70235 .91267 L .6935 .92485 L F
.49527 1.05532 m .49412 1.05726 L .4771 1.05622 L .343 .261 0 r
F
.51143 1.05585 m .49412 1.05726 L .49527 1.05532 L .259 .135 0 r
F
.396 1.04986 m .37287 1.04587 L .37965 1.04326 L .624 .724 0 r
F
.40196 1.04709 m .396 1.04986 L .37965 1.04326 L .595 .703 0 r
F
.57472 1.0491 m .56231 1.04711 L .5594 1.0521 L .358 .004 0 r
F
.56473 .57475 m .56915 .57167 L .58161 .57603 L .488 .606 0 r
F
.55269 .57108 m .56915 .57167 L .56473 .57475 L .452 .561 0 r
F
.46156 .79397 m .45 .78843 L .46048 .79133 L .427 .484 0 r
F
.47184 .79639 m .46156 .79397 L .46048 .79133 L .411 .46 0 r
F
.47311 .79855 m .46156 .79397 L .47184 .79639 L .409 .459 0 r
F
.59879 .85927 m .60276 .86886 L .59383 .86148 L .485 .459 0 r
F
.59879 .85927 m .60828 .86605 L .60276 .86886 L F
.61133 .58417 m .61854 .58144 L .62991 .58853 L .652 .707 0 r
F
.61854 .58144 m .6379 .58607 L .62991 .58853 L .679 .725 0 r
F
.38583 .75948 m .37649 .74815 L .38698 .75235 L .69 .623 0 r
F
.39639 .76299 m .38583 .75948 L .38698 .75235 L .651 .603 0 r
F
.42818 .7786 m .41754 .77045 L .42813 .77435 L .528 .548 0 r
F
.43875 .7819 m .42818 .7786 L .42813 .77435 L .49 .524 0 r
F
.76377 .5985 m .78362 .61364 L .77339 .61485 L .903 .807 0 r
F
.75389 .6003 m .76377 .5985 L .77339 .61485 L .895 .802 0 r
F
.49617 .80596 m .48773 .80555 L .4859 .80385 L .379 .413 0 r
F
.49756 .8071 m .48773 .80555 L .49617 .80596 L .377 .411 0 r
F
.3419 1.04276 m .31781 1.03516 L .32605 1.03302 L .722 .769 0 r
F
.34943 1.04029 m .3419 1.04276 L .32605 1.03302 L .704 .758 0 r
F
.45 .78843 m .43875 .7819 L .44934 .78531 L .456 .506 0 r
F
.46048 .79133 m .45 .78843 L .44934 .78531 L .428 .482 0 r
F
.5233 .81801 m .52542 .82295 L .52135 .81766 L .354 .371 0 r
F
.5233 .81801 m .52834 .82351 L .52542 .82295 L F
.4069 .34217 m .42996 .32467 L .4332 .33089 L 1 .987 0 r
F
.4069 .34217 m .40261 .33592 L .42996 .32467 L F
.54657 .82985 m .55129 .83603 L .5437 .83002 L .355 .364 0 r
F
.54657 .82985 m .55489 .83585 L .55129 .83603 L F
.59965 .57817 m .61854 .58144 L .61133 .58417 L .625 .701 0 r
F
.77097 .92049 m .77135 .94032 L .76153 .93683 L .991 .791 0 r
F
.77097 .92049 m .78121 .92338 L .77135 .94032 L F
.68252 .90295 m .68407 .91929 L .67463 .91342 L .92 .682 0 r
F
.68252 .90295 m .69244 .90793 L .68407 .91929 L F
.34573 .3581 m .3659 .33666 L .37121 .34297 L 1 .922 0 r
F
.34573 .3581 m .33948 .35194 L .3659 .33666 L F
.44423 1.05099 m .44008 1.05373 L .42359 1.04959 L .475 .598 0 r
F
.46042 1.0541 m .44008 1.05373 L .44423 1.05099 L .458 .55 0 r
F
.48309 .80052 m .47311 .79855 L .47184 .79639 L .396 .437 0 r
F
.48434 .80217 m .47311 .79855 L .48309 .80052 L .393 .435 0 r
F
.58929 .8527 m .59383 .86148 L .58489 .85446 L .437 .439 0 r
F
.58929 .8527 m .59879 .85927 L .59383 .86148 L F
.53609 .82416 m .54052 .82994 L .5337 .82412 L .353 .365 0 r
F
.53609 .82416 m .5437 .83002 L .54052 .82994 L F
.39639 .76299 m .38698 .75235 L .39747 .7567 L .651 .603 0 r
F
.40697 .76666 m .39639 .76299 L .39747 .7567 L .61 .582 0 r
F
.47928 1.05389 m .4771 1.05622 L .46042 1.0541 L .395 .398 0 r
F
.49527 1.05532 m .4771 1.05622 L .47928 1.05389 L .343 .261 0 r
F
.55806 .8353 m .56319 .84207 L .55489 .83585 L .369 .379 0 r
F
.55806 .8353 m .56701 .84141 L .56319 .84207 L F
.54411 .31058 m .54537 .3045 L .57406 .30572 L 1 .934 0 r
F
.51615 .31188 m .54537 .3045 L .54411 .31058 L 1 .956 0 r
F
.37287 1.04587 m .34943 1.04029 L .35699 1.03793 L .667 .744 0 r
F
.37965 1.04326 m .37287 1.04587 L .35699 1.03793 L .643 .728 0 r
F
.50162 .56063 m .51466 .56081 L .51454 .56295 L .144 .119 0 r
F
.50162 .56063 m .50062 .55923 L .51466 .56081 L F
.49495 .80482 m .4859 .80385 L .48434 .80217 L .381 .416 0 r
F
.49617 .80596 m .4859 .80385 L .49495 .80482 L .379 .413 0 r
F
.63797 .3037 m .64252 .29793 L .67103 .30676 L .976 .885 0 r
F
.71382 .59216 m .73418 .60369 L .72436 .60526 L .853 .79 0 r
F
.70446 .59427 m .71382 .59216 L .72436 .60526 L .84 .783 0 r
F
.52515 .81825 m .52834 .82351 L .5233 .81801 L .355 .372 0 r
F
.52515 .81825 m .53111 .82391 L .52834 .82351 L F
.37651 .34926 m .39831 .3296 L .40261 .33592 L 1 .954 0 r
F
.37651 .34926 m .37121 .34297 L .39831 .3296 L F
.67479 .58761 m .69513 .59628 L .68582 .59819 L .798 .772 0 r
F
.66607 .58997 m .67479 .58761 L .68582 .59819 L .78 .762 0 r
F
.67259 .89771 m .67463 .91342 L .66518 .90724 L .889 .662 0 r
F
.67259 .89771 m .68252 .90295 L .67463 .91342 L F
.55269 .57108 m .55608 .568 L .56915 .57167 L .452 .561 0 r
F
.54022 .56796 m .55608 .568 L .55269 .57108 L .418 .489 0 r
F
.30959 1.03738 m .28536 1.02755 L .29421 1.02572 L .767 .785 0 r
F
.31781 1.03516 m .30959 1.03738 L .29421 1.02572 L .752 .777 0 r
F
.76073 .91749 m .76153 .93683 L .7517 .93322 L .985 .783 0 r
F
.76073 .91749 m .77097 .92049 L .76153 .93683 L F
.43875 .7819 m .42813 .77435 L .43872 .77833 L .49 .524 0 r
F
.44934 .78531 m .43875 .7819 L .43872 .77833 L .455 .5 0 r
F
.64591 .58346 m .66607 .58997 L .65736 .59221 L .746 .754 0 r
F
.6379 .58607 m .64591 .58346 L .65736 .59221 L .724 .741 0 r
F
.57979 .84637 m .58489 .85446 L .57596 .84778 L .409 .423 0 r
F
.57979 .84637 m .58929 .8527 L .58489 .85446 L F
.40697 .76666 m .39747 .7567 L .40796 .76117 L .61 .582 0 r
F
.41754 .77045 m .40697 .76666 L .40796 .76117 L .567 .559 0 r
F
.77366 .59663 m .79386 .61236 L .78362 .61364 L .911 .812 0 r
F
.76377 .5985 m .77366 .59663 L .78362 .61364 L .903 .807 0 r
F
.47318 .55413 m .48462 .55771 L .48674 .55741 L .359 0 0 r
F
.47318 .55413 m .46996 .55676 L .48462 .55771 L F
.66265 .89224 m .66518 .90724 L .65572 .90075 L .852 .64 0 r
F
.66265 .89224 m .67259 .89771 L .66518 .90724 L F
.50986 .80976 m .50657 .81254 L .50455 .81152 L .369 .398 0 r
F
.5109 .81025 m .50657 .81254 L .50986 .80976 L .369 .397 0 r
F
.5109 .81025 m .50865 .8135 L .50657 .81254 L F
.51196 .8107 m .50865 .8135 L .5109 .81025 L .368 .395 0 r
F
.51196 .8107 m .51078 .8144 L .50865 .8135 L F
.26771 1.0314 m .24329 1.01875 L .25268 1.01724 L .814 .803 0 r
F
.27652 1.02944 m .26771 1.0314 L .25268 1.01724 L .804 .797 0 r
F
.4332 .33089 m .45824 .31581 L .46038 .32201 L 1 .999 0 r
F
.4332 .33089 m .42996 .32467 L .45824 .31581 L F
.46048 .79133 m .44934 .78531 L .45994 .7888 L .428 .482 0 r
F
.47098 .79432 m .46048 .79133 L .45994 .7888 L .412 .459 0 r
F
.47184 .79639 m .46048 .79133 L .47098 .79432 L .411 .46 0 r
F
.50885 .80925 m .50455 .81152 L .50263 .81046 L .37 .399 0 r
F
.50986 .80976 m .50455 .81152 L .50885 .80925 L .369 .398 0 r
F
.51304 .81112 m .51078 .8144 L .51196 .8107 L .367 .393 0 r
F
.51304 .81112 m .51293 .81523 L .51078 .8144 L F
.51454 .56295 m .52868 .56265 L .52745 .5653 L .282 .211 0 r
F
.51454 .56295 m .51466 .56081 L .52868 .56265 L F
.49392 .80369 m .48434 .80217 L .48309 .80052 L .383 .418 0 r
F
.49495 .80482 m .48434 .80217 L .49392 .80369 L .381 .416 0 r
F
.54022 .56796 m .54254 .56501 L .55608 .568 L .418 .489 0 r
F
.52745 .5653 m .54254 .56501 L .54022 .56796 L .366 .375 0 r
F
.48213 .79893 m .47184 .79639 L .47098 .79432 L .397 .439 0 r
F
.48309 .80052 m .47184 .79639 L .48213 .79893 L .396 .437 0 r
F
.50788 .80871 m .50263 .81046 L .50081 .80936 L .371 .4 0 r
F
.50885 .80925 m .50263 .81046 L .50788 .80871 L .37 .399 0 r
F
.51412 .81149 m .51293 .81523 L .51304 .81112 L .366 .391 0 r
F
.51412 .81149 m .51508 .81597 L .51293 .81523 L F
.75047 .91436 m .7517 .93322 L .74186 .92947 L .977 .773 0 r
F
.75047 .91436 m .76073 .91749 L .7517 .93322 L F
.52687 .81837 m .53111 .82391 L .52515 .81825 L .357 .375 0 r
F
.52687 .81837 m .5337 .82412 L .53111 .82391 L F
.58161 .57603 m .58703 .5729 L .59965 .57817 L .561 .663 0 r
F
.56915 .57167 m .58703 .5729 L .58161 .57603 L .521 .639 0 r
F
.6527 .88653 m .65572 .90075 L .64624 .89401 L .808 .617 0 r
F
.6527 .88653 m .66265 .89224 L .65572 .90075 L F
.51615 .31188 m .51627 .30573 L .54537 .3045 L 1 .956 0 r
F
.48814 .31567 m .51627 .30573 L .51615 .31188 L 1 .978 0 r
F
.52745 .5653 m .52868 .56265 L .54254 .56501 L .366 .375 0 r
F
.53824 .824 m .5437 .83002 L .53609 .82416 L .36 .376 0 r
F
.53824 .824 m .54657 .82985 L .5437 .83002 L F
.50697 .80815 m .50081 .80936 L .49912 .80824 L .371 .401 0 r
F
.50788 .80871 m .50081 .80936 L .50697 .80815 L .371 .4 0 r
F
.5491 .8294 m .55489 .83585 L .54657 .82985 L .367 .382 0 r
F
.5491 .8294 m .55806 .8353 L .55489 .83585 L F
.57029 .84027 m .57596 .84778 L .56701 .84141 L .395 .412 0 r
F
.57029 .84027 m .57979 .84637 L .57596 .84778 L F
.51519 .81181 m .51508 .81597 L .51412 .81149 L .365 .39 0 r
F
.51519 .81181 m .51722 .81663 L .51508 .81597 L F
.4636 1.05159 m .46042 1.0541 L .44423 1.05099 L .429 .492 0 r
F
.47928 1.05389 m .46042 1.0541 L .4636 1.05159 L .395 .398 0 r
F
.41754 .77045 m .40796 .76117 L .41845 .76573 L .567 .559 0 r
F
.42813 .77435 m .41754 .77045 L .41845 .76573 L .525 .537 0 r
F
.57406 .30572 m .57644 .29965 L .60549 .30339 L .994 .914 0 r
F
.54537 .3045 m .57644 .29965 L .57406 .30572 L 1 .933 0 r
F
.64274 .88063 m .64624 .89401 L .63676 .88707 L .758 .593 0 r
F
.64274 .88063 m .6527 .88653 L .64624 .89401 L F
.44934 .78531 m .43872 .77833 L .44933 .78236 L .455 .5 0 r
F
.45994 .7888 m .44934 .78531 L .44933 .78236 L .427 .477 0 r
F
.50612 .80758 m .49912 .80824 L .49756 .8071 L .372 .402 0 r
F
.50697 .80815 m .49912 .80824 L .50612 .80758 L .371 .401 0 r
F
.46038 .32201 m .48712 .30948 L .48814 .31567 L 1 .994 0 r
F
.46038 .32201 m .45824 .31581 L .48712 .30948 L F
.51624 .81209 m .51722 .81663 L .51519 .81181 L .364 .388 0 r
F
.51624 .81209 m .51931 .8172 L .51722 .81663 L F
.60897 .29742 m .64252 .29793 L .63797 .3037 L .992 .899 0 r
F
.60549 .30339 m .60897 .29742 L .63797 .3037 L .983 .898 0 r
F
.30305 .72364 m .29653 .70627 L .30688 .70988 L .921 .74 0 r
F
.30305 .72364 m .29254 .7208 L .29653 .70627 L F
.31355 .72663 m .30305 .72364 L .30688 .70988 L .904 .728 0 r
F
.29254 .7208 m .28616 .70282 L .29653 .70627 L .935 .751 0 r
F
.29254 .7208 m .28203 .71809 L .28616 .70282 L F
.31355 .72663 m .30688 .70988 L .31722 .71366 L .904 .728 0 r
F
.32405 .72977 m .31355 .72663 L .31722 .71366 L .885 .714 0 r
F
.48814 .31567 m .48712 .30948 L .51627 .30573 L 1 .978 0 r
F
.54112 1.31508 m .54203 1.31953 L .5097 1.32339 L .935 .943 0 r
F
.57216 1.30901 m .54203 1.31953 L .54112 1.31508 L 1 .973 0 r
F
.57216 1.30901 m .57408 1.31354 L .54203 1.31953 L F
.28203 .71809 m .27579 .69951 L .28616 .70282 L .947 .762 0 r
F
.28203 .71809 m .27151 .71551 L .27579 .69951 L F
.74021 .9111 m .74186 .92947 L .732 .92555 L .968 .762 0 r
F
.74021 .9111 m .75047 .91436 L .74186 .92947 L F
.32405 .72977 m .31722 .71366 L .32756 .71762 L .885 .714 0 r
F
.33454 .73309 m .32405 .72977 L .32756 .71762 L .863 .699 0 r
F
.63278 .87459 m .63676 .88707 L .62727 .88003 L .701 .569 0 r
F
.63278 .87459 m .64274 .88063 L .63676 .88707 L F
.27151 .71551 m .26541 .69633 L .27579 .69951 L .958 .771 0 r
F
.27151 .71551 m .26098 .71305 L .26541 .69633 L F
.49308 .8026 m .48309 .80052 L .48213 .79893 L .385 .42 0 r
F
.49392 .80369 m .48309 .80052 L .49308 .8026 L .383 .418 0 r
F
.33454 .73309 m .32756 .71762 L .33788 .72178 L .863 .699 0 r
F
.34503 .73658 m .33454 .73309 L .33788 .72178 L .838 .684 0 r
F
.72319 .58997 m .74403 .60203 L .73418 .60369 L .865 .797 0 r
F
.71382 .59216 m .72319 .58997 L .73418 .60369 L .853 .79 0 r
F
.62576 .57856 m .64591 .58346 L .6379 .58607 L .706 .742 0 r
F
.61854 .58144 m .62576 .57856 L .6379 .58607 L .679 .725 0 r
F
.34943 1.04029 m .32605 1.03302 L .33431 1.03097 L .704 .758 0 r
F
.35699 1.03793 m .34943 1.04029 L .33431 1.03097 L .683 .745 0 r
F
.50535 .80701 m .49756 .8071 L .49617 .80596 L .373 .403 0 r
F
.50612 .80758 m .49756 .8071 L .50535 .80701 L .372 .402 0 r
F
.26098 .71305 m .25502 .69326 L .26541 .69633 L .967 .78 0 r
F
.26098 .71305 m .25045 .71068 L .25502 .69326 L F
.51726 .81232 m .51931 .8172 L .51624 .81209 L .364 .387 0 r
F
.51726 .81232 m .52135 .81766 L .51931 .8172 L F
.52846 .81838 m .5337 .82412 L .52687 .81837 L .36 .38 0 r
F
.52846 .81838 m .53609 .82416 L .5337 .82412 L F
.78358 .5947 m .80412 .61103 L .79386 .61236 L .919 .816 0 r
F
.77366 .59663 m .78358 .5947 L .79386 .61236 L .911 .812 0 r
F
.57644 .29965 m .60897 .29742 L .60549 .30339 L 1 .915 0 r
F
.40196 1.04709 m .37965 1.04326 L .38646 1.04076 L .595 .703 0 r
F
.40794 1.04445 m .40196 1.04709 L .38646 1.04076 L .564 .679 0 r
F
.42359 1.04959 m .40196 1.04709 L .40794 1.04445 L .538 .663 0 r
F
.34503 .73658 m .33788 .72178 L .3482 .72614 L .838 .684 0 r
F
.35552 .74026 m .34503 .73658 L .3482 .72614 L .809 .667 0 r
F
.62282 .86847 m .62727 .88003 L .61778 .87299 L .642 .544 0 r
F
.62282 .86847 m .63278 .87459 L .62727 .88003 L F
.42813 .77435 m .41845 .76573 L .42895 .77035 L .525 .537 0 r
F
.43872 .77833 m .42813 .77435 L .42895 .77035 L .485 .514 0 r
F
.25045 .71068 m .24462 .6903 L .25502 .69326 L .974 .787 0 r
F
.25045 .71068 m .23992 .70842 L .24462 .6903 L F
.50981 1.31901 m .5097 1.32339 L .47737 1.32514 L .874 .911 0 r
F
.54112 1.31508 m .5097 1.32339 L .50981 1.31901 L .935 .943 0 r
F
.56079 .83439 m .56701 .84141 L .55806 .8353 L .385 .404 0 r
F
.56079 .83439 m .57029 .84027 L .56701 .84141 L F
.33948 .35194 m .36057 .33033 L .3659 .33666 L 1 .92 0 r
F
.33948 .35194 m .33322 .34578 L .36057 .33033 L F
.60265 1.30084 m .57408 1.31354 L .57216 1.30901 L 1 .993 0 r
F
.60265 1.30084 m .60557 1.30545 L .57408 1.31354 L F
.42869 1.04693 m .42359 1.04959 L .40794 1.04445 L .503 .63 0 r
F
.44423 1.05099 m .42359 1.04959 L .42869 1.04693 L .475 .598 0 r
F
.59965 .57817 m .60601 .57511 L .61854 .58144 L .625 .701 0 r
F
.58703 .5729 m .60601 .57511 L .59965 .57817 L .595 .691 0 r
F
.35552 .74026 m .3482 .72614 L .35852 .7307 L .809 .667 0 r
F
.36601 .74412 m .35552 .74026 L .35852 .7307 L .775 .649 0 r
F
.68354 .58514 m .70446 .59427 L .69513 .59628 L .814 .781 0 r
F
.67479 .58761 m .68354 .58514 L .69513 .59628 L .798 .772 0 r
F
.23992 .70842 m .2342 .68744 L .24462 .6903 L .981 .795 0 r
F
.23992 .70842 m .22937 .70623 L .2342 .68744 L F
.61285 .86233 m .61778 .87299 L .60828 .86605 L .581 .52 0 r
F
.61285 .86233 m .62282 .86847 L .61778 .87299 L F
.47098 .79432 m .45994 .7888 L .47055 .79236 L .412 .459 0 r
F
.48149 .7974 m .47098 .79432 L .47055 .79236 L .398 .438 0 r
F
.48213 .79893 m .47098 .79432 L .48149 .7974 L .397 .439 0 r
F
.45584 .55155 m .46671 .56071 L .46996 .55676 L .487 .016 0 r
F
.45584 .55155 m .45144 .56419 L .46671 .56071 L F
.50465 .80643 m .49617 .80596 L .49495 .80482 L .374 .404 0 r
F
.50535 .80701 m .49617 .80596 L .50465 .80643 L .373 .403 0 r
F
.72993 .90769 m .732 .92555 L .72213 .92146 L .957 .75 0 r
F
.72993 .90769 m .74021 .9111 L .732 .92555 L F
.51824 .81249 m .52135 .81766 L .51726 .81232 L .364 .387 0 r
F
.51824 .81249 m .5233 .81801 L .52135 .81766 L F
.22937 .70623 m .22378 .68465 L .2342 .68744 L .987 .801 0 r
F
.22937 .70623 m .21882 .70413 L .22378 .68465 L F
.40261 .33592 m .42671 .31834 L .42996 .32467 L 1 .978 0 r
F
.40261 .33592 m .39831 .3296 L .42671 .31834 L F
.60601 .57511 m .62576 .57856 L .61854 .58144 L .656 .723 0 r
F
.36601 .74412 m .35852 .7307 L .36882 .73546 L .775 .649 0 r
F
.37649 .74815 m .36601 .74412 L .36882 .73546 L .738 .63 0 r
F
.31781 1.03516 m .29421 1.02572 L .30309 1.02396 L .752 .777 0 r
F
.32605 1.03302 m .31781 1.03516 L .30309 1.02396 L .736 .768 0 r
F
.45994 .7888 m .44933 .78236 L .45994 .78644 L .427 .477 0 r
F
.47055 .79236 m .45994 .7888 L .45994 .78644 L .411 .455 0 r
F
.60289 .85624 m .60828 .86605 L .59879 .85927 L .524 .497 0 r
F
.60289 .85624 m .61285 .86233 L .60828 .86605 L F
.54013 .82365 m .54657 .82985 L .53824 .824 L .367 .387 0 r
F
.54013 .82365 m .5491 .8294 L .54657 .82985 L F
.21882 .70413 m .21335 .68195 L .22378 .68465 L .992 .807 0 r
F
.21882 .70413 m .20827 .70209 L .21335 .68195 L F
.27652 1.02944 m .25268 1.01724 L .26208 1.01579 L .804 .797 0 r
F
.28536 1.02755 m .27652 1.02944 L .26208 1.01579 L .792 .79 0 r
F
.51154 1.05485 m .51143 1.05585 L .49527 1.05532 L .174 .125 0 r
F
.37965 1.04326 m .35699 1.03793 L .36456 1.03566 L .643 .728 0 r
F
.38646 1.04076 m .37965 1.04326 L .36456 1.03566 L .617 .71 0 r
F
.37649 .74815 m .36882 .73546 L .37913 .74041 L .738 .63 0 r
F
.38698 .75235 m .37649 .74815 L .37913 .74041 L .698 .609 0 r
F
.49245 .80155 m .48213 .79893 L .48149 .7974 L .386 .421 0 r
F
.49308 .8026 m .48213 .79893 L .49245 .80155 L .385 .42 0 r
F
.65395 .58072 m .67479 .58761 L .66607 .58997 L .767 .766 0 r
F
.64591 .58346 m .65395 .58072 L .66607 .58997 L .746 .754 0 r
F
.43872 .77833 m .42895 .77035 L .43946 .775 L .485 .514 0 r
F
.44933 .78236 m .43872 .77833 L .43946 .775 L .45 .491 0 r
F
.56915 .57167 m .57359 .56841 L .58703 .5729 L .521 .639 0 r
F
.55608 .568 m .57359 .56841 L .56915 .57167 L .476 .6 0 r
F
.50404 .80586 m .49495 .80482 L .49392 .80369 L .374 .405 0 r
F
.50465 .80643 m .49495 .80482 L .50404 .80586 L .374 .404 0 r
F
.20827 .70209 m .2029 .67931 L .21335 .68195 L .996 .812 0 r
F
.20827 .70209 m .19771 .70012 L .2029 .67931 L F
.51916 .8126 m .5233 .81801 L .51824 .81249 L .364 .387 0 r
F
.51916 .8126 m .52515 .81825 L .5233 .81801 L F
.37121 .34297 m .394 .32321 L .39831 .3296 L 1 .949 0 r
F
.37121 .34297 m .3659 .33666 L .394 .32321 L F
.5417 1.05626 m .54365 1.05424 L .5276 1.05549 L .228 0 0 r
F
.59292 .85025 m .59879 .85927 L .58929 .8527 L .474 .475 0 r
F
.59292 .85025 m .60289 .85624 L .59879 .85927 L F
.52989 .81826 m .53609 .82416 L .52846 .81838 L .364 .385 0 r
F
.52989 .81826 m .53824 .824 L .53609 .82416 L F
.71964 .90411 m .72213 .92146 L .71225 .91717 L .944 .737 0 r
F
.71964 .90411 m .72993 .90769 L .72213 .92146 L F
.49642 1.05363 m .49527 1.05532 L .47928 1.05389 L .285 .181 0 r
F
.51154 1.05485 m .49527 1.05532 L .49642 1.05363 L .174 .125 0 r
F
.55128 .82868 m .55806 .8353 L .5491 .8294 L .379 .4 0 r
F
.55128 .82868 m .56079 .83439 L .55806 .8353 L F
.38698 .75235 m .37913 .74041 L .38943 .74551 L .698 .609 0 r
F
.39747 .7567 m .38698 .75235 L .38943 .74551 L .654 .588 0 r
F
.4484 1.04842 m .44423 1.05099 L .42869 1.04693 L .452 .554 0 r
F
.4636 1.05159 m .44423 1.05099 L .4484 1.04842 L .429 .492 0 r
F
.79351 .59272 m .81438 .60965 L .80412 .61103 L .925 .82 0 r
F
.78358 .5947 m .79351 .59272 L .80412 .61103 L .919 .816 0 r
F
.47849 1.32084 m .47737 1.32514 L .44533 1.32482 L .824 .881 0 r
F
.50981 1.31901 m .47737 1.32514 L .47849 1.32084 L .874 .911 0 r
F
.58296 .84439 m .58929 .8527 L .57979 .84637 L .435 .456 0 r
F
.58296 .84439 m .59292 .85025 L .58929 .8527 L F
.54537 .3045 m .54663 .2983 L .57644 .29965 L 1 .933 0 r
F
.51627 .30573 m .54663 .2983 L .54537 .3045 L 1 .954 0 r
F
.63232 1.2907 m .60557 1.30545 L .60265 1.30084 L 1 .998 0 r
F
.63232 1.2907 m .63621 1.2954 L .60557 1.30545 L F
.50352 .8053 m .49392 .80369 L .49308 .8026 L .375 .406 0 r
F
.50404 .80586 m .49392 .80369 L .50352 .8053 L .374 .405 0 r
F
.52002 .81266 m .52515 .81825 L .51916 .8126 L .365 .388 0 r
F
.52002 .81266 m .52687 .81837 L .52515 .81825 L F
.23393 1.02032 m .22458 1.02193 L .21053 1.00516 L .845 .811 0 r
F
.39747 .7567 m .38943 .74551 L .39973 .75073 L .654 .588 0 r
F
.40796 .76117 m .39747 .7567 L .39973 .75073 L .607 .567 0 r
F
.73258 .58769 m .75389 .6003 L .74403 .60203 L .876 .803 0 r
F
.72319 .58997 m .73258 .58769 L .74403 .60203 L .865 .797 0 r
F
.70935 .90036 m .71225 .91717 L .70235 .91267 L .928 .723 0 r
F
.70935 .90036 m .71964 .90411 L .71225 .91717 L F
.44933 .78236 m .43946 .775 L .44997 .77965 L .45 .491 0 r
F
.45994 .78644 m .44933 .78236 L .44997 .77965 L .423 .47 0 r
F
.55647 1.05781 m .54365 1.05424 L .5417 1.05626 L .417 0 0 r
F
.55647 1.05781 m .5594 1.0521 L .54365 1.05424 L F
.47055 .79236 m .45994 .78644 L .47056 .79053 L .411 .455 0 r
F
.48118 .79597 m .47055 .79236 L .47056 .79053 L .397 .436 0 r
F
.48149 .7974 m .47055 .79236 L .48118 .79597 L .398 .438 0 r
F
.48146 1.05179 m .47928 1.05389 L .4636 1.05159 L .353 .325 0 r
F
.49642 1.05363 m .47928 1.05389 L .48146 1.05179 L .285 .181 0 r
F
.57299 .83868 m .57979 .84637 L .57029 .84027 L .412 .439 0 r
F
.57299 .83868 m .58296 .84439 L .57979 .84637 L F
.49203 .80055 m .48149 .7974 L .48118 .79597 L .386 .421 0 r
F
.49245 .80155 m .48149 .7974 L .49203 .80055 L F
.40796 .76117 m .39973 .75073 L .41003 .75604 L .607 .567 0 r
F
.41845 .76573 m .40796 .76117 L .41003 .75604 L .561 .544 0 r
F
.50311 .80475 m .49308 .8026 L .49245 .80155 L .376 .407 0 r
F
.50352 .8053 m .49308 .8026 L .50311 .80475 L .375 .406 0 r
F
.42996 .32467 m .45609 .30948 L .45824 .31581 L 1 .988 0 r
F
.42996 .32467 m .42671 .31834 L .45609 .30948 L F
.53115 .81803 m .53824 .824 L .52989 .81826 L .368 .392 0 r
F
.53115 .81803 m .54013 .82365 L .53824 .824 L F
.69905 .89641 m .70235 .91267 L .69244 .90793 L .908 .708 0 r
F
.69905 .89641 m .70935 .90036 L .70235 .91267 L F
.54176 .82312 m .5491 .8294 L .54013 .82365 L .375 .398 0 r
F
.54176 .82312 m .55128 .82868 L .5491 .8294 L F
.52082 .81265 m .52687 .81837 L .52002 .81266 L .366 .39 0 r
F
.52082 .81265 m .52846 .81838 L .52687 .81837 L F
.55608 .568 m .55949 .56475 L .57359 .56841 L .476 .6 0 r
F
.54254 .56501 m .55949 .56475 L .55608 .568 L .443 .533 0 r
F
.69231 .58255 m .71382 .59216 L .70446 .59427 L .829 .789 0 r
F
.68354 .58514 m .69231 .58255 L .70446 .59427 L .814 .781 0 r
F
.56303 .83313 m .57029 .84027 L .56079 .83439 L .399 .426 0 r
F
.56303 .83313 m .57299 .83868 L .57029 .84027 L F
.41845 .76573 m .41003 .75604 L .42033 .76138 L .561 .544 0 r
F
.42895 .77035 m .41845 .76573 L .42033 .76138 L .516 .522 0 r
F
.45994 .78644 m .44997 .77965 L .46048 .78428 L .423 .47 0 r
F
.47056 .79053 m .45994 .78644 L .46048 .78428 L .408 .45 0 r
F
.35699 1.03793 m .33431 1.03097 L .34259 1.02901 L .683 .745 0 r
F
.36456 1.03566 m .35699 1.03793 L .34259 1.02901 L .661 .731 0 r
F
.68873 .89226 m .69244 .90793 L .68252 .90295 L .885 .691 0 r
F
.68873 .89226 m .69905 .89641 L .69244 .90793 L F
.58703 .5729 m .59247 .5696 L .60601 .57511 L .595 .691 0 r
F
.57359 .56841 m .59247 .5696 L .58703 .5729 L .558 .672 0 r
F
.63301 .57552 m .65395 .58072 L .64591 .58346 L .73 .757 0 r
F
.62576 .57856 m .63301 .57552 L .64591 .58346 L .706 .742 0 r
F
.51627 .30573 m .5164 .29945 L .54663 .2983 L 1 .954 0 r
F
.48712 .30948 m .5164 .29945 L .51627 .30573 L 1 .972 0 r
F
.79351 .59272 m .80346 .59069 L .81438 .60965 L .925 .82 0 r
F
.51316 .80695 m .50986 .80976 L .50885 .80925 L .371 .399 0 r
F
.51316 .80695 m .5109 .81025 L .50986 .80976 L .37 .398 0 r
F
.51316 .80695 m .51196 .8107 L .5109 .81025 L F
.50062 .55923 m .51478 .55865 L .51466 .56081 L .173 .125 0 r
F
.50062 .55923 m .49962 .55803 L .51478 .55865 L F
.51316 .80695 m .50885 .80925 L .50788 .80871 L .371 .399 0 r
F
.51316 .80695 m .51304 .81112 L .51196 .8107 L .37 .398 0 r
F
.28536 1.02755 m .26208 1.01579 L .27149 1.0144 L .792 .79 0 r
F
.29421 1.02572 m .28536 1.02755 L .27149 1.0144 L .78 .783 0 r
F
.50279 .80423 m .49245 .80155 L .49203 .80055 L .377 .408 0 r
F
.50311 .80475 m .49245 .80155 L .50279 .80423 L .376 .407 0 r
F
.60897 .29742 m .61247 .29137 L .64252 .29793 L .992 .899 0 r
F
.51316 .80695 m .50788 .80871 L .50697 .80815 L .371 .399 0 r
F
.51316 .80695 m .51412 .81149 L .51304 .81112 L .37 .397 0 r
F
.5709 1.06422 m .5594 1.0521 L .55647 1.05781 L .619 .031 0 r
F
.5709 1.06422 m .57472 1.0491 L .5594 1.0521 L F
.57644 .29965 m .57883 .29347 L .60897 .29742 L 1 .915 0 r
F
.54663 .2983 m .57883 .29347 L .57644 .29965 L 1 .933 0 r
F
.32605 1.03302 m .30309 1.02396 L .31198 1.02229 L .736 .768 0 r
F
.33431 1.03097 m .32605 1.03302 L .31198 1.02229 L .719 .757 0 r
F
.52153 .81259 m .52846 .81838 L .52082 .81265 L .367 .392 0 r
F
.52153 .81259 m .52989 .81826 L .52846 .81838 L F
.82009 .9125 m .82205 .93402 L .81186 .93148 L .98 .814 0 r
F
.82009 .9125 m .83063 .91446 L .82205 .93402 L F
.51316 .80695 m .50697 .80815 L .50612 .80758 L .371 .399 0 r
F
.51316 .80695 m .51519 .81181 L .51412 .81149 L .369 .396 0 r
F
.42895 .77035 m .42033 .76138 L .43064 .76671 L .516 .522 0 r
F
.43946 .775 m .42895 .77035 L .43064 .76671 L .475 .5 0 r
F
.67841 .8879 m .68252 .90295 L .67259 .89771 L .858 .673 0 r
F
.67841 .8879 m .68873 .89226 L .68252 .90295 L F
.45824 .31581 m .4861 .30317 L .48712 .30948 L 1 .985 0 r
F
.45824 .31581 m .45609 .30948 L .4861 .30317 L F
.48118 .79597 m .47056 .79053 L .4812 .79464 L .397 .436 0 r
F
.49183 .79961 m .48118 .79597 L .4812 .79464 L .386 .42 0 r
F
.49203 .80055 m .48118 .79597 L .49183 .79961 L .386 .421 0 r
F
.55306 .82771 m .56079 .83439 L .55128 .82868 L .389 .416 0 r
F
.55306 .82771 m .56303 .83313 L .56079 .83439 L F
.51316 .80695 m .50612 .80758 L .50535 .80701 L .371 .399 0 r
F
.51316 .80695 m .51624 .81209 L .51519 .81181 L .369 .396 0 r
F
.54021 1.3107 m .54112 1.31508 L .50981 1.31901 L .926 .942 0 r
F
.57024 1.30455 m .54112 1.31508 L .54021 1.3107 L 1 .977 0 r
F
.57024 1.30455 m .57216 1.30901 L .54112 1.31508 L F
.54254 .56501 m .54488 .56191 L .55949 .56475 L .443 .533 0 r
F
.52868 .56265 m .54488 .56191 L .54254 .56501 L .396 .421 0 r
F
.4668 1.04927 m .4636 1.05159 L .4484 1.04842 L .398 .433 0 r
F
.48146 1.05179 m .4636 1.05159 L .4668 1.04927 L .353 .325 0 r
F
.48712 .30948 m .4861 .30317 L .5164 .29945 L 1 .972 0 r
F
.40794 1.04445 m .38646 1.04076 L .39329 1.03839 L .564 .679 0 r
F
.41395 1.04197 m .40794 1.04445 L .39329 1.03839 L .533 .652 0 r
F
.42869 1.04693 m .40794 1.04445 L .41395 1.04197 L .503 .63 0 r
F
.23393 1.02032 m .21053 1.00516 L .22039 1.00408 L .845 .811 0 r
F
.24329 1.01875 m .23393 1.02032 L .22039 1.00408 L .836 .806 0 r
F
.53223 .81767 m .54013 .82365 L .53115 .81803 L .372 .398 0 r
F
.53223 .81767 m .54176 .82312 L .54013 .82365 L F
.51316 .80695 m .50535 .80701 L .50465 .80643 L .371 .399 0 r
F
.662 .57785 m .68354 .58514 L .67479 .58761 L .786 .777 0 r
F
.65395 .58072 m .662 .57785 L .67479 .58761 L .767 .766 0 r
F
.51316 .80695 m .51726 .81232 L .51624 .81209 L .369 .396 0 r
F
.66809 .88334 m .67259 .89771 L .66265 .89224 L .826 .654 0 r
F
.66809 .88334 m .67841 .8879 L .67259 .89771 L F
.47056 .79053 m .46048 .78428 L .47101 .78887 L .408 .45 0 r
F
.4812 .79464 m .47056 .79053 L .47101 .78887 L .395 .432 0 r
F
.742 .58534 m .76377 .5985 L .75389 .6003 L .885 .808 0 r
F
.73258 .58769 m .742 .58534 L .75389 .6003 L .876 .803 0 r
F
.57883 .29347 m .61247 .29137 L .60897 .29742 L 1 .915 0 r
F
.51466 .56081 m .52992 .5599 L .52868 .56265 L .317 .241 0 r
F
.51466 .56081 m .51478 .55865 L .52992 .5599 L F
.43946 .775 m .43064 .76671 L .44095 .772 L .475 .5 0 r
F
.44997 .77965 m .43946 .775 L .44095 .772 L .44 .478 0 r
F
.80955 .91049 m .81186 .93148 L .80165 .92887 L .976 .808 0 r
F
.80955 .91049 m .82009 .9125 L .81186 .93148 L F
.50258 .80373 m .49203 .80055 L .49183 .79961 L .377 .408 0 r
F
.50279 .80423 m .49203 .80055 L .50258 .80373 L F
.51316 .80695 m .50465 .80643 L .50404 .80586 L .371 .399 0 r
F
.59973 1.29629 m .57216 1.30901 L .57024 1.30455 L 1 1 0 r
F
.59973 1.29629 m .60265 1.30084 L .57216 1.30901 L F
.51316 .80695 m .51824 .81249 L .51726 .81232 L .369 .395 0 r
F
.60601 .57511 m .61239 .57188 L .62576 .57856 L .656 .723 0 r
F
.59247 .5696 m .61239 .57188 L .60601 .57511 L .629 .716 0 r
F
.39831 .3296 m .42346 .31192 L .42671 .31834 L 1 .97 0 r
F
.39831 .3296 m .394 .32321 L .42346 .31192 L F
.61239 .57188 m .63301 .57552 L .62576 .57856 L .685 .742 0 r
F
.52868 .56265 m .52992 .5599 L .54488 .56191 L .396 .421 0 r
F
.44746 1.32062 m .44533 1.32482 L .41385 1.3225 L .788 .856 0 r
F
.47849 1.32084 m .44533 1.32482 L .44746 1.32062 L .824 .881 0 r
F
.65776 .87856 m .66265 .89224 L .6527 .88653 L .79 .634 0 r
F
.65776 .87856 m .66809 .88334 L .66265 .89224 L F
.50992 1.31471 m .50981 1.31901 L .47849 1.32084 L .859 .906 0 r
F
.54021 1.3107 m .50981 1.31901 L .50992 1.31471 L .926 .942 0 r
F
.52216 .81247 m .52989 .81826 L .52153 .81259 L .369 .395 0 r
F
.52216 .81247 m .53115 .81803 L .52989 .81826 L F
.43381 1.04442 m .42869 1.04693 L .41395 1.04197 L .472 .595 0 r
F
.4484 1.04842 m .42869 1.04693 L .43381 1.04442 L .452 .554 0 r
F
.66091 1.2788 m .63621 1.2954 L .63232 1.2907 L 1 .986 0 r
F
.66091 1.2788 m .66575 1.28357 L .63621 1.2954 L F
.54309 .82241 m .55128 .82868 L .54176 .82312 L .381 .409 0 r
F
.54309 .82241 m .55306 .82771 L .55128 .82868 L F
.38646 1.04076 m .36456 1.03566 L .37216 1.03351 L .617 .71 0 r
F
.39329 1.03839 m .38646 1.04076 L .37216 1.03351 L .589 .69 0 r
F
.51316 .80695 m .50404 .80586 L .50352 .8053 L .371 .399 0 r
F
.64743 .8736 m .6527 .88653 L .64274 .88063 L .748 .613 0 r
F
.64743 .8736 m .65776 .87856 L .6527 .88653 L F
.51316 .80695 m .51916 .8126 L .51824 .81249 L .369 .395 0 r
F
.3659 .33666 m .38967 .31676 L .394 .32321 L 1 .944 0 r
F
.3659 .33666 m .36057 .33033 L .38967 .31676 L F
.63709 .86848 m .64274 .88063 L .63278 .87459 L .701 .592 0 r
F
.63709 .86848 m .64743 .8736 L .64274 .88063 L F
.44997 .77965 m .44095 .772 L .45126 .77722 L .44 .478 0 r
F
.46048 .78428 m .44997 .77965 L .45126 .77722 L .417 .459 0 r
F
.62675 .86324 m .63278 .87459 L .62282 .86847 L .651 .569 0 r
F
.62675 .86324 m .63709 .86848 L .63278 .87459 L F
.799 .90839 m .80165 .92887 L .79144 .92617 L .972 .802 0 r
F
.799 .90839 m .80955 .91049 L .80165 .92887 L F
.51316 .80695 m .50352 .8053 L .50311 .80475 L .371 .399 0 r
F
.51316 .80695 m .52002 .81266 L .51916 .8126 L .369 .396 0 r
F
.61641 .85792 m .62282 .86847 L .61285 .86233 L .599 .547 0 r
F
.61641 .85792 m .62675 .86324 L .62282 .86847 L F
.4812 .79464 m .47101 .78887 L .48154 .79343 L .395 .432 0 r
F
.49184 .79874 m .4812 .79464 L .48154 .79343 L .385 .418 0 r
F
.49183 .79961 m .4812 .79464 L .49184 .79874 L .386 .42 0 r
F
.60608 .85256 m .61285 .86233 L .60289 .85624 L .548 .524 0 r
F
.60608 .85256 m .61641 .85792 L .61285 .86233 L F
.50248 .80327 m .49183 .79961 L .49184 .79874 L .377 .408 0 r
F
.50258 .80373 m .49183 .79961 L .50248 .80327 L F
.59575 .84722 m .60289 .85624 L .59292 .85025 L .5 .502 0 r
F
.59575 .84722 m .60608 .85256 L .60289 .85624 L F
.46996 .55676 m .48249 .55821 L .48462 .55771 L .281 0 0 r
F
.46996 .55676 m .46671 .56071 L .48249 .55821 L F
.5227 .81229 m .53115 .81803 L .52216 .81247 L .371 .398 0 r
F
.5227 .81229 m .53223 .81767 L .53115 .81803 L F
.51316 .80695 m .50311 .80475 L .50279 .80423 L .372 .4 0 r
F
.58542 .84191 m .59292 .85025 L .58296 .84439 L .459 .481 0 r
F
.58542 .84191 m .59575 .84722 L .59292 .85025 L F
.53312 .8172 m .54176 .82312 L .53223 .81767 L .376 .404 0 r
F
.53312 .8172 m .54309 .82241 L .54176 .82312 L F
.46048 .78428 m .45126 .77722 L .46157 .78236 L .417 .459 0 r
F
.47101 .78887 m .46048 .78428 L .46157 .78236 L .404 .441 0 r
F
.51316 .80695 m .52082 .81265 L .52002 .81266 L .369 .396 0 r
F
.70109 .57987 m .72319 .58997 L .71382 .59216 L .843 .796 0 r
F
.69231 .58255 m .70109 .57987 L .71382 .59216 L .829 .789 0 r
F
.58509 1.09426 m .57472 1.0491 L .5709 1.06422 L 1 .137 0 r
F
.58509 1.09426 m .58977 1.07221 L .57472 1.0491 L F
.57509 .83669 m .58296 .84439 L .57299 .83868 L .427 .462 0 r
F
.57509 .83669 m .58542 .84191 L .58296 .84439 L F
.78845 .90622 m .79144 .92617 L .78121 .92338 L .967 .796 0 r
F
.78845 .90622 m .799 .90839 L .79144 .92617 L F
.57359 .56841 m .57805 .56498 L .59247 .5696 L .558 .672 0 r
F
.55949 .56475 m .57805 .56498 L .57359 .56841 L .514 .641 0 r
F
.62842 1.28603 m .60265 1.30084 L .59973 1.29629 L 1 1 0 r
F
.62842 1.28603 m .63232 1.2907 L .60265 1.30084 L F
.51316 .80695 m .50279 .80423 L .50258 .80373 L .372 .4 0 r
F
.56476 .83155 m .57299 .83868 L .56303 .83313 L .41 .445 0 r
F
.56476 .83155 m .57509 .83669 L .57299 .83868 L F
.51316 .80695 m .52153 .81259 L .52082 .81265 L .37 .397 0 r
F
.29421 1.02572 m .27149 1.0144 L .28092 1.01308 L .78 .783 0 r
F
.30309 1.02396 m .29421 1.02572 L .28092 1.01308 L .766 .775 0 r
F
.47962 1.31661 m .47849 1.32084 L .44746 1.32062 L .808 .873 0 r
F
.50992 1.31471 m .47849 1.32084 L .47962 1.31661 L .859 .906 0 r
F
.47101 .78887 m .46157 .78236 L .47189 .7874 L .404 .441 0 r
F
.48154 .79343 m .47101 .78887 L .47189 .7874 L .392 .426 0 r
F
.24329 1.01875 m .22039 1.00408 L .23026 1.00305 L .836 .806 0 r
F
.25268 1.01724 m .24329 1.01875 L .23026 1.00305 L .827 .8 0 r
F
.45258 1.04604 m .4484 1.04842 L .43381 1.04442 L .428 .507 0 r
F
.4668 1.04927 m .4484 1.04842 L .45258 1.04604 L .398 .433 0 r
F
.54663 .2983 m .54789 .29198 L .57883 .29347 L 1 .933 0 r
F
.5164 .29945 m .54789 .29198 L .54663 .2983 L 1 .951 0 r
F
.49184 .79874 m .48154 .79343 L .49207 .79796 L .385 .418 0 r
F
.50249 .80284 m .49184 .79874 L .49207 .79796 L .377 .407 0 r
F
.50248 .80327 m .49184 .79874 L .50249 .80284 L .377 .408 0 r
F
.55444 .82649 m .56303 .83313 L .55306 .82771 L .397 .43 0 r
F
.55444 .82649 m .56476 .83155 L .56303 .83313 L F
.75143 .58291 m .77366 .59663 L .76377 .5985 L .895 .813 0 r
F
.742 .58534 m .75143 .58291 L .76377 .5985 L .885 .808 0 r
F
.36882 .73546 m .35852 .7307 L .36313 .72135 L .792 .635 0 r
F
.35852 .7307 m .3531 .71582 L .36313 .72135 L .829 .655 0 r
F
.35852 .7307 m .3482 .72614 L .3531 .71582 L F
.51316 .80695 m .50258 .80373 L .50248 .80327 L .372 .4 0 r
F
.36882 .73546 m .36313 .72135 L .37315 .72709 L .792 .635 0 r
F
.37913 .74041 m .36882 .73546 L .37315 .72709 L .749 .614 0 r
F
.77789 .90395 m .78121 .92338 L .77097 .92049 L .961 .788 0 r
F
.77789 .90395 m .78845 .90622 L .78121 .92338 L F
.3482 .72614 m .34307 .71053 L .3531 .71582 L .862 .674 0 r
F
.3482 .72614 m .33788 .72178 L .34307 .71053 L F
.51316 .80695 m .52216 .81247 L .52153 .81259 L .37 .397 0 r
F
.52314 .81206 m .53223 .81767 L .5227 .81229 L .373 .401 0 r
F
.52314 .81206 m .53312 .8172 L .53223 .81767 L F
.37913 .74041 m .37315 .72709 L .38316 .73303 L .749 .614 0 r
F
.38943 .74551 m .37913 .74041 L .38316 .73303 L .701 .592 0 r
F
.33788 .72178 m .33302 .70548 L .34307 .71053 L .891 .691 0 r
F
.33788 .72178 m .32756 .71762 L .33302 .70548 L F
.36456 1.03566 m .34259 1.02901 L .35089 1.02715 L .661 .731 0 r
F
.37216 1.03351 m .36456 1.03566 L .35089 1.02715 L .638 .715 0 r
F
.33431 1.03097 m .31198 1.02229 L .32089 1.0207 L .719 .757 0 r
F
.34259 1.02901 m .33431 1.03097 L .32089 1.0207 L .7 .745 0 r
F
.38943 .74551 m .38316 .73303 L .39317 .73909 L .701 .592 0 r
F
.39973 .75073 m .38943 .74551 L .39317 .73909 L .65 .569 0 r
F
.54412 .82152 m .55306 .82771 L .54309 .82241 L .387 .419 0 r
F
.54412 .82152 m .55444 .82649 L .55306 .82771 L F
.51165 1.05401 m .51154 1.05485 L .49642 1.05363 L .107 .117 0 r
F
.48154 .79343 m .47189 .7874 L .4822 .79237 L .392 .426 0 r
F
.49207 .79796 m .48154 .79343 L .4822 .79237 L .383 .414 0 r
F
.32756 .71762 m .32296 .70067 L .33302 .70548 L .915 .708 0 r
F
.32756 .71762 m .31722 .71366 L .32296 .70067 L F
.42671 .31834 m .45393 .30304 L .45609 .30948 L 1 .979 0 r
F
.42671 .31834 m .42346 .31192 L .45393 .30304 L F
.49757 1.05213 m .49642 1.05363 L .48146 1.05179 L .233 .135 0 r
F
.51165 1.05401 m .49642 1.05363 L .49757 1.05213 L .107 .117 0 r
F
.64028 .57234 m .662 .57785 L .65395 .58072 L .753 .771 0 r
F
.63301 .57552 m .64028 .57234 L .65395 .58072 L .73 .757 0 r
F
.39973 .75073 m .39317 .73909 L .40317 .74524 L .65 .569 0 r
F
.41003 .75604 m .39973 .75073 L .40317 .74524 L .598 .546 0 r
F
.51316 .80695 m .50248 .80327 L .50249 .80284 L .372 .401 0 r
F
.51316 .80695 m .5227 .81229 L .52216 .81247 L .371 .398 0 r
F
.31722 .71366 m .31289 .69607 L .32296 .70067 L .935 .723 0 r
F
.31722 .71366 m .30688 .70988 L .31289 .69607 L F
.41003 .75604 m .40317 .74524 L .41318 .7514 L .598 .546 0 r
F
.42033 .76138 m .41003 .75604 L .41318 .7514 L .546 .523 0 r
F
.76732 .90159 m .77097 .92049 L .76073 .91749 L .954 .78 0 r
F
.76732 .90159 m .77789 .90395 L .77097 .92049 L F
.5338 .81662 m .54309 .82241 L .53312 .8172 L .38 .41 0 r
F
.5338 .81662 m .54412 .82152 L .54309 .82241 L F
.67008 .57485 m .69231 .58255 L .68354 .58514 L .804 .787 0 r
F
.662 .57785 m .67008 .57485 L .68354 .58514 L .786 .777 0 r
F
.42033 .76138 m .41318 .7514 L .42318 .75751 L .546 .523 0 r
F
.43064 .76671 m .42033 .76138 L .42318 .75751 L .499 .501 0 r
F
.53974 1.05808 m .52668 1.05561 L .52575 1.0558 L .303 0 0 r
F
.53974 1.05808 m .5417 1.05626 L .52668 1.05561 L F
.49207 .79796 m .4822 .79237 L .49252 .79727 L .383 .414 0 r
F
.50261 .80246 m .49207 .79796 L .49252 .79727 L .376 .406 0 r
F
.50249 .80284 m .49207 .79796 L .50261 .80246 L .377 .407 0 r
F
.30688 .70988 m .30281 .69168 L .31289 .69607 L .952 .737 0 r
F
.30688 .70988 m .29653 .70627 L .30281 .69168 L F
.51316 .80695 m .50249 .80284 L .50261 .80246 L .372 .401 0 r
F
.51316 .80695 m .52314 .81206 L .5227 .81229 L .371 .399 0 r
F
.43064 .76671 m .42318 .75751 L .43318 .76353 L .499 .501 0 r
F
.44095 .772 m .43064 .76671 L .43318 .76353 L .458 .48 0 r
F
.52348 .81177 m .53312 .8172 L .52314 .81206 L .375 .404 0 r
F
.52348 .81177 m .5338 .81662 L .53312 .8172 L F
.48365 1.04988 m .48146 1.05179 L .4668 1.04927 L .314 .265 0 r
F
.49757 1.05213 m .48146 1.05179 L .48365 1.04988 L .233 .135 0 r
F
.75675 .89912 m .76073 .91749 L .75047 .91436 L .946 .772 0 r
F
.75675 .89912 m .76732 .90159 L .76073 .91749 L F
.44095 .772 m .43318 .76353 L .44319 .76941 L .458 .48 0 r
F
.45126 .77722 m .44095 .772 L .44319 .76941 L .426 .461 0 r
F
.29653 .70627 m .29271 .68747 L .30281 .69168 L .966 .75 0 r
F
.29653 .70627 m .28616 .70282 L .29271 .68747 L F
.59247 .5696 m .59793 .56611 L .61239 .57188 L .629 .716 0 r
F
.57805 .56498 m .59793 .56611 L .59247 .5696 L .597 .704 0 r
F
.5164 .29945 m .51652 .29304 L .54789 .29198 L 1 .951 0 r
F
.4861 .30317 m .51652 .29304 L .5164 .29945 L 1 .967 0 r
F
.55949 .56475 m .56292 .5613 L .57805 .56498 L .514 .641 0 r
F
.54488 .56191 m .56292 .5613 L .55949 .56475 L .471 .586 0 r
F
.50261 .80246 m .49252 .79727 L .50284 .80212 L .376 .406 0 r
F
.51316 .80695 m .50261 .80246 L .50284 .80212 L .372 .4 0 r
F
.45126 .77722 m .44319 .76941 L .45319 .77514 L .426 .461 0 r
F
.46157 .78236 m .45126 .77722 L .45319 .77514 L .409 .444 0 r
F
.51316 .80695 m .52348 .81177 L .52314 .81206 L .372 .4 0 r
F
.57883 .29347 m .58123 .2872 L .61247 .29137 L 1 .915 0 r
F
.54789 .29198 m .58123 .2872 L .57883 .29347 L 1 .931 0 r
F
.46157 .78236 m .45319 .77514 L .46319 .78072 L .409 .444 0 r
F
.47189 .7874 m .46157 .78236 L .46319 .78072 L .397 .43 0 r
F
.48681 .55776 m .49861 .55675 L .49962 .55803 L 0 0 0 r
F
.48462 .55771 m .48786 .55749 L .48681 .55776 L F
.48786 .55749 m .49861 .55675 L .48681 .55776 L F
.48462 .55771 m .48249 .55821 L .49861 .55675 L F
.48249 .55821 m .48035 .55827 L .49589 .55542 L .184 .129 0 r
F
.49516 .55561 m .49589 .55542 L .4976 .5551 L F
.48249 .55821 m .49589 .55542 L .49516 .55561 L F
.45609 .30948 m .48508 .29673 L .4861 .30317 L 1 .978 0 r
F
.45609 .30948 m .45393 .30304 L .48508 .29673 L F
.47189 .7874 m .46319 .78072 L .47319 .78615 L .397 .43 0 r
F
.4822 .79237 m .47189 .7874 L .47319 .78615 L .387 .419 0 r
F
.28616 .70282 m .2826 .68343 L .29271 .68747 L .978 .761 0 r
F
.28616 .70282 m .27579 .69951 L .2826 .68343 L F
.74617 .89652 m .75047 .91436 L .74021 .9111 L .936 .762 0 r
F
.74617 .89652 m .75675 .89912 L .75047 .91436 L F
.41395 1.04197 m .39329 1.03839 L .40014 1.03616 L .533 .652 0 r
F
.41997 1.03963 m .41395 1.04197 L .40014 1.03616 L .501 .623 0 r
F
.43381 1.04442 m .41395 1.04197 L .41997 1.03963 L .472 .595 0 r
F
.70991 .5771 m .73258 .58769 L .72319 .58997 L .856 .803 0 r
F
.70109 .57987 m .70991 .5771 L .72319 .58997 L .843 .796 0 r
F
.4822 .79237 m .47319 .78615 L .48319 .79147 L .387 .419 0 r
F
.49252 .79727 m .4822 .79237 L .48319 .79147 L .38 .41 0 r
F
.25268 1.01724 m .23026 1.00305 L .24014 1.00208 L .827 .8 0 r
F
.26208 1.01579 m .25268 1.01724 L .24014 1.00208 L .817 .794 0 r
F
.49252 .79727 m .48319 .79147 L .49318 .79668 L .38 .41 0 r
F
.50284 .80212 m .49252 .79727 L .49318 .79668 L .375 .404 0 r
F
.61879 .56848 m .64028 .57234 L .63301 .57552 L .713 .76 0 r
F
.61239 .57188 m .61879 .56848 L .63301 .57552 L .685 .742 0 r
F
.5393 1.30642 m .54021 1.3107 L .50992 1.31471 L .914 .939 0 r
F
.56831 1.30018 m .54021 1.3107 L .5393 1.30642 L .999 .98 0 r
F
.56831 1.30018 m .57024 1.30455 L .54021 1.3107 L F
.41697 1.31844 m .41385 1.3225 L .38321 1.31826 L .763 .837 0 r
F
.44746 1.32062 m .41385 1.3225 L .41697 1.31844 L .788 .856 0 r
F
.50284 .80212 m .49318 .79668 L .50317 .80183 L .375 .404 0 r
F
.51316 .80695 m .50284 .80212 L .50317 .80183 L .372 .4 0 r
F
.394 .32321 m .42019 .3054 L .42346 .31192 L 1 .963 0 r
F
.394 .32321 m .38967 .31676 L .42019 .3054 L F
.51316 .80695 m .50317 .80183 L .50361 .8016 L .371 .399 0 r
F
.51316 .80695 m .52371 .81144 L .52348 .81177 L .372 .4 0 r
F
.51316 .80695 m .50361 .8016 L .50414 .80142 L .371 .398 0 r
F
.51316 .80695 m .52383 .81105 L .52371 .81144 L .372 .401 0 r
F
.51316 .80695 m .50414 .80142 L .50477 .80129 L .37 .397 0 r
F
.51316 .80695 m .52385 .81063 L .52383 .81105 L .372 .401 0 r
F
.51316 .80695 m .50477 .80129 L .50548 .80123 L .37 .397 0 r
F
.51316 .80695 m .52375 .81017 L .52385 .81063 L .372 .4 0 r
F
.51316 .80695 m .50548 .80123 L .50627 .80122 L .369 .396 0 r
F
.51316 .80695 m .52355 .80967 L .52375 .81017 L .372 .4 0 r
F
.51316 .80695 m .50627 .80122 L .50714 .80128 L .369 .396 0 r
F
.51316 .80695 m .52324 .80915 L .52355 .80967 L .372 .4 0 r
F
.51316 .80695 m .50714 .80128 L .50806 .80139 L .369 .395 0 r
F
.51316 .80695 m .52282 .8086 L .52324 .80915 L .371 .399 0 r
F
.68816 1.26544 m .66575 1.28357 L .66091 1.2788 L 1 .962 0 r
F
.68816 1.26544 m .69392 1.27022 L .66575 1.28357 L F
.51316 .80695 m .50806 .80139 L .50904 .80156 L .369 .395 0 r
F
.51316 .80695 m .52231 .80804 L .52282 .8086 L .371 .399 0 r
F
.51316 .80695 m .50904 .80156 L .51006 .80178 L .369 .396 0 r
F
.51316 .80695 m .5217 .80746 L .52231 .80804 L .371 .399 0 r
F
.51316 .80695 m .51006 .80178 L .51112 .80206 L .369 .396 0 r
F
.51316 .80695 m .521 .80688 L .5217 .80746 L .371 .399 0 r
F
.51316 .80695 m .51112 .80206 L .51219 .80239 L .369 .396 0 r
F
.51316 .80695 m .52022 .80631 L .521 .80688 L .371 .399 0 r
F
.51316 .80695 m .51219 .80239 L .51327 .80276 L .37 .397 0 r
F
.51316 .80695 m .51937 .80573 L .52022 .80631 L .371 .399 0 r
F
.51316 .80695 m .51327 .80276 L .51436 .80318 L .37 .398 0 r
F
.51316 .80695 m .51846 .80518 L .51937 .80573 L .371 .399 0 r
F
.51316 .80695 m .51436 .80318 L .51543 .80363 L .37 .398 0 r
F
.51316 .80695 m .51749 .80464 L .51846 .80518 L .371 .399 0 r
F
.51316 .80695 m .51543 .80363 L .51648 .80412 L .37 .398 0 r
F
.51316 .80695 m .51648 .80412 L .51749 .80464 L .371 .399 0 r
F
.65605 1.27402 m .63232 1.2907 L .62842 1.28603 L 1 .993 0 r
F
.65605 1.27402 m .66091 1.2788 L .63232 1.2907 L F
.52371 .81144 m .5338 .81662 L .52348 .81177 L .376 .406 0 r
F
.4861 .30317 m .48508 .29673 L .51652 .29304 L 1 .967 0 r
F
.39329 1.03839 m .37216 1.03351 L .37978 1.03148 L .589 .69 0 r
F
.40014 1.03616 m .39329 1.03839 L .37978 1.03148 L .56 .667 0 r
F
.53427 .81594 m .54412 .82152 L .5338 .81662 L .383 .414 0 r
F
.52371 .81144 m .53427 .81594 L .5338 .81662 L .376 .406 0 r
F
.76088 .58042 m .78358 .5947 L .77366 .59663 L .903 .818 0 r
F
.75143 .58291 m .76088 .58042 L .77366 .59663 L .895 .813 0 r
F
.54483 .82048 m .55444 .82649 L .54412 .82152 L .392 .426 0 r
F
.53427 .81594 m .54483 .82048 L .54412 .82152 L .383 .414 0 r
F
.30309 1.02396 m .28092 1.01308 L .29037 1.01183 L .766 .775 0 r
F
.31198 1.02229 m .30309 1.02396 L .29037 1.01183 L .751 .766 0 r
F
.59793 .56611 m .61879 .56848 L .61239 .57188 L .663 .74 0 r
F
.27579 .69951 m .27247 .67954 L .2826 .68343 L .988 .772 0 r
F
.27579 .69951 m .26541 .69633 L .27247 .67954 L F
.73559 .8938 m .74021 .9111 L .72993 .90769 L .924 .751 0 r
F
.73559 .8938 m .74617 .89652 L .74021 .9111 L F
.5554 .82506 m .56476 .83155 L .55444 .82649 L .404 .441 0 r
F
.54483 .82048 m .5554 .82506 L .55444 .82649 L .392 .426 0 r
F
.5968 1.2918 m .57024 1.30455 L .56831 1.30018 L 1 1 0 r
F
.5968 1.2918 m .59973 1.29629 L .57024 1.30455 L F
.55351 1.06214 m .5417 1.05626 L .53974 1.05808 L .489 0 0 r
F
.55351 1.06214 m .55647 1.05781 L .5417 1.05626 L F
.56597 .82968 m .57509 .83669 L .56476 .83155 L .418 .459 0 r
F
.5554 .82506 m .56597 .82968 L .56476 .83155 L .404 .441 0 r
F
.4496 1.3165 m .44746 1.32062 L .41697 1.31844 L .771 .847 0 r
F
.47962 1.31661 m .44746 1.32062 L .4496 1.3165 L .808 .873 0 r
F
.50317 .80183 m .49405 .7962 L .50361 .8016 L .373 .401 0 r
F
.50317 .80183 m .49318 .79668 L .49405 .7962 L F
.57655 .83433 m .58542 .84191 L .57509 .83669 L .441 .479 0 r
F
.56597 .82968 m .57655 .83433 L .57509 .83669 L .418 .459 0 r
F
.52383 .81105 m .53427 .81594 L .52371 .81144 L .377 .407 0 r
F
.47001 1.04714 m .4668 1.04927 L .45258 1.04604 L .367 .379 0 r
F
.48365 1.04988 m .4668 1.04927 L .47001 1.04714 L .314 .265 0 r
F
.51003 1.31049 m .50992 1.31471 L .47962 1.31661 L .842 .898 0 r
F
.5393 1.30642 m .50992 1.31471 L .51003 1.31049 L .914 .939 0 r
F
.43894 1.04209 m .43381 1.04442 L .41997 1.03963 L .45 .557 0 r
F
.45258 1.04604 m .43381 1.04442 L .43894 1.04209 L .428 .507 0 r
F
.725 .89094 m .72993 .90769 L .71964 .90411 L .911 .74 0 r
F
.725 .89094 m .73559 .8938 L .72993 .90769 L F
.58714 .83901 m .59575 .84722 L .58542 .84191 L .475 .5 0 r
F
.57655 .83433 m .58714 .83901 L .58542 .84191 L .441 .479 0 r
F
.26541 .69633 m .26233 .67578 L .27247 .67954 L .996 .781 0 r
F
.26541 .69633 m .25502 .69326 L .26233 .67578 L F
.54488 .56191 m .54723 .55861 L .56292 .5613 L .471 .586 0 r
F
.52992 .5599 m .54723 .55861 L .54488 .56191 L .434 .487 0 r
F
.49318 .79668 m .48448 .79073 L .49405 .7962 L .376 .404 0 r
F
.49318 .79668 m .48319 .79147 L .48448 .79073 L F
.59773 .8437 m .60608 .85256 L .59575 .84722 L .516 .522 0 r
F
.58714 .83901 m .59773 .8437 L .59575 .84722 L .475 .5 0 r
F
.50361 .8016 m .49511 .79584 L .50414 .80142 L .371 .398 0 r
F
.50361 .8016 m .49405 .7962 L .49511 .79584 L F
.52383 .81105 m .53452 .81517 L .53427 .81594 L .377 .407 0 r
F
.52385 .81063 m .53452 .81517 L .52383 .81105 L .377 .408 0 r
F
.7144 .88793 m .71964 .90411 L .70935 .90036 L .896 .727 0 r
F
.7144 .88793 m .725 .89094 L .71964 .90411 L F
.53452 .81517 m .54483 .82048 L .53427 .81594 L .385 .418 0 r
F
.49962 .55803 m .5149 .55632 L .51478 .55865 L .246 .134 0 r
F
.49962 .55803 m .49861 .55675 L .5149 .55632 L F
.60833 .84836 m .61641 .85792 L .60608 .85256 L .561 .544 0 r
F
.59773 .8437 m .60833 .84836 L .60608 .85256 L .516 .522 0 r
F
.34259 1.02901 m .32089 1.0207 L .32982 1.0192 L .7 .745 0 r
F
.35089 1.02715 m .34259 1.02901 L .32982 1.0192 L .68 .733 0 r
F
.48319 .79147 m .47491 .78514 L .48448 .79073 L .381 .409 0 r
F
.48319 .79147 m .47319 .78615 L .47491 .78514 L F
.25502 .69326 m .25218 .67214 L .26233 .67578 L 1 .79 0 r
F
.25502 .69326 m .24462 .6903 L .25218 .67214 L F
.61893 .85297 m .62675 .86324 L .61641 .85792 L .607 .566 0 r
F
.60833 .84836 m .61893 .85297 L .61641 .85792 L .561 .544 0 r
F
.7038 .88475 m .70935 .90036 L .69905 .89641 L .877 .713 0 r
F
.7038 .88475 m .7144 .88793 L .70935 .90036 L F
.50414 .80142 m .49636 .79559 L .50477 .80129 L .369 .395 0 r
F
.50414 .80142 m .49511 .79584 L .49636 .79559 L F
.52385 .81063 m .53455 .81431 L .53452 .81517 L .377 .408 0 r
F
.52375 .81017 m .53455 .81431 L .52385 .81063 L F
.62954 .85749 m .63709 .86848 L .62675 .86324 L .652 .588 0 r
F
.61893 .85297 m .62954 .85749 L .62675 .86324 L .607 .566 0 r
F
.37216 1.03351 m .35089 1.02715 L .35921 1.0254 L .638 .715 0 r
F
.37978 1.03148 m .37216 1.03351 L .35921 1.0254 L .612 .697 0 r
F
.52992 .5599 m .53116 .55695 L .54723 .55861 L .434 .487 0 r
F
.51478 .55865 m .53116 .55695 L .52992 .5599 L .369 .312 0 r
F
.62451 1.28139 m .59973 1.29629 L .5968 1.2918 L 1 1 0 r
F
.62451 1.28139 m .62842 1.28603 L .59973 1.29629 L F
.6932 .88139 m .69905 .89641 L .68873 .89226 L .856 .699 0 r
F
.6932 .88139 m .7038 .88475 L .69905 .89641 L F
.54521 .81929 m .5554 .82506 L .54483 .82048 L .395 .432 0 r
F
.53452 .81517 m .54521 .81929 L .54483 .82048 L .385 .418 0 r
F
.51478 .55865 m .5149 .55632 L .53116 .55695 L .369 .312 0 r
F
.47319 .78615 m .46533 .77939 L .47491 .78514 L .388 .416 0 r
F
.47319 .78615 m .46319 .78072 L .46533 .77939 L F
.64015 .86189 m .64743 .8736 L .63709 .86848 L .695 .609 0 r
F
.62954 .85749 m .64015 .86189 L .63709 .86848 L .652 .588 0 r
F
.67818 .57175 m .70109 .57987 L .69231 .58255 L .82 .796 0 r
F
.67008 .57485 m .67818 .57175 L .69231 .58255 L .804 .787 0 r
F
.64758 .56902 m .67008 .57485 L .662 .57785 L .774 .783 0 r
F
.64028 .57234 m .64758 .56902 L .662 .57785 L .753 .771 0 r
F
.68259 .87786 m .68873 .89226 L .67841 .8879 L .832 .683 0 r
F
.68259 .87786 m .6932 .88139 L .68873 .89226 L F
.65076 .86614 m .65776 .87856 L .64743 .8736 L .735 .629 0 r
F
.64015 .86189 m .65076 .86614 L .64743 .8736 L .695 .609 0 r
F
.49405 .7962 m .48607 .79017 L .49511 .79584 L .372 .398 0 r
F
.49405 .7962 m .48448 .79073 L .48607 .79017 L F
.50477 .80129 m .49779 .79546 L .50548 .80123 L .367 .392 0 r
F
.50477 .80129 m .49636 .79559 L .49779 .79546 L F
.67198 .87414 m .67841 .8879 L .66809 .88334 L .804 .666 0 r
F
.67198 .87414 m .68259 .87786 L .67841 .8879 L F
.24462 .6903 m .24201 .6686 L .25218 .67214 L 1 .797 0 r
F
.24462 .6903 m .2342 .68744 L .24201 .6686 L F
.66137 .87023 m .66809 .88334 L .65776 .87856 L .771 .648 0 r
F
.65076 .86614 m .66137 .87023 L .65776 .87856 L .735 .629 0 r
F
.52375 .81017 m .53436 .81337 L .53455 .81431 L .377 .408 0 r
F
.52355 .80967 m .53436 .81337 L .52375 .81017 L F
.66137 .87023 m .67198 .87414 L .66809 .88334 L .771 .648 0 r
F
.26208 1.01579 m .24014 1.00208 L .25004 1.00117 L .817 .794 0 r
F
.27149 1.0144 m .26208 1.01579 L .25004 1.00117 L .806 .788 0 r
F
.46319 .78072 m .45574 .77345 L .46533 .77939 L .398 .425 0 r
F
.46319 .78072 m .45319 .77514 L .45574 .77345 L F
.53455 .81431 m .54521 .81929 L .53452 .81517 L .386 .42 0 r
F
.48075 1.31247 m .47962 1.31661 L .4496 1.3165 L .788 .863 0 r
F
.51003 1.31049 m .47962 1.31661 L .48075 1.31247 L .842 .898 0 r
F
.57805 .56498 m .58253 .56134 L .59793 .56611 L .597 .704 0 r
F
.56292 .5613 m .58253 .56134 L .57805 .56498 L .558 .682 0 r
F
.77035 .57786 m .79351 .59272 L .78358 .5947 L .911 .822 0 r
F
.76088 .58042 m .77035 .57786 L .78358 .5947 L .903 .818 0 r
F
.55592 .82342 m .56597 .82968 L .5554 .82506 L .408 .45 0 r
F
.54521 .81929 m .55592 .82342 L .5554 .82506 L .395 .432 0 r
F
.54789 .29198 m .54916 .28556 L .58123 .2872 L 1 .931 0 r
F
.51652 .29304 m .54916 .28556 L .54789 .29198 L 1 .947 0 r
F
.71874 .57424 m .742 .58534 L .73258 .58769 L .867 .809 0 r
F
.70991 .5771 m .71874 .57424 L .73258 .58769 L .856 .803 0 r
F
.50548 .80123 m .49937 .79546 L .50627 .80122 L .366 .39 0 r
F
.50548 .80123 m .49779 .79546 L .49937 .79546 L F
.45319 .77514 m .44615 .7673 L .45574 .77345 L .411 .438 0 r
F
.45319 .77514 m .44319 .76941 L .44615 .7673 L F
.52355 .80967 m .53396 .81237 L .53436 .81337 L .377 .408 0 r
F
.52324 .80915 m .53396 .81237 L .52355 .80967 L .376 .407 0 r
F
.42346 .31192 m .45177 .29649 L .45393 .30304 L 1 .972 0 r
F
.42346 .31192 m .42019 .3054 L .45177 .29649 L F
.45678 1.04383 m .45258 1.04604 L .43894 1.04209 L .404 .461 0 r
F
.47001 1.04714 m .45258 1.04604 L .45678 1.04383 L .367 .379 0 r
F
.2342 .68744 m .23182 .66515 L .24201 .6686 L 1 .804 0 r
F
.2342 .68744 m .22378 .68465 L .23182 .66515 L F
.44319 .76941 m .43656 .76091 L .44615 .7673 L .433 .454 0 r
F
.44319 .76941 m .43318 .76353 L .43656 .76091 L F
.45144 .56419 m .46344 .56405 L .46671 .56071 L .258 0 0 r
F
.45144 .56419 m .44702 .57598 L .46344 .56405 L F
.43654 .59359 m .44702 .57598 L .44472 .57746 L 0 0 0 r
F
.43654 .59359 m .43095 .61283 L .44428 .58226 L F
.43862 .5901 m .44428 .58226 L .44702 .57598 L F
.43654 .59359 m .44428 .58226 L .43862 .5901 L F
.44472 .57746 m .44702 .57598 L .45144 .56419 L F
.44264 .58006 m .45689 .56463 L .45699 .56465 L 1 .856 0 r
F
.44702 .57598 m .46017 .56539 L .46344 .56405 L 0 0 0 r
F
.44702 .57598 m .44918 .57458 L .46017 .56539 L F
.4508 .57323 m .45699 .56465 L .46017 .56539 L 1 .856 0 r
F
.43095 .61283 m .44264 .58006 L .44702 .57598 L 1 .995 0 r
F
.44702 .57598 m .44264 .58006 L .44918 .57458 L 0 0 0 r
F
.44264 .58006 m .45699 .56465 L .4508 .57323 L 1 .856 0 r
F
.31198 1.02229 m .29037 1.01183 L .29984 1.01066 L .751 .766 0 r
F
.32089 1.0207 m .31198 1.02229 L .29984 1.01066 L .735 .756 0 r
F
.50627 .80122 m .5011 .79558 L .50714 .80128 L .365 .388 0 r
F
.50627 .80122 m .49937 .79546 L .5011 .79558 L F
.56664 .82755 m .57655 .83433 L .56597 .82968 L .423 .469 0 r
F
.55592 .82342 m .56664 .82755 L .56597 .82968 L .408 .45 0 r
F
.48448 .79073 m .47702 .78438 L .48607 .79017 L .374 .398 0 r
F
.48448 .79073 m .47491 .78514 L .47702 .78438 L F
.43318 .76353 m .42696 .75428 L .43656 .76091 L .471 .473 0 r
F
.43318 .76353 m .42318 .75751 L .42696 .75428 L F
.52324 .80915 m .53334 .81132 L .53396 .81237 L .376 .407 0 r
F
.52282 .8086 m .53334 .81132 L .52324 .80915 L .375 .406 0 r
F
.49511 .79584 m .48794 .7898 L .49636 .79559 L .368 .391 0 r
F
.49511 .79584 m .48607 .79017 L .48794 .7898 L F
.56697 1.07117 m .55647 1.05781 L .55351 1.06214 L .84 .035 0 r
F
.56697 1.07117 m .5709 1.06422 L .55647 1.05781 L F
.42318 .75751 m .41736 .74743 L .42696 .75428 L .521 .495 0 r
F
.42318 .75751 m .41318 .7514 L .41736 .74743 L F
.53455 .81431 m .54527 .81797 L .54521 .81929 L .386 .42 0 r
F
.53436 .81337 m .54527 .81797 L .53455 .81431 L .386 .421 0 r
F
.41318 .7514 m .40776 .74041 L .41736 .74743 L .578 .519 0 r
F
.41318 .7514 m .40317 .74524 L .40776 .74041 L F
.54527 .81797 m .55592 .82342 L .54521 .81929 L .397 .436 0 r
F
.40317 .74524 m .39816 .73329 L .40776 .74041 L .638 .543 0 r
F
.40317 .74524 m .39317 .73909 L .39816 .73329 L F
.50714 .80128 m .50295 .79581 L .50806 .80139 L .364 .387 0 r
F
.50714 .80128 m .5011 .79558 L .50295 .79581 L F
.52282 .8086 m .53251 .81022 L .53334 .81132 L .375 .406 0 r
F
.52231 .80804 m .53251 .81022 L .52282 .8086 L .374 .405 0 r
F
.22378 .68465 m .22163 .66179 L .23182 .66515 L 1 .81 0 r
F
.22378 .68465 m .21335 .68195 L .22163 .66179 L F
.39317 .73909 m .38856 .72617 L .39816 .73329 L .699 .568 0 r
F
.39317 .73909 m .38316 .73303 L .38856 .72617 L F
.57736 .83167 m .58714 .83901 L .57655 .83433 L .45 .491 0 r
F
.56664 .82755 m .57736 .83167 L .57655 .83433 L .423 .469 0 r
F
.38316 .73303 m .37895 .71915 L .38856 .72617 L .756 .593 0 r
F
.38316 .73303 m .37315 .72709 L .37895 .71915 L F
.68238 1.26059 m .66091 1.2788 L .65605 1.27402 L 1 .965 0 r
F
.68238 1.26059 m .68816 1.26544 L .66091 1.2788 L F
.50806 .80139 m .50491 .79616 L .50904 .80156 L .364 .387 0 r
F
.50806 .80139 m .50295 .79581 L .50491 .79616 L F
.37315 .72709 m .36933 .71231 L .37895 .71915 L .808 .617 0 r
F
.37315 .72709 m .36313 .72135 L .36933 .71231 L F
.52231 .80804 m .53149 .80909 L .53251 .81022 L .374 .405 0 r
F
.5217 .80746 m .53149 .80909 L .52231 .80804 L .374 .404 0 r
F
.62522 .56493 m .64758 .56902 L .64028 .57234 L .739 .775 0 r
F
.61879 .56848 m .62522 .56493 L .64028 .57234 L .713 .76 0 r
F
.47491 .78514 m .46796 .77841 L .47702 .78438 L .378 .4 0 r
F
.47491 .78514 m .46533 .77939 L .46796 .77841 L F
.59793 .56611 m .60341 .56245 L .61879 .56848 L .663 .74 0 r
F
.58253 .56134 m .60341 .56245 L .59793 .56611 L .636 .733 0 r
F
.49636 .79559 m .49008 .78962 L .49779 .79546 L .364 .385 0 r
F
.49636 .79559 m .48794 .7898 L .49008 .78962 L F
.51652 .29304 m .51664 .28653 L .54916 .28556 L 1 .947 0 r
F
.48508 .29673 m .51664 .28653 L .51652 .29304 L 1 .962 0 r
F
.36313 .72135 m .3597 .70571 L .36933 .71231 L .853 .64 0 r
F
.36313 .72135 m .3531 .71582 L .3597 .70571 L F
.49874 1.05072 m .49757 1.05213 L .48365 1.04988 L .195 .122 0 r
F
.51176 1.05317 m .49757 1.05213 L .49874 1.05072 L .069 .11 0 r
F
.51176 1.05317 m .51165 1.05401 L .49757 1.05213 L F
.40014 1.03616 m .37978 1.03148 L .38742 1.02958 L .56 .667 0 r
F
.40702 1.03408 m .40014 1.03616 L .38742 1.02958 L .531 .642 0 r
F
.41997 1.03963 m .40014 1.03616 L .40702 1.03408 L .501 .623 0 r
F
.65118 1.26922 m .62842 1.28603 L .62451 1.28139 L 1 1 0 r
F
.65118 1.26922 m .65605 1.27402 L .62842 1.28603 L F
.42601 1.03745 m .41997 1.03963 L .40702 1.03408 L .472 .591 0 r
F
.43894 1.04209 m .41997 1.03963 L .42601 1.03745 L .45 .557 0 r
F
.50904 .80156 m .50695 .79662 L .51006 .80178 L .364 .387 0 r
F
.50904 .80156 m .50491 .79616 L .50695 .79662 L F
.45393 .30304 m .48405 .29018 L .48508 .29673 L 1 .971 0 r
F
.45393 .30304 m .45177 .29649 L .48405 .29018 L F
.5217 .80746 m .53027 .80795 L .53149 .80909 L .374 .404 0 r
F
.521 .80688 m .53027 .80795 L .5217 .80746 L .373 .403 0 r
F
.53436 .81337 m .545 .81654 L .54527 .81797 L .386 .421 0 r
F
.53396 .81237 m .545 .81654 L .53436 .81337 L F
.21335 .68195 m .21142 .6585 L .22163 .66179 L 1 .816 0 r
F
.21335 .68195 m .2029 .67931 L .21142 .6585 L F
.5881 .83576 m .59773 .8437 L .58714 .83901 L .485 .514 0 r
F
.57736 .83167 m .5881 .83576 L .58714 .83901 L .45 .491 0 r
F
.52481 1.05578 m .52575 1.0558 L .52334 1.0555 L .106 0 0 r
F
.52481 1.05578 m .52334 1.0555 L .51165 1.05401 L F
.52633 1.05607 m .52481 1.05578 L .52387 1.05529 L .25 0 0 r
F
.53777 1.05911 m .52575 1.0558 L .52481 1.05578 L .309 0 0 r
F
.53578 1.05908 m .53777 1.05911 L .53178 1.05757 L .25 0 0 r
F
.53578 1.05908 m .53178 1.05757 L .52481 1.05578 L F
.5475 1.06411 m .53777 1.05911 L .53578 1.05908 L .404 0 0 r
F
.54005 1.06069 m .53578 1.05908 L .53378 1.05802 L 0 .059 0 r
F
.54445 1.06257 m .53578 1.05908 L .54005 1.06069 L F
.53578 1.05908 m .52481 1.05578 L .52633 1.05607 L .25 0 0 r
F
.52481 1.05578 m .51165 1.05401 L .51176 1.05317 L .106 0 0 r
F
.41697 1.31844 m .38321 1.31826 L .38731 1.31437 L .763 .837 0 r
F
.4201 1.31444 m .41697 1.31844 L .38731 1.31437 L .746 .828 0 r
F
.4496 1.3165 m .41697 1.31844 L .4201 1.31444 L .771 .847 0 r
F
.27149 1.0144 m .25004 1.00117 L .25995 1.00033 L .806 .788 0 r
F
.28092 1.01308 m .27149 1.0144 L .25995 1.00033 L .794 .781 0 r
F
.55601 .82162 m .56664 .82755 L .55592 .82342 L .411 .455 0 r
F
.54527 .81797 m .55601 .82162 L .55592 .82342 L .397 .436 0 r
F
.3531 .71582 m .35006 .6994 L .3597 .70571 L .891 .662 0 r
F
.3531 .71582 m .34307 .71053 L .35006 .6994 L F
.51006 .80178 m .50906 .79718 L .51112 .80206 L .364 .388 0 r
F
.51006 .80178 m .50695 .79662 L .50906 .79718 L F
.35089 1.02715 m .32982 1.0192 L .33877 1.0178 L .68 .733 0 r
F
.35921 1.0254 m .35089 1.02715 L .33877 1.0178 L .658 .718 0 r
F
.521 .80688 m .52887 .80679 L .53027 .80795 L .373 .403 0 r
F
.52022 .80631 m .52887 .80679 L .521 .80688 L .372 .402 0 r
F
.48607 .79017 m .47951 .78389 L .48794 .7898 L .367 .387 0 r
F
.48607 .79017 m .47702 .78438 L .47951 .78389 L F
.77984 .57525 m .80346 .59069 L .79351 .59272 L .918 .826 0 r
F
.77035 .57786 m .77984 .57525 L .79351 .59272 L .911 .822 0 r
F
.60341 .56245 m .62522 .56493 L .61879 .56848 L .695 .761 0 r
F
.53839 1.30225 m .5393 1.30642 L .51003 1.31049 L .897 .933 0 r
F
.56638 1.29593 m .5393 1.30642 L .53839 1.30225 L .993 .981 0 r
F
.56638 1.29593 m .56831 1.30018 L .5393 1.30642 L F
.56292 .5613 m .56635 .55765 L .58253 .56134 L .558 .682 0 r
F
.54723 .55861 m .56635 .55765 L .56292 .5613 L .511 .641 0 r
F
.48585 1.0481 m .48365 1.04988 L .47001 1.04714 L .28 .222 0 r
F
.49874 1.05072 m .48365 1.04988 L .48585 1.0481 L .195 .122 0 r
F
.48508 .29673 m .48405 .29018 L .51664 .28653 L 1 .962 0 r
F
.51112 .80206 m .51122 .79784 L .51219 .80239 L .365 .39 0 r
F
.51112 .80206 m .50906 .79718 L .51122 .79784 L F
.52022 .80631 m .52732 .80564 L .52887 .80679 L .372 .402 0 r
F
.51937 .80573 m .52732 .80564 L .52022 .80631 L .371 .401 0 r
F
.46533 .77939 m .45889 .77222 L .46796 .77841 L .384 .403 0 r
F
.46533 .77939 m .45574 .77345 L .45889 .77222 L F
.545 .81654 m .55601 .82162 L .54527 .81797 L .398 .438 0 r
F
.59386 1.2874 m .56831 1.30018 L .56638 1.29593 L 1 1 0 r
F
.59386 1.2874 m .5968 1.2918 L .56831 1.30018 L F
.34307 .71053 m .34041 .69339 L .35006 .6994 L .923 .682 0 r
F
.34307 .71053 m .33302 .70548 L .34041 .69339 L F
.59885 .8398 m .60833 .84836 L .59773 .8437 L .524 .536 0 r
F
.5881 .83576 m .59885 .8398 L .59773 .8437 L .485 .514 0 r
F
.51219 .80239 m .51339 .79859 L .51327 .80276 L .366 .391 0 r
F
.51219 .80239 m .51122 .79784 L .51339 .79859 L F
.51937 .80573 m .52562 .80451 L .52732 .80564 L .371 .401 0 r
F
.51846 .80518 m .52562 .80451 L .51937 .80573 L .371 .4 0 r
F
.49779 .79546 m .49245 .78963 L .49937 .79546 L .36 .38 0 r
F
.49779 .79546 m .49008 .78962 L .49245 .78963 L F
.68631 .56854 m .70991 .5771 L .70109 .57987 L .835 .803 0 r
F
.67818 .57175 m .68631 .56854 L .70109 .57987 L .82 .796 0 r
F
.45174 1.31244 m .4496 1.3165 L .4201 1.31444 L .751 .836 0 r
F
.48075 1.31247 m .4496 1.3165 L .45174 1.31244 L .788 .863 0 r
F
.46671 .56071 m .47413 .55938 L .47378 .55959 L .072 0 0 r
F
.47378 .55959 m .48035 .55827 L .48249 .55821 L F
.47413 .55938 m .48035 .55827 L .47378 .55959 L F
.46671 .56071 m .46344 .56405 L .48035 .55827 L F
.46344 .56405 m .46017 .56539 L .47505 .55882 L .302 .139 0 r
F
.47491 .5589 m .47505 .55882 L .4782 .55743 L F
.46344 .56405 m .47505 .55882 L .47491 .5589 L F
.51327 .80276 m .51556 .79943 L .51436 .80318 L .367 .393 0 r
F
.51327 .80276 m .51339 .79859 L .51556 .79943 L F
.51846 .80518 m .52378 .8034 L .52562 .80451 L .371 .4 0 r
F
.51749 .80464 m .52378 .8034 L .51846 .80518 L .37 .399 0 r
F
.38731 1.31437 m .38321 1.31826 L .3537 1.31218 L .747 .822 0 r
F
.53396 .81237 m .5444 .81502 L .545 .81654 L .386 .421 0 r
F
.53334 .81132 m .5444 .81502 L .53396 .81237 L .384 .42 0 r
F
.72759 .5713 m .75143 .58291 L .742 .58534 L .878 .815 0 r
F
.71874 .57424 m .72759 .5713 L .742 .58534 L .867 .809 0 r
F
.71383 1.2509 m .69392 1.27022 L .68816 1.26544 L 1 .933 0 r
F
.71383 1.2509 m .72046 1.25563 L .69392 1.27022 L F
.51436 .80318 m .51771 .80033 L .51543 .80363 L .368 .395 0 r
F
.51436 .80318 m .51556 .79943 L .51771 .80033 L F
.51749 .80464 m .52184 .80233 L .52378 .8034 L .37 .399 0 r
F
.51648 .80412 m .52184 .80233 L .51749 .80464 L .369 .398 0 r
F
.53777 1.05911 m .53974 1.05808 L .52575 1.0558 L .309 0 0 r
F
.51543 .80363 m .51981 .8013 L .51648 .80412 L .369 .397 0 r
F
.51543 .80363 m .51771 .80033 L .51981 .8013 L F
.51648 .80412 m .51981 .8013 L .52184 .80233 L .369 .398 0 r
F
.22039 1.00408 m .21053 1.00516 L .19941 .98741 L .858 .809 0 r
F
.51014 1.30639 m .51003 1.31049 L .48075 1.31247 L .82 .887 0 r
F
.53839 1.30225 m .51003 1.31049 L .51014 1.30639 L .897 .933 0 r
F
.37978 1.03148 m .35921 1.0254 L .36755 1.02377 L .612 .697 0 r
F
.38742 1.02958 m .37978 1.03148 L .36755 1.02377 L .586 .677 0 r
F
.4441 1.03993 m .43894 1.04209 L .42601 1.03745 L .43 .518 0 r
F
.45678 1.04383 m .43894 1.04209 L .4441 1.03993 L .404 .461 0 r
F
.33302 .70548 m .33074 .68768 L .34041 .69339 L .95 .702 0 r
F
.33302 .70548 m .32296 .70067 L .33074 .68768 L F
.65489 .56557 m .67818 .57175 L .67008 .57485 L .794 .794 0 r
F
.64758 .56902 m .65489 .56557 L .67008 .57485 L .774 .783 0 r
F
.56675 .82522 m .57736 .83167 L .56664 .82755 L .427 .477 0 r
F
.55601 .82162 m .56675 .82522 L .56664 .82755 L .411 .455 0 r
F
.6096 .84376 m .61893 .85297 L .60833 .84836 L .566 .559 0 r
F
.59885 .8398 m .6096 .84376 L .60833 .84836 L .524 .536 0 r
F
.45574 .77345 m .44981 .76575 L .45889 .77222 L .394 .41 0 r
F
.45574 .77345 m .44615 .7673 L .44981 .76575 L F
.32089 1.0207 m .29984 1.01066 L .30932 1.00958 L .735 .756 0 r
F
.32982 1.0192 m .32089 1.0207 L .30932 1.00958 L .718 .745 0 r
F
.47324 1.04515 m .47001 1.04714 L .45678 1.04383 L .339 .334 0 r
F
.48585 1.0481 m .47001 1.04714 L .47324 1.04515 L .28 .222 0 r
F
.49937 .79546 m .49504 .78983 L .5011 .79558 L .357 .375 0 r
F
.49937 .79546 m .49245 .78963 L .49504 .78983 L F
.47702 .78438 m .47106 .77779 L .47951 .78389 L .367 .382 0 r
F
.47702 .78438 m .46796 .77841 L .47106 .77779 L F
.32296 .70067 m .32105 .68224 L .33074 .68768 L .971 .719 0 r
F
.32296 .70067 m .31289 .69607 L .32105 .68224 L F
.48794 .7898 m .48235 .78367 L .49008 .78962 L .359 .375 0 r
F
.48794 .7898 m .47951 .78389 L .48235 .78367 L F
.62058 1.27679 m .5968 1.2918 L .59386 1.2874 L 1 1 0 r
F
.62058 1.27679 m .62451 1.28139 L .5968 1.2918 L F
.53334 .81132 m .54347 .81342 L .5444 .81502 L .384 .42 0 r
F
.53251 .81022 m .54347 .81342 L .53334 .81132 L .383 .418 0 r
F
.62037 .84762 m .62954 .85749 L .61893 .85297 L .608 .581 0 r
F
.6096 .84376 m .62037 .84762 L .61893 .85297 L .566 .559 0 r
F
.545 .81654 m .55565 .81966 L .55601 .82162 L .398 .438 0 r
F
.5444 .81502 m .55565 .81966 L .545 .81654 L .397 .438 0 r
F
.44615 .7673 m .44073 .75897 L .44981 .76575 L .408 .421 0 r
F
.44615 .7673 m .43656 .76091 L .44073 .75897 L F
.54723 .55861 m .54959 .55509 L .56635 .55765 L .511 .641 0 r
F
.53116 .55695 m .54959 .55509 L .54723 .55861 L .474 .565 0 r
F
.55565 .81966 m .56675 .82522 L .55601 .82162 L .411 .458 0 r
F
.48249 .55821 m .4976 .5551 L .49861 .55675 L .184 .129 0 r
F
.57752 .82877 m .5881 .83576 L .57736 .83167 L .454 .5 0 r
F
.56675 .82522 m .57752 .82877 L .57736 .83167 L .427 .477 0 r
F
.31289 .69607 m .31135 .67706 L .32105 .68224 L .989 .735 0 r
F
.31289 .69607 m .30281 .69168 L .31135 .67706 L F
.28092 1.01308 m .25995 1.00033 L .26987 .99955 L .794 .781 0 r
F
.29037 1.01183 m .28092 1.01308 L .26987 .99955 L .781 .773 0 r
F
.63114 .85136 m .64015 .86189 L .62954 .85749 L .648 .602 0 r
F
.62037 .84762 m .63114 .85136 L .62954 .85749 L .608 .581 0 r
F
.77984 .57525 m .78935 .57258 L .80346 .59069 L .918 .826 0 r
F
.5011 .79558 m .49782 .79021 L .50295 .79581 L .355 .372 0 r
F
.5011 .79558 m .49504 .78983 L .49782 .79021 L F
.53251 .81022 m .54223 .81177 L .54347 .81342 L .383 .418 0 r
F
.53149 .80909 m .54223 .81177 L .53251 .81022 L .381 .416 0 r
F
.48189 1.30843 m .48075 1.31247 L .45174 1.31244 L .764 .849 0 r
F
.51014 1.30639 m .48075 1.31247 L .48189 1.30843 L .82 .887 0 r
F
.43656 .76091 m .43164 .75184 L .44073 .75897 L .433 .436 0 r
F
.43656 .76091 m .42696 .75428 L .43164 .75184 L F
.22039 1.00408 m .19941 .98741 L .20968 .9869 L .858 .809 0 r
F
.23026 1.00305 m .22039 1.00408 L .20968 .9869 L .85 .804 0 r
F
.55052 1.06416 m .53974 1.05808 L .53777 1.05911 L .494 0 0 r
F
.55052 1.06416 m .55351 1.06214 L .53974 1.05808 L F
.58253 .56134 m .58702 .55752 L .60341 .56245 L .636 .733 0 r
F
.56635 .55765 m .58702 .55752 L .58253 .56134 L .604 .72 0 r
F
.64191 .85495 m .65076 .86614 L .64015 .86189 L .686 .622 0 r
F
.63114 .85136 m .64191 .85495 L .64015 .86189 L .648 .602 0 r
F
.82529 .89332 m .83063 .91446 L .82009 .9125 L .957 .811 0 r
F
.82529 .89332 m .83607 .89465 L .83063 .91446 L F
.46796 .77841 m .46261 .77146 L .47106 .77779 L .368 .378 0 r
F
.46796 .77841 m .45889 .77222 L .46261 .77146 L F
.53116 .55695 m .53241 .55374 L .54959 .55509 L .474 .565 0 r
F
.5149 .55632 m .53241 .55374 L .53116 .55695 L .431 .422 0 r
F
.30281 .69168 m .30162 .6721 L .31135 .67706 L 1 .75 0 r
F
.30281 .69168 m .29271 .68747 L .30162 .6721 L F
.49008 .78962 m .48551 .78372 L .49245 .78963 L .353 .365 0 r
F
.49008 .78962 m .48235 .78367 L .48551 .78372 L F
.42696 .75428 m .42255 .74433 L .43164 .75184 L .48 .456 0 r
F
.42696 .75428 m .41736 .74743 L .42255 .74433 L F
.49861 .55675 m .51502 .5537 L .5149 .55632 L .349 .186 0 r
F
.49861 .55675 m .4976 .5551 L .51502 .5537 L F
.67659 1.25569 m .65605 1.27402 L .65118 1.26922 L 1 .968 0 r
F
.67659 1.25569 m .68238 1.26059 L .65605 1.27402 L F
.50295 .79581 m .50076 .79077 L .50491 .79616 L .354 .371 0 r
F
.50295 .79581 m .49782 .79021 L .50076 .79077 L F
.81452 .89192 m .82009 .9125 L .80955 .91049 L .952 .806 0 r
F
.81452 .89192 m .82529 .89332 L .82009 .9125 L F
.53149 .80909 m .54069 .81008 L .54223 .81177 L .381 .416 0 r
F
.53027 .80795 m .54069 .81008 L .53149 .80909 L .379 .413 0 r
F
.461 1.04178 m .45678 1.04383 L .4441 1.03993 L .379 .419 0 r
F
.47324 1.04515 m .45678 1.04383 L .461 1.04178 L .339 .334 0 r
F
.5883 .83224 m .59885 .8398 L .5881 .83576 L .489 .523 0 r
F
.57752 .82877 m .5883 .83224 L .5881 .83576 L .454 .5 0 r
F
.35921 1.0254 m .33877 1.0178 L .34774 1.01652 L .658 .718 0 r
F
.36755 1.02377 m .35921 1.0254 L .34774 1.01652 L .635 .702 0 r
F
.5444 .81502 m .55485 .8176 L .55565 .81966 L .397 .438 0 r
F
.54347 .81342 m .55485 .8176 L .5444 .81502 L .396 .437 0 r
F
.65269 .85838 m .66137 .87023 L .65076 .86614 L .722 .641 0 r
F
.64191 .85495 m .65269 .85838 L .65076 .86614 L .686 .622 0 r
F
.63166 .56124 m .65489 .56557 L .64758 .56902 L .763 .789 0 r
F
.62522 .56493 m .63166 .56124 L .64758 .56902 L .739 .775 0 r
F
.5149 .55632 m .51502 .5537 L .53241 .55374 L .431 .422 0 r
F
.73647 .56828 m .76088 .58042 L .75143 .58291 L .888 .819 0 r
F
.72759 .5713 m .73647 .56828 L .75143 .58291 L .878 .815 0 r
F
.80374 .89046 m .80955 .91049 L .799 .90839 L .947 .8 0 r
F
.80374 .89046 m .81452 .89192 L .80955 .91049 L F
.47951 .78389 m .47461 .77755 L .48235 .78367 L .354 .363 0 r
F
.47951 .78389 m .47106 .77779 L .47461 .77755 L F
.41736 .74743 m .41346 .73648 L .42255 .74433 L .541 .481 0 r
F
.41736 .74743 m .40776 .74041 L .41346 .73648 L F
.56632 .82271 m .57752 .82877 L .56675 .82522 L .427 .481 0 r
F
.55565 .81966 m .56632 .82271 L .56675 .82522 L .411 .458 0 r
F
.69445 .56523 m .71874 .57424 L .70991 .5771 L .849 .81 0 r
F
.68631 .56854 m .69445 .56523 L .70991 .5771 L .835 .803 0 r
F
.66348 .86164 m .67198 .87414 L .66137 .87023 L .754 .658 0 r
F
.65269 .85838 m .66348 .86164 L .66137 .87023 L .722 .641 0 r
F
.40702 1.03408 m .38742 1.02958 L .39509 1.02782 L .531 .642 0 r
F
.41391 1.03215 m .40702 1.03408 L .39509 1.02782 L .501 .615 0 r
F
.42601 1.03745 m .40702 1.03408 L .41391 1.03215 L .472 .591 0 r
F
.64629 1.26441 m .62451 1.28139 L .62058 1.27679 L 1 1 0 r
F
.64629 1.26441 m .65118 1.26922 L .62451 1.28139 L F
.79295 .88892 m .799 .90839 L .78845 .90622 L .941 .794 0 r
F
.79295 .88892 m .80374 .89046 L .799 .90839 L F
.50491 .79616 m .50383 .79148 L .50695 .79662 L .354 .372 0 r
F
.50491 .79616 m .50076 .79077 L .50383 .79148 L F
.29271 .68747 m .29188 .66734 L .30162 .6721 L 1 .763 0 r
F
.29271 .68747 m .2826 .68343 L .29188 .66734 L F
.53027 .80795 m .53887 .80836 L .54069 .81008 L .379 .413 0 r
F
.52887 .80679 m .53887 .80836 L .53027 .80795 L .377 .41 0 r
F
.58006 1.08913 m .5709 1.06422 L .56697 1.07117 L .929 .076 0 r
F
.58006 1.08913 m .58509 1.09426 L .5709 1.06422 L F
.55485 .8176 m .56632 .82271 L .55565 .81966 L .411 .459 0 r
F
.40776 .74041 m .40436 .72836 L .41346 .73648 L .612 .508 0 r
F
.40776 .74041 m .39816 .73329 L .40436 .72836 L F
.78217 .8873 m .78845 .90622 L .77789 .90395 L .934 .787 0 r
F
.78217 .8873 m .79295 .88892 L .78845 .90622 L F
.32982 1.0192 m .30932 1.00958 L .31882 1.00859 L .718 .745 0 r
F
.33877 1.0178 m .32982 1.0192 L .31882 1.00859 L .699 .733 0 r
F
.66348 .86164 m .67427 .86473 L .67198 .87414 L .754 .658 0 r
F
.67427 .86473 m .68259 .87786 L .67198 .87414 L .783 .675 0 r
F
.43207 1.03544 m .42601 1.03745 L .41391 1.03215 L .45 .558 0 r
F
.4441 1.03993 m .42601 1.03745 L .43207 1.03544 L .43 .518 0 r
F
.60341 .56245 m .60891 .55862 L .62522 .56493 L .695 .761 0 r
F
.58702 .55752 m .60891 .55862 L .60341 .56245 L .674 .759 0 r
F
.70717 1.24608 m .68816 1.26544 L .68238 1.26059 L 1 .933 0 r
F
.70717 1.24608 m .71383 1.2509 L .68816 1.26544 L F
.45889 .77222 m .45414 .76483 L .46261 .77146 L .372 .376 0 r
F
.45889 .77222 m .44981 .76575 L .45414 .76483 L F
.77139 .8856 m .77789 .90395 L .76732 .90159 L .927 .78 0 r
F
.77139 .8856 m .78217 .8873 L .77789 .90395 L F
.59909 .83561 m .6096 .84376 L .59885 .8398 L .526 .547 0 r
F
.5883 .83224 m .59909 .83561 L .59885 .8398 L .489 .523 0 r
F
.39816 .73329 m .39527 .72007 L .40436 .72836 L .687 .536 0 r
F
.39816 .73329 m .38856 .72617 L .39527 .72007 L F
.68506 .86765 m .6932 .88139 L .68259 .87786 L .808 .691 0 r
F
.67427 .86473 m .68506 .86765 L .68259 .87786 L .783 .675 0 r
F
.60891 .55862 m .63166 .56124 L .62522 .56493 L .725 .779 0 r
F
.4201 1.31444 m .38731 1.31437 L .39142 1.31054 L .746 .828 0 r
F
.42325 1.31051 m .4201 1.31444 L .39142 1.31054 L .727 .816 0 r
F
.45174 1.31244 m .4201 1.31444 L .42325 1.31051 L .751 .836 0 r
F
.23026 1.00305 m .20968 .9869 L .21996 .98644 L .85 .804 0 r
F
.24014 1.00208 m .23026 1.00305 L .21996 .98644 L .841 .798 0 r
F
.49245 .78963 m .48897 .78403 L .49504 .78983 L .347 .357 0 r
F
.49245 .78963 m .48551 .78372 L .48897 .78403 L F
.50695 .79662 m .507 .79235 L .50906 .79718 L .355 .374 0 r
F
.50695 .79662 m .50383 .79148 L .507 .79235 L F
.7606 .88379 m .76732 .90159 L .75675 .89912 L .918 .772 0 r
F
.7606 .88379 m .77139 .8856 L .76732 .90159 L F
.52887 .80679 m .53678 .80664 L .53887 .80836 L .377 .41 0 r
F
.52732 .80564 m .53678 .80664 L .52887 .80679 L .375 .408 0 r
F
.66223 .562 m .68631 .56854 L .67818 .57175 L .812 .803 0 r
F
.65489 .56557 m .66223 .562 L .67818 .57175 L .794 .794 0 r
F
.38742 1.02958 m .36755 1.02377 L .37591 1.02227 L .586 .677 0 r
F
.39509 1.02782 m .38742 1.02958 L .37591 1.02227 L .558 .656 0 r
F
.29037 1.01183 m .26987 .99955 L .27981 .99885 L .781 .773 0 r
F
.29984 1.01066 m .29037 1.01183 L .27981 .99885 L .768 .765 0 r
F
.69585 .8704 m .7038 .88475 L .6932 .88139 L .831 .705 0 r
F
.68506 .86765 m .69585 .8704 L .6932 .88139 L .808 .691 0 r
F
.54347 .81342 m .55363 .81544 L .55485 .8176 L .396 .437 0 r
F
.54223 .81177 m .55363 .81544 L .54347 .81342 L .393 .435 0 r
F
.74981 .88188 m .75675 .89912 L .74617 .89652 L .908 .763 0 r
F
.74981 .88188 m .7606 .88379 L .75675 .89912 L F
.38856 .72617 m .38617 .71179 L .39527 .72007 L .76 .565 0 r
F
.38856 .72617 m .37895 .71915 L .38617 .71179 L F
.70664 .87298 m .7144 .88793 L .7038 .88475 L .851 .719 0 r
F
.69585 .8704 m .70664 .87298 L .7038 .88475 L .831 .705 0 r
F
.2826 .68343 m .28213 .66276 L .29188 .66734 L 1 .775 0 r
F
.2826 .68343 m .27247 .67954 L .28213 .66276 L F
.73902 .87985 m .74617 .89652 L .73559 .8938 L .896 .753 0 r
F
.73902 .87985 m .74981 .88188 L .74617 .89652 L F
.53747 1.29823 m .53839 1.30225 L .51014 1.30639 L .874 .923 0 r
F
.56444 1.29181 m .53839 1.30225 L .53747 1.29823 L .982 .98 0 r
F
.56444 1.29181 m .56638 1.29593 L .53839 1.30225 L F
.71744 .87541 m .725 .89094 L .7144 .88793 L .868 .731 0 r
F
.70664 .87298 m .71744 .87541 L .7144 .88793 L .851 .719 0 r
F
.72823 .8777 m .73559 .8938 L .725 .89094 L .883 .743 0 r
F
.72823 .8777 m .73902 .87985 L .73559 .8938 L F
.71744 .87541 m .72823 .8777 L .725 .89094 L .868 .731 0 r
F
.38731 1.31437 m .3537 1.31218 L .35873 1.30851 L .747 .822 0 r
F
.39142 1.31054 m .38731 1.31437 L .35873 1.30851 L .731 .813 0 r
F
.50906 .79718 m .51024 .79335 L .51122 .79784 L .357 .377 0 r
F
.50906 .79718 m .507 .79235 L .51024 .79335 L F
.59091 1.28311 m .56638 1.29593 L .56444 1.29181 L 1 1 0 r
F
.59091 1.28311 m .59386 1.2874 L .56638 1.29593 L F
.52732 .80564 m .53444 .80494 L .53678 .80664 L .375 .408 0 r
F
.52562 .80451 m .53444 .80494 L .52732 .80564 L .372 .405 0 r
F
.57701 .82566 m .5883 .83224 L .57752 .82877 L .455 .505 0 r
F
.56632 .82271 m .57701 .82566 L .57752 .82877 L .427 .481 0 r
F
.37895 .71915 m .37706 .70367 L .38617 .71179 L .825 .594 0 r
F
.37895 .71915 m .36933 .71231 L .37706 .70367 L F
.45389 1.30848 m .45174 1.31244 L .42325 1.31051 L .727 .822 0 r
F
.48189 1.30843 m .45174 1.31244 L .45389 1.30848 L .764 .849 0 r
F
.60989 .83887 m .62037 .84762 L .6096 .84376 L .565 .569 0 r
F
.59909 .83561 m .60989 .83887 L .6096 .84376 L .526 .547 0 r
F
.56635 .55765 m .56981 .55377 L .58702 .55752 L .604 .72 0 r
F
.54959 .55509 m .56981 .55377 L .56635 .55765 L .566 .695 0 r
F
.51122 .79784 m .51351 .79449 L .51339 .79859 L .358 .381 0 r
F
.51122 .79784 m .51024 .79335 L .51351 .79449 L F
.44981 .76575 m .44566 .75783 L .45414 .76483 L .381 .378 0 r
F
.44981 .76575 m .44073 .75897 L .44566 .75783 L F
.47106 .77779 m .46685 .77121 L .47461 .77755 L .35 .35 0 r
F
.47106 .77779 m .46261 .77146 L .46685 .77121 L F
.52562 .80451 m .53188 .80326 L .53444 .80494 L .372 .405 0 r
F
.52378 .8034 m .53188 .80326 L .52562 .80451 L .37 .402 0 r
F
.48235 .78367 m .47856 .77767 L .48551 .78372 L .343 .347 0 r
F
.48235 .78367 m .47461 .77755 L .47856 .77767 L F
.4999 1.0493 m .49874 1.05072 L .48585 1.0481 L .174 .118 0 r
F
.51188 1.05217 m .49874 1.05072 L .4999 1.0493 L .061 .107 0 r
F
.51188 1.05217 m .51176 1.05317 L .49874 1.05072 L F
.51025 1.30242 m .51014 1.30639 L .48189 1.30843 L .792 .871 0 r
F
.53747 1.29823 m .51014 1.30639 L .51025 1.30242 L .874 .923 0 r
F
.36933 .71231 m .36794 .69583 L .37706 .70367 L .88 .621 0 r
F
.36933 .71231 m .3597 .70571 L .36794 .69583 L F
.44927 1.03794 m .4441 1.03993 L .43207 1.03544 L .409 .48 0 r
F
.461 1.04178 
.51648 .80412 m .51981 .8013 L .52184 .80233 L .369 .398 0 r
F
.22039 1.00408 m .21053 1.00516 L .19941 .98741 L .858 .809 0 r
F
.51014 1.30639 m .51003 1.31049 L .48075 1.31247 L .82 .887 0 r
F
.53839 1.30225 m .51003 1.31049 L .51014 1.30639 L .897 .933 0 r
F
.37978 1.03148 m .35921 1.0254 L .36755 1.02377 L .612 .697 0 r
F
.38742 1.02958 m .37978 1.03148 L .36755 1.02377 L .586 .677 0 r
F
.4441 1.03993 m .43894 1.04209 L .42601 1.03745 L .43 .518 0 r
F
.45678 1.04383 m .43894 1.04209 L .4441 1.03993 L .404 .461 0 r
F
.33302 .70548 m .33074 .68768 L .34041 .69339 L .95 .702 0 r
F
.33302 .70548 m .32296 .70067 L .33074 .68768 L F
.65489 .56557 m .67818 .57175 L .67008 .57485 L .794 .794 0 r
F
.64758 .56902 m .65489 .56557 L .67008 .57485 L .774 .783 0 r
F
.56675 .82522 m .57736 .83167 L .56664 .82755 L .427 .477 0 r
F
.55601 .82162 m .56675 .82522 L .56664 .82755 L .411 .455 0 r
F
.6096 .84376 m .61893 .85297 L .60833 .84836 L .566 .559 0 r
F
.59885 .8398 m .6096 .84376 L .60833 .84836 L .524 .536 0 r
F
.45574 .77345 m .44981 .76575 L .45889 .77222 L .394 .41 0 r
F
.45574 .77345 m .44615 .7673 L .44981 .76575 L F
.32089 1.0207 m .29984 1.01066 L .30932 1.00958 L .735 .756 0 r
F
.32982 1.0192 m .32089 1.0207 L .30932 1.00958 L .718 .745 0 r
F
.47324 1.04515 m .47001 1.04714 L .45678 1.04383 L .339 .334 0 r
F
.48585 1.0481 m .47001 1.04714 L .47324 1.04515 L .28 .222 0 r
F
.49937 .79546 m .49504 .78983 L .5011 .79558 L .357 .375 0 r
F
.49937 .79546 m .49245 .78963 L .49504 .78983 L F
.47702 .78438 m .47106 .77779 L .47951 .78389 L .367 .382 0 r
F
.47702 .78438 m .46796 .77841 L .47106 .77779 L F
.32296 .70067 m .32105 .68224 L .33074 .68768 L .971 .719 0 r
F
.32296 .70067 m .31289 .69607 L .32105 .68224 L F
.48794 .7898 m .48235 .78367 L .49008 .78962 L .359 .375 0 r
F
.48794 .7898 m .47951 .78389 L .48235 .78367 L F
.62058 1.27679 m .5968 1.2918 L .59386 1.2874 L 1 1 0 r
F
.62058 1.27679 m .62451 1.28139 L .5968 1.2918 L F
.53334 .81132 m .54347 .81342 L .5444 .81502 L .384 .42 0 r
F
.53251 .81022 m .54347 .81342 L .53334 .81132 L .383 .418 0 r
F
.62037 .84762 m .62954 .85749 L .61893 .85297 L .608 .581 0 r
F
.6096 .84376 m .62037 .84762 L .61893 .85297 L .566 .559 0 r
F
.545 .81654 m .55565 .81966 L .55601 .82162 L .398 .438 0 r
F
.5444 .81502 m .55565 .81966 L .545 .81654 L .397 .438 0 r
F
.44615 .7673 m .44073 .75897 L .44981 .76575 L .408 .421 0 r
F
.44615 .7673 m .43656 .76091 L .44073 .75897 L F
.54723 .55861 m .54959 .55509 L .56635 .55765 L .511 .641 0 r
F
.53116 .55695 m .54959 .55509 L .54723 .55861 L .474 .565 0 r
F
.55565 .81966 m .56675 .82522 L .55601 .82162 L .411 .458 0 r
F
.48249 .55821 m .4976 .5551 L .49861 .55675 L .184 .129 0 r
F
.57752 .82877 m .5881 .83576 L .57736 .83167 L .454 .5 0 r
F
.56675 .82522 m .57752 .82877 L .57736 .83167 L .427 .477 0 r
F
.31289 .69607 m .31135 .67706 L .32105 .68224 L .989 .735 0 r
F
.31289 .69607 m .30281 .69168 L .31135 .67706 L F
.28092 1.01308 m .25995 1.00033 L .26987 .99955 L .794 .781 0 r
F
.29037 1.01183 m .28092 1.01308 L .26987 .99955 L .781 .773 0 r
F
.63114 .85136 m .64015 .86189 L .62954 .85749 L .648 .602 0 r
F
.62037 .84762 m .63114 .85136 L .62954 .85749 L .608 .581 0 r
F
.77984 .57525 m .78935 .57258 L .80346 .59069 L .918 .826 0 r
F
.5011 .79558 m .49782 .79021 L .50295 .79581 L .355 .372 0 r
F
.5011 .79558 m .49504 .78983 L .49782 .79021 L F
.53251 .81022 m .54223 .81177 L .54347 .81342 L .383 .418 0 r
F
.53149 .80909 m .54223 .81177 L .53251 .81022 L .381 .416 0 r
F
.48189 1.30843 m .48075 1.31247 L .45174 1.31244 L .764 .849 0 r
F
.51014 1.30639 m .48075 1.31247 L .48189 1.30843 L .82 .887 0 r
F
.43656 .76091 m .43164 .75184 L .44073 .75897 L .433 .436 0 r
F
.43656 .76091 m .42696 .75428 L .43164 .75184 L F
.22039 1.00408 m .19941 .98741 L .20968 .9869 L .858 .809 0 r
F
.23026 1.00305 m .22039 1.00408 L .20968 .9869 L .85 .804 0 r
F
.55052 1.06416 m .53974 1.05808 L .53777 1.05911 L .494 0 0 r
F
.55052 1.06416 m .55351 1.06214 L .53974 1.05808 L F
.58253 .56134 m .58702 .55752 L .60341 .56245 L .636 .733 0 r
F
.56635 .55765 m .58702 .55752 L .58253 .56134 L .604 .72 0 r
F
.64191 .85495 m .65076 .86614 L .64015 .86189 L .686 .622 0 r
F
.63114 .85136 m .64191 .85495 L .64015 .86189 L .648 .602 0 r
F
.82529 .89332 m .83063 .91446 L .82009 .9125 L .957 .811 0 r
F
.82529 .89332 m .83607 .89465 L .83063 .91446 L F
.46796 .77841 m .46261 .77146 L .47106 .77779 L .368 .378 0 r
F
.46796 .77841 m .45889 .77222 L .46261 .77146 L F
.53116 .55695 m .53241 .55374 L .54959 .55509 L .474 .565 0 r
F
.5149 .55632 m .53241 .55374 L .53116 .55695 L .431 .422 0 r
F
.30281 .69168 m .30162 .6721 L .31135 .67706 L 1 .75 0 r
F
.30281 .69168 m .29271 .68747 L .30162 .6721 L F
.49008 .78962 m .48551 .78372 L .49245 .78963 L .353 .365 0 r
F
.49008 .78962 m .48235 .78367 L .48551 .78372 L F
.42696 .75428 m .42255 .74433 L .43164 .75184 L .48 .456 0 r
F
.42696 .75428 m .41736 .74743 L .42255 .74433 L F
.49861 .55675 m .51502 .5537 L .5149 .55632 L .349 .186 0 r
F
.49861 .55675 m .4976 .5551 L .51502 .5537 L F
.67659 1.25569 m .65605 1.27402 L .65118 1.26922 L 1 .968 0 r
F
.67659 1.25569 m .68238 1.26059 L .65605 1.27402 L F
.50295 .79581 m .50076 .79077 L .50491 .79616 L .354 .371 0 r
F
.50295 .79581 m .49782 .79021 L .50076 .79077 L F
.81452 .89192 m .82009 .9125 L .80955 .91049 L .952 .806 0 r
F
.81452 .89192 m .82529 .89332 L .82009 .9125 L F
.53149 .80909 m .54069 .81008 L .54223 .81177 L .381 .416 0 r
F
.53027 .80795 m .54069 .81008 L .53149 .80909 L .379 .413 0 r
F
.461 1.04178 m .45678 1.04383 L .4441 1.03993 L .379 .419 0 r
F
.47324 1.04515 m .45678 1.04383 L .461 1.04178 L .339 .334 0 r
F
.5883 .83224 m .59885 .8398 L .5881 .83576 L .489 .523 0 r
F
.57752 .82877 m .5883 .83224 L .5881 .83576 L .454 .5 0 r
F
.35921 1.0254 m .33877 1.0178 L .34774 1.01652 L .658 .718 0 r
F
.36755 1.02377 m .35921 1.0254 L .34774 1.01652 L .635 .702 0 r
F
.5444 .81502 m .55485 .8176 L .55565 .81966 L .397 .438 0 r
F
.54347 .81342 m .55485 .8176 L .5444 .81502 L .396 .437 0 r
F
.65269 .85838 m .66137 .87023 L .65076 .86614 L .722 .641 0 r
F
.64191 .85495 m .65269 .85838 L .65076 .86614 L .686 .622 0 r
F
.63166 .56124 m .65489 .56557 L .64758 .56902 L .763 .789 0 r
F
.62522 .56493 m .63166 .56124 L .64758 .56902 L .739 .775 0 r
F
.5149 .55632 m .51502 .5537 L .53241 .55374 L .431 .422 0 r
F
.73647 .56828 m .76088 .58042 L .75143 .58291 L .888 .819 0 r
F
.72759 .5713 m .73647 .56828 L .75143 .58291 L .878 .815 0 r
F
.80374 .89046 m .80955 .91049 L .799 .90839 L .947 .8 0 r
F
.80374 .89046 m .81452 .89192 L .80955 .91049 L F
.47951 .78389 m .47461 .77755 L .48235 .78367 L .354 .363 0 r
F
.47951 .78389 m .47106 .77779 L .47461 .77755 L F
.41736 .74743 m .41346 .73648 L .42255 .74433 L .541 .481 0 r
F
.41736 .74743 m .40776 .74041 L .41346 .73648 L F
.56632 .82271 m .57752 .82877 L .56675 .82522 L .427 .481 0 r
F
.55565 .81966 m .56632 .82271 L .56675 .82522 L .411 .458 0 r
F
.69445 .56523 m .71874 .57424 L .70991 .5771 L .849 .81 0 r
F
.68631 .56854 m .69445 .56523 L .70991 .5771 L .835 .803 0 r
F
.66348 .86164 m .67198 .87414 L .66137 .87023 L .754 .658 0 r
F
.65269 .85838 m .66348 .86164 L .66137 .87023 L .722 .641 0 r
F
.40702 1.03408 m .38742 1.02958 L .39509 1.02782 L .531 .642 0 r
F
.41391 1.03215 m .40702 1.03408 L .39509 1.02782 L .501 .615 0 r
F
.42601 1.03745 m .40702 1.03408 L .41391 1.03215 L .472 .591 0 r
F
.64629 1.26441 m .62451 1.28139 L .62058 1.27679 L 1 1 0 r
F
.64629 1.26441 m .65118 1.26922 L .62451 1.28139 L F
.79295 .88892 m .799 .90839 L .78845 .90622 L .941 .794 0 r
F
.79295 .88892 m .80374 .89046 L .799 .90839 L F
.50491 .79616 m .50383 .79148 L .50695 .79662 L .354 .372 0 r
F
.50491 .79616 m .50076 .79077 L .50383 .79148 L F
.29271 .68747 m .29188 .66734 L .30162 .6721 L 1 .763 0 r
F
.29271 .68747 m .2826 .68343 L .29188 .66734 L F
.53027 .80795 m .53887 .80836 L .54069 .81008 L .379 .413 0 r
F
.52887 .80679 m .53887 .80836 L .53027 .80795 L .377 .41 0 r
F
.58006 1.08913 m .5709 1.06422 L .56697 1.07117 L .929 .076 0 r
F
.58006 1.08913 m .58509 1.09426 L .5709 1.06422 L F
.55485 .8176 m .56632 .82271 L .55565 .81966 L .411 .459 0 r
F
.40776 .74041 m .40436 .72836 L .41346 .73648 L .612 .508 0 r
F
.40776 .74041 m .39816 .73329 L .40436 .72836 L F
.78217 .8873 m .78845 .90622 L .77789 .90395 L .934 .787 0 r
F
.78217 .8873 m .79295 .88892 L .78845 .90622 L F
.32982 1.0192 m .30932 1.00958 L .31882 1.00859 L .718 .745 0 r
F
.33877 1.0178 m .32982 1.0192 L .31882 1.00859 L .699 .733 0 r
F
.66348 .86164 m .67427 .86473 L .67198 .87414 L .754 .658 0 r
F
.67427 .86473 m .68259 .87786 L .67198 .87414 L .783 .675 0 r
F
.43207 1.03544 m .42601 1.03745 L .41391 1.03215 L .45 .558 0 r
F
.4441 1.03993 m .42601 1.03745 L .43207 1.03544 L .43 .518 0 r
F
.60341 .56245 m .60891 .55862 L .62522 .56493 L .695 .761 0 r
F
.58702 .55752 m .60891 .55862 L .60341 .56245 L .674 .759 0 r
F
.70717 1.24608 m .68816 1.26544 L .68238 1.26059 L 1 .933 0 r
F
.70717 1.24608 m .71383 1.2509 L .68816 1.26544 L F
.45889 .77222 m .45414 .76483 L .46261 .77146 L .372 .376 0 r
F
.45889 .77222 m .44981 .76575 L .45414 .76483 L F
.77139 .8856 m .77789 .90395 L .76732 .90159 L .927 .78 0 r
F
.77139 .8856 m .78217 .8873 L .77789 .90395 L F
.59909 .83561 m .6096 .84376 L .59885 .8398 L .526 .547 0 r
F
.5883 .83224 m .59909 .83561 L .59885 .8398 L .489 .523 0 r
F
.39816 .73329 m .39527 .72007 L .40436 .72836 L .687 .536 0 r
F
.39816 .73329 m .38856 .72617 L .39527 .72007 L F
.68506 .86765 m .6932 .88139 L .68259 .87786 L .808 .691 0 r
F
.67427 .86473 m .68506 .86765 L .68259 .87786 L .783 .675 0 r
F
.60891 .55862 m .63166 .56124 L .62522 .56493 L .725 .779 0 r
F
.4201 1.31444 m .38731 1.31437 L .39142 1.31054 L .746 .828 0 r
F
.42325 1.31051 m .4201 1.31444 L .39142 1.31054 L .727 .816 0 r
F
.45174 1.31244 m .4201 1.31444 L .42325 1.31051 L .751 .836 0 r
F
.23026 1.00305 m .20968 .9869 L .21996 .98644 L .85 .804 0 r
F
.24014 1.00208 m .23026 1.00305 L .21996 .98644 L .841 .798 0 r
F
.49245 .78963 m .48897 .78403 L .49504 .78983 L .347 .357 0 r
F
.49245 .78963 m .48551 .78372 L .48897 .78403 L F
.50695 .79662 m .507 .79235 L .50906 .79718 L .355 .374 0 r
F
.50695 .79662 m .50383 .79148 L .507 .79235 L F
.7606 .88379 m .76732 .90159 L .75675 .89912 L .918 .772 0 r
F
.7606 .88379 m .77139 .8856 L .76732 .90159 L F
.52887 .80679 m .53678 .80664 L .53887 .80836 L .377 .41 0 r
F
.52732 .80564 m .53678 .80664 L .52887 .80679 L .375 .408 0 r
F
.66223 .562 m .68631 .56854 L .67818 .57175 L .812 .803 0 r
F
.65489 .56557 m .66223 .562 L .67818 .57175 L .794 .794 0 r
F
.38742 1.02958 m .36755 1.02377 L .37591 1.02227 L .586 .677 0 r
F
.39509 1.02782 m .38742 1.02958 L .37591 1.02227 L .558 .656 0 r
F
.29037 1.01183 m .26987 .99955 L .27981 .99885 L .781 .773 0 r
F
.29984 1.01066 m .29037 1.01183 L .27981 .99885 L .768 .765 0 r
F
.69585 .8704 m .7038 .88475 L .6932 .88139 L .831 .705 0 r
F
.68506 .86765 m .69585 .8704 L .6932 .88139 L .808 .691 0 r
F
.54347 .81342 m .55363 .81544 L .55485 .8176 L .396 .437 0 r
F
.54223 .81177 m .55363 .81544 L .54347 .81342 L .393 .435 0 r
F
.74981 .88188 m .75675 .89912 L .74617 .89652 L .908 .763 0 r
F
.74981 .88188 m .7606 .88379 L .75675 .89912 L F
.38856 .72617 m .38617 .71179 L .39527 .72007 L .76 .565 0 r
F
.38856 .72617 m .37895 .71915 L .38617 .71179 L F
.70664 .87298 m .7144 .88793 L .7038 .88475 L .851 .719 0 r
F
.69585 .8704 m .70664 .87298 L .7038 .88475 L .831 .705 0 r
F
.2826 .68343 m .28213 .66276 L .29188 .66734 L 1 .775 0 r
F
.2826 .68343 m .27247 .67954 L .28213 .66276 L F
.73902 .87985 m .74617 .89652 L .73559 .8938 L .896 .753 0 r
F
.73902 .87985 m .74981 .88188 L .74617 .89652 L F
.53747 1.29823 m .53839 1.30225 L .51014 1.30639 L .874 .923 0 r
F
.56444 1.29181 m .53839 1.30225 L .53747 1.29823 L .982 .98 0 r
F
.56444 1.29181 m .56638 1.29593 L .53839 1.30225 L F
.71744 .87541 m .725 .89094 L .7144 .88793 L .868 .731 0 r
F
.70664 .87298 m .71744 .87541 L .7144 .88793 L .851 .719 0 r
F
.72823 .8777 m .73559 .8938 L .725 .89094 L .883 .743 0 r
F
.72823 .8777 m .73902 .87985 L .73559 .8938 L F
.71744 .87541 m .72823 .8777 L .725 .89094 L .868 .731 0 r
F
.38731 1.31437 m .3537 1.31218 L .35873 1.30851 L .747 .822 0 r
F
.39142 1.31054 m .38731 1.31437 L .35873 1.30851 L .731 .813 0 r
F
.50906 .79718 m .51024 .79335 L .51122 .79784 L .357 .377 0 r
F
.50906 .79718 m .507 .79235 L .51024 .79335 L F
.59091 1.28311 m .56638 1.29593 L .56444 1.29181 L 1 1 0 r
F
.59091 1.28311 m .59386 1.2874 L .56638 1.29593 L F
.52732 .80564 m .53444 .80494 L .53678 .80664 L .375 .408 0 r
F
.52562 .80451 m .53444 .80494 L .52732 .80564 L .372 .405 0 r
F
.57701 .82566 m .5883 .83224 L .57752 .82877 L .455 .505 0 r
F
.56632 .82271 m .57701 .82566 L .57752 .82877 L .427 .481 0 r
F
.37895 .71915 m .37706 .70367 L .38617 .71179 L .825 .594 0 r
F
.37895 .71915 m .36933 .71231 L .37706 .70367 L F
.45389 1.30848 m .45174 1.31244 L .42325 1.31051 L .727 .822 0 r
F
.48189 1.30843 m .45174 1.31244 L .45389 1.30848 L .764 .849 0 r
F
.60989 .83887 m .62037 .84762 L .6096 .84376 L .565 .569 0 r
F
.59909 .83561 m .60989 .83887 L .6096 .84376 L .526 .547 0 r
F
.56635 .55765 m .56981 .55377 L .58702 .55752 L .604 .72 0 r
F
.54959 .55509 m .56981 .55377 L .56635 .55765 L .566 .695 0 r
F
.51122 .79784 m .51351 .79449 L .51339 .79859 L .358 .381 0 r
F
.51122 .79784 m .51024 .79335 L .51351 .79449 L F
.44981 .76575 m .44566 .75783 L .45414 .76483 L .381 .378 0 r
F
.44981 .76575 m .44073 .75897 L .44566 .75783 L F
.47106 .77779 m .46685 .77121 L .47461 .77755 L .35 .35 0 r
F
.47106 .77779 m .46261 .77146 L .46685 .77121 L F
.52562 .80451 m .53188 .80326 L .53444 .80494 L .372 .405 0 r
F
.52378 .8034 m .53188 .80326 L .52562 .80451 L .37 .402 0 r
F
.48235 .78367 m .47856 .77767 L .48551 .78372 L .343 .347 0 r
F
.48235 .78367 m .47461 .77755 L .47856 .77767 L F
.4999 1.0493 m .49874 1.05072 L .48585 1.0481 L .174 .118 0 r
F
.51188 1.05217 m .49874 1.05072 L .4999 1.0493 L .061 .107 0 r
F
.51188 1.05217 m .51176 1.05317 L .49874 1.05072 L F
.51025 1.30242 m .51014 1.30639 L .48189 1.30843 L .792 .871 0 r
F
.53747 1.29823 m .51014 1.30639 L .51025 1.30242 L .874 .923 0 r
F
.36933 .71231 m .36794 .69583 L .37706 .70367 L .88 .621 0 r
F
.36933 .71231 m .3597 .70571 L .36794 .69583 L F
.44927 1.03794 m .4441 1.03993 L .43207 1.03544 L .409 .48 0 r
F
.461 1.04178 m .4441 1.03993 L .44927 1.03794 L .379 .419 0 r
F
.49504 .78983 m .49268 .7846 L .49782 .79021 L .343 .351 0 r
F
.49504 .78983 m .48897 .78403 L .49268 .7846 L F
.27247 .67954 m .27235 .65832 L .28213 .66276 L 1 .785 0 r
F
.27247 .67954 m .26233 .67578 L .27235 .65832 L F
.51339 .79859 m .51677 .79573 L .51556 .79943 L .361 .385 0 r
F
.51339 .79859 m .51351 .79449 L .51677 .79573 L F
.52378 .8034 m .52913 .80162 L .53188 .80326 L .37 .402 0 r
F
.52184 .80233 m .52913 .80162 L .52378 .8034 L .369 .399 0 r
F
.55485 .8176 m .56534 .82007 L .56632 .82271 L .411 .459 0 r
F
.55363 .81544 m .56534 .82007 L .55485 .8176 L .409 .458 0 r
F
.48807 1.0464 m .48585 1.0481 L .47324 1.04515 L .256 .198 0 r
F
.4999 1.0493 m .48585 1.0481 L .48807 1.0464 L .174 .118 0 r
F
.54223 .81177 m .55198 .81322 L .55363 .81544 L .393 .435 0 r
F
.54069 .81008 m .55198 .81322 L .54223 .81177 L .39 .431 0 r
F
.52387 1.05529 m .51176 1.05317 L .51188 1.05217 L 0 .089 0 r
F
.52387 1.05529 m .52481 1.05578 L .51176 1.05317 L F
.51556 .79943 m .52 .79708 L .51771 .80033 L .363 .388 0 r
F
.51556 .79943 m .51677 .79573 L .52 .79708 L F
.52184 .80233 m .52621 .80004 L .52913 .80162 L .369 .399 0 r
F
.51981 .8013 m .52621 .80004 L .52184 .80233 L .367 .396 0 r
F
.56534 .82007 m .57701 .82566 L .56632 .82271 L .426 .483 0 r
F
.61663 1.27226 m .59386 1.2874 L .59091 1.28311 L 1 1 0 r
F
.61663 1.27226 m .62058 1.27679 L .59386 1.2874 L F
.74537 .56519 m .77035 .57786 L .76088 .58042 L .897 .824 0 r
F
.73647 .56828 m .74537 .56519 L .76088 .58042 L .888 .819 0 r
F
.51771 .80033 m .52316 .79852 L .51981 .8013 L .365 .392 0 r
F
.51771 .80033 m .52 .79708 L .52316 .79852 L F
.51981 .8013 m .52316 .79852 L .52621 .80004 L .367 .396 0 r
F
.3597 .70571 m .35881 .68837 L .36794 .69583 L .927 .648 0 r
F
.3597 .70571 m .35006 .6994 L .35881 .68837 L F
.56297 1.07238 m .55351 1.06214 L .55052 1.06416 L .675 .02 0 r
F
.56297 1.07238 m .56697 1.07117 L .55351 1.06214 L F
.24014 1.00208 m .21996 .98644 L .23026 .98605 L .841 .798 0 r
F
.25004 1.00117 m .24014 1.00208 L .23026 .98605 L .832 .793 0 r
F
.6207 .84199 m .63114 .85136 L .62037 .84762 L .603 .591 0 r
F
.60989 .83887 m .6207 .84199 L .62037 .84762 L .565 .569 0 r
F
.44073 .75897 m .43717 .75037 L .44566 .75783 L .396 .386 0 r
F
.44073 .75897 m .43164 .75184 L .43717 .75037 L F
.36755 1.02377 m .34774 1.01652 L .35672 1.01535 L .635 .702 0 r
F
.37591 1.02227 m .36755 1.02377 L .35672 1.01535 L .61 .684 0 r
F
.58772 .8285 m .59909 .83561 L .5883 .83224 L .487 .529 0 r
F
.57701 .82566 m .58772 .8285 L .5883 .83224 L .455 .505 0 r
F
.26233 .67578 m .26256 .65402 L .27235 .65832 L 1 .794 0 r
F
.26233 .67578 m .25218 .67214 L .26256 .65402 L F
.70262 .56183 m .72759 .5713 L .71874 .57424 L .861 .816 0 r
F
.69445 .56523 m .70262 .56183 L .71874 .57424 L .849 .81 0 r
F
.47647 1.04329 m .47324 1.04515 L .461 1.04178 L .314 .299 0 r
F
.48807 1.0464 m .47324 1.04515 L .47647 1.04329 L .256 .198 0 r
F
.35006 .6994 m .34965 .68131 L .35881 .68837 L .964 .673 0 r
F
.35006 .6994 m .34041 .69339 L .34965 .68131 L F
.33877 1.0178 m .31882 1.00859 L .32833 1.00771 L .699 .733 0 r
F
.34774 1.01652 m .33877 1.0178 L .32833 1.00771 L .678 .72 0 r
F
.67077 1.25071 m .65118 1.26922 L .64629 1.26441 L 1 .971 0 r
F
.67077 1.25071 m .67659 1.25569 L .65118 1.26922 L F
.49782 .79021 m .4966 .78539 L .50076 .79077 L .341 .349 0 r
F
.49782 .79021 m .49268 .7846 L .4966 .78539 L F
.29984 1.01066 m .27981 .99885 L .28976 .99824 L .768 .765 0 r
F
.30932 1.00958 m .29984 1.01066 L .28976 .99824 L .752 .755 0 r
F
.35873 1.30851 m .3537 1.31218 L .32556 1.30436 L .738 .812 0 r
F
.54069 .81008 m .54993 .81096 L .55198 .81322 L .39 .431 0 r
F
.53887 .80836 m .54993 .81096 L .54069 .81008 L .387 .427 0 r
F
.73768 1.23545 m .72046 1.25563 L .71383 1.2509 L 1 .905 0 r
F
.73768 1.23545 m .74514 1.24003 L .72046 1.25563 L F
.63813 .5574 m .66223 .562 L .65489 .56557 L .785 .801 0 r
F
.63166 .56124 m .63813 .5574 L .65489 .56557 L .763 .789 0 r
F
.48303 1.30451 m .48189 1.30843 L .45389 1.30848 L .736 .831 0 r
F
.51025 1.30242 m .48189 1.30843 L .48303 1.30451 L .792 .871 0 r
F
.46261 .77146 m .45908 .76458 L .46685 .77121 L .346 .338 0 r
F
.46261 .77146 m .45414 .76483 L .45908 .76458 L F
.54959 .55509 m .55196 .55131 L .56981 .55377 L .566 .695 0 r
F
.53241 .55374 m .55196 .55131 L .54959 .55509 L .521 .646 0 r
F
.63153 .84496 m .64191 .85495 L .63114 .85136 L .64 .612 0 r
F
.6207 .84199 m .63153 .84496 L .63114 .85136 L .603 .591 0 r
F
.48551 .78372 m .48288 .77816 L .48897 .78403 L .333 .333 0 r
F
.48551 .78372 m .47856 .77767 L .48288 .77816 L F
.43164 .75184 m .42869 .74238 L .43717 .75037 L .422 .402 0 r
F
.43164 .75184 m .42255 .74433 L .42869 .74238 L F
.55363 .81544 m .56381 .81733 L .56534 .82007 L .409 .458 0 r
F
.55198 .81322 m .56381 .81733 L .55363 .81544 L .406 .456 0 r
F
.58702 .55752 m .59153 .5535 L .60891 .55862 L .674 .759 0 r
F
.56981 .55377 m .59153 .5535 L .58702 .55752 L .65 .754 0 r
F
.7005 1.24117 m .68238 1.26059 L .67659 1.25569 L 1 .931 0 r
F
.7005 1.24117 m .70717 1.24608 L .68238 1.26059 L F
.34041 .69339 m .34048 .67464 L .34965 .68131 L .993 .696 0 r
F
.34041 .69339 m .33074 .68768 L .34048 .67464 L F
.25218 .67214 m .25275 .64984 L .26256 .65402 L 1 .803 0 r
F
.25218 .67214 m .24201 .6686 L .25275 .64984 L F
.41391 1.03215 m .39509 1.02782 L .40277 1.02621 L .501 .615 0 r
F
.42083 1.03038 m .41391 1.03215 L .40277 1.02621 L .472 .586 0 r
F
.43207 1.03544 m .41391 1.03215 L .42083 1.03038 L .45 .558 0 r
F
.47461 .77755 m .47159 .77146 L .47856 .77767 L .331 .324 0 r
F
.47461 .77755 m .46685 .77121 L .47159 .77146 L F
.64138 1.25958 m .62058 1.27679 L .61663 1.27226 L 1 1 0 r
F
.64138 1.25958 m .64629 1.26441 L .62058 1.27679 L F
.50076 .79077 m .5007 .7864 L .50383 .79148 L .34 .35 0 r
F
.50076 .79077 m .4966 .78539 L .5007 .7864 L F
.57584 .82242 m .58772 .8285 L .57701 .82566 L .451 .507 0 r
F
.56534 .82007 m .57584 .82242 L .57701 .82566 L .426 .483 0 r
F
.66959 .55831 m .69445 .56523 L .68631 .56854 L .828 .811 0 r
F
.66223 .562 m .66959 .55831 L .68631 .56854 L .812 .803 0 r
F
.53887 .80836 m .5475 .80868 L .54993 .81096 L .387 .427 0 r
F
.53678 .80664 m .5475 .80868 L .53887 .80836 L .383 .422 0 r
F
.25004 1.00117 m .23026 .98605 L .24056 .98571 L .832 .793 0 r
F
.25995 1.00033 m .25004 1.00117 L .24056 .98571 L .822 .786 0 r
F
.59844 .83121 m .60989 .83887 L .59909 .83561 L .523 .553 0 r
F
.58772 .8285 m .59844 .83121 L .59909 .83561 L .487 .529 0 r
F
.64236 .84778 m .65269 .85838 L .64191 .85495 L .675 .631 0 r
F
.63153 .84496 m .64236 .84778 L .64191 .85495 L .64 .612 0 r
F
.39509 1.02782 m .37591 1.02227 L .3843 1.02091 L .558 .656 0 r
F
.40277 1.02621 m .39509 1.02782 L .3843 1.02091 L .529 .632 0 r
F
.42255 .74433 m .4202 .7338 L .42869 .74238 L .48 .426 0 r
F
.42255 .74433 m .41346 .73648 L .4202 .7338 L F
.56381 .81733 m .57584 .82242 L .56534 .82007 L .423 .482 0 r
F
.46524 1.03988 m .461 1.04178 L .44927 1.03794 L .357 .382 0 r
F
.47647 1.04329 m .461 1.04178 L .46524 1.03988 L .314 .299 0 r
F
.46344 .56405 m .4782 .55743 L .48035 .55827 L .302 .139 0 r
F
.61443 .55463 m .63813 .5574 L .63166 .56124 L .752 .795 0 r
F
.60891 .55862 m .61443 .55463 L .63166 .56124 L .725 .779 0 r
F
.53241 .55374 m .53367 .55023 L .55196 .55131 L .521 .646 0 r
F
.51502 .5537 m .53367 .55023 L .53241 .55374 L .49 .551 0 r
F
.33074 .68768 m .33129 .66835 L .34048 .67464 L 1 .717 0 r
F
.33074 .68768 m .32105 .68224 L .33129 .66835 L F
.43816 1.0336 m .43207 1.03544 L .42083 1.03038 L .431 .524 0 r
F
.44927 1.03794 m .43207 1.03544 L .43816 1.0336 L .409 .48 0 r
F
.75428 .56204 m .77984 .57525 L .77035 .57786 L .905 .828 0 r
F
.74537 .56519 m .75428 .56204 L .77035 .57786 L .897 .824 0 r
F
.59153 .5535 m .61443 .55463 L .60891 .55862 L .71 .782 0 r
F
.24201 .6686 m .24292 .64576 L .25275 .64984 L 1 .81 0 r
F
.24201 .6686 m .23182 .66515 L .24292 .64576 L F
.42325 1.31051 m .39142 1.31054 L .39554 1.30678 L .727 .816 0 r
F
.42641 1.30666 m .42325 1.31051 L .39554 1.30678 L .705 .803 0 r
F
.45389 1.30848 m .42325 1.31051 L .42641 1.30666 L .727 .822 0 r
F
.50383 .79148 m .50494 .7876 L .507 .79235 L .341 .353 0 r
F
.50383 .79148 m .5007 .7864 L .50494 .7876 L F
.45414 .76483 m .4513 .75757 L .45908 .76458 L .347 .327 0 r
F
.45414 .76483 m .44566 .75783 L .4513 .75757 L F
.48035 .55827 m .49659 .55293 L .4976 .5551 L .389 .153 0 r
F
.48035 .55827 m .4782 .55743 L .49659 .55293 L F
.53678 .80664 m .54471 .80641 L .5475 .80868 L .383 .422 0 r
F
.53444 .80494 m .54471 .80641 L .53678 .80664 L .379 .417 0 r
F
.41346 .73648 m .41171 .72466 L .4202 .7338 L .562 .456 0 r
F
.41346 .73648 m .40436 .72836 L .41171 .72466 L F
.65321 .85043 m .66348 .86164 L .65269 .85838 L .707 .65 0 r
F
.64236 .84778 m .65321 .85043 L .65269 .85838 L .675 .631 0 r
F
.48897 .78403 m .48751 .77896 L .49268 .7846 L .325 .323 0 r
F
.48897 .78403 m .48288 .77816 L .48751 .77896 L F
.55198 .81322 m .56176 .81453 L .56381 .81733 L .406 .456 0 r
F
.54993 .81096 m .56176 .81453 L .55198 .81322 L .402 .451 0 r
F
.51502 .5537 m .51514 .55069 L .53367 .55023 L .49 .551 0 r
F
.4976 .5551 m .51514 .55069 L .51502 .5537 L .453 .372 0 r
F
.39142 1.31054 m .35873 1.30851 L .36379 1.30489 L .731 .813 0 r
F
.39554 1.30678 m .39142 1.31054 L .36379 1.30489 L .713 .803 0 r
F
.30932 1.00958 m .28976 .99824 L .29973 .99771 L .752 .755 0 r
F
.31882 1.00859 m .30932 1.00958 L .29973 .99771 L .736 .745 0 r
F
.4976 .5551 m .49659 .55293 L .51514 .55069 L .453 .372 0 r
F
.5475 1.06411 m .55052 1.06416 L .53777 1.05911 L .404 0 0 r
F
.53654 1.29438 m .53747 1.29823 L .51025 1.30242 L .843 .905 0 r
F
.56249 1.28787 m .53747 1.29823 L .53654 1.29438 L .964 .975 0 r
F
.56249 1.28787 m .56444 1.29181 L .53747 1.29823 L F
.60918 .83377 m .6207 .84199 L .60989 .83887 L .559 .576 0 r
F
.59844 .83121 m .60918 .83377 L .60989 .83887 L .523 .553 0 r
F
.40436 .72836 m .40323 .71507 L .41171 .72466 L .657 .491 0 r
F
.40436 .72836 m .39527 .72007 L .40323 .71507 L F
.58795 1.27899 m .56444 1.29181 L .56249 1.28787 L 1 1 0 r
F
.58795 1.27899 m .59091 1.28311 L .56444 1.29181 L F
.32105 .68224 m .32207 .66238 L .33129 .66835 L 1 .736 0 r
F
.32105 .68224 m .31135 .67706 L .32207 .66238 L F
.507 .79235 m .50926 .78897 L .51024 .79335 L .344 .358 0 r
F
.507 .79235 m .50494 .7876 L .50926 .78897 L F
.53444 .80494 m .5416 .80417 L .54471 .80641 L .379 .417 0 r
F
.53188 .80326 m .5416 .80417 L .53444 .80494 L .375 .411 0 r
F
.34774 1.01652 m .32833 1.00771 L .33787 1.00694 L .678 .72 0 r
F
.35672 1.01535 m .34774 1.01652 L .33787 1.00694 L .656 .705 0 r
F
.71081 .55835 m .73647 .56828 L .72759 .5713 L .872 .822 0 r
F
.70262 .56183 m .71081 .55835 L .72759 .5713 L .861 .816 0 r
F
.45605 1.30463 m .45389 1.30848 L .42641 1.30666 L .701 .804 0 r
F
.48303 1.30451 m .45389 1.30848 L .45605 1.30463 L .736 .831 0 r
F
.66406 .8529 m .67427 .86473 L .66348 .86164 L .736 .667 0 r
F
.65321 .85043 m .66406 .8529 L .66348 .86164 L .707 .65 0 r
F
.37591 1.02227 m .35672 1.01535 L .36573 1.01431 L .61 .684 0 r
F
.3843 1.02091 m .37591 1.02227 L .36573 1.01431 L .583 .665 0 r
F
.58636 .82463 m .59844 .83121 L .58772 .8285 L .482 .532 0 r
F
.57584 .82242 m .58636 .82463 L .58772 .8285 L .451 .507 0 r
F
.25995 1.00033 m .24056 .98571 L .25088 .98545 L .822 .786 0 r
F
.26987 .99955 m .25995 1.00033 L .25088 .98545 L .811 .779 0 r
F
.23182 .66515 m .23307 .64176 L .24292 .64576 L 1 .817 0 r
F
.23182 .66515 m .22163 .66179 L .23307 .64176 L F
.39527 .72007 m .39474 .70526 L .40323 .71507 L .754 .527 0 r
F
.39527 .72007 m .38617 .71179 L .39474 .70526 L F
.46685 .77121 m .4646 .765 L .47159 .77146 L .318 .299 0 r
F
.46685 .77121 m .45908 .76458 L .4646 .765 L F
.47856 .77767 m .47677 .77217 L .48288 .77816 L .314 .302 0 r
F
.47856 .77767 m .47159 .77146 L .47677 .77217 L F
.7302 1.23077 m .71383 1.2509 L .70717 1.24608 L 1 .901 0 r
F
.7302 1.23077 m .73768 1.23545 L .71383 1.2509 L F
.51036 1.2986 m .51025 1.30242 L .48303 1.30451 L .757 .848 0 r
F
.53654 1.29438 m .51025 1.30242 L .51036 1.2986 L .843 .905 0 r
F
.51024 .79335 m .51362 .79049 L .51351 .79449 L .347 .364 0 r
F
.51024 .79335 m .50926 .78897 L .51362 .79049 L F
.53188 .80326 m .53818 .80198 L .5416 .80417 L .375 .411 0 r
F
.52913 .80162 m .53818 .80198 L .53188 .80326 L .371 .405 0 r
F
.61268 1.26781 m .59091 1.28311 L .58795 1.27899 L 1 1 0 r
F
.61268 1.26781 m .61663 1.27226 L .59091 1.28311 L F
.56981 .55377 m .57327 .54969 L .59153 .5535 L .65 .754 0 r
F
.55196 .55131 m .57327 .54969 L .56981 .55377 L .623 .742 0 r
F
.44566 .75783 m .44351 .75005 L .4513 .75757 L .353 .322 0 r
F
.44566 .75783 m .43717 .75037 L .44351 .75005 L F
.56381 .81733 m .57402 .81908 L .57584 .82242 L .423 .482 0 r
F
.56176 .81453 m .57402 .81908 L .56381 .81733 L .42 .479 0 r
F
.45447 1.0361 m .44927 1.03794 L .43816 1.0336 L .389 .444 0 r
F
.46524 1.03988 m .44927 1.03794 L .45447 1.0361 L .357 .382 0 r
F
.66406 .8529 m .67491 .85522 L .67427 .86473 L .736 .667 0 r
F
.67491 .85522 m .68506 .86765 L .67427 .86473 L .763 .683 0 r
F
.66494 1.24563 m .64629 1.26441 L .64138 1.25958 L 1 .973 0 r
F
.66494 1.24563 m .67077 1.25071 L .64629 1.26441 L F
.49268 .7846 m .49242 .78006 L .4966 .78539 L .321 .318 0 r
F
.49268 .7846 m .48751 .77896 L .49242 .78006 L F
.38617 .71179 m .38625 .69553 L .39474 .70526 L .841 .563 0 r
F
.38617 .71179 m .37706 .70367 L .38625 .69553 L F
.31135 .67706 m .31284 .65669 L .32207 .66238 L 1 .753 0 r
F
.31135 .67706 m .30162 .6721 L .31284 .65669 L F
.57402 .81908 m .58636 .82463 L .57584 .82242 L .445 .507 0 r
F
.54993 .81096 m .5592 .8117 L .56176 .81453 L .402 .451 0 r
F
.5475 .80868 m .5592 .8117 L .54993 .81096 L .397 .445 0 r
F
.51351 .79449 m .51799 .79214 L .51677 .79573 L .351 .371 0 r
F
.51351 .79449 m .51362 .79049 L .51799 .79214 L F
.52913 .80162 m .5345 .79984 L .53818 .80198 L .371 .405 0 r
F
.52621 .80004 m .5345 .79984 L .52913 .80162 L .367 .399 0 r
F
.61993 .83618 m .63153 .84496 L .6207 .84199 L .595 .598 0 r
F
.60918 .83377 m .61993 .83618 L .6207 .84199 L .559 .576 0 r
F
.64462 .55343 m .66959 .55831 L .66223 .562 L .805 .811 0 r
F
.63813 .5574 m .64462 .55343 L .66223 .562 L .785 .801 0 r
F
.35873 1.30851 m .32556 1.30436 L .33151 1.30095 L .738 .812 0 r
F
.36379 1.30489 m .35873 1.30851 L .33151 1.30095 L .723 .803 0 r
F
.6938 1.23614 m .67659 1.25569 L .67077 1.25071 L 1 .929 0 r
F
.6938 1.23614 m .7005 1.24117 L .67659 1.25569 L F
.22163 .66179 m .22321 .63784 L .23307 .64176 L 1 .822 0 r
F
.22163 .66179 m .21142 .6585 L .22321 .63784 L F
.51677 .79573 m .5223 .79391 L .52 .79708 L .355 .378 0 r
F
.51677 .79573 m .51799 .79214 L .5223 .79391 L F
.52621 .80004 m .53061 .79778 L .5345 .79984 L .367 .399 0 r
F
.52316 .79852 m .53061 .79778 L .52621 .80004 L .363 .392 0 r
F
.76322 .55882 m .78935 .57258 L .77984 .57525 L .913 .832 0 r
F
.75428 .56204 m .76322 .55882 L .77984 .57525 L .905 .828 0 r
F
.68578 .85736 m .69585 .8704 L .68506 .86765 L .787 .697 0 r
F
.67491 .85522 m .68578 .85736 L .68506 .86765 L .763 .683 0 r
F
.37706 .70367 m .37775 .68615 L .38625 .69553 L .914 .598 0 r
F
.37706 .70367 m .36794 .69583 L .37775 .68615 L F
.50108 1.04777 m .4999 1.0493 L .48807 1.0464 L .17 .115 0 r
F
.51199 1.05087 m .4999 1.0493 L .50108 1.04777 L .079 .106 0 r
F
.51199 1.05087 m .51188 1.05217 L .4999 1.0493 L F
.52 .79708 m .52652 .7958 L .52316 .79852 L .359 .385 0 r
F
.52 .79708 m .5223 .79391 L .52652 .7958 L F
.52316 .79852 m .52652 .7958 L .53061 .79778 L .363 .392 0 r
F
.67698 .55453 m .70262 .56183 L .69445 .56523 L .843 .818 0 r
F
.66959 .55831 m .67698 .55453 L .69445 .56523 L .828 .811 0 r
F
.49029 1.0447 m .48807 1.0464 L .47647 1.04329 L .242 .189 0 r
F
.50108 1.04777 m .48807 1.0464 L .49029 1.0447 L .17 .115 0 r
F
.31882 1.00859 m .29973 .99771 L .30971 .99729 L .736 .745 0 r
F
.32833 1.00771 m .31882 1.00859 L .30971 .99729 L .718 .733 0 r
F
.69665 .85935 m .70664 .87298 L .69585 .8704 L .808 .711 0 r
F
.68578 .85736 m .69665 .85935 L .69585 .8704 L .787 .697 0 r
F
.26987 .99955 m .25088 .98545 L .2612 .98526 L .811 .779 0 r
F
.27981 .99885 m .26987 .99955 L .2612 .98526 L .799 .772 0 r
F
.59691 .82668 m .60918 .83377 L .59844 .83121 L .515 .557 0 r
F
.58636 .82463 m .59691 .82668 L .59844 .83121 L .482 .532 0 r
F
.43717 .75037 m .43571 .74186 L .44351 .75005 L .369 .326 0 r
F
.43717 .75037 m .42869 .74238 L .43571 .74186 L F
.52292 1.0542 m .51188 1.05217 L .51199 1.05087 L 0 .093 0 r
F
.52292 1.0542 m .52387 1.05529 L .51188 1.05217 L F
.30162 .6721 m .30358 .65125 L .31284 .65669 L 1 .768 0 r
F
.30162 .6721 m .29188 .66734 L .30358 .65125 L F
.48417 1.30072 m .48303 1.30451 L .45605 1.30463 L .702 .808 0 r
F
.51036 1.2986 m .48303 1.30451 L .48417 1.30072 L .757 .848 0 r
F
.63646 1.25474 m .61663 1.27226 L .61268 1.26781 L 1 1 0 r
F
.63646 1.25474 m .64138 1.25958 L .61663 1.27226 L F
.42083 1.03038 m .40277 1.02621 L .41048 1.02477 L .472 .586 0 r
F
.42777 1.02878 m .42083 1.03038 L .41048 1.02477 L .449 .556 0 r
F
.43816 1.0336 m .42083 1.03038 L .42777 1.02878 L .431 .524 0 r
F
.36794 .69583 m .36922 .6773 L .37775 .68615 L .972 .631 0 r
F
.36794 .69583 m .35881 .68837 L .36922 .6773 L F
.40277 1.02621 m .3843 1.02091 L .3927 1.0197 L .529 .632 0 r
F
.41048 1.02477 m .40277 1.02621 L .3927 1.0197 L .5 .606 0 r
F
.4966 .78539 m .49756 .78141 L .5007 .7864 L .32 .318 0 r
F
.4966 .78539 m .49242 .78006 L .49756 .78141 L F
.5475 .80868 m .55617 .80888 L .5592 .8117 L .397 .445 0 r
F
.54471 .80641 m .55617 .80888 L .5475 .80868 L .391 .438 0 r
F
.57502 1.08398 m .56697 1.07117 L .56297 1.07238 L .697 .038 0 r
F
.57502 1.08398 m .58006 1.08913 L .56697 1.07117 L F
.47973 1.04151 m .47647 1.04329 L .46524 1.03988 L .296 .277 0 r
F
.49029 1.0447 m .47647 1.04329 L .47973 1.04151 L .242 .189 0 r
F
.6307 .83842 m .64236 .84778 L .63153 .84496 L .629 .619 0 r
F
.61993 .83618 m .6307 .83842 L .63153 .84496 L .595 .598 0 r
F
.70752 .8612 m .71744 .87541 L .70664 .87298 L .827 .723 0 r
F
.69665 .85935 m .70752 .8612 L .70664 .87298 L .808 .711 0 r
F
.45908 .76458 m .4576 .75822 L .4646 .765 L .306 .271 0 r
F
.45908 .76458 m .4513 .75757 L .4576 .75822 L F
.48288 .77816 m .48233 .77331 L .48751 .77896 L .302 .285 0 r
F
.48288 .77816 m .47677 .77217 L .48233 .77331 L F
.59153 .5535 m .59606 .54931 L .61443 .55463 L .71 .782 0 r
F
.57327 .54969 m .59606 .54931 L .59153 .5535 L .694 .784 0 r
F
.56176 .81453 m .57157 .81569 L .57402 .81908 L .42 .479 0 r
F
.5592 .8117 m .57157 .81569 L .56176 .81453 L .415 .474 0 r
F
.55196 .55131 m .55433 .54728 L .57327 .54969 L .623 .742 0 r
F
.53367 .55023 m .55433 .54728 L .55196 .55131 L .592 .718 0 r
F
.35672 1.01535 m .33787 1.00694 L .34742 1.00629 L .656 .705 0 r
F
.36573 1.01431 m .35672 1.01535 L .34742 1.00629 L .632 .689 0 r
F
.61997 .55048 m .64462 .55343 L .63813 .5574 L .778 .809 0 r
F
.61443 .55463 m .61997 .55048 L .63813 .5574 L .752 .795 0 r
F
.71902 .55478 m .74537 .56519 L .73647 .56828 L .883 .827 0 r
F
.71081 .55835 m .71902 .55478 L .73647 .56828 L .872 .822 0 r
F
.7184 .8629 m .72823 .8777 L .71744 .87541 L .844 .735 0 r
F
.70752 .8612 m .7184 .8629 L .71744 .87541 L .827 .723 0 r
F
.35881 .68837 m .36068 .66906 L .36922 .6773 L 1 .662 0 r
F
.35881 .68837 m .34965 .68131 L .36068 .66906 L F
.55893 1.07083 m .55052 1.06416 L .5475 1.06411 L .507 0 0 r
F
.55893 1.07083 m .56297 1.07238 L .55052 1.06416 L F
.47159 .77146 m .47064 .76605 L .47677 .77217 L .292 .264 0 r
F
.47159 .77146 m .4646 .765 L .47064 .76605 L F
.42869 .74238 m .42792 .73283 L .43571 .74186 L .398 .343 0 r
F
.42869 .74238 m .4202 .7338 L .42792 .73283 L F
.58425 .82067 m .59691 .82668 L .58636 .82463 L .474 .532 0 r
F
.57402 .81908 m .58425 .82067 L .58636 .82463 L .445 .507 0 r
F
.44427 1.03193 m .43816 1.0336 L .42777 1.02878 L .413 .49 0 r
F
.45447 1.0361 m .43816 1.0336 L .44427 1.03193 L .389 .444 0 r
F
.29188 .66734 m .2943 .64602 L .30358 .65125 L 1 .781 0 r
F
.29188 .66734 m .28213 .66276 L .2943 .64602 L F
.59606 .54931 m .61997 .55048 L .61443 .55463 L .742 .801 0 r
F
.20968 .9869 m .19941 .98741 L .19136 .96882 L .873 .808 0 r
F
.72928 .86447 m .73902 .87985 L .72823 .8777 L .858 .746 0 r
F
.7184 .8629 m .72928 .86447 L .72823 .8777 L .844 .735 0 r
F
.53378 1.05802 m .52387 1.05529 L .52292 1.0542 L 0 .077 0 r
F
.53378 1.05802 m .53578 1.05908 L .52387 1.05529 L F
.3843 1.02091 m .36573 1.01431 L .37476 1.01342 L .583 .665 0 r
F
.3927 1.0197 m .3843 1.02091 L .37476 1.01342 L .555 .643 0 r
F
.7227 1.22597 m .70717 1.24608 L .7005 1.24117 L 1 .897 0 r
F
.7227 1.22597 m .7302 1.23077 L .70717 1.24608 L F
.57157 .81569 m .58425 .82067 L .57402 .81908 L .437 .504 0 r
F
.54471 .80641 m .55268 .80608 L .55617 .80888 L .391 .438 0 r
F
.5416 .80417 m .55268 .80608 L .54471 .80641 L .385 .429 0 r
F
.5007 .7864 m .50286 .78298 L .50494 .7876 L .322 .323 0 r
F
.5007 .7864 m .49756 .78141 L .50286 .78298 L F
.42641 1.30666 m .39554 1.30678 L .39967 1.30308 L .705 .803 0 r
F
.42957 1.30291 m .42641 1.30666 L .39967 1.30308 L .681 .787 0 r
F
.45605 1.30463 m .42641 1.30666 L .42957 1.30291 L .701 .804 0 r
F
.4695 1.0381 m .46524 1.03988 L .45447 1.0361 L .338 .352 0 r
F
.47973 1.04151 m .46524 1.03988 L .4695 1.0381 L .296 .277 0 r
F
.39554 1.30678 m .36379 1.30489 L .36886 1.30134 L .713 .803 0 r
F
.39967 1.30308 m .39554 1.30678 L .36886 1.30134 L .693 .79 0 r
F
.64148 .84049 m .65321 .85043 L .64236 .84778 L .661 .638 0 r
F
.6307 .83842 m .64148 .84049 L .64236 .84778 L .629 .619 0 r
F
.74017 .86591 m .74981 .88188 L .73902 .87985 L .872 .755 0 r
F
.72928 .86447 m .74017 .86591 L .73902 .87985 L .858 .746 0 r
F
.60747 .82857 m .61993 .83618 L .60918 .83377 L .55 .58 0 r
F
.59691 .82668 m .60747 .82857 L .60918 .83377 L .515 .557 0 r
F
.27981 .99885 m .2612 .98526 L .27154 .98515 L .799 .772 0 r
F
.28976 .99824 m .27981 .99885 L .27154 .98515 L .785 .763 0 r
F
.76322 .55882 m .77218 .55555 L .78935 .57258 L .913 .832 0 r
F
.34965 .68131 m .35211 .66139 L .36068 .66906 L 1 .691 0 r
F
.34965 .68131 m .34048 .67464 L .35211 .66139 L F
.75105 .86724 m .7606 .88379 L .74981 .88188 L .883 .764 0 r
F
.74017 .86591 m .75105 .86724 L .74981 .88188 L .872 .755 0 r
F
.4202 .7338 m .42013 .72282 L .42792 .73283 L .47 .375 0 r
F
.4202 .7338 m .41171 .72466 L .42013 .72282 L F
.53367 .55023 m .53492 .54641 L .55433 .54728 L .592 .718 0 r
F
.51514 .55069 m .53492 .54641 L .53367 .55023 L .558 .671 0 r
F
.32833 1.00771 m .30971 .99729 L .31971 .99697 L .718 .733 0 r
F
.33787 1.00694 m .32833 1.00771 L .31971 .99697 L .698 .721 0 r
F
.76195 .86847 m .77139 .8856 L .7606 .88379 L .894 .773 0 r
F
.75105 .86724 m .76195 .86847 L .7606 .88379 L .883 .764 0 r
F
.56053 1.28416 m .56249 1.28787 L .53654 1.29438 L .934 .96 0 r
F
.58497 1.27507 m .56249 1.28787 L .56053 1.28416 L 1 1 0 r
F
.58497 1.27507 m .58795 1.27899 L .56249 1.28787 L F
.33151 1.30095 m .32556 1.30436 L .29909 1.29489 L .736 .804 0 r
F
.53562 1.29074 m .53654 1.29438 L .51036 1.2986 L .801 .877 0 r
F
.56053 1.28416 m .53654 1.29438 L .53562 1.29074 L .934 .96 0 r
F
.5416 .80417 m .54878 .80333 L .55268 .80608 L .385 .429 0 r
F
.53818 .80198 m .54878 .80333 L .5416 .80417 L .379 .42 0 r
F
.4513 .75757 m .45059 .75097 L .4576 .75822 L .297 .245 0 r
F
.4513 .75757 m .44351 .75005 L .45059 .75097 L F
.65908 1.24044 m .64138 1.25958 L .63646 1.25474 L 1 .973 0 r
F
.65908 1.24044 m .66494 1.24563 L .64138 1.25958 L F
.48751 .77896 m .48823 .7748 L .49242 .78006 L .294 .277 0 r
F
.48751 .77896 m .48233 .77331 L .48823 .7748 L F
.50494 .7876 m .50827 .78473 L .50926 .78897 L .325 .331 0 r
F
.50494 .7876 m .50286 .78298 L .50827 .78473 L F
.5592 .8117 m .5685 .81229 L .57157 .81569 L .415 .474 0 r
F
.55617 .80888 m .5685 .81229 L .5592 .8117 L .408 .466 0 r
F
.68708 1.23095 m .67077 1.25071 L .66494 1.24563 L 1 .924 0 r
F
.68708 1.23095 m .6938 1.23614 L .67077 1.25071 L F
.77284 .8696 m .78217 .8873 L .77139 .8856 L .903 .78 0 r
F
.76195 .86847 m .77284 .8696 L .77139 .8856 L .894 .773 0 r
F
.28213 .66276 m .28501 .64096 L .2943 .64602 L 1 .792 0 r
F
.28213 .66276 m .27235 .65832 L .28501 .64096 L F
.45822 1.30088 m .45605 1.30463 L .42957 1.30291 L .67 .782 0 r
F
.48417 1.30072 m .45605 1.30463 L .45822 1.30088 L .702 .808 0 r
F
.20968 .9869 m .19136 .96882 L .20195 .96891 L .873 .808 0 r
F
.21996 .98644 m .20968 .9869 L .20195 .96891 L .866 .803 0 r
F
.75949 1.21927 m .74514 1.24003 L .73768 1.23545 L 1 .88 0 r
F
.75949 1.21927 m .76771 1.2236 L .74514 1.24003 L F
.78374 .87065 m .79295 .88892 L .78217 .8873 L .911 .787 0 r
F
.77284 .8696 m .78374 .87065 L .78217 .8873 L .903 .78 0 r
F
.65113 .54934 m .67698 .55453 L .66959 .55831 L .823 .82 0 r
F
.64462 .55343 m .65113 .54934 L .66959 .55831 L .805 .811 0 r
F
.65228 .84239 m .66406 .8529 L .65321 .85043 L .691 .656 0 r
F
.64148 .84049 m .65228 .84239 L .65321 .85043 L .661 .638 0 r
F
.68438 .55064 m .71081 .55835 L .70262 .56183 L .857 .825 0 r
F
.67698 .55453 m .68438 .55064 L .70262 .56183 L .843 .818 0 r
F
.41171 .72466 m .41235 .71179 L .42013 .72282 L .59 .42 0 r
F
.41171 .72466 m .40323 .71507 L .41235 .71179 L F
.60871 1.26349 m .58795 1.27899 L .58497 1.27507 L 1 1 0 r
F
.60871 1.26349 m .61268 1.26781 L .58795 1.27899 L F
.79464 .87161 m .80374 .89046 L .79295 .88892 L .919 .794 0 r
F
.78374 .87065 m .79464 .87161 L .79295 .88892 L .911 .787 0 r
F
.51514 .55069 m .51526 .54727 L .53492 .54641 L .558 .671 0 r
F
.49659 .55293 m .51526 .54727 L .51514 .55069 L .538 .587 0 r
F
.34048 .67464 m .34352 .65424 L .35211 .66139 L 1 .717 0 r
F
.34048 .67464 m .33129 .66835 L .34352 .65424 L F
.80554 .87249 m .81452 .89192 L .80374 .89046 L .925 .799 0 r
F
.79464 .87161 m .80554 .87249 L .80374 .89046 L .919 .794 0 r
F
.36379 1.30489 m .33151 1.30095 L .33747 1.29759 L .723 .803 0 r
F
.36886 1.30134 m .36379 1.30489 L .33747 1.29759 L .707 .794 0 r
F
.51047 1.29498 m .51036 1.2986 L .48417 1.30072 L .713 .815 0 r
F
.53562 1.29074 m .51036 1.2986 L .51047 1.29498 L .801 .877 0 r
F
.81644 .87331 m .82529 .89332 L .81452 .89192 L .931 .805 0 r
F
.80554 .87249 m .81644 .87331 L .81452 .89192 L .925 .799 0 r
F
.82735 .87406 m .83607 .89465 L .82529 .89332 L .936 .81 0 r
F
.81644 .87331 m .82735 .87406 L .82529 .89332 L .931 .805 0 r
F
.53818 .80198 m .54451 .80064 L .54878 .80333 L .379 .42 0 r
F
.5345 .79984 m .54451 .80064 L .53818 .80198 L .372 .409 0 r
F
.49659 .55293 m .49557 .55014 L .51526 .54727 L .538 .587 0 r
F
.4782 .55743 m .49557 .55014 L .49659 .55293 L .547 .461 0 r
F
.50926 .78897 m .51374 .78663 L .51362 .79049 L .331 .341 0 r
F
.50926 .78897 m .50827 .78473 L .51374 .78663 L F
.82735 .87406 m .83826 .87475 L .83607 .89465 L .936 .81 0 r
F
.4782 .55743 m .47604 .55556 L .49557 .55014 L .547 .461 0 r
F
.46017 .56539 m .47604 .55556 L .4782 .55743 L .61 .399 0 r
F
.45969 1.03441 m .45447 1.0361 L .44427 1.03193 L .37 .412 0 r
F
.4695 1.0381 m .45447 1.0361 L .45969 1.03441 L .338 .352 0 r
F
.57327 .54969 m .57675 .54539 L .59606 .54931 L .694 .784 0 r
F
.55433 .54728 m .57675 .54539 L .57327 .54969 L .678 .783 0 r
F
.59451 .82209 m .60747 .82857 L .59691 .82668 L .505 .557 0 r
F
.58425 .82067 m .59451 .82209 L .59691 .82668 L .474 .532 0 r
F
.40323 .71507 m .40458 .69999 L .41235 .71179 L .729 .471 0 r
F
.40323 .71507 m .39474 .70526 L .40458 .69999 L F
.61805 .83028 m .6307 .83842 L .61993 .83618 L .583 .603 0 r
F
.60747 .82857 m .61805 .83028 L .61993 .83618 L .55 .58 0 r
F
.46017 .56539 m .45689 .56463 L .47604 .55556 L .61 .399 0 r
F
.54445 1.06257 m .5475 1.06411 L .53578 1.05908 L 0 .059 0 r
F
.36573 1.01431 m .34742 1.00629 L .35699 1.00578 L .632 .689 0 r
F
.37476 1.01342 m .36573 1.01431 L .35699 1.00578 L .607 .671 0 r
F
.28976 .99824 m .27154 .98515 L .28188 .98513 L .785 .763 0 r
F
.29973 .99771 m .28976 .99824 L .28188 .98513 L .771 .754 0 r
F
.47677 .77217 m .47713 .76764 L .48233 .77331 L .27 .238 0 r
F
.47677 .77217 m .47064 .76605 L .47713 .76764 L F
.4646 .765 m .4645 .75973 L .47064 .76605 L .264 .219 0 r
F
.4646 .765 m .4576 .75822 L .4645 .75973 L F
.72726 .55114 m .75428 .56204 L .74537 .56519 L .893 .831 0 r
F
.71902 .55478 m .72726 .55114 L .74537 .56519 L .883 .827 0 r
F
.57157 .81569 m .5814 .81668 L .58425 .82067 L .437 .504 0 r
F
.5685 .81229 m .5814 .81668 L .57157 .81569 L .429 .498 0 r
F
.27235 .65832 m .27569 .63605 L .28501 .64096 L 1 .802 0 r
F
.27235 .65832 m .26256 .65402 L .27569 .63605 L F
.41048 1.02477 m .3927 1.0197 L .40113 1.01866 L .5 .606 0 r
F
.41822 1.02349 m .41048 1.02477 L .40113 1.01866 L .472 .579 0 r
F
.42777 1.02878 m .41048 1.02477 L .41822 1.02349 L .449 .556 0 r
F
.21996 .98644 m .20195 .96891 L .21256 .96906 L .866 .803 0 r
F
.23026 .98605 m .21996 .98644 L .21256 .96906 L .858 .798 0 r
F
.5345 .79984 m .5399 .79805 L .54451 .80064 L .372 .409 0 r
F
.53061 .79778 m .5399 .79805 L .5345 .79984 L .365 .399 0 r
F
.66308 .84412 m .67491 .85522 L .66406 .8529 L .719 .673 0 r
F
.65228 .84239 m .66308 .84412 L .66406 .8529 L .691 .656 0 r
F
.51362 .79049 m .51921 .78868 L .51799 .79214 L .337 .352 0 r
F
.51362 .79049 m .51374 .78663 L .51921 .78868 L F
.39474 .70526 m .39681 .68798 L .40458 .69999 L .857 .521 0 r
F
.39474 .70526 m .38625 .69553 L .39681 .68798 L F
.5814 .81668 m .59451 .82209 L .58425 .82067 L .462 .53 0 r
F
.63152 1.24987 m .61268 1.26781 L .60871 1.26349 L 1 1 0 r
F
.63152 1.24987 m .63646 1.25474 L .61268 1.26781 L F
.55617 .80888 m .56486 .80892 L .5685 .81229 L .408 .466 0 r
F
.55268 .80608 m .56486 .80892 L .55617 .80888 L .401 .456 0 r
F
.43474 1.02735 m .42777 1.02878 L .41822 1.02349 L .432 .525 0 r
F
.44427 1.03193 m .42777 1.02878 L .43474 1.02735 L .413 .49 0 r
F
.49242 .78006 m .4944 .77656 L .49756 .78141 L .292 .277 0 r
F
.49242 .78006 m .48823 .7748 L .4944 .77656 L F
.44351 .75005 m .44357 .74306 L .45059 .75097 L .296 .226 0 r
F
.44351 .75005 m .43571 .74186 L .44357 .74306 L F
.33129 .66835 m .3349 .64754 L .34352 .65424 L 1 .74 0 r
F
.33129 .66835 m .32207 .66238 L .3349 .64754 L F
.71517 1.22104 m .7005 1.24117 L .6938 1.23614 L 1 .891 0 r
F
.71517 1.22104 m .7227 1.22597 L .7005 1.24117 L F
.53061 .79778 m .53502 .79554 L .5399 .79805 L .365 .399 0 r
F
.52652 .7958 m .53502 .79554 L .53061 .79778 L .358 .387 0 r
F
.51799 .79214 m .52462 .79085 L .5223 .79391 L .344 .364 0 r
F
.51799 .79214 m .51921 .78868 L .52462 .79085 L F
.38625 .69553 m .38903 .67644 L .39681 .68798 L .96 .569 0 r
F
.38625 .69553 m .37775 .68615 L .38903 .67644 L F
.52652 .7958 m .5299 .79314 L .53502 .79554 L .358 .387 0 r
F
.5223 .79391 m .5299 .79314 L .52652 .7958 L .351 .375 0 r
F
.33787 1.00694 m .31971 .99697 L .32972 .99677 L .698 .721 0 r
F
.34742 1.00629 m .33787 1.00694 L .32972 .99677 L .677 .707 0 r
F
.5223 .79391 m .52462 .79085 L .5299 .79314 L .351 .375 0 r
F
.3927 1.0197 m .37476 1.01342 L .38381 1.01267 L .555 .643 0 r
F
.40113 1.01866 m .3927 1.0197 L .38381 1.01267 L .527 .62 0 r
F
.48532 1.29709 m .48417 1.30072 L .45822 1.30088 L .662 .776 0 r
F
.51047 1.29498 m .48417 1.30072 L .48532 1.29709 L .713 .815 0 r
F
.62553 .54619 m .65113 .54934 L .64462 .55343 L .801 .82 0 r
F
.61997 .55048 m .62553 .54619 L .64462 .55343 L .778 .809 0 r
F
.44264 .58006 m .43829 .57935 L .45689 .56463 L 1 .856 0 r
F
.42567 .60689 m .43829 .57935 L .44264 .58006 L 1 1 0 r
F
.43095 .61283 m .42567 .60689 L .44264 .58006 L 1 .995 0 r
F
.49253 1.04295 m .49029 1.0447 L .47973 1.04151 L .238 .193 0 r
F
.50226 1.04606 m .49029 1.0447 L .49253 1.04295 L .18 .127 0 r
F
.50226 1.04606 m .50108 1.04777 L .49029 1.0447 L F
.66308 .84412 m .6739 .84568 L .67491 .85522 L .719 .673 0 r
F
.6739 .84568 m .68578 .85736 L .67491 .85522 L .744 .688 0 r
F
.5121 1.04921 m .50108 1.04777 L .50226 1.04606 L .112 .107 0 r
F
.5121 1.04921 m .51199 1.05087 L .50108 1.04777 L F
.59606 .54931 m .6006 .54494 L .61997 .55048 L .742 .801 0 r
F
.57675 .54539 m .6006 .54494 L .59606 .54931 L .734 .808 0 r
F
.62865 .83181 m .64148 .84049 L .6307 .83842 L .616 .624 0 r
F
.61805 .83028 m .62865 .83181 L .6307 .83842 L .583 .603 0 r
F
.37775 .68615 m .38122 .6658 L .38903 .67644 L 1 .613 0 r
F
.37775 .68615 m .36922 .6773 L .38122 .6658 L F
.26256 .65402 m .26635 .63127 L .27569 .63605 L 1 .811 0 r
F
.26256 .65402 m .25275 .64984 L .26635 .63127 L F
.75124 1.21484 m .73768 1.23545 L .7302 1.23077 L 1 .875 0 r
F
.75124 1.21484 m .75949 1.21927 L .73768 1.23545 L F
.23026 .98605 m .21256 .96906 L .22316 .96927 L .858 .798 0 r
F
.24056 .98571 m .23026 .98605 L .22316 .96927 L .849 .792 0 r
F
.6006 .54494 m .62553 .54619 L .61997 .55048 L .772 .818 0 r
F
.483 1.03975 m .47973 1.04151 L .4695 1.0381 L .285 .265 0 r
F
.49253 1.04295 m .47973 1.04151 L .483 1.03975 L .238 .193 0 r
F
.29973 .99771 m .28188 .98513 L .29224 .9852 L .771 .754 0 r
F
.30971 .99729 m .29973 .99771 L .29224 .9852 L .755 .744 0 r
F
.60479 .82332 m .61805 .83028 L .60747 .82857 L .537 .582 0 r
F
.59451 .82209 m .60479 .82332 L .60747 .82857 L .505 .557 0 r
F
.4504 1.03041 m .44427 1.03193 L .43474 1.02735 L .395 .458 0 r
F
.45969 1.03441 m .44427 1.03193 L .4504 1.03041 L .37 .412 0 r
F
.32207 .66238 m .32626 .6412 L .3349 .64754 L 1 .76 0 r
F
.32207 .66238 m .31284 .65669 L .32626 .6412 L F
.55268 .80608 m .56068 .80561 L .56486 .80892 L .401 .456 0 r
F
.54878 .80333 m .56068 .80561 L .55268 .80608 L .393 .445 0 r
F
.52197 1.0525 m .51199 1.05087 L .5121 1.04921 L .038 .098 0 r
F
.52197 1.0525 m .52292 1.0542 L .51199 1.05087 L F
.55433 .54728 m .55672 .54299 L .57675 .54539 L .678 .783 0 r
F
.53492 .54641 m .55672 .54299 L .55433 .54728 L .664 .778 0 r
F
.68034 1.22559 m .66494 1.24563 L .65908 1.24044 L 1 .917 0 r
F
.68034 1.22559 m .68708 1.23095 L .66494 1.24563 L F
.49756 .78141 m .50077 .77855 L .50286 .78298 L .294 .283 0 r
F
.49756 .78141 m .4944 .77656 L .50077 .77855 L F
.39967 1.30308 m .36886 1.30134 L .37394 1.29784 L .693 .79 0 r
F
.40383 1.29947 m .39967 1.30308 L .37394 1.29784 L .671 .776 0 r
F
.42957 1.30291 m .39967 1.30308 L .40383 1.29947 L .681 .787 0 r
F
.43275 1.29925 m .42957 1.30291 L .40383 1.29947 L .653 .767 0 r
F
.45822 1.30088 m .42957 1.30291 L .43275 1.29925 L .67 .782 0 r
F
.43571 .74186 m .43654 .73417 L .44357 .74306 L .311 .22 0 r
F
.43571 .74186 m .42792 .73283 L .43654 .73417 L F
.68472 .84709 m .69665 .85935 L .68578 .85736 L .767 .703 0 r
F
.6739 .84568 m .68472 .84709 L .68578 .85736 L .744 .688 0 r
F
.5685 .81229 m .57783 .81271 L .5814 .81668 L .429 .498 0 r
F
.56486 .80892 m .57783 .81271 L .5685 .81229 L .421 .489 0 r
F
.33151 1.30095 m .29909 1.29489 L .30589 1.29178 L .736 .804 0 r
F
.33747 1.29759 m .33151 1.30095 L .30589 1.29178 L .722 .796 0 r
F
.69181 .54666 m .71902 .55478 L .71081 .55835 L .869 .83 0 r
F
.68438 .55064 m .69181 .54666 L .71081 .55835 L .857 .825 0 r
F
.65321 1.23509 m .63646 1.25474 L .63152 1.24987 L 1 .971 0 r
F
.65321 1.23509 m .65908 1.24044 L .63646 1.25474 L F
.48233 .77331 m .48402 .76964 L .48823 .7748 L .256 .224 0 r
F
.48233 .77331 m .47713 .76764 L .48402 .76964 L F
.41564 .65096 m .42567 .60689 L .43095 .61283 L 1 .613 0 r
F
.4216 .67501 m .43095 .61283 L .4359 .64414 L 1 .515 0 r
F
.4216 .67501 m .41564 .65096 L .43095 .61283 L F
.59873 1.12395 m .59042 1.12678 L .58509 1.09426 L .207 .037 0 r
F
.59259 1.10656 m .59873 1.12395 L .58509 1.09426 L 0 0 0 r
F
.59259 1.10656 m .58509 1.09426 L .58006 1.08913 L F
.36922 .6773 m .37339 .6562 L .38122 .6658 L 1 .654 0 r
F
.36922 .6773 m .36068 .66906 L .37339 .6562 L F
.4576 .75822 m .45834 .75312 L .4645 .75973 L .231 .169 0 r
F
.4576 .75822 m .45059 .75097 L .45834 .75312 L F
.56996 1.07881 m .57502 1.08398 L .56297 1.07238 L 0 .006 0 r
F
.56996 1.07881 m .56297 1.07238 L .55893 1.07083 L F
.65766 .54513 m .68438 .55064 L .67698 .55453 L .84 .828 0 r
F
.65113 .54934 m .65766 .54513 L .67698 .55453 L .823 .82 0 r
F
.37476 1.01342 m .35699 1.00578 L .36658 1.0054 L .607 .671 0 r
F
.38381 1.01267 m .37476 1.01342 L .36658 1.0054 L .58 .651 0 r
F
.47377 1.0364 m .4695 1.0381 L .45969 1.03441 L .323 .33 0 r
F
.483 1.03975 m .4695 1.0381 L .47377 1.0364 L .285 .265 0 r
F
.73552 .54743 m .76322 .55882 L .75428 .56204 L .901 .835 0 r
F
.72726 .55114 m .73552 .54743 L .75428 .56204 L .893 .831 0 r
F
.24056 .98571 m .22316 .96927 L .23378 .96955 L .849 .792 0 r
F
.25088 .98545 m .24056 .98571 L .23378 .96955 L .84 .785 0 r
F
.25275 .64984 m .25699 .6266 L .26635 .63127 L 1 .819 0 r
F
.25275 .64984 m .24292 .64576 L .25699 .6266 L F
.59126 .81749 m .60479 .82332 L .59451 .82209 L .491 .555 0 r
F
.5814 .81668 m .59126 .81749 L .59451 .82209 L .462 .53 0 r
F
.63927 .83317 m .65228 .84239 L .64148 .84049 L .646 .643 0 r
F
.62865 .83181 m .63927 .83317 L .64148 .84049 L .616 .624 0 r
F
.47064 .76605 m .47192 .76195 L .47713 .76764 L .227 .179 0 r
F
.47064 .76605 m .4645 .75973 L .47192 .76195 L F
.57783 .81271 m .59126 .81749 L .5814 .81668 L .449 .524 0 r
F
.55486 1.06791 m .55893 1.07083 L .5475 1.06411 L 0 .045 0 r
F
.55486 1.06791 m .5475 1.06411 L .54445 1.06257 L F
.55857 1.28075 m .56053 1.28416 L .53562 1.29074 L .887 .93 0 r
F
.58199 1.27143 m .56053 1.28416 L .55857 1.28075 L 1 1 0 r
F
.58199 1.27143 m .58497 1.27507 L .56053 1.28416 L F
.54878 .80333 m .55599 .80237 L .56068 .80561 L .393 .445 0 r
F
.54451 .80064 m .55599 .80237 L .54878 .80333 L .384 .431 0 r
F
.69556 .84835 m .70752 .8612 L .69665 .85935 L .787 .716 0 r
F
.68472 .84709 m .69556 .84835 L .69665 .85935 L .767 .703 0 r
F
.34742 1.00629 m .32972 .99677 L .33974 .99669 L .677 .707 0 r
F
.35699 1.00578 m .34742 1.00629 L .33974 .99669 L .654 .691 0 r
F
.53176 1.05608 m .52292 1.0542 L .52197 1.0525 L 0 .087 0 r
F
.53176 1.05608 m .53378 1.05802 L .52292 1.0542 L F
.4604 1.29728 m .45822 1.30088 L .43275 1.29925 L .634 .755 0 r
F
.48532 1.29709 m .45822 1.30088 L .4604 1.29728 L .662 .776 0 r
F
.53469 1.28737 m .53562 1.29074 L .51047 1.29498 L .743 .831 0 r
F
.55857 1.28075 m .53562 1.29074 L .53469 1.28737 L .887 .93 0 r
F
.36886 1.30134 m .33747 1.29759 L .34345 1.29428 L .707 .794 0 r
F
.37394 1.29784 m .36886 1.30134 L .34345 1.29428 L .689 .782 0 r
F
.31284 .65669 m .31759 .63515 L .32626 .6412 L 1 .777 0 r
F
.31284 .65669 m .30358 .65125 L .31759 .63515 L F
.50286 .78298 m .50728 .7807 L .50827 .78473 L .301 .295 0 r
F
.50286 .78298 m .50077 .77855 L .50728 .7807 L F
.42792 .73283 m .42953 .72384 L .43654 .73417 L .352 .239 0 r
F
.42792 .73283 m .42013 .72282 L .42953 .72384 L F
.70763 1.21593 m .6938 1.23614 L .68708 1.23095 L 1 .883 0 r
F
.70763 1.21593 m .71517 1.22104 L .6938 1.23614 L F
.36068 .66906 m .36553 .64753 L .37339 .6562 L 1 .69 0 r
F
.36068 .66906 m .35211 .66139 L .36553 .64753 L F
.60473 1.25934 m .58497 1.27507 L .58199 1.27143 L 1 1 0 r
F
.60473 1.25934 m .60871 1.26349 L .58497 1.27507 L F
.53492 .54641 m .53619 .54227 L .55672 .54299 L .664 .778 0 r
F
.51526 .54727 m .53619 .54227 L .53492 .54641 L .655 .768 0 r
F
.30971 .99729 m .29224 .9852 L .30261 .98538 L .755 .744 0 r
F
.31971 .99697 m .30971 .99729 L .30261 .98538 L .738 .733 0 r
F
.41822 1.02349 m .40113 1.01866 L .40959 1.01778 L .472 .579 0 r
F
.42597 1.0224 m .41822 1.02349 L .40959 1.01778 L .447 .549 0 r
F
.43474 1.02735 m .41822 1.02349 L .42597 1.0224 L .432 .525 0 r
F
.61508 .82438 m .62865 .83181 L .61805 .83028 L .569 .604 0 r
F
.60479 .82332 m .61508 .82438 L .61805 .83028 L .537 .582 0 r
F
.7064 .84947 m .7184 .8629 L .70752 .8612 L .805 .728 0 r
F
.69556 .84835 m .7064 .84947 L .70752 .8612 L .787 .716 0 r
F
.74298 1.21028 m .7302 1.23077 L .7227 1.22597 L 1 .869 0 r
F
.74298 1.21028 m .75124 1.21484 L .7302 1.23077 L F
.51058 1.29157 m .51047 1.29498 L .48532 1.29709 L .659 .767 0 r
F
.53469 1.28737 m .51047 1.29498 L .51058 1.29157 L .743 .831 0 r
F
.40113 1.01866 m .38381 1.01267 L .39288 1.01209 L .527 .62 0 r
F
.40959 1.01778 m .40113 1.01866 L .39288 1.01209 L .498 .595 0 r
F
.54451 .80064 m .55086 .79924 L .55599 .80237 L .384 .431 0 r
F
.5399 .79805 m .55086 .79924 L .54451 .80064 L .374 .416 0 r
F
.56486 .80892 m .57359 .8088 L .57783 .81271 L .421 .489 0 r
F
.56068 .80561 m .57359 .8088 L .56486 .80892 L .413 .478 0 r
F
.25088 .98545 m .23378 .96955 L .2444 .9699 L .84 .785 0 r
F
.2612 .98526 m .25088 .98545 L .2444 .9699 L .829 .778 0 r
F
.42013 .72282 m .42253 .71154 L .42953 .72384 L .442 .294 0 r
F
.42013 .72282 m .41235 .71179 L .42253 .71154 L F
.46493 1.03284 m .45969 1.03441 L .4504 1.03041 L .353 .384 0 r
F
.47377 1.0364 m .45969 1.03441 L .46493 1.03284 L .323 .33 0 r
F
.24292 .64576 m .2476 .62202 L .25699 .6266 L 1 .826 0 r
F
.24292 .64576 m .23307 .64176 L .2476 .62202 L F
.57675 .54539 m .58024 .54089 L .6006 .54494 L .734 .808 0 r
F
.55672 .54299 m .58024 .54089 L .57675 .54539 L .729 .815 0 r
F
.62657 1.245 m .60871 1.26349 L .60473 1.25934 L 1 1 0 r
F
.62657 1.245 m .63152 1.24987 L .60871 1.26349 L F
.50827 .78473 m .51386 .78298 L .51374 .78663 L .309 .31 0 r
F
.50827 .78473 m .50728 .7807 L .51386 .78298 L F
.48823 .7748 m .49123 .77192 L .4944 .77656 L .252 .222 0 r
F
.48823 .7748 m .48402 .76964 L .49123 .77192 L F
.6499 .83436 m .66308 .84412 L .65228 .84239 L .675 .661 0 r
F
.63927 .83317 m .6499 .83436 L .65228 .84239 L .646 .643 0 r
F
.44173 1.0261 m .43474 1.02735 L .42597 1.0224 L .415 .493 0 r
F
.4504 1.03041 m .43474 1.02735 L .44173 1.0261 L .395 .458 0 r
F
.51526 .54727 m .51539 .54343 L .53619 .54227 L .655 .768 0 r
F
.49557 .55014 m .51539 .54343 L .51526 .54727 L .661 .755 0 r
F
.35211 .66139 m .35763 .63962 L .36553 .64753 L 1 .723 0 r
F
.35211 .66139 m .34352 .65424 L .35763 .63962 L F
.45059 .75097 m .45217 .74606 L .45834 .75312 L .197 .12 0 r
F
.45059 .75097 m .44357 .74306 L .45217 .74606 L F
.30358 .65125 m .3089 .62935 L .31759 .63515 L 1 .792 0 r
F
.30358 .65125 m .2943 .64602 L .3089 .62935 L F
.71725 .85046 m .72928 .86447 L .7184 .8629 L .822 .739 0 r
F
.7064 .84947 m .71725 .85046 L .7184 .8629 L .805 .728 0 r
F
.63111 .54176 m .65766 .54513 L .65113 .54934 L .821 .83 0 r
F
.62553 .54619 m .63111 .54176 L .65113 .54934 L .801 .82 0 r
F
.41235 .71179 m .41557 .697 L .42253 .71154 L .65 .378 0 r
F
.41235 .71179 m .40458 .69999 L .41557 .697 L F
.5399 .79805 m .54532 .79623 L .55086 .79924 L .374 .416 0 r
F
.53502 .79554 m .54532 .79623 L .5399 .79805 L .364 .4 0 r
F
.49557 .55014 m .49454 .54676 L .51539 .54343 L .661 .755 0 r
F
.47604 .55556 m .49454 .54676 L .49557 .55014 L .715 .765 0 r
F
.67358 1.21999 m .65908 1.24044 L .65321 1.23509 L 1 .907 0 r
F
.67358 1.21999 m .68034 1.22559 L .65908 1.24044 L F
.51374 .78663 m .52044 .78539 L .51921 .78868 L .32 .327 0 r
F
.51374 .78663 m .51386 .78298 L .52044 .78539 L F
.40458 .69999 m .40863 .68112 L .41557 .697 L .871 .464 0 r
F
.40458 .69999 m .39681 .68798 L .40863 .68112 L F
.47604 .55556 m .47388 .55276 L .49454 .54676 L .715 .765 0 r
F
.45689 .56463 m .47388 .55276 L .47604 .55556 L .914 .886 0 r
F
.54139 1.06001 m .53378 1.05802 L .53176 1.05608 L 0 .076 0 r
F
.54139 1.06001 m .54445 1.06257 L .53378 1.05802 L F
.39681 .68798 m .40169 .66589 L .40863 .68112 L 1 .535 0 r
F
.39681 .68798 m .38903 .67644 L .40169 .66589 L F
.69926 .5426 m .72726 .55114 L .71902 .55478 L .88 .835 0 r
F
.69181 .54666 m .69926 .5426 L .71902 .55478 L .869 .83 0 r
F
.60114 .81811 m .61508 .82438 L .60479 .82332 L .522 .58 0 r
F
.59126 .81749 m .60114 .81811 L .60479 .82332 L .491 .555 0 r
F
.48647 1.29364 m .48532 1.29709 L .4604 1.29728 L .615 .734 0 r
F
.51058 1.29157 m .48532 1.29709 L .48647 1.29364 L .659 .767 0 r
F
.53502 .79554 m .53945 .79333 L .54532 .79623 L .364 .4 0 r
F
.5299 .79314 m .53945 .79333 L .53502 .79554 L .353 .382 0 r
F
.7438 .54365 m .77218 .55555 L .76322 .55882 L .909 .839 0 r
F
.73552 .54743 m .7438 .54365 L .76322 .55882 L .901 .835 0 r
F
.57783 .81271 m .58719 .81295 L .59126 .81749 L .449 .524 0 r
F
.57359 .8088 m .58719 .81295 L .57783 .81271 L .436 .515 0 r
F
.38381 1.01267 m .36658 1.0054 L .37619 1.00518 L .58 .651 0 r
F
.39288 1.01209 m .38381 1.01267 L .37619 1.00518 L .552 .629 0 r
F
.2612 .98526 m .2444 .9699 L .25503 .97033 L .829 .778 0 r
F
.27154 .98515 m .2612 .98526 L .25503 .97033 L .818 .771 0 r
F
.72811 .85133 m .74017 .86591 L .72928 .86447 L .837 .749 0 r
F
.71725 .85046 m .72811 .85133 L .72928 .86447 L .822 .739 0 r
F
.31971 .99697 m .30261 .98538 L .31299 .98567 L .738 .733 0 r
F
.32972 .99677 m .31971 .99697 L .31299 .98567 L .719 .721 0 r
F
.35699 1.00578 m .33974 .99669 L .34978 .99675 L .654 .691 0 r
F
.36658 1.0054 m .35699 1.00578 L .34978 .99675 L .629 .675 0 r
F
.51921 .78868 m .52694 .78792 L .52462 .79085 L .331 .345 0 r
F
.51921 .78868 m .52044 .78539 L .52694 .78792 L F
.6006 .54494 m .60516 .5404 L .62553 .54619 L .772 .818 0 r
F
.58024 .54089 m .60516 .5404 L .6006 .54494 L .77 .828 0 r
F
.45689 .56463 m .45362 .56227 L .47388 .55276 L .914 .886 0 r
F
.43829 .57935 m .45362 .56227 L .45689 .56463 L 1 1 0 r
F
.23307 .64176 m .2382 .61751 L .2476 .62202 L 1 .832 0 r
F
.23307 .64176 m .22321 .63784 L .2382 .61751 L F
.38903 .67644 m .3947 .65274 L .40169 .66589 L 1 .596 0 r
F
.38903 .67644 m .38122 .6658 L .3947 .65274 L F
.5299 .79314 m .5333 .79056 L .53945 .79333 L .353 .382 0 r
F
.52462 .79085 m .5333 .79056 L .5299 .79314 L .342 .364 0 r
F
.60516 .5404 m .63111 .54176 L .62553 .54619 L .799 .831 0 r
F
.64731 1.22952 m .63152 1.24987 L .62657 1.245 L 1 .966 0 r
F
.64731 1.22952 m .65321 1.23509 L .63152 1.24987 L F
.42567 .60689 m .42037 .60093 L .43829 .57935 L 1 1 0 r
F
.47713 .76764 m .47979 .76464 L .48402 .76964 L .204 .158 0 r
F
.47713 .76764 m .47192 .76195 L .47979 .76464 L F
.40956 .63488 m .42037 .60093 L .42567 .60689 L 1 .735 0 r
F
.41564 .65096 m .40956 .63488 L .42567 .60689 L 1 .613 0 r
F
.58652 1.09502 m .58006 1.08913 L .57502 1.08398 L 0 .001 0 r
F
.58652 1.09502 m .59259 1.10656 L .58006 1.08913 L F
.33747 1.29759 m .30589 1.29178 L .31272 1.28872 L .722 .796 0 r
F
.34345 1.29428 m .33747 1.29759 L .31272 1.28872 L .707 .787 0 r
F
.52462 .79085 m .52694 .78792 L .5333 .79056 L .342 .364 0 r
F
.6254 .82524 m .63927 .83317 L .62865 .83181 L .6 .626 0 r
F
.61508 .82438 m .6254 .82524 L .62865 .83181 L .569 .604 0 r
F
.66055 .83538 m .6739 .84568 L .66308 .84412 L .701 .678 0 r
F
.6499 .83436 m .66055 .83538 L .66308 .84412 L .675 .661 0 r
F
.56068 .80561 m .5687 .80499 L .57359 .8088 L .413 .478 0 r
F
.55599 .80237 m .5687 .80499 L .56068 .80561 L .403 .464 0 r
F
.4645 .75973 m .46668 .75624 L .47192 .76195 L .17 .114 0 r
F
.4645 .75973 m .45834 .75312 L .46668 .75624 L F
.58719 .81295 m .60114 .81811 L .59126 .81749 L .475 .549 0 r
F
.66421 .54082 m .69181 .54666 L .68438 .55064 L .855 .834 0 r
F
.65766 .54513 m .66421 .54082 L .68438 .55064 L .84 .828 0 r
F
.34352 .65424 m .34971 .63232 L .35763 .63962 L 1 .751 0 r
F
.34352 .65424 m .3349 .64754 L .34971 .63232 L F
.40383 1.29947 m .37394 1.29784 L .37905 1.29443 L .671 .776 0 r
F
.40799 1.29595 m .40383 1.29947 L .37905 1.29443 L .647 .759 0 r
F
.43275 1.29925 m .40383 1.29947 L .40799 1.29595 L .653 .767 0 r
F
.70006 1.21062 m .68708 1.23095 L .68034 1.22559 L 1 .872 0 r
F
.70006 1.21062 m .70763 1.21593 L .68708 1.23095 L F
.45656 1.02905 m .4504 1.03041 L .44173 1.0261 L .378 .428 0 r
F
.46493 1.03284 m .4504 1.03041 L .45656 1.02905 L .353 .384 0 r
F
.4944 .77656 m .49867 .77438 L .50077 .77855 L .256 .231 0 r
F
.4944 .77656 m .49123 .77192 L .49867 .77438 L F
.73898 .85208 m .75105 .86724 L .74017 .86591 L .85 .758 0 r
F
.72811 .85133 m .73898 .85208 L .74017 .86591 L .837 .749 0 r
F
.43594 1.29572 m .43275 1.29925 L .40799 1.29595 L .622 .744 0 r
F
.4604 1.29728 m .43275 1.29925 L .43594 1.29572 L .634 .755 0 r
F
.2943 .64602 m .30019 .62375 L .3089 .62935 L 1 .804 0 r
F
.2943 .64602 m .28501 .64096 L .30019 .62375 L F
.30589 1.29178 m .29909 1.29489 L .27452 1.28386 L .738 .799 0 r
F
.49477 1.04108 m .49253 1.04295 L .483 1.03975 L .242 .207 0 r
F
.50344 1.04412 m .49253 1.04295 L .49477 1.04108 L .199 .153 0 r
F
.50344 1.04412 m .50226 1.04606 L .49253 1.04295 L F
.73469 1.20559 m .7227 1.22597 L .71517 1.22104 L 1 .861 0 r
F
.73469 1.20559 m .74298 1.21028 L .7227 1.22597 L F
.38122 .6658 m .38767 .64172 L .3947 .65274 L 1 .651 0 r
F
.38122 .6658 m .37339 .6562 L .38767 .64172 L F
.51222 1.04715 m .50226 1.04606 L .50344 1.04412 L .152 .111 0 r
F
.51222 1.04715 m .5121 1.04921 L .50226 1.04606 L F
.55672 .54299 m .55912 .53847 L .58024 .54089 L .729 .815 0 r
F
.53619 .54227 m .55912 .53847 L .55672 .54299 L .729 .824 0 r
F
.44357 .74306 m .44599 .73827 L .45217 .74606 L .168 .081 0 r
F
.44357 .74306 m .43654 .73417 L .44599 .73827 L F
.48628 1.03797 m .483 1.03975 L .47377 1.0364 L .28 .263 0 r
F
.49477 1.04108 m .483 1.03975 L .48628 1.03797 L .242 .207 0 r
F
.43829 .57935 m .43394 .57636 L .45362 .56227 L 1 1 0 r
F
.42037 .60093 m .43394 .57636 L .43829 .57935 L F
.77904 1.20248 m .76771 1.2236 L .75949 1.21927 L 1 .859 0 r
F
.77904 1.20248 m .78796 1.20646 L .76771 1.2236 L F
.27154 .98515 m .25503 .97033 L .26566 .97084 L .818 .771 0 r
F
.28188 .98513 m .27154 .98515 L .26566 .97084 L .805 .762 0 r
F
.74986 .85273 m .76195 .86847 L .75105 .86724 L .862 .767 0 r
F
.73898 .85208 m .74986 .85273 L .75105 .86724 L .85 .758 0 r
F
.37394 1.29784 m .34345 1.29428 L .34945 1.29104 L .689 .782 0 r
F
.37905 1.29443 m .37394 1.29784 L .34945 1.29104 L .669 .77 0 r
F
.52101 1.05025 m .5121 1.04921 L .51222 1.04715 L .104 .101 0 r
F
.52101 1.05025 m .52197 1.0525 L .5121 1.04921 L F
.66055 .83538 m .67121 .83623 L .6739 .84568 L .701 .678 0 r
F
.67121 .83623 m .68472 .84709 L .6739 .84568 L .725 .693 0 r
F
.55599 .80237 m .56323 .8013 L .5687 .80499 L .403 .464 0 r
F
.55086 .79924 m .56323 .8013 L .55599 .80237 L .391 .446 0 r
F
.40959 1.01778 m .39288 1.01209 L .40198 1.01167 L .498 .595 0 r
F
.41807 1.01708 m .40959 1.01778 L .40198 1.01167 L .47 .567 0 r
F
.42597 1.0224 m .40959 1.01778 L .41807 1.01708 L .447 .549 0 r
F
.56488 1.07363 m .55893 1.07083 L .55486 1.06791 L 0 .041 0 r
F
.56488 1.07363 m .56996 1.07881 L .55893 1.07083 L F
.43376 1.02148 m .42597 1.0224 L .41807 1.01708 L .43 .519 0 r
F
.44173 1.0261 m .42597 1.0224 L .43376 1.02148 L .415 .493 0 r
F
.32972 .99677 m .31299 .98567 L .32338 .98608 L .719 .721 0 r
F
.33974 .99669 m .32972 .99677 L .32338 .98608 L .698 .707 0 r
F
.59873 1.12395 m .605 1.14985 L .59042 1.12678 L .207 .037 0 r
F
.37339 .6562 m .3806 .63231 L .38767 .64172 L 1 .699 0 r
F
.37339 .6562 m .36553 .64753 L .3806 .63231 L F
.5566 1.27773 m .55857 1.28075 L .53469 1.28737 L .813 .868 0 r
F
.57901 1.2682 m .55857 1.28075 L .5566 1.27773 L 1 1 0 r
F
.57901 1.2682 m .58199 1.27143 L .55857 1.28075 L F
.47806 1.03475 m .47377 1.0364 L .46493 1.03284 L .313 .316 0 r
F
.48628 1.03797 m .47377 1.0364 L .47806 1.03475 L .28 .263 0 r
F
.76074 .85327 m .77284 .8696 L .76195 .86847 L .873 .774 0 r
F
.74986 .85273 m .76074 .85327 L .76195 .86847 L .862 .767 0 r
F
.3349 .64754 m .34176 .62547 L .34971 .63232 L 1 .774 0 r
F
.3349 .64754 m .32626 .6412 L .34176 .62547 L F
.46258 1.29383 m .4604 1.29728 L .43594 1.29572 L .594 .72 0 r
F
.48647 1.29364 m .4604 1.29728 L .46258 1.29383 L .615 .734 0 r
F
.60074 1.25547 m .58199 1.27143 L .57901 1.2682 L 1 1 0 r
F
.60074 1.25547 m .60473 1.25934 L .58199 1.27143 L F
.63574 .82593 m .6499 .83436 L .63927 .83317 L .63 .646 0 r
F
.6254 .82524 m .63574 .82593 L .63927 .83317 L .6 .626 0 r
F
.57359 .8088 m .58234 .80851 L .58719 .81295 L .436 .515 0 r
F
.5687 .80499 m .58234 .80851 L .57359 .8088 L .426 .502 0 r
F
.61105 .81854 m .6254 .82524 L .61508 .82438 L .552 .603 0 r
F
.60114 .81811 m .61105 .81854 L .61508 .82438 L .522 .58 0 r
F
.50077 .77855 m .50629 .77694 L .50728 .7807 L .267 .248 0 r
F
.50077 .77855 m .49867 .77438 L .50629 .77694 L F
.53376 1.28433 m .53469 1.28737 L .51058 1.29157 L .667 .756 0 r
F
.5566 1.27773 m .53469 1.28737 L .53376 1.28433 L .813 .868 0 r
F
.28501 .64096 m .29145 .61831 L .30019 .62375 L 1 .815 0 r
F
.28501 .64096 m .27569 .63605 L .29145 .61831 L F
.36658 1.0054 m .34978 .99675 L .35984 .99695 L .629 .675 0 r
F
.37619 1.00518 m .36658 1.0054 L .35984 .99695 L .603 .656 0 r
F
.6668 1.21407 m .65321 1.23509 L .64731 1.22952 L 1 .892 0 r
F
.6668 1.21407 m .67358 1.21999 L .65321 1.23509 L F
.55076 1.06422 m .54445 1.06257 L .54139 1.06001 L 0 .068 0 r
F
.55076 1.06422 m .55486 1.06791 L .54445 1.06257 L F
.7438 .54365 m .7521 .53981 L .77218 .55555 L .909 .839 0 r
F
.77164 .85373 m .78374 .87065 L .77284 .8696 L .882 .782 0 r
F
.76074 .85327 m .77164 .85373 L .77284 .8696 L .873 .774 0 r
F
.6216 1.2401 m .60473 1.25934 L .60074 1.25547 L 1 1 0 r
F
.6216 1.2401 m .62657 1.245 L .60473 1.25934 L F
.48402 .76964 m .48804 .76757 L .49123 .77192 L .197 .155 0 r
F
.48402 .76964 m .47979 .76464 L .48804 .76757 L F
.28188 .98513 m .26566 .97084 L .2763 .97145 L .805 .762 0 r
F
.29224 .9852 m .28188 .98513 L .2763 .97145 L .791 .753 0 r
F
.53619 .54227 m .53746 .53784 L .55912 .53847 L .729 .824 0 r
F
.51539 .54343 m .53746 .53784 L .53619 .54227 L .743 .838 0 r
F
.39288 1.01209 m .37619 1.00518 L .38581 1.00512 L .552 .629 0 r
F
.40198 1.01167 m .39288 1.01209 L .38581 1.00512 L .522 .606 0 r
F
.70673 .53845 m .73552 .54743 L .72726 .55114 L .891 .84 0 r
F
.69926 .5426 m .70673 .53845 L .72726 .55114 L .88 .835 0 r
F
.43654 .73417 m .43981 .72915 L .44599 .73827 L .164 .067 0 r
F
.43654 .73417 m .42953 .72384 L .43981 .72915 L F
.44874 1.02502 m .44173 1.0261 L .43376 1.02148 L .398 .463 0 r
F
.45656 1.02905 m .44173 1.0261 L .44874 1.02502 L .378 .428 0 r
F
.52973 1.05344 m .52197 1.0525 L .52101 1.05025 L .062 .094 0 r
F
.52973 1.05344 m .53176 1.05608 L .52197 1.0525 L F
.63671 .5372 m .66421 .54082 L .65766 .54513 L .84 .839 0 r
F
.63111 .54176 m .63671 .5372 L .65766 .54513 L .821 .83 0 r
F
.68189 .83694 m .69556 .84835 L .68472 .84709 L .747 .707 0 r
F
.67121 .83623 m .68189 .83694 L .68472 .84709 L .725 .693 0 r
F
.51069 1.28843 m .51058 1.29157 L .48647 1.29364 L .594 .7 0 r
F
.53376 1.28433 m .51058 1.29157 L .51069 1.28843 L .667 .756 0 r
F
.55086 .79924 m .55724 .79775 L .56323 .8013 L .391 .446 0 r
F
.54532 .79623 m .55724 .79775 L .55086 .79924 L .379 .426 0 r
F
.58719 .81295 m .59657 .81299 L .60114 .81811 L .475 .549 0 r
F
.58234 .80851 m .59657 .81299 L .58719 .81295 L .458 .54 0 r
F
.59657 .81299 m .61105 .81854 L .60114 .81811 L .504 .575 0 r
F
.58024 .54089 m .58375 .5362 L .60516 .5404 L .77 .828 0 r
F
.55912 .53847 m .58375 .5362 L .58024 .54089 L .773 .841 0 r
F
.45834 .75312 m .46143 .75051 L .46668 .75624 L .092 .076 0 r
F
.45834 .75312 m .45217 .74606 L .46143 .75051 L F
.69247 1.20505 m .68034 1.22559 L .67358 1.21999 L 1 .858 0 r
F
.69247 1.20505 m .70006 1.21062 L .68034 1.22559 L F
.78253 .85411 m .79464 .87161 L .78374 .87065 L .891 .788 0 r
F
.77164 .85373 m .78253 .85411 L .78374 .87065 L .882 .782 0 r
F
.47019 1.03138 m .46493 1.03284 L .45656 1.02905 L .34 .363 0 r
F
.47806 1.03475 m .46493 1.03284 L .47019 1.03138 L .313 .316 0 r
F
.72638 1.20072 m .71517 1.22104 L .70763 1.21593 L 1 .851 0 r
F
.72638 1.20072 m .73469 1.20559 L .71517 1.22104 L F
.36553 .64753 m .37349 .624 L .3806 .63231 L 1 .741 0 r
F
.36553 .64753 m .35763 .63962 L .37349 .624 L F
.7701 1.19839 m .75949 1.21927 L .75124 1.21484 L 1 .853 0 r
F
.7701 1.19839 m .77904 1.20248 L .75949 1.21927 L F
.40169 .66589 m .40956 .63488 L .41564 .65096 L 1 .59 0 r
F
.40169 .66589 m .3947 .65274 L .40956 .63488 L F
.40863 .68112 m .40169 .66589 L .41564 .65096 L 1 .509 0 r
F
.50728 .7807 m .51398 .77958 L .51386 .78298 L .281 .27 0 r
F
.50728 .7807 m .50629 .77694 L .51398 .77958 L F
.64139 1.22366 m .62657 1.245 L .6216 1.2401 L 1 .954 0 r
F
.64139 1.22366 m .64731 1.22952 L .62657 1.245 L F
.42037 .60093 m .41505 .59495 L .43394 .57636 L 1 1 0 r
F
.47192 .76195 m .47555 .75989 L .47979 .76464 L .129 .091 0 r
F
.47192 .76195 m .46668 .75624 L .47555 .75989 L F
.40339 .62366 m .41505 .59495 L .42037 .60093 L 1 .821 0 r
F
.40956 .63488 m .40339 .62366 L .42037 .60093 L 1 .735 0 r
F
.58048 1.08625 m .57502 1.08398 L .56996 1.07881 L 0 .028 0 r
F
.58048 1.08625 m .58652 1.09502 L .57502 1.08398 L F
.20195 .96891 m .19136 .96882 L .18652 .94956 L .891 .808 0 r
F
.32626 .6412 m .33378 .61898 L .34176 .62547 L 1 .794 0 r
F
.32626 .6412 m .31759 .63515 L .33378 .61898 L F
.3947 .65274 m .40339 .62366 L .40956 .63488 L 1 .665 0 r
F
.3947 .65274 m .38767 .64172 L .40339 .62366 L F
.79344 .8544 m .80554 .87249 L .79464 .87161 L .899 .794 0 r
F
.78253 .85411 m .79344 .8544 L .79464 .87161 L .891 .788 0 r
F
.34345 1.29428 m .31272 1.28872 L .31956 1.28572 L .707 .787 0 r
F
.34945 1.29104 m .34345 1.29428 L .31956 1.28572 L .69 .777 0 r
F
.67079 .5364 m .69926 .5426 L .69181 .54666 L .869 .84 0 r
F
.66421 .54082 m .67079 .5364 L .69181 .54666 L .855 .834 0 r
F
.40863 .68112 m .41564 .65096 L .4216 .67501 L 1 .509 0 r
F
.41557 .697 m .40863 .68112 L .4216 .67501 L .878 .381 0 r
F
.33974 .99669 m .32338 .98608 L .33379 .98662 L .698 .707 0 r
F
.34978 .99675 m .33974 .99669 L .33379 .98662 L .676 .692 0 r
F
.51539 .54343 m .51551 .5392 L .53746 .53784 L .743 .838 0 r
F
.49454 .54676 m .51551 .5392 L .51539 .54343 L .785 .864 0 r
F
.6461 .82644 m .66055 .83538 L .6499 .83436 L .657 .664 0 r
F
.63574 .82593 m .6461 .82644 L .6499 .83436 L .63 .646 0 r
F
.54532 .79623 m .55077 .79436 L .55724 .79775 L .379 .426 0 r
F
.53945 .79333 m .55077 .79436 L .54532 .79623 L .364 .403 0 r
F
.27569 .63605 m .28269 .61301 L .29145 .61831 L 1 .824 0 r
F
.27569 .63605 m .26635 .63127 L .28269 .61301 L F
.30589 1.29178 m .27452 1.28386 L .28213 1.2811 L .738 .799 0 r
F
.31272 1.28872 m .30589 1.29178 L .28213 1.2811 L .725 .792 0 r
F
.42953 .72384 m .43365 .7174 L .43981 .72915 L .224 .066 0 r
F
.42953 .72384 m .42253 .71154 L .43365 .7174 L F
.60974 .53571 m .63671 .5372 L .63111 .54176 L .823 .842 0 r
F
.60516 .5404 m .60974 .53571 L .63111 .54176 L .799 .831 0 r
F
.29224 .9852 m .2763 .97145 L .28695 .97216 L .791 .753 0 r
F
.30261 .98538 m .29224 .9852 L .28695 .97216 L .776 .743 0 r
F
.5687 .80499 m .57676 .80421 L .58234 .80851 L .426 .502 0 r
F
.56323 .8013 m .57676 .80421 L .5687 .80499 L .414 .485 0 r
F
.58375 .5362 m .60974 .53571 L .60516 .5404 L .801 .844 0 r
F
.69258 .8375 m .7064 .84947 L .69556 .84835 L .767 .72 0 r
F
.68189 .83694 m .69258 .8375 L .69556 .84835 L .747 .707 0 r
F
.80435 .85463 m .81644 .87331 L .80554 .87249 L .906 .8 0 r
F
.79344 .8544 m .80435 .85463 L .80554 .87249 L .899 .794 0 r
F
.51386 .78298 m .52167 .78231 L .52044 .78539 L .298 .295 0 r
F
.51386 .78298 m .51398 .77958 L .52167 .78231 L F
.48763 1.29041 m .48647 1.29364 L .46258 1.29383 L .562 .68 0 r
F
.51069 1.28843 m .48647 1.29364 L .48763 1.29041 L .594 .7 0 r
F
.41557 .697 m .4216 .67501 L .42756 .70014 L .878 .381 0 r
F
.42253 .71154 m .41557 .697 L .42756 .70014 L .388 .167 0 r
F
.62098 .81878 m .63574 .82593 L .6254 .82524 L .582 .625 0 r
F
.61105 .81854 m .62098 .81878 L .6254 .82524 L .552 .603 0 r
F
.49454 .54676 m .49352 .54284 L .51551 .5392 L .785 .864 0 r
F
.47388 .55276 m .49352 .54284 L .49454 .54676 L .889 .925 0 r
F
.40799 1.29595 m .37905 1.29443 L .38417 1.29109 L .647 .759 0 r
F
.41217 1.29253 m .40799 1.29595 L .38417 1.29109 L .62 .739 0 r
F
.43594 1.29572 m .40799 1.29595 L .41217 1.29253 L .622 .744 0 r
F
.20195 .96891 m .18652 .94956 L .19734 .95027 L .891 .808 0 r
F
.21256 .96906 m .20195 .96891 L .19734 .95027 L .884 .803 0 r
F
.42253 .71154 m .42756 .70014 L .43365 .7174 L .388 .167 0 r
F
.53945 .79333 m .54391 .79114 L .55077 .79436 L .364 .403 0 r
F
.5333 .79056 m .54391 .79114 L .53945 .79333 L .349 .377 0 r
F
.38767 .64172 m .39718 .61472 L .40339 .62366 L 1 .731 0 r
F
.38767 .64172 m .3806 .63231 L .39718 .61472 L F
.53831 1.05674 m .53176 1.05608 L .52973 1.05344 L .032 .088 0 r
F
.53831 1.05674 m .54139 1.06001 L .53176 1.05608 L F
.81527 .85479 m .82735 .87406 L .81644 .87331 L .912 .805 0 r
F
.80435 .85463 m .81527 .85479 L .81644 .87331 L .906 .8 0 r
F
.37619 1.00518 m .35984 .99695 L .36992 .9973 L .603 .656 0 r
F
.38581 1.00512 m .37619 1.00518 L .36992 .9973 L .575 .635 0 r
F
.47388 .55276 m .47171 .54917 L .49352 .54284 L .889 .925 0 r
F
.45362 .56227 m .47171 .54917 L .47388 .55276 L 1 1 0 r
F
.46274 1.02783 m .45656 1.02905 L .44874 1.02502 L .363 .402 0 r
F
.47019 1.03138 m .45656 1.02905 L .46274 1.02783 L .34 .363 0 r
F
.52044 .78539 m .52928 .78512 L .52694 .78792 L .315 .323 0 r
F
.52044 .78539 m .52167 .78231 L .52928 .78512 L F
.49123 .77192 m .49657 .77056 L .49867 .77438 L .204 .167 0 r
F
.49123 .77192 m .48804 .76757 L .49657 .77056 L F
.43915 1.29231 m .43594 1.29572 L .41217 1.29253 L .588 .715 0 r
F
.46258 1.29383 m .43594 1.29572 L .43915 1.29231 L .594 .72 0 r
F
.35763 .63962 m .36635 .61644 L .37349 .624 L 1 .775 0 r
F
.35763 .63962 m .34971 .63232 L .36635 .61644 L F
.5333 .79056 m .53672 .78806 L .54391 .79114 L .349 .377 0 r
F
.52694 .78792 m .53672 .78806 L .5333 .79056 L .332 .35 0 r
F
.41807 1.01708 m .40198 1.01167 L .41109 1.01144 L .47 .567 0 r
F
.42657 1.01657 m .41807 1.01708 L .41109 1.01144 L .444 .539 0 r
F
.43376 1.02148 m .41807 1.01708 L .42657 1.01657 L .43 .519 0 r
F
.52694 .78792 m .52928 .78512 L .53672 .78806 L .332 .35 0 r
F
.45362 .56227 m .45034 .55878 L .47171 .54917 L 1 1 0 r
F
.43394 .57636 m .45034 .55878 L .45362 .56227 L F
.82619 .85489 m .83826 .87475 L .82735 .87406 L .918 .81 0 r
F
.81527 .85479 m .82619 .85489 L .82735 .87406 L .912 .805 0 r
F
.37905 1.29443 m .34945 1.29104 L .35547 1.28787 L .669 .77 0 r
F
.38417 1.29109 m .37905 1.29443 L .35547 1.28787 L .647 .755 0 r
F
.65998 1.20773 m .64731 1.22952 L .64139 1.22366 L 1 .87 0 r
F
.65998 1.20773 m .6668 1.21407 L .64731 1.22952 L F
.70328 .83792 m .71725 .85046 L .7064 .84947 L .786 .731 0 r
F
.69258 .8375 m .70328 .83792 L .7064 .84947 L .767 .72 0 r
F
.21256 .96906 m .19734 .95027 L .20816 .95105 L .884 .803 0 r
F
.22316 .96927 m .21256 .96906 L .20816 .95105 L .877 .797 0 r
F
.40339 .62366 m .39718 .61472 L .41505 .59495 L 1 .821 0 r
F
.44157 1.02074 m .43376 1.02148 L .42657 1.01657 L .414 .489 0 r
F
.44874 1.02502 m .43376 1.02148 L .44157 1.02074 L .398 .463 0 r
F
.31759 .63515 m .32578 .61275 L .33378 .61898 L 1 .81 0 r
F
.31759 .63515 m .3089 .62935 L .32578 .61275 L F
.76113 1.19419 m .75124 1.21484 L .74298 1.21028 L 1 .847 0 r
F
.76113 1.19419 m .7701 1.19839 L .75124 1.21484 L F
.71805 1.19566 m .70763 1.21593 L .70006 1.21062 L 1 .84 0 r
F
.71805 1.19566 m .72638 1.20072 L .70763 1.21593 L F
.30261 .98538 m .28695 .97216 L .29761 .97297 L .776 .743 0 r
F
.31299 .98567 m .30261 .98538 L .29761 .97297 L .759 .732 0 r
F
.55912 .53847 m .56152 .53372 L .58375 .5362 L .773 .841 0 r
F
.53746 .53784 m .56152 .53372 L .55912 .53847 L .785 .859 0 r
F
.40198 1.01167 m .38581 1.00512 L .39546 1.00524 L .522 .606 0 r
F
.41109 1.01144 m .40198 1.01167 L .39546 1.00524 L .493 .58 0 r
F
.58234 .80851 m .59112 .80803 L .59657 .81299 L .458 .54 0 r
F
.57676 .80421 m .59112 .80803 L .58234 .80851 L .44 .527 0 r
F
.26635 .63127 m .2739 .60781 L .28269 .61301 L 1 .832 0 r
F
.26635 .63127 m .25699 .6266 L .2739 .60781 L F
.82619 .85489 m .83713 .85493 L .83826 .87475 L .918 .81 0 r
F
.65648 .82678 m .67121 .83623 L .66055 .83538 L .683 .681 0 r
F
.6461 .82644 m .65648 .82678 L .66055 .83538 L .657 .664 0 r
F
.68485 1.19915 m .67358 1.21999 L .6668 1.21407 L 1 .84 0 r
F
.68485 1.19915 m .69247 1.20505 L .67358 1.21999 L F
.71423 .53423 m .7438 .54365 L .73552 .54743 L .9 .844 0 r
F
.70673 .53845 m .71423 .53423 L .73552 .54743 L .891 .84 0 r
F
.34978 .99675 m .33379 .98662 L .3442 .9873 L .676 .692 0 r
F
.35984 .99695 m .34978 .99675 L .3442 .9873 L .651 .676 0 r
F
.45217 .74606 m .45616 .74476 L .46143 .75051 L 0 .059 0 r
F
.45217 .74606 m .44599 .73827 L .45616 .74476 L F
.49703 1.03906 m .49477 1.04108 L .48628 1.03797 L .253 .226 0 r
F
.50464 1.04191 m .49477 1.04108 L .49703 1.03906 L .222 .185 0 r
F
.50464 1.04191 m .50344 1.04412 L .49477 1.04108 L F
.60598 .81285 m .62098 .81878 L .61105 .81854 L .533 .599 0 r
F
.59657 .81299 m .60598 .81285 L .61105 .81854 L .504 .575 0 r
F
.43394 .57636 m .4296 .57219 L .45034 .55878 L 1 1 0 r
F
.41505 .59495 m .4296 .57219 L .43394 .57636 L F
.56323 .8013 m .5705 .80008 L .57676 .80421 L .414 .485 0 r
F
.55724 .79775 m .5705 .80008 L .56323 .8013 L .401 .465 0 r
F
.51233 1.04472 m .50344 1.04412 L .50464 1.04191 L .191 .15 0 r
F
.51233 1.04472 m .51222 1.04715 L .50344 1.04412 L F
.48959 1.03614 m .48628 1.03797 L .47806 1.03475 L .281 .268 0 r
F
.49703 1.03906 m .48628 1.03797 L .48959 1.03614 L .253 .226 0 r
F
.55979 1.06843 m .55486 1.06791 L .55076 1.06422 L 0 .064 0 r
F
.55979 1.06843 m .56488 1.07363 L .55486 1.06791 L F
.3806 .63231 m .39092 .60694 L .39718 .61472 L 1 .783 0 r
F
.3806 .63231 m .37349 .624 L .39092 .60694 L F
.59112 .80803 m .60598 .81285 L .59657 .81299 L .483 .566 0 r
F
.22316 .96927 m .20816 .95105 L .21898 .95189 L .877 .797 0 r
F
.23378 .96955 m .22316 .96927 L .21898 .95189 L .869 .791 0 r
F
.46478 1.29055 m .46258 1.29383 L .43915 1.29231 L .551 .676 0 r
F
.48763 1.29041 m .46258 1.29383 L .46478 1.29055 L .562 .68 0 r
F
.57601 1.26553 m .57901 1.2682 L .5566 1.27773 L .972 .959 0 r
F
.59674 1.25203 m .57901 1.2682 L .57601 1.26553 L 1 1 0 r
F
.59674 1.25203 m .60074 1.25547 L .57901 1.2682 L F
.55463 1.27522 m .5566 1.27773 L .53376 1.28433 L .699 .748 0 r
F
.57601 1.26553 m .5566 1.27773 L .55463 1.27522 L .972 .959 0 r
F
.64232 .53253 m .67079 .5364 L .66421 .54082 L .856 .846 0 r
F
.63671 .5372 m .64232 .53253 L .66421 .54082 L .84 .839 0 r
F
.71399 .83822 m .72811 .85133 L .71725 .85046 L .802 .742 0 r
F
.70328 .83792 m .71399 .83822 L .71725 .85046 L .786 .731 0 r
F
.61661 1.23519 m .60074 1.25547 L .59674 1.25203 L 1 1 0 r
F
.61661 1.23519 m .6216 1.2401 L .60074 1.25547 L F
.47979 .76464 m .48484 .76365 L .48804 .76757 L .117 .09 0 r
F
.47979 .76464 m .47555 .75989 L .48484 .76365 L F
.63093 .81884 m .6461 .82644 L .63574 .82593 L .611 .646 0 r
F
.62098 .81878 m .63093 .81884 L .63574 .82593 L .582 .625 0 r
F
.52004 1.0475 m .51222 1.04715 L .51233 1.04472 L .161 .122 0 r
F
.52004 1.0475 m .52101 1.05025 L .51222 1.04715 L F
.49867 .77438 m .50529 .77354 L .50629 .77694 L .222 .189 0 r
F
.49867 .77438 m .49657 .77056 L .50529 .77354 L F
.48238 1.03312 m .47806 1.03475 L .47019 1.03138 L .307 .309 0 r
F
.48959 1.03614 m .47806 1.03475 L .48238 1.03312 L .281 .268 0 r
F
.34971 .63232 m .35918 .60939 L .36635 .61644 L 1 .802 0 r
F
.34971 .63232 m .34176 .62547 L .35918 .60939 L F
.53282 1.28169 m .53376 1.28433 L .51069 1.28843 L .575 .639 0 r
F
.55463 1.27522 m .53376 1.28433 L .53282 1.28169 L .699 .748 0 r
F
.45579 1.0241 m .44874 1.02502 L .44157 1.02074 L .382 .434 0 r
F
.46274 1.02783 m .44874 1.02502 L .45579 1.0241 L .363 .402 0 r
F
.63545 1.21734 m .6216 1.2401 L .61661 1.23519 L 1 .933 0 r
F
.63545 1.21734 m .64139 1.22366 L .6216 1.2401 L F
.46668 .75624 m .47128 .75556 L .47555 .75989 L .019 .073 0 r
F
.46668 .75624 m .46143 .75051 L .47128 .75556 L F
.41505 .59495 m .40971 .58894 L .4296 .57219 L 1 1 0 r
F
.39718 .61472 m .40971 .58894 L .41505 .59495 L 1 .875 0 r
F
.57443 1.07884 m .56996 1.07881 L .56488 1.07363 L 0 .052 0 r
F
.57443 1.07884 m .58048 1.08625 L .56996 1.07881 L F
.67738 .5319 m .70673 .53845 L .69926 .5426 L .881 .845 0 r
F
.67079 .5364 m .67738 .5319 L .69926 .5426 L .869 .84 0 r
F
.31299 .98567 m .29761 .97297 L .30827 .97391 L .759 .732 0 r
F
.32338 .98608 m .31299 .98567 L .30827 .97391 L .74 .72 0 r
F
.23378 .96955 m .21898 .95189 L .2298 .9528 L .869 .791 0 r
F
.2444 .9699 m .23378 .96955 L .2298 .9528 L .86 .785 0 r
F
.54665 1.06006 m .54139 1.06001 L .53831 1.05674 L .025 .082 0 r
F
.54665 1.06006 m .55076 1.06422 L .54139 1.06001 L F
.34945 1.29104 m .31956 1.28572 L .32643 1.28278 L .69 .777 0 r
F
.35547 1.28787 m .34945 1.29104 L .32643 1.28278 L .672 .766 0 r
F
.31272 1.28872 m .28213 1.2811 L .28977 1.27839 L .725 .792 0 r
F
.31956 1.28572 m .31272 1.28872 L .28977 1.27839 L .711 .784 0 r
F
.38581 1.00512 m .36992 .9973 L .38001 .99783 L .575 .635 0 r
F
.39546 1.00524 m .38581 1.00512 L .38001 .99783 L .545 .613 0 r
F
.3089 .62935 m .31775 .60674 L .32578 .61275 L 1 .823 0 r
F
.3089 .62935 m .30019 .62375 L .31775 .60674 L F
.42756 .70014 m .4216 .67501 L .43524 .69553 L .179 .033 0 r
F
.55724 .79775 m .56364 .79616 L .5705 .80008 L .401 .465 0 r
F
.55077 .79436 m .56364 .79616 L .55724 .79775 L .385 .439 0 r
F
.53746 .53784 m .53873 .53313 L .56152 .53372 L .785 .859 0 r
F
.51551 .5392 m .53873 .53313 L .53746 .53784 L .815 .885 0 r
F
.65648 .82678 m .66687 .82697 L .67121 .83623 L .683 .681 0 r
F
.66687 .82697 m .68189 .83694 L .67121 .83623 L .707 .696 0 r
F
.25699 .6266 m .2651 .60271 L .2739 .60781 L 1 .839 0 r
F
.25699 .6266 m .2476 .62202 L .2651 .60271 L F
.58375 .5362 m .58727 .53133 L .60974 .53571 L .801 .844 0 r
F
.56152 .53372 m .58727 .53133 L .58375 .5362 L .811 .861 0 r
F
.39718 .61472 m .39092 .60694 L .40971 .58894 L 1 .875 0 r
F
.5108 1.2856 m .51069 1.28843 L .48763 1.29041 L .531 .607 0 r
F
.53282 1.28169 m .51069 1.28843 L .5108 1.2856 L .575 .639 0 r
F
.75215 1.18985 m .74298 1.21028 L .73469 1.20559 L 1 .838 0 r
F
.75215 1.18985 m .76113 1.19419 L .74298 1.21028 L F
.72472 .8384 m .73898 .85208 L .72811 .85133 L .817 .752 0 r
F
.71399 .83822 m .72472 .8384 L .72811 .85133 L .802 .742 0 r
F
.47548 1.02999 m .47019 1.03138 L .46274 1.02783 L .33 .347 0 r
F
.48238 1.03312 m .47019 1.03138 L .47548 1.02999 L .307 .309 0 r
F
.35984 .99695 m .3442 .9873 L .35463 .98813 L .651 .676 0 r
F
.36992 .9973 m .35984 .99695 L .35463 .98813 L .624 .658 0 r
F
.70969 1.19035 m .70006 1.21062 L .69247 1.20505 L 1 .825 0 r
F
.70969 1.19035 m .71805 1.19566 L .70006 1.21062 L F
.5277 1.05027 m .52101 1.05025 L .52004 1.0475 L .136 .104 0 r
F
.5277 1.05027 m .52973 1.05344 L .52101 1.05025 L F
.61434 .53088 m .64232 .53253 L .63671 .5372 L .844 .852 0 r
F
.60974 .53571 m .61434 .53088 L .63671 .5372 L .823 .842 0 r
F
.57676 .80421 m .58484 .80325 L .59112 .80803 L .44 .527 0 r
F
.5705 .80008 m .58484 .80325 L .57676 .80421 L .427 .51 0 r
F
.2444 .9699 m .2298 .9528 L .24062 .95379 L .86 .785 0 r
F
.25503 .97033 m .2444 .9699 L .24062 .95379 L .85 .778 0 r
F
.50629 .77694 m .5141 .77648 L .51398 .77958 L .246 .22 0 r
F
.50629 .77694 m .50529 .77354 L .5141 .77648 L F
.37349 .624 m .38464 .59978 L .39092 .60694 L 1 .821 0 r
F
.37349 .624 m .36635 .61644 L .38464 .59978 L F
.67721 1.19285 m .6668 1.21407 L .65998 1.20773 L 1 .817 0 r
F
.67721 1.19285 m .68485 1.19915 L .6668 1.21407 L F
.65314 1.20079 m .64139 1.22366 L .63545 1.21734 L 1 .839 0 r
F
.65314 1.20079 m .65998 1.20773 L .64139 1.22366 L F
.44599 .73827 m .45088 .73899 L .45616 .74476 L 0 .035 0 r
F
.44599 .73827 m .43981 .72915 L .45088 .73899 L F
.58727 .53133 m .61434 .53088 L .60974 .53571 L .829 .857 0 r
F
.42657 1.01657 m .41109 1.01144 L .42023 1.0114 L .444 .539 0 r
F
.4351 1.01625 m .42657 1.01657 L .42023 1.0114 L .427 .509 0 r
F
.44157 1.02074 m .42657 1.01657 L .4351 1.01625 L .414 .489 0 r
F
.61541 .81251 m .63093 .81884 L .62098 .81878 L .562 .622 0 r
F
.60598 .81285 m .61541 .81251 L .62098 .81878 L .533 .599 0 r
F
.41217 1.29253 m .38417 1.29109 L .38931 1.28785 L .62 .739 0 r
F
.41637 1.28923 m .41217 1.29253 L .38931 1.28785 L .59 .715 0 r
F
.43915 1.29231 m .41217 1.29253 L .41637 1.28923 L .588 .715 0 r
F
.55077 .79436 m .55624 .79244 L .56364 .79616 L .385 .439 0 r
F
.54391 .79114 m .55624 .79244 L .55077 .79436 L .367 .41 0 r
F
.41109 1.01144 m .39546 1.00524 L .40513 1.00553 L .493 .58 0 r
F
.42023 1.0114 m .41109 1.01144 L .40513 1.00553 L .464 .553 0 r
F
.32338 .98608 m .30827 .97391 L .31894 .97498 L .74 .72 0 r
F
.33379 .98662 m .32338 .98608 L .31894 .97498 L .72 .707 0 r
F
.51551 .5392 m .51563 .53463 L .53873 .53313 L .815 .885 0 r
F
.49352 .54284 m .51563 .53463 L .51551 .5392 L .877 .926 0 r
F
.34176 .62547 m .35198 .60271 L .35918 .60939 L 1 .823 0 r
F
.34176 .62547 m .33378 .61898 L .35198 .60271 L F
.73546 .83847 m .74986 .85273 L .73898 .85208 L .83 .761 0 r
F
.72472 .8384 m .73546 .83847 L .73898 .85208 L .817 .752 0 r
F
.72175 .52993 m .7521 .53981 L .7438 .54365 L .909 .847 0 r
F
.71423 .53423 m .72175 .52993 L .7438 .54365 L .9 .844 0 r
F
.48879 1.28742 m .48763 1.29041 L .46478 1.29055 L .513 .609 0 r
F
.5108 1.2856 m .48763 1.29041 L .48879 1.28742 L .531 .607 0 r
F
.6409 .81872 m .65648 .82678 L .6461 .82644 L .638 .665 0 r
F
.63093 .81884 m .6409 .81872 L .6461 .82644 L .611 .646 0 r
F
.38417 1.29109 m .35547 1.28787 L .36151 1.28478 L .647 .755 0 r
F
.38931 1.28785 m .38417 1.29109 L .36151 1.28478 L .623 .738 0 r
F
.67729 .827 m .69258 .8375 L .68189 .83694 L .729 .71 0 r
F
.66687 .82697 m .67729 .827 L .68189 .83694 L .707 .696 0 r
F
.25503 .97033 m .24062 .95379 L .25145 .95486 L .85 .778 0 r
F
.26566 .97084 m .25503 .97033 L .25145 .95486 L .839 .77 0 r
F
.59112 .80803 m .59993 .80735 L .60598 .81285 L .483 .566 0 r
F
.58484 .80325 m .59993 .80735 L .59112 .80803 L .462 .553 0 r
F
.44236 1.28905 m .43915 1.29231 L .41637 1.28923 L .551 .681 0 r
F
.46478 1.29055 m .43915 1.29231 L .44236 1.28905 L .551 .676 0 r
F
.4494 1.02019 m .44157 1.02074 L .4351 1.01625 L .397 .459 0 r
F
.45579 1.0241 m .44157 1.02074 L .4494 1.02019 L .382 .434 0 r
F
.46895 1.02673 m .46274 1.02783 L .45579 1.0241 L .35 .379 0 r
F
.47548 1.02999 m .46274 1.02783 L .46895 1.02673 L .33 .347 0 r
F
.28213 1.2811 m .27452 1.28386 L .2521 1.27138 L .743 .796 0 r
F
.51398 .77958 m .52291 .77944 L .52167 .78231 L .272 .257 0 r
F
.51398 .77958 m .5141 .77648 L .52291 .77944 L F
.2476 .62202 m .25627 .59769 L .2651 .60271 L 1 .844 0 r
F
.2476 .62202 m .2382 .61751 L .25627 .59769 L F
.48804 .76757 m .49445 .76723 L .49657 .77056 L .131 .1 0 r
F
.48804 .76757 m .48484 .76365 L .49445 .76723 L F
.30019 .62375 m .3097 .60089 L .31775 .60674 L 1 .834 0 r
F
.30019 .62375 m .29145 .61831 L .3097 .60089 L F
.59993 .80735 m .61541 .81251 L .60598 .81285 L .511 .591 0 r
F
.49352 .54284 m .49248 .53846 L .51563 .53463 L .877 .926 0 r
F
.47171 .54917 m .49248 .53846 L .49352 .54284 L .996 .994 0 r
F
.54391 .79114 m .54838 .78893 L .55624 .79244 L .367 .41 0 r
F
.53672 .78806 m .54838 .78893 L .54391 .79114 L .347 .375 0 r
F
.53521 1.05299 m .52973 1.05344 L .5277 1.05027 L .12 .095 0 r
F
.53521 1.05299 m .53831 1.05674 L .52973 1.05344 L F
.60431 1.11377 m .59873 1.12395 L .59259 1.10656 L .386 .165 0 r
F
.59732 1.10149 m .59259 1.10656 L .58652 1.09502 L .208 .063 0 r
F
.59732 1.10149 m .60431 1.11377 L .59259 1.10656 L F
.74315 1.18536 m .73469 1.20559 L .72638 1.20072 L 1 .829 0 r
F
.74315 1.18536 m .75215 1.18985 L .73469 1.20559 L F
.47171 .54917 m .46954 .54496 L .49248 .53846 L .996 .994 0 r
F
.45034 .55878 m .46954 .54496 L .47171 .54917 L 1 1 0 r
F
.74621 .83844 m .76074 .85327 L .74986 .85273 L .843 .769 0 r
F
.73546 .83847 m .74621 .83844 L .74986 .85273 L .83 .761 0 r
F
.39546 1.00524 m .38001 .99783 L .39012 .99853 L .545 .613 0 r
F
.40513 1.00553 m .39546 1.00524 L .39012 .99853 L .514 .588 0 r
F
.52167 .78231 m .53163 .78247 L .52928 .78512 L .299 .297 0 r
F
.52167 .78231 m .52291 .77944 L .53163 .78247 L F
.36992 .9973 m .35463 .98813 L .36507 .98912 L .624 .658 0 r
F
.38001 .99783 m .36992 .9973 L .36507 .98912 L .596 .638 0 r
F
.79612 1.18515 m .78796 1.20646 L .77904 1.20248 L 1 .843 0 r
F
.79612 1.18515 m .80567 1.18872 L .78796 1.20646 L F
.53672 .78806 m .54015 .78562 L .54838 .78893 L .347 .375 0 r
F
.52928 .78512 m .54015 .78562 L .53672 .78806 L .324 .337 0 r
F
.45034 .55878 m .44705 .55452 L .46954 .54496 L 1 1 0 r
F
.4296 .57219 m .44705 .55452 L .45034 .55878 L F
.39092 .60694 m .40435 .58292 L .40971 .58894 L 1 .906 0 r
F
.39092 .60694 m .38464 .59978 L .40435 .58292 L F
.5705 .80008 m .5778 .79871 L .58484 .80325 L .427 .51 0 r
F
.56364 .79616 m .5778 .79871 L .5705 .80008 L .412 .487 0 r
F
.52928 .78512 m .53163 .78247 L .54015 .78562 L .324 .337 0 r
F
.70131 1.18476 m .69247 1.20505 L .68485 1.19915 L 1 .808 0 r
F
.70131 1.18476 m .70969 1.19035 L .69247 1.20505 L F
.64796 .52774 m .67738 .5319 L .67079 .5364 L .871 .852 0 r
F
.64232 .53253 m .64796 .52774 L .67079 .5364 L .856 .846 0 r
F
.26566 .97084 m .25145 .95486 L .26228 .95603 L .839 .77 0 r
F
.2763 .97145 m .26566 .97084 L .26228 .95603 L .827 .761 0 r
F
.56152 .53372 m .56394 .52877 L .58727 .53133 L .811 .861 0 r
F
.53873 .53313 m .56394 .52877 L .56152 .53372 L .832 .883 0 r
F
.33379 .98662 m .31894 .97498 L .32962 .97618 L .72 .707 0 r
F
.3442 .9873 m .33379 .98662 L .32962 .97618 L .697 .692 0 r
F
.4296 .57219 m .42524 .56735 L .44705 .55452 L 1 1 0 r
F
.40971 .58894 m .42524 .56735 L .4296 .57219 L F
.61133 1.12842 m .605 1.14985 L .59873 1.12395 L .879 .382 0 r
F
.60431 1.11377 m .61133 1.12842 L .59873 1.12395 L .386 .165 0 r
F
.43981 .72915 m .44557 .7332 L .45088 .73899 L 0 .004 0 r
F
.43981 .72915 m .43365 .7174 L .44557 .7332 L F
.55468 1.06321 m .55076 1.06422 L .54665 1.06006 L .047 .08 0 r
F
.55468 1.06321 m .55979 1.06843 L .55076 1.06422 L F
.36635 .61644 m .37833 .59301 L .38464 .59978 L 1 .849 0 r
F
.36635 .61644 m .35918 .60939 L .37833 .59301 L F
.684 .5273 m .71423 .53423 L .70673 .53845 L .892 .85 0 r
F
.67738 .5319 m .684 .5273 L .70673 .53845 L .881 .845 0 r
F
.62948 1.21028 m .61661 1.23519 L .6116 1.23026 L 1 .896 0 r
F
.62948 1.21028 m .63545 1.21734 L .61661 1.23519 L F
.6116 1.23026 m .61661 1.23519 L .59674 1.25203 L 1 1 0 r
F
.46143 .75051 m .467 .75193 L .47128 .75556 L 0 .052 0 r
F
.46143 .75051 m .45616 .74476 L .467 .75193 L F
.40971 .58894 m .40435 .58292 L .42524 .56735 L 1 1 0 r
F
.56838 1.07217 m .56488 1.07363 L .55979 1.06843 L .021 .069 0 r
F
.56838 1.07217 m .57443 1.07884 L .56488 1.07363 L F
.31956 1.28572 m .28977 1.27839 L .29743 1.27574 L .711 .784 0 r
F
.32643 1.28278 m .31956 1.28572 L .29743 1.27574 L .696 .774 0 r
F
.66954 1.18601 m .65998 1.20773 L .65314 1.20079 L 1 .787 0 r
F
.66954 1.18601 m .67721 1.19285 L .65998 1.20773 L F
.47555 .75989 m .48162 .76038 L .48484 .76365 L 0 .078 0 r
F
.47555 .75989 m .47128 .75556 L .48162 .76038 L F
.59035 1.09132 m .58652 1.09502 L .58048 1.08625 L .131 .064 0 r
F
.59035 1.09132 m .59732 1.10149 L .58652 1.09502 L F
.43365 .7174 m .44025 .72739 L .44557 .7332 L 0 0 0 r
F
.42756 .70014 m .43524 .69553 L .44025 .72739 L .179 .033 0 r
F
.43365 .7174 m .42756 .70014 L .44025 .72739 L 0 0 0 r
F
.59273 1.2493 m .59674 1.25203 L .57601 1.26553 L 1 1 0 r
F
.6116 1.23026 m .59674 1.25203 L .59273 1.2493 L F
.68772 .82689 m .70328 .83792 L .69258 .8375 L .749 .723 0 r
F
.67729 .827 m .68772 .82689 L .69258 .8375 L .729 .71 0 r
F
.46698 1.28746 m .46478 1.29055 L .44236 1.28905 L .508 .623 0 r
F
.48879 1.28742 m .46478 1.29055 L .46698 1.28746 L .513 .609 0 r
F
.75697 .83832 m .77164 .85373 L .76074 .85327 L .854 .777 0 r
F
.74621 .83844 m .75697 .83832 L .76074 .85327 L .843 .769 0 r
F
.35547 1.28787 m .32643 1.28278 L .33332 1.2799 L .672 .766 0 r
F
.36151 1.28478 m .35547 1.28787 L .33332 1.2799 L .653 .753 0 r
F
.33378 .61898 m .34476 .59627 L .35198 .60271 L 1 .839 0 r
F
.33378 .61898 m .32578 .61275 L .34476 .59627 L F
.4993 1.03687 m .49703 1.03906 L .48959 1.03614 L .266 .247 0 r
F
.50584 1.03944 m .49703 1.03906 L .4993 1.03687 L .245 .219 0 r
F
.50584 1.03944 m .50464 1.04191 L .49703 1.03906 L F
.46286 1.02333 m .45579 1.0241 L .4494 1.02019 L .367 .408 0 r
F
.46895 1.02673 m .45579 1.0241 L .46286 1.02333 L .35 .379 0 r
F
.64627 1.193 m .63545 1.21734 L .62948 1.21028 L 1 .796 0 r
F
.64627 1.193 m .65314 1.20079 L .63545 1.21734 L F
.57301 1.2637 m .57601 1.26553 L .55463 1.27522 L .804 .782 0 r
F
.59273 1.2493 m .57601 1.26553 L .57301 1.2637 L 1 1 0 r
F
.49291 1.03422 m .48959 1.03614 L .48238 1.03312 L .286 .277 0 r
F
.4993 1.03687 m .48959 1.03614 L .49291 1.03422 L .266 .247 0 r
F
.6509 .81843 m .66687 .82697 L .65648 .82678 L .664 .682 0 r
F
.6409 .81872 m .6509 .81843 L .65648 .82678 L .638 .665 0 r
F
.51245 1.04194 m .50464 1.04191 L .50584 1.03944 L .225 .193 0 r
F
.51245 1.04194 m .51233 1.04472 L .50464 1.04191 L F
.62487 .81199 m .6409 .81872 L .63093 .81884 L .591 .643 0 r
F
.61541 .81251 m .62487 .81199 L .63093 .81884 L .562 .622 0 r
F
.2763 .97145 m .26228 .95603 L .27311 .9573 L .827 .761 0 r
F
.28695 .97216 m .2763 .97145 L .27311 .9573 L .813 .752 0 r
F
.55265 1.27338 m .55463 1.27522 L .53282 1.28169 L .575 .529 0 r
F
.57301 1.2637 m .55463 1.27522 L .55265 1.27338 L .804 .782 0 r
F
.29145 .61831 m .30162 .59517 L .3097 .60089 L 1 .843 0 r
F
.29145 .61831 m .28269 .61301 L .30162 .59517 L F
.49657 .77056 m .50428 .77057 L .50529 .77354 L .162 .124 0 r
F
.49657 .77056 m .49445 .76723 L .50428 .77057 L F
.48671 1.03149 m .48238 1.03312 L .47548 1.02999 L .305 .307 0 r
F
.49291 1.03422 m .48238 1.03312 L .48671 1.03149 L .286 .277 0 r
F
.53188 1.27954 m .53282 1.28169 L .5108 1.2856 L .512 .466 0 r
F
.55265 1.27338 m .53282 1.28169 L .53188 1.27954 L .575 .529 0 r
F
.42023 1.0114 m .40513 1.00553 L .41482 1.00602 L .464 .553 0 r
F
.4294 1.01155 m .42023 1.0114 L .41482 1.00602 L .438 .524 0 r
F
.4351 1.01625 m .42023 1.0114 L .4294 1.01155 L .427 .509 0 r
F
.73412 1.18068 m .72638 1.20072 L .71805 1.19566 L 1 .817 0 r
F
.73412 1.18068 m .74315 1.18536 L .72638 1.20072 L F
.54252 1.0556 m .53831 1.05674 L .53521 1.05299 L .117 .092 0 r
F
.54252 1.0556 m .54665 1.06006 L .53831 1.05674 L F
.78656 1.18149 m .77904 1.20248 L .7701 1.19839 L 1 .837 0 r
F
.78656 1.18149 m .79612 1.18515 L .77904 1.20248 L F
.51907 1.04436 m .51233 1.04472 L .51245 1.04194 L .207 .171 0 r
F
.51907 1.04436 m .52004 1.0475 L .51233 1.04472 L F
.72175 .52993 m .72929 .52557 L .7521 .53981 L .909 .847 0 r
F
.56364 .79616 m .57007 .79443 L .5778 .79871 L .412 .487 0 r
F
.55624 .79244 m .57007 .79443 L .56364 .79616 L .395 .457 0 r
F
.58484 .80325 m .59295 .80211 L .59993 .80735 L .462 .553 0 r
F
.5778 .79871 m .59295 .80211 L .58484 .80325 L .441 .535 0 r
F
.58727 .53133 m .5908 .5263 L .61434 .53088 L .829 .857 0 r
F
.56394 .52877 m .5908 .5263 L .58727 .53133 L .843 .876 0 r
F
.44365 1.01612 m .4351 1.01625 L .4294 1.01155 L .41 .479 0 r
F
.4494 1.02019 m .4351 1.01625 L .44365 1.01612 L .397 .459 0 r
F
.76774 .83811 m .78253 .85411 L .77164 .85373 L .864 .784 0 r
F
.75697 .83832 m .76774 .83811 L .77164 .85373 L .854 .777 0 r
F
.3442 .9873 m .32962 .97618 L .34031 .97753 L .697 .692 0 r
F
.35463 .98813 m .3442 .9873 L .34031 .97753 L .672 .676 0 r
F
.61895 .52591 m .64796 .52774 L .64232 .53253 L .862 .859 0 r
F
.61434 .53088 m .61895 .52591 L .64232 .53253 L .844 .852 0 r
F
.38001 .99783 m .36507 .98912 L .37553 .99028 L .596 .638 0 r
F
.39012 .99853 m .38001 .99783 L .37553 .99028 L .565 .616 0 r
F
.53873 .53313 m .54001 .52818 L .56394 .52877 L .832 .883 0 r
F
.51563 .53463 m .54001 .52818 L .53873 .53313 L .872 .915 0 r
F
.28213 1.2811 m .2521 1.27138 L .26047 1.26901 L .743 .796 0 r
F
.28977 1.27839 m .28213 1.2811 L .26047 1.26901 L .732 .789 0 r
F
.28695 .97216 m .27311 .9573 L .28394 .95867 L .813 .752 0 r
F
.29761 .97297 m .28695 .97216 L .28394 .95867 L .798 .742 0 r
F
.69291 1.17882 m .68485 1.19915 L .67721 1.19285 L 1 .786 0 r
F
.69291 1.17882 m .70131 1.18476 L .68485 1.19915 L F
.51092 1.28312 m .5108 1.2856 L .48879 1.28742 L .486 .483 0 r
F
.53188 1.27954 m .5108 1.2856 L .51092 1.28312 L .512 .466 0 r
F
.69816 .82665 m .71399 .83822 L .70328 .83792 L .767 .735 0 r
F
.68772 .82689 m .69816 .82665 L .70328 .83792 L .749 .723 0 r
F
.60876 .80649 m .62487 .81199 L .61541 .81251 L .54 .616 0 r
F
.59993 .80735 m .60876 .80649 L .61541 .81251 L .511 .591 0 r
F
.48078 1.02866 m .47548 1.02999 L .46895 1.02673 L .323 .335 0 r
F
.48671 1.03149 m .47548 1.02999 L .48078 1.02866 L .305 .307 0 r
F
.5908 .5263 m .61895 .52591 L .61434 .53088 L .853 .867 0 r
F
.40513 1.00553 m .39012 .99853 L .40024 .99941 L .514 .588 0 r
F
.41482 1.00602 m .40513 1.00553 L .40024 .99941 L .483 .562 0 r
F
.59295 .80211 m .60876 .80649 L .59993 .80735 L .487 .579 0 r
F
.41637 1.28923 m .38931 1.28785 L .39446 1.28471 L .59 .715 0 r
F
.42058 1.28605 m .41637 1.28923 L .39446 1.28471 L .558 .688 0 r
F
.44236 1.28905 m .41637 1.28923 L .42058 1.28605 L .551 .681 0 r
F
.58339 1.08264 m .58048 1.08625 L .57443 1.07884 L .121 .07 0 r
F
.58339 1.08264 m .59035 1.09132 L .58048 1.08625 L F
.38464 .59978 m .39898 .57688 L .40435 .58292 L 1 .924 0 r
F
.38464 .59978 m .37833 .59301 L .39898 .57688 L F
.35918 .60939 m .372 .58648 L .37833 .59301 L 1 .868 0 r
F
.35918 .60939 m .35198 .60271 L .372 .58648 L F
.66184 1.17849 m .65314 1.20079 L .64627 1.193 L 1 .75 0 r
F
.66184 1.17849 m .66954 1.18601 L .65314 1.20079 L F
.52565 1.04668 m .52004 1.0475 L .51907 1.04436 L .192 .155 0 r
F
.52565 1.04668 m .5277 1.05027 L .52004 1.0475 L F
.77853 .83782 m .79344 .8544 L .78253 .85411 L .873 .79 0 r
F
.76774 .83811 m .77853 .83782 L .78253 .85411 L .864 .784 0 r
F
.45727 1.01981 m .4494 1.02019 L .44365 1.01612 L .381 .431 0 r
F
.46286 1.02333 m .4494 1.02019 L .45727 1.01981 L .367 .408 0 r
F
.38931 1.28785 m .36151 1.28478 L .36756 1.28177 L .623 .738 0 r
F
.39446 1.28471 m .38931 1.28785 L .36756 1.28177 L .598 .718 0 r
F
.50529 .77354 m .51422 .77372 L .5141 .77648 L .202 .162 0 r
F
.50529 .77354 m .50428 .77057 L .51422 .77372 L F
.32578 .61275 m .33751 .59003 L .34476 .59627 L 1 .852 0 r
F
.32578 .61275 m .31775 .60674 L .33751 .59003 L F
.6509 .81843 m .66092 .81798 L .66687 .82697 L .664 .682 0 r
F
.66092 .81798 m .67729 .827 L .66687 .82697 L .688 .698 0 r
F
.55624 .79244 m .56174 .79042 L .57007 .79443 L .395 .457 0 r
F
.54838 .78893 m .56174 .79042 L .55624 .79244 L .374 .421 0 r
F
.29761 .97297 m .28394 .95867 L .29478 .96017 L .798 .742 0 r
F
.30827 .97391 m .29761 .97297 L .29478 .96017 L .781 .731 0 r
F
.28269 .61301 m .29352 .58955 L .30162 .59517 L 1 .85 0 r
F
.28269 .61301 m .2739 .60781 L .29352 .58955 L F
.51563 .53463 m .51576 .52974 L .54001 .52818 L .872 .915 0 r
F
.49248 .53846 m .51576 .52974 L .51563 .53463 L .942 .96 0 r
F
.62347 1.20192 m .62948 1.21028 L .6116 1.23026 L 1 .835 0 r
F
.63936 1.18396 m .62948 1.21028 L .62347 1.20192 L 1 .739 0 r
F
.63936 1.18396 m .64627 1.193 L .62948 1.21028 L F
.44559 1.28595 m .44236 1.28905 L .42058 1.28605 L .514 .64 0 r
F
.46698 1.28746 m .44236 1.28905 L .44559 1.28595 L .508 .623 0 r
F
.77697 1.17773 m .7701 1.19839 L .76113 1.19419 L 1 .83 0 r
F
.77697 1.17773 m .78656 1.18149 L .7701 1.19839 L F
.35463 .98813 m .34031 .97753 L .35101 .97903 L .672 .676 0 r
F
.36507 .98912 m .35463 .98813 L .35101 .97903 L .645 .658 0 r
F
.48995 1.2847 m .48879 1.28742 L .46698 1.28746 L .479 .52 0 r
F
.51092 1.28312 m .48879 1.28742 L .48995 1.2847 L .486 .483 0 r
F
.47518 1.02573 m .46895 1.02673 L .46286 1.02333 L .339 .362 0 r
F
.48078 1.02866 m .46895 1.02673 L .47518 1.02573 L .323 .335 0 r
F
.61133 1.12842 m .61837 1.14454 L .605 1.14985 L .879 .382 0 r
F
.605 1.14985 m .59648 1.21538 L .59107 1.18228 L 1 .517 0 r
F
.605 1.14985 m .61126 1.17475 L .59648 1.21538 L F
.61837 1.14454 m .61126 1.17475 L .605 1.14985 L 1 .509 0 r
F
.72508 1.1758 m .71805 1.19566 L .70969 1.19035 L 1 .804 0 r
F
.72508 1.1758 m .73412 1.18068 L .71805 1.19566 L F
.63435 .81129 m .6509 .81843 L .6409 .81872 L .618 .663 0 r
F
.62487 .81199 m .63435 .81129 L .6409 .81872 L .591 .643 0 r
F
.69064 .52262 m .72175 .52993 L .71423 .53423 L .902 .853 0 r
F
.684 .5273 m .69064 .52262 L .71423 .53423 L .892 .85 0 r
F
.65361 .52285 m .684 .5273 L .67738 .5319 L .885 .857 0 r
F
.64796 .52774 m .65361 .52285 L .67738 .5319 L .871 .852 0 r
F
.48484 .76365 m .49232 .76455 L .49445 .76723 L .027 .088 0 r
F
.48484 .76365 m .48162 .76038 L .49232 .76455 L F
.78933 .83745 m .80435 .85463 L .79344 .8544 L .881 .796 0 r
F
.77853 .83782 m .78933 .83745 L .79344 .8544 L .873 .79 0 r
F
.70862 .82628 m .72472 .8384 L .71399 .83822 L .784 .745 0 r
F
.69816 .82665 m .70862 .82628 L .71399 .83822 L .767 .735 0 r
F
.32643 1.28278 m .29743 1.27574 L .30511 1.27314 L .696 .774 0 r
F
.33332 1.2799 m .32643 1.28278 L .30511 1.27314 L .68 .764 0 r
F
.62347 1.20192 m .6116 1.23026 L .60658 1.22532 L 1 .835 0 r
F
.60658 1.22532 m .6116 1.23026 L .59273 1.2493 L 1 1 0 r
F
.56231 1.06594 m .55979 1.06843 L .55468 1.06321 L .1 .081 0 r
F
.56231 1.06594 m .56838 1.07217 L .55979 1.06843 L F
.45616 .74476 m .46268 .74961 L .467 .75193 L 0 .018 0 r
F
.45616 .74476 m .45088 .73899 L .46268 .74961 L F
.40435 .58292 m .42087 .56209 L .42524 .56735 L 1 1 0 r
F
.40435 .58292 m .39898 .57688 L .42087 .56209 L F
.5778 .79871 m .58513 .79717 L .59295 .80211 L .441 .535 0 r
F
.57007 .79443 m .58513 .79717 L .5778 .79871 L .426 .511 0 r
F
.49248 .53846 m .49145 .53368 L .51576 .52974 L .942 .96 0 r
F
.46954 .54496 m .49145 .53368 L .49248 .53846 L 1 1 0 r
F
.68448 1.17246 m .67721 1.19285 L .66954 1.18601 L 1 .761 0 r
F
.68448 1.17246 m .69291 1.17882 L .67721 1.19285 L F
.54838 .78893 m .55288 .78669 L .56174 .79042 L .374 .421 0 r
F
.54015 .78562 m .55288 .78669 L .54838 .78893 L .348 .377 0 r
F
.5321 1.04889 m .5277 1.05027 L .52565 1.04668 L .183 .144 0 r
F
.5321 1.04889 m .53521 1.05299 L .5277 1.05027 L F
.5141 .77648 m .52416 .7768 L .52291 .77944 L .244 .213 0 r
F
.5141 .77648 m .51422 .77372 L .52416 .7768 L F
.39012 .99853 m .37553 .99028 L .386 .99161 L .565 .616 0 r
F
.40024 .99941 m .39012 .99853 L .386 .99161 L .534 .593 0 r
F
.54955 1.05797 m .54665 1.06006 L .54252 1.0556 L .13 .095 0 r
F
.54955 1.05797 m .55468 1.06321 L .54665 1.06006 L F
.42524 .56735 m .44375 .54972 L .44705 .55452 L 1 1 0 r
F
.42524 .56735 m .42087 .56209 L .44375 .54972 L F
.30827 .97391 m .29478 .96017 L .30562 .96179 L .781 .731 0 r
F
.31894 .97498 m .30827 .97391 L .30562 .96179 L .763 .718 0 r
F
.36151 1.28478 m .33332 1.2799 L .34022 1.2771 L .653 .753 0 r
F
.36756 1.28177 m .36151 1.28478 L .34022 1.2771 L .632 .738 0 r
F
.46954 .54496 m .46736 .54026 L .49145 .53368 L 1 1 0 r
F
.44705 .55452 m .46736 .54026 L .46954 .54496 L F
.44705 .55452 m .44375 .54972 L .46736 .54026 L F
.56394 .52877 m .56636 .52362 L .5908 .5263 L .843 .876 0 r
F
.54001 .52818 m .56636 .52362 L .56394 .52877 L .87 .901 0 r
F
.80013 .83702 m .81527 .85479 L .80435 .85463 L .889 .801 0 r
F
.78933 .83745 m .80013 .83702 L .80435 .85463 L .881 .796 0 r
F
.4294 1.01155 m .41482 1.00602 L .42454 1.00671 L .438 .524 0 r
F
.43859 1.01191 m .4294 1.01155 L .42454 1.00671 L .421 .494 0 r
F
.44365 1.01612 m .4294 1.01155 L .43859 1.01191 L .41 .479 0 r
F
.65411 1.17011 m .64627 1.193 L .63936 1.18396 L 1 .705 0 r
F
.65411 1.17011 m .66184 1.17849 L .64627 1.193 L F
.467 .75193 m .46268 .74961 L .46502 .75103 L .4 0 0 r
F
.47128 .75556 m .47569 .75712 L .48051 .75986 L 0 .06 0 r
F
.47128 .75556 m .467 .75193 L .47837 .75806 L F
.46995 .75384 m .46502 .75103 L .47511 .75718 L .4 0 0 r
F
.467 .75193 m .46502 .75103 L .46995 .75384 L F
.48051 .75986 m .47837 .75806 L .48162 .76038 L 0 .06 0 r
F
.47569 .75712 m .47837 .75806 L .48051 .75986 L F
.54015 .78562 m .5436 .78321 L .55288 .78669 L .348 .377 0 r
F
.53163 .78247 m .5436 .78321 L .54015 .78562 L .318 .325 0 r
F
.52291 .77944 m .53399 .77993 L .53163 .78247 L .283 .269 0 r
F
.52291 .77944 m .52416 .7768 L .53399 .77993 L F
.46995 1.02271 m .46286 1.02333 L .45727 1.01981 L .354 .385 0 r
F
.47518 1.02573 m .46286 1.02333 L .46995 1.02271 L .339 .362 0 r
F
.58872 1.24785 m .59273 1.2493 L .57301 1.2637 L 1 .996 0 r
F
.60658 1.22532 m .59273 1.2493 L .58872 1.24785 L 1 1 0 r
F
.41482 1.00602 m .40024 .99941 L .41039 1.00048 L .483 .562 0 r
F
.42454 1.00671 m .41482 1.00602 L .41039 1.00048 L .454 .534 0 r
F
.53163 .78247 m .53399 .77993 L .5436 .78321 L .318 .325 0 r
F
.57643 1.07498 m .57443 1.07884 L .56838 1.07217 L .142 .082 0 r
F
.57643 1.07498 m .58339 1.08264 L .57443 1.07884 L F
.67095 .81738 m .68772 .82689 L .67729 .827 L .71 .712 0 r
F
.66092 .81798 m .67095 .81738 L .67729 .827 L .688 .698 0 r
F
.28977 1.27839 m .26047 1.26901 L .26886 1.2667 L .732 .789 0 r
F
.29743 1.27574 m .28977 1.27839 L .26886 1.2667 L .719 .782 0 r
F
.35198 .60271 m .36564 .58011 L .372 .58648 L 1 .882 0 r
F
.35198 .60271 m .34476 .59627 L .36564 .58011 L F
.36507 .98912 m .35101 .97903 L .36172 .98071 L .645 .658 0 r
F
.37553 .99028 m .36507 .98912 L .36172 .98071 L .616 .639 0 r
F
.19734 .95027 m .18652 .94956 L .18501 .92977 L .911 .809 0 r
F
.76737 1.17384 m .76113 1.19419 L .75215 1.18985 L 1 .822 0 r
F
.76737 1.17384 m .77697 1.17773 L .76113 1.19419 L F
.45223 1.01618 m .44365 1.01612 L .43859 1.01191 L .394 .449 0 r
F
.45727 1.01981 m .44365 1.01612 L .45223 1.01618 L .381 .431 0 r
F
.61762 .80545 m .63435 .81129 L .62487 .81199 L .568 .638 0 r
F
.60876 .80649 m .61762 .80545 L .62487 .81199 L .54 .616 0 r
F
.46919 1.2846 m .46698 1.28746 L .44559 1.28595 L .48 .559 0 r
F
.48995 1.2847 m .46698 1.28746 L .46919 1.2846 L .479 .52 0 r
F
.7191 .8258 m .73546 .83847 L .72472 .8384 L .799 .755 0 r
F
.70862 .82628 m .7191 .8258 L .72472 .8384 L .784 .745 0 r
F
.31775 .60674 m .33024 .58392 L .33751 .59003 L 1 .861 0 r
F
.31775 .60674 m .3097 .60089 L .33024 .58392 L F
.2739 .60781 m .2854 .58402 L .29352 .58955 L 1 .856 0 r
F
.2739 .60781 m .2651 .60271 L .2854 .58402 L F
.71601 1.17067 m .70969 1.19035 L .70131 1.18476 L 1 .788 0 r
F
.71601 1.17067 m .72508 1.1758 L .70969 1.19035 L F
.59295 .80211 m .60109 .80079 L .60876 .80649 L .487 .579 0 r
F
.58513 .79717 m .60109 .80079 L .59295 .80211 L .461 .562 0 r
F
.61741 1.19101 m .62347 1.20192 L .60658 1.22532 L 1 .739 0 r
F
.63241 1.17314 m .62347 1.20192 L .61741 1.19101 L 1 .668 0 r
F
.63241 1.17314 m .63936 1.18396 L .62347 1.20192 L F
.81095 .83652 m .82619 .85489 L .81527 .85479 L .896 .806 0 r
F
.80013 .83702 m .81095 .83652 L .81527 .85479 L .889 .801 0 r
F
.31894 .97498 m .30562 .96179 L .31647 .96355 L .763 .718 0 r
F
.32962 .97618 m .31894 .97498 L .31647 .96355 L .742 .705 0 r
F
.37833 .59301 m .39358 .57081 L .39898 .57688 L 1 .933 0 r
F
.37833 .59301 m .372 .58648 L .39358 .57081 L F
.62357 .52082 m .65361 .52285 L .64796 .52774 L .879 .865 0 r
F
.61895 .52591 m .62357 .52082 L .64796 .52774 L .862 .859 0 r
F
.19734 .95027 m .18501 .92977 L .19594 .93112 L .911 .809 0 r
F
.20816 .95105 m .19734 .95027 L .19594 .93112 L .905 .804 0 r
F
.57001 1.26311 m .57301 1.2637 L .55265 1.27338 L .6 .362 0 r
F
.58872 1.24785 m .57301 1.2637 L .57001 1.26311 L 1 .996 0 r
F
.50158 1.03452 m .4993 1.03687 L .49291 1.03422 L .279 .268 0 r
F
.50704 1.03674 m .4993 1.03687 L .50158 1.03452 L .266 .249 0 r
F
.50704 1.03674 m .50584 1.03944 L .4993 1.03687 L F
.60109 .80079 m .61762 .80545 L .60876 .80649 L .514 .605 0 r
F
.49624 1.03221 m .49291 1.03422 L .48671 1.03149 L .293 .288 0 r
F
.50158 1.03452 m .49291 1.03422 L .49624 1.03221 L .279 .268 0 r
F
.67603 1.16559 m .66954 1.18601 L .66184 1.17849 L 1 .73 0 r
F
.67603 1.16559 m .68448 1.17246 L .66954 1.18601 L F
.5908 .5263 m .59434 .52112 L .61895 .52591 L .853 .867 0 r
F
.56636 .52362 m .59434 .52112 L .5908 .5263 L .871 .887 0 r
F
.53837 1.05092 m .53521 1.05299 L .5321 1.04889 L .181 .141 0 r
F
.53837 1.05092 m .54252 1.0556 L .53521 1.05299 L F
.51257 1.03887 m .50584 1.03944 L .50704 1.03674 L .254 .231 0 r
F
.51257 1.03887 m .51245 1.04194 L .50584 1.03944 L F
.57007 .79443 m .57653 .79256 L .58513 .79717 L .426 .511 0 r
F
.56174 .79042 m .57653 .79256 L .57007 .79443 L .407 .479 0 r
F
.55067 1.27239 m .55265 1.27338 L .53188 1.27954 L .467 .216 0 r
F
.57001 1.26311 m .55265 1.27338 L .55067 1.27239 L .6 .362 0 r
F
.64386 .81041 m .66092 .81798 L .6509 .81843 L .644 .682 0 r
F
.63435 .81129 m .64386 .81041 L .6509 .81843 L .618 .663 0 r
F
.20816 .95105 m .19594 .93112 L .20686 .93254 L .905 .804 0 r
F
.21898 .95189 m .20816 .95105 L .20686 .93254 L .899 .798 0 r
F
.49445 .76723 m .50327 .76812 L .50428 .77057 L .084 .099 0 r
F
.49445 .76723 m .49232 .76455 L .50327 .76812 L F
.64635 1.16068 m .63936 1.18396 L .63241 1.17314 L 1 .653 0 r
F
.64635 1.16068 m .65411 1.17011 L .63936 1.18396 L F
.49107 1.02982 m .48671 1.03149 L .48078 1.02866 L .306 .308 0 r
F
.49624 1.03221 m .48671 1.03149 L .49107 1.02982 L .293 .288 0 r
F
.61509 1.11459 m .61133 1.12842 L .60431 1.11377 L .634 .371 0 r
F
.60728 1.10354 m .60431 1.11377 L .59732 1.10149 L .418 .279 0 r
F
.60728 1.10354 m .61509 1.11459 L .60431 1.11377 L F
.82178 .83597 m .83713 .85493 L .82619 .85489 L .902 .811 0 r
F
.81095 .83652 m .82178 .83597 L .82619 .85489 L .896 .806 0 r
F
.59434 .52112 m .62357 .52082 L .61895 .52591 L .874 .875 0 r
F
.53094 1.27797 m .53188 1.27954 L .51092 1.28312 L .428 .251 0 r
F
.55067 1.27239 m .53188 1.27954 L .53094 1.27797 L .467 .216 0 r
F
.40024 .99941 m .386 .99161 L .39649 .99313 L .534 .593 0 r
F
.41039 1.00048 m .40024 .99941 L .39649 .99313 L .501 .567 0 r
F
.62292 1.12645 m .61837 1.14454 L .61133 1.12842 L .862 .46 0 r
F
.61509 1.11459 m .62292 1.12645 L .61133 1.12842 L .634 .371 0 r
F
.61126 1.17475 m .60154 1.22036 L .59648 1.21538 L 1 .613 0 r
F
.61126 1.17475 m .61741 1.19101 L .60154 1.22036 L F
.62541 1.15997 m .61741 1.19101 L .61126 1.17475 L 1 .59 0 r
F
.61837 1.14454 m .62541 1.15997 L .61126 1.17475 L 1 .509 0 r
F
.54001 .52818 m .54129 .52299 L .56636 .52362 L .87 .901 0 r
F
.51576 .52974 m .54129 .52299 L .54001 .52818 L .915 .933 0 r
F
.5181 1.04089 m .51245 1.04194 L .51257 1.03887 L .243 .216 0 r
F
.5181 1.04089 m .51907 1.04436 L .51245 1.04194 L F
.21898 .95189 m .20686 .93254 L .21778 .93403 L .899 .798 0 r
F
.2298 .9528 m .21898 .95189 L .21778 .93403 L .891 .792 0 r
F
.32962 .97618 m .31647 .96355 L .32732 .96546 L .742 .705 0 r
F
.34031 .97753 m .32962 .97618 L .32732 .96546 L .719 .69 0 r
F
.42058 1.28605 m .39446 1.28471 L .39964 1.28168 L .558 .688 0 r
F
.4248 1.28301 m .42058 1.28605 L .39964 1.28168 L .525 .656 0 r
F
.44559 1.28595 m .42058 1.28605 L .4248 1.28301 L .514 .64 0 r
F
.46516 1.0196 m .45727 1.01981 L .45223 1.01618 L .366 .404 0 r
F
.46995 1.02271 m .45727 1.01981 L .46516 1.0196 L .354 .385 0 r
F
.7296 .82521 m .74621 .83844 L .73546 .83847 L .813 .764 0 r
F
.7191 .8258 m .7296 .82521 L .73546 .83847 L .799 .755 0 r
F
.39446 1.28471 m .36756 1.28177 L .37364 1.27885 L .598 .718 0 r
F
.39964 1.28168 m .39446 1.28471 L .37364 1.27885 L .57 .695 0 r
F
.61741 1.19101 m .60658 1.22532 L .60154 1.22036 L 1 .739 0 r
F
.62541 1.15997 m .63241 1.17314 L .61741 1.19101 L 1 .59 0 r
F
.59947 1.09356 m .59732 1.10149 L .59035 1.09132 L .329 .214 0 r
F
.59947 1.09356 m .60728 1.10354 L .59732 1.10149 L F
.69729 .51786 m .72929 .52557 L .72175 .52993 L .911 .857 0 r
F
.69064 .52262 m .69729 .51786 L .72175 .52993 L .902 .853 0 r
F
.75776 1.16981 m .75215 1.18985 L .74315 1.18536 L 1 .813 0 r
F
.75776 1.16981 m .76737 1.17384 L .75215 1.18985 L F
.48612 1.02735 m .48078 1.02866 L .47518 1.02573 L .319 .329 0 r
F
.49107 1.02982 m .48078 1.02866 L .48612 1.02735 L .306 .308 0 r
F
.37553 .99028 m .36172 .98071 L .37244 .98255 L .616 .639 0 r
F
.386 .99161 m .37553 .99028 L .37244 .98255 L .584 .617 0 r
F
.51103 1.28106 m .51092 1.28312 L .48995 1.2847 L .426 .333 0 r
F
.53094 1.27797 m .51092 1.28312 L .51103 1.28106 L .428 .251 0 r
F
.68101 .81664 m .69816 .82665 L .68772 .82689 L .73 .725 0 r
F
.67095 .81738 m .68101 .81664 L .68772 .82689 L .71 .712 0 r
F
.62292 1.12645 m .63074 1.13853 L .61837 1.14454 L .862 .46 0 r
F
.63074 1.13853 m .62541 1.15997 L .61837 1.14454 L 1 .534 0 r
F
.33332 1.2799 m .30511 1.27314 L .31281 1.27061 L .68 .764 0 r
F
.34022 1.2771 m .33332 1.2799 L .31281 1.27061 L .662 .753 0 r
F
.65929 .51786 m .69064 .52262 L .684 .5273 L .897 .861 0 r
F
.65361 .52285 m .65929 .51786 L .684 .5273 L .885 .857 0 r
F
.2298 .9528 m .21778 .93403 L .2287 .9356 L .891 .792 0 r
F
.24062 .95379 m .2298 .9528 L .2287 .9356 L .883 .785 0 r
F
.63856 1.15011 m .63241 1.17314 L .62541 1.15997 L 1 .596 0 r
F
.63856 1.15011 m .64635 1.16068 L .63241 1.17314 L F
.70693 1.16526 m .70131 1.18476 L .69291 1.17882 L 1 .769 0 r
F
.70693 1.16526 m .71601 1.17067 L .70131 1.18476 L F
.82178 .83597 m .83262 .83536 L .83713 .85493 L .902 .811 0 r
F
.60154 1.22036 m .60658 1.22532 L .58872 1.24785 L 1 1 0 r
F
.55623 1.05997 m .55468 1.06321 L .54955 1.05797 L .161 .114 0 r
F
.55623 1.05997 m .56231 1.06594 L .55468 1.06321 L F
.39898 .57688 m .41649 .55655 L .42087 .56209 L 1 1 0 r
F
.39898 .57688 m .39358 .57081 L .41649 .55655 L F
.45088 .73899 m .45832 .74992 L .46268 .74961 L .644 .029 0 r
F
.45088 .73899 m .44557 .7332 L .45832 .74992 L F
.52359 1.04279 m .51907 1.04436 L .5181 1.04089 L .234 .204 0 r
F
.52359 1.04279 m .52565 1.04668 L .51907 1.04436 L F
.63074 1.13853 m .63856 1.15011 L .62541 1.15997 L 1 .534 0 r
F
.2651 .60271 m .27725 .57855 L .2854 .58402 L 1 .861 0 r
F
.2651 .60271 m .25627 .59769 L .27725 .57855 L F
.66755 1.15813 m .66184 1.17849 L .65411 1.17011 L 1 .695 0 r
F
.66755 1.15813 m .67603 1.16559 L .66184 1.17849 L F
.3097 .60089 m .32295 .57792 L .33024 .58392 L 1 .869 0 r
F
.3097 .60089 m .30162 .59517 L .32295 .57792 L F
.56174 .79042 m .56725 .78829 L .57653 .79256 L .407 .479 0 r
F
.55288 .78669 m .56725 .78829 L .56174 .79042 L .383 .438 0 r
F
.24062 .95379 m .2287 .9356 L .23962 .93725 L .883 .785 0 r
F
.25145 .95486 m .24062 .95379 L .23962 .93725 L .873 .778 0 r
F
.34476 .59627 m .35926 .57385 L .36564 .58011 L 1 .891 0 r
F
.34476 .59627 m .33751 .59003 L .35926 .57385 L F
.56947 1.06799 m .56838 1.07217 L .56231 1.06594 L .173 .115 0 r
F
.56947 1.06799 m .57643 1.07498 L .56838 1.07217 L F
.44882 1.28303 m .44559 1.28595 L .4248 1.28301 L .484 .592 0 r
F
.46919 1.2846 m .44559 1.28595 L .44882 1.28303 L .48 .559 0 r
F
.42454 1.00671 m .41039 1.00048 L .42056 1.00175 L .454 .534 0 r
F
.43427 1.00759 m .42454 1.00671 L .42056 1.00175 L .43 .504 0 r
F
.43859 1.01191 m .42454 1.00671 L .43427 1.00759 L .421 .494 0 r
F
.44781 1.01246 m .43859 1.01191 L .43427 1.00759 L .404 .464 0 r
F
.45223 1.01618 m .43859 1.01191 L .44781 1.01246 L .394 .449 0 r
F
.48144 1.02481 m .47518 1.02573 L .46995 1.02271 L .331 .348 0 r
F
.48612 1.02735 m .47518 1.02573 L .48144 1.02481 L .319 .329 0 r
F
.51576 .52974 m .51588 .52458 L .54129 .52299 L .915 .933 0 r
F
.49145 .53368 m .51588 .52458 L .51576 .52974 L .987 .976 0 r
F
.34031 .97753 m .32732 .96546 L .33817 .96752 L .719 .69 0 r
F
.35101 .97903 m .34031 .97753 L .33817 .96752 L .693 .674 0 r
F
.36756 1.28177 m .34022 1.2771 L .34715 1.27438 L .632 .738 0 r
F
.37364 1.27885 m .36756 1.28177 L .34715 1.27438 L .609 .722 0 r
F
.50428 .77057 m .51434 .77132 L .51422 .77372 L .151 .11 0 r
F
.50428 .77057 m .50327 .76812 L .51434 .77132 L F
.58513 .79717 m .59248 .79545 L .60109 .80079 L .461 .562 0 r
F
.57653 .79256 m .59248 .79545 L .58513 .79717 L .44 .538 0 r
F
.59167 1.08463 m .59035 1.09132 L .58339 1.08264 L .278 .184 0 r
F
.59167 1.08463 m .59947 1.09356 L .59035 1.09132 L F
.29743 1.27574 m .26886 1.2667 L .27727 1.26444 L .719 .782 0 r
F
.30511 1.27314 m .29743 1.27574 L .27727 1.26444 L .705 .773 0 r
F
.62651 .80422 m .64386 .81041 L .63435 .81129 L .596 .66 0 r
F
.61762 .80545 m .62651 .80422 L .63435 .81129 L .568 .638 0 r
F
.49112 1.28228 m .48995 1.2847 L .46919 1.2846 L .435 .416 0 r
F
.51103 1.28106 m .48995 1.2847 L .49112 1.28228 L .426 .333 0 r
F
.74011 .82453 m .75697 .83832 L .74621 .83844 L .825 .772 0 r
F
.7296 .82521 m .74011 .82453 L .74621 .83844 L .813 .764 0 r
F
.5444 1.05272 m .54252 1.0556 L .53837 1.05092 L .189 .146 0 r
F
.5444 1.05272 m .54955 1.05797 L .54252 1.0556 L F
.42087 .56209 m .44044 .54453 L .44375 .54972 L 1 1 0 r
F
.42087 .56209 m .41649 .55655 L .44044 .54453 L F
.25145 .95486 m .23962 .93725 L .25053 .93899 L .873 .778 0 r
F
.26228 .95603 m .25145 .95486 L .25053 .93899 L .863 .77 0 r
F
.26047 1.26901 m .2521 1.27138 L .23208 1.25756 L .752 .794 0 r
F
.48162 .76038 m .49017 .7627 L .49232 .76455 L 0 .076 0 r
F
.48162 .76038 m .47837 .75806 L .49017 .7627 L F
.372 .58648 m .38817 .56473 L .39358 .57081 L 1 .938 0 r
F
.372 .58648 m .36564 .58011 L .38817 .56473 L F
.64386 .81041 m .65339 .80938 L .66092 .81798 L .644 .682 0 r
F
.65339 .80938 m .67095 .81738 L .66092 .81798 L .668 .698 0 r
F
.74812 1.16562 m .74315 1.18536 L .73412 1.18068 L 1 .802 0 r
F
.74812 1.16562 m .75776 1.16981 L .74315 1.18536 L F
.49145 .53368 m .49041 .52858 L .51588 .52458 L .987 .976 0 r
F
.46736 .54026 m .49041 .52858 L .49145 .53368 L 1 1 0 r
F
.52898 1.04454 m .52565 1.04668 L .52359 1.04279 L .228 .196 0 r
F
.52898 1.04454 m .5321 1.04889 L .52565 1.04668 L F
.41039 1.00048 m .39649 .99313 L .40699 .99484 L .501 .567 0 r
F
.42056 1.00175 m .41039 1.00048 L .40699 .99484 L .469 .54 0 r
F
.46084 1.01643 m .45223 1.01618 L .44781 1.01246 L .377 .421 0 r
F
.46516 1.0196 m .45223 1.01618 L .46084 1.01643 L .366 .404 0 r
F
.386 .99161 m .37244 .98255 L .38317 .98458 L .584 .617 0 r
F
.39649 .99313 m .386 .99161 L .38317 .98458 L .551 .594 0 r
F
.44375 .54972 m .46517 .53518 L .46736 .54026 L 1 1 0 r
F
.44375 .54972 m .44044 .54453 L .46517 .53518 L F
.56636 .52362 m .56879 .51831 L .59434 .52112 L .871 .887 0 r
F
.54129 .52299 m .56879 .51831 L .56636 .52362 L .9 .912 0 r
F
.69782 1.15953 m .69291 1.17882 L .68448 1.17246 L 1 .747 0 r
F
.69782 1.15953 m .70693 1.16526 L .69291 1.17882 L F
.26228 .95603 m .25053 .93899 L .26145 .94083 L .863 .77 0 r
F
.27311 .9573 m .26228 .95603 L .26145 .94083 L .851 .761 0 r
F
.55288 .78669 m .5574 .78438 L .56725 .78829 L .383 .438 0 r
F
.5436 .78321 m .5574 .78438 L .55288 .78669 L .354 .384 0 r
F
.46736 .54026 m .46517 .53518 L .49041 .52858 L 1 1 0 r
F
.65905 1.15003 m .65411 1.17011 L .64635 1.16068 L 1 .656 0 r
F
.65905 1.15003 m .66755 1.15813 L .65411 1.17011 L F
.69109 .81576 m .70862 .82628 L .69816 .82665 L .749 .737 0 r
F
.68101 .81664 m .69109 .81576 L .69816 .82665 L .73 .725 0 r
F
.60109 .80079 m .60926 .79928 L .61762 .80545 L .514 .605 0 r
F
.59248 .79545 m .60926 .79928 L .60109 .80079 L .487 .589 0 r
F
.467 .75193 m .47511 .75718 L .47837 .75806 L .4 0 0 r
F
.60926 .79928 m .62651 .80422 L .61762 .80545 L .543 .63 0 r
F
.47708 1.0222 m .46995 1.02271 L .46516 1.0196 L .343 .365 0 r
F
.48144 1.02481 m .46995 1.02271 L .47708 1.0222 L .331 .348 0 r
F
.35101 .97903 m .33817 .96752 L .34903 .96975 L .693 .674 0 r
F
.36172 .98071 m .35101 .97903 L .34903 .96975 L .665 .656 0 r
F
.51422 .77372 m .52541 .77437 L .52416 .7768 L .215 .168 0 r
F
.51422 .77372 m .51434 .77132 L .52541 .77437 L F
.81054 1.16737 m .80567 1.18872 L .79612 1.18515 L 1 .831 0 r
F
.81054 1.16737 m .82063 1.17045 L .80567 1.18872 L F
.62822 .51562 m .65929 .51786 L .65361 .52285 L .893 .87 0 r
F
.62357 .52082 m .62822 .51562 L .65361 .52285 L .879 .865 0 r
F
.27311 .9573 m .26145 .94083 L .27236 .94278 L .851 .761 0 r
F
.28394 .95867 m .27311 .9573 L .27236 .94278 L .837 .751 0 r
F
.75063 .82375 m .76774 .83811 L .75697 .83832 L .837 .779 0 r
F
.74011 .82453 m .75063 .82375 L .75697 .83832 L .825 .772 0 r
F
.58472 1.24896 m .58546 1.25051 L .57001 1.26311 L .709 .315 0 r
F
.58472 1.24896 m .57001 1.26311 L .56992 1.26315 L F
.57648 1.25611 m .56992 1.26315 L .567 1.26433 L F
.58472 1.24896 m .56992 1.26315 L .57648 1.25611 L F
.58075 1.25551 m .58472 1.24896 L .567 1.26433 L 0 0 0 r
F
.58394 1.24735 m .58472 1.24896 L .58075 1.25551 L 1 1 0 r
F
.59648 1.21538 m .58472 1.24896 L .58394 1.24735 L F
.60154 1.22036 m .58872 1.24785 L .58472 1.24896 L F
.59648 1.21538 m .60154 1.22036 L .58472 1.24896 L F
.59174 1.23873 m .59648 1.21538 L .58345 1.24862 L 0 0 0 r
F
.58472 1.24896 m .58872 1.24785 L .58546 1.25051 L .709 .315 0 r
F
.58955 1.24207 m .58345 1.24862 L .58075 1.25551 L 0 0 0 r
F
.59174 1.23873 m .58345 1.24862 L .58955 1.24207 L F
.5436 .78321 m .54706 .78079 L .5574 .78438 L .354 .384 0 r
F
.53399 .77993 m .54706 .78079 L .5436 .78321 L .317 .319 0 r
F
.58387 1.07658 m .58339 1.08264 L .57643 1.07498 L .254 .18 0 r
F
.58387 1.07658 m .59167 1.08463 L .58339 1.08264 L F
.47141 1.28197 m .46919 1.2846 L .44882 1.28303 L .447 .484 0 r
F
.49112 1.28228 m .46919 1.2846 L .47141 1.28197 L .435 .416 0 r
F
.52416 .7768 m .53636 .77749 L .53399 .77993 L .271 .244 0 r
F
.52416 .7768 m .52541 .77437 L .53636 .77749 L F
.65052 1.14125 m .64635 1.16068 L .63856 1.15011 L 1 .613 0 r
F
.65052 1.14125 m .65905 1.15003 L .64635 1.16068 L F
.30162 .59517 m .31563 .572 L .32295 .57792 L 1 .875 0 r
F
.30162 .59517 m .29352 .58955 L .31563 .572 L F
.53399 .77993 m .53636 .77749 L .54706 .78079 L .317 .319 0 r
F
.69729 .51786 m .70397 .51303 L .72929 .52557 L .911 .857 0 r
F
.73847 1.16126 m .73412 1.18068 L .72508 1.1758 L 1 .79 0 r
F
.73847 1.16126 m .74812 1.16562 L .73412 1.18068 L F
.59434 .52112 m .5979 .51581 L .62357 .52082 L .874 .875 0 r
F
.56879 .51831 m .5979 .51581 L .59434 .52112 L .894 .895 0 r
F
.28394 .95867 m .27236 .94278 L .28327 .94486 L .837 .751 0 r
F
.29478 .96017 m .28394 .95867 L .28327 .94486 L .822 .741 0 r
F
.53421 1.0461 m .5321 1.04889 L .52898 1.04454 L .227 .193 0 r
F
.53421 1.0461 m .53837 1.05092 L .5321 1.04889 L F
.57653 .79256 m .58302 .79052 L .59248 .79545 L .44 .538 0 r
F
.56725 .78829 m .58302 .79052 L .57653 .79256 L .421 .505 0 r
F
.33751 .59003 m .35286 .56766 L .35926 .57385 L 1 .898 0 r
F
.33751 .59003 m .33024 .58392 L .35286 .56766 L F
.5979 .51581 m .62822 .51562 L .62357 .52082 L .892 .882 0 r
F
.68869 1.15341 m .68448 1.17246 L .67603 1.16559 L 1 .723 0 r
F
.68869 1.15341 m .69782 1.15953 L .68448 1.17246 L F
.34022 1.2771 m .31281 1.27061 L .32053 1.26816 L .662 .753 0 r
F
.34715 1.27438 m .34022 1.2771 L .32053 1.26816 L .643 .74 0 r
F
.43427 1.00759 m .42056 1.00175 L .43075 1.00322 L .43 .504 0 r
F
.44404 1.00868 m .43427 1.00759 L .43075 1.00322 L .412 .474 0 r
F
.44781 1.01246 m .43427 1.00759 L .44404 1.00868 L .404 .464 0 r
F
.56249 1.06147 m .56231 1.06594 L .55623 1.05997 L .205 .154 0 r
F
.56249 1.06147 m .56947 1.06799 L .56231 1.06594 L F
.47308 1.01955 m .46516 1.0196 L .46084 1.01643 L .353 .381 0 r
F
.47708 1.0222 m .46516 1.0196 L .47308 1.01955 L .343 .365 0 r
F
.36172 .98071 m .34903 .96975 L .3599 .97216 L .665 .656 0 r
F
.37244 .98255 m .36172 .98071 L .3599 .97216 L .635 .637 0 r
F
.39649 .99313 m .38317 .98458 L .39391 .98679 L .551 .594 0 r
F
.40699 .99484 m .39649 .99313 L .39391 .98679 L .516 .569 0 r
F
.50387 1.032 m .50158 1.03452 L .49624 1.03221 L .292 .286 0 r
F
.50825 1.03382 m .50158 1.03452 L .50387 1.032 L .284 .274 0 r
F
.50825 1.03382 m .50704 1.03674 L .50158 1.03452 L F
.66498 .51279 m .69729 .51786 L .69064 .52262 L .907 .865 0 r
F
.65929 .51786 m .66498 .51279 L .69064 .52262 L .897 .861 0 r
F
.55013 1.05419 m .54955 1.05797 L .5444 1.05272 L .207 .163 0 r
F
.55013 1.05419 m .55623 1.05997 L .54955 1.05797 L F
.39358 .57081 m .41209 .55082 L .41649 .55655 L 1 1 0 r
F
.39358 .57081 m .38817 .56473 L .41209 .55082 L F
.44557 .7332 m .45388 .75585 L .45832 .74992 L .86 .072 0 r
F
.44557 .7332 m .44025 .72739 L .45388 .75585 L F
.39964 1.28168 m .37364 1.27885 L .37974 1.27604 L .57 .695 0 r
F
.40483 1.27878 m .39964 1.28168 L .37974 1.27604 L .541 .67 0 r
F
.4248 1.28301 m .39964 1.28168 L .40483 1.27878 L .525 .656 0 r
F
.49959 1.03009 m .49624 1.03221 L .49107 1.02982 L .3 .299 0 r
F
.50387 1.032 m .49624 1.03221 L .49959 1.03009 L .292 .286 0 r
F
.64198 1.13187 m .63856 1.15011 L .63074 1.13853 L .945 .567 0 r
F
.64198 1.13187 m .65052 1.14125 L .63856 1.15011 L F
.80044 1.1642 m .79612 1.18515 L .78656 1.18149 L 1 .825 0 r
F
.80044 1.1642 m .81054 1.16737 L .79612 1.18515 L F
.567 1.26433 m .57001 1.26311 L .56132 1.26728 L .343 .144 0 r
F
.57323 1.26109 m .567 1.26433 L .56399 1.26794 L 0 0 0 r
F
.58075 1.25551 m .567 1.26433 L .57323 1.26109 L F
.567 1.26433 m .56132 1.26728 L .55067 1.27239 L .343 .144 0 r
F
.42905 1.28013 m .4248 1.28301 L .40483 1.27878 L .493 .619 0 r
F
.44882 1.28303 m .4248 1.28301 L .42905 1.28013 L .484 .592 0 r
F
.51268 1.03555 m .50704 1.03674 L .50825 1.03382 L .276 .263 0 r
F
.51268 1.03555 m .51257 1.03887 L .50704 1.03674 L F
.66294 .80819 m .68101 .81664 L .67095 .81738 L .691 .713 0 r
F
.65339 .80938 m .66294 .80819 L .67095 .81738 L .668 .698 0 r
F
.70118 .81477 m .7191 .8258 L .70862 .82628 L .766 .748 0 r
F
.69109 .81576 m .70118 .81477 L .70862 .82628 L .749 .737 0 r
F
.29478 .96017 m .28327 .94486 L .29418 .94706 L .822 .741 0 r
F
.30562 .96179 m .29478 .96017 L .29418 .94706 L .806 .729 0 r
F
.76117 .82288 m .77853 .83782 L .76774 .83811 L .847 .786 0 r
F
.75063 .82375 m .76117 .82288 L .76774 .83811 L .837 .779 0 r
F
.63542 .80282 m .65339 .80938 L .64386 .81041 L .622 .679 0 r
F
.62651 .80422 m .63542 .80282 L .64386 .81041 L .596 .66 0 r
F
.45705 1.01321 m .44781 1.01246 L .44404 1.00868 L .387 .434 0 r
F
.46084 1.01643 m .44781 1.01246 L .45705 1.01321 L .377 .421 0 r
F
.26047 1.26901 m .23208 1.25756 L .24113 1.25563 L .752 .794 0 r
F
.26886 1.2667 m .26047 1.26901 L .24113 1.25563 L .741 .788 0 r
F
.49544 1.0281 m .49107 1.02982 L .48612 1.02735 L .309 .312 0 r
F
.49959 1.03009 m .49107 1.02982 L .49544 1.0281 L .3 .299 0 r
F
.54129 .52299 m .54258 .51761 L .56879 .51831 L .9 .912 0 r
F
.51588 .52458 m .54258 .51761 L .54129 .52299 L .947 .944 0 r
F
.42056 1.00175 m .40699 .99484 L .41752 .99674 L .469 .54 0 r
F
.43075 1.00322 m .42056 1.00175 L .41752 .99674 L .439 .511 0 r
F
.30511 1.27314 m .27727 1.26444 L .2857 1.26224 L .705 .773 0 r
F
.31281 1.27061 m .30511 1.27314 L .2857 1.26224 L .69 .764 0 r
F
.63342 1.1221 m .63074 1.13853 L .62292 1.12645 L .839 .517 0 r
F
.63342 1.1221 m .64198 1.13187 L .63074 1.13853 L F
.49232 .76455 m .50225 .76625 L .50327 .76812 L 0 .093 0 r
F
.49232 .76455 m .49017 .7627 L .50225 .76625 L F
.54868 1.27246 m .55067 1.27239 L .53094 1.27797 L .281 .14 0 r
F
.567 1.26433 m .55067 1.27239 L .54868 1.27246 L .343 .144 0 r
F
.62486 1.11224 m .62292 1.12645 L .61509 1.11459 L .704 .462 0 r
F
.62486 1.11224 m .63342 1.1221 L .62292 1.12645 L F
.51712 1.03717 m .51257 1.03887 L .51268 1.03555 L .27 .252 0 r
F
.51712 1.03717 m .5181 1.04089 L .51257 1.03887 L F
.36564 .58011 m .38274 .55862 L .38817 .56473 L 1 .941 0 r
F
.36564 .58011 m .35926 .57385 L .38274 .55862 L F
.53 1.27704 m .53094 1.27797 L .51103 1.28106 L .307 .144 0 r
F
.54868 1.27246 m .53094 1.27797 L .53 1.27704 L .281 .14 0 r
F
.49148 1.02605 m .48612 1.02735 L .48144 1.02481 L .317 .325 0 r
F
.49544 1.0281 m .48612 1.02735 L .49148 1.02605 L .309 .312 0 r
F
.6163 1.1026 m .61509 1.11459 L .60728 1.10354 L .557 .406 0 r
F
.6163 1.1026 m .62486 1.11224 L .61509 1.11459 L F
.37364 1.27885 m .34715 1.27438 L .3541 1.27174 L .609 .722 0 r
F
.37974 1.27604 m .37364 1.27885 L .3541 1.27174 L .584 .703 0 r
F
.30562 .96179 m .29418 .94706 L .30509 .9494 L .806 .729 0 r
F
.31647 .96355 m .30562 .96179 L .30509 .9494 L .787 .716 0 r
F
.72879 1.15669 m .72508 1.1758 L .71601 1.17067 L 1 .776 0 r
F
.72879 1.15669 m .73847 1.16126 L .72508 1.1758 L F
.57607 1.0692 m .57643 1.07498 L .56947 1.06799 L .249 .19 0 r
F
.57607 1.0692 m .58387 1.07658 L .57643 1.07498 L F
.67954 1.14688 m .67603 1.16559 L .66755 1.15813 L 1 .695 0 r
F
.67954 1.14688 m .68869 1.15341 L .67603 1.16559 L F
.51114 1.27943 m .51103 1.28106 L .49112 1.28228 L .347 .186 0 r
F
.53 1.27704 m .51103 1.28106 L .51114 1.27943 L .307 .144 0 r
F
.59248 .79545 m .59986 .79356 L .60926 .79928 L .487 .589 0 r
F
.58302 .79052 m .59986 .79356 L .59248 .79545 L .458 .567 0 r
F
.37244 .98255 m .3599 .97216 L .37077 .97474 L .635 .637 0 r
F
.38317 .98458 m .37244 .98255 L .37077 .97474 L .601 .615 0 r
F
.53924 1.04744 m .53837 1.05092 L .53421 1.0461 L .231 .196 0 r
F
.53924 1.04744 m .5444 1.05272 L .53837 1.05092 L F
.52152 1.03866 m .5181 1.04089 L .51712 1.03717 L .264 .244 0 r
F
.52152 1.03866 m .52359 1.04279 L .5181 1.04089 L F
.41649 .55655 m .43712 .53904 L .44044 .54453 L 1 1 0 r
F
.41649 .55655 m .41209 .55082 L .43712 .53904 L F
.45207 1.2803 m .44882 1.28303 L .42905 1.28013 L .459 .537 0 r
F
.47141 1.28197 m .44882 1.28303 L .45207 1.2803 L .447 .484 0 r
F
.79032 1.16093 m .78656 1.18149 L .77697 1.17773 L .999 .818 0 r
F
.79032 1.16093 m .80044 1.1642 L .78656 1.18149 L F
.56725 .78829 m .5728 .78602 L .58302 .79052 L .421 .505 0 r
F
.5574 .78438 m .5728 .78602 L .56725 .78829 L .397 .461 0 r
F
.60774 1.09343 m .60728 1.10354 L .59947 1.09356 L .431 .353 0 r
F
.60774 1.09343 m .6163 1.1026 L .60728 1.10354 L F
.77173 .82194 m .78933 .83745 L .77853 .83782 L .857 .792 0 r
F
.76117 .82288 m .77173 .82194 L .77853 .83782 L .847 .786 0 r
F
.46948 1.01685 m .46084 1.01643 L .45705 1.01321 L .362 .395 0 r
F
.47308 1.01955 m .46084 1.01643 L .46948 1.01685 L .353 .381 0 r
F
.48773 1.02395 m .48144 1.02481 L .47708 1.0222 L .326 .338 0 r
F
.49148 1.02605 m .48144 1.02481 L .48773 1.02395 L .317 .325 0 r
F
.61745 .79759 m .63542 .80282 L .62651 .80422 L .571 .653 0 r
F
.60926 .79928 m .61745 .79759 L .62651 .80422 L .543 .63 0 r
F
.51588 .52458 m .516 .51919 L .54258 .51761 L .947 .944 0 r
F
.49041 .52858 m .516 .51919 L .51588 .52458 L 1 .982 0 r
F
.29352 .58955 m .30829 .56614 L .31563 .572 L 1 .879 0 r
F
.29352 .58955 m .2854 .58402 L .30829 .56614 L F
.31647 .96355 m .30509 .9494 L .316 .95189 L .787 .716 0 r
F
.32732 .96546 m .31647 .96355 L .316 .95189 L .765 .702 0 r
F
.40699 .99484 m .39391 .98679 L .40467 .98918 L .516 .569 0 r
F
.41752 .99674 m .40699 .99484 L .40467 .98918 L .481 .542 0 r
F
.59986 .79356 m .61745 .79759 L .60926 .79928 L .514 .616 0 r
F
.7113 .81365 m .7296 .82521 L .7191 .8258 L .782 .758 0 r
F
.70118 .81477 m .7113 .81365 L .7191 .8258 L .766 .748 0 r
F
.49229 1.28019 m .49112 1.28228 L .47141 1.28197 L .381 .303 0 r
F
.51114 1.27943 m .49112 1.28228 L .49229 1.28019 L .347 .186 0 r
F
.44044 .54453 m .46298 .5298 L .46517 .53518 L 1 1 0 r
F
.44044 .54453 m .43712 .53904 L .46298 .5298 L F
.67036 1.1399 m .66755 1.15813 L .65905 1.15003 L .995 .664 0 r
F
.67036 1.1399 m .67954 1.14688 L .66755 1.15813 L F
.33024 .58392 m .34644 .56153 L .35286 .56766 L 1 .902 0 r
F
.33024 .58392 m .32295 .57792 L .34644 .56153 L F
.59918 1.08486 m .59947 1.09356 L .59167 1.08463 L .371 .311 0 r
F
.59918 1.08486 m .60774 1.09343 L .59947 1.09356 L F
.52584 1.04 m .52359 1.04279 L .52152 1.03866 L .261 .238 0 r
F
.52584 1.04 m .52898 1.04454 L .52359 1.04279 L F
.7191 1.15189 m .71601 1.17067 L .70693 1.16526 L 1 .759 0 r
F
.7191 1.15189 m .72879 1.15669 L .71601 1.17067 L F
.63288 .51031 m .66498 .51279 L .65929 .51786 L .906 .875 0 r
F
.62822 .51562 m .63288 .51031 L .65929 .51786 L .893 .87 0 r
F
.49041 .52858 m .48937 .5232 L .516 .51919 L 1 .982 0 r
F
.46517 .53518 m .48937 .5232 L .49041 .52858 L 1 1 0 r
F
.56879 .51831 m .57123 .51283 L .5979 .51581 L .894 .895 0 r
F
.54258 .51761 m .57123 .51283 L .56879 .51831 L .925 .92 0 r
F
.50327 .76812 m .51446 .76925 L .51434 .77132 L .097 .107 0 r
F
.50327 .76812 m .50225 .76625 L .51446 .76925 L F
.67251 .80686 m .69109 .81576 L .68101 .81664 L .712 .727 0 r
F
.66294 .80819 m .67251 .80686 L .68101 .81664 L .691 .713 0 r
F
.32732 .96546 m .316 .95189 L .32691 .95455 L .765 .702 0 r
F
.33817 .96752 m .32732 .96546 L .32691 .95455 L .741 .687 0 r
F
.48423 1.0218 m .47708 1.0222 L .47308 1.01955 L .334 .35 0 r
F
.48773 1.02395 m .47708 1.0222 L .48423 1.0218 L .326 .338 0 r
F
.46517 .53518 m .46298 .5298 L .48937 .5232 L 1 1 0 r
F
.48596 .76104 m .48801 .76184 L .49017 .7627 L .278 0 0 r
F
.48801 .76184 m .48584 .76201 L .49 .76261 L .172 0 0 r
F
.49017 .7627 m .48801 .76184 L .50123 .76494 L 0 .085 0 r
F
.48801 .76184 m .50019 .76408 L .50123 .76494 L .172 0 0 r
F
.48801 .76184 m .49 .76261 L .50019 .76408 L F
.47837 .75806 m .48801 .76184 L .48596 .76104 L .278 0 0 r
F
.47837 .75806 m .47511 .75718 L .48801 .76184 L F
.44404 1.00868 m .43075 1.00322 L .44096 1.00488 L .412 .474 0 r
F
.45383 1.00996 m .44404 1.00868 L .44096 1.00488 L .394 .444 0 r
F
.45705 1.01321 m .44404 1.00868 L .45383 1.00996 L .387 .434 0 r
F
.55549 1.05526 m .55623 1.05997 L .55013 1.05419 L .233 .192 0 r
F
.55549 1.05526 m .56249 1.06147 L .55623 1.05997 L F
.38317 .98458 m .37077 .97474 L .38165 .9775 L .601 .615 0 r
F
.39391 .98679 m .38317 .98458 L .38165 .9775 L .566 .592 0 r
F
.43075 1.00322 m .41752 .99674 L .42805 .99883 L .439 .511 0 r
F
.44096 1.00488 m .43075 1.00322 L .42805 .99883 L .418 .481 0 r
F
.78019 1.15756 m .77697 1.17773 L .76737 1.17384 L .997 .811 0 r
F
.78019 1.15756 m .79032 1.16093 L .77697 1.17773 L F
.7823 .82093 m .80013 .83702 L .78933 .83745 L .866 .798 0 r
F
.77173 .82194 m .7823 .82093 L .78933 .83745 L .857 .792 0 r
F
.26886 1.2667 m .24113 1.25563 L .25021 1.25375 L .741 .788 0 r
F
.27727 1.26444 m .26886 1.2667 L .25021 1.25375 L .73 .781 0 r
F
.5574 .78438 m .56193 .78197 L .5728 .78602 L .397 .461 0 r
F
.54706 .78079 m .56193 .78197 L .5574 .78438 L .365 .4 0 r
F
.63542 .80282 m .64436 .80125 L .65339 .80938 L .622 .679 0 r
F
.64436 .80125 m .66294 .80819 L .65339 .80938 L .648 .697 0 r
F
.34715 1.27438 m .32053 1.26816 L .32827 1.26578 L .643 .74 0 r
F
.3541 1.27174 m .34715 1.27438 L .32827 1.26578 L .622 .725 0 r
F
.46268 .74961 m .47181 .7583 L .47511 .75718 L .594 .004 0 r
F
.46268 .74961 m .45832 .74992 L .47181 .7583 L F
.56826 1.06235 m .56947 1.06799 L .56249 1.06147 L .255 .209 0 r
F
.56826 1.06235 m .57607 1.0692 L .56947 1.06799 L F
.66117 1.13247 m .65905 1.15003 L .65052 1.14125 L .95 .63 0 r
F
.66117 1.13247 m .67036 1.1399 L .65905 1.15003 L F
.54401 1.04851 m .5444 1.05272 L .53924 1.04744 L .241 .207 0 r
F
.54401 1.04851 m .55013 1.05419 L .5444 1.05272 L F
.38817 .56473 m .40769 .54493 L .41209 .55082 L 1 .991 0 r
F
.38817 .56473 m .38274 .55862 L .40769 .54493 L F
.44025 .72739 m .44932 .76996 L .45388 .75585 L 1 .101 0 r
F
.44025 .72739 m .43457 .74781 L .44932 .76996 L F
.31281 1.27061 m .2857 1.26224 L .29415 1.26011 L .69 .764 0 r
F
.32053 1.26816 m .31281 1.27061 L .29415 1.26011 L .674 .753 0 r
F
.6707 .50763 m .70397 .51303 L .69729 .51786 L .917 .868 0 r
F
.66498 .51279 m .6707 .50763 L .69729 .51786 L .907 .865 0 r
F
.46633 1.01414 m .45705 1.01321 L .45383 1.00996 L .37 .406 0 r
F
.46948 1.01685 m .45705 1.01321 L .46633 1.01414 L .362 .395 0 r
F
.33817 .96752 m .32691 .95455 L .33782 .95737 L .741 .687 0 r
F
.34903 .96975 m .33817 .96752 L .33782 .95737 L .715 .67 0 r
F
.59062 1.0769 m .59167 1.08463 L .58387 1.07658 L .335 .284 0 r
F
.59062 1.0769 m .59918 1.08486 L .59167 1.08463 L F
.5979 .51581 m .60147 .51036 L .62822 .51562 L .892 .882 0 r
F
.57123 .51283 m .60147 .51036 L .5979 .51581 L .913 .901 0 r
F
.60147 .51036 m .63288 .51031 L .62822 .51562 L .907 .887 0 r
F
.53003 1.04117 m .52898 1.04454 L .52584 1.04 L .26 .235 0 r
F
.53003 1.04117 m .53421 1.0461 L .52898 1.04454 L F
.35926 .57385 m .3773 .5525 L .38274 .55862 L 1 .941 0 r
F
.35926 .57385 m .35286 .56766 L .3773 .5525 L F
.47363 1.27959 m .47141 1.28197 L .45207 1.2803 L .409 .402 0 r
F
.49229 1.28019 m .47141 1.28197 L .47363 1.27959 L .381 .303 0 r
F
.51434 .77132 m .52668 .7721 L .52541 .77437 L .192 .132 0 r
F
.51434 .77132 m .51446 .76925 L .52668 .7721 L F
.48103 1.01963 m .47308 1.01955 L .46948 1.01685 L .341 .361 0 r
F
.48423 1.0218 m .47308 1.01955 L .48103 1.01963 L .334 .35 0 r
F
.70939 1.14683 m .70693 1.16526 L .69782 1.15953 L 1 .741 0 r
F
.70939 1.14683 m .7191 1.15189 L .70693 1.16526 L F
.58302 .79052 m .58952 .78832 L .59986 .79356 L .458 .567 0 r
F
.5728 .78602 m .58952 .78832 L .58302 .79052 L .437 .535 0 r
F
.41752 .99674 m .40467 .98918 L .41544 .99175 L .481 .542 0 r
F
.42805 .99883 m .41752 .99674 L .41544 .99175 L .448 .513 0 r
F
.72143 .81243 m .74011 .82453 L .7296 .82521 L .796 .767 0 r
F
.7113 .81365 m .72143 .81243 L .7296 .82521 L .782 .758 0 r
F
.54706 .78079 m .55054 .77833 L .56193 .78197 L .365 .4 0 r
F
.53636 .77749 m .55054 .77833 L .54706 .78079 L .323 .322 0 r
F
.40483 1.27878 m .37974 1.27604 L .38586 1.27334 L .541 .67 0 r
F
.41004 1.27601 m .40483 1.27878 L .38586 1.27334 L .51 .64 0 r
F
.42905 1.28013 m .40483 1.27878 L .41004 1.27601 L .493 .619 0 r
F
.79288 .81984 m .81095 .83652 L .80013 .83702 L .874 .804 0 r
F
.7823 .82093 m .79288 .81984 L .80013 .83702 L .866 .798 0 r
F
.2854 .58402 m .30093 .56033 L .30829 .56614 L 1 .883 0 r
F
.2854 .58402 m .27725 .57855 L .30093 .56033 L F
.77004 1.15406 m .76737 1.17384 L .75776 1.16981 L .994 .802 0 r
F
.77004 1.15406 m .78019 1.15756 L .76737 1.17384 L F
.65197 1.12462 m .65052 1.14125 L .64198 1.13187 L .891 .595 0 r
F
.65197 1.12462 m .66117 1.13247 L .65052 1.14125 L F
.39391 .98679 m .38165 .9775 L .39254 .98045 L .566 .592 0 r
F
.40467 .98918 m .39391 .98679 L .39254 .98045 L .529 .567 0 r
F
.4333 1.27741 m .42905 1.28013 L .41004 1.27601 L .47 .577 0 r
F
.45207 1.2803 m .42905 1.28013 L .4333 1.27741 L .459 .537 0 r
F
.52541 .77437 m .53875 .77508 L .53636 .77749 L .267 .226 0 r
F
.52541 .77437 m .52668 .7721 L .53875 .77508 L F
.34903 .96975 m .33782 .95737 L .34873 .96038 L .715 .67 0 r
F
.3599 .97216 m .34903 .96975 L .34873 .96038 L .685 .652 0 r
F
.53636 .77749 m .53875 .77508 L .55054 .77833 L .323 .322 0 r
F
.37974 1.27604 m .3541 1.27174 L .36107 1.26921 L .584 .703 0 r
F
.38586 1.27334 m .37974 1.27604 L .36107 1.26921 L .558 .681 0 r
F
.54258 .51761 m .54387 .51205 L .57123 .51283 L .925 .92 0 r
F
.516 .51919 m .54387 .51205 L .54258 .51761 L .972 .95 0 r
F
.62567 .79572 m .64436 .80125 L .63542 .80282 L .599 .674 0 r
F
.61745 .79759 m .62567 .79572 L .63542 .80282 L .571 .653 0 r
F
.50618 1.02934 m .50387 1.032 L .49959 1.03009 L .303 .301 0 r
F
.50947 1.03073 m .50387 1.032 L .50618 1.02934 L .298 .294 0 r
F
.50947 1.03073 m .50825 1.03382 L .50387 1.032 L F
.68211 .80539 m .70118 .81477 L .69109 .81576 L .732 .74 0 r
F
.67251 .80686 m .68211 .80539 L .69109 .81576 L .712 .727 0 r
F
.50296 1.02787 m .49959 1.03009 L .49544 1.0281 L .307 .308 0 r
F
.50618 1.02934 m .49959 1.03009 L .50296 1.02787 L .303 .301 0 r
F
.64275 1.11645 m .64198 1.13187 L .63342 1.1221 L .814 .557 0 r
F
.64275 1.11645 m .65197 1.12462 L .64198 1.13187 L F
.5128 1.03204 m .50825 1.03382 L .50947 1.03073 L .294 .287 0 r
F
.5128 1.03204 m .51268 1.03555 L .50825 1.03382 L F
.49984 1.02634 m .49544 1.0281 L .49148 1.02605 L .312 .315 0 r
F
.50296 1.02787 m .49544 1.0281 L .49984 1.02634 L .307 .308 0 r
F
.32295 .57792 m .34 .55543 L .34644 .56153 L 1 .905 0 r
F
.32295 .57792 m .31563 .572 L .34 .55543 L F
.69967 1.14149 m .69782 1.15953 L .68869 1.15341 L .987 .72 0 r
F
.69967 1.14149 m .70939 1.14683 L .69782 1.15953 L F
.58205 1.06949 m .58387 1.07658 L .57607 1.0692 L .313 .271 0 r
F
.58205 1.06949 m .59062 1.0769 L .58387 1.07658 L F
.53406 1.04215 m .53421 1.0461 L .53003 1.04117 L .262 .237 0 r
F
.53406 1.04215 m .53924 1.04744 L .53421 1.0461 L F
.59986 .79356 m .60726 .79148 L .61745 .79759 L .514 .616 0 r
F
.58952 .78832 m .60726 .79148 L .59986 .79356 L .484 .596 0 r
F
.47815 1.01743 m .46948 1.01685 L .46633 1.01414 L .349 .371 0 r
F
.48103 1.01963 m .46948 1.01685 L .47815 1.01743 L .341 .361 0 r
F
.41209 .55082 m .4338 .53332 L .43712 .53904 L 1 1 0 r
F
.41209 .55082 m .40769 .54493 L .4338 .53332 L F
.44096 1.00488 m .42805 .99883 L .43861 1.0011 L .418 .481 0 r
F
.4512 1.00673 m .44096 1.00488 L .43861 1.0011 L .4 .45 0 r
F
.45383 1.00996 m .44096 1.00488 L .4512 1.00673 L .394 .444 0 r
F
.63352 1.10809 m .63342 1.1221 L .62486 1.11224 L .722 .518 0 r
F
.63352 1.10809 m .64275 1.11645 L .63342 1.1221 L F
.51614 1.03325 m .51268 1.03555 L .5128 1.03204 L .29 .28 0 r
F
.51614 1.03325 m .51712 1.03717 L .51268 1.03555 L F
.3599 .97216 m .34873 .96038 L .35964 .96356 L .685 .652 0 r
F
.37077 .97474 m .3599 .97216 L .35964 .96356 L .652 .632 0 r
F
.49686 1.02476 m .49148 1.02605 L .48773 1.02395 L .317 .323 0 r
F
.49984 1.02634 m .49148 1.02605 L .49686 1.02476 L .312 .315 0 r
F
.80348 .81869 m .82178 .83597 L .81095 .83652 L .881 .808 0 r
F
.79288 .81984 m .80348 .81869 L .81095 .83652 L .874 .804 0 r
F
.60726 .79148 m .62567 .79572 L .61745 .79759 L .543 .641 0 r
F
.75987 1.15042 m .75776 1.16981 L .74812 1.16562 L .99 .792 0 r
F
.75987 1.15042 m .77004 1.15406 L .75776 1.16981 L F
.46364 1.01144 m .45383 1.00996 L .4512 1.00673 L .377 .414 0 r
F
.46633 1.01414 m .45383 1.00996 L .46364 1.01144 L .37 .406 0 r
F
.27727 1.26444 m .25021 1.25375 L .2593 1.25193 L .73 .781 0 r
F
.2857 1.26224 m .27727 1.26444 L .2593 1.25193 L .717 .773 0 r
F
.56043 1.05588 m .56249 1.06147 L .55549 1.05526 L .265 .231 0 r
F
.56043 1.05588 m .56826 1.06235 L .56249 1.06147 L F
.54848 1.04927 m .55013 1.05419 L .54401 1.04851 L .257 .227 0 r
F
.54848 1.04927 m .55549 1.05526 L .55013 1.05419 L F
.73159 .81111 m .75063 .82375 L .74011 .82453 L .81 .775 0 r
F
.72143 .81243 m .73159 .81111 L .74011 .82453 L .796 .767 0 r
F
.65332 .79952 m .67251 .80686 L .66294 .80819 L .672 .713 0 r
F
.64436 .80125 m .65332 .79952 L .66294 .80819 L .648 .697 0 r
F
.49017 .7627 m .50123 .76494 L .50225 .76625 L 0 .085 0 r
F
.56399 1.26794 m .567 1.26433 L .54868 1.27246 L .044 0 0 r
F
.40467 .98918 m .39254 .98045 L .40344 .98356 L .529 .567 0 r
F
.41544 .99175 m .40467 .98918 L .40344 .98356 L .491 .54 0 r
F
.62429 1.09973 m .62486 1.11224 L .6163 1.1026 L .619 .477 0 r
F
.62429 1.09973 m .63352 1.10809 L .62486 1.11224 L F
.42805 .99883 m .41544 .99175 L .42622 .99449 L .448 .513 0 r
F
.43861 1.0011 m .42805 .99883 L .42622 .99449 L .423 .483 0 r
F
.45534 1.27778 m .45207 1.2803 L .4333 1.27741 L .43 .476 0 r
F
.47363 1.27959 m .45207 1.2803 L .45534 1.27778 L .409 .402 0 r
F
.5728 .78602 m .57836 .7836 L .58952 .78832 L .437 .535 0 r
F
.56193 .78197 m .57836 .7836 L .5728 .78602 L .413 .49 0 r
F
.53414 1.27621 m .53348 1.27619 L .53 1.27704 L 0 0 0 r
F
.54669 1.27369 m .54868 1.27246 L .53348 1.27619 L F
.54669 1.27369 m .53348 1.27619 L .53414 1.27621 L F
.54669 1.27369 m .53 1.27704 L .52905 1.27679 L F
.53876 1.27637 m .52905 1.27679 L .5281 1.27715 L .167 0 0 r
F
.54469 1.27594 m .53755 1.27633 L .53876 1.27637 L F
.53755 1.27633 m .52905 1.27679 L .53876 1.27637 L F
.56399 1.26794 m .54868 1.27246 L .54669 1.27369 L .044 0 0 r
F
.19594 .93112 m .18501 .92977 L .18689 .90961 L .934 .811 0 r
F
.51944 1.03435 m .51712 1.03717 L .51614 1.03325 L .287 .275 0 r
F
.51944 1.03435 m .52152 1.03866 L .51712 1.03717 L F
.52905 1.27679 m .53 1.27704 L .51114 1.27943 L .158 .126 0 r
F
.49404 1.02313 m .48773 1.02395 L .48423 1.0218 L .322 .33 0 r
F
.49686 1.02476 m .48773 1.02395 L .49404 1.02313 L .317 .323 0 r
F
.19594 .93112 m .18689 .90961 L .19781 .91162 L .934 .811 0 r
F
.20686 .93254 m .19594 .93112 L .19781 .91162 L .929 .806 0 r
F
.20686 .93254 m .19781 .91162 L .20873 .91369 L F
.21778 .93403 m .20686 .93254 L .20873 .91369 L .923 .8 0 r
F
.516 .51919 m .51613 .51359 L .54387 .51205 L .972 .95 0 r
F
.48937 .5232 m .51613 .51359 L .516 .51919 L 1 .984 0 r
F
.63756 .5049 m .6707 .50763 L .66498 .51279 L .917 .878 0 r
F
.63288 .51031 m .63756 .5049 L .66498 .51279 L .906 .875 0 r
F
.21778 .93403 m .20873 .91369 L .21964 .91584 L .923 .8 0 r
F
.2287 .9356 m .21778 .93403 L .21964 .91584 L .916 .794 0 r
F
.68992 1.13582 m .68869 1.15341 L .67954 1.14688 L .964 .698 0 r
F
.68992 1.13582 m .69967 1.14149 L .68869 1.15341 L F
.51125 1.27825 m .51114 1.27943 L .49229 1.28019 L .252 .136 0 r
F
.52905 1.27679 m .51114 1.27943 L .51125 1.27825 L .158 .126 0 r
F
.2287 .9356 m .21964 .91584 L .23055 .91807 L .916 .794 0 r
F
.23962 .93725 m .2287 .9356 L .23055 .91807 L .908 .787 0 r
F
.43712 .53904 m .46078 .52416 L .46298 .5298 L 1 1 0 r
F
.43712 .53904 m .4338 .53332 L .46078 .52416 L F
.61506 1.09152 m .6163 1.1026 L .60774 1.09343 L .517 .436 0 r
F
.61506 1.09152 m .62429 1.09973 L .6163 1.1026 L F
.32053 1.26816 m .29415 1.26011 L .30262 1.25804 L .674 .753 0 r
F
.32827 1.26578 m .32053 1.26816 L .30262 1.25804 L .657 .742 0 r
F
.37077 .97474 m .35964 .96356 L .37055 .96694 L .652 .632 0 r
F
.38165 .9775 m .37077 .97474 L .37055 .96694 L .616 .61 0 r
F
.3541 1.27174 m .32827 1.26578 L .33603 1.26348 L .622 .725 0 r
F
.36107 1.26921 m .3541 1.27174 L .33603 1.26348 L .6 .709 0 r
F
.23962 .93725 m .23055 .91807 L .24145 .9204 L .908 .787 0 r
F
.25053 .93899 m .23962 .93725 L .24145 .9204 L .899 .779 0 r
F
.8141 .81749 m .83262 .83536 L .82178 .83597 L .888 .813 0 r
F
.80348 .81869 m .8141 .81749 L .82178 .83597 L .881 .808 0 r
F
.57123 .51283 m .57368 .50721 L .60147 .51036 L .913 .901 0 r
F
.54387 .51205 m .57368 .50721 L .57123 .51283 L .945 .925 0 r
F
.7497 1.14663 m .74812 1.16562 L .73847 1.16126 L .984 .781 0 r
F
.7497 1.14663 m .75987 1.15042 L .74812 1.16562 L F
.25053 .93899 m .24145 .9204 L .25234 .92282 L .899 .779 0 r
F
.26145 .94083 m .25053 .93899 L .25234 .92282 L .889 .77 0 r
F
.35286 .56766 m .37183 .54635 L .3773 .5525 L 1 .94 0 r
F
.35286 .56766 m .34644 .56153 L .37183 .54635 L F
.47563 1.01524 m .46633 1.01414 L .46364 1.01144 L .355 .38 0 r
F
.47815 1.01743 m .46633 1.01414 L .47563 1.01524 L .349 .371 0 r
F
.52269 1.03532 m .52152 1.03866 L .51944 1.03435 L .284 .271 0 r
F
.52269 1.03532 m .52584 1.04 L .52152 1.03866 L F
.53788 1.04292 m .53924 1.04744 L .53406 1.04215 L .268 .244 0 r
F
.53788 1.04292 m .54401 1.04851 L .53924 1.04744 L F
.38274 .55862 m .40326 .53893 L .40769 .54493 L 1 .984 0 r
F
.38274 .55862 m .3773 .5525 L .40326 .53893 L F
.57348 1.06256 m .57607 1.0692 L .56826 1.06235 L .301 .269 0 r
F
.57348 1.06256 m .58205 1.06949 L .57607 1.0692 L F
.49142 1.02148 m .48423 1.0218 L .48103 1.01963 L .327 .338 0 r
F
.49404 1.02313 m .48423 1.0218 L .49142 1.02148 L .322 .33 0 r
F
.48937 .5232 m .48833 .5176 L .51613 .51359 L 1 .984 0 r
F
.46298 .5298 m .48833 .5176 L .48937 .5232 L 1 1 0 r
F
.6707 .50763 m .67643 .50239 L .70397 .51303 L .917 .868 0 r
F
.46298 .5298 m .46078 .52416 L .48833 .5176 L 1 1 0 r
F
.26145 .94083 m .25234 .92282 L .26322 .92536 L .889 .77 0 r
F
.27236 .94278 m .26145 .94083 L .26322 .92536 L .878 .761 0 r
F
.69173 .8038 m .7113 .81365 L .70118 .81477 L .75 .751 0 r
F
.68211 .80539 m .69173 .8038 L .70118 .81477 L .732 .74 0 r
F
.49347 1.27843 m .49229 1.28019 L .47363 1.27959 L .319 .198 0 r
F
.51125 1.27825 m .49229 1.28019 L .49347 1.27843 L .252 .136 0 r
F
.60582 1.08361 m .60774 1.09343 L .59918 1.08486 L .432 .397 0 r
F
.60582 1.08361 m .61506 1.09152 L .60774 1.09343 L F
.27236 .94278 m .26322 .92536 L .2741 .92801 L .878 .761 0 r
F
.28327 .94486 m .27236 .94278 L .2741 .92801 L .865 .751 0 r
F
.68016 1.12983 m .67954 1.14688 L .67036 1.1399 L .935 .673 0 r
F
.68016 1.12983 m .68992 1.13582 L .67954 1.14688 L F
.24113 1.25563 m .23208 1.25756 L .21467 1.24251 L .764 .793 0 r
F
.74176 .8097 m .76117 .82288 L .75063 .82375 L .822 .783 0 r
F
.73159 .81111 m .74176 .8097 L .75063 .82375 L .81 .775 0 r
F
.41544 .99175 m .40344 .98356 L .41435 .98684 L .491 .54 0 r
F
.42622 .99449 m .41544 .99175 L .41435 .98684 L .455 .512 0 r
F
.28327 .94486 m .2741 .92801 L .28498 .9308 L .865 .751 0 r
F
.29418 .94706 m .28327 .94486 L .28498 .9308 L .85 .739 0 r
F
.38165 .9775 m .37055 .96694 L .38147 .97049 L .616 .61 0 r
F
.39254 .98045 m .38165 .9775 L .38147 .97049 L .578 .587 0 r
F
.60506 .5048 m .63756 .5049 L .63288 .51031 L .921 .89 0 r
F
.60147 .51036 m .60506 .5048 L .63288 .51031 L .907 .887 0 r
F
.56193 .78197 m .56649 .77942 L .57836 .7836 L .413 .49 0 r
F
.55054 .77833 m .56649 .77942 L .56193 .78197 L .381 .426 0 r
F
.57368 .50721 m .60506 .5048 L .60147 .51036 L .929 .906 0 r
F
.52584 1.03616 m .52584 1.04 L .52269 1.03532 L .283 .269 0 r
F
.52584 1.03616 m .53003 1.04117 L .52584 1.04 L F
.48902 1.01982 m .48103 1.01963 L .47815 1.01743 L .332 .345 0 r
F
.49142 1.02148 m .48103 1.01963 L .48902 1.01982 L .327 .338 0 r
F
.4512 1.00673 m .43861 1.0011 L .44919 1.00355 L .4 .45 0 r
F
.46146 1.00876 m .4512 1.00673 L .44919 1.00355 L .382 .42 0 r
F
.46364 1.01144 m .4512 1.00673 L .46146 1.00876 L .377 .414 0 r
F
.31563 .572 m .33353 .54936 L .34 .55543 L 1 .907 0 r
F
.31563 .572 m .30829 .56614 L .33353 .54936 L F
.62567 .79572 m .63391 .79369 L .64436 .80125 L .599 .674 0 r
F
.63391 .79369 m .65332 .79952 L .64436 .80125 L .626 .694 0 r
F
.50225 .76625 m .51459 .76745 L .51446 .76925 L .054 .106 0 r
F
.50225 .76625 m .50123 .76494 L .51459 .76745 L F
.29418 .94706 m .28498 .9308 L .29585 .93374 L .85 .739 0 r
F
.30509 .9494 m .29418 .94706 L .29585 .93374 L .833 .727 0 r
F
.8141 .81749 m .82473 .81623 L .83262 .83536 L .888 .813 0 r
F
.41004 1.27601 m .38586 1.27334 L .39199 1.27076 L .51 .64 0 r
F
.41527 1.27339 m .41004 1.27601 L .39199 1.27076 L .482 .607 0 r
F
.4333 1.27741 m .41004 1.27601 L .41527 1.27339 L .47 .577 0 r
F
.73951 1.14267 m .73847 1.16126 L .72879 1.15669 L .976 .768 0 r
F
.73951 1.14267 m .7497 1.14663 L .73847 1.16126 L F
.58952 .78832 m .59606 .78593 L .60726 .79148 L .484 .596 0 r
F
.57836 .7836 m .59606 .78593 L .58952 .78832 L .454 .567 0 r
F
.43861 1.0011 m .42622 .99449 L .43702 .9974 L .423 .483 0 r
F
.44919 1.00355 m .43861 1.0011 L .43702 .9974 L .404 .453 0 r
F
.59659 1.07605 m .59918 1.08486 L .59062 1.0769 L .388 .365 0 r
F
.59659 1.07605 m .60582 1.08361 L .59918 1.08486 L F
.5526 1.04969 m .55549 1.05526 L .54848 1.04927 L .277 .252 0 r
F
.5526 1.04969 m .56043 1.05588 L .55549 1.05526 L F
.47511 .75718 m .48584 .76201 L .48801 .76184 L .397 0 0 r
F
.47511 .75718 m .47181 .7583 L .48584 .76201 L F
.67039 1.1235 m .67036 1.1399 L .66117 1.13247 L .896 .646 0 r
F
.67039 1.1235 m .68016 1.12983 L .67036 1.1399 L F
.30509 .9494 m .29585 .93374 L .30671 .93683 L .833 .727 0 r
F
.316 .95189 m .30509 .9494 L .30671 .93683 L .813 .713 0 r
F
.2857 1.26224 m .2593 1.25193 L .26841 1.25017 L .717 .773 0 r
F
.29415 1.26011 m .2857 1.26224 L .26841 1.25017 L .703 .764 0 r
F
.38586 1.27334 m .36107 1.26921 L .36806 1.26678 L .558 .681 0 r
F
.39199 1.27076 m .38586 1.27334 L .36806 1.26678 L .531 .657 0 r
F
.6623 .79765 m .68211 .80539 L .67251 .80686 L .694 .728 0 r
F
.65332 .79952 m .6623 .79765 L .67251 .80686 L .672 .713 0 r
F
.47587 1.27747 m .47363 1.27959 L .45534 1.27778 L .365 .317 0 r
F
.49347 1.27843 m .47363 1.27959 L .47587 1.27747 L .319 .198 0 r
F
.47349 1.01308 m .46364 1.01144 L .46146 1.00876 L .36 .387 0 r
F
.47563 1.01524 m .46364 1.01144 L .47349 1.01308 L .355 .38 0 r
F
.43758 1.27487 m .4333 1.27741 L .41527 1.27339 L .447 .531 0 r
F
.45534 1.27778 m .4333 1.27741 L .43758 1.27487 L .43 .476 0 r
F
.54145 1.04344 m .54401 1.04851 L .53788 1.04292 L .277 .256 0 r
F
.54145 1.04344 m .54848 1.04927 L .54401 1.04851 L F
.56491 1.056 m .56826 1.06235 L .56043 1.05588 L .298 .274 0 r
F
.56491 1.056 m .57348 1.06256 L .56826 1.06235 L F
.316 .95189 m .30671 .93683 L .31757 .9401 L .813 .713 0 r
F
.32691 .95455 m .316 .95189 L .31757 .9401 L .791 .699 0 r
F
.82212 1.14921 m .82063 1.17045 L .81054 1.16737 L .969 .822 0 r
F
.82212 1.14921 m .83266 1.15176 L .82063 1.17045 L F
.39254 .98045 m .38147 .97049 L .3924 .97421 L .578 .587 0 r
F
.40344 .98356 m .39254 .98045 L .3924 .97421 L .538 .562 0 r
F
.55054 .77833 m .55404 .77578 L .56649 .77942 L .381 .426 0 r
F
.53875 .77508 m .55404 .77578 L .55054 .77833 L .337 .337 0 r
F
.45832 .74992 m .46848 .76172 L .47181 .7583 L .72 .024 0 r
F
.45832 .74992 m .45388 .75585 L .46848 .76172 L F
.48686 1.01815 m .47815 1.01743 L .47563 1.01524 L .337 .352 0 r
F
.48902 1.01982 m .47815 1.01743 L .48686 1.01815 L .332 .345 0 r
F
.52886 1.03684 m .53003 1.04117 L .52584 1.03616 L .284 .269 0 r
F
.52886 1.03684 m .53406 1.04215 L .53003 1.04117 L F
.61469 .78921 m .63391 .79369 L .62567 .79572 L .573 .665 0 r
F
.60726 .79148 m .61469 .78921 L .62567 .79572 L .543 .641 0 r
F
.6606 1.11685 m .66117 1.13247 L .65197 1.12462 L .848 .617 0 r
F
.6606 1.11685 m .67039 1.1235 L .66117 1.13247 L F
.59606 .78593 m .61469 .78921 L .60726 .79148 L .513 .625 0 r
F
.40769 .54493 m .43046 .52743 L .4338 .53332 L 1 1 0 r
F
.40769 .54493 m .40326 .53893 L .43046 .52743 L F
.54387 .51205 m .54517 .50632 L .57368 .50721 L .945 .925 0 r
F
.51613 .51359 m .54517 .50632 L .54387 .51205 L .99 .953 0 r
F
.7293 1.13852 m .72879 1.15669 L .7191 1.15189 L .965 .754 0 r
F
.7293 1.13852 m .73951 1.14267 L .72879 1.15669 L F
.51446 .76925 m .52794 .76992 L .52668 .7721 L .182 .119 0 r
F
.51446 .76925 m .51459 .76745 L .52794 .76992 L F
.58735 1.06889 m .59062 1.0769 L .58205 1.06949 L .36 .341 0 r
F
.58735 1.06889 m .59659 1.07605 L .59062 1.0769 L F
.42622 .99449 m .41435 .98684 L .42527 .99027 L .455 .512 0 r
F
.43702 .9974 m .42622 .99449 L .42527 .99027 L .425 .482 0 r
F
.75195 .80821 m .77173 .82194 L .76117 .82288 L .833 .789 0 r
F
.74176 .8097 m .75195 .80821 L .76117 .82288 L .822 .783 0 r
F
.32691 .95455 m .31757 .9401 L .32842 .94354 L .791 .699 0 r
F
.33782 .95737 m .32691 .95455 L .32842 .94354 L .766 .682 0 r
F
.70137 .80209 m .72143 .81243 L .7113 .81365 L .766 .761 0 r
F
.69173 .8038 m .70137 .80209 L .7113 .81365 L .75 .751 0 r
F
.53875 .77508 m .54114 .77264 L .55404 .77578 L .337 .337 0 r
F
.52668 .7721 m .54114 .77264 L .53875 .77508 L .274 .223 0 r
F
.32827 1.26578 m .30262 1.25804 L .31111 1.25606 L .657 .742 0 r
F
.33603 1.26348 m .32827 1.26578 L .31111 1.25606 L .638 .729 0 r
F
.50634 1.02557 m .50296 1.02787 L .49984 1.02634 L .313 .315 0 r
F
.50849 1.02657 m .50296 1.02787 L .50634 1.02557 L .311 .312 0 r
F
.50849 1.02657 m .50618 1.02934 L .50296 1.02787 L F
.51069 1.02751 m .50618 1.02934 L .50849 1.02657 L .308 .308 0 r
F
.51069 1.02751 m .50947 1.03073 L .50618 1.02934 L F
.52668 .7721 m .52794 .76992 L .54114 .77264 L .274 .223 0 r
F
.6508 1.10992 m .65197 1.12462 L .64275 1.11645 L .79 .586 0 r
F
.6508 1.10992 m .6606 1.11685 L .65197 1.12462 L F
.33782 .95737 m .32842 .94354 L .33927 .94718 L .766 .682 0 r
F
.34873 .96038 m .33782 .95737 L .33927 .94718 L .737 .665 0 r
F
.24113 1.25563 m .21467 1.24251 L .22434 1.24106 L .764 .793 0 r
F
.25021 1.25375 m .24113 1.25563 L .22434 1.24106 L .754 .787 0 r
F
.50426 1.02453 m .49984 1.02634 L .49686 1.02476 L .315 .319 0 r
F
.50634 1.02557 m .49984 1.02634 L .50426 1.02453 L .313 .315 0 r
F
.51292 1.02838 m .50947 1.03073 L .51069 1.02751 L .306 .304 0 r
F
.51292 1.02838 m .5128 1.03204 L .50947 1.03073 L F
.81156 1.14658 m .81054 1.16737 L .80044 1.1642 L .967 .816 0 r
F
.81156 1.14658 m .82212 1.14921 L .81054 1.16737 L F
.34644 .56153 m .36634 .54018 L .37183 .54635 L 1 .939 0 r
F
.34644 .56153 m .34 .55543 L .36634 .54018 L F
.64225 .4994 m .67643 .50239 L .6707 .50763 L .927 .881 0 r
F
.63756 .5049 m .64225 .4994 L .6707 .50763 L .917 .878 0 r
F
.36107 1.26921 m .33603 1.26348 L .34382 1.26128 L .6 .709 0 r
F
.36806 1.26678 m .36107 1.26921 L .34382 1.26128 L .577 .691 0 r
F
.40344 .98356 m .3924 .97421 L .40333 .97809 L .538 .562 0 r
F
.41435 .98684 m .40344 .98356 L .40333 .97809 L .498 .535 0 r
F
.50227 1.02345 m .49686 1.02476 L .49404 1.02313 L .317 .322 0 r
F
.50426 1.02453 m .49686 1.02476 L .50227 1.02345 L .315 .319 0 r
F
.51515 1.02919 m .5128 1.03204 L .51292 1.02838 L .304 .3 0 r
F
.51515 1.02919 m .51614 1.03325 L .5128 1.03204 L F
.48496 1.01649 m .47563 1.01524 L .47349 1.01308 L .341 .358 0 r
F
.48686 1.01815 m .47563 1.01524 L .48496 1.01649 L .337 .352 0 r
F
.44919 1.00355 m .43702 .9974 L .44784 1.00045 L .404 .453 0 r
F
.4598 1.00615 m .44919 1.00355 L .44784 1.00045 L .385 .423 0 r
F
.46146 1.00876 m .44919 1.00355 L .4598 1.00615 L .382 .42 0 r
F
.71908 1.13416 m .7191 1.15189 L .70939 1.14683 L .952 .738 0 r
F
.71908 1.13416 m .7293 1.13852 L .7191 1.15189 L F
.64099 1.10279 m .64275 1.11645 L .63352 1.10809 L .72 .555 0 r
F
.64099 1.10279 m .6508 1.10992 L .64275 1.11645 L F
.53173 1.03736 m .53406 1.04215 L .52886 1.03684 L .287 .273 0 r
F
.53173 1.03736 m .53788 1.04292 L .53406 1.04215 L F
.3773 .5525 m .39882 .53283 L .40326 .53893 L 1 .977 0 r
F
.3773 .5525 m .37183 .54635 L .39882 .53283 L F
.34873 .96038 m .33927 .94718 L .35012 .951 L .737 .665 0 r
F
.35964 .96356 m .34873 .96038 L .35012 .951 L .705 .646 0 r
F
.57836 .7836 m .58395 .78099 L .59606 .78593 L .454 .567 0 r
F
.56649 .77942 m .58395 .78099 L .57836 .7836 L .432 .524 0 r
F
.47174 1.01095 m .46146 1.00876 L .4598 1.00615 L .364 .392 0 r
F
.47349 1.01308 m .46146 1.00876 L .47174 1.01095 L .36 .387 0 r
F
.57811 1.06209 m .58205 1.06949 L .57348 1.06256 L .34 .325 0 r
F
.57811 1.06209 m .58735 1.06889 L .58205 1.06949 L F
.45861 1.27548 m .45534 1.27778 L .43758 1.27487 L .398 .412 0 r
F
.47587 1.27747 m .45534 1.27778 L .45861 1.27548 L .365 .317 0 r
F
.4338 .53332 m .45857 .51833 L .46078 .52416 L 1 1 0 r
F
.4338 .53332 m .43046 .52743 L .45857 .51833 L F
.50039 1.02235 m .49404 1.02313 L .49142 1.02148 L .32 .326 0 r
F
.50227 1.02345 m .49404 1.02313 L .50039 1.02235 L .317 .322 0 r
F
.51736 1.02991 m .51614 1.03325 L .51515 1.02919 L .302 .297 0 r
F
.51736 1.02991 m .51944 1.03435 L .51614 1.03325 L F
.51613 .51359 m .51626 .50781 L .54517 .50632 L .99 .953 0 r
F
.48833 .5176 m .51626 .50781 L .51613 .51359 L 1 .982 0 r
F
.30829 .56614 m .32705 .5433 L .33353 .54936 L 1 .908 0 r
F
.30829 .56614 m .30093 .56033 L .32705 .5433 L F
.54474 1.04371 m .54848 1.04927 L .54145 1.04344 L .289 .272 0 r
F
.54474 1.04371 m .5526 1.04969 L .54848 1.04927 L F
.55632 1.04974 m .56043 1.05588 L .5526 1.04969 L .299 .282 0 r
F
.55632 1.04974 m .56491 1.056 L .56043 1.05588 L F
.63118 1.09555 m .63352 1.10809 L .62429 1.09973 L .643 .522 0 r
F
.63118 1.09555 m .64099 1.10279 L .63352 1.10809 L F
.801 1.14386 m .80044 1.1642 L .79032 1.16093 L .964 .81 0 r
F
.801 1.14386 m .81156 1.14658 L .80044 1.1642 L F
.76216 .80663 m .7823 .82093 L .77173 .82194 L .843 .796 0 r
F
.75195 .80821 m .76216 .80663 L .77173 .82194 L .833 .789 0 r
F
.43702 .9974 m .42527 .99027 L .4362 .99383 L .425 .482 0 r
F
.44784 1.00045 m .43702 .9974 L .4362 .99383 L .406 .452 0 r
F
.64218 .79149 m .6623 .79765 L .65332 .79952 L .651 .712 0 r
F
.63391 .79369 m .64218 .79149 L .65332 .79952 L .626 .694 0 r
F
.35964 .96356 m .35012 .951 L .36096 .95503 L .705 .646 0 r
F
.37055 .96694 m .35964 .96356 L .36096 .95503 L .669 .625 0 r
F
.57368 .50721 m .57614 .50147 L .60506 .5048 L .929 .906 0 r
F
.54517 .50632 m .57614 .50147 L .57368 .50721 L .961 .928 0 r
F
.29415 1.26011 m .26841 1.25017 L .27754 1.24848 L .703 .764 0 r
F
.30262 1.25804 m .29415 1.26011 L .27754 1.24848 L .689 .755 0 r
F
.67131 .79564 m .69173 .8038 L .68211 .80539 L .715 .741 0 r
F
.6623 .79765 m .67131 .79564 L .68211 .80539 L .694 .728 0 r
F
.49863 1.02122 m .49142 1.02148 L .48902 1.01982 L .323 .33 0 r
F
.50039 1.02235 m .49142 1.02148 L .49863 1.02122 L .32 .326 0 r
F
.51952 1.03054 m .51944 1.03435 L .51736 1.02991 L .301 .295 0 r
F
.51952 1.03054 m .52269 1.03532 L .51944 1.03435 L F
.70884 1.12957 m .70939 1.14683 L .69967 1.14149 L .934 .721 0 r
F
.70884 1.12957 m .71908 1.13416 L .70939 1.14683 L F
.46078 .52416 m .48728 .51179 L .48833 .5176 L 1 1 0 r
F
.46078 .52416 m .45857 .51833 L .48728 .51179 L F
.62136 1.0883 m .62429 1.09973 L .61506 1.09152 L .563 .488 0 r
F
.62136 1.0883 m .63118 1.09555 L .62429 1.09973 L F
.41435 .98684 m .40333 .97809 L .41427 .98211 L .498 .535 0 r
F
.42527 .99027 m .41435 .98684 L .41427 .98211 L .459 .507 0 r
F
.48833 .5176 m .48728 .51179 L .51626 .50781 L 1 .982 0 r
F
.5281 1.27715 m .52905 1.27679 L .51367 1.27806 L 0 0 0 r
F
.5281 1.27715 m .51367 1.27806 L .51476 1.27802 L F
.51476 1.27802 m .51367 1.27806 L .51125 1.27825 L F
.5281 1.27715 m .51125 1.27825 L .51137 1.27749 L F
.52714 1.2779 m .5281 1.27715 L .51255 1.27747 L .112 0 0 r
F
.51338 1.27755 m .51255 1.27747 L .51137 1.27749 L F
.52714 1.2779 m .51255 1.27747 L .51338 1.27755 L F
.52419 1.27774 m .51137 1.27749 L .51148 1.27706 L F
.5227 1.27779 m .51137 1.27749 L .52419 1.27774 L F
.52714 1.2779 m .5227 1.27779 L .52419 1.27774 L F
.52618 1.27876 m .52714 1.2779 L .51148 1.27706 L .186 0 0 r
F
.52558 1.27868 m .51148 1.27706 L .5116 1.27681 L F
.52618 1.27876 m .5251 1.27863 L .52558 1.27868 L F
.5251 1.27863 m .51148 1.27706 L .52558 1.27868 L F
.54469 1.27594 m .54669 1.27369 L .52905 1.27679 L .167 0 0 r
F
.71103 .80027 m .73159 .81111 L .72143 .81243 L .782 .77 0 r
F
.70137 .80209 m .71103 .80027 L .72143 .81243 L .766 .761 0 r
F
.60865 .49913 m .64225 .4994 L .63756 .5049 L .932 .893 0 r
F
.60506 .5048 m .60865 .49913 L .63756 .5049 L .921 .89 0 r
F
.51137 1.27749 m .51125 1.27825 L .49347 1.27843 L .152 .124 0 r
F
.48336 1.01486 m .47349 1.01308 L .47174 1.01095 L .345 .363 0 r
F
.48496 1.01649 m .47349 1.01308 L .48336 1.01486 L .341 .358 0 r
F
.57683 1.27101 m .58075 1.25551 L .56399 1.26794 L .377 .009 0 r
F
.59174 1.23873 m .58075 1.25551 L .57683 1.27101 L 0 0 0 r
F
.53441 1.03771 m .53788 1.04292 L .53173 1.03736 L .292 .28 0 r
F
.53441 1.03771 m .54145 1.04344 L .53788 1.04292 L F
.37055 .96694 m .36096 .95503 L .3718 .95924 L .669 .625 0 r
F
.38147 .97049 m .37055 .96694 L .3718 .95924 L .63 .603 0 r
F
.61155 1.08116 m .61506 1.09152 L .60582 1.08361 L .487 .454 0 r
F
.61155 1.08116 m .62136 1.0883 L .61506 1.09152 L F
.49703 1.0201 m .48902 1.01982 L .48686 1.01815 L .325 .333 0 r
F
.49863 1.02122 m .48902 1.01982 L .49703 1.0201 L .323 .33 0 r
F
.56099 1.27389 m .54669 1.27369 L .54469 1.27594 L .313 0 0 r
F
.56099 1.27389 m .56399 1.26794 L .54669 1.27369 L F
.56886 1.05561 m .57348 1.06256 L .56491 1.056 L .328 .316 0 r
F
.56886 1.05561 m .57811 1.06209 L .57348 1.06256 L F
.52163 1.03108 m .52269 1.03532 L .51952 1.03054 L .3 .293 0 r
F
.52163 1.03108 m .52584 1.03616 L .52269 1.03532 L F
.57614 .50147 m .60865 .49913 L .60506 .5048 L .943 .909 0 r
F
.79043 1.14104 m .79032 1.16093 L .78019 1.15756 L .96 .802 0 r
F
.79043 1.14104 m .801 1.14386 L .79032 1.16093 L F
.41527 1.27339 m .39199 1.27076 L .39815 1.26832 L .482 .607 0 r
F
.42052 1.27093 m .41527 1.27339 L .39815 1.26832 L .461 .571 0 r
F
.43758 1.27487 m .41527 1.27339 L .42052 1.27093 L .447 .531 0 r
F
.25021 1.25375 m .22434 1.24106 L .23402 1.23967 L .754 .787 0 r
F
.2593 1.25193 m .25021 1.25375 L .23402 1.23967 L .743 .781 0 r
F
.59606 .78593 m .60262 .78336 L .61469 .78921 L .513 .625 0 r
F
.58395 .78099 m .60262 .78336 L .59606 .78593 L .479 .599 0 r
F
.6986 1.12473 m .69967 1.14149 L .68992 1.13582 L .913 .702 0 r
F
.6986 1.12473 m .70884 1.12957 L .69967 1.14149 L F
.49465 1.27698 m .49347 1.27843 L .47587 1.27747 L .251 .133 0 r
F
.51137 1.27749 m .49347 1.27843 L .49465 1.27698 L .152 .124 0 r
F
.39199 1.27076 m .36806 1.26678 L .37508 1.26447 L .531 .657 0 r
F
.39815 1.26832 m .39199 1.27076 L .37508 1.26447 L .503 .63 0 r
F
.57683 1.27101 m .56399 1.26794 L .56099 1.27389 L .377 .009 0 r
F
.56649 .77942 m .57107 .77671 L .58395 .78099 L .432 .524 0 r
F
.55404 .77578 m .57107 .77671 L .56649 .77942 L .402 .46 0 r
F
.4598 1.00615 m .44784 1.00045 L .45868 1.00364 L .385 .423 0 r
F
.47042 1.0089 m .4598 1.00615 L .45868 1.00364 L .367 .395 0 r
F
.47174 1.01095 m .4598 1.00615 L .47042 1.0089 L .364 .392 0 r
F
.60173 1.07419 m .60582 1.08361 L .59659 1.07605 L .425 .423 0 r
F
.60173 1.07419 m .61155 1.08116 L .60582 1.08361 L F
.61469 .78921 m .62215 .78678 L .63391 .79369 L .573 .665 0 r
F
.62215 .78678 m .64218 .79149 L .63391 .79369 L .601 .688 0 r
F
.38147 .97049 m .3718 .95924 L .38265 .96364 L .63 .603 0 r
F
.3924 .97421 m .38147 .97049 L .38265 .96364 L .587 .578 0 r
F
.42527 .99027 m .41427 .98211 L .42521 .98624 L .459 .507 0 r
F
.4362 .99383 m .42527 .99027 L .42521 .98624 L .425 .478 0 r
F
.77239 .80498 m .79288 .81984 L .7823 .82093 L .852 .801 0 r
F
.76216 .80663 m .77239 .80498 L .7823 .82093 L .843 .796 0 r
F
.49559 1.01897 m .48686 1.01815 L .48496 1.01649 L .328 .337 0 r
F
.49703 1.0201 m .48686 1.01815 L .49559 1.01897 L .325 .333 0 r
F
.33603 1.26348 m .31111 1.25606 L .31963 1.25415 L .638 .729 0 r
F
.34382 1.26128 m .33603 1.26348 L .31963 1.25415 L .618 .715 0 r
F
.44784 1.00045 m .4362 .99383 L .44715 .9975 L .406 .452 0 r
F
.45868 1.00364 m .44784 1.00045 L .44715 .9975 L .386 .423 0 r
F
.52364 1.03152 m .52584 1.03616 L .52163 1.03108 L .3 .293 0 r
F
.52364 1.03152 m .52886 1.03684 L .52584 1.03616 L F
.40326 .53893 m .4271 .52139 L .43046 .52743 L 1 1 0 r
F
.40326 .53893 m .39882 .53283 L .4271 .52139 L F
.54771 1.04372 m .5526 1.04969 L .54474 1.04371 L .303 .291 0 r
F
.54771 1.04372 m .55632 1.04974 L .5526 1.04969 L F
.60262 .78336 m .62215 .78678 L .61469 .78921 L .543 .652 0 r
F
.77984 1.13811 m .78019 1.15756 L .77004 1.15406 L .955 .794 0 r
F
.77984 1.13811 m .79043 1.14104 L .78019 1.15756 L F
.68834 1.11963 m .68992 1.13582 L .68016 1.12983 L .886 .681 0 r
F
.68834 1.11963 m .6986 1.12473 L .68992 1.13582 L F
.34 .55543 m .36084 .53399 L .36634 .54018 L 1 .937 0 r
F
.34 .55543 m .33353 .54936 L .36084 .53399 L F
.44187 1.27252 m .43758 1.27487 L .42052 1.27093 L .422 .481 0 r
F
.45861 1.27548 m .43758 1.27487 L .44187 1.27252 L .398 .412 0 r
F
.48205 1.01328 m .47174 1.01095 L .47042 1.0089 L .348 .367 0 r
F
.48336 1.01486 m .47174 1.01095 L .48205 1.01328 L .345 .363 0 r
F
.5919 1.06746 m .59659 1.07605 L .58735 1.06889 L .393 .394 0 r
F
.5919 1.06746 m .60173 1.07419 L .59659 1.07605 L F
.53687 1.03788 m .54145 1.04344 L .53441 1.03771 L .299 .289 0 r
F
.53687 1.03788 m .54474 1.04371 L .54145 1.04344 L F
.3924 .97421 m .38265 .96364 L .3935 .96819 L .587 .578 0 r
F
.40333 .97809 m .3924 .97421 L .3935 .96819 L .543 .553 0 r
F
.47811 1.27561 m .47587 1.27747 L .45861 1.27548 L .318 .238 0 r
F
.49465 1.27698 m .47587 1.27747 L .47811 1.27561 L .251 .133 0 r
F
.5596 1.04942 m .56491 1.056 L .55632 1.04974 L .32 .312 0 r
F
.5596 1.04942 m .56886 1.05561 L .56491 1.056 L F
.54517 .50632 m .54647 .50045 L .57614 .50147 L .961 .928 0 r
F
.51626 .50781 m .54647 .50045 L .54517 .50632 L 1 .953 0 r
F
.36806 1.26678 m .34382 1.26128 L .35163 1.25918 L .577 .691 0 r
F
.37508 1.26447 m .36806 1.26678 L .35163 1.25918 L .552 .67 0 r
F
.50123 .76494 m .51471 .7658 L .51459 .76745 L .04 .107 0 r
F
.50123 .76494 m .50019 .76408 L .51471 .7658 L F
.49433 1.01786 m .48496 1.01649 L .48336 1.01486 L .331 .341 0 r
F
.49559 1.01897 m .48496 1.01649 L .49433 1.01786 L .328 .337 0 r
F
.64225 .4994 m .64696 .49382 L .67643 .50239 L .927 .881 0 r
F
.72071 .79835 m .74176 .8097 L .73159 .81111 L .796 .779 0 r
F
.71103 .80027 m .72071 .79835 L .73159 .81111 L .782 .77 0 r
F
.52556 1.03184 m .52886 1.03684 L .52364 1.03152 L .301 .294 0 r
F
.52556 1.03184 m .53173 1.03736 L .52886 1.03684 L F
.37183 .54635 m .39437 .52666 L .39882 .53283 L 1 .97 0 r
F
.37183 .54635 m .36634 .54018 L .39437 .52666 L F
.68034 .7935 m .70137 .80209 L .69173 .8038 L .734 .753 0 r
F
.67131 .79564 m .68034 .7935 L .69173 .8038 L .715 .741 0 r
F
.67806 1.11426 m .68016 1.12983 L .67039 1.1235 L .853 .658 0 r
F
.67806 1.11426 m .68834 1.11963 L .68016 1.12983 L F
.55404 .77578 m .55756 .77308 L .57107 .77671 L .402 .46 0 r
F
.54114 .77264 m .55756 .77308 L .55404 .77578 L .359 .368 0 r
F
.30262 1.25804 m .27754 1.24848 L .28669 1.24686 L .689 .755 0 r
F
.31111 1.25606 m .30262 1.25804 L .28669 1.24686 L .673 .744 0 r
F
.76925 1.13507 m .77004 1.15406 L .75987 1.15042 L .949 .785 0 r
F
.76925 1.13507 m .77984 1.13811 L .77004 1.15406 L F
.4362 .99383 m .42521 .98624 L .43617 .99046 L .425 .478 0 r
F
.44715 .9975 m .4362 .99383 L .43617 .99046 L .405 .448 0 r
F
.65047 .78913 m .67131 .79564 L .6623 .79765 L .675 .728 0 r
F
.64218 .79149 m .65047 .78913 L .6623 .79765 L .651 .712 0 r
F
.58208 1.06097 m .58735 1.06889 L .57811 1.06209 L .37 .371 0 r
F
.58208 1.06097 m .5919 1.06746 L .58735 1.06889 L F
.40333 .97809 m .3935 .96819 L .40435 .97286 L .543 .553 0 r
F
.41427 .98211 m .40333 .97809 L .40435 .97286 L .499 .526 0 r
F
.78263 .80326 m .80348 .81869 L .79288 .81984 L .861 .807 0 r
F
.77239 .80498 m .78263 .80326 L .79288 .81984 L .852 .801 0 r
F
.47181 .7583 m .48364 .76296 L .48584 .76201 L .412 0 0 r
F
.47181 .7583 m .46848 .76172 L .48364 .76296 L F
.66778 1.10863 m .67039 1.1235 L .6606 1.11685 L .813 .634 0 r
F
.66778 1.10863 m .67806 1.11426 L .67039 1.1235 L F
.50974 1.02321 m .50634 1.02557 L .50426 1.02453 L .317 .32 0 r
F
.51082 1.02371 m .50634 1.02557 L .50974 1.02321 L .316 .319 0 r
F
.51082 1.02371 m .50849 1.02657 L .50634 1.02557 L F
.51192 1.02418 m .50849 1.02657 L .51082 1.02371 L .315 .317 0 r
F
.51192 1.02418 m .51069 1.02751 L .50849 1.02657 L F
.2593 1.25193 m .23402 1.23967 L .24371 1.23833 L .743 .781 0 r
F
.26841 1.25017 m .2593 1.25193 L .24371 1.23833 L .731 .773 0 r
F
.43046 .52743 m .45635 .51233 L .45857 .51833 L 1 1 0 r
F
.43046 .52743 m .4271 .52139 L .45635 .51233 L F
.45868 1.00364 m .44715 .9975 L .45811 1.00126 L .386 .423 0 r
F
.46953 1.00694 m .45868 1.00364 L .45811 1.00126 L .368 .395 0 r
F
.47042 1.0089 m .45868 1.00364 L .46953 1.00694 L .367 .395 0 r
F
.5087 1.02268 m .50426 1.02453 L .50227 1.02345 L .317 .321 0 r
F
.50974 1.02321 m .50426 1.02453 L .5087 1.02268 L .317 .32 0 r
F
.51304 1.02462 m .51069 1.02751 L .51192 1.02418 L .314 .315 0 r
F
.51304 1.02462 m .51292 1.02838 L .51069 1.02751 L F
.51459 .76745 m .52922 .76772 L .52794 .76992 L .194 .123 0 r
F
.51459 .76745 m .51471 .7658 L .52922 .76772 L F
.49326 1.01677 m .48336 1.01486 L .48205 1.01328 L .333 .344 0 r
F
.49433 1.01786 m .48336 1.01486 L .49326 1.01677 L .331 .341 0 r
F
.54114 .77264 m .54355 .77011 L .55756 .77308 L .359 .368 0 r
F
.52794 .76992 m .54355 .77011 L .54114 .77264 L .294 .238 0 r
F
.48107 1.01176 m .47042 1.0089 L .46953 1.00694 L .35 .369 0 r
F
.48205 1.01328 m .47042 1.0089 L .48107 1.01176 L .348 .367 0 r
F
.5077 1.02213 m .50227 1.02345 L .50039 1.02235 L .318 .322 0 r
F
.5087 1.02268 m .50227 1.02345 L .5077 1.02213 L .317 .321 0 r
F
.51416 1.02503 m .51292 1.02838 L .51304 1.02462 L .313 .314 0 r
F
.51416 1.02503 m .51515 1.02919 L .51292 1.02838 L F
.75864 1.13189 m .75987 1.15042 L .7497 1.14663 L .942 .775 0 r
F
.75864 1.13189 m .76925 1.13507 L .75987 1.15042 L F
.52734 1.03205 m .53173 1.03736 L .52556 1.03184 L .304 .298 0 r
F
.52734 1.03205 m .53441 1.03771 L .53173 1.03736 L F
.58395 .78099 m .58956 .77821 L .60262 .78336 L .479 .599 0 r
F
.57107 .77671 m .58956 .77821 L .58395 .78099 L .452 .561 0 r
F
.65749 1.10275 m .6606 1.11685 L .6508 1.10992 L .765 .608 0 r
F
.65749 1.10275 m .66778 1.10863 L .6606 1.11685 L F
.51626 .50781 m .51638 .50187 L .54647 .50045 L 1 .953 0 r
F
.48728 .51179 m .51638 .50187 L .51626 .50781 L 1 .979 0 r
F
.52794 .76992 m .52922 .76772 L .54355 .77011 L .294 .238 0 r
F
.5391 1.03786 m .54474 1.04371 L .53687 1.03788 L .307 .301 0 r
F
.5391 1.03786 m .54771 1.04372 L .54474 1.04371 L F
.50676 1.02157 m .50039 1.02235 L .49863 1.02122 L .319 .323 0 r
F
.5077 1.02213 m .50039 1.02235 L .50676 1.02157 L .318 .322 0 r
F
.55034 1.04345 m .55632 1.04974 L .54771 1.04372 L .317 .312 0 r
F
.55034 1.04345 m .5596 1.04942 L .55632 1.04974 L F
.57225 1.05473 m .57811 1.06209 L .56886 1.05561 L .352 .353 0 r
F
.57225 1.05473 m .58208 1.06097 L .57811 1.06209 L F
.51526 1.02538 m .51515 1.02919 L .51416 1.02503 L .312 .312 0 r
F
.51526 1.02538 m .51736 1.02991 L .51515 1.02919 L F
.4619 1.2734 m .45861 1.27548 L .44187 1.27252 L .363 .347 0 r
F
.47811 1.27561 m .45861 1.27548 L .4619 1.2734 L .318 .238 0 r
F
.41427 .98211 m .40435 .97286 L .4152 .97764 L .499 .526 0 r
F
.42521 .98624 m .41427 .98211 L .4152 .97764 L .457 .497 0 r
F
.57614 .50147 m .57861 .4956 L .60865 .49913 L .943 .909 0 r
F
.54647 .50045 m .57861 .4956 L .57614 .50147 L .974 .93 0 r
F
.64719 1.09667 m .6508 1.10992 L .64099 1.10279 L .711 .581 0 r
F
.64719 1.09667 m .65749 1.10275 L .6508 1.10992 L F
.44715 .9975 m .43617 .99046 L .44713 .99474 L .405 .448 0 r
F
.45811 1.00126 m .44715 .9975 L .44713 .99474 L .386 .419 0 r
F
.50588 1.02101 m .49863 1.02122 L .49703 1.0201 L .32 .324 0 r
F
.50676 1.02157 m .49863 1.02122 L .50588 1.02101 L .319 .323 0 r
F
.45857 .51833 m .48623 .50581 L .48728 .51179 L 1 1 0 r
F
.45857 .51833 m .45635 .51233 L .48623 .50581 L F
.51635 1.0257 m .51736 1.02991 L .51526 1.02538 L .311 .31 0 r
F
.51635 1.0257 m .51952 1.03054 L .51736 1.02991 L F
.61227 .49335 m .64696 .49382 L .64225 .4994 L .943 .896 0 r
F
.60865 .49913 m .61227 .49335 L .64225 .4994 L .932 .893 0 r
F
.29585 .93374 m .28907 .91659 L .29978 .92029 L .881 .738 0 r
F
.29585 .93374 m .28498 .9308 L .28907 .91659 L F
.30671 .93683 m .29585 .93374 L .29978 .92029 L .863 .725 0 r
F
.28498 .9308 m .27835 .91307 L .28907 .91659 L .896 .751 0 r
F
.28498 .9308 m .2741 .92801 L .27835 .91307 L F
.30671 .93683 m .29978 .92029 L .31048 .92416 L .863 .725 0 r
F
.31757 .9401 m .30671 .93683 L .31048 .92416 L .843 .71 0 r
F
.48728 .51179 m .48623 .50581 L .51638 .50187 L 1 .979 0 r
F
.2741 .92801 m .26762 .90969 L .27835 .91307 L .909 .762 0 r
F
.2741 .92801 m .26322 .92536 L .26762 .90969 L F
.74802 1.12857 m .7497 1.14663 L .73951 1.14267 L .933 .764 0 r
F
.74802 1.12857 m .75864 1.13189 L .7497 1.14663 L F
.31757 .9401 m .31048 .92416 L .32117 .92824 L .843 .71 0 r
F
.32842 .94354 m .31757 .9401 L .32117 .92824 L .819 .694 0 r
F
.63689 1.09043 m .64099 1.10279 L .63118 1.09555 L .65 .553 0 r
F
.63689 1.09043 m .64719 1.09667 L .64099 1.10279 L F
.26322 .92536 m .25688 .90646 L .26762 .90969 L .92 .772 0 r
F
.26322 .92536 m .25234 .92282 L .25688 .90646 L F
.49239 1.01572 m .48205 1.01328 L .48107 1.01176 L .335 .347 0 r
F
.49326 1.01677 m .48205 1.01328 L .49239 1.01572 L .333 .344 0 r
F
.32842 .94354 m .32117 .92824 L .33186 .93252 L .819 .694 0 r
F
.33927 .94718 m .32842 .94354 L .33186 .93252 L .792 .676 0 r
F
.73042 .79634 m .75195 .80821 L .74176 .8097 L .808 .786 0 r
F
.72071 .79835 m .73042 .79634 L .74176 .8097 L .796 .779 0 r
F
.62963 .78417 m .65047 .78913 L .64218 .79149 L .629 .708 0 r
F
.62215 .78678 m .62963 .78417 L .64218 .79149 L .601 .688 0 r
F
.34382 1.26128 m .31963 1.25415 L .32816 1.25234 L .618 .715 0 r
F
.35163 1.25918 m .34382 1.26128 L .32816 1.25234 L .596 .699 0 r
F
.50508 1.02044 m .49703 1.0201 L .49559 1.01897 L .321 .326 0 r
F
.50588 1.02101 m .49703 1.0201 L .50508 1.02044 L .32 .324 0 r
F
.25234 .92282 m .24613 .90335 L .25688 .90646 L .929 .781 0 r
F
.25234 .92282 m .24145 .9204 L .24613 .90335 L F
.5174 1.02596 m .51952 1.03054 L .51635 1.0257 L .311 .309 0 r
F
.5174 1.02596 m .52163 1.03108 L .51952 1.03054 L F
.52899 1.03214 m .53441 1.03771 L .52734 1.03205 L .307 .303 0 r
F
.52899 1.03214 m .53687 1.03788 L .53441 1.03771 L F
.79289 .80148 m .8141 .81749 L .80348 .81869 L .869 .811 0 r
F
.78263 .80326 m .79289 .80148 L .80348 .81869 L .861 .807 0 r
F
.57861 .4956 m .61227 .49335 L .60865 .49913 L .955 .911 0 r
F
.39815 1.26832 m .37508 1.26447 L .38211 1.26228 L .503 .63 0 r
F
.40433 1.26603 m .39815 1.26832 L .38211 1.26228 L .476 .6 0 r
F
.42052 1.27093 m .39815 1.26832 L .40433 1.26603 L .461 .571 0 r
F
.33927 .94718 m .33186 .93252 L .34253 .93702 L .792 .676 0 r
F
.35012 .951 m .33927 .94718 L .34253 .93702 L .76 .657 0 r
F
.62658 1.08411 m .63118 1.09555 L .62136 1.0883 L .585 .523 0 r
F
.62658 1.08411 m .63689 1.09043 L .63118 1.09555 L F
.42521 .98624 m .4152 .97764 L .42606 .98248 L .457 .497 0 r
F
.43617 .99046 m .42521 .98624 L .42606 .98248 L .422 .468 0 r
F
.24145 .9204 m .23536 .90035 L .24613 .90335 L .937 .789 0 r
F
.24145 .9204 m .23055 .91807 L .23536 .90035 L F
.56242 1.04872 m .56886 1.05561 L .5596 1.04942 L .339 .34 0 r
F
.56242 1.04872 m .57225 1.05473 L .56886 1.05561 L F
.33353 .54936 m .35531 .52778 L .36084 .53399 L 1 .935 0 r
F
.33353 .54936 m .32705 .5433 L .35531 .52778 L F
.42579 1.26864 m .42052 1.27093 L .40433 1.26603 L .441 .531 0 r
F
.44187 1.27252 m .42052 1.27093 L .42579 1.26864 L .422 .481 0 r
F
.60262 .78336 m .6092 .7806 L .62215 .78678 L .543 .652 0 r
F
.58956 .77821 m .6092 .7806 L .60262 .78336 L .51 .631 0 r
F
.35012 .951 m .34253 .93702 L .3532 .94173 L .76 .657 0 r
F
.36096 .95503 m .35012 .951 L .3532 .94173 L .724 .637 0 r
F
.6894 .79124 m .71103 .80027 L .70137 .80209 L .752 .764 0 r
F
.68034 .7935 m .6894 .79124 L .70137 .80209 L .734 .753 0 r
F
.23055 .91807 m .22459 .89745 L .23536 .90035 L .944 .797 0 r
F
.23055 .91807 m .21964 .91584 L .22459 .89745 L F
.61628 1.07778 m .62136 1.0883 L .61155 1.08116 L .52 .493 0 r
F
.61628 1.07778 m .62658 1.08411 L .62136 1.0883 L F
.46953 1.00694 m .45811 1.00126 L .46909 1.00509 L .368 .395 0 r
F
.48041 1.01032 m .46953 1.00694 L .46909 1.00509 L .351 .37 0 r
F
.48107 1.01176 m .46953 1.00694 L .48041 1.01032 L .35 .369 0 r
F
.45388 .75585 m .46511 .76656 L .46848 .76172 L .518 .02 0 r
F
.45388 .75585 m .44932 .76996 L .46511 .76656 L F
.50436 1.01987 m .49559 1.01897 L .49433 1.01786 L .322 .327 0 r
F
.50508 1.02044 m .49559 1.01897 L .50436 1.01987 L .321 .326 0 r
F
.73739 1.12509 m .73951 1.14267 L .7293 1.13852 L .921 .751 0 r
F
.73739 1.12509 m .74802 1.12857 L .73951 1.14267 L F
.51841 1.02617 m .52163 1.03108 L .5174 1.02596 L .311 .309 0 r
F
.51841 1.02617 m .52364 1.03152 L .52163 1.03108 L F
.21964 .91584 m .2138 .89464 L .22459 .89745 L .95 .803 0 r
F
.21964 .91584 m .20873 .91369 L .2138 .89464 L F
.39882 .53283 m .42374 .51523 L .4271 .52139 L 1 .993 0 r
F
.39882 .53283 m .39437 .52666 L .42374 .51523 L F
.6092 .7806 m .62963 .78417 L .62215 .78678 L .574 .678 0 r
F
.36096 .95503 m .3532 .94173 L .36386 .94666 L .724 .637 0 r
F
.3718 .95924 m .36096 .95503 L .36386 .94666 L .684 .615 0 r
F
.31111 1.25606 m .28669 1.24686 L .29586 1.24531 L .673 .744 0 r
F
.31963 1.25415 m .31111 1.25606 L .29586 1.24531 L .655 .733 0 r
F
.45811 1.00126 m .44713 .99474 L .45811 .99906 L .386 .419 0 r
F
.46909 1.00509 m .45811 1.00126 L .45811 .99906 L .367 .392 0 r
F
.60597 1.07149 m .61155 1.08116 L .60173 1.07419 L .461 .463 0 r
F
.60597 1.07149 m .61628 1.07778 L .61155 1.08116 L F
.54106 1.03765 m .54771 1.04372 L .5391 1.03786 L .316 .314 0 r
F
.54106 1.03765 m .55034 1.04345 L .54771 1.04372 L F
.20873 .91369 m .20301 .89191 L .2138 .89464 L .955 .81 0 r
F
.20873 .91369 m .19781 .91162 L .20301 .89191 L F
.26841 1.25017 m .24371 1.23833 L .25343 1.23705 L .731 .773 0 r
F
.27754 1.24848 m .26841 1.25017 L .25343 1.23705 L .719 .765 0 r
F
.51148 1.27706 m .51137 1.27749 L .49465 1.27698 L .061 .112 0 r
F
.37508 1.26447 m .35163 1.25918 L .35946 1.2572 L .552 .67 0 r
F
.38211 1.26228 m .37508 1.26447 L .35946 1.2572 L .526 .648 0 r
F
.3718 .95924 m .36386 .94666 L .37452 .95178 L .684 .615 0 r
F
.38265 .96364 m .3718 .95924 L .37452 .95178 L .64 .591 0 r
F
.49174 1.01472 m .48107 1.01176 L .48041 1.01032 L .337 .348 0 r
F
.49239 1.01572 m .48107 1.01176 L .49174 1.01472 L .335 .347 0 r
F
.65879 .78664 m .68034 .7935 L .67131 .79564 L .698 .742 0 r
F
.65047 .78913 m .65879 .78664 L .67131 .79564 L .675 .728 0 r
F
.43617 .99046 m .42606 .98248 L .43692 .98735 L .422 .468 0 r
F
.44713 .99474 m .43617 .99046 L .43692 .98735 L .402 .44 0 r
F
.57107 .77671 m .57567 .77382 L .58956 .77821 L .452 .561 0 r
F
.55756 .77308 m .57567 .77382 L .57107 .77671 L .426 .503 0 r
F
.50373 1.01931 m .49433 1.01786 L .49326 1.01677 L .323 .329 0 r
F
.50436 1.01987 m .49433 1.01786 L .50373 1.01931 L .322 .327 0 r
F
.19781 .91162 m .1922 .88926 L .20301 .89191 L .96 .815 0 r
F
.19781 .91162 m .18689 .90961 L .1922 .88926 L F
.51937 1.02633 m .52364 1.03152 L .51841 1.02617 L .311 .31 0 r
F
.51937 1.02633 m .52556 1.03184 L .52364 1.03152 L F
.36634 .54018 m .3899 .52042 L .39437 .52666 L 1 .965 0 r
F
.36634 .54018 m .36084 .53399 L .3899 .52042 L F
.54268 1.27873 m .5281 1.27715 L .52714 1.2779 L .303 0 0 r
F
.54268 1.27873 m .54469 1.27594 L .5281 1.27715 L F
.59566 1.06531 m .60173 1.07419 L .5919 1.06746 L .415 .434 0 r
F
.59566 1.06531 m .60597 1.07149 L .60173 1.07419 L F
.53047 1.03212 m .53687 1.03788 L .52899 1.03214 L .312 .309 0 r
F
.53047 1.03212 m .5391 1.03786 L .53687 1.03788 L F
.72675 1.12143 m .7293 1.13852 L .71908 1.13416 L .907 .737 0 r
F
.72675 1.12143 m .73739 1.12509 L .7293 1.13852 L F
.49584 1.27581 m .49465 1.27698 L .47811 1.27561 L .186 .125 0 r
F
.51148 1.27706 m .49465 1.27698 L .49584 1.27581 L .061 .112 0 r
F
.55259 1.04291 m .5596 1.04942 L .55034 1.04345 L .331 .332 0 r
F
.55259 1.04291 m .56242 1.04872 L .5596 1.04942 L F
.38265 .96364 m .37452 .95178 L .38517 .95708 L .64 .591 0 r
F
.3935 .96819 m .38265 .96364 L .38517 .95708 L .592 .566 0 r
F
.44617 1.27036 m .44187 1.27252 L .42579 1.26864 L .395 .429 0 r
F
.4619 1.2734 m .44187 1.27252 L .44617 1.27036 L .363 .347 0 r
F
.48584 .76201 m .49916 .76343 L .50019 .76408 L .169 0 0 r
F
.48584 .76201 m .48364 .76296 L .49916 .76343 L F
.80318 .79964 m .82473 .81623 L .8141 .81749 L .876 .816 0 r
F
.79289 .80148 m .80318 .79964 L .8141 .81749 L .869 .811 0 r
F
.58536 1.05927 m .5919 1.06746 L .58208 1.06097 L .392 .407 0 r
F
.58536 1.05927 m .59566 1.06531 L .5919 1.06746 L F
.54647 .50045 m .54778 .49445 L .57861 .4956 L .974 .93 0 r
F
.51638 .50187 m .54778 .49445 L .54647 .50045 L 1 .952 0 r
F
.50319 1.01877 m .49326 1.01677 L .49239 1.01572 L .324 .33 0 r
F
.50373 1.01931 m .49326 1.01677 L .50319 1.01877 L .323 .329 0 r
F
.52026 1.02642 m .52556 1.03184 L .51937 1.02633 L .312 .311 0 r
F
.52026 1.02642 m .52734 1.03205 L .52556 1.03184 L F
.22434 1.24106 m .21467 1.24251 L .20009 1.22637 L .778 .794 0 r
F
.3935 .96819 m .38517 .95708 L .39583 .9625 L .592 .566 0 r
F
.40435 .97286 m .3935 .96819 L .39583 .9625 L .543 .539 0 r
F
.74014 .79424 m .76216 .80663 L .75195 .80821 L .82 .793 0 r
F
.73042 .79634 m .74014 .79424 L .75195 .80821 L .808 .786 0 r
F
.71611 1.11758 m .71908 1.13416 L .70884 1.12957 L .89 .722 0 r
F
.71611 1.11758 m .72675 1.12143 L .71908 1.13416 L F
.44713 .99474 m .43692 .98735 L .4478 .99222 L .402 .44 0 r
F
.45811 .99906 m .44713 .99474 L .4478 .99222 L .382 .412 0 r
F
.55796 1.28061 m .54469 1.27594 L .54268 1.27873 L .449 0 0 r
F
.55796 1.28061 m .56099 1.27389 L .54469 1.27594 L F
.46909 1.00509 m .45811 .99906 L .4691 1.0034 L .367 .392 0 r
F
.48008 1.00898 m .46909 1.00509 L .4691 1.0034 L .351 .368 0 r
F
.48041 1.01032 m .46909 1.00509 L .48008 1.00898 L .351 .37 0 r
F
.48037 1.27399 m .47811 1.27561 L .4619 1.2734 L .269 .175 0 r
F
.49584 1.27581 m .47811 1.27561 L .48037 1.27399 L .186 .125 0 r
F
.57505 1.05339 m .58208 1.06097 L .57225 1.05473 L .372 .384 0 r
F
.57505 1.05339 m .58536 1.05927 L .58208 1.06097 L F
.4913 1.01378 m .48041 1.01032 L .48008 1.00898 L .337 .349 0 r
F
.49174 1.01472 m .48041 1.01032 L .4913 1.01378 L .337 .348 0 r
F
.40435 .97286 m .39583 .9625 L .40649 .96801 L .543 .539 0 r
F
.4152 .97764 m .40435 .97286 L .40649 .96801 L .494 .511 0 r
F
.50276 1.01824 m .49239 1.01572 L .49174 1.01472 L .325 .332 0 r
F
.50319 1.01877 m .49239 1.01572 L .50276 1.01824 L .324 .33 0 r
F
.4271 .52139 m .45413 .50619 L .45635 .51233 L 1 1 0 r
F
.4271 .52139 m .42374 .51523 L .45413 .50619 L F
.53177 1.03197 m .5391 1.03786 L .53047 1.03212 L .317 .317 0 r
F
.53177 1.03197 m .54106 1.03765 L .5391 1.03786 L F
.70545 1.11352 m .70884 1.12957 L .6986 1.12473 L .87 .705 0 r
F
.70545 1.11352 m .71611 1.11758 L .70884 1.12957 L F
.54274 1.03725 m .55034 1.04345 L .54106 1.03765 L .325 .327 0 r
F
.54274 1.03725 m .55259 1.04291 L .55034 1.04345 L F
.52108 1.02646 m .52734 1.03205 L .52026 1.02642 L .313 .313 0 r
F
.52108 1.02646 m .52899 1.03214 L .52734 1.03205 L F
.55756 .77308 m .56109 .77022 L .57567 .77382 L .426 .503 0 r
F
.54355 .77011 m .56109 .77022 L .55756 .77308 L .387 .413 0 r
F
.69848 .78887 m .72071 .79835 L .71103 .80027 L .768 .774 0 r
F
.6894 .79124 m .69848 .78887 L .71103 .80027 L .752 .764 0 r
F
.56474 1.04767 m .57225 1.05473 L .56242 1.04872 L .355 .365 0 r
F
.56474 1.04767 m .57505 1.05339 L .57225 1.05473 L F
.4152 .97764 m .40649 .96801 L .41714 .97355 L .494 .511 0 r
F
.42606 .98248 m .4152 .97764 L .41714 .97355 L .449 .483 0 r
F
.45811 .99906 m .4478 .99222 L .45867 .99707 L .382 .412 0 r
F
.4691 1.0034 m .45811 .99906 L .45867 .99707 L .364 .387 0 r
F
.35163 1.25918 m .32816 1.25234 L .33671 1.25064 L .596 .699 0 r
F
.35946 1.2572 m .35163 1.25918 L .33671 1.25064 L .573 .681 0 r
F
.69478 1.10925 m .6986 1.12473 L .68834 1.11963 L .846 .687 0 r
F
.69478 1.10925 m .70545 1.11352 L .6986 1.12473 L F
.58956 .77821 m .5952 .77523 L .6092 .7806 L .51 .631 0 r
F
.57567 .77382 m .5952 .77523 L .58956 .77821 L .475 .599 0 r
F
.63714 .7814 m .65879 .78664 L .65047 .78913 L .655 .726 0 r
F
.62963 .78417 m .63714 .7814 L .65047 .78913 L .629 .708 0 r
F
.51638 .50187 m .51651 .49579 L .54778 .49445 L 1 .952 0 r
F
.48623 .50581 m .51651 .49579 L .51638 .50187 L 1 .975 0 r
F
.80318 .79964 m .81348 .79774 L .82473 .81623 L .876 .816 0 r
F
.51316 1.02081 m .50974 1.02321 L .5087 1.02268 L .319 .322 0 r
F
.51316 1.02081 m .51082 1.02371 L .50974 1.02321 L .318 .322 0 r
F
.51316 1.02081 m .51192 1.02418 L .51082 1.02371 L .318 .321 0 r
F
.50019 .76408 m .51483 .76413 L .51471 .7658 L .069 .113 0 r
F
.50019 .76408 m .49916 .76343 L .51483 .76413 L F
.51316 1.02081 m .5087 1.02268 L .5077 1.02213 L .319 .322 0 r
F
.51316 1.02081 m .51304 1.02462 L .51192 1.02418 L .318 .321 0 r
F
.27754 1.24848 m .25343 1.23705 L .26316 1.23584 L .719 .765 0 r
F
.28669 1.24686 m .27754 1.24848 L .26316 1.23584 L .705 .756 0 r
F
.50244 1.01774 m .49174 1.01472 L .4913 1.01378 L .326 .333 0 r
F
.50276 1.01824 m .49174 1.01472 L .50244 1.01774 L .325 .332 0 r
F
.61227 .49335 m .61589 .48749 L .64696 .49382 L .943 .896 0 r
F
.51316 1.02081 m .5077 1.02213 L .50676 1.02157 L .319 .322 0 r
F
.51316 1.02081 m .51416 1.02503 L .51304 1.02462 L .318 .32 0 r
F
.57289 1.28779 m .56099 1.27389 L .55796 1.28061 L .646 .034 0 r
F
.57289 1.28779 m .57683 1.27101 L .56099 1.27389 L F
.57861 .4956 m .58109 .48962 L .61227 .49335 L .955 .911 0 r
F
.54778 .49445 m .58109 .48962 L .57861 .4956 L .985 .93 0 r
F
.31963 1.25415 m .29586 1.24531 L .30505 1.24385 L .655 .733 0 r
F
.32816 1.25234 m .31963 1.25415 L .30505 1.24385 L .637 .72 0 r
F
.52182 1.02645 m .52899 1.03214 L .52108 1.02646 L .315 .316 0 r
F
.52182 1.02645 m .53047 1.03212 L .52899 1.03214 L F
.83069 1.13075 m .83266 1.15176 L .82212 1.14921 L .94 .815 0 r
F
.83069 1.13075 m .84159 1.13274 L .83266 1.15176 L F
.51316 1.02081 m .50676 1.02157 L .50588 1.02101 L .319 .322 0 r
F
.51316 1.02081 m .51526 1.02538 L .51416 1.02503 L .317 .32 0 r
F
.42606 .98248 m .41714 .97355 L .4278 .97909 L .449 .483 0 r
F
.43692 .98735 m .42606 .98248 L .4278 .97909 L .416 .454 0 r
F
.68411 1.10475 m .68834 1.11963 L .67806 1.11426 L .816 .668 0 r
F
.68411 1.10475 m .69478 1.10925 L .68834 1.11963 L F
.45635 .51233 m .48517 .49969 L .48623 .50581 L 1 .993 0 r
F
.45635 .51233 m .45413 .50619 L .48517 .49969 L F
.48008 1.00898 m .4691 1.0034 L .4801 1.00775 L .351 .368 0 r
F
.49109 1.0129 m .48008 1.00898 L .4801 1.00775 L .337 .348 0 r
F
.4913 1.01378 m .48008 1.00898 L .49109 1.0129 L .337 .349 0 r
F
.55443 1.0421 m .56242 1.04872 L .55259 1.04291 L .342 .35 0 r
F
.55443 1.0421 m .56474 1.04767 L .56242 1.04872 L F
.51316 1.02081 m .50588 1.02101 L .50508 1.02044 L .319 .322 0 r
F
.51316 1.02081 m .51635 1.0257 L .51526 1.02538 L .317 .319 0 r
F
.54355 .77011 m .54597 .76742 L .56109 .77022 L .387 .413 0 r
F
.52922 .76772 m .54597 .76742 L .54355 .77011 L .328 .278 0 r
F
.4652 1.27153 m .4619 1.2734 L .44617 1.27036 L .326 .286 0 r
F
.48037 1.27399 m .4619 1.2734 L .4652 1.27153 L .269 .175 0 r
F
.48623 .50581 m .48517 .49969 L .51651 .49579 L 1 .975 0 r
F
.40433 1.26603 m .38211 1.26228 L .38917 1.26023 L .476 .6 0 r
F
.41053 1.26389 m .40433 1.26603 L .38917 1.26023 L .457 .568 0 r
F
.42579 1.26864 m .40433 1.26603 L .41053 1.26389 L .441 .531 0 r
F
.22434 1.24106 m .20009 1.22637 L .21028 1.22543 L .778 .794 0 r
F
.23402 1.23967 m .22434 1.24106 L .21028 1.22543 L .769 .788 0 r
F
.53289 1.0317 m .54106 1.03765 L .53177 1.03197 L .322 .324 0 r
F
.53289 1.0317 m .54274 1.03725 L .54106 1.03765 L F
.51316 1.02081 m .50508 1.02044 L .50436 1.01987 L .319 .322 0 r
F
.66713 .784 m .6894 .79124 L .68034 .7935 L .718 .755 0 r
F
.65879 .78664 m .66713 .784 L .68034 .7935 L .698 .742 0 r
F
.51316 1.02081 m .5174 1.02596 L .51635 1.0257 L .317 .319 0 r
F
.67343 1.10003 m .67806 1.11426 L .66778 1.10863 L .782 .646 0 r
F
.67343 1.10003 m .68411 1.10475 L .67806 1.11426 L F
.4691 1.0034 m .45867 .99707 L .46956 1.00188 L .364 .387 0 r
F
.4801 1.00775 m .4691 1.0034 L .46956 1.00188 L .349 .364 0 r
F
.74989 .79206 m .77239 .80498 L .76216 .80663 L .831 .8 0 r
F
.74014 .79424 m .74989 .79206 L .76216 .80663 L .82 .793 0 r
F
.58109 .48962 m .61589 .48749 L .61227 .49335 L .964 .912 0 r
F
.51471 .7658 m .5305 .76541 L .52922 .76772 L .231 .129 0 r
F
.51471 .7658 m .51483 .76413 L .5305 .76541 L F
.43692 .98735 m .4278 .97909 L .43846 .98459 L .416 .454 0 r
F
.4478 .99222 m .43692 .98735 L .43846 .98459 L .396 .426 0 r
F
.81979 1.1287 m .82212 1.14921 L .81156 1.14658 L .936 .81 0 r
F
.81979 1.1287 m .83069 1.13075 L .82212 1.14921 L F
.50222 1.01728 m .4913 1.01378 L .49109 1.0129 L .327 .334 0 r
F
.50244 1.01774 m .4913 1.01378 L .50222 1.01728 L .326 .333 0 r
F
.51316 1.02081 m .50436 1.01987 L .50373 1.01931 L .319 .322 0 r
F
.51316 1.02081 m .51841 1.02617 L .5174 1.02596 L .317 .319 0 r
F
.6092 .7806 m .61581 .77767 L .62963 .78417 L .574 .678 0 r
F
.5952 .77523 m .61581 .77767 L .6092 .7806 L .544 .662 0 r
F
.39437 .52666 m .42037 .50897 L .42374 .51523 L 1 .984 0 r
F
.39437 .52666 m .3899 .52042 L .42037 .50897 L F
.61581 .77767 m .63714 .7814 L .62963 .78417 L .605 .701 0 r
F
.52922 .76772 m .5305 .76541 L .54597 .76742 L .328 .278 0 r
F
.66274 1.09509 m .66778 1.10863 L .65749 1.10275 L .742 .624 0 r
F
.66274 1.09509 m .67343 1.10003 L .66778 1.10863 L F
.52247 1.02637 m .53047 1.03212 L .52182 1.02645 L .317 .319 0 r
F
.52247 1.02637 m .53177 1.03197 L .53047 1.03212 L F
.43107 1.26652 m .42579 1.26864 L .41053 1.26389 L .419 .489 0 r
F
.44617 1.27036 m .42579 1.26864 L .43107 1.26652 L .395 .429 0 r
F
.54412 1.03666 m .55259 1.04291 L .54274 1.03725 L .333 .339 0 r
F
.54412 1.03666 m .55443 1.0421 L .55259 1.04291 L F
.38211 1.26228 m .35946 1.2572 L .36731 1.25533 L .526 .648 0 r
F
.38917 1.26023 m .38211 1.26228 L .36731 1.25533 L .499 .623 0 r
F
.51316 1.02081 m .50373 1.01931 L .50319 1.01877 L .319 .323 0 r
F
.65205 1.08995 m .65749 1.10275 L .64719 1.09667 L .697 .6 0 r
F
.65205 1.08995 m .66274 1.09509 L .65749 1.10275 L F
.51316 1.02081 m .51937 1.02633 L .51841 1.02617 L .317 .319 0 r
F
.36084 .53399 m .38541 .51411 L .3899 .52042 L 1 .959 0 r
F
.36084 .53399 m .35531 .52778 L .38541 .51411 L F
.64136 1.08464 m .64719 1.09667 L .63689 1.09043 L .646 .574 0 r
F
.64136 1.08464 m .65205 1.08995 L .64719 1.09667 L F
.4478 .99222 m .43846 .98459 L .44913 .99 L .396 .426 0 r
F
.45867 .99707 m .4478 .99222 L .44913 .99 L .376 .401 0 r
F
.63066 1.0792 m .63689 1.09043 L .62658 1.08411 L .592 .548 0 r
F
.63066 1.0792 m .64136 1.08464 L .63689 1.09043 L F
.80888 1.12656 m .81156 1.14658 L .801 1.14386 L .932 .803 0 r
F
.80888 1.12656 m .81979 1.1287 L .81156 1.14658 L F
.51316 1.02081 m .50319 1.01877 L .50276 1.01824 L .32 .323 0 r
F
.51316 1.02081 m .52026 1.02642 L .51937 1.02633 L .317 .319 0 r
F
.61997 1.07367 m .62658 1.08411 L .61628 1.07778 L .536 .52 0 r
F
.61997 1.07367 m .63066 1.0792 L .62658 1.08411 L F
.4801 1.00775 m .46956 1.00188 L .48045 1.00666 L .349 .364 0 r
F
.49111 1.0121 m .4801 1.00775 L .48045 1.00666 L .336 .346 0 r
F
.49109 1.0129 m .4801 1.00775 L .49111 1.0121 L .337 .348 0 r
F
.60928 1.06811 m .61628 1.07778 L .60597 1.07149 L .483 .491 0 r
F
.60928 1.06811 m .61997 1.07367 L .61628 1.07778 L F
.50212 1.01685 m .49109 1.0129 L .49111 1.0121 L .327 .334 0 r
F
.50222 1.01728 m .49109 1.0129 L .50212 1.01685 L F
.59859 1.06256 m .60597 1.07149 L .59566 1.06531 L .436 .462 0 r
F
.59859 1.06256 m .60928 1.06811 L .60597 1.07149 L F
.46848 .76172 m .48143 .76413 L .48364 .76296 L .333 0 0 r
F
.46848 .76172 m .46511 .76656 L .48143 .76413 L F
.52303 1.02624 m .53177 1.03197 L .52247 1.02637 L .32 .323 0 r
F
.52303 1.02624 m .53289 1.0317 L .53177 1.03197 L F
.51316 1.02081 m .50276 1.01824 L .50244 1.01774 L .32 .324 0 r
F
.5879 1.05705 m .59566 1.06531 L .58536 1.05927 L .407 .435 0 r
F
.5879 1.05705 m .59859 1.06256 L .59566 1.06531 L F
.5338 1.03132 m .54274 1.03725 L .53289 1.0317 L .326 .331 0 r
F
.5338 1.03132 m .54412 1.03666 L .54274 1.03725 L F
.45867 .99707 m .44913 .99 L .4598 .99533 L .376 .401 0 r
F
.46956 1.00188 m .45867 .99707 L .4598 .99533 L .359 .378 0 r
F
.51316 1.02081 m .52108 1.02646 L .52026 1.02642 L .317 .319 0 r
F
.70758 .78639 m .73042 .79634 L .72071 .79835 L .783 .783 0 r
F
.69848 .78887 m .70758 .78639 L .72071 .79835 L .768 .774 0 r
F
.58759 1.32034 m .57683 1.27101 L .57289 1.28779 L 1 .144 0 r
F
.58759 1.32034 m .59242 1.29616 L .57683 1.27101 L F
.57722 1.05162 m .58536 1.05927 L .57505 1.05339 L .386 .409 0 r
F
.57722 1.05162 m .5879 1.05705 L .58536 1.05927 L F
.79796 1.12434 m .801 1.14386 L .79043 1.14104 L .927 .797 0 r
F
.79796 1.12434 m .80888 1.12656 L .801 1.14386 L F
.57567 .77382 m .58029 .77073 L .5952 .77523 L .475 .599 0 r
F
.56109 .77022 m .58029 .77073 L .57567 .77382 L .451 .549 0 r
F
.51316 1.02081 m .50244 1.01774 L .50222 1.01728 L .32 .324 0 r
F
.56654 1.04629 m .57505 1.05339 L .56474 1.04767 L .368 .385 0 r
F
.56654 1.04629 m .57722 1.05162 L .57505 1.05339 L F
.51316 1.02081 m .52182 1.02645 L .52108 1.02646 L .318 .32 0 r
F
.28669 1.24686 m .26316 1.23584 L .27291 1.2347 L .705 .756 0 r
F
.29586 1.24531 m .28669 1.24686 L .27291 1.2347 L .69 .747 0 r
F
.46956 1.00188 m .4598 .99533 L .47047 1.00057 L .359 .378 0 r
F
.48045 1.00666 m .46956 1.00188 L .47047 1.00057 L .345 .358 0 r
F
.23402 1.23967 m .21028 1.22543 L .22048 1.22455 L .769 .788 0 r
F
.24371 1.23833 m .23402 1.23967 L .22048 1.22455 L .759 .781 0 r
F
.4505 1.26839 m .44617 1.27036 L .43107 1.26652 L .366 .377 0 r
F
.4652 1.27153 m .44617 1.27036 L .4505 1.26839 L .326 .286 0 r
F
.54778 .49445 m .54909 .48833 L .58109 .48962 L .985 .93 0 r
F
.51651 .49579 m .54909 .48833 L .54778 .49445 L 1 .951 0 r
F
.49111 1.0121 m .48045 1.00666 L .49135 1.0114 L .336 .346 0 r
F
.50213 1.01645 m .49111 1.0121 L .49135 1.0114 L .326 .333 0 r
F
.50212 1.01685 m .49111 1.0121 L .50213 1.01645 L .327 .334 0 r
F
.55586 1.04105 m .56474 1.04767 L .55443 1.0421 L .352 .366 0 r
F
.55586 1.04105 m .56654 1.04629 L .56474 1.04767 L F
.75966 .7898 m .78263 .80326 L .77239 .80498 L .841 .805 0 r
F
.74989 .79206 m .75966 .7898 L .77239 .80498 L .831 .8 0 r
F
.36386 .94666 m .3532 .94173 L .35796 .93266 L .745 .624 0 r
F
.3532 .94173 m .34759 .92697 L .35796 .93266 L .786 .647 0 r
F
.3532 .94173 m .34253 .93702 L .34759 .92697 L F
.51316 1.02081 m .50222 1.01728 L .50212 1.01685 L .321 .324 0 r
F
.36386 .94666 m .35796 .93266 L .36832 .93857 L .745 .624 0 r
F
.37452 .95178 m .36386 .94666 L .36832 .93857 L .698 .6 0 r
F
.78704 1.12202 m .79043 1.14104 L .77984 1.13811 L .921 .789 0 r
F
.78704 1.12202 m .79796 1.12434 L .79043 1.14104 L F
.34253 .93702 m .3372 .92154 L .34759 .92697 L .821 .668 0 r
F
.34253 .93702 m .33186 .93252 L .3372 .92154 L F
.51316 1.02081 m .52247 1.02637 L .52182 1.02645 L .318 .321 0 r
F
.52348 1.02605 m .53289 1.0317 L .52303 1.02624 L .322 .326 0 r
F
.52348 1.02605 m .5338 1.03132 L .53289 1.0317 L F
.37452 .95178 m .36832 .93857 L .37868 .94469 L .698 .6 0 r
F
.38517 .95708 m .37452 .95178 L .37868 .94469 L .646 .574 0 r
F
.33186 .93252 m .32681 .91637 L .3372 .92154 L .852 .688 0 r
F
.33186 .93252 m .32117 .92824 L .32681 .91637 L F
.35946 1.2572 m .33671 1.25064 L .34529 1.24904 L .573 .681 0 r
F
.36731 1.25533 m .35946 1.2572 L .34529 1.24904 L .549 .661 0 r
F
.32816 1.25234 m .30505 1.24385 L .31426 1.24249 L .637 .72 0 r
F
.33671 1.25064 m .32816 1.25234 L .31426 1.24249 L .617 .706 0 r
F
.38517 .95708 m .37868 .94469 L .38903 .95096 L .646 .574 0 r
F
.39583 .9625 m .38517 .95708 L .38903 .95096 L .591 .547 0 r
F
.54518 1.0359 m .55443 1.0421 L .54412 1.03666 L .34 .35 0 r
F
.54518 1.0359 m .55586 1.04105 L .55443 1.0421 L F
.5116 1.27681 m .51148 1.27706 L .49584 1.27581 L 0 .102 0 r
F
.48045 1.00666 m .47047 1.00057 L .48114 1.00571 L .345 .358 0 r
F
.49135 1.0114 m .48045 1.00666 L .48114 1.00571 L .334 .342 0 r
F
.32117 .92824 m .3164 .91144 L .32681 .91637 L .877 .706 0 r
F
.32117 .92824 m .31048 .92416 L .3164 .91144 L F
.42374 .51523 m .45189 .49993 L .45413 .50619 L 1 .991 0 r
F
.42374 .51523 m .42037 .50897 L .45189 .49993 L F
.49704 1.27484 m .49584 1.27581 L .48037 1.27399 L .129 .118 0 r
F
.5116 1.27681 m .49584 1.27581 L .49704 1.27484 L 0 .102 0 r
F
.64467 .77848 m .66713 .784 L .65879 .78664 L .68 .742 0 r
F
.63714 .7814 m .64467 .77848 L .65879 .78664 L .655 .726 0 r
F
.39583 .9625 m .38903 .95096 L .39938 .9573 L .591 .547 0 r
F
.40649 .96801 m .39583 .9625 L .39938 .9573 L .535 .519 0 r
F
.51316 1.02081 m .50212 1.01685 L .50213 1.01645 L .321 .325 0 r
F
.51316 1.02081 m .52303 1.02624 L .52247 1.02637 L .319 .322 0 r
F
.31048 .92416 m .30598 .90676 L .3164 .91144 L .899 .723 0 r
F
.31048 .92416 m .29978 .92029 L .30598 .90676 L F
.40649 .96801 m .39938 .9573 L .40973 .96367 L .535 .519 0 r
F
.41714 .97355 m .40649 .96801 L .40973 .96367 L .481 .49 0 r
F
.77611 1.11959 m .77984 1.13811 L .76925 1.13507 L .914 .781 0 r
F
.77611 1.11959 m .78704 1.12202 L .77984 1.13811 L F
.53451 1.03083 m .54412 1.03666 L .5338 1.03132 L .33 .337 0 r
F
.53451 1.03083 m .54518 1.0359 L .54412 1.03666 L F
.6755 .78124 m .69848 .78887 L .6894 .79124 L .738 .767 0 r
F
.66713 .784 m .6755 .78124 L .6894 .79124 L .718 .755 0 r
F
.41714 .97355 m .40973 .96367 L .42008 .96998 L .481 .49 0 r
F
.4278 .97909 m .41714 .97355 L .42008 .96998 L .435 .461 0 r
F
.54066 1.28131 m .52714 1.2779 L .52618 1.27876 L .373 0 0 r
F
.54066 1.28131 m .54268 1.27873 L .52714 1.2779 L F
.49135 1.0114 m .48114 1.00571 L .49181 1.01079 L .334 .342 0 r
F
.50225 1.01611 m .49135 1.0114 L .49181 1.01079 L .325 .331 0 r
F
.50213 1.01645 m .49135 1.0114 L .50225 1.01611 L .326 .333 0 r
F
.29978 .92029 m .29554 .90229 L .30598 .90676 L .917 .738 0 r
F
.29978 .92029 m .28907 .91659 L .29554 .90229 L F
.51316 1.02081 m .50213 1.01645 L .50225 1.01611 L .321 .324 0 r
F
.51316 1.02081 m .52348 1.02605 L .52303 1.02624 L .319 .323 0 r
F
.4278 .97909 m .42008 .96998 L .43043 .97618 L .435 .461 0 r
F
.43846 .98459 m .4278 .97909 L .43043 .97618 L .406 .433 0 r
F
.52383 1.0258 m .5338 1.03132 L .52348 1.02605 L .324 .329 0 r
F
.52383 1.0258 m .53451 1.03083 L .5338 1.03132 L F
.48263 1.27257 m .48037 1.27399 L .4652 1.27153 L .225 .134 0 r
F
.49704 1.27484 m .48037 1.27399 L .48263 1.27257 L .129 .118 0 r
F
.76517 1.11705 m .76925 1.13507 L .75864 1.13189 L .905 .771 0 r
F
.76517 1.11705 m .77611 1.11959 L .76925 1.13507 L F
.43846 .98459 m .43043 .97618 L .44077 .98224 L .406 .433 0 r
F
.44913 .99 m .43846 .98459 L .44077 .98224 L .385 .408 0 r
F
.28907 .91659 m .28509 .89802 L .29554 .90229 L .932 .751 0 r
F
.28907 .91659 m .27835 .91307 L .28509 .89802 L F
.5952 .77523 m .60085 .77206 L .61581 .77767 L .544 .662 0 r
F
.58029 .77073 m .60085 .77206 L .5952 .77523 L .51 .637 0 r
F
.51651 .49579 m .51664 .48958 L .54909 .48833 L 1 .951 0 r
F
.48517 .49969 m .51664 .48958 L .51651 .49579 L 1 .971 0 r
F
.56109 .77022 m .56463 .76714 L .58029 .77073 L .451 .549 0 r
F
.54597 .76742 m .56463 .76714 L .56109 .77022 L .42 .47 0 r
F
.50225 1.01611 m .49181 1.01079 L .50248 1.01581 L .325 .331 0 r
F
.51316 1.02081 m .50225 1.01611 L .50248 1.01581 L .32 .324 0 r
F
.44913 .99 m .44077 .98224 L .45112 .98815 L .385 .408 0 r
F
.4598 .99533 m .44913 .99 L .45112 .98815 L .367 .385 0 r
F
.51316 1.02081 m .52383 1.0258 L .52348 1.02605 L .32 .324 0 r
F
.58109 .48962 m .58358 .48354 L .61589 .48749 L .964 .912 0 r
F
.54909 .48833 m .58358 .48354 L .58109 .48962 L .993 .93 0 r
F
.4598 .99533 m .45112 .98815 L .46147 .99389 L .367 .385 0 r
F
.47047 1.00057 m .4598 .99533 L .46147 .99389 L .352 .365 0 r
F
.48591 .76303 m .49811 .7627 L .49916 .76343 L .086 0 0 r
F
.48699 .7629 m .49811 .7627 L .48591 .76303 L F
.48364 .76296 m .48699 .7629 L .48591 .76303 L F
.48364 .76296 m .48143 .76413 L .49811 .7627 L F
.48739 .76362 m .49706 .76159 L .49811 .7627 L 0 0 0 r
F
.48143 .76413 m .48854 .76298 L .48739 .76362 L F
.48854 .76298 m .49706 .76159 L .48739 .76362 L F
.47242 .76547 m .47921 .76483 L .48143 .76413 L .145 0 0 r
F
.46511 .76656 m .47278 .76562 L .47242 .76547 L F
.47278 .76562 m .47921 .76483 L .47242 .76547 L F
.44932 .76996 m .44473 .78317 L .46172 .77076 L .286 0 0 r
F
.46511 .76656 m .46172 .77076 L .47921 .76483 L .145 0 0 r
F
.46172 .77076 m .47699 .76457 L .47921 .76483 L 0 0 0 r
F
.45236 .7776 m .45833 .77282 L .46172 .77076 L F
.44473 .78317 m .45833 .77282 L .45236 .7776 L F
.44932 .76996 m .46172 .77076 L .46511 .76656 L .286 0 0 r
F
.45833 .77282 m .45493 .77264 L .46384 .76841 L .548 .217 0 r
F
.46172 .77076 m .45833 .77282 L .47373 .76601 L 0 0 0 r
F
.46172 .77076 m .47373 .76601 L .47358 .76595 L F
.45833 .77282 m .46384 .76841 L .47475 .76322 L .548 .217 0 r
F
.47358 .76595 m .47373 .76601 L .47699 .76457 L 0 0 0 r
F
.47921 .76483 m .47699 .76457 L .49246 .76078 L .296 .143 0 r
F
.49183 .76113 m .49246 .76078 L .49601 .75991 L F
.48143 .76413 m .47921 .76483 L .4953 .76191 L 0 0 0 r
F
.48143 .76413 m .4953 .76191 L .49453 .762 L F
.47921 .76483 m .49246 .76078 L .49183 .76113 L .296 .143 0 r
F
.49453 .762 m .4953 .76191 L .49706 .76159 L 0 0 0 r
F
.45413 .50619 m .48411 .49344 L .48517 .49969 L 1 .985 0 r
F
.45413 .50619 m .45189 .49993 L .48411 .49344 L F
.47047 1.00057 m .46147 .99389 L .47181 .99947 L .352 .365 0 r
F
.48114 1.00571 m .47047 1.00057 L .47181 .99947 L .34 .349 0 r
F
.27835 .91307 m .27463 .89392 L .28509 .89802 L .944 .763 0 r
F
.27835 .91307 m .26762 .90969 L .27463 .89392 L F
.75422 1.11438 m .75864 1.13189 L .74802 1.12857 L .895 .761 0 r
F
.75422 1.11438 m .76517 1.11705 L .75864 1.13189 L F
.41053 1.26389 m .38917 1.26023 L .39625 1.25833 L .457 .568 0 r
F
.41675 1.26191 m .41053 1.26389 L .39625 1.25833 L .438 .533 0 r
F
.43107 1.26652 m .41053 1.26389 L .41675 1.26191 L .419 .489 0 r
F
.7167 .78381 m .74014 .79424 L .73042 .79634 L .797 .79 0 r
F
.70758 .78639 m .7167 .78381 L .73042 .79634 L .783 .783 0 r
F
.48114 1.00571 m .47181 .99947 L .48216 1.00493 L .34 .349 0 r
F
.49181 1.01079 m .48114 1.00571 L .48216 1.00493 L .33 .337 0 r
F
.24371 1.23833 m .22048 1.22455 L .2307 1.22373 L .759 .781 0 r
F
.25343 1.23705 m .24371 1.23833 L .2307 1.22373 L .748 .774 0 r
F
.49181 1.01079 m .48216 1.00493 L .49249 1.01028 L .33 .337 0 r
F
.50248 1.01581 m .49181 1.01079 L .49249 1.01028 L .324 .329 0 r
F
.62244 .77456 m .64467 .77848 L .63714 .7814 L .634 .722 0 r
F
.61581 .77767 m .62244 .77456 L .63714 .7814 L .605 .701 0 r
F
.50248 1.01581 m .49249 1.01028 L .50283 1.01556 L .324 .329 0 r
F
.51316 1.02081 m .50248 1.01581 L .50283 1.01556 L .32 .324 0 r
F
.3899 .52042 m .41698 .50262 L .42037 .50897 L 1 .976 0 r
F
.3899 .52042 m .38541 .51411 L .41698 .50262 L F
.51316 1.02081 m .50283 1.01556 L .50328 1.01537 L .319 .323 0 r
F
.51316 1.02081 m .52407 1.02551 L .52383 1.0258 L .32 .324 0 r
F
.51316 1.02081 m .50328 1.01537 L .50383 1.01523 L .319 .322 0 r
F
.51316 1.02081 m .5242 1.02516 L .52407 1.02551 L .321 .324 0 r
F
.51316 1.02081 m .50383 1.01523 L .50448 1.01515 L .318 .321 0 r
F
.51316 1.02081 m .52422 1.02477 L .5242 1.02516 L .321 .325 0 r
F
.51316 1.02081 m .50448 1.01515 L .50522 1.01513 L .318 .32 0 r
F
.51316 1.02081 m .52412 1.02434 L .52422 1.02477 L .321 .324 0 r
F
.51316 1.02081 m .50522 1.01513 L .50604 1.01517 L .317 .319 0 r
F
.51316 1.02081 m .5239 1.02387 L .52412 1.02434 L .32 .324 0 r
F
.51316 1.02081 m .50604 1.01517 L .50693 1.01527 L .317 .319 0 r
F
.51316 1.02081 m .52358 1.02338 L .5239 1.02387 L .32 .324 0 r
F
.51316 1.02081 m .50693 1.01527 L .50789 1.01542 L .317 .319 0 r
F
.51316 1.02081 m .52315 1.02285 L .52358 1.02338 L .32 .323 0 r
F
.69421 1.49598 m .671 1.51383 L .666 1.5093 L 1 .974 0 r
F
.69421 1.49598 m .70015 1.50057 L .671 1.51383 L F
.51316 1.02081 m .50789 1.01542 L .5089 1.01563 L .317 .319 0 r
F
.51316 1.02081 m .52262 1.02231 L .52315 1.02285 L .319 .323 0 r
F
.51316 1.02081 m .5089 1.01563 L .50996 1.0159 L .317 .319 0 r
F
.51316 1.02081 m .52199 1.02175 L .52262 1.02231 L .319 .322 0 r
F
.51316 1.02081 m .50996 1.0159 L .51104 1.01621 L .317 .319 0 r
F
.51316 1.02081 m .52127 1.02118 L .52199 1.02175 L .319 .322 0 r
F
.51316 1.02081 m .51104 1.01621 L .51216 1.01657 L .317 .32 0 r
F
.51316 1.02081 m .52047 1.02061 L .52127 1.02118 L .319 .322 0 r
F
.51316 1.02081 m .51216 1.01657 L .51328 1.01697 L .318 .32 0 r
F
.51316 1.02081 m .51959 1.02003 L .52047 1.02061 L .319 .322 0 r
F
.51316 1.02081 m .51328 1.01697 L .5144 1.01741 L .318 .321 0 r
F
.51316 1.02081 m .51864 1.01947 L .51959 1.02003 L .319 .322 0 r
F
.51316 1.02081 m .5144 1.01741 L .51551 1.01789 L .318 .321 0 r
F
.51316 1.02081 m .51764 1.01892 L .51864 1.01947 L .319 .322 0 r
F
.51316 1.02081 m .51551 1.01789 L .51659 1.01839 L .318 .322 0 r
F
.51316 1.02081 m .51659 1.01839 L .51764 1.01892 L .319 .322 0 r
F
.52407 1.02551 m .53451 1.03083 L .52383 1.0258 L .325 .331 0 r
F
.48517 .49969 m .48411 .49344 L .51664 .48958 L 1 .971 0 r
F
.38917 1.26023 m .36731 1.25533 L .37518 1.2536 L .499 .623 0 r
F
.39625 1.25833 m .38917 1.26023 L .37518 1.2536 L .473 .595 0 r
F
.53499 1.03023 m .54518 1.0359 L .53451 1.03083 L .334 .343 0 r
F
.52407 1.02551 m .53499 1.03023 L .53451 1.03083 L .325 .331 0 r
F
.76945 .78747 m .79289 .80148 L .78263 .80326 L .85 .81 0 r
F
.75966 .7898 m .76945 .78747 L .78263 .80326 L .841 .805 0 r
F
.54592 1.03498 m .55586 1.04105 L .54518 1.0359 L .345 .358 0 r
F
.53499 1.03023 m .54592 1.03498 L .54518 1.0359 L .334 .343 0 r
F
.29586 1.24531 m .27291 1.2347 L .28267 1.23365 L .69 .747 0 r
F
.30505 1.24385 m .29586 1.24531 L .28267 1.23365 L .674 .736 0 r
F
.60085 .77206 m .62244 .77456 L .61581 .77767 L .578 .69 0 r
F
.26762 .90969 m .26415 .88999 L .27463 .89392 L .955 .775 0 r
F
.26762 .90969 m .25688 .90646 L .26415 .88999 L F
.74327 1.11157 m .74802 1.12857 L .73739 1.12509 L .883 .75 0 r
F
.74327 1.11157 m .75422 1.11438 L .74802 1.12857 L F
.55685 1.03977 m .56654 1.04629 L .55586 1.04105 L .359 .378 0 r
F
.54592 1.03498 m .55685 1.03977 L .55586 1.04105 L .345 .358 0 r
F
.55491 1.28587 m .54268 1.27873 L .54066 1.28131 L .538 .006 0 r
F
.55491 1.28587 m .55796 1.28061 L .54268 1.27873 L F
.56779 1.04461 m .57722 1.05162 L .56654 1.04629 L .377 .401 0 r
F
.55685 1.03977 m .56779 1.04461 L .56654 1.04629 L .359 .378 0 r
F
.50283 1.01556 m .49339 1.00989 L .50328 1.01537 L .322 .326 0 r
F
.50283 1.01556 m .49249 1.01028 L .49339 1.00989 L F
.57874 1.04949 m .5879 1.05705 L .57722 1.05162 L .396 .427 0 r
F
.56779 1.04461 m .57874 1.04949 L .57722 1.05162 L .377 .401 0 r
F
.5242 1.02516 m .53499 1.03023 L .52407 1.02551 L .326 .333 0 r
F
.46852 1.26986 m .4652 1.27153 L .4505 1.26839 L .291 .234 0 r
F
.48263 1.27257 m .4652 1.27153 L .46852 1.26986 L .225 .134 0 r
F
.43638 1.26458 m .43107 1.26652 L .41675 1.26191 L .396 .445 0 r
F
.4505 1.26839 m .43107 1.26652 L .43638 1.26458 L .366 .377 0 r
F
.73232 1.10861 m .73739 1.12509 L .72675 1.12143 L .869 .737 0 r
F
.73232 1.10861 m .74327 1.11157 L .73739 1.12509 L F
.58969 1.05439 m .59859 1.06256 L .5879 1.05705 L .417 .454 0 r
F
.57874 1.04949 m .58969 1.05439 L .5879 1.05705 L .396 .427 0 r
F
.25688 .90646 m .25365 .88619 L .26415 .88999 L .963 .784 0 r
F
.25688 .90646 m .24613 .90335 L .25365 .88619 L F
.54597 .76742 m .54841 .76452 L .56463 .76714 L .42 .47 0 r
F
.5305 .76541 m .54841 .76452 L .54597 .76742 L .371 .343 0 r
F
.49249 1.01028 m .48349 1.00432 L .49339 1.00989 L .326 .331 0 r
F
.49249 1.01028 m .48216 1.00493 L .48349 1.00432 L F
.60065 1.0593 m .60928 1.06811 L .59859 1.06256 L .45 .483 0 r
F
.58969 1.05439 m .60065 1.0593 L .59859 1.06256 L .417 .454 0 r
F
.50328 1.01537 m .49449 1.00961 L .50383 1.01523 L .32 .323 0 r
F
.50328 1.01537 m .49339 1.00989 L .49449 1.00961 L F
.5242 1.02516 m .53525 1.02953 L .53499 1.03023 L .326 .333 0 r
F
.52422 1.02477 m .53525 1.02953 L .5242 1.02516 L .327 .334 0 r
F
.72136 1.10549 m .72675 1.12143 L .71611 1.11758 L .853 .724 0 r
F
.72136 1.10549 m .73232 1.10861 L .72675 1.12143 L F
.53525 1.02953 m .54592 1.03498 L .53499 1.03023 L .336 .346 0 r
F
.49916 .76343 m .51496 .76229 L .51483 .76413 L .145 .124 0 r
F
.49916 .76343 m .49811 .7627 L .51496 .76229 L F
.61161 1.06419 m .61997 1.07367 L .60928 1.06811 L .494 .511 0 r
F
.60065 1.0593 m .61161 1.06419 L .60928 1.06811 L .45 .483 0 r
F
.33671 1.25064 m .31426 1.24249 L .32348 1.24122 L .617 .706 0 r
F
.34529 1.24904 m .33671 1.25064 L .32348 1.24122 L .595 .69 0 r
F
.48216 1.00493 m .47359 .99863 L .48349 1.00432 L .333 .339 0 r
F
.48216 1.00493 m .47181 .99947 L .47359 .99863 L F
.24613 .90335 m .24314 .88253 L .25365 .88619 L .97 .793 0 r
F
.24613 .90335 m .23536 .90035 L .24314 .88253 L F
.62258 1.06902 m .63066 1.0792 L .61997 1.07367 L .542 .539 0 r
F
.61161 1.06419 m .62258 1.06902 L .61997 1.07367 L .494 .511 0 r
F
.71039 1.10219 m .71611 1.11758 L .70545 1.11352 L .834 .709 0 r
F
.71039 1.10219 m .72136 1.10549 L .71611 1.11758 L F
.50383 1.01523 m .49578 1.00945 L .50448 1.01515 L .317 .319 0 r
F
.50383 1.01523 m .49449 1.00961 L .49578 1.00945 L F
.52422 1.02477 m .53529 1.02874 L .53525 1.02953 L .327 .334 0 r
F
.52412 1.02434 m .53529 1.02874 L .52422 1.02477 L F
.63355 1.07375 m .64136 1.08464 L .63066 1.0792 L .591 .565 0 r
F
.62258 1.06902 m .63355 1.07375 L .63066 1.0792 L .542 .539 0 r
F
.36731 1.25533 m .34529 1.24904 L .35389 1.24756 L .549 .661 0 r
F
.37518 1.2536 m .36731 1.25533 L .35389 1.24756 L .524 .64 0 r
F
.5305 .76541 m .53179 .7629 L .54841 .76452 L .371 .343 0 r
F
.51483 .76413 m .53179 .7629 L .5305 .76541 L .289 .166 0 r
F
.69942 1.09871 m .70545 1.11352 L .69478 1.10925 L .811 .693 0 r
F
.69942 1.09871 m .71039 1.10219 L .70545 1.11352 L F
.54632 1.0339 m .55685 1.03977 L .54592 1.03498 L .349 .364 0 r
F
.53525 1.02953 m .54632 1.0339 L .54592 1.03498 L .336 .346 0 r
F
.51483 .76413 m .51496 .76229 L .53179 .7629 L .289 .166 0 r
F
.47181 .99947 m .46368 .99277 L .47359 .99863 L .342 .35 0 r
F
.47181 .99947 m .46147 .99389 L .46368 .99277 L F
.64453 1.07835 m .65205 1.08995 L .64136 1.08464 L .637 .59 0 r
F
.63355 1.07375 m .64453 1.07835 L .64136 1.08464 L .591 .565 0 r
F
.68389 .77836 m .70758 .78639 L .69848 .78887 L .755 .778 0 r
F
.6755 .78124 m .68389 .77836 L .69848 .78887 L .738 .767 0 r
F
.65222 .77542 m .6755 .78124 L .66713 .784 L .703 .757 0 r
F
.64467 .77848 m .65222 .77542 L .66713 .784 L .68 .742 0 r
F
.68845 1.09503 m .69478 1.10925 L .68411 1.10475 L .785 .675 0 r
F
.68845 1.09503 m .69942 1.09871 L .69478 1.10925 L F
.65551 1.0828 m .66274 1.09509 L .65205 1.08995 L .681 .613 0 r
F
.64453 1.07835 m .65551 1.0828 L .65205 1.08995 L .637 .59 0 r
F
.49339 1.00989 m .48514 1.0039 L .49449 1.00961 L .321 .324 0 r
F
.49339 1.00989 m .48349 1.00432 L .48514 1.0039 L F
.50448 1.01515 m .49726 1.00942 L .50522 1.01513 L .315 .316 0 r
F
.50448 1.01515 m .49578 1.00945 L .49726 1.00942 L F
.67747 1.09115 m .68411 1.10475 L .67343 1.10003 L .754 .656 0 r
F
.67747 1.09115 m .68845 1.09503 L .68411 1.10475 L F
.23536 .90035 m .23262 .87897 L .24314 .88253 L .976 .801 0 r
F
.23536 .90035 m .22459 .89745 L .23262 .87897 L F
.66649 1.08707 m .67343 1.10003 L .66274 1.09509 L .72 .635 0 r
F
.65551 1.0828 m .66649 1.08707 L .66274 1.09509 L .681 .613 0 r
F
.52412 1.02434 m .5351 1.02786 L .53529 1.02874 L .327 .334 0 r
F
.5239 1.02387 m .5351 1.02786 L .52412 1.02434 L .326 .333 0 r
F
.66649 1.08707 m .67747 1.09115 L .67343 1.10003 L .72 .635 0 r
F
.25343 1.23705 m .2307 1.22373 L .24093 1.22298 L .748 .774 0 r
F
.26316 1.23584 m .25343 1.23705 L .24093 1.22298 L .736 .767 0 r
F
.46147 .99389 m .45376 .9867 L .46368 .99277 L .354 .364 0 r
F
.46147 .99389 m .45112 .98815 L .45376 .9867 L F
.53529 1.02874 m .54632 1.0339 L .53525 1.02953 L .337 .348 0 r
F
.58029 .77073 m .58492 .76743 L .60085 .77206 L .51 .637 0 r
F
.56463 .76714 m .58492 .76743 L .58029 .77073 L .476 .598 0 r
F
.77926 .78507 m .80318 .79964 L .79289 .80148 L .859 .815 0 r
F
.76945 .78747 m .77926 .78507 L .79289 .80148 L .85 .81 0 r
F
.55739 1.03828 m .56779 1.04461 L .55685 1.03977 L .364 .387 0 r
F
.54632 1.0339 m .55739 1.03828 L .55685 1.03977 L .349 .364 0 r
F
.54909 .48833 m .55041 .4821 L .58358 .48354 L .993 .93 0 r
F
.51664 .48958 m .55041 .4821 L .54909 .48833 L 1 .949 0 r
F
.72585 .78114 m .74989 .79206 L .74014 .79424 L .809 .798 0 r
F
.7167 .78381 m .72585 .78114 L .74014 .79424 L .797 .79 0 r
F
.50522 1.01513 m .4989 1.0095 L .50604 1.01517 L .313 .313 0 r
F
.50522 1.01513 m .49726 1.00942 L .4989 1.0095 L F
.45112 .98815 m .44384 .98041 L .45376 .9867 L .371 .383 0 r
F
.45112 .98815 m .44077 .98224 L .44384 .98041 L F
.5239 1.02387 m .53468 1.02692 L .5351 1.02786 L .326 .333 0 r
F
.52358 1.02338 m .53468 1.02692 L .5239 1.02387 L .325 .332 0 r
F
.42037 .50897 m .44965 .49356 L .45189 .49993 L 1 .983 0 r
F
.42037 .50897 m .41698 .50262 L .44965 .49356 L F
.45484 1.26662 m .4505 1.26839 L .43638 1.26458 L .337 .328 0 r
F
.46852 1.26986 m .4505 1.26839 L .45484 1.26662 L .291 .234 0 r
F
.22459 .89745 m .22208 .87551 L .23262 .87897 L .981 .809 0 r
F
.22459 .89745 m .2138 .89464 L .22208 .87551 L F
.44077 .98224 m .43391 .97386 L .44384 .98041 L .391 .405 0 r
F
.44077 .98224 m .43043 .97618 L .43391 .97386 L F
.4339 .801 m .44473 .78317 L .44236 .78397 L 0 0 0 r
F
.4339 .801 m .4281 .82217 L .44189 .78982 L F
.43604 .79747 m .44189 .78982 L .44473 .78317 L F
.4339 .801 m .44189 .78982 L .43604 .79747 L F
.44137 .79105 m .44019 .78814 L .44473 .78317 L 1 1 0 r
F
.4281 .82217 m .44019 .78814 L .44137 .79105 L F
.44019 .78814 m .43568 .78799 L .43903 .78532 L .931 .713 0 r
F
.44473 .78317 m .44019 .78814 L .445 .78308 L 0 0 0 r
F
.445 .78308 m .44019 .78814 L .44695 .78243 L F
.44473 .78317 m .44695 .78243 L .45833 .77282 L F
.44236 .78397 m .44473 .78317 L .44932 .76996 L F
.44019 .78814 m .43903 .78532 L .45493 .77264 L .931 .713 0 r
F
.44019 .78814 m .45493 .77264 L .45503 .77264 L F
.44863 .78101 m .45503 .77264 L .45833 .77282 L F
.44019 .78814 m .45503 .77264 L .44863 .78101 L F
.30505 1.24385 m .28267 1.23365 L .29246 1.23268 L .674 .736 0 r
F
.31426 1.24249 m .30505 1.24385 L .29246 1.23268 L .657 .724 0 r
F
.50604 1.01517 m .50068 1.0097 L .50693 1.01527 L .312 .311 0 r
F
.50604 1.01517 m .4989 1.0095 L .50068 1.0097 L F
.56848 1.04266 m .57874 1.04949 L .56779 1.04461 L .382 .412 0 r
F
.55739 1.03828 m .56848 1.04266 L .56779 1.04461 L .364 .387 0 r
F
.48349 1.00432 m .47577 .99804 L .48514 1.0039 L .325 .326 0 r
F
.48349 1.00432 m .47359 .99863 L .47577 .99804 L F
.43043 .97618 m .42398 .96705 L .43391 .97386 L .414 .432 0 r
F
.43043 .97618 m .42008 .96998 L .42398 .96705 L F
.52358 1.02338 m .53404 1.02592 L .53468 1.02692 L .325 .332 0 r
F
.52315 1.02285 m .53404 1.02592 L .52358 1.02338 L .324 .33 0 r
F
.49449 1.00961 m .48707 1.00366 L .49578 1.00945 L .316 .316 0 r
F
.49449 1.00961 m .48514 1.0039 L .48707 1.00366 L F
.56884 1.29582 m .55796 1.28061 L .55491 1.28587 L .885 .04 0 r
F
.56884 1.29582 m .57289 1.28779 L .55796 1.28061 L F
.42008 .96998 m .41405 .96001 L .42398 .96705 L .457 .461 0 r
F
.42008 .96998 m .40973 .96367 L .41405 .96001 L F
.53529 1.02874 m .54638 1.03269 L .54632 1.0339 L .337 .348 0 r
F
.5351 1.02786 m .54638 1.03269 L .53529 1.02874 L .337 .349 0 r
F
.40973 .96367 m .40412 .95279 L .41405 .96001 L .516 .491 0 r
F
.40973 .96367 m .39938 .9573 L .40412 .95279 L F
.54638 1.03269 m .55739 1.03828 L .54632 1.0339 L .351 .368 0 r
F
.39938 .9573 m .39419 .94547 L .40412 .95279 L .581 .522 0 r
F
.39938 .9573 m .38903 .95096 L .39419 .94547 L F
.50693 1.01527 m .5026 1.01002 L .50789 1.01542 L .311 .31 0 r
F
.50693 1.01527 m .50068 1.0097 L .5026 1.01002 L F
.52315 1.02285 m .53318 1.02486 L .53404 1.02592 L .324 .33 0 r
F
.52262 1.02231 m .53318 1.02486 L .52315 1.02285 L .323 .329 0 r
F
.2138 .89464 m .21152 .87214 L .22208 .87551 L .985 .815 0 r
F
.2138 .89464 m .20301 .89191 L .21152 .87214 L F
.38903 .95096 m .38425 .93814 L .39419 .94547 L .647 .552 0 r
F
.38903 .95096 m .37868 .94469 L .38425 .93814 L F
.57958 1.04703 m .58969 1.05439 L .57874 1.04949 L .402 .439 0 r
F
.56848 1.04266 m .57958 1.04703 L .57874 1.04949 L .382 .412 0 r
F
.37868 .94469 m .37431 .93091 L .38425 .93814 L .709 .58 0 r
F
.37868 .94469 m .36832 .93857 L .37431 .93091 L F
.68824 1.49134 m .666 1.5093 L .66099 1.50475 L 1 .978 0 r
F
.68824 1.49134 m .69421 1.49598 L .666 1.5093 L F
.50789 1.01542 m .50462 1.01045 L .5089 1.01563 L .311 .309 0 r
F
.50789 1.01542 m .5026 1.01002 L .50462 1.01045 L F
.36832 .93857 m .36436 .92388 L .37431 .93091 L .765 .608 0 r
F
.36832 .93857 m .35796 .93266 L .36436 .92388 L F
.52262 1.02231 m .53212 1.02377 L .53318 1.02486 L .323 .329 0 r
F
.52199 1.02175 m .53212 1.02377 L .52262 1.02231 L .322 .327 0 r
F
.62909 .77129 m .65222 .77542 L .64467 .77848 L .662 .741 0 r
F
.62244 .77456 m .62909 .77129 L .64467 .77848 L .634 .722 0 r
F
.47359 .99863 m .4664 .992 L .47577 .99804 L .33 .331 0 r
F
.47359 .99863 m .46368 .99277 L .4664 .992 L F
.60085 .77206 m .60653 .76871 L .62244 .77456 L .578 .69 0 r
F
.58492 .76743 m .60653 .76871 L .60085 .77206 L .548 .673 0 r
F
.49578 1.00945 m .48928 1.00362 L .49726 1.00942 L .312 .309 0 r
F
.49578 1.00945 m .48707 1.00366 L .48928 1.00362 L F
.51664 .48958 m .51676 .48326 L .55041 .4821 L 1 .949 0 r
F
.48411 .49344 m .51676 .48326 L .51664 .48958 L 1 .966 0 r
F
.35796 .93266 m .3544 .91711 L .36436 .92388 L .814 .634 0 r
F
.35796 .93266 m .34759 .92697 L .3544 .91711 L F
.49824 1.27397 m .49704 1.27484 L .48263 1.27257 L .088 .112 0 r
F
.51171 1.27655 m .49704 1.27484 L .49824 1.27397 L 0 .096 0 r
F
.51171 1.27655 m .5116 1.27681 L .49704 1.27484 L F
.39625 1.25833 m .37518 1.2536 L .38308 1.25201 L .473 .595 0 r
F
.40335 1.25658 m .39625 1.25833 L .38308 1.25201 L .453 .565 0 r
F
.41675 1.26191 m .39625 1.25833 L .40335 1.25658 L .438 .533 0 r
F
.423 1.26011 m .41675 1.26191 L .40335 1.25658 L .418 .495 0 r
F
.43638 1.26458 m .41675 1.26191 L .423 1.26011 L .396 .445 0 r
F
.5089 1.01563 m .50674 1.01099 L .50996 1.0159 L .311 .309 0 r
F
.5089 1.01563 m .50462 1.01045 L .50674 1.01099 L F
.45189 .49993 m .48304 .48708 L .48411 .49344 L 1 .979 0 r
F
.45189 .49993 m .44965 .49356 L .48304 .48708 L F
.52199 1.02175 m .53086 1.02266 L .53212 1.02377 L .322 .327 0 r
F
.52127 1.02118 m .53086 1.02266 L .52199 1.02175 L .321 .326 0 r
F
.5351 1.02786 m .5461 1.03135 L .54638 1.03269 L .337 .349 0 r
F
.53468 1.02692 m .5461 1.03135 L .5351 1.02786 L .337 .348 0 r
F
.20301 .89191 m .20095 .86885 L .21152 .87214 L .988 .821 0 r
F
.20301 .89191 m .1922 .88926 L .20095 .86885 L F
.59069 1.05137 m .60065 1.0593 L .58969 1.05439 L .422 .468 0 r
F
.57958 1.04703 m .59069 1.05137 L .58969 1.05439 L .402 .439 0 r
F
.52522 1.27938 m .52618 1.27876 L .5116 1.27681 L .214 0 0 r
F
.52522 1.27938 m .5116 1.27681 L .51171 1.27655 L F
.26316 1.23584 m .24093 1.22298 L .25118 1.22229 L .736 .767 0 r
F
.27291 1.2347 m .26316 1.23584 L .25118 1.22229 L .723 .758 0 r
F
.55748 1.03661 m .56848 1.04266 L .55739 1.03828 L .367 .392 0 r
F
.54638 1.03269 m .55748 1.03661 L .55739 1.03828 L .351 .368 0 r
F
.34759 .92697 m .34442 .91065 L .3544 .91711 L .855 .658 0 r
F
.34759 .92697 m .3372 .92154 L .34442 .91065 L F
.50996 1.0159 m .50892 1.01162 L .51104 1.01621 L .311 .31 0 r
F
.50996 1.0159 m .50674 1.01099 L .50892 1.01162 L F
.34529 1.24904 m .32348 1.24122 L .33273 1.24007 L .595 .69 0 r
F
.35389 1.24756 m .34529 1.24904 L .33273 1.24007 L .572 .672 0 r
F
.52127 1.02118 m .52942 1.02152 L .53086 1.02266 L .321 .326 0 r
F
.52047 1.02061 m .52942 1.02152 L .52127 1.02118 L .32 .324 0 r
F
.48514 1.0039 m .47835 .99773 L .48707 1.00366 L .316 .313 0 r
F
.48514 1.0039 m .47577 .99804 L .47835 .99773 L F
.78909 .78261 m .81348 .79774 L .80318 .79964 L .867 .82 0 r
F
.77926 .78507 m .78909 .78261 L .80318 .79964 L .859 .815 0 r
F
.60653 .76871 m .62909 .77129 L .62244 .77456 L .611 .716 0 r
F
.56463 .76714 m .56819 .76385 L .58492 .76743 L .476 .598 0 r
F
.54841 .76452 m .56819 .76385 L .56463 .76714 L .453 .534 0 r
F
.48491 1.2713 m .48263 1.27257 L .46852 1.26986 L .187 .121 0 r
F
.49824 1.27397 m .48263 1.27257 L .48491 1.2713 L .088 .112 0 r
F
.48411 .49344 m .48304 .48708 L .51676 .48326 L 1 .966 0 r
F
.51104 1.01621 m .51115 1.01235 L .51216 1.01657 L .312 .312 0 r
F
.51104 1.01621 m .50892 1.01162 L .51115 1.01235 L F
.52047 1.02061 m .52781 1.02038 L .52942 1.02152 L .32 .324 0 r
F
.51959 1.02003 m .52781 1.02038 L .52047 1.02061 L .319 .323 0 r
F
.46368 .99277 m .45701 .98572 L .4664 .992 L .338 .339 0 r
F
.46368 .99277 m .45376 .9867 L .45701 .98572 L F
.5461 1.03135 m .55748 1.03661 L .54638 1.03269 L .351 .37 0 r
F
.3372 .92154 m .33443 .90451 L .34442 .91065 L .89 .681 0 r
F
.3372 .92154 m .32681 .91637 L .33443 .90451 L F
.60181 1.05565 m .61161 1.06419 L .60065 1.0593 L .456 .497 0 r
F
.59069 1.05137 m .60181 1.05565 L .60065 1.0593 L .422 .468 0 r
F
.51216 1.01657 m .5134 1.01316 L .51328 1.01697 L .313 .314 0 r
F
.51216 1.01657 m .51115 1.01235 L .5134 1.01316 L F
.51959 1.02003 m .52605 1.01925 L .52781 1.02038 L .319 .323 0 r
F
.51864 1.01947 m .52605 1.01925 L .51959 1.02003 L .318 .322 0 r
F
.49726 1.00942 m .49174 1.00376 L .4989 1.0095 L .307 .303 0 r
F
.49726 1.00942 m .48928 1.00362 L .49174 1.00376 L F
.6923 .77537 m .7167 .78381 L .70758 .78639 L .772 .787 0 r
F
.68389 .77836 m .6923 .77537 L .70758 .78639 L .755 .778 0 r
F
.51328 1.01697 m .51565 1.01404 L .5144 1.01741 L .314 .315 0 r
F
.51328 1.01697 m .5134 1.01316 L .51565 1.01404 L F
.51864 1.01947 m .52415 1.01814 L .52605 1.01925 L .318 .322 0 r
F
.51764 1.01892 m .52415 1.01814 L .51864 1.01947 L .317 .321 0 r
F
.53468 1.02692 m .54547 1.02991 L .5461 1.03135 L .337 .348 0 r
F
.53404 1.02592 m .54547 1.02991 L .53468 1.02692 L .335 .347 0 r
F
.73502 .77839 m .75966 .7898 L .74989 .79206 L .821 .804 0 r
F
.72585 .78114 m .73502 .77839 L .74989 .79206 L .809 .798 0 r
F
.72078 1.48158 m .70015 1.50057 L .69421 1.49598 L 1 .946 0 r
F
.72078 1.48158 m .72763 1.48615 L .70015 1.50057 L F
.5144 1.01741 m .51787 1.01499 L .51551 1.01789 L .315 .317 0 r
F
.5144 1.01741 m .51565 1.01404 L .51787 1.01499 L F
.51764 1.01892 m .52214 1.01705 L .52415 1.01814 L .317 .321 0 r
F
.51659 1.01839 m .52214 1.01705 L .51764 1.01892 L .317 .32 0 r
F
.53862 1.28305 m .52618 1.27876 L .52522 1.27938 L .388 0 0 r
F
.53862 1.28305 m .54066 1.28131 L .52618 1.27876 L F
.51551 1.01789 m .52004 1.016 L .51659 1.01839 L .316 .319 0 r
F
.51551 1.01789 m .51787 1.01499 L .52004 1.016 L F
.51659 1.01839 m .52004 1.016 L .52214 1.01705 L .317 .32 0 r
F
.21028 1.22543 m .20009 1.22637 L .18852 1.20926 L .795 .795 0 r
F
.37518 1.2536 m .35389 1.24756 L .36251 1.24621 L .524 .64 0 r
F
.38308 1.25201 m .37518 1.2536 L .36251 1.24621 L .498 .616 0 r
F
.44171 1.26283 m .43638 1.26458 L .423 1.26011 L .372 .402 0 r
F
.45484 1.26662 m .43638 1.26458 L .44171 1.26283 L .337 .328 0 r
F
.32681 .91637 m .32442 .89869 L .33443 .90451 L .918 .702 0 r
F
.32681 .91637 m .3164 .91144 L .32442 .89869 L F
.6598 .77221 m .68389 .77836 L .6755 .78124 L .724 .77 0 r
F
.65222 .77542 m .6598 .77221 L .6755 .78124 L .703 .757 0 r
F
.56861 1.04049 m .57958 1.04703 L .56848 1.04266 L .385 .419 0 r
F
.55748 1.03661 m .56861 1.04049 L .56848 1.04266 L .367 .392 0 r
F
.61294 1.05985 m .62258 1.06902 L .61161 1.06419 L .498 .525 0 r
F
.60181 1.05565 m .61294 1.05985 L .61161 1.06419 L .456 .497 0 r
F
.45376 .9867 m .44762 .97915 L .45701 .98572 L .351 .351 0 r
F
.45376 .9867 m .44384 .98041 L .44762 .97915 L F
.31426 1.24249 m .29246 1.23268 L .30226 1.2318 L .657 .724 0 r
F
.32348 1.24122 m .31426 1.24249 L .30226 1.2318 L .638 .711 0 r
F
.47185 1.26835 m .46852 1.26986 L .45484 1.26662 L .258 .194 0 r
F
.48491 1.2713 m .46852 1.26986 L .47185 1.26835 L .187 .121 0 r
F
.4989 1.0095 m .49442 1.00409 L .50068 1.0097 L .304 .298 0 r
F
.4989 1.0095 m .49174 1.00376 L .49442 1.00409 L F
.47577 .99804 m .46961 .99161 L .47835 .99773 L .316 .311 0 r
F
.47577 .99804 m .4664 .992 L .46961 .99161 L F
.3164 .91144 m .3144 .89316 L .32442 .89869 L .941 .721 0 r
F
.3164 .91144 m .30598 .90676 L .3144 .89316 L F
.48707 1.00366 m .48129 .99769 L .48928 1.00362 L .307 .301 0 r
F
.48707 1.00366 m .47835 .99773 L .48129 .99769 L F
.53404 1.02592 m .54452 1.02839 L .54547 1.02991 L .335 .347 0 r
F
.53318 1.02486 m .54452 1.02839 L .53404 1.02592 L .333 .344 0 r
F
.62407 1.06394 m .63355 1.07375 L .62258 1.06902 L .541 .552 0 r
F
.61294 1.05985 m .62407 1.06394 L .62258 1.06902 L .498 .525 0 r
F
.5461 1.03135 m .55712 1.03478 L .55748 1.03661 L .351 .37 0 r
F
.54547 1.02991 m .55712 1.03478 L .5461 1.03135 L .35 .369 0 r
F
.44384 .98041 m .43822 .97224 L .44762 .97915 L .368 .368 0 r
F
.44384 .98041 m .43391 .97386 L .43822 .97224 L F
.54841 .76452 m .55085 .76138 L .56819 .76385 L .453 .534 0 r
F
.53179 .7629 m .55085 .76138 L .54841 .76452 L .418 .428 0 r
F
.55712 1.03478 m .56861 1.04049 L .55748 1.03661 L .368 .394 0 r
F
.57974 1.04431 m .59069 1.05137 L .57958 1.04703 L .405 .447 0 r
F
.56861 1.04049 m .57974 1.04431 L .57958 1.04703 L .385 .419 0 r
F
.30598 .90676 m .30435 .8879 L .3144 .89316 L .959 .738 0 r
F
.30598 .90676 m .29554 .90229 L .30435 .8879 L F
.27291 1.2347 m .25118 1.22229 L .26144 1.22169 L .723 .758 0 r
F
.28267 1.23365 m .27291 1.2347 L .26144 1.22169 L .709 .749 0 r
F
.63522 1.0679 m .64453 1.07835 L .63355 1.07375 L .584 .577 0 r
F
.62407 1.06394 m .63522 1.0679 L .63355 1.07375 L .541 .552 0 r
F
.78909 .78261 m .79894 .78009 L .81348 .79774 L .867 .82 0 r
F
.50068 1.0097 m .49729 1.0046 L .5026 1.01002 L .301 .294 0 r
F
.50068 1.0097 m .49442 1.00409 L .49729 1.0046 L F
.53318 1.02486 m .54324 1.0268 L .54452 1.02839 L .333 .344 0 r
F
.53212 1.02377 m .54324 1.0268 L .53318 1.02486 L .331 .341 0 r
F
.43391 .97386 m .42882 .96496 L .43822 .97224 L .391 .391 0 r
F
.43391 .97386 m .42398 .96705 L .42882 .96496 L F
.21028 1.22543 m .18852 1.20926 L .19914 1.20887 L .795 .795 0 r
F
.22048 1.22455 m .21028 1.22543 L .19914 1.20887 L .786 .789 0 r
F
.55182 1.28865 m .54066 1.28131 L .53862 1.28305 L .54 0 0 r
F
.55182 1.28865 m .55491 1.28587 L .54066 1.28131 L F
.58492 .76743 m .58958 .76393 L .60653 .76871 L .548 .673 0 r
F
.56819 .76385 m .58958 .76393 L .58492 .76743 L .514 .644 0 r
F
.64637 1.07171 m .65551 1.0828 L .64453 1.07835 L .625 .601 0 r
F
.63522 1.0679 m .64637 1.07171 L .64453 1.07835 L .584 .577 0 r
F
.83613 1.11212 m .84159 1.13274 L .83069 1.13075 L .913 .811 0 r
F
.83613 1.11212 m .84728 1.1135 L .84159 1.13274 L F
.4664 .992 m .46086 .98524 L .46961 .99161 L .319 .31 0 r
F
.4664 .992 m .45701 .98572 L .46086 .98524 L F
.53179 .7629 m .53308 .76011 L .55085 .76138 L .418 .428 0 r
F
.51496 .76229 m .53308 .76011 L .53179 .7629 L .36 .26 0 r
F
.29554 .90229 m .29429 .88289 L .30435 .8879 L .974 .753 0 r
F
.29554 .90229 m .28509 .89802 L .29429 .88289 L F
.48928 1.00362 m .48456 .99793 L .49174 1.00376 L .299 .289 0 r
F
.48928 1.00362 m .48129 .99769 L .48456 .99793 L F
.42398 .96705 m .41941 .95727 L .42882 .96496 L .421 .419 0 r
F
.42398 .96705 m .41405 .96001 L .41941 .95727 L F
.49811 .7627 m .51508 .76013 L .51496 .76229 L .258 .137 0 r
F
.49811 .7627 m .49706 .76159 L .51508 .76013 L F
.68225 1.48662 m .66099 1.50475 L .65595 1.50019 L 1 .983 0 r
F
.68225 1.48662 m .68824 1.49134 L .66099 1.50475 L F
.5026 1.01002 m .50033 1.00528 L .50462 1.01045 L .3 .293 0 r
F
.5026 1.01002 m .49729 1.0046 L .50033 1.00528 L F
.82498 1.11066 m .83069 1.13075 L .81979 1.1287 L .908 .805 0 r
F
.82498 1.11066 m .83613 1.11212 L .83069 1.13075 L F
.53212 1.02377 m .54165 1.02516 L .54324 1.0268 L .331 .341 0 r
F
.53086 1.02266 m .54165 1.02516 L .53212 1.02377 L .328 .337 0 r
F
.4592 1.26503 m .45484 1.26662 L .44171 1.26283 L .309 .285 0 r
F
.47185 1.26835 m .45484 1.26662 L .4592 1.26503 L .258 .194 0 r
F
.59089 1.04806 m .60181 1.05565 L .59069 1.05137 L .425 .477 0 r
F
.57974 1.04431 m .59089 1.04806 L .59069 1.05137 L .405 .447 0 r
F
.35389 1.24756 m .33273 1.24007 L .342 1.23903 L .572 .672 0 r
F
.36251 1.24621 m .35389 1.24756 L .342 1.23903 L .548 .653 0 r
F
.54547 1.02991 m .5563 1.03283 L .55712 1.03478 L .35 .369 0 r
F
.54452 1.02839 m .5563 1.03283 L .54547 1.02991 L .348 .367 0 r
F
.65753 1.07534 m .66649 1.08707 L .65551 1.0828 L .663 .623 0 r
F
.64637 1.07171 m .65753 1.07534 L .65551 1.0828 L .625 .601 0 r
F
.63577 .76787 m .6598 .77221 L .65222 .77542 L .688 .758 0 r
F
.62909 .77129 m .63577 .76787 L .65222 .77542 L .662 .741 0 r
F
.51496 .76229 m .51508 .76013 L .53308 .76011 L .36 .26 0 r
F
.74421 .77555 m .76945 .78747 L .75966 .7898 L .832 .81 0 r
F
.73502 .77839 m .74421 .77555 L .75966 .7898 L .821 .804 0 r
F
.81383 1.10913 m .81979 1.1287 L .80888 1.12656 L .903 .799 0 r
F
.81383 1.10913 m .82498 1.11066 L .81979 1.1287 L F
.47835 .99773 m .47328 .99159 L .48129 .99769 L .302 .29 0 r
F
.47835 .99773 m .46961 .99161 L .47328 .99159 L F
.41405 .96001 m .41 .94922 L .41941 .95727 L .481 .451 0 r
F
.41405 .96001 m .40412 .95279 L .41 .94922 L F
.56816 1.03814 m .57974 1.04431 L .56861 1.04049 L .386 .422 0 r
F
.55712 1.03478 m .56816 1.03814 L .56861 1.04049 L .368 .394 0 r
F
.70074 .77227 m .72585 .78114 L .7167 .78381 L .787 .795 0 r
F
.6923 .77537 m .70074 .77227 L .7167 .78381 L .772 .787 0 r
F
.66869 1.0788 m .67747 1.09115 L .66649 1.08707 L .698 .644 0 r
F
.65753 1.07534 m .66869 1.0788 L .66649 1.08707 L .663 .623 0 r
F
.40335 1.25658 m .38308 1.25201 L .391 1.25057 L .453 .565 0 r
F
.41048 1.255 m .40335 1.25658 L .391 1.25057 L .436 .533 0 r
F
.423 1.26011 m .40335 1.25658 L .41048 1.255 L .418 .495 0 r
F
.80267 1.10753 m .80888 1.12656 L .79796 1.12434 L .897 .793 0 r
F
.80267 1.10753 m .81383 1.10913 L .80888 1.12656 L F
.50462 1.01045 m .50351 1.00611 L .50674 1.01099 L .3 .293 0 r
F
.50462 1.01045 m .50033 1.00528 L .50351 1.00611 L F
.28509 .89802 m .28421 .87808 L .29429 .88289 L .986 .767 0 r
F
.28509 .89802 m .27463 .89392 L .28421 .87808 L F
.53086 1.02266 m .53976 1.02349 L .54165 1.02516 L .328 .337 0 r
F
.52942 1.02152 m .53976 1.02349 L .53086 1.02266 L .325 .333 0 r
F
.58239 1.31543 m .57289 1.28779 L .56884 1.29582 L 1 .08 0 r
F
.58239 1.31543 m .58759 1.32034 L .57289 1.28779 L F
.5563 1.03283 m .56816 1.03814 L .55712 1.03478 L .367 .394 0 r
F
.40412 .95279 m .40059 .94087 L .41 .94922 L .556 .485 0 r
F
.40412 .95279 m .39419 .94547 L .40059 .94087 L F
.79151 1.10583 m .79796 1.12434 L .78704 1.12202 L .89 .785 0 r
F
.79151 1.10583 m .80267 1.10753 L .79796 1.12434 L F
.32348 1.24122 m .30226 1.2318 L .31208 1.23103 L .638 .711 0 r
F
.33273 1.24007 m .32348 1.24122 L .31208 1.23103 L .618 .697 0 r
F
.66869 1.0788 m .67985 1.08207 L .67747 1.09115 L .698 .644 0 r
F
.67985 1.08207 m .68845 1.09503 L .67747 1.09115 L .729 .663 0 r
F
.42927 1.25849 m .423 1.26011 L .41048 1.255 L .398 .457 0 r
F
.44171 1.26283 m .423 1.26011 L .42927 1.25849 L .372 .402 0 r
F
.60653 .76871 m .61223 .76517 L .62909 .77129 L .611 .716 0 r
F
.58958 .76393 m .61223 .76517 L .60653 .76871 L .586 .705 0 r
F
.7139 1.47692 m .69421 1.49598 L .68824 1.49134 L 1 .946 0 r
F
.7139 1.47692 m .72078 1.48158 L .69421 1.49598 L F
.45701 .98572 m .45209 .97854 L .46086 .98524 L .326 .313 0 r
F
.45701 .98572 m .44762 .97915 L .45209 .97854 L F
.78035 1.10404 m .78704 1.12202 L .77611 1.11959 L .882 .778 0 r
F
.78035 1.10404 m .79151 1.10583 L .78704 1.12202 L F
.60206 1.05169 m .61294 1.05985 L .60181 1.05565 L .457 .506 0 r
F
.59089 1.04806 m .60206 1.05169 L .60181 1.05565 L .425 .477 0 r
F
.39419 .94547 m .39118 .93235 L .40059 .94087 L .637 .52 0 r
F
.39419 .94547 m .38425 .93814 L .39118 .93235 L F
.69102 1.08515 m .69942 1.09871 L .68845 1.09503 L .756 .68 0 r
F
.67985 1.08207 m .69102 1.08515 L .68845 1.09503 L .729 .663 0 r
F
.61223 .76517 m .63577 .76787 L .62909 .77129 L .643 .739 0 r
F
.22048 1.22455 m .19914 1.20887 L .20978 1.20854 L .786 .789 0 r
F
.2307 1.22373 m .22048 1.22455 L .20978 1.20854 L .777 .783 0 r
F
.49174 1.00376 m .48813 .99842 L .49442 1.00409 L .292 .279 0 r
F
.49174 1.00376 m .48456 .99793 L .48813 .99842 L F
.50674 1.01099 m .50679 1.00709 L .50892 1.01162 L .301 .295 0 r
F
.50674 1.01099 m .50351 1.00611 L .50679 1.00709 L F
.76919 1.10215 m .77611 1.11959 L .76517 1.11705 L .873 .769 0 r
F
.76919 1.10215 m .78035 1.10404 L .77611 1.11959 L F
.52942 1.02152 m .5376 1.02181 L .53976 1.02349 L .325 .333 0 r
F
.52781 1.02038 m .5376 1.02181 L .52942 1.02152 L .322 .329 0 r
F
.6674 .76888 m .6923 .77537 L .68389 .77836 L .744 .782 0 r
F
.6598 .77221 m .6674 .76888 L .68389 .77836 L .724 .77 0 r
F
.38308 1.25201 m .36251 1.24621 L .37116 1.24499 L .498 .616 0 r
F
.391 1.25057 m .38308 1.25201 L .37116 1.24499 L .473 .59 0 r
F
.28267 1.23365 m .26144 1.22169 L .27171 1.22116 L .709 .749 0 r
F
.29246 1.23268 m .28267 1.23365 L .27171 1.22116 L .694 .739 0 r
F
.70219 1.08805 m .71039 1.10219 L .69942 1.09871 L .781 .697 0 r
F
.69102 1.08515 m .70219 1.08805 L .69942 1.09871 L .756 .68 0 r
F
.54452 1.02839 m .55503 1.03077 L .5563 1.03283 L .348 .367 0 r
F
.54324 1.0268 m .55503 1.03077 L .54452 1.02839 L .345 .363 0 r
F
.75802 1.10014 m .76517 1.11705 L .75422 1.11438 L .863 .759 0 r
F
.75802 1.10014 m .76919 1.10215 L .76517 1.11705 L F
.38425 .93814 m .38177 .92384 L .39118 .93235 L .716 .553 0 r
F
.38425 .93814 m .37431 .93091 L .38177 .92384 L F
.71335 1.09078 m .72136 1.10549 L .71039 1.10219 L .802 .711 0 r
F
.70219 1.08805 m .71335 1.09078 L .71039 1.10219 L .781 .697 0 r
F
.27463 .89392 m .27411 .87347 L .28421 .87808 L .995 .779 0 r
F
.27463 .89392 m .26415 .88999 L .27411 .87347 L F
.74686 1.09801 m .75422 1.11438 L .74327 1.11157 L .85 .749 0 r
F
.74686 1.09801 m .75802 1.10014 L .75422 1.11438 L F
.72452 1.09334 m .73232 1.10861 L .72136 1.10549 L .82 .725 0 r
F
.71335 1.09078 m .72452 1.09334 L .72136 1.10549 L .802 .711 0 r
F
.73569 1.09575 m .74327 1.11157 L .73232 1.10861 L .836 .738 0 r
F
.73569 1.09575 m .74686 1.09801 L .74327 1.11157 L F
.72452 1.09334 m .73569 1.09575 L .73232 1.10861 L .82 .725 0 r
F
.50892 1.01162 m .51014 1.00819 L .51115 1.01235 L .302 .297 0 r
F
.50892 1.01162 m .50679 1.00709 L .51014 1.00819 L F
.52781 1.02038 m .53518 1.02012 L .5376 1.02181 L .322 .329 0 r
F
.52605 1.01925 m .53518 1.02012 L .52781 1.02038 L .32 .326 0 r
F
.57922 1.04139 m .59089 1.04806 L .57974 1.04431 L .405 .451 0 r
F
.56816 1.03814 m .57922 1.04139 L .57974 1.04431 L .386 .422 0 r
F
.37431 .93091 m .37234 .91549 L .38177 .92384 L .787 .586 0 r
F
.37431 .93091 m .36436 .92388 L .37234 .91549 L F
.61324 1.05521 m .62407 1.06394 L .61294 1.05985 L .495 .534 0 r
F
.60206 1.05169 m .61324 1.05521 L .61294 1.05985 L .457 .506 0 r
F
.56819 .76385 m .57177 .76032 L .58958 .76393 L .514 .644 0 r
F
.55085 .76138 m .57177 .76032 L .56819 .76385 L .484 .598 0 r
F
.51115 1.01235 m .51352 1.00941 L .5134 1.01316 L .304 .301 0 r
F
.51115 1.01235 m .51014 1.00819 L .51352 1.00941 L F
.44762 .97915 m .44332 .97145 L .45209 .97854 L .338 .321 0 r
F
.44762 .97915 m .43822 .97224 L .44332 .97145 L F
.46961 .99161 m .46525 .98526 L .47328 .99159 L .298 .28 0 r
F
.46961 .99161 m .46086 .98524 L .46525 .98526 L F
.52605 1.01925 m .53253 1.01845 L .53518 1.02012 L .32 .326 0 r
F
.52415 1.01814 m .53253 1.01845 L .52605 1.01925 L .317 .322 0 r
F
.48129 .99769 m .47736 .99196 L .48456 .99793 L .288 .271 0 r
F
.48129 .99769 m .47328 .99159 L .47736 .99196 L F
.49944 1.2731 m .49824 1.27397 L .48491 1.2713 L .067 .108 0 r
F
.51183 1.27613 m .49824 1.27397 L .49944 1.2731 L 0 .093 0 r
F
.51183 1.27613 m .51171 1.27655 L .49824 1.27397 L F
.36436 .92388 m .36291 .90745 L .37234 .91549 L .847 .617 0 r
F
.36436 .92388 m .3544 .91711 L .36291 .90745 L F
.44706 1.26127 m .44171 1.26283 L .42927 1.25849 L .347 .361 0 r
F
.4592 1.26503 m .44171 1.26283 L .44706 1.26127 L .309 .285 0 r
F
.49442 1.00409 m .49197 .99916 L .49729 1.0046 L .287 .273 0 r
F
.49442 1.00409 m .48813 .99842 L .49197 .99916 L F
.26415 .88999 m .26399 .86902 L .27411 .87347 L 1 .79 0 r
F
.26415 .88999 m .25365 .88619 L .26399 .86902 L F
.5134 1.01316 m .5169 1.01074 L .51565 1.01404 L .306 .304 0 r
F
.5134 1.01316 m .51352 1.00941 L .5169 1.01074 L F
.52415 1.01814 m .52969 1.0168 L .53253 1.01845 L .317 .322 0 r
F
.52214 1.01705 m .52969 1.0168 L .52415 1.01814 L .315 .319 0 r
F
.5563 1.03283 m .56714 1.03563 L .56816 1.03814 L .367 .394 0 r
F
.55503 1.03077 m .56714 1.03563 L .5563 1.03283 L .364 .391 0 r
F
.4872 1.27012 m .48491 1.2713 L .47185 1.26835 L .161 .117 0 r
F
.49944 1.2731 m .48491 1.2713 L .4872 1.27012 L .067 .108 0 r
F
.54324 1.0268 m .55333 1.02863 L .55503 1.03077 L .345 .363 0 r
F
.54165 1.02516 m .55333 1.02863 L .54324 1.0268 L .341 .358 0 r
F
.52424 1.2795 m .52522 1.27938 L .51171 1.27655 L .197 0 0 r
F
.52424 1.2795 m .51171 1.27655 L .51183 1.27613 L F
.51565 1.01404 m .52024 1.01215 L .51787 1.01499 L .308 .308 0 r
F
.51565 1.01404 m .5169 1.01074 L .52024 1.01215 L F
.52214 1.01705 m .52667 1.01519 L .52969 1.0168 L .315 .319 0 r
F
.52004 1.016 m .52667 1.01519 L .52214 1.01705 L .313 .315 0 r
F
.56714 1.03563 m .57922 1.04139 L .56816 1.03814 L .384 .422 0 r
F
.75343 .77264 m .77926 .78507 L .76945 .78747 L .842 .815 0 r
F
.74421 .77555 m .75343 .77264 L .76945 .78747 L .832 .81 0 r
F
.51787 1.01499 m .52351 1.01364 L .52004 1.016 L .311 .312 0 r
F
.51787 1.01499 m .52024 1.01215 L .52351 1.01364 L F
.52004 1.016 m .52351 1.01364 L .52667 1.01519 L .313 .315 0 r
F
.3544 .91711 m .35345 .89981 L .36291 .90745 L .897 .646 0 r
F
.3544 .91711 m .34442 .91065 L .35345 .89981 L F
.5647 1.29772 m .55491 1.28587 L .55182 1.28865 L .765 .028 0 r
F
.5647 1.29772 m .56884 1.29582 L .55491 1.28587 L F
.2307 1.22373 m .20978 1.20854 L .22042 1.20828 L .777 .783 0 r
F
.24093 1.22298 m .2307 1.22373 L .22042 1.20828 L .767 .776 0 r
F
.62443 1.05858 m .63522 1.0679 L .62407 1.06394 L .534 .56 0 r
F
.61324 1.05521 m .62443 1.05858 L .62407 1.06394 L .495 .534 0 r
F
.43822 .97224 m .43454 .96387 L .44332 .97145 L .357 .336 0 r
F
.43822 .97224 m .42882 .96496 L .43454 .96387 L F
.36251 1.24621 m .342 1.23903 L .3513 1.23812 L .548 .653 0 r
F
.37116 1.24499 m .36251 1.24621 L .3513 1.23812 L .523 .631 0 r
F
.5903 1.04452 m .60206 1.05169 L .59089 1.04806 L .424 .481 0 r
F
.57922 1.04139 m .5903 1.04452 L .59089 1.04806 L .405 .451 0 r
F
.25365 .88619 m .25385 .86471 L .26399 .86902 L 1 .8 0 r
F
.25365 .88619 m .24314 .88253 L .25385 .86471 L F
.7092 .76907 m .73502 .77839 L .72585 .78114 L .8 .803 0 r
F
.70074 .77227 m .7092 .76907 L .72585 .78114 L .787 .795 0 r
F
.4752 1.26698 m .47185 1.26835 L .4592 1.26503 L .231 .167 0 r
F
.4872 1.27012 m .47185 1.26835 L .4752 1.26698 L .161 .117 0 r
F
.34442 .91065 m .34398 .89261 L .35345 .89981 L .936 .673 0 r
F
.34442 .91065 m .33443 .90451 L .34398 .89261 L F
.33273 1.24007 m .31208 1.23103 L .32192 1.23037 L .618 .697 0 r
F
.342 1.23903 m .33273 1.24007 L .32192 1.23037 L .596 .681 0 r
F
.67624 1.48183 m .65595 1.50019 L .6509 1.49561 L 1 .987 0 r
F
.67624 1.48183 m .68225 1.48662 L .65595 1.50019 L F
.49729 1.0046 m .49603 1.00013 L .50033 1.00528 L .284 .269 0 r
F
.49729 1.0046 m .49197 .99916 L .49603 1.00013 L F
.29246 1.23268 m .27171 1.22116 L .282 1.22072 L .694 .739 0 r
F
.30226 1.2318 m .29246 1.23268 L .282 1.22072 L .678 .728 0 r
F
.54165 1.02516 m .55121 1.02645 L .55333 1.02863 L .341 .358 0 r
F
.53976 1.02349 m .55121 1.02645 L .54165 1.02516 L .337 .352 0 r
F
.74548 1.46635 m .72763 1.48615 L .72078 1.48158 L 1 .916 0 r
F
.74548 1.46635 m .75319 1.4708 L .72763 1.48615 L F
.53657 1.28367 m .52522 1.27938 L .52424 1.2795 L .346 0 0 r
F
.53657 1.28367 m .53862 1.28305 L .52522 1.27938 L F
.64247 .76429 m .6674 .76888 L .6598 .77221 L .712 .773 0 r
F
.63577 .76787 m .64247 .76429 L .6598 .77221 L .688 .758 0 r
F
.46086 .98524 m .45721 .97862 L .46525 .98526 L .296 .271 0 r
F
.46086 .98524 m .45209 .97854 L .45721 .97862 L F
.55085 .76138 m .5533 .75797 L .57177 .76032 L .484 .598 0 r
F
.53308 .76011 m .5533 .75797 L .55085 .76138 L .463 .521 0 r
F
.63563 1.06179 m .64637 1.07171 L .63522 1.0679 L .573 .585 0 r
F
.62443 1.05858 m .63563 1.06179 L .63522 1.0679 L .534 .56 0 r
F
.48456 .99793 m .48183 .99267 L .48813 .99842 L .276 .255 0 r
F
.48456 .99793 m .47736 .99196 L .48183 .99267 L F
.42882 .96496 m .42575 .95572 L .43454 .96387 L .384 .36 0 r
F
.42882 .96496 m .41941 .95727 L .42575 .95572 L F
.55503 1.03077 m .56557 1.03301 L .56714 1.03563 L .364 .391 0 r
F
.55333 1.02863 m .56557 1.03301 L .55503 1.03077 L .36 .386 0 r
F
.58958 .76393 m .59425 .76023 L .61223 .76517 L .586 .705 0 r
F
.57177 .76032 m .59425 .76023 L .58958 .76393 L .559 .687 0 r
F
.70701 1.47216 m .68824 1.49134 L .68225 1.48662 L 1 .946 0 r
F
.70701 1.47216 m .7139 1.47692 L .68824 1.49134 L F
.33443 .90451 m .33449 .88582 L .34398 .89261 L .968 .697 0 r
F
.33443 .90451 m .32442 .89869 L .33449 .88582 L F
.24314 .88253 m .24369 .86052 L .25385 .86471 L 1 .809 0 r
F
.24314 .88253 m .23262 .87897 L .24369 .86052 L F
.41048 1.255 m .391 1.25057 L .39895 1.2493 L .436 .533 0 r
F
.41763 1.2536 m .41048 1.255 L .39895 1.2493 L .418 .499 0 r
F
.42927 1.25849 m .41048 1.255 L .41763 1.2536 L .398 .457 0 r
F
.47328 .99159 m .47015 .9858 L .47736 .99196 L .276 .251 0 r
F
.47328 .99159 m .46525 .98526 L .47015 .9858 L F
.50033 1.00528 m .50027 1.0013 L .50351 1.00611 L .283 .269 0 r
F
.50033 1.00528 m .49603 1.00013 L .50027 1.0013 L F
.57801 1.0383 m .5903 1.04452 L .57922 1.04139 L .403 .452 0 r
F
.56714 1.03563 m .57801 1.0383 L .57922 1.04139 L .384 .422 0 r
F
.67503 .76543 m .70074 .77227 L .6923 .77537 L .762 .792 0 r
F
.6674 .76888 m .67503 .76543 L .6923 .77537 L .744 .782 0 r
F
.53976 1.02349 m .54869 1.02423 L .55121 1.02645 L .337 .352 0 r
F
.5376 1.02181 m .54869 1.02423 L .53976 1.02349 L .332 .345 0 r
F
.24093 1.22298 m .22042 1.20828 L .23108 1.20808 L .767 .776 0 r
F
.25118 1.22229 m .24093 1.22298 L .23108 1.20808 L .755 .769 0 r
F
.6014 1.04751 m .61324 1.05521 L .60206 1.05169 L .453 .51 0 r
F
.5903 1.04452 m .6014 1.04751 L .60206 1.05169 L .424 .481 0 r
F
.64685 1.06483 m .65753 1.07534 L .64637 1.07171 L .61 .608 0 r
F
.63563 1.06179 m .64685 1.06483 L .64637 1.07171 L .573 .585 0 r
F
.391 1.25057 m .37116 1.24499 L .37983 1.24393 L .473 .59 0 r
F
.39895 1.2493 m .391 1.25057 L .37983 1.24393 L .451 .561 0 r
F
.41941 .95727 m .41697 .94694 L .42575 .95572 L .424 .392 0 r
F
.41941 .95727 m .41 .94922 L .41697 .94694 L F
.56557 1.03301 m .57801 1.0383 L .56714 1.03563 L .381 .419 0 r
F
.46358 1.26359 m .4592 1.26503 L .44706 1.26127 L .284 .25 0 r
F
.4752 1.26698 m .4592 1.26503 L .46358 1.26359 L .231 .167 0 r
F
.61794 .76147 m .64247 .76429 L .63577 .76787 L .673 .759 0 r
F
.61223 .76517 m .61794 .76147 L .63577 .76787 L .643 .739 0 r
F
.53308 .76011 m .53438 .757 L .5533 .75797 L .463 .521 0 r
F
.51508 .76013 m .53438 .757 L .53308 .76011 L .431 .392 0 r
F
.32442 .89869 m .32497 .87944 L .33449 .88582 L .992 .72 0 r
F
.32442 .89869 m .3144 .89316 L .32497 .87944 L F
.43556 1.25705 m .42927 1.25849 L .41763 1.2536 L .376 .419 0 r
F
.44706 1.26127 m .42927 1.25849 L .43556 1.25705 L .347 .361 0 r
F
.76267 .76966 m .78909 .78261 L .77926 .78507 L .851 .82 0 r
F
.75343 .77264 m .76267 .76966 L .77926 .78507 L .842 .815 0 r
F
.59425 .76023 m .61794 .76147 L .61223 .76517 L .624 .734 0 r
F
.23262 .87897 m .23351 .85645 L .24369 .86052 L 1 .816 0 r
F
.23262 .87897 m .22208 .87551 L .23351 .85645 L F
.50351 1.00611 m .50465 1.00265 L .50679 1.00709 L .284 .271 0 r
F
.50351 1.00611 m .50027 1.0013 L .50465 1.00265 L F
.45209 .97854 m .44915 .97157 L .45721 .97862 L .298 .265 0 r
F
.45209 .97854 m .44332 .97145 L .44915 .97157 L F
.47921 .76483 m .49601 .75991 L .49706 .76159 L .296 .143 0 r
F
.5376 1.02181 m .54581 1.02201 L .54869 1.02423 L .332 .345 0 r
F
.53518 1.02012 m .54581 1.02201 L .5376 1.02181 L .327 .338 0 r
F
.41 .94922 m .40819 .93756 L .41697 .94694 L .506 .431 0 r
F
.41 .94922 m .40059 .94087 L .40819 .93756 L F
.65807 1.06769 m .66869 1.0788 L .65753 1.07534 L .645 .629 0 r
F
.64685 1.06483 m .65807 1.06769 L .65753 1.07534 L .61 .608 0 r
F
.48813 .99842 m .48662 .99371 L .49197 .99916 L .267 .244 0 r
F
.48813 .99842 m .48183 .99267 L .48662 .99371 L F
.55333 1.02863 m .56345 1.03032 L .56557 1.03301 L .36 .386 0 r
F
.55121 1.02645 m .56345 1.03032 L .55333 1.02863 L .354 .379 0 r
F
.51508 .76013 m .51521 .75756 L .53438 .757 L .431 .392 0 r
F
.49706 .76159 m .51521 .75756 L .51508 .76013 L .379 .202 0 r
F
.30226 1.2318 m .282 1.22072 L .29231 1.22038 L .678 .728 0 r
F
.31208 1.23103 m .30226 1.2318 L .29231 1.22038 L .66 .716 0 r
F
.49706 .76159 m .49601 .75991 L .51521 .75756 L .379 .202 0 r
F
.54869 1.28923 m .53862 1.28305 L .53657 1.28367 L .48 0 0 r
F
.54869 1.28923 m .55182 1.28865 L .53862 1.28305 L F
.61251 1.05035 m .62443 1.05858 L .61324 1.05521 L .488 .538 0 r
F
.6014 1.04751 m .61251 1.05035 L .61324 1.05521 L .453 .51 0 r
F
.40059 .94087 m .39941 .9277 L .40819 .93756 L .609 .473 0 r
F
.40059 .94087 m .39118 .93235 L .39941 .9277 L F
.3144 .89316 m .31543 .8734 L .32497 .87944 L 1 .74 0 r
F
.3144 .89316 m .30435 .8879 L .31543 .8734 L F
.50679 1.00709 m .50912 1.00415 L .51014 1.00819 L .287 .275 0 r
F
.50679 1.00709 m .50465 1.00265 L .50912 1.00415 L F
.53518 1.02012 m .54258 1.01979 L .54581 1.02201 L .327 .338 0 r
F
.53253 1.01845 m .54258 1.01979 L .53518 1.02012 L .322 .33 0 r
F
.342 1.23903 m .32192 1.23037 L .33178 1.22983 L .596 .681 0 r
F
.3513 1.23812 m .342 1.23903 L .33178 1.22983 L .573 .663 0 r
F
.71768 .76579 m .74421 .77555 L .73502 .77839 L .813 .81 0 r
F
.7092 .76907 m .71768 .76579 L .73502 .77839 L .8 .803 0 r
F
.6693 1.07037 m .67985 1.08207 L .66869 1.0788 L .676 .649 0 r
F
.65807 1.06769 m .6693 1.07037 L .66869 1.0788 L .645 .629 0 r
F
.37116 1.24499 m .3513 1.23812 L .36061 1.23735 L .523 .631 0 r
F
.37983 1.24393 m .37116 1.24499 L .36061 1.23735 L .497 .608 0 r
F
.5889 1.04083 m .6014 1.04751 L .5903 1.04452 L .421 .481 0 r
F
.57801 1.0383 m .5889 1.04083 L .5903 1.04452 L .403 .452 0 r
F
.25118 1.22229 m .23108 1.20808 L .24175 1.20796 L .755 .769 0 r
F
.26144 1.22169 m .25118 1.22229 L .24175 1.20796 L .743 .761 0 r
F
.22208 .87551 m .22332 .85246 L .23351 .85645 L 1 .823 0 r
F
.22208 .87551 m .21152 .87214 L .22332 .85246 L F
.39118 .93235 m .39063 .9176 L .39941 .9277 L .713 .515 0 r
F
.39118 .93235 m .38177 .92384 L .39063 .9176 L F
.46525 .98526 m .46291 .97939 L .47015 .9858 L .263 .228 0 r
F
.46525 .98526 m .45721 .97862 L .46291 .97939 L F
.47736 .99196 m .4755 .98681 L .48183 .99267 L .256 .225 0 r
F
.47736 .99196 m .47015 .9858 L .4755 .98681 L F
.73775 1.46179 m .72078 1.48158 L .7139 1.47692 L 1 .914 0 r
F
.73775 1.46179 m .74548 1.46635 L .72078 1.48158 L F
.51014 1.00819 m .51364 1.00578 L .51352 1.00941 L .29 .281 0 r
F
.51014 1.00819 m .50912 1.00415 L .51364 1.00578 L F
.53253 1.01845 m .53905 1.0176 L .54258 1.01979 L .322 .33 0 r
F
.52969 1.0168 m .53905 1.0176 L .53253 1.01845 L .317 .323 0 r
F
.57177 .76032 m .57536 .75657 L .59425 .76023 L .559 .687 0 r
F
.5533 .75797 m .57536 .75657 L .57177 .76032 L .529 .658 0 r
F
.44332 .97145 m .44109 .96397 L .44915 .97157 L .308 .265 0 r
F
.44332 .97145 m .43454 .96387 L .44109 .96397 L F
.56557 1.03301 m .57613 1.03511 L .57801 1.0383 L .381 .419 0 r
F
.56345 1.03032 m .57613 1.03511 L .56557 1.03301 L .376 .413 0 r
F
.45243 1.25987 m .44706 1.26127 L .43556 1.25705 L .324 .323 0 r
F
.46358 1.26359 m .44706 1.26127 L .45243 1.25987 L .284 .25 0 r
F
.6693 1.07037 m .68054 1.07287 L .67985 1.08207 L .676 .649 0 r
F
.68054 1.07287 m .69102 1.08515 L .67985 1.08207 L .705 .667 0 r
F
.67021 1.47694 m .6509 1.49561 L .64584 1.49101 L 1 .99 0 r
F
.67021 1.47694 m .67624 1.48183 L .6509 1.49561 L F
.49197 .99916 m .4917 .99503 L .49603 1.00013 L .262 .237 0 r
F
.49197 .99916 m .48662 .99371 L .4917 .99503 L F
.38177 .92384 m .38184 .90759 L .39063 .9176 L .808 .556 0 r
F
.38177 .92384 m .37234 .91549 L .38184 .90759 L F
.30435 .8879 m .30587 .86766 L .31543 .8734 L 1 .758 0 r
F
.30435 .8879 m .29429 .88289 L .30587 .86766 L F
.57613 1.03511 m .5889 1.04083 L .57801 1.0383 L .399 .448 0 r
F
.55121 1.02645 m .5608 1.02759 L .56345 1.03032 L .354 .379 0 r
F
.54869 1.02423 m .5608 1.02759 L .55121 1.02645 L .348 .371 0 r
F
.51352 1.00941 m .51816 1.00754 L .5169 1.01074 L .294 .287 0 r
F
.51352 1.00941 m .51364 1.00578 L .51816 1.00754 L F
.52969 1.0168 m .53525 1.01546 L .53905 1.0176 L .317 .323 0 r
F
.52667 1.01519 m .53525 1.01546 L .52969 1.0168 L .312 .316 0 r
F
.62364 1.05302 m .63563 1.06179 L .62443 1.05858 L .524 .564 0 r
F
.61251 1.05035 m .62364 1.05302 L .62443 1.05858 L .488 .538 0 r
F
.64919 .76057 m .67503 .76543 L .6674 .76888 L .734 .786 0 r
F
.64247 .76429 m .64919 .76057 L .6674 .76888 L .712 .773 0 r
F
.70009 1.46727 m .68225 1.48662 L .67624 1.48183 L 1 .944 0 r
F
.70009 1.46727 m .70701 1.47216 L .68225 1.48662 L F
.21152 .87214 m .2131 .84856 L .22332 .85246 L 1 .829 0 r
F
.21152 .87214 m .20095 .86885 L .2131 .84856 L F
.5169 1.01074 m .52262 1.0094 L .52024 1.01215 L .298 .294 0 r
F
.5169 1.01074 m .51816 1.00754 L .52262 1.0094 L F
.52667 1.01519 m .53121 1.01337 L .53525 1.01546 L .312 .316 0 r
F
.52351 1.01364 m .53121 1.01337 L .52667 1.01519 L .307 .308 0 r
F
.77193 .76662 m .79894 .78009 L .78909 .78261 L .859 .824 0 r
F
.76267 .76966 m .77193 .76662 L .78909 .78261 L .851 .82 0 r
F
.69178 1.0752 m .70219 1.08805 L .69102 1.08515 L .731 .684 0 r
F
.68054 1.07287 m .69178 1.0752 L .69102 1.08515 L .705 .667 0 r
F
.37234 .91549 m .37304 .89795 L .38184 .90759 L .887 .594 0 r
F
.37234 .91549 m .36291 .90745 L .37304 .89795 L F
.50066 1.27212 m .49944 1.2731 L .4872 1.27012 L .065 .105 0 r
F
.51195 1.2754 m .49944 1.2731 L .50066 1.27212 L 0 .094 0 r
F
.51195 1.2754 m .51183 1.27613 L .49944 1.2731 L F
.52024 1.01215 m .52699 1.01134 L .52351 1.01364 L .303 .301 0 r
F
.52024 1.01215 m .52262 1.0094 L .52699 1.01134 L F
.52351 1.01364 m .52699 1.01134 L .53121 1.01337 L .307 .308 0 r
F
.68268 .76187 m .7092 .76907 L .70074 .77227 L .779 .801 0 r
F
.67503 .76543 m .68268 .76187 L .70074 .77227 L .762 .792 0 r
F
.4895 1.26894 m .4872 1.27012 L .4752 1.26698 L .147 .113 0 r
F
.50066 1.27212 m .4872 1.27012 L .4895 1.26894 L .065 .105 0 r
F
.31208 1.23103 m .29231 1.22038 L .30263 1.22015 L .66 .716 0 r
F
.32192 1.23037 m .31208 1.23103 L .30263 1.22015 L .641 .702 0 r
F
.70303 1.07736 m .71335 1.09078 L .70219 1.08805 L .753 .699 0 r
F
.69178 1.0752 m .70303 1.07736 L .70219 1.08805 L .731 .684 0 r
F
.26144 1.22169 m .24175 1.20796 L .25243 1.20791 L .743 .761 0 r
F
.27171 1.22116 m .26144 1.22169 L .25243 1.20791 L .73 .752 0 r
F
.59982 1.04318 m .61251 1.05035 L .6014 1.04751 L .445 .511 0 r
F
.5889 1.04083 m .59982 1.04318 L .6014 1.04751 L .421 .481 0 r
F
.43454 .96387 m .43302 .95566 L .44109 .96397 L .329 .277 0 r
F
.43454 .96387 m .42575 .95572 L .43302 .95566 L F
.52326 1.27899 m .51183 1.27613 L .51195 1.2754 L 0 .079 0 r
F
.52326 1.27899 m .52424 1.2795 L .51183 1.27613 L F
.29429 .88289 m .29629 .86219 L .30587 .86766 L 1 .774 0 r
F
.29429 .88289 m .28421 .87808 L .29629 .86219 L F
.41763 1.2536 m .39895 1.2493 L .40692 1.2482 L .418 .499 0 r
F
.42481 1.25238 m .41763 1.2536 L .40692 1.2482 L .399 .464 0 r
F
.43556 1.25705 m .41763 1.2536 L .42481 1.25238 L .376 .419 0 r
F
.36291 .90745 m .36422 .88889 L .37304 .89795 L .949 .63 0 r
F
.36291 .90745 m .35345 .89981 L .36422 .88889 L F
.39895 1.2493 m .37983 1.24393 L .38852 1.24304 L .451 .561 0 r
F
.40692 1.2482 m .39895 1.2493 L .38852 1.24304 L .435 .531 0 r
F
.49603 1.00013 m .49701 .99659 L .50027 1.0013 L .26 .236 0 r
F
.49603 1.00013 m .4917 .99503 L .49701 .99659 L F
.54869 1.02423 m .55766 1.02483 L .5608 1.02759 L .348 .371 0 r
F
.54581 1.02201 m .55766 1.02483 L .54869 1.02423 L .341 .361 0 r
F
.57718 1.31049 m .56884 1.29582 L .5647 1.29772 L .742 .046 0 r
F
.57718 1.31049 m .58239 1.31543 L .56884 1.29582 L F
.47857 1.26569 m .4752 1.26698 L .46358 1.26359 L .212 .152 0 r
F
.4895 1.26894 m .4752 1.26698 L .47857 1.26569 L .147 .113 0 r
F
.63479 1.05551 m .64685 1.06483 L .63563 1.06179 L .56 .589 0 r
F
.62364 1.05302 m .63479 1.05551 L .63563 1.06179 L .524 .564 0 r
F
.71428 1.07935 m .72452 1.09334 L .71335 1.09078 L .774 .713 0 r
F
.70303 1.07736 m .71428 1.07935 L .71335 1.09078 L .753 .699 0 r
F
.45721 .97862 m .45567 .97263 L .46291 .97939 L .251 .205 0 r
F
.45721 .97862 m .44915 .97157 L .45567 .97263 L F
.48183 .99267 m .48126 .98823 L .48662 .99371 L .241 .207 0 r
F
.48183 .99267 m .4755 .98681 L .48126 .98823 L F
.59425 .76023 m .59894 .75633 L .61794 .76147 L .624 .734 0 r
F
.57536 .75657 m .59894 .75633 L .59425 .76023 L .604 .725 0 r
F
.56345 1.03032 m .5736 1.03185 L .57613 1.03511 L .376 .413 0 r
F
.5608 1.02759 m .5736 1.03185 L .56345 1.03032 L .369 .404 0 r
F
.5533 .75797 m .55576 .7543 L .57536 .75657 L .529 .658 0 r
F
.53438 .757 m .55576 .7543 L .5533 .75797 L .503 .611 0 r
F
.3513 1.23812 m .33178 1.22983 L .34165 1.22942 L .573 .663 0 r
F
.36061 1.23735 m .3513 1.23812 L .34165 1.22942 L .549 .644 0 r
F
.62368 .7576 m .64919 .76057 L .64247 .76429 L .701 .776 0 r
F
.61794 .76147 m .62368 .7576 L .64247 .76429 L .673 .759 0 r
F
.72619 .76242 m .75343 .77264 L .74421 .77555 L .825 .816 0 r
F
.71768 .76579 m .72619 .76242 L .74421 .77555 L .813 .81 0 r
F
.72554 1.0812 m .73569 1.09575 L .72452 1.09334 L .792 .726 0 r
F
.71428 1.07935 m .72554 1.0812 L .72452 1.09334 L .774 .713 0 r
F
.35345 .89981 m .35538 .88046 L .36422 .88889 L .995 .664 0 r
F
.35345 .89981 m .34398 .89261 L .35538 .88046 L F
.56052 1.29668 m .55182 1.28865 L .54869 1.28923 L .576 0 0 r
F
.56052 1.29668 m .5647 1.29772 L .55182 1.28865 L F
.47015 .9858 m .46916 .98079 L .4755 .98681 L .232 .19 0 r
F
.47015 .9858 m .46291 .97939 L .46916 .98079 L F
.42575 .95572 m .42495 .94646 L .43302 .95566 L .364 .302 0 r
F
.42575 .95572 m .41697 .94694 L .42495 .94646 L F
.58672 1.03703 m .59982 1.04318 L .5889 1.04083 L .417 .478 0 r
F
.57613 1.03511 m .58672 1.03703 L .5889 1.04083 L .399 .448 0 r
F
.44187 1.25579 m .43556 1.25705 L .42481 1.25238 L .355 .383 0 r
F
.45243 1.25987 m .43556 1.25705 L .44187 1.25579 L .324 .323 0 r
F
.28421 .87808 m .28668 .85694 L .29629 .86219 L 1 .788 0 r
F
.28421 .87808 m .27411 .87347 L .28668 .85694 L F
.59894 .75633 m .62368 .7576 L .61794 .76147 L .659 .759 0 r
F
.19914 1.20887 m .18852 1.20926 L .18013 1.19132 L .813 .797 0 r
F
.73681 1.08291 m .74686 1.09801 L .73569 1.09575 L .807 .738 0 r
F
.72554 1.0812 m .73681 1.08291 L .73569 1.09575 L .792 .726 0 r
F
.5345 1.28318 m .53657 1.28367 L .5276 1.28063 L .257 0 0 r
F
.5345 1.28318 m .5276 1.28063 L .52424 1.2795 L F
.54555 1.28821 m .53657 1.28367 L .5345 1.28318 L .349 0 0 r
F
.54389 1.28737 m .54869 1.28923 L .53657 1.28367 L F
.54555 1.28821 m .5463 1.28846 L .54389 1.28737 L F
.5463 1.28846 m .54869 1.28923 L .54389 1.28737 L F
.54206 1.28596 m .53473 1.28326 L .53241 1.28175 L 0 .063 0 r
F
.53473 1.28326 m .5345 1.28318 L .53441 1.28312 L F
.53473 1.28326 m .53441 1.28312 L .53241 1.28175 L F
.54238 1.2861 m .5345 1.28318 L .54206 1.28596 L F
.5345 1.28318 m .52424 1.2795 L .52326 1.27899 L .257 0 0 r
F
.37983 1.24393 m .36061 1.23735 L .36995 1.23673 L .497 .608 0 r
F
.38852 1.24304 m .37983 1.24393 L .36995 1.23673 L .472 .582 0 r
F
.73 1.45712 m .7139 1.47692 L .70701 1.47216 L 1 .91 0 r
F
.73 1.45712 m .73775 1.46179 L .7139 1.47692 L F
.5736 1.03185 m .58672 1.03703 L .57613 1.03511 L .393 .442 0 r
F
.54581 1.02201 m .55405 1.02209 L .55766 1.02483 L .341 .361 0 r
F
.54258 1.01979 m .55405 1.02209 L .54581 1.02201 L .333 .349 0 r
F
.50027 1.0013 m .5025 .99834 L .50465 1.00265 L .261 .239 0 r
F
.50027 1.0013 m .49701 .99659 L .5025 .99834 L F
.46798 1.26228 m .46358 1.26359 L .45243 1.25987 L .263 .224 0 r
F
.47857 1.26569 m .46358 1.26359 L .46798 1.26228 L .212 .152 0 r
F
.64595 1.05781 m .65807 1.06769 L .64685 1.06483 L .594 .612 0 r
F
.63479 1.05551 m .64595 1.05781 L .64685 1.06483 L .56 .589 0 r
F
.74808 1.08448 m .75802 1.10014 L .74686 1.09801 L .821 .749 0 r
F
.73681 1.08291 m .74808 1.08448 L .74686 1.09801 L .807 .738 0 r
F
.61075 1.04536 m .62364 1.05302 L .61251 1.05035 L .477 .539 0 r
F
.59982 1.04318 m .61075 1.04536 L .61251 1.05035 L .445 .511 0 r
F
.27171 1.22116 m .25243 1.20791 L .26312 1.20795 L .73 .752 0 r
F
.282 1.22072 m .27171 1.22116 L .26312 1.20795 L .716 .742 0 r
F
.77193 .76662 m .78122 .76351 L .79894 .78009 L .859 .824 0 r
F
.34398 .89261 m .34651 .87266 L .35538 .88046 L 1 .694 0 r
F
.34398 .89261 m .33449 .88582 L .34651 .87266 L F
.75935 1.08594 m .76919 1.10215 L .75802 1.10014 L .834 .758 0 r
F
.74808 1.08448 m .75935 1.08594 L .75802 1.10014 L .821 .749 0 r
F
.41697 .94694 m .41689 .93619 L .42495 .94646 L .418 .344 0 r
F
.41697 .94694 m .40819 .93756 L .41689 .93619 L F
.53438 .757 m .53568 .75356 L .55576 .7543 L .503 .611 0 r
F
.51521 .75756 m .53568 .75356 L .53438 .757 L .492 .533 0 r
F
.32192 1.23037 m .30263 1.22015 L .31297 1.22003 L .641 .702 0 r
F
.33178 1.22983 m .32192 1.23037 L .31297 1.22003 L .62 .687 0 r
F
.77062 1.08728 m .78035 1.10404 L .76919 1.10215 L .845 .767 0 r
F
.75935 1.08594 m .77062 1.08728 L .76919 1.10215 L .834 .758 0 r
F
.54258 1.01979 m .55002 1.01938 L .55405 1.02209 L .333 .349 0 r
F
.53905 1.0176 m .55002 1.01938 L .54258 1.01979 L .325 .337 0 r
F
.44915 .97157 m .44841 .96537 L .45567 .97263 L .243 .184 0 r
F
.44915 .97157 m .44109 .96397 L .44841 .96537 L F
.66416 1.47192 m .64584 1.49101 L .64075 1.4864 L 1 .992 0 r
F
.66416 1.47192 m .67021 1.47694 L .64584 1.49101 L F
.48662 .99371 m .48736 .99 L .4917 .99503 L .231 .196 0 r
F
.48662 .99371 m .48126 .98823 L .48736 .99 L F
.50465 1.00265 m .5081 1.00026 L .50912 1.00415 L .265 .245 0 r
F
.50465 1.00265 m .5025 .99834 L .5081 1.00026 L F
.5608 1.02759 m .57043 1.02856 L .5736 1.03185 L .369 .404 0 r
F
.55766 1.02483 m .57043 1.02856 L .5608 1.02759 L .361 .393 0 r
F
.69314 1.46223 m .67624 1.48183 L .67021 1.47694 L 1 .941 0 r
F
.69314 1.46223 m .70009 1.46727 L .67624 1.48183 L F
.7819 1.08852 m .79151 1.10583 L .78035 1.10404 L .854 .776 0 r
F
.77062 1.08728 m .7819 1.08852 L .78035 1.10404 L .845 .767 0 r
F
.27411 .87347 m .27705 .85188 L .28668 .85694 L 1 .8 0 r
F
.27411 .87347 m .26399 .86902 L .27705 .85188 L F
.19914 1.20887 m .18013 1.19132 L .19109 1.19151 L .813 .797 0 r
F
.20978 1.20854 m .19914 1.20887 L .19109 1.19151 L .806 .791 0 r
F
.76808 1.45048 m .75319 1.4708 L .74548 1.46635 L 1 .89 0 r
F
.76808 1.45048 m .77659 1.4547 L .75319 1.4708 L F
.79318 1.08966 m .80267 1.10753 L .79151 1.10583 L .863 .783 0 r
F
.7819 1.08852 m .79318 1.08966 L .79151 1.10583 L .854 .776 0 r
F
.65593 .75673 m .68268 .76187 L .67503 .76543 L .754 .798 0 r
F
.64919 .76057 m .65593 .75673 L .67503 .76543 L .734 .786 0 r
F
.65712 1.05994 m .6693 1.07037 L .65807 1.06769 L .626 .633 0 r
F
.64595 1.05781 m .65712 1.05994 L .65807 1.06769 L .594 .612 0 r
F
.69035 .7582 m .71768 .76579 L .7092 .76907 L .794 .809 0 r
F
.68268 .76187 m .69035 .7582 L .7092 .76907 L .779 .801 0 r
F
.40819 .93756 m .40884 .92483 L .41689 .93619 L .541 .399 0 r
F
.40819 .93756 m .39941 .9277 L .40884 .92483 L F
.80446 1.09072 m .81383 1.10913 L .80267 1.10753 L .871 .79 0 r
F
.79318 1.08966 m .80446 1.09072 L .80267 1.10753 L .863 .783 0 r
F
.51521 .75756 m .51534 .75455 L .53568 .75356 L .492 .533 0 r
F
.49601 .75991 m .51534 .75455 L .51521 .75756 L .482 .415 0 r
F
.33449 .88582 m .33761 .86542 L .34651 .87266 L 1 .722 0 r
F
.33449 .88582 m .32497 .87944 L .33761 .86542 L F
.81575 1.09169 m .82498 1.11066 L .81383 1.10913 L .877 .796 0 r
F
.80446 1.09072 m .81575 1.09169 L .81383 1.10913 L .871 .79 0 r
F
.82703 1.0926 m .83613 1.11212 L .82498 1.11066 L .883 .802 0 r
F
.81575 1.09169 m .82703 1.0926 L .82498 1.11066 L .877 .796 0 r
F
.83832 1.09343 m .84728 1.1135 L .83613 1.11212 L .889 .807 0 r
F
.82703 1.0926 m .83832 1.09343 L .83613 1.11212 L .883 .802 0 r
F
.53905 1.0176 m .5456 1.01671 L .55002 1.01938 L .325 .337 0 r
F
.53525 1.01546 m .5456 1.01671 L .53905 1.0176 L .317 .325 0 r
F
.49601 .75991 m .49495 .75758 L .51534 .75455 L .482 .415 0 r
F
.47699 .76457 m .49495 .75758 L .49601 .75991 L .483 .272 0 r
F
.50912 1.00415 m .51376 1.00232 L .51364 1.00578 L .271 .254 0 r
F
.50912 1.00415 m .5081 1.00026 L .51376 1.00232 L F
.83832 1.09343 m .84962 1.0942 L .84728 1.1135 L .889 .807 0 r
F
.47699 .76457 m .47475 .76322 L .49495 .75758 L .483 .272 0 r
F
.45833 .77282 m .47475 .76322 L .47699 .76457 L .548 .217 0 r
F
.45783 1.25863 m .45243 1.25987 L .44187 1.25579 L .303 .292 0 r
F
.46798 1.26228 m .45243 1.25987 L .45783 1.25863 L .263 .224 0 r
F
.57536 .75657 m .57896 .75259 L .59894 .75633 L .604 .725 0 r
F
.55576 .7543 m .57896 .75259 L .57536 .75657 L .583 .711 0 r
F
.59734 1.03877 m .61075 1.04536 L .59982 1.04318 L .436 .508 0 r
F
.58672 1.03703 m .59734 1.03877 L .59982 1.04318 L .417 .478 0 r
F
.39941 .9277 m .4008 .91265 L .40884 .92483 L .691 .458 0 r
F
.39941 .9277 m .39063 .9176 L .4008 .91265 L F
.62171 1.04735 m .63479 1.05551 L .62364 1.05302 L .51 .565 0 r
F
.61075 1.04536 m .62171 1.04735 L .62364 1.05302 L .477 .539 0 r
F
.36061 1.23735 m .34165 1.22942 L .35155 1.22915 L .549 .644 0 r
F
.36995 1.23673 m .36061 1.23735 L .35155 1.22915 L .523 .622 0 r
F
.282 1.22072 m .26312 1.20795 L .27382 1.20809 L .716 .742 0 r
F
.29231 1.22038 m .282 1.22072 L .27382 1.20809 L .7 .732 0 r
F
.4755 .98681 m .47588 .98274 L .48126 .98823 L .206 .162 0 r
F
.4755 .98681 m .46916 .98079 L .47588 .98274 L F
.46291 .97939 m .4628 .97457 L .46916 .98079 L .202 .15 0 r
F
.46291 .97939 m .45567 .97263 L .4628 .97457 L F
.73473 .75897 m .76267 .76966 L .75343 .77264 L .835 .821 0 r
F
.72619 .76242 m .73473 .75897 L .75343 .77264 L .825 .816 0 r
F
.5736 1.03185 m .58377 1.03319 L .58672 1.03703 L .393 .442 0 r
F
.57043 1.02856 m .58377 1.03319 L .5736 1.03185 L .385 .432 0 r
F
.26399 .86902 m .2674 .84698 L .27705 .85188 L 1 .81 0 r
F
.26399 .86902 m .25385 .86471 L .2674 .84698 L F
.40692 1.2482 m .38852 1.24304 L .39724 1.24231 L .435 .531 0 r
F
.41491 1.24728 m .40692 1.2482 L .39724 1.24231 L .417 .499 0 r
F
.42481 1.25238 m .40692 1.2482 L .41491 1.24728 L .399 .464 0 r
F
.20978 1.20854 m .19109 1.19151 L .20206 1.19176 L .806 .791 0 r
F
.22042 1.20828 m .20978 1.20854 L .20206 1.19176 L .797 .785 0 r
F
.53525 1.01546 m .54083 1.01411 L .5456 1.01671 L .317 .325 0 r
F
.53121 1.01337 m .54083 1.01411 L .53525 1.01546 L .309 .312 0 r
F
.6683 1.06189 m .68054 1.07287 L .6693 1.07037 L .655 .652 0 r
F
.65712 1.05994 m .6683 1.06189 L .6693 1.07037 L .626 .633 0 r
F
.51364 1.00578 m .51942 1.00449 L .51816 1.00754 L .277 .264 0 r
F
.51364 1.00578 m .51376 1.00232 L .51942 1.00449 L F
.39063 .9176 m .39276 .90026 L .4008 .91265 L .829 .514 0 r
F
.39063 .9176 m .38184 .90759 L .39276 .90026 L F
.58377 1.03319 m .59734 1.03877 L .58672 1.03703 L .41 .471 0 r
F
.55766 1.02483 m .56666 1.02528 L .57043 1.02856 L .361 .393 0 r
F
.55405 1.02209 m .56666 1.02528 L .55766 1.02483 L .352 .38 0 r
F
.43201 1.25135 m .42481 1.25238 L .41491 1.24728 L .379 .429 0 r
F
.44187 1.25579 m .42481 1.25238 L .43201 1.25135 L .355 .383 0 r
F
.4917 .99503 m .49374 .99202 L .49701 .99659 L .227 .193 0 r
F
.4917 .99503 m .48736 .99 L .49374 .99202 L F
.44109 .96397 m .44114 .9574 L .44841 .96537 L .245 .171 0 r
F
.44109 .96397 m .43302 .95566 L .44114 .9574 L F
.32497 .87944 m .32869 .85865 L .33761 .86542 L 1 .746 0 r
F
.32497 .87944 m .31543 .8734 L .32869 .85865 L F
.72222 1.45229 m .70701 1.47216 L .70009 1.46727 L 1 .905 0 r
F
.72222 1.45229 m .73 1.45712 L .70701 1.47216 L F
.53121 1.01337 m .53578 1.01158 L .54083 1.01411 L .309 .312 0 r
F
.52699 1.01134 m .53578 1.01158 L .53121 1.01337 L .301 .299 0 r
F
.51816 1.00754 m .52502 1.00676 L .52262 1.0094 L .285 .275 0 r
F
.51816 1.00754 m .51942 1.00449 L .52502 1.00676 L F
.38184 .90759 m .3847 .88836 L .39276 .90026 L .939 .566 0 r
F
.38184 .90759 m .37304 .89795 L .3847 .88836 L F
.52699 1.01134 m .53049 1.00913 L .53578 1.01158 L .301 .299 0 r
F
.52262 1.0094 m .53049 1.00913 L .52699 1.01134 L .292 .287 0 r
F
.33178 1.22983 m .31297 1.22003 L .32332 1.22004 L .62 .687 0 r
F
.34165 1.22942 m .33178 1.22983 L .32332 1.22004 L .598 .671 0 r
F
.52262 1.0094 m .52502 1.00676 L .53049 1.00913 L .292 .287 0 r
F
.38852 1.24304 m .36995 1.23673 L .3793 1.23628 L .472 .582 0 r
F
.39724 1.24231 m .38852 1.24304 L .3793 1.23628 L .449 .555 0 r
F
.62944 .75357 m .65593 .75673 L .64919 .76057 L .726 .792 0 r
F
.62368 .7576 m .62944 .75357 L .64919 .76057 L .701 .776 0 r
F
.42262 .81639 m .43568 .78799 L .44019 .78814 L 1 1 0 r
F
.4281 .82217 m .42262 .81639 L .44019 .78814 L F
.49181 1.2677 m .4895 1.26894 L .47857 1.26569 L .145 .111 0 r
F
.50188 1.27094 m .4895 1.26894 L .49181 1.2677 L .079 .105 0 r
F
.50188 1.27094 m .50066 1.27212 L .4895 1.26894 L F
.6683 1.06189 m .6795 1.06366 L .68054 1.07287 L .655 .652 0 r
F
.6795 1.06366 m .69178 1.0752 L .68054 1.07287 L .682 .67 0 r
F
.51207 1.27428 m .50066 1.27212 L .50188 1.27094 L .004 .096 0 r
F
.51207 1.27428 m .51195 1.2754 L .50066 1.27212 L F
.59894 .75633 m .60365 .75225 L .62368 .7576 L .659 .759 0 r
F
.57896 .75259 m .60365 .75225 L .59894 .75633 L .646 .757 0 r
F
.63268 1.04915 m .64595 1.05781 L .63479 1.05551 L .544 .59 0 r
F
.62171 1.04735 m .63268 1.04915 L .63479 1.05551 L .51 .565 0 r
F
.37304 .89795 m .37663 .87743 L .3847 .88836 L 1 .613 0 r
F
.37304 .89795 m .36422 .88889 L .37663 .87743 L F
.25385 .86471 m .25772 .84221 L .2674 .84698 L 1 .819 0 r
F
.25385 .86471 m .24369 .86052 L .25772 .84221 L F
.75956 1.44614 m .74548 1.46635 L .73775 1.46179 L 1 .885 0 r
F
.75956 1.44614 m .76808 1.45048 L .74548 1.46635 L F
.22042 1.20828 m .20206 1.19176 L .21303 1.19208 L .797 .785 0 r
F
.23108 1.20808 m .22042 1.20828 L .21303 1.19208 L .788 .778 0 r
F
.60365 .75225 m .62944 .75357 L .62368 .7576 L .692 .78 0 r
F
.48195 1.26444 m .47857 1.26569 L .46798 1.26228 L .201 .147 0 r
F
.49181 1.2677 m .47857 1.26569 L .48195 1.26444 L .145 .111 0 r
F
.29231 1.22038 m .27382 1.20809 L .28453 1.20833 L .7 .732 0 r
F
.30263 1.22015 m .29231 1.22038 L .28453 1.20833 L .683 .72 0 r
F
.60798 1.04032 m .62171 1.04735 L .61075 1.04536 L .464 .536 0 r
F
.59734 1.03877 m .60798 1.04032 L .61075 1.04536 L .436 .508 0 r
F
.44821 1.25471 m .44187 1.25579 L .43201 1.25135 L .334 .349 0 r
F
.45783 1.25863 m .44187 1.25579 L .44821 1.25471 L .303 .292 0 r
F
.31543 .8734 m .31974 .85226 L .32869 .85865 L 1 .767 0 r
F
.31543 .8734 m .30587 .86766 L .31974 .85226 L F
.55405 1.02209 m .56233 1.02204 L .56666 1.02528 L .352 .38 0 r
F
.55002 1.01938 m .56233 1.02204 L .55405 1.02209 L .342 .364 0 r
F
.52228 1.27783 m .51195 1.2754 L .51207 1.27428 L 0 .085 0 r
F
.52228 1.27783 m .52326 1.27899 L .51195 1.2754 L F
.55576 .7543 m .55824 .75035 L .57896 .75259 L .583 .711 0 r
F
.53568 .75356 m .55824 .75035 L .55576 .7543 L .564 .689 0 r
F
.68618 1.45699 m .67021 1.47694 L .66416 1.47192 L 1 .934 0 r
F
.68618 1.45699 m .69314 1.46223 L .67021 1.47694 L F
.49701 .99659 m .50034 .99424 L .5025 .99834 L .229 .197 0 r
F
.49701 .99659 m .49374 .99202 L .50034 .99424 L F
.43302 .95566 m .43387 .94838 L .44114 .9574 L .267 .172 0 r
F
.43302 .95566 m .42495 .94646 L .43387 .94838 L F
.69071 1.06526 m .70303 1.07736 L .69178 1.0752 L .706 .686 0 r
F
.6795 1.06366 m .69071 1.06526 L .69178 1.0752 L .682 .67 0 r
F
.57043 1.02856 m .58008 1.02935 L .58377 1.03319 L .385 .432 0 r
F
.56666 1.02528 m .58008 1.02935 L .57043 1.02856 L .376 .419 0 r
F
.69805 .75444 m .72619 .76242 L .71768 .76579 L .807 .816 0 r
F
.69035 .7582 m .69805 .75444 L .71768 .76579 L .794 .809 0 r
F
.65809 1.46673 m .64075 1.4864 L .63565 1.48177 L 1 .991 0 r
F
.65809 1.46673 m .66416 1.47192 L .64075 1.4864 L F
.48126 .98823 m .483 .98508 L .48736 .99 L .189 .146 0 r
F
.48126 .98823 m .47588 .98274 L .483 .98508 L F
.41223 .86244 m .42262 .81639 L .4281 .82217 L 1 .613 0 r
F
.4184 .88765 m .4281 .82217 L .4332 .85512 L 1 .514 0 r
F
.4184 .88765 m .41223 .86244 L .4281 .82217 L F
.60173 1.35263 m .59311 1.35458 L .58759 1.32034 L .187 .034 0 r
F
.59537 1.33455 m .60173 1.35263 L .58759 1.32034 L 0 0 0 r
F
.59537 1.33455 m .58759 1.32034 L .58239 1.31543 L F
.36422 .88889 m .36852 .8676 L .37663 .87743 L 1 .656 0 r
F
.36422 .88889 m .35538 .88046 L .36852 .8676 L F
.45567 .97263 m .45642 .96803 L .4628 .97457 L .168 .11 0 r
F
.45567 .97263 m .44841 .96537 L .45642 .96803 L F
.57194 1.30554 m .5647 1.29772 L .56052 1.29668 L .542 .006 0 r
F
.57194 1.30554 m .57718 1.31049 L .5647 1.29772 L F
.6627 .75276 m .69035 .7582 L .68268 .76187 L .773 .808 0 r
F
.65593 .75673 m .6627 .75276 L .68268 .76187 L .754 .798 0 r
F
.36995 1.23673 m .35155 1.22915 L .36147 1.22903 L .523 .622 0 r
F
.3793 1.23628 m .36995 1.23673 L .36147 1.22903 L .496 .598 0 r
F
.4724 1.26106 m .46798 1.26228 L .45783 1.25863 L .247 .207 0 r
F
.48195 1.26444 m .46798 1.26228 L .4724 1.26106 L .201 .147 0 r
F
.74328 .75545 m .77193 .76662 L .76267 .76966 L .845 .826 0 r
F
.73473 .75897 m .74328 .75545 L .76267 .76966 L .835 .821 0 r
F
.23108 1.20808 m .21303 1.19208 L .22401 1.19247 L .788 .778 0 r
F
.24175 1.20796 m .23108 1.20808 L .22401 1.19247 L .777 .771 0 r
F
.24369 .86052 m .24803 .83756 L .25772 .84221 L 1 .827 0 r
F
.24369 .86052 m .23351 .85645 L .24803 .83756 L F
.59398 1.03434 m .60798 1.04032 L .59734 1.03877 L .427 .501 0 r
F
.58377 1.03319 m .59398 1.03434 L .59734 1.03877 L .41 .471 0 r
F
.64367 1.05077 m .65712 1.05994 L .64595 1.05781 L .576 .613 0 r
F
.63268 1.04915 m .64367 1.05077 L .64595 1.05781 L .544 .59 0 r
F
.46916 .98079 m .47048 .97722 L .47588 .98274 L .159 .113 0 r
F
.46916 .98079 m .4628 .97457 L .47048 .97722 L F
.58008 1.02935 m .59398 1.03434 L .58377 1.03319 L .402 .461 0 r
F
.55631 1.29416 m .54869 1.28923 L .54555 1.28821 L .391 0 0 r
F
.54646 1.28808 m .54555 1.28821 L .54238 1.2861 L 0 .055 0 r
F
.55208 1.29081 m .54887 1.28953 L .54646 1.28808 L F
.54887 1.28953 m .54555 1.28821 L .54646 1.28808 L F
.55631 1.29416 m .56052 1.29668 L .55623 1.29398 L .391 0 0 r
F
.55329 1.2922 m .55623 1.29398 L .54869 1.28923 L F
.55631 1.29416 m .55623 1.29398 L .55329 1.2922 L F
.55002 1.01938 m .55749 1.01885 L .56233 1.02204 L .342 .364 0 r
F
.5456 1.01671 m .55749 1.01885 L .55002 1.01938 L .331 .347 0 r
F
.70192 1.06671 m .71428 1.07935 L .70303 1.07736 L .728 .701 0 r
F
.69071 1.06526 m .70192 1.06671 L .70303 1.07736 L .706 .686 0 r
F
.34165 1.22942 m .32332 1.22004 L .33369 1.22018 L .598 .671 0 r
F
.35155 1.22915 m .34165 1.22942 L .33369 1.22018 L .574 .653 0 r
F
.53241 1.28175 m .52326 1.27899 L .52228 1.27783 L 0 .074 0 r
F
.53241 1.28175 m .5345 1.28318 L .52326 1.27899 L F
.30587 .86766 m .31076 .8462 L .31974 .85226 L 1 .785 0 r
F
.30587 .86766 m .29629 .86219 L .31076 .8462 L F
.5025 .99834 m .50708 .9966 L .5081 1.00026 L .235 .206 0 r
F
.5025 .99834 m .50034 .99424 L .50708 .9966 L F
.42495 .94646 m .42661 .93783 L .43387 .94838 L .316 .2 0 r
F
.42495 .94646 m .41689 .93619 L .42661 .93783 L F
.71442 1.44728 m .70009 1.46727 L .69314 1.46223 L 1 .897 0 r
F
.71442 1.44728 m .72222 1.45229 L .70009 1.46727 L F
.35538 .88046 m .36038 .85877 L .36852 .8676 L 1 .695 0 r
F
.35538 .88046 m .34651 .87266 L .36038 .85877 L F
.53568 .75356 m .53699 .74979 L .55824 .75035 L .564 .689 0 r
F
.51534 .75455 m .53699 .74979 L .53568 .75356 L .552 .657 0 r
F
.30263 1.22015 m .28453 1.20833 L .29526 1.20868 L .683 .72 0 r
F
.31297 1.22003 m .30263 1.22015 L .29526 1.20868 L .665 .707 0 r
F
.41491 1.24728 m .39724 1.24231 L .40598 1.24177 L .417 .499 0 r
F
.42293 1.24655 m .41491 1.24728 L .40598 1.24177 L .399 .466 0 r
F
.43201 1.25135 m .41491 1.24728 L .42293 1.24655 L .379 .429 0 r
F
.61864 1.04167 m .63268 1.04915 L .62171 1.04735 L .494 .563 0 r
F
.60798 1.04032 m .61864 1.04167 L .62171 1.04735 L .464 .536 0 r
F
.71315 1.068 m .72554 1.0812 L .71428 1.07935 L .748 .715 0 r
F
.70192 1.06671 m .71315 1.068 L .71428 1.07935 L .728 .701 0 r
F
.75101 1.44167 m .73775 1.46179 L .73 1.45712 L 1 .88 0 r
F
.75101 1.44167 m .75956 1.44614 L .73775 1.46179 L F
.39724 1.24231 m .3793 1.23628 L .38869 1.23599 L .449 .555 0 r
F
.40598 1.24177 m .39724 1.24231 L .38869 1.23599 L .432 .525 0 r
F
.5456 1.01671 m .55217 1.01575 L .55749 1.01885 L .331 .347 0 r
F
.54083 1.01411 m .55217 1.01575 L .5456 1.01671 L .319 .328 0 r
F
.56666 1.02528 m .57569 1.02555 L .58008 1.02935 L .376 .419 0 r
F
.56233 1.02204 m .57569 1.02555 L .56666 1.02528 L .365 .403 0 r
F
.24175 1.20796 m .22401 1.19247 L .235 1.19294 L .777 .771 0 r
F
.25243 1.20791 m .24175 1.20796 L .235 1.19294 L .766 .763 0 r
F
.41689 .93619 m .41937 .92516 L .42661 .93783 L .399 .266 0 r
F
.41689 .93619 m .40884 .92483 L .41937 .92516 L F
.46324 1.25752 m .45783 1.25863 L .44821 1.25471 L .284 .266 0 r
F
.4724 1.26106 m .45783 1.25863 L .46324 1.25752 L .247 .207 0 r
F
.23351 .85645 m .23831 .83301 L .24803 .83756 L 1 .834 0 r
F
.23351 .85645 m .22332 .85246 L .23831 .83301 L F
.57896 .75259 m .58258 .74839 L .60365 .75225 L .646 .757 0 r
F
.55824 .75035 m .58258 .74839 L .57896 .75259 L .636 .755 0 r
F
.5081 1.00026 m .51389 .99907 L .51376 1.00232 L .244 .218 0 r
F
.5081 1.00026 m .50708 .9966 L .51389 .99907 L F
.48736 .99 m .49046 .98768 L .49374 .99202 L .182 .142 0 r
F
.48736 .99 m .483 .98508 L .49046 .98768 L F
.65468 1.0522 m .6683 1.06189 L .65712 1.05994 L .606 .634 0 r
F
.64367 1.05077 m .65468 1.0522 L .65712 1.05994 L .576 .613 0 r
F
.43924 1.2505 m .43201 1.25135 L .42293 1.24655 L .36 .395 0 r
F
.44821 1.25471 m .43201 1.25135 L .43924 1.2505 L .334 .349 0 r
F
.51534 .75455 m .51546 .7511 L .53699 .74979 L .552 .657 0 r
F
.49495 .75758 m .51546 .7511 L .51534 .75455 L .558 .62 0 r
F
.34651 .87266 m .3522 .85077 L .36038 .85877 L 1 .729 0 r
F
.34651 .87266 m .33761 .86542 L .3522 .85077 L F
.44841 .96537 m .45003 .96102 L .45642 .96803 L .133 .078 0 r
F
.44841 .96537 m .44114 .9574 L .45003 .96102 L F
.29629 .86219 m .30176 .8404 L .31076 .8462 L 1 .801 0 r
F
.29629 .86219 m .28668 .85694 L .30176 .8404 L F
.72439 1.06915 m .73681 1.08291 L .72554 1.0812 L .765 .727 0 r
F
.71315 1.068 m .72439 1.06915 L .72554 1.0812 L .748 .715 0 r
F
.63522 .7494 m .6627 .75276 L .65593 .75673 L .749 .805 0 r
F
.62944 .75357 m .63522 .7494 L .65593 .75673 L .726 .792 0 r
F
.40884 .92483 m .41216 .91009 L .41937 .92516 L .613 .361 0 r
F
.40884 .92483 m .4008 .91265 L .41216 .91009 L F
.54083 1.01411 m .54645 1.01273 L .55217 1.01575 L .319 .328 0 r
F
.53578 1.01158 m .54645 1.01273 L .54083 1.01411 L .306 .309 0 r
F
.49495 .75758 m .49389 .75461 L .51546 .7511 L .558 .62 0 r
F
.47475 .76322 m .49389 .75461 L .49495 .75758 L .603 .612 0 r
F
.67919 1.45149 m .66416 1.47192 L .65809 1.46673 L 1 .924 0 r
F
.67919 1.45149 m .68618 1.45699 L .66416 1.47192 L F
.51376 1.00232 m .52069 1.00162 L .51942 1.00449 L .255 .234 0 r
F
.51376 1.00232 m .51389 .99907 L .52069 1.00162 L F
.4008 .91265 m .40498 .89359 L .41216 .91009 L .848 .456 0 r
F
.4008 .91265 m .39276 .90026 L .40498 .89359 L F
.47475 .76322 m .47251 .76086 L .49389 .75461 L .603 .612 0 r
F
.45493 .77264 m .47251 .76086 L .47475 .76322 L .79 .752 0 r
F
.54238 1.2861 m .54555 1.28821 L .5345 1.28318 L 0 .063 0 r
F
.39276 .90026 m .3978 .87779 L .40498 .89359 L 1 .532 0 r
F
.39276 .90026 m .3847 .88836 L .3978 .87779 L F
.70577 .75058 m .73473 .75897 L .72619 .76242 L .82 .822 0 r
F
.69805 .75444 m .70577 .75058 L .72619 .76242 L .807 .816 0 r
F
.60421 1.03529 m .61864 1.04167 L .60798 1.04032 L .449 .53 0 r
F
.59398 1.03434 m .60421 1.03529 L .60798 1.04032 L .427 .501 0 r
F
.53578 1.01158 m .54037 1.00981 L .54645 1.01273 L .306 .309 0 r
F
.53049 1.00913 m .54037 1.00981 L .53578 1.01158 L .293 .289 0 r
F
.75187 .75185 m .78122 .76351 L .77193 .76662 L .854 .83 0 r
F
.74328 .75545 m .75187 .75185 L .77193 .76662 L .845 .826 0 r
F
.58008 1.02935 m .58977 1.02995 L .59398 1.03434 L .402 .461 0 r
F
.57569 1.02555 m .58977 1.02995 L .58008 1.02935 L .392 .446 0 r
F
.3793 1.23628 m .36147 1.22903 L .3714 1.22908 L .496 .598 0 r
F
.38869 1.23599 m .3793 1.23628 L .3714 1.22908 L .47 .573 0 r
F
.25243 1.20791 m .235 1.19294 L .24599 1.19349 L .766 .763 0 r
F
.26312 1.20795 m .25243 1.20791 L .24599 1.19349 L .753 .755 0 r
F
.73563 1.07017 m .74808 1.08448 L .73681 1.08291 L .781 .738 0 r
F
.72439 1.06915 m .73563 1.07017 L .73681 1.08291 L .765 .727 0 r
F
.31297 1.22003 m .29526 1.20868 L .30599 1.20915 L .665 .707 0 r
F
.32332 1.22004 m .31297 1.22003 L .30599 1.20915 L .645 .693 0 r
F
.35155 1.22915 m .33369 1.22018 L .34408 1.22046 L .574 .653 0 r
F
.36147 1.22903 m .35155 1.22915 L .34408 1.22046 L .548 .632 0 r
F
.51942 1.00449 m .52742 1.00426 L .52502 1.00676 L .268 .251 0 r
F
.51942 1.00449 m .52069 1.00162 L .52742 1.00426 L F
.60365 .75225 m .60838 .748 L .62944 .75357 L .692 .78 0 r
F
.58258 .74839 m .60838 .748 L .60365 .75225 L .685 .784 0 r
F
.45493 .77264 m .45154 .77074 L .47251 .76086 L .79 .752 0 r
F
.43568 .78799 m .45154 .77074 L .45493 .77264 L 1 1 0 r
F
.22332 .85246 m .22857 .82854 L .23831 .83301 L 1 .84 0 r
F
.22332 .85246 m .2131 .84856 L .22857 .82854 L F
.3847 .88836 m .39057 .86421 L .3978 .87779 L 1 .596 0 r
F
.3847 .88836 m .37663 .87743 L .39057 .86421 L F
.53049 1.00913 m .53401 1.00699 L .54037 1.00981 L .293 .289 0 r
F
.52502 1.00676 m .53401 1.00699 L .53049 1.00913 L .28 .27 0 r
F
.60838 .748 m .63522 .7494 L .62944 .75357 L .721 .798 0 r
F
.652 1.46132 m .63565 1.48177 L .63053 1.47713 L 1 .986 0 r
F
.652 1.46132 m .65809 1.46673 L .63565 1.48177 L F
.42262 .81639 m .41713 .81059 L .43568 .78799 L 1 1 0 r
F
.47588 .98274 m .47863 .98033 L .483 .98508 L .13 .095 0 r
F
.47588 .98274 m .47048 .97722 L .47863 .98033 L F
.40594 .84577 m .41713 .81059 L .42262 .81639 L 1 .74 0 r
F
.41223 .86244 m .40594 .84577 L .42262 .81639 L 1 .613 0 r
F
.58909 1.32274 m .59537 1.33455 L .58239 1.31543 L 0 0 0 r
F
.58909 1.32274 m .58239 1.31543 L .57718 1.31049 L F
.52502 1.00676 m .52742 1.00426 L .53401 1.00699 L .28 .27 0 r
F
.62932 1.04282 m .64367 1.05077 L .63268 1.04915 L .526 .588 0 r
F
.61864 1.04167 m .62932 1.04282 L .63268 1.04915 L .494 .563 0 r
F
.6657 1.05345 m .6795 1.06366 L .6683 1.06189 L .634 .653 0 r
F
.65468 1.0522 m .6657 1.05345 L .6683 1.06189 L .606 .634 0 r
F
.56233 1.02204 m .57064 1.02183 L .57569 1.02555 L .365 .403 0 r
F
.55749 1.01885 m .57064 1.02183 L .56233 1.02204 L .353 .383 0 r
F
.4628 .97457 m .46506 .97169 L .47048 .97722 L .096 .081 0 r
F
.4628 .97457 m .45642 .96803 L .46506 .97169 L F
.58977 1.02995 m .60421 1.03529 L .59398 1.03434 L .419 .49 0 r
F
.66949 .74868 m .69805 .75444 L .69035 .7582 L .789 .816 0 r
F
.6627 .75276 m .66949 .74868 L .69035 .7582 L .773 .808 0 r
F
.33761 .86542 m .344 .84341 L .3522 .85077 L 1 .759 0 r
F
.33761 .86542 m .32869 .85865 L .344 .84341 L F
.7066 1.44205 m .69314 1.46223 L .68618 1.45699 L 1 .887 0 r
F
.7066 1.44205 m .71442 1.44728 L .69314 1.46223 L F
.45458 1.25379 m .44821 1.25471 L .43924 1.2505 L .315 .319 0 r
F
.46324 1.25752 m .44821 1.25471 L .45458 1.25379 L .284 .266 0 r
F
.49374 .99202 m .49817 .99042 L .50034 .99424 L .185 .146 0 r
F
.49374 .99202 m .49046 .98768 L .49817 .99042 L F
.74689 1.07107 m .75935 1.08594 L .74808 1.08448 L .795 .749 0 r
F
.73563 1.07017 m .74689 1.07107 L .74808 1.08448 L .781 .738 0 r
F
.28668 .85694 m .29273 .83481 L .30176 .8404 L 1 .814 0 r
F
.28668 .85694 m .27705 .85188 L .29273 .83481 L F
.49413 1.26635 m .49181 1.2677 L .48195 1.26444 L .153 .11 0 r
F
.50311 1.26952 m .49181 1.2677 L .49413 1.26635 L .104 .105 0 r
F
.50311 1.26952 m .50188 1.27094 L .49181 1.2677 L F
.74244 1.43705 m .73 1.45712 L .72222 1.45229 L 1 .872 0 r
F
.74244 1.43705 m .75101 1.44167 L .73 1.45712 L F
.37663 .87743 m .38329 .85291 L .39057 .86421 L 1 .654 0 r
F
.37663 .87743 m .36852 .8676 L .38329 .85291 L F
.51219 1.27273 m .50188 1.27094 L .50311 1.26952 L .051 .098 0 r
F
.51219 1.27273 m .51207 1.27428 L .50188 1.27094 L F
.55824 .75035 m .56072 .74616 L .58258 .74839 L .636 .755 0 r
F
.53699 .74979 m .56072 .74616 L .55824 .75035 L .631 .752 0 r
F
.44114 .9574 m .44364 .95322 L .45003 .96102 L .106 .069 0 r
F
.44114 .9574 m .43387 .94838 L .44364 .95322 L F
.48535 1.26316 m .48195 1.26444 L .4724 1.26106 L .198 .149 0 r
F
.49413 1.26635 m .48195 1.26444 L .48535 1.26316 L .153 .11 0 r
F
.43568 .78799 m .43118 .7854 L .45154 .77074 L 1 1 0 r
F
.41713 .81059 m .43118 .7854 L .43568 .78799 L F
.78836 1.43408 m .77659 1.4547 L .76808 1.45048 L 1 .867 0 r
F
.78836 1.43408 m .79758 1.43799 L .77659 1.4547 L F
.26312 1.20795 m .24599 1.19349 L .257 1.19414 L .753 .755 0 r
F
.27382 1.20809 m .26312 1.20795 L .257 1.19414 L .74 .745 0 r
F
.75815 1.07186 m .77062 1.08728 L .75935 1.08594 L .808 .758 0 r
F
.74689 1.07107 m .75815 1.07186 L .75935 1.08594 L .795 .749 0 r
F
.52128 1.27607 m .51207 1.27428 L .51219 1.27273 L 0 .091 0 r
F
.52128 1.27607 m .52228 1.27783 L .51207 1.27428 L F
.6657 1.05345 m .67674 1.05452 L .6795 1.06366 L .634 .653 0 r
F
.67674 1.05452 m .69071 1.06526 L .6795 1.06366 L .659 .671 0 r
F
.55749 1.01885 m .56498 1.0182 L .57064 1.02183 L .353 .383 0 r
F
.55217 1.01575 m .56498 1.0182 L .55749 1.01885 L .339 .361 0 r
F
.40598 1.24177 m .38869 1.23599 L .39809 1.2359 L .432 .525 0 r
F
.41474 1.24142 m .40598 1.24177 L .39809 1.2359 L .415 .494 0 r
F
.42293 1.24655 m .40598 1.24177 L .41474 1.24142 L .399 .466 0 r
F
.56669 1.30057 m .57194 1.30554 L .56052 1.29668 L 0 .029 0 r
F
.56669 1.30057 m .56052 1.29668 L .55631 1.29416 L F
.43098 1.24602 m .42293 1.24655 L .41474 1.24142 L .38 .432 0 r
F
.43924 1.2505 m .42293 1.24655 L .43098 1.24602 L .36 .395 0 r
F
.32332 1.22004 m .30599 1.20915 L .31674 1.20975 L .645 .693 0 r
F
.33369 1.22018 m .32332 1.22004 L .31674 1.20975 L .623 .677 0 r
F
.60173 1.35263 m .60822 1.37983 L .59311 1.35458 L .187 .034 0 r
F
.36852 .8676 m .37597 .84334 L .38329 .85291 L 1 .705 0 r
F
.36852 .8676 m .36038 .85877 L .37597 .84334 L F
.47684 1.2599 m .4724 1.26106 L .46324 1.25752 L .237 .198 0 r
F
.48535 1.26316 m .4724 1.26106 L .47684 1.2599 L .198 .149 0 r
F
.76942 1.07254 m .7819 1.08852 L .77062 1.08728 L .819 .767 0 r
F
.75815 1.07186 m .76942 1.07254 L .77062 1.08728 L .808 .758 0 r
F
.32869 .85865 m .33576 .83653 L .344 .84341 L 1 .784 0 r
F
.32869 .85865 m .31974 .85226 L .33576 .83653 L F
.64003 1.04378 m .65468 1.0522 L .64367 1.05077 L .556 .611 0 r
F
.62932 1.04282 m .64003 1.04378 L .64367 1.05077 L .526 .588 0 r
F
.57569 1.02555 m .58475 1.02563 L .58977 1.02995 L .392 .446 0 r
F
.57064 1.02183 m .58475 1.02563 L .57569 1.02555 L .38 .428 0 r
F
.61447 1.03604 m .62932 1.04282 L .61864 1.04167 L .477 .557 0 r
F
.60421 1.03529 m .61447 1.03604 L .61864 1.04167 L .449 .53 0 r
F
.50034 .99424 m .50605 .99324 L .50708 .9966 L .195 .158 0 r
F
.50034 .99424 m .49817 .99042 L .50605 .99324 L F
.27705 .85188 m .28368 .8294 L .29273 .83481 L 1 .825 0 r
F
.27705 .85188 m .2674 .84698 L .28368 .8294 L F
.36147 1.22903 m .34408 1.22046 L .35448 1.2209 L .548 .632 0 r
F
.3714 1.22908 m .36147 1.22903 L .35448 1.2209 L .521 .61 0 r
F
.67217 1.44566 m .65809 1.46673 L .652 1.46132 L 1 .909 0 r
F
.67217 1.44566 m .67919 1.45149 L .65809 1.46673 L F
.55208 1.29081 m .55631 1.29416 L .54555 1.28821 L 0 .055 0 r
F
.75187 .75185 m .76047 .74819 L .78122 .76351 L .854 .83 0 r
F
.78069 1.07313 m .79318 1.08966 L .7819 1.08852 L .83 .774 0 r
F
.76942 1.07254 m .78069 1.07313 L .7819 1.08852 L .819 .767 0 r
F
.483 .98508 m .48716 .98366 L .49046 .98768 L .119 .092 0 r
F
.483 .98508 m .47863 .98033 L .48716 .98366 L F
.27382 1.20809 m .257 1.19414 L .26801 1.19489 L .74 .745 0 r
F
.28453 1.20833 m .27382 1.20809 L .26801 1.19489 L .725 .735 0 r
F
.53699 .74979 m .53831 .7457 L .56072 .74616 L .631 .752 0 r
F
.51546 .7511 m .53831 .7457 L .53699 .74979 L .64 .752 0 r
F
.38869 1.23599 m .3714 1.22908 L .38136 1.2293 L .47 .573 0 r
F
.39809 1.2359 m .38869 1.23599 L .38136 1.2293 L .446 .545 0 r
F
.71351 .74664 m .74328 .75545 L .73473 .75897 L .832 .828 0 r
F
.70577 .75058 m .71351 .74664 L .73473 .75897 L .82 .822 0 r
F
.43387 .94838 m .43724 .94401 L .44364 .95322 L .108 .062 0 r
F
.43387 .94838 m .42661 .93783 L .43724 .94401 L F
.44649 1.24984 m .43924 1.2505 L .43098 1.24602 L .34 .363 0 r
F
.45458 1.25379 m .43924 1.2505 L .44649 1.24984 L .315 .319 0 r
F
.53031 1.27957 m .52228 1.27783 L .52128 1.27607 L 0 .084 0 r
F
.53031 1.27957 m .53241 1.28175 L .52228 1.27783 L F
.64103 .7451 m .66949 .74868 L .6627 .75276 L .77 .816 0 r
F
.63522 .7494 m .64103 .7451 L .6627 .75276 L .749 .805 0 r
F
.68779 1.05544 m .70192 1.06671 L .69071 1.06526 L .683 .687 0 r
F
.67674 1.05452 m .68779 1.05544 L .69071 1.06526 L .659 .671 0 r
F
.55217 1.01575 m .55878 1.01469 L .56498 1.0182 L .339 .361 0 r
F
.54645 1.01273 m .55878 1.01469 L .55217 1.01575 L .323 .335 0 r
F
.58977 1.02995 m .59948 1.03034 L .60421 1.03529 L .419 .49 0 r
F
.58475 1.02563 m .59948 1.03034 L .58977 1.02995 L .408 .475 0 r
F
.59948 1.03034 m .61447 1.03604 L .60421 1.03529 L .435 .519 0 r
F
.58258 .74839 m .58622 .744 L .60838 .748 L .685 .784 0 r
F
.56072 .74616 m .58622 .744 L .58258 .74839 L .684 .79 0 r
F
.45642 .96803 m .45962 .96613 L .46506 .97169 L .014 .068 0 r
F
.45642 .96803 m .45003 .96102 L .45962 .96613 L F
.69875 1.43655 m .68618 1.45699 L .67919 1.45149 L 1 .873 0 r
F
.69875 1.43655 m .7066 1.44205 L .68618 1.45699 L F
.79198 1.07362 m .80446 1.09072 L .79318 1.08966 L .839 .782 0 r
F
.78069 1.07313 m .79198 1.07362 L .79318 1.08966 L .83 .774 0 r
F
.46869 1.25653 m .46324 1.25752 L .45458 1.25379 L .27 .248 0 r
F
.47684 1.2599 m .46324 1.25752 L .46869 1.25653 L .237 .198 0 r
F
.73385 1.43226 m .72222 1.45229 L .71442 1.44728 L 1 .863 0 r
F
.73385 1.43226 m .74244 1.43705 L .72222 1.45229 L F
.36038 .85877 m .36861 .83495 L .37597 .84334 L 1 .749 0 r
F
.36038 .85877 m .3522 .85077 L .36861 .83495 L F
.77911 1.43006 m .76808 1.45048 L .75956 1.44614 L 1 .862 0 r
F
.77911 1.43006 m .78836 1.43408 L .76808 1.45048 L F
.3978 .87779 m .40594 .84577 L .41223 .86244 L 1 .591 0 r
F
.3978 .87779 m .39057 .86421 L .40594 .84577 L F
.40498 .89359 m .3978 .87779 L .41223 .86244 L 1 .507 0 r
F
.50708 .9966 m .51401 .99609 L .51389 .99907 L .21 .175 0 r
F
.50708 .9966 m .50605 .99324 L .51401 .99609 L F
.64588 1.45559 m .63053 1.47713 L .62539 1.47247 L 1 .975 0 r
F
.64588 1.45559 m .652 1.46132 L .63053 1.47713 L F
.41713 .81059 m .41162 .80476 L .43118 .7854 L 1 1 0 r
F
.47048 .97722 m .47423 .97587 L .47863 .98033 L .047 .08 0 r
F
.47048 .97722 m .46506 .97169 L .47423 .97587 L F
.39956 .8343 m .41162 .80476 L .41713 .81059 L 1 .832 0 r
F
.40594 .84577 m .39956 .8343 L .41713 .81059 L 1 .74 0 r
F
.58284 1.31389 m .57718 1.31049 L .57194 1.30554 L 0 .018 0 r
F
.58284 1.31389 m .58909 1.32274 L .57718 1.31049 L F
.19109 1.19151 m .18013 1.19132 L .17506 1.1727 L .835 .8 0 r
F
.31974 .85226 m .3275 .83004 L .33576 .83653 L 1 .804 0 r
F
.31974 .85226 m .31076 .8462 L .3275 .83004 L F
.39057 .86421 m .39956 .8343 L .40594 .84577 L 1 .669 0 r
F
.39057 .86421 m .38329 .85291 L .39956 .8343 L F
.80327 1.07403 m .81575 1.09169 L .80446 1.09072 L .847 .788 0 r
F
.79198 1.07362 m .80327 1.07403 L .80446 1.09072 L .839 .782 0 r
F
.67631 .74449 m .70577 .75058 L .69805 .75444 L .805 .824 0 r
F
.66949 .74868 m .67631 .74449 L .69805 .75444 L .789 .816 0 r
F
.40498 .89359 m .41223 .86244 L .4184 .88765 L 1 .507 0 r
F
.41216 .91009 m .40498 .89359 L .4184 .88765 L .861 .373 0 r
F
.33369 1.22018 m .31674 1.20975 L .3275 1.21049 L .623 .677 0 r
F
.34408 1.22046 m .33369 1.22018 L .3275 1.21049 L .599 .659 0 r
F
.51546 .7511 m .51559 .74724 L .53831 .7457 L .64 .752 0 r
F
.49389 .75461 m .51559 .74724 L .51546 .7511 L .676 .767 0 r
F
.65075 1.04455 m .6657 1.05345 L .65468 1.0522 L .585 .633 0 r
F
.64003 1.04378 m .65075 1.04455 L .65468 1.0522 L .556 .611 0 r
F
.54645 1.01273 m .55209 1.01132 L .55878 1.01469 L .323 .335 0 r
F
.54037 1.00981 m .55209 1.01132 L .54645 1.01273 L .306 .308 0 r
F
.2674 .84698 m .27461 .82413 L .28368 .8294 L 1 .834 0 r
F
.2674 .84698 m .25772 .84221 L .27461 .82413 L F
.42661 .93783 m .43086 .93197 L .43724 .94401 L .182 .061 0 r
F
.42661 .93783 m .41937 .92516 L .43086 .93197 L F
.61312 .74359 m .64103 .7451 L .63522 .7494 L .748 .813 0 r
F
.60838 .748 m .61312 .74359 L .63522 .7494 L .721 .798 0 r
F
.28453 1.20833 m .26801 1.19489 L .27902 1.19574 L .725 .735 0 r
F
.29526 1.20868 m .28453 1.20833 L .27902 1.19574 L .708 .723 0 r
F
.57064 1.02183 m .57898 1.02144 L .58475 1.02563 L .38 .428 0 r
F
.56498 1.0182 m .57898 1.02144 L .57064 1.02183 L .365 .405 0 r
F
.58622 .744 m .61312 .74359 L .60838 .748 L .72 .806 0 r
F
.69886 1.0562 m .71315 1.068 L .70192 1.06671 L .704 .702 0 r
F
.68779 1.05544 m .69886 1.0562 L .70192 1.06671 L .683 .687 0 r
F
.81457 1.07437 m .82703 1.0926 L .81575 1.09169 L .854 .794 0 r
F
.80327 1.07403 m .81457 1.07437 L .81575 1.09169 L .847 .788 0 r
F
.51389 .99907 m .52197 .99898 L .52069 1.00162 L .228 .197 0 r
F
.51389 .99907 m .51401 .99609 L .52197 .99898 L F
.41216 .91009 m .4184 .88765 L .42457 .91403 L .861 .373 0 r
F
.41937 .92516 m .41216 .91009 L .42457 .91403 L .367 .144 0 r
F
.62475 1.03658 m .64003 1.04378 L .62932 1.04282 L .506 .583 0 r
F
.61447 1.03604 m .62475 1.03658 L .62932 1.04282 L .477 .557 0 r
F
.49389 .75461 m .49283 .75108 L .51559 .74724 L .676 .767 0 r
F
.47251 .76086 m .49283 .75108 L .49389 .75461 L .779 .83 0 r
F
.19109 1.19151 m .17506 1.1727 L .18625 1.17349 L .835 .8 0 r
F
.20206 1.19176 m .19109 1.19151 L .18625 1.17349 L .828 .794 0 r
F
.41937 .92516 m .42457 .91403 L .43086 .93197 L .367 .144 0 r
F
.54037 1.00981 m .54498 1.00807 L .55209 1.01132 L .306 .308 0 r
F
.53401 1.00699 m .54498 1.00807 L .54037 1.00981 L .287 .279 0 r
F
.38329 .85291 m .39312 .82528 L .39956 .8343 L 1 .739 0 r
F
.38329 .85291 m .37597 .84334 L .39312 .82528 L F
.53919 1.28324 m .53241 1.28175 L .53031 1.27957 L 0 .077 0 r
F
.53919 1.28324 m .54238 1.2861 L .53241 1.28175 L F
.82588 1.07464 m .83832 1.09343 L .82703 1.0926 L .861 .8 0 r
F
.81457 1.07437 m .82588 1.07464 L .82703 1.0926 L .854 .794 0 r
F
.3714 1.22908 m .35448 1.2209 L .3649 1.22151 L .521 .61 0 r
F
.38136 1.2293 m .3714 1.22908 L .3649 1.22151 L .493 .586 0 r
F
.47251 .76086 m .47026 .75767 L .49283 .75108 L .779 .83 0 r
F
.45154 .77074 m .47026 .75767 L .47251 .76086 L 1 .987 0 r
F
.46097 1.25302 m .45458 1.25379 L .44649 1.24984 L .298 .293 0 r
F
.46869 1.25653 m .45458 1.25379 L .46097 1.25302 L .27 .248 0 r
F
.52069 1.00162 m .52984 1.00192 L .52742 1.00426 L .248 .222 0 r
F
.52069 1.00162 m .52197 .99898 L .52984 1.00192 L F
.49046 .98768 m .49599 .98699 L .49817 .99042 L .124 .097 0 r
F
.49046 .98768 m .48716 .98366 L .49599 .98699 L F
.3522 .85077 m .36121 .82736 L .36861 .83495 L 1 .785 0 r
F
.3522 .85077 m .344 .84341 L .36121 .82736 L F
.53401 1.00699 m .53754 1.00494 L .54498 1.00807 L .287 .279 0 r
F
.52742 1.00426 m .53754 1.00494 L .53401 1.00699 L .268 .25 0 r
F
.41474 1.24142 m .39809 1.2359 L .40752 1.23599 L .415 .494 0 r
F
.42354 1.24127 m .41474 1.24142 L .40752 1.23599 L .397 .461 0 r
F
.43098 1.24602 m .41474 1.24142 L .42354 1.24127 L .38 .432 0 r
F
.52742 1.00426 m .52984 1.00192 L .53754 1.00494 L .268 .25 0 r
F
.45154 .77074 m .44814 .76764 L .47026 .75767 L 1 .987 0 r
F
.43118 .7854 m .44814 .76764 L .45154 .77074 L 1 1 0 r
F
.83719 1.07484 m .84962 1.0942 L .83832 1.09343 L .867 .805 0 r
F
.82588 1.07464 m .83719 1.07484 L .83832 1.09343 L .861 .8 0 r
F
.66512 1.43938 m .652 1.46132 L .64588 1.45559 L 1 .886 0 r
F
.66512 1.43938 m .67217 1.44566 L .652 1.46132 L F
.70994 1.05681 m .72439 1.06915 L .71315 1.068 L .724 .715 0 r
F
.69886 1.0562 m .70994 1.05681 L .71315 1.068 L .704 .702 0 r
F
.20206 1.19176 m .18625 1.17349 L .19744 1.17435 L .828 .794 0 r
F
.21303 1.19208 m .20206 1.19176 L .19744 1.17435 L .82 .788 0 r
F
.39956 .8343 m .39312 .82528 L .41162 .80476 L 1 .832 0 r
F
.43906 1.24568 m .43098 1.24602 L .42354 1.24127 L .361 .399 0 r
F
.44649 1.24984 m .43098 1.24602 L .43906 1.24568 L .34 .363 0 r
F
.31076 .8462 m .31921 .82384 L .3275 .83004 L 1 .821 0 r
F
.31076 .8462 m .30176 .8404 L .31921 .82384 L F
.76984 1.42591 m .75956 1.44614 L .75101 1.44167 L 1 .855 0 r
F
.76984 1.42591 m .77911 1.43006 L .75956 1.44614 L F
.72523 1.42724 m .71442 1.44728 L .7066 1.44205 L 1 .851 0 r
F
.72523 1.42724 m .73385 1.43226 L .71442 1.44728 L F
.29526 1.20868 m .27902 1.19574 L .29005 1.19671 L .708 .723 0 r
F
.30599 1.20915 m .29526 1.20868 L .29005 1.19671 L .69 .711 0 r
F
.56072 .74616 m .56321 .74172 L .58622 .744 L .684 .79 0 r
F
.53831 .7457 m .56321 .74172 L .56072 .74616 L .692 .8 0 r
F
.39809 1.2359 m .38136 1.2293 L .39134 1.22971 L .446 .545 0 r
F
.40752 1.23599 m .39809 1.2359 L .39134 1.22971 L .428 .515 0 r
F
.58475 1.02563 m .59385 1.02552 L .59948 1.03034 L .408 .475 0 r
F
.57898 1.02144 m .59385 1.02552 L .58475 1.02563 L .395 .455 0 r
F
.25772 .84221 m .26551 .81898 L .27461 .82413 L 1 .842 0 r
F
.25772 .84221 m .24803 .83756 L .26551 .81898 L F
.83719 1.07484 m .84851 1.07498 L .84962 1.0942 L .867 .805 0 r
F
.6615 1.04514 m .67674 1.05452 L .6657 1.05345 L .612 .652 0 r
F
.65075 1.04455 m .6615 1.04514 L .6657 1.05345 L .585 .633 0 r
F
.69087 1.4307 m .67919 1.45149 L .67217 1.44566 L 1 .854 0 r
F
.69087 1.4307 m .69875 1.43655 L .67919 1.45149 L F
.72128 .74262 m .75187 .75185 L .74328 .75545 L .842 .833 0 r
F
.71351 .74664 m .72128 .74262 L .74328 .75545 L .832 .828 0 r
F
.34408 1.22046 m .3275 1.21049 L .33828 1.21137 L .599 .659 0 r
F
.35448 1.2209 m .34408 1.22046 L .33828 1.21137 L .573 .64 0 r
F
.45003 .96102 m .45417 .96056 L .45962 .96613 L 0 .05 0 r
F
.45003 .96102 m .44364 .95322 L .45417 .96056 L F
.49647 1.26484 m .49413 1.26635 L .48535 1.26316 L .167 .123 0 r
F
.50434 1.26781 m .49413 1.26635 L .49647 1.26484 L .132 .105 0 r
F
.50434 1.26781 m .50311 1.26952 L .49413 1.26635 L F
.60923 1.03053 m .62475 1.03658 L .61447 1.03604 L .458 .547 0 r
F
.59948 1.03034 m .60923 1.03053 L .61447 1.03604 L .435 .519 0 r
F
.43118 .7854 m .42667 .78154 L .44814 .76764 L 1 1 0 r
F
.41162 .80476 m .42667 .78154 L .43118 .7854 L F
.56498 1.0182 m .57251 1.0174 L .57898 1.02144 L .365 .405 0 r
F
.55878 1.01469 m .57251 1.0174 L .56498 1.0182 L .349 .378 0 r
F
.5123 1.27079 m .50311 1.26952 L .50434 1.26781 L .098 .101 0 r
F
.5123 1.27079 m .51219 1.27273 L .50311 1.26952 L F
.48876 1.26183 m .48535 1.26316 L .47684 1.2599 L .201 .157 0 r
F
.49647 1.26484 m .48535 1.26316 L .48876 1.26183 L .167 .123 0 r
F
.56142 1.29558 m .55631 1.29416 L .55208 1.29081 L 0 .054 0 r
F
.56142 1.29558 m .56669 1.30057 L .55631 1.29416 L F
.37597 .84334 m .38664 .81749 L .39312 .82528 L 1 .793 0 r
F
.37597 .84334 m .36861 .83495 L .38664 .81749 L F
.59385 1.02552 m .60923 1.03053 L .59948 1.03034 L .424 .504 0 r
F
.21303 1.19208 m .19744 1.17435 L .20864 1.17527 L .82 .788 0 r
F
.22401 1.19247 m .21303 1.19208 L .20864 1.17527 L .811 .781 0 r
F
.64685 .74067 m .67631 .74449 L .66949 .74868 L .789 .825 0 r
F
.64103 .7451 m .64685 .74067 L .66949 .74868 L .77 .816 0 r
F
.72104 1.0573 m .73563 1.07017 L .72439 1.06915 L .741 .727 0 r
F
.70994 1.05681 m .72104 1.0573 L .72439 1.06915 L .724 .715 0 r
F
.47863 .98033 m .48384 .9801 L .48716 .98366 L .029 .082 0 r
F
.47863 .98033 m .47423 .97587 L .48384 .9801 L F
.63505 1.03693 m .65075 1.04455 L .64003 1.04378 L .535 .607 0 r
F
.62475 1.03658 m .63505 1.03693 L .64003 1.04378 L .506 .583 0 r
F
.52029 1.27379 m .51219 1.27273 L .5123 1.27079 L .066 .096 0 r
F
.52029 1.27379 m .52128 1.27607 L .51219 1.27273 L F
.49817 .99042 m .50501 .99026 L .50605 .99324 L .142 .108 0 r
F
.49817 .99042 m .49599 .98699 L .50501 .99026 L F
.4813 1.25877 m .47684 1.2599 L .46869 1.25653 L .232 .196 0 r
F
.48876 1.26183 m .47684 1.2599 L .4813 1.25877 L .201 .157 0 r
F
.344 .84341 m .35378 .82032 L .36121 .82736 L 1 .813 0 r
F
.344 .84341 m .33576 .83653 L .35378 .82032 L F
.45378 1.24936 m .44649 1.24984 L .43906 1.24568 L .322 .333 0 r
F
.46097 1.25302 m .44649 1.24984 L .45378 1.24936 L .298 .293 0 r
F
.63973 1.44937 m .62539 1.47247 L .62023 1.46779 L 1 .952 0 r
F
.63973 1.44937 m .64588 1.45559 L .62539 1.47247 L F
.46506 .97169 m .46981 .97184 L .47423 .97587 L 0 .064 0 r
F
.46506 .97169 m .45962 .96613 L .46981 .97184 L F
.41162 .80476 m .40609 .79891 L .42667 .78154 L 1 1 0 r
F
.39312 .82528 m .40609 .79891 L .41162 .80476 L 1 .889 0 r
F
.57658 1.3065 m .57194 1.30554 L .56669 1.30057 L 0 .042 0 r
F
.57658 1.3065 m .58284 1.31389 L .57194 1.30554 L F
.68314 .74021 m .71351 .74664 L .70577 .75058 L .818 .831 0 r
F
.67631 .74449 m .68314 .74021 L .70577 .75058 L .805 .824 0 r
F
.30599 1.20915 m .29005 1.19671 L .30108 1.19781 L .69 .711 0 r
F
.31674 1.20975 m .30599 1.20915 L .30108 1.19781 L .67 .697 0 r
F
.22401 1.19247 m .20864 1.17527 L .21984 1.17628 L .811 .781 0 r
F
.235 1.19294 m .22401 1.19247 L .21984 1.17628 L .801 .774 0 r
F
.54783 1.28697 m .54238 1.2861 L .53919 1.28324 L 0 .072 0 r
F
.54783 1.28697 m .55208 1.29081 L .54238 1.2861 L F
.38136 1.2293 m .3649 1.22151 L .37534 1.2223 L .493 .586 0 r
F
.39134 1.22971 m .38136 1.2293 L .37534 1.2223 L .465 .559 0 r
F
.30176 .8404 m .31089 .81786 L .31921 .82384 L 1 .835 0 r
F
.30176 .8404 m .29273 .83481 L .31089 .81786 L F
.42457 .91403 m .4184 .88765 L .4325 .91017 L .157 .03 0 r
F
.55878 1.01469 m .56541 1.01353 L .57251 1.0174 L .349 .378 0 r
F
.55209 1.01132 m .56541 1.01353 L .55878 1.01469 L .329 .346 0 r
F
.53831 .7457 m .53963 .74132 L .56321 .74172 L .692 .8 0 r
F
.51559 .74724 m .53963 .74132 L .53831 .7457 L .719 .819 0 r
F
.6615 1.04514 m .67226 1.04557 L .67674 1.05452 L .612 .652 0 r
F
.67226 1.04557 m .68779 1.05544 L .67674 1.05452 L .637 .67 0 r
F
.24803 .83756 m .25638 .81393 L .26551 .81898 L 1 .848 0 r
F
.24803 .83756 m .23831 .83301 L .25638 .81393 L F
.58622 .744 m .58986 .73942 L .61312 .74359 L .72 .806 0 r
F
.56321 .74172 m .58986 .73942 L .58622 .744 L .727 .818 0 r
F
.39312 .82528 m .38664 .81749 L .40609 .79891 L 1 .889 0 r
F
.76055 1.42163 m .75101 1.44167 L .74244 1.43705 L 1 .847 0 r
F
.76055 1.42163 m .76984 1.42591 L .75101 1.44167 L F
.73215 1.05765 m .74689 1.07107 L .73563 1.07017 L .757 .738 0 r
F
.72104 1.0573 m .73215 1.05765 L .73563 1.07017 L .741 .727 0 r
F
.47415 1.25563 m .46869 1.25653 L .46097 1.25302 L .259 .235 0 r
F
.4813 1.25877 m .46869 1.25653 L .47415 1.25563 L .232 .196 0 r
F
.35448 1.2209 m .33828 1.21137 L .34907 1.21242 L .573 .64 0 r
F
.3649 1.22151 m .35448 1.2209 L .34907 1.21242 L .545 .619 0 r
F
.71659 1.42198 m .7066 1.44205 L .69875 1.43655 L 1 .837 0 r
F
.71659 1.42198 m .72523 1.42724 L .7066 1.44205 L F
.52821 1.27683 m .52128 1.27607 L .52029 1.27379 L .04 .091 0 r
F
.52821 1.27683 m .53031 1.27957 L .52128 1.27607 L F
.61788 .73902 m .64685 .74067 L .64103 .7451 L .771 .826 0 r
F
.61312 .74359 m .61788 .73902 L .64103 .7451 L .748 .813 0 r
F
.57898 1.02144 m .58735 1.02087 L .59385 1.02552 L .395 .455 0 r
F
.57251 1.0174 m .58735 1.02087 L .57898 1.02144 L .38 .43 0 r
F
.235 1.19294 m .21984 1.17628 L .23104 1.17737 L .801 .774 0 r
F
.24599 1.19349 m .235 1.19294 L .23104 1.17737 L .791 .766 0 r
F
.50605 .99324 m .51413 .99344 L .51401 .99609 L .167 .127 0 r
F
.50605 .99324 m .50501 .99026 L .51413 .99344 L F
.36861 .83495 m .38013 .81037 L .38664 .81749 L 1 .834 0 r
F
.36861 .83495 m .36121 .82736 L .38013 .81037 L F
.68296 1.42441 m .67217 1.44566 L .66512 1.43938 L 1 .83 0 r
F
.68296 1.42441 m .69087 1.4307 L .67217 1.44566 L F
.65805 1.43246 m .64588 1.45559 L .63973 1.44937 L 1 .853 0 r
F
.65805 1.43246 m .66512 1.43938 L .64588 1.45559 L F
.44364 .95322 m .44869 .95497 L .45417 .96056 L 0 .026 0 r
F
.44364 .95322 m .43724 .94401 L .44869 .95497 L F
.58986 .73942 m .61788 .73902 L .61312 .74359 L .751 .825 0 r
F
.42354 1.24127 m .40752 1.23599 L .41698 1.23629 L .397 .461 0 r
F
.43236 1.24133 m .42354 1.24127 L .41698 1.23629 L .378 .427 0 r
F
.43906 1.24568 m .42354 1.24127 L .43236 1.24133 L .361 .399 0 r
F
.61899 1.03052 m .63505 1.03693 L .62475 1.03658 L .484 .574 0 r
F
.60923 1.03053 m .61899 1.03052 L .62475 1.03658 L .458 .547 0 r
F
.55209 1.01132 m .55775 1.00983 L .56541 1.01353 L .329 .346 0 r
F
.54498 1.00807 m .55775 1.00983 L .55209 1.01132 L .307 .31 0 r
F
.40752 1.23599 m .39134 1.22971 L .40134 1.23032 L .428 .515 0 r
F
.41698 1.23629 m .40752 1.23599 L .40134 1.23032 L .411 .483 0 r
F
.31674 1.20975 m .30108 1.19781 L .31212 1.19904 L .67 .697 0 r
F
.3275 1.21049 m .31674 1.20975 L .31212 1.19904 L .648 .681 0 r
F
.51559 .74724 m .51572 .743 L .53963 .74132 L .719 .819 0 r
F
.49283 .75108 m .51572 .743 L .51559 .74724 L .78 .86 0 r
F
.33576 .83653 m .34632 .81367 L .35378 .82032 L 1 .835 0 r
F
.33576 .83653 m .3275 .83004 L .34632 .81367 L F
.74327 1.05789 m .75815 1.07186 L .74689 1.07107 L .772 .748 0 r
F
.73215 1.05765 m .74327 1.05789 L .74689 1.07107 L .757 .738 0 r
F
.72907 .73852 m .76047 .74819 L .75187 .75185 L .852 .837 0 r
F
.72128 .74262 m .72907 .73852 L .75187 .75185 L .842 .833 0 r
F
.64538 1.03709 m .6615 1.04514 L .65075 1.04455 L .563 .629 0 r
F
.63505 1.03693 m .64538 1.03709 L .65075 1.04455 L .535 .607 0 r
F
.68305 1.04583 m .69886 1.0562 L .68779 1.05544 L .66 .687 0 r
F
.67226 1.04557 m .68305 1.04583 L .68779 1.05544 L .637 .67 0 r
F
.24599 1.19349 m .23104 1.17737 L .24225 1.17855 L .791 .766 0 r
F
.257 1.19414 m .24599 1.19349 L .24225 1.17855 L .779 .758 0 r
F
.59385 1.02552 m .60297 1.0252 L .60923 1.03053 L .424 .504 0 r
F
.58735 1.02087 m .60297 1.0252 L .59385 1.02552 L .411 .484 0 r
F
.44717 1.24555 m .43906 1.24568 L .43236 1.24133 L .342 .367 0 r
F
.45378 1.24936 m .43906 1.24568 L .44717 1.24555 L .322 .333 0 r
F
.4674 1.25238 m .46097 1.25302 L .45378 1.24936 L .284 .273 0 r
F
.47415 1.25563 m .46097 1.25302 L .4674 1.25238 L .259 .235 0 r
F
.51401 .99609 m .52326 .99657 L .52197 .99898 L .196 .155 0 r
F
.51401 .99609 m .51413 .99344 L .52326 .99657 L F
.23831 .83301 m .24723 .80896 L .25638 .81393 L 1 .854 0 r
F
.23831 .83301 m .22857 .82854 L .24723 .80896 L F
.48716 .98366 m .49379 .98408 L .49599 .98699 L .04 .088 0 r
F
.48716 .98366 m .48384 .9801 L .49379 .98408 L F
.29273 .83481 m .30254 .81205 L .31089 .81786 L 1 .846 0 r
F
.29273 .83481 m .28368 .8294 L .30254 .81205 L F
.60297 1.0252 m .61899 1.03052 L .60923 1.03053 L .44 .533 0 r
F
.49283 .75108 m .49176 .74705 L .51572 .743 L .78 .86 0 r
F
.47026 .75767 m .49176 .74705 L .49283 .75108 L .906 .939 0 r
F
.54498 1.00807 m .54962 1.00632 L .55775 1.00983 L .307 .31 0 r
F
.53754 1.00494 m .54962 1.00632 L .54498 1.00807 L .283 .271 0 r
F
.53599 1.27986 m .53031 1.27957 L .52821 1.27683 L .024 .087 0 r
F
.53599 1.27986 m .53919 1.28324 L .53031 1.27957 L F
.60751 1.3428 m .60173 1.35263 L .59537 1.33455 L .364 .142 0 r
F
.60028 1.33016 m .59537 1.33455 L .58909 1.32274 L .164 .059 0 r
F
.60028 1.33016 m .60751 1.3428 L .59537 1.33455 L F
.75124 1.41717 m .74244 1.43705 L .73385 1.43226 L 1 .838 0 r
F
.75124 1.41717 m .76055 1.42163 L .74244 1.43705 L F
.47026 .75767 m .46801 .75381 L .49176 .74705 L .906 .939 0 r
F
.44814 .76764 m .46801 .75381 L .47026 .75767 L 1 1 0 r
F
.7544 1.05802 m .76942 1.07254 L .75815 1.07186 L .785 .758 0 r
F
.74327 1.05789 m .7544 1.05802 L .75815 1.07186 L .772 .748 0 r
F
.39134 1.22971 m .37534 1.2223 L .3858 1.22327 L .465 .559 0 r
F
.40134 1.23032 m .39134 1.22971 L .3858 1.22327 L .44 .53 0 r
F
.52197 .99898 m .53228 .99973 L .52984 1.00192 L .226 .191 0 r
F
.52197 .99898 m .52326 .99657 L .53228 .99973 L F
.3649 1.22151 m .34907 1.21242 L .35988 1.21365 L .545 .619 0 r
F
.37534 1.2223 m .3649 1.22151 L .35988 1.21365 L .516 .595 0 r
F
.80608 1.41723 m .79758 1.43799 L .78836 1.43408 L 1 .849 0 r
F
.80608 1.41723 m .81596 1.42075 L .79758 1.43799 L F
.53754 1.00494 m .54109 1.00296 L .54962 1.00632 L .283 .271 0 r
F
.52984 1.00192 m .54109 1.00296 L .53754 1.00494 L .255 .23 0 r
F
.44814 .76764 m .44473 .76372 L .46801 .75381 L 1 1 0 r
F
.42667 .78154 m .44473 .76372 L .44814 .76764 L F
.38664 .81749 m .40054 .79305 L .40609 .79891 L 1 .922 0 r
F
.38664 .81749 m .38013 .81037 L .40054 .79305 L F
.57251 1.0174 m .58007 1.01643 L .58735 1.02087 L .38 .43 0 r
F
.56541 1.01353 m .58007 1.01643 L .57251 1.0174 L .361 .399 0 r
F
.52984 1.00192 m .53228 .99973 L .54109 1.00296 L .255 .23 0 r
F
.70793 1.4164 m .69875 1.43655 L .69087 1.4307 L 1 .818 0 r
F
.70793 1.4164 m .71659 1.42198 L .69875 1.43655 L F
.65269 .73612 m .68314 .74021 L .67631 .74449 L .805 .833 0 r
F
.64685 .74067 m .65269 .73612 L .67631 .74449 L .789 .825 0 r
F
.257 1.19414 m .24225 1.17855 L .25345 1.17982 L .779 .758 0 r
F
.26801 1.19489 m .257 1.19414 L .25345 1.17982 L .766 .748 0 r
F
.56321 .74172 m .56572 .73706 L .58986 .73942 L .727 .818 0 r
F
.53963 .74132 m .56572 .73706 L .56321 .74172 L .745 .836 0 r
F
.3275 1.21049 m .31212 1.19904 L .32318 1.20043 L .648 .681 0 r
F
.33828 1.21137 m .3275 1.21049 L .32318 1.20043 L .624 .664 0 r
F
.42667 .78154 m .42215 .77697 L .44473 .76372 L 1 1 0 r
F
.40609 .79891 m .42215 .77697 L .42667 .78154 L F
.61478 1.35799 m .60822 1.37983 L .60173 1.35263 L .862 .373 0 r
F
.60751 1.3428 m .61478 1.35799 L .60173 1.35263 L .364 .142 0 r
F
.43724 .94401 m .44319 .94936 L .44869 .95497 L 0 0 0 r
F
.43724 .94401 m .43086 .93197 L .44319 .94936 L F
.55614 1.29058 m .55208 1.29081 L .54783 1.28697 L 0 .071 0 r
F
.55614 1.29058 m .56142 1.29558 L .55208 1.29081 L F
.36121 .82736 m .37359 .80367 L .38013 .81037 L 1 .863 0 r
F
.36121 .82736 m .35378 .82032 L .37359 .80367 L F
.69 .73583 m .72128 .74262 L .71351 .74664 L .831 .836 0 r
F
.68314 .74021 m .69 .73583 L .71351 .74664 L .818 .831 0 r
F
.63356 1.44236 m .62023 1.46779 L .61505 1.4631 L 1 .913 0 r
F
.63356 1.44236 m .63973 1.44937 L .62023 1.46779 L F
.45962 .96613 m .46537 .96857 L .46981 .97184 L 0 .041 0 r
F
.45962 .96613 m .45417 .96056 L .46537 .96857 L F
.40609 .79891 m .40054 .79305 L .42215 .77697 L 1 1 0 r
F
.57032 1.29991 m .56669 1.30057 L .56142 1.29558 L 0 .06 0 r
F
.57032 1.29991 m .57658 1.3065 L .56669 1.30057 L F
.67503 1.41755 m .66512 1.43938 L .65805 1.43246 L 1 .798 0 r
F
.67503 1.41755 m .68296 1.42441 L .66512 1.43938 L F
.47423 .97587 m .48051 .97723 L .48384 .9801 L 0 .069 0 r
F
.47423 .97587 m .46981 .97184 L .48051 .97723 L F
.59307 1.31977 m .58909 1.32274 L .58284 1.31389 L .07 .058 0 r
F
.59307 1.31977 m .60028 1.33016 L .58909 1.32274 L F
.43086 .93197 m .43768 .94372 L .44319 .94936 L 0 0 0 r
F
.42457 .91403 m .4325 .91017 L .43768 .94372 L .157 .03 0 r
F
.43086 .93197 m .42457 .91403 L .43768 .94372 L 0 0 0 r
F
.69385 1.04593 m .70994 1.05681 L .69886 1.0562 L .682 .701 0 r
F
.68305 1.04583 m .69385 1.04593 L .69886 1.0562 L .66 .687 0 r
F
.76555 1.05805 m .78069 1.07313 L .76942 1.07254 L .797 .766 0 r
F
.7544 1.05802 m .76555 1.05805 L .76942 1.07254 L .785 .758 0 r
F
.3275 .83004 m .33884 .80729 L .34632 .81367 L 1 .852 0 r
F
.3275 .83004 m .31921 .82384 L .33884 .80729 L F
.49881 1.26315 m .49647 1.26484 L .48876 1.26183 L .185 .143 0 r
F
.50558 1.26584 m .49647 1.26484 L .49881 1.26315 L .162 .121 0 r
F
.50558 1.26584 m .50434 1.26781 L .49647 1.26484 L F
.46109 1.24904 m .45378 1.24936 L .44717 1.24555 L .305 .307 0 r
F
.4674 1.25238 m .45378 1.24936 L .46109 1.24904 L .284 .273 0 r
F
.65094 1.42462 m .63973 1.44937 L .63356 1.44236 L 1 .807 0 r
F
.65094 1.42462 m .65805 1.43246 L .63973 1.44937 L F
.49219 1.26041 m .48876 1.26183 L .4813 1.25877 L .209 .169 0 r
F
.49881 1.26315 m .48876 1.26183 L .49219 1.26041 L .185 .143 0 r
F
.65574 1.03707 m .67226 1.04557 L .6615 1.04514 L .589 .649 0 r
F
.64538 1.03709 m .65574 1.03707 L .6615 1.04514 L .563 .629 0 r
F
.51242 1.26848 m .50434 1.26781 L .50558 1.26584 L .139 .106 0 r
F
.51242 1.26848 m .5123 1.27079 L .50434 1.26781 L F
.62879 1.0303 m .64538 1.03709 L .63505 1.03693 L .512 .599 0 r
F
.61899 1.03052 m .62879 1.0303 L .63505 1.03693 L .484 .574 0 r
F
.26801 1.19489 m .25345 1.17982 L .26466 1.18121 L .766 .748 0 r
F
.27902 1.19574 m .26801 1.19489 L .26466 1.18121 L .751 .738 0 r
F
.28368 .8294 m .29418 .80639 L .30254 .81205 L 1 .855 0 r
F
.28368 .8294 m .27461 .82413 L .29418 .80639 L F
.49599 .98699 m .50397 .98774 L .50501 .99026 L .071 .095 0 r
F
.49599 .98699 m .49379 .98408 L .50397 .98774 L F
.48578 1.25763 m .4813 1.25877 L .47415 1.25563 L .231 .198 0 r
F
.49219 1.26041 m .4813 1.25877 L .48578 1.25763 L .209 .169 0 r
F
.41698 1.23629 m .40134 1.23032 L .41137 1.23113 L .411 .483 0 r
F
.42646 1.23681 m .41698 1.23629 L .41137 1.23113 L .392 .45 0 r
F
.43236 1.24133 m .41698 1.23629 L .42646 1.23681 L .378 .427 0 r
F
.7419 1.41253 m .73385 1.43226 L .72523 1.42724 L 1 .826 0 r
F
.7419 1.41253 m .75124 1.41717 L .73385 1.43226 L F
.54355 1.28281 m .53919 1.28324 L .53599 1.27986 L .024 .083 0 r
F
.54355 1.28281 m .54783 1.28697 L .53919 1.28324 L F
.79619 1.41361 m .78836 1.43408 L .77911 1.43006 L 1 .843 0 r
F
.79619 1.41361 m .80608 1.41723 L .78836 1.43408 L F
.51928 1.27109 m .5123 1.27079 L .51242 1.26848 L .12 .099 0 r
F
.51928 1.27109 m .52029 1.27379 L .5123 1.27079 L F
.72907 .73852 m .73689 .73435 L .76047 .74819 L .852 .837 0 r
F
.56541 1.01353 m .57207 1.01222 L .58007 1.01643 L .361 .399 0 r
F
.55775 1.00983 m .57207 1.01222 L .56541 1.01353 L .339 .361 0 r
F
.58735 1.02087 m .59575 1.02011 L .60297 1.0252 L .411 .484 0 r
F
.58007 1.01643 m .59575 1.02011 L .58735 1.02087 L .395 .458 0 r
F
.58986 .73942 m .59353 .73467 L .61788 .73902 L .751 .825 0 r
F
.56572 .73706 m .59353 .73467 L .58986 .73942 L .763 .84 0 r
F
.44121 1.2416 m .43236 1.24133 L .42646 1.23681 L .359 .394 0 r
F
.44717 1.24555 m .43236 1.24133 L .44121 1.2416 L .342 .367 0 r
F
.77671 1.05799 m .79198 1.07362 L .78069 1.07313 L .807 .774 0 r
F
.76555 1.05805 m .77671 1.05799 L .78069 1.07313 L .797 .766 0 r
F
.33828 1.21137 m .32318 1.20043 L .33424 1.20197 L .624 .664 0 r
F
.34907 1.21242 m .33828 1.21137 L .33424 1.20197 L .598 .645 0 r
F
.62266 .73431 m .65269 .73612 L .64685 .74067 L .792 .837 0 r
F
.61788 .73902 m .62266 .73431 L .64685 .74067 L .771 .826 0 r
F
.37534 1.2223 m .35988 1.21365 L .37069 1.21505 L .516 .595 0 r
F
.3858 1.22327 m .37534 1.2223 L .37069 1.21505 L .486 .569 0 r
F
.53963 .74132 m .54095 .73667 L .56572 .73706 L .745 .836 0 r
F
.51572 .743 m .54095 .73667 L .53963 .74132 L .783 .865 0 r
F
.27902 1.19574 m .26466 1.18121 L .27587 1.18271 L .751 .738 0 r
F
.29005 1.19671 m .27902 1.19574 L .27587 1.18271 L .735 .726 0 r
F
.69923 1.41045 m .69087 1.4307 L .68296 1.42441 L 1 .796 0 r
F
.69923 1.41045 m .70793 1.4164 L .69087 1.4307 L F
.70467 1.0459 m .72104 1.0573 L .70994 1.05681 L .701 .715 0 r
F
.69385 1.04593 m .70467 1.0459 L .70994 1.05681 L .682 .701 0 r
F
.61212 1.02468 m .62879 1.0303 L .61899 1.03052 L .462 .561 0 r
F
.60297 1.0252 m .61212 1.02468 L .61899 1.03052 L .44 .533 0 r
F
.47965 1.25478 m .47415 1.25563 L .4674 1.25238 L .253 .228 0 r
F
.48578 1.25763 m .47415 1.25563 L .47965 1.25478 L .231 .198 0 r
F
.59353 .73467 m .62266 .73431 L .61788 .73902 L .779 .839 0 r
F
.40134 1.23032 m .3858 1.22327 L .39628 1.22444 L .44 .53 0 r
F
.41137 1.23113 m .40134 1.23032 L .39628 1.22444 L .422 .499 0 r
F
.59575 1.02011 m .61212 1.02468 L .60297 1.0252 L .427 .513 0 r
F
.58587 1.31099 m .58284 1.31389 L .57658 1.3065 L .051 .064 0 r
F
.58587 1.31099 m .59307 1.31977 L .58284 1.31389 L F
.38013 .81037 m .39497 .78716 L .40054 .79305 L 1 .941 0 r
F
.38013 .81037 m .37359 .80367 L .39497 .78716 L F
.35378 .82032 m .36703 .79723 L .37359 .80367 L 1 .883 0 r
F
.35378 .82032 m .34632 .81367 L .36703 .79723 L F
.66707 1.40996 m .65805 1.43246 L .65094 1.42462 L 1 .759 0 r
F
.66707 1.40996 m .67503 1.41755 L .65805 1.43246 L F
.52609 1.27364 m .52029 1.27379 L .51928 1.27109 L .105 .096 0 r
F
.52609 1.27364 m .52821 1.27683 L .52029 1.27379 L F
.78788 1.05784 m .80327 1.07403 L .79198 1.07362 L .817 .781 0 r
F
.77671 1.05799 m .78788 1.05784 L .79198 1.07362 L .807 .774 0 r
F
.4553 1.2456 m .44717 1.24555 L .44121 1.2416 L .324 .337 0 r
F
.46109 1.24904 m .44717 1.24555 L .4553 1.2456 L .305 .307 0 r
F
.50501 .99026 m .51426 .99115 L .51413 .99344 L .114 .102 0 r
F
.50501 .99026 m .50397 .98774 L .51426 .99115 L F
.31921 .82384 m .33133 .80111 L .33884 .80729 L 1 .865 0 r
F
.31921 .82384 m .31089 .81786 L .33133 .80111 L F
.65574 1.03707 m .66611 1.03688 L .67226 1.04557 L .589 .649 0 r
F
.66611 1.03688 m .68305 1.04583 L .67226 1.04557 L .614 .668 0 r
F
.55775 1.00983 m .56344 1.00826 L .57207 1.01222 L .339 .361 0 r
F
.54962 1.00632 m .56344 1.00826 L .55775 1.00983 L .313 .317 0 r
F
.29005 1.19671 m .27587 1.18271 L .28709 1.18434 L .735 .726 0 r
F
.30108 1.19781 m .29005 1.19671 L .28709 1.18434 L .717 .713 0 r
F
.27461 .82413 m .28578 .80084 L .29418 .80639 L 1 .862 0 r
F
.27461 .82413 m .26551 .81898 L .28578 .80084 L F
.51572 .743 m .51585 .73844 L .54095 .73667 L .783 .865 0 r
F
.49176 .74705 m .51585 .73844 L .51572 .743 L .856 .914 0 r
F
.62734 1.43395 m .63356 1.44236 L .61505 1.4631 L 1 .847 0 r
F
.64379 1.41545 m .63356 1.44236 L .62734 1.43395 L 1 .747 0 r
F
.64379 1.41545 m .65094 1.42462 L .63356 1.44236 L F
.78628 1.40987 m .77911 1.43006 L .76984 1.42591 L 1 .836 0 r
F
.78628 1.40987 m .79619 1.41361 L .77911 1.43006 L F
.34907 1.21242 m .33424 1.20197 L .34531 1.20368 L .598 .645 0 r
F
.35988 1.21365 m .34907 1.21242 L .34531 1.20368 L .569 .624 0 r
F
.47384 1.25186 m .4674 1.25238 L .46109 1.24904 L .273 .257 0 r
F
.47965 1.25478 m .4674 1.25238 L .47384 1.25186 L .253 .228 0 r
F
.61478 1.35799 m .62207 1.37475 L .60822 1.37983 L .862 .373 0 r
F
.60822 1.37983 m .59942 1.44892 L .59381 1.41404 L 1 .516 0 r
F
.60822 1.37983 m .61471 1.40595 L .59942 1.44892 L F
.62207 1.37475 m .61471 1.40595 L .60822 1.37983 L 1 .507 0 r
F
.73254 1.40766 m .72523 1.42724 L .71659 1.42198 L 1 .812 0 r
F
.73254 1.40766 m .7419 1.41253 L .72523 1.42724 L F
.63861 1.0299 m .65574 1.03707 L .64538 1.03709 L .539 .622 0 r
F
.62879 1.0303 m .63861 1.0299 L .64538 1.03709 L .512 .599 0 r
F
.69688 .73136 m .72907 .73852 L .72128 .74262 L .842 .841 0 r
F
.69 .73583 m .69688 .73136 L .72128 .74262 L .831 .836 0 r
F
.65856 .73146 m .69 .73583 L .68314 .74021 L .82 .84 0 r
F
.65269 .73612 m .65856 .73146 L .68314 .74021 L .805 .833 0 r
F
.48384 .9801 m .49158 .98187 L .49379 .98408 L 0 .078 0 r
F
.48384 .9801 m .48051 .97723 L .49158 .98187 L F
.79906 1.05761 m .81457 1.07437 L .80327 1.07403 L .826 .787 0 r
F
.78788 1.05784 m .79906 1.05761 L .80327 1.07403 L .817 .781 0 r
F
.71551 1.04574 m .73215 1.05765 L .72104 1.0573 L .719 .727 0 r
F
.70467 1.0459 m .71551 1.04574 L .72104 1.0573 L .701 .715 0 r
F
.62734 1.43395 m .61505 1.4631 L .60986 1.45839 L 1 .847 0 r
F
.56404 1.29379 m .56142 1.29558 L .55614 1.29058 L .014 .074 0 r
F
.56404 1.29379 m .57032 1.29991 L .56142 1.29558 L F
.45417 .96056 m .4609 .9667 L .46537 .96857 L 0 .006 0 r
F
.45417 .96056 m .44869 .95497 L .4609 .9667 L F
.40054 .79305 m .41763 .77196 L .42215 .77697 L 1 1 0 r
F
.40054 .79305 m .39497 .78716 L .41763 .77196 L F
.58007 1.01643 m .58766 1.01528 L .59575 1.02011 L .395 .458 0 r
F
.57207 1.01222 m .58766 1.01528 L .58007 1.01643 L .376 .424 0 r
F
.49176 .74705 m .49069 .7426 L .51585 .73844 L .856 .914 0 r
F
.46801 .75381 m .49069 .7426 L .49176 .74705 L .983 .987 0 r
F
.69051 1.40404 m .68296 1.42441 L .67503 1.41755 L 1 .769 0 r
F
.69051 1.40404 m .69923 1.41045 L .68296 1.42441 L F
.54962 1.00632 m .55428 1.00453 L .56344 1.00826 L .313 .317 0 r
F
.54109 1.00296 m .55428 1.00453 L .54962 1.00632 L .282 .266 0 r
F
.53277 1.27611 m .52821 1.27683 L .52609 1.27364 L .096 .093 0 r
F
.53277 1.27611 m .53599 1.27986 L .52821 1.27683 L F
.51413 .99344 m .52455 .99441 L .52326 .99657 L .16 .117 0 r
F
.51413 .99344 m .51426 .99115 L .52455 .99441 L F
.3858 1.22327 m .37069 1.21505 L .38153 1.21664 L .486 .569 0 r
F
.39628 1.22444 m .3858 1.22327 L .38153 1.21664 L .457 .541 0 r
F
.55083 1.28556 m .54783 1.28697 L .54355 1.28281 L .042 .082 0 r
F
.55083 1.28556 m .55614 1.29058 L .54783 1.28697 L F
.42215 .77697 m .44131 .75921 L .44473 .76372 L 1 1 0 r
F
.42215 .77697 m .41763 .77196 L .44131 .75921 L F
.30108 1.19781 m .28709 1.18434 L .29831 1.18611 L .717 .713 0 r
F
.31212 1.19904 m .30108 1.19781 L .29831 1.18611 L .697 .699 0 r
F
.46801 .75381 m .46575 .74944 L .49069 .7426 L .983 .987 0 r
F
.44473 .76372 m .46575 .74944 L .46801 .75381 L 1 1 0 r
F
.44473 .76372 m .44131 .75921 L .46575 .74944 L F
.56572 .73706 m .56823 .73221 L .59353 .73467 L .763 .84 0 r
F
.54095 .73667 m .56823 .73221 L .56572 .73706 L .788 .863 0 r
F
.81026 1.05731 m .82588 1.07464 L .81457 1.07437 L .834 .793 0 r
F
.79906 1.05761 m .81026 1.05731 L .81457 1.07437 L .826 .787 0 r
F
.42646 1.23681 m .41137 1.23113 L .42142 1.23215 L .392 .45 0 r
F
.43597 1.23754 m .42646 1.23681 L .42142 1.23215 L .372 .416 0 r
F
.44121 1.2416 m .42646 1.23681 L .43597 1.23754 L .359 .394 0 r
F
.65907 1.40144 m .65094 1.42462 L .64379 1.41545 L 1 .711 0 r
F
.65907 1.40144 m .66707 1.40996 L .65094 1.42462 L F
.46981 .97184 m .47715 .97539 L .48051 .97723 L 0 .047 0 r
F
.46981 .97184 m .46537 .96857 L .47715 .97539 L F
.54109 1.00296 m .54467 1.00101 L .55428 1.00453 L .282 .266 0 r
F
.53228 .99973 m .54467 1.00101 L .54109 1.00296 L .246 .212 0 r
F
.52326 .99657 m .53472 .99767 L .53228 .99973 L .205 .159 0 r
F
.52326 .99657 m .52455 .99441 L .53472 .99767 L F
.46843 1.24888 m .46109 1.24904 L .4553 1.2456 L .291 .285 0 r
F
.47384 1.25186 m .46109 1.24904 L .46843 1.24888 L .273 .257 0 r
F
.41137 1.23113 m .39628 1.22444 L .40678 1.22582 L .422 .499 0 r
F
.42142 1.23215 m .41137 1.23113 L .40678 1.22582 L .404 .467 0 r
F
.53228 .99973 m .53472 .99767 L .54467 1.00101 L .246 .212 0 r
F
.57866 1.30329 m .57658 1.3065 L .57032 1.29991 L .068 .072 0 r
F
.57866 1.30329 m .58587 1.31099 L .57658 1.3065 L F
.67651 1.03652 m .69385 1.04593 L .68305 1.04583 L .638 .685 0 r
F
.66611 1.03688 m .67651 1.03652 L .68305 1.04583 L .614 .668 0 r
F
.34632 .81367 m .36044 .79096 L .36703 .79723 L 1 .897 0 r
F
.34632 .81367 m .33884 .80729 L .36044 .79096 L F
.35988 1.21365 m .34531 1.20368 L .35639 1.20557 L .569 .624 0 r
F
.37069 1.21505 m .35988 1.21365 L .35639 1.20557 L .539 .601 0 r
F
.18625 1.17349 m .17506 1.1727 L .17342 1.15354 L .859 .803 0 r
F
.77634 1.40601 m .76984 1.42591 L .76055 1.42163 L 1 .828 0 r
F
.77634 1.40601 m .78628 1.40987 L .76984 1.42591 L F
.45009 1.24207 m .44121 1.2416 L .43597 1.23754 L .339 .362 0 r
F
.4553 1.2456 m .44121 1.2416 L .45009 1.24207 L .324 .337 0 r
F
.6213 1.02397 m .63861 1.0299 L .62879 1.0303 L .488 .587 0 r
F
.61212 1.02468 m .6213 1.02397 L .62879 1.0303 L .462 .561 0 r
F
.72636 1.04545 m .74327 1.05789 L .73215 1.05765 L .735 .738 0 r
F
.71551 1.04574 m .72636 1.04545 L .73215 1.05765 L .719 .727 0 r
F
.31089 .81786 m .32379 .79508 L .33133 .80111 L 1 .875 0 r
F
.31089 .81786 m .30254 .81205 L .32379 .79508 L F
.26551 .81898 m .27736 .79538 L .28578 .80084 L 1 .868 0 r
F
.26551 .81898 m .25638 .81393 L .27736 .79538 L F
.72316 1.40252 m .71659 1.42198 L .70793 1.4164 L 1 .796 0 r
F
.72316 1.40252 m .73254 1.40766 L .71659 1.42198 L F
.59575 1.02011 m .60418 1.01915 L .61212 1.02468 L .427 .513 0 r
F
.58766 1.01528 m .60418 1.01915 L .59575 1.02011 L .411 .487 0 r
F
.62107 1.42281 m .62734 1.43395 L .60986 1.45839 L 1 .746 0 r
F
.6366 1.40436 m .62734 1.43395 L .62107 1.42281 L 1 .672 0 r
F
.6366 1.40436 m .64379 1.41545 L .62734 1.43395 L F
.82146 1.05694 m .83719 1.07484 L .82588 1.07464 L .841 .799 0 r
F
.81026 1.05731 m .82146 1.05694 L .82588 1.07464 L .834 .793 0 r
F
.31212 1.19904 m .29831 1.18611 L .30954 1.18802 L .697 .699 0 r
F
.32318 1.20043 m .31212 1.19904 L .30954 1.18802 L .675 .684 0 r
F
.37359 .80367 m .38938 .78125 L .39497 .78716 L 1 .952 0 r
F
.37359 .80367 m .36703 .79723 L .38938 .78125 L F
.62746 .72947 m .65856 .73146 L .65269 .73612 L .811 .845 0 r
F
.62266 .73431 m .62746 .72947 L .65269 .73612 L .792 .837 0 r
F
.18625 1.17349 m .17342 1.15354 L .18473 1.15495 L .859 .803 0 r
F
.19744 1.17435 m .18625 1.17349 L .18473 1.15495 L .852 .798 0 r
F
.50117 1.26128 m .49881 1.26315 L .49219 1.26041 L .203 .165 0 r
F
.50683 1.2636 m .49881 1.26315 L .50117 1.26128 L .188 .149 0 r
F
.50683 1.2636 m .50558 1.26584 L .49881 1.26315 L F
.60418 1.01915 m .6213 1.02397 L .61212 1.02468 L .443 .542 0 r
F
.49564 1.25889 m .49219 1.26041 L .48578 1.25763 L .218 .184 0 r
F
.50117 1.26128 m .49219 1.26041 L .49564 1.25889 L .203 .165 0 r
F
.68177 1.3971 m .67503 1.41755 L .66707 1.40996 L 1 .737 0 r
F
.68177 1.3971 m .69051 1.40404 L .67503 1.41755 L F
.59353 .73467 m .5972 .72976 L .62266 .73431 L .779 .839 0 r
F
.56823 .73221 m .5972 .72976 L .59353 .73467 L .795 .857 0 r
F
.53926 1.27842 m .53599 1.27986 L .53277 1.27611 L .096 .091 0 r
F
.53926 1.27842 m .54355 1.28281 L .53599 1.27986 L F
.51255 1.26586 m .50558 1.26584 L .50683 1.2636 L .174 .135 0 r
F
.51255 1.26586 m .51242 1.26848 L .50558 1.26584 L F
.57207 1.01222 m .57876 1.01076 L .58766 1.01528 L .376 .424 0 r
F
.56344 1.00826 m .57876 1.01076 L .57207 1.01222 L .352 .382 0 r
F
.64846 1.02932 m .66611 1.03688 L .65574 1.03707 L .566 .643 0 r
F
.63861 1.0299 m .64846 1.02932 L .65574 1.03707 L .539 .622 0 r
F
.19744 1.17435 m .18473 1.15495 L .19604 1.15643 L .852 .798 0 r
F
.20864 1.17527 m .19744 1.17435 L .19604 1.15643 L .845 .792 0 r
F
.49379 .98408 m .50292 .98579 L .50397 .98774 L 0 .089 0 r
F
.49379 .98408 m .49158 .98187 L .50292 .98579 L F
.65104 1.3918 m .64379 1.41545 L .6366 1.40436 L 1 .657 0 r
F
.65104 1.3918 m .65907 1.40144 L .64379 1.41545 L F
.49029 1.25645 m .48578 1.25763 L .47965 1.25478 L .234 .204 0 r
F
.49564 1.25889 m .48578 1.25763 L .49029 1.25645 L .218 .184 0 r
F
.61868 1.34428 m .61478 1.35799 L .60751 1.3428 L .594 .353 0 r
F
.61059 1.33291 m .60751 1.3428 L .60028 1.33016 L .383 .249 0 r
F
.61059 1.33291 m .61868 1.34428 L .60751 1.3428 L F
.83268 1.05651 m .84851 1.07498 L .83719 1.07484 L .848 .804 0 r
F
.82146 1.05694 m .83268 1.05651 L .83719 1.07484 L .841 .799 0 r
F
.5972 .72976 m .62746 .72947 L .62266 .73431 L .802 .851 0 r
F
.39628 1.22444 m .38153 1.21664 L .39238 1.21843 L .457 .541 0 r
F
.40678 1.22582 m .39628 1.22444 L .39238 1.21843 L .432 .511 0 r
F
.62678 1.35653 m .62207 1.37475 L .61478 1.35799 L .838 .452 0 r
F
.61868 1.34428 m .62678 1.35653 L .61478 1.35799 L .594 .353 0 r
F
.61471 1.40595 m .60465 1.45366 L .59942 1.44892 L 1 .614 0 r
F
.61471 1.40595 m .62107 1.42281 L .60465 1.45366 L F
.62936 1.39076 m .62107 1.42281 L .61471 1.40595 L 1 .591 0 r
F
.62207 1.37475 m .62936 1.39076 L .61471 1.40595 L 1 .507 0 r
F
.54095 .73667 m .54228 .73179 L .56823 .73221 L .788 .863 0 r
F
.51585 .73844 m .54228 .73179 L .54095 .73667 L .834 .896 0 r
F
.51827 1.26804 m .51242 1.26848 L .51255 1.26586 L .163 .125 0 r
F
.51827 1.26804 m .51928 1.27109 L .51242 1.26848 L F
.20864 1.17527 m .19604 1.15643 L .20735 1.15798 L .845 .792 0 r
F
.21984 1.17628 m .20864 1.17527 L .20735 1.15798 L .837 .785 0 r
F
.32318 1.20043 m .30954 1.18802 L .32077 1.19009 L .675 .684 0 r
F
.33424 1.20197 m .32318 1.20043 L .32077 1.19009 L .65 .667 0 r
F
.46347 1.24583 m .4553 1.2456 L .45009 1.24207 L .307 .31 0 r
F
.46843 1.24888 m .4553 1.2456 L .46347 1.24583 L .291 .285 0 r
F
.73723 1.04505 m .7544 1.05802 L .74327 1.05789 L .75 .748 0 r
F
.72636 1.04545 m .73723 1.04505 L .74327 1.05789 L .735 .738 0 r
F
.62107 1.42281 m .60986 1.45839 L .60465 1.45366 L 1 .746 0 r
F
.62936 1.39076 m .6366 1.40436 L .62107 1.42281 L 1 .591 0 r
F
.60252 1.32269 m .60028 1.33016 L .59307 1.31977 L .29 .172 0 r
F
.60252 1.32269 m .61059 1.33291 L .60028 1.33016 L F
.70379 .72681 m .73689 .73435 L .72907 .73852 L .853 .846 0 r
F
.69688 .73136 m .70379 .72681 L .72907 .73852 L .842 .841 0 r
F
.76639 1.40199 m .76055 1.42163 L .75124 1.41717 L 1 .819 0 r
F
.76639 1.40199 m .77634 1.40601 L .76055 1.42163 L F
.48517 1.25396 m .47965 1.25478 L .47384 1.25186 L .25 .225 0 r
F
.49029 1.25645 m .47965 1.25478 L .48517 1.25396 L .234 .204 0 r
F
.37069 1.21505 m .35639 1.20557 L .36748 1.20764 L .539 .601 0 r
F
.38153 1.21664 m .37069 1.21505 L .36748 1.20764 L .507 .576 0 r
F
.68693 1.03602 m .70467 1.0459 L .69385 1.04593 L .659 .7 0 r
F
.67651 1.03652 m .68693 1.03602 L .69385 1.04593 L .638 .685 0 r
F
.62678 1.35653 m .63488 1.36901 L .62207 1.37475 L .838 .452 0 r
F
.63488 1.36901 m .62936 1.39076 L .62207 1.37475 L 1 .531 0 r
F
.66444 .72671 m .69688 .73136 L .69 .73583 L .834 .847 0 r
F
.65856 .73146 m .66444 .72671 L .69 .73583 L .82 .84 0 r
F
.21984 1.17628 m .20735 1.15798 L .21865 1.15962 L .837 .785 0 r
F
.23104 1.17737 m .21984 1.17628 L .21865 1.15962 L .828 .778 0 r
F
.64297 1.38094 m .6366 1.40436 L .62936 1.39076 L 1 .597 0 r
F
.64297 1.38094 m .65104 1.3918 L .6366 1.40436 L F
.71376 1.39709 m .70793 1.4164 L .69923 1.41045 L 1 .776 0 r
F
.71376 1.39709 m .72316 1.40252 L .70793 1.4164 L F
.83268 1.05651 m .84391 1.05602 L .84851 1.07498 L .848 .804 0 r
F
.55775 1.28796 m .55614 1.29058 L .55083 1.28556 L .079 .084 0 r
F
.55775 1.28796 m .56404 1.29379 L .55614 1.29058 L F
.39497 .78716 m .41308 .76665 L .41763 .77196 L 1 1 0 r
F
.39497 .78716 m .38938 .78125 L .41308 .76665 L F
.44869 .95497 m .45638 .96766 L .4609 .9667 L .697 .038 0 r
F
.44869 .95497 m .44319 .94936 L .45638 .96766 L F
.52396 1.27013 m .51928 1.27109 L .51827 1.26804 L .153 .117 0 r
F
.52396 1.27013 m .52609 1.27364 L .51928 1.27109 L F
.63488 1.36901 m .64297 1.38094 L .62936 1.39076 L 1 .531 0 r
F
.25638 .81393 m .26892 .78999 L .27736 .79538 L 1 .873 0 r
F
.25638 .81393 m .24723 .80896 L .26892 .78999 L F
.67299 1.38953 m .66707 1.40996 L .65907 1.40144 L 1 .7 0 r
F
.67299 1.38953 m .68177 1.3971 L .66707 1.40996 L F
.30254 .81205 m .31623 .78917 L .32379 .79508 L 1 .882 0 r
F
.30254 .81205 m .29418 .80639 L .31623 .78917 L F
.56344 1.00826 m .56916 1.00656 L .57876 1.01076 L .352 .382 0 r
F
.55428 1.00453 m .56916 1.00656 L .56344 1.00826 L .323 .33 0 r
F
.23104 1.17737 m .21865 1.15962 L .22996 1.16135 L .828 .778 0 r
F
.24225 1.17855 m .23104 1.17737 L .22996 1.16135 L .818 .77 0 r
F
.33884 .80729 m .35383 .7848 L .36044 .79096 L 1 .907 0 r
F
.33884 .80729 m .33133 .80111 L .35383 .7848 L F
.57145 1.29632 m .57032 1.29991 L .56404 1.29379 L .099 .08 0 r
F
.57145 1.29632 m .57866 1.30329 L .57032 1.29991 L F
.42142 1.23215 m .40678 1.22582 L .4173 1.22741 L .404 .467 0 r
F
.4315 1.23339 m .42142 1.23215 L .4173 1.22741 L .384 .433 0 r
F
.43597 1.23754 m .42142 1.23215 L .4315 1.23339 L .372 .416 0 r
F
.44551 1.23848 m .43597 1.23754 L .4315 1.23339 L .352 .382 0 r
F
.45009 1.24207 m .43597 1.23754 L .44551 1.23848 L .339 .362 0 r
F
.48032 1.25142 m .47384 1.25186 L .46843 1.24888 L .265 .246 0 r
F
.48517 1.25396 m .47384 1.25186 L .48032 1.25142 L .25 .225 0 r
F
.51585 .73844 m .51598 .73358 L .54228 .73179 L .834 .896 0 r
F
.49069 .7426 m .51598 .73358 L .51585 .73844 L .911 .944 0 r
F
.33424 1.20197 m .32077 1.19009 L .332 1.19233 L .65 .667 0 r
F
.34531 1.20368 m .33424 1.20197 L .332 1.19233 L .623 .648 0 r
F
.50397 .98774 m .51438 .98924 L .51426 .99115 L .053 .099 0 r
F
.50397 .98774 m .50292 .98579 L .51438 .98924 L F
.58766 1.01528 m .59527 1.01395 L .60418 1.01915 L .411 .487 0 r
F
.57876 1.01076 m .59527 1.01395 L .58766 1.01528 L .392 .453 0 r
F
.59444 1.31359 m .59307 1.31977 L .58587 1.31099 L .227 .134 0 r
F
.59444 1.31359 m .60252 1.32269 L .59307 1.31977 L F
.6305 1.02306 m .64846 1.02932 L .63861 1.0299 L .515 .612 0 r
F
.6213 1.02397 m .6305 1.02306 L .63861 1.0299 L .488 .587 0 r
F
.74812 1.04454 m .76555 1.05805 L .7544 1.05802 L .764 .758 0 r
F
.73723 1.04505 m .74812 1.04454 L .7544 1.05802 L .75 .748 0 r
F
.54551 1.28052 m .54355 1.28281 L .53926 1.27842 L .107 .09 0 r
F
.54551 1.28052 m .55083 1.28556 L .54355 1.28281 L F
.41763 .77196 m .43788 .75429 L .44131 .75921 L 1 1 0 r
F
.41763 .77196 m .41308 .76665 L .43788 .75429 L F
.24225 1.17855 m .22996 1.16135 L .24126 1.16318 L .818 .77 0 r
F
.25345 1.17982 m .24225 1.17855 L .24126 1.16318 L .807 .761 0 r
F
.48507 .97914 m .48936 .98054 L .49158 .98187 L 0 .062 0 r
F
.49158 .98187 m .48936 .98054 L .50186 .98446 L 0 .08 0 r
F
.48936 .98054 m .48712 .98029 L .49344 .98188 L .215 0 0 r
F
.49928 .98365 m .5008 .98373 L .50186 .98446 L F
.48936 .98054 m .5008 .98373 L .49928 .98365 L F
.5008 .98373 m .49973 .98349 L .5023 .98381 L 0 .093 0 r
F
.5008 .98373 m .5023 .98381 L .51477 .98537 L F
.48936 .98054 m .49344 .98188 L .5008 .98373 L .215 0 0 r
F
.48051 .97723 m .48936 .98054 L .48507 .97914 L 0 .062 0 r
F
.48051 .97723 m .47715 .97539 L .48936 .98054 L F
.36703 .79723 m .38377 .77533 L .38938 .78125 L 1 .957 0 r
F
.36703 .79723 m .36044 .79096 L .38377 .77533 L F
.64846 1.02932 m .65833 1.02856 L .66611 1.03688 L .566 .643 0 r
F
.65833 1.02856 m .67651 1.03652 L .66611 1.03688 L .591 .663 0 r
F
.75642 1.39781 m .75124 1.41717 L .7419 1.41253 L 1 .808 0 r
F
.75642 1.39781 m .76639 1.40199 L .75124 1.41717 L F
.49069 .7426 m .48961 .7378 L .51598 .73358 L .911 .944 0 r
F
.46575 .74944 m .48961 .7378 L .49069 .7426 L 1 1 0 r
F
.52953 1.27209 m .52609 1.27364 L .52396 1.27013 L .148 .112 0 r
F
.52953 1.27209 m .53277 1.27611 L .52609 1.27364 L F
.40678 1.22582 m .39238 1.21843 L .40325 1.22043 L .432 .511 0 r
F
.4173 1.22741 m .40678 1.22582 L .40325 1.22043 L .413 .479 0 r
F
.459 1.24275 m .45009 1.24207 L .44551 1.23848 L .321 .331 0 r
F
.46347 1.24583 m .45009 1.24207 L .459 1.24275 L .307 .31 0 r
F
.38153 1.21664 m .36748 1.20764 L .37858 1.20991 L .507 .576 0 r
F
.39238 1.21843 m .38153 1.21664 L .37858 1.20991 L .474 .548 0 r
F
.44131 .75921 m .46348 .74465 L .46575 .74944 L 1 1 0 r
F
.44131 .75921 m .43788 .75429 L .46348 .74465 L F
.56823 .73221 m .57075 .72717 L .5972 .72976 L .795 .857 0 r
F
.54228 .73179 m .57075 .72717 L .56823 .73221 L .824 .882 0 r
F
.70434 1.3913 m .69923 1.41045 L .69051 1.40404 L 1 .753 0 r
F
.70434 1.3913 m .71376 1.39709 L .69923 1.41045 L F
.25345 1.17982 m .24126 1.16318 L .25256 1.16511 L .807 .761 0 r
F
.26466 1.18121 m .25345 1.17982 L .25256 1.16511 L .794 .751 0 r
F
.55428 1.00453 m .55896 1.00267 L .56916 1.00656 L .323 .33 0 r
F
.54467 1.00101 m .55896 1.00267 L .55428 1.00453 L .287 .268 0 r
F
.46575 .74944 m .46348 .74465 L .48961 .7378 L 1 1 0 r
F
.66419 1.38126 m .65907 1.40144 L .65104 1.3918 L 1 .658 0 r
F
.66419 1.38126 m .67299 1.38953 L .65907 1.40144 L F
.69737 1.03537 m .71551 1.04574 L .70467 1.0459 L .679 .714 0 r
F
.68693 1.03602 m .69737 1.03537 L .70467 1.0459 L .659 .7 0 r
F
.60418 1.01915 m .61264 1.01799 L .6213 1.02397 L .443 .542 0 r
F
.59527 1.01395 m .61264 1.01799 L .60418 1.01915 L .428 .517 0 r
F
.46537 .96857 m .47376 .97509 L .47715 .97539 L .484 0 0 r
F
.46537 .96857 m .4609 .9667 L .47376 .97509 L F
.61264 1.01799 m .6305 1.02306 L .6213 1.02397 L .463 .57 0 r
F
.47581 1.24884 m .46843 1.24888 L .46347 1.24583 L .279 .267 0 r
F
.48032 1.25142 m .46843 1.24888 L .47581 1.24884 L .265 .246 0 r
F
.34531 1.20368 m .332 1.19233 L .34324 1.19475 L .623 .648 0 r
F
.35639 1.20557 m .34531 1.20368 L .34324 1.19475 L .593 .627 0 r
F
.51426 .99115 m .52585 .99248 L .52455 .99441 L .124 .108 0 r
F
.51426 .99115 m .51438 .98924 L .52585 .99248 L F
.82106 1.39999 m .81596 1.42075 L .80608 1.41723 L .961 .834 0 r
F
.82106 1.39999 m .8315 1.40305 L .81596 1.42075 L F
.63228 .72451 m .66444 .72671 L .65856 .73146 L .827 .853 0 r
F
.62746 .72947 m .63228 .72451 L .65856 .73146 L .811 .845 0 r
F
.26466 1.18121 m .25256 1.16511 L .26385 1.16716 L .794 .751 0 r
F
.27587 1.18271 m .26466 1.18121 L .26385 1.16716 L .78 .74 0 r
F
.75902 1.04394 m .77671 1.05799 L .76555 1.05805 L .776 .766 0 r
F
.74812 1.04454 m .75902 1.04394 L .76555 1.05805 L .764 .758 0 r
F
.54467 1.00101 m .54826 .99907 L .55896 1.00267 L .287 .268 0 r
F
.53472 .99767 m .54826 .99907 L .54467 1.00101 L .242 .2 0 r
F
.58637 1.30543 m .58587 1.31099 L .57866 1.30329 L .195 .123 0 r
F
.58637 1.30543 m .59444 1.31359 L .58587 1.31099 L F
.52455 .99441 m .53718 .9957 L .53472 .99767 L .188 .134 0 r
F
.52455 .99441 m .52585 .99248 L .53718 .9957 L F
.65537 1.37227 m .65104 1.3918 L .64297 1.38094 L 1 .613 0 r
F
.65537 1.37227 m .66419 1.38126 L .65104 1.3918 L F
.29418 .80639 m .30865 .78334 L .31623 .78917 L 1 .888 0 r
F
.29418 .80639 m .28578 .80084 L .30865 .78334 L F
.53472 .99767 m .53718 .9957 L .54826 .99907 L .242 .2 0 r
F
.70379 .72681 m .71072 .72219 L .73689 .73435 L .853 .846 0 r
F
.74643 1.39344 m .7419 1.41253 L .73254 1.40766 L 1 .795 0 r
F
.74643 1.39344 m .75642 1.39781 L .7419 1.41253 L F
.5972 .72976 m .60089 .7247 L .62746 .72947 L .802 .851 0 r
F
.57075 .72717 m .60089 .7247 L .5972 .72976 L .821 .87 0 r
F
.27587 1.18271 m .26385 1.16716 L .27515 1.16934 L .78 .74 0 r
F
.28709 1.18434 m .27587 1.18271 L .27515 1.16934 L .764 .729 0 r
F
.53495 1.27388 m .53277 1.27611 L .52953 1.27209 L .148 .112 0 r
F
.53495 1.27388 m .53926 1.27842 L .53277 1.27611 L F
.57876 1.01076 m .58548 1.00913 L .59527 1.01395 L .392 .453 0 r
F
.56916 1.00656 m .58548 1.00913 L .57876 1.01076 L .368 .408 0 r
F
.33133 .80111 m .3472 .77873 L .35383 .7848 L 1 .913 0 r
F
.33133 .80111 m .32379 .79508 L .3472 .77873 L F
.60089 .7247 m .63228 .72451 L .62746 .72947 L .823 .861 0 r
F
.69489 1.38511 m .69051 1.40404 L .68177 1.3971 L 1 .727 0 r
F
.69489 1.38511 m .70434 1.3913 L .69051 1.40404 L F
.4315 1.23339 m .4173 1.22741 L .42784 1.22921 L .384 .433 0 r
F
.4416 1.23485 m .4315 1.23339 L .42784 1.22921 L .363 .398 0 r
F
.44551 1.23848 m .4315 1.23339 L .4416 1.23485 L .352 .382 0 r
F
.56423 1.28985 m .56404 1.29379 L .55775 1.28796 L .131 .092 0 r
F
.56423 1.28985 m .57145 1.29632 L .56404 1.29379 L F
.47167 1.24623 m .46347 1.24583 L .459 1.24275 L .292 .286 0 r
F
.47581 1.24884 m .46347 1.24583 L .47167 1.24623 L .279 .267 0 r
F
.35639 1.20557 m .34324 1.19475 L .35449 1.19736 L .593 .627 0 r
F
.36748 1.20764 m .35639 1.20557 L .35449 1.19736 L .561 .604 0 r
F
.39238 1.21843 m .37858 1.20991 L .3897 1.21237 L .474 .548 0 r
F
.40325 1.22043 m .39238 1.21843 L .3897 1.21237 L .443 .518 0 r
F
.50355 1.25924 m .50117 1.26128 L .49564 1.25889 L .219 .186 0 r
F
.50808 1.26115 m .50117 1.26128 L .50355 1.25924 L .21 .175 0 r
F
.50808 1.26115 m .50683 1.2636 L .50117 1.26128 L F
.67035 .72185 m .70379 .72681 L .69688 .73136 L .846 .852 0 r
F
.66444 .72671 m .67035 .72185 L .69688 .73136 L .834 .847 0 r
F
.55143 1.28231 m .55083 1.28556 L .54551 1.28052 L .129 .096 0 r
F
.55143 1.28231 m .55775 1.28796 L .55083 1.28556 L F
.38938 .78125 m .40853 .76112 L .41308 .76665 L 1 1 0 r
F
.38938 .78125 m .38377 .77533 L .40853 .76112 L F
.44319 .94936 m .45177 .97465 L .45638 .96766 L .929 .076 0 r
F
.44319 .94936 m .43768 .94372 L .45177 .97465 L F
.49911 1.25726 m .49564 1.25889 L .49029 1.25645 L .229 .198 0 r
F
.50355 1.25924 m .49564 1.25889 L .49911 1.25726 L .219 .186 0 r
F
.64653 1.36264 m .64297 1.38094 L .63488 1.36901 L .922 .563 0 r
F
.64653 1.36264 m .65537 1.37227 L .64297 1.38094 L F
.81061 1.39683 m .80608 1.41723 L .79619 1.41361 L .961 .828 0 r
F
.81061 1.39683 m .82106 1.39999 L .80608 1.41723 L F
.51267 1.26298 m .50683 1.2636 L .50808 1.26115 L .202 .166 0 r
F
.51267 1.26298 m .51255 1.26586 L .50683 1.2636 L F
.66823 1.02763 m .68693 1.03602 L .67651 1.03652 L .615 .681 0 r
F
.65833 1.02856 m .66823 1.02763 L .67651 1.03652 L .591 .663 0 r
F
.70783 1.0346 m .72636 1.04545 L .71551 1.04574 L .698 .726 0 r
F
.69737 1.03537 m .70783 1.0346 L .71551 1.04574 L .679 .714 0 r
F
.28709 1.18434 m .27515 1.16934 L .28644 1.17166 L .764 .729 0 r
F
.29831 1.18611 m .28709 1.18434 L .28644 1.17166 L .746 .716 0 r
F
.76994 1.04324 m .78788 1.05784 L .77671 1.05799 L .788 .774 0 r
F
.75902 1.04394 m .76994 1.04324 L .77671 1.05799 L .776 .766 0 r
F
.63973 1.02196 m .65833 1.02856 L .64846 1.02932 L .541 .635 0 r
F
.6305 1.02306 m .63973 1.02196 L .64846 1.02932 L .515 .612 0 r
F
.45507 1.23963 m .44551 1.23848 L .4416 1.23485 L .333 .349 0 r
F
.459 1.24275 m .44551 1.23848 L .45507 1.23963 L .321 .331 0 r
F
.49482 1.25523 m .49029 1.25645 L .48517 1.25396 L .239 .211 0 r
F
.49911 1.25726 m .49029 1.25645 L .49482 1.25523 L .229 .198 0 r
F
.54228 .73179 m .54362 .72669 L .57075 .72717 L .824 .882 0 r
F
.51598 .73358 m .54362 .72669 L .54228 .73179 L .873 .916 0 r
F
.4173 1.22741 m .40325 1.22043 L .41414 1.22263 L .413 .479 0 r
F
.42784 1.22921 m .4173 1.22741 L .41414 1.22263 L .393 .444 0 r
F
.63767 1.35259 m .63488 1.36901 L .62678 1.35653 L .809 .508 0 r
F
.63767 1.35259 m .64653 1.36264 L .63488 1.36901 L F
.49158 .98187 m .50186 .98446 L .50292 .98579 L 0 .08 0 r
F
.6288 1.34243 m .62678 1.35653 L .61868 1.34428 L .663 .448 0 r
F
.6288 1.34243 m .63767 1.35259 L .62678 1.35653 L F
.51726 1.26473 m .51255 1.26586 L .51267 1.26298 L .195 .158 0 r
F
.51726 1.26473 m .51827 1.26804 L .51255 1.26586 L F
.36044 .79096 m .37814 .76938 L .38377 .77533 L 1 .958 0 r
F
.36044 .79096 m .35383 .7848 L .37814 .76938 L F
.49071 1.25316 m .48517 1.25396 L .48032 1.25142 L .249 .225 0 r
F
.49482 1.25523 m .48517 1.25396 L .49071 1.25316 L .239 .211 0 r
F
.61994 1.33252 m .61868 1.34428 L .61059 1.33291 L .505 .382 0 r
F
.61994 1.33252 m .6288 1.34243 L .61868 1.34428 L F
.29831 1.18611 m .28644 1.17166 L .29773 1.17413 L .746 .716 0 r
F
.30954 1.18802 m .29831 1.18611 L .29773 1.17413 L .726 .701 0 r
F
.73642 1.38885 m .73254 1.40766 L .72316 1.40252 L .996 .781 0 r
F
.73642 1.38885 m .74643 1.39344 L .73254 1.40766 L F
.57829 1.29799 m .57866 1.30329 L .57145 1.29632 L .185 .126 0 r
F
.57829 1.29799 m .58637 1.30543 L .57866 1.30329 L F
.68541 1.37848 m .68177 1.3971 L .67299 1.38953 L 1 .698 0 r
F
.68541 1.37848 m .69489 1.38511 L .68177 1.3971 L F
.59527 1.01395 m .60292 1.01242 L .61264 1.01799 L .428 .517 0 r
F
.58548 1.00913 m .60292 1.01242 L .59527 1.01395 L .409 .484 0 r
F
.36748 1.20764 m .35449 1.19736 L .36574 1.20015 L .561 .604 0 r
F
.37858 1.20991 m .36748 1.20764 L .36574 1.20015 L .526 .579 0 r
F
.54016 1.27546 m .53926 1.27842 L .53495 1.27388 L .154 .116 0 r
F
.54016 1.27546 m .54551 1.28052 L .53926 1.27842 L F
.52182 1.26636 m .51827 1.26804 L .51726 1.26473 L .19 .152 0 r
F
.52182 1.26636 m .52396 1.27013 L .51827 1.26804 L F
.41308 .76665 m .43444 .74905 L .43788 .75429 L 1 1 0 r
F
.41308 .76665 m .40853 .76112 L .43444 .74905 L F
.80014 1.39357 m .79619 1.41361 L .78628 1.40987 L .96 .821 0 r
F
.80014 1.39357 m .81061 1.39683 L .79619 1.41361 L F
.56916 1.00656 m .5749 1.00471 L .58548 1.00913 L .368 .408 0 r
F
.55896 1.00267 m .5749 1.00471 L .56916 1.00656 L .337 .351 0 r
F
.61108 1.32312 m .61059 1.33291 L .60252 1.32269 L .39 .317 0 r
F
.61108 1.32312 m .61994 1.33252 L .61059 1.33291 L F
.78088 1.04246 m .79906 1.05761 L .78788 1.05784 L .798 .781 0 r
F
.76994 1.04324 m .78088 1.04246 L .78788 1.05784 L .788 .774 0 r
F
.46794 1.24361 m .459 1.24275 L .45507 1.23963 L .303 .304 0 r
F
.47167 1.24623 m .459 1.24275 L .46794 1.24361 L .292 .286 0 r
F
.48683 1.25105 m .48032 1.25142 L .47581 1.24884 L .259 .239 0 r
F
.49071 1.25316 m .48032 1.25142 L .48683 1.25105 L .249 .225 0 r
F
.62113 1.01664 m .63973 1.02196 L .6305 1.02306 L .489 .597 0 r
F
.61264 1.01799 m .62113 1.01664 L .6305 1.02306 L .463 .57 0 r
F
.51598 .73358 m .51611 .72848 L .54362 .72669 L .873 .916 0 r
F
.48961 .7378 m .51611 .72848 L .51598 .73358 L .948 .96 0 r
F
.28578 .80084 m .30104 .77758 L .30865 .78334 L 1 .893 0 r
F
.28578 .80084 m .27736 .79538 L .30104 .77758 L F
.30954 1.18802 m .29773 1.17413 L .30903 1.17676 L .726 .701 0 r
F
.32077 1.19009 m .30954 1.18802 L .30903 1.17676 L .703 .685 0 r
F
.40325 1.22043 m .3897 1.21237 L .40083 1.21503 L .443 .518 0 r
F
.41414 1.22263 m .40325 1.22043 L .40083 1.21503 L .42 .486 0 r
F
.60292 1.01242 m .62113 1.01664 L .61264 1.01799 L .444 .547 0 r
F
.71831 1.0337 m .73723 1.04505 L .72636 1.04545 L .715 .738 0 r
F
.70783 1.0346 m .71831 1.0337 L .72636 1.04545 L .698 .726 0 r
F
.43788 .75429 m .46121 .73955 L .46348 .74465 L 1 1 0 r
F
.43788 .75429 m .43444 .74905 L .46121 .73955 L F
.67592 1.37136 m .67299 1.38953 L .66419 1.38126 L .971 .665 0 r
F
.67592 1.37136 m .68541 1.37848 L .67299 1.38953 L F
.32379 .79508 m .34054 .77272 L .3472 .77873 L 1 .917 0 r
F
.32379 .79508 m .31623 .78917 L .34054 .77272 L F
.60222 1.31435 m .60252 1.32269 L .59444 1.31359 L .332 .264 0 r
F
.60222 1.31435 m .61108 1.32312 L .60252 1.32269 L F
.52629 1.26787 m .52396 1.27013 L .52182 1.26636 L .186 .148 0 r
F
.52629 1.26787 m .52953 1.27209 L .52396 1.27013 L F
.72639 1.38401 m .72316 1.40252 L .71376 1.39709 L .987 .764 0 r
F
.72639 1.38401 m .73642 1.38885 L .72316 1.40252 L F
.63711 .71944 m .67035 .72185 L .66444 .72671 L .842 .859 0 r
F
.63228 .72451 m .63711 .71944 L .66444 .72671 L .827 .853 0 r
F
.48961 .7378 m .48853 .73271 L .51611 .72848 L .948 .96 0 r
F
.46348 .74465 m .48853 .73271 L .48961 .7378 L 1 1 0 r
F
.57075 .72717 m .57328 .72196 L .60089 .7247 L .821 .87 0 r
F
.54362 .72669 m .57328 .72196 L .57075 .72717 L .853 .895 0 r
F
.50292 .98579 m .51451 .9877 L .51438 .98924 L 0 .096 0 r
F
.50292 .98579 m .50186 .98446 L .51451 .9877 L F
.67815 1.02656 m .69737 1.03537 L .68693 1.03602 L .638 .697 0 r
F
.66823 1.02763 m .67815 1.02656 L .68693 1.03602 L .615 .681 0 r
F
.32077 1.19009 m .30903 1.17676 L .32032 1.17957 L .703 .685 0 r
F
.332 1.19233 m .32077 1.19009 L .32032 1.17957 L .677 .668 0 r
F
.48321 1.24892 m .47581 1.24884 L .47167 1.24623 L .269 .253 0 r
F
.48683 1.25105 m .47581 1.24884 L .48321 1.24892 L .259 .239 0 r
F
.46348 .74465 m .46121 .73955 L .48853 .73271 L 1 1 0 r
F
.47715 .97539 m .48712 .98029 L .48936 .98054 L .371 0 0 r
F
.47715 .97539 m .47376 .97509 L .48712 .98029 L F
.4416 1.23485 m .42784 1.22921 L .43841 1.23122 L .363 .398 0 r
F
.45173 1.23652 m .4416 1.23485 L .43841 1.23122 L .342 .364 0 r
F
.45507 1.23963 m .4416 1.23485 L .45173 1.23652 L .333 .349 0 r
F
.55699 1.28371 m .55775 1.28796 L .55143 1.28231 L .161 .118 0 r
F
.55699 1.28371 m .56423 1.28985 L .55775 1.28796 L F
.37858 1.20991 m .36574 1.20015 L .377 1.20314 L .526 .579 0 r
F
.3897 1.21237 m .37858 1.20991 L .377 1.20314 L .491 .551 0 r
F
.42784 1.22921 m .41414 1.22263 L .42505 1.22503 L .393 .444 0 r
F
.43841 1.23122 m .42784 1.22921 L .42505 1.22503 L .372 .409 0 r
F
.78965 1.39019 m .78628 1.40987 L .77634 1.40601 L .959 .814 0 r
F
.78965 1.39019 m .80014 1.39357 L .78628 1.40987 L F
.79183 1.0416 m .81026 1.05731 L .79906 1.05761 L .807 .787 0 r
F
.78088 1.04246 m .79183 1.0416 L .79906 1.05761 L .798 .781 0 r
F
.55896 1.00267 m .56366 1.0007 L .5749 1.00471 L .337 .351 0 r
F
.54826 .99907 m .56366 1.0007 L .55896 1.00267 L .298 .279 0 r
F
.63973 1.02196 m .64899 1.02069 L .65833 1.02856 L .541 .635 0 r
F
.64899 1.02069 m .66823 1.02763 L .65833 1.02856 L .567 .656 0 r
F
.4609 .9667 m .47034 .97695 L .47376 .97509 L .634 .014 0 r
F
.4609 .9667 m .45638 .96766 L .47034 .97695 L F
.57021 1.29112 m .57145 1.29632 L .56423 1.28985 L .189 .138 0 r
F
.57021 1.29112 m .57829 1.29799 L .57145 1.29632 L F
.66641 1.36376 m .66419 1.38126 L .65537 1.37227 L .924 .629 0 r
F
.66641 1.36376 m .67592 1.37136 L .66419 1.38126 L F
.5451 1.27679 m .54551 1.28052 L .54016 1.27546 L .167 .127 0 r
F
.5451 1.27679 m .55143 1.28231 L .54551 1.28052 L F
.38377 .77533 m .40395 .75544 L .40853 .76112 L 1 1 0 r
F
.38377 .77533 m .37814 .76938 L .40395 .75544 L F
.43768 .94372 m .44704 .99042 L .45177 .97465 L 1 .109 0 r
F
.43768 .94372 m .43179 .96622 L .44704 .99042 L F
.67627 .71691 m .71072 .72219 L .70379 .72681 L .857 .856 0 r
F
.67035 .72185 m .67627 .71691 L .70379 .72681 L .846 .852 0 r
F
.46467 1.24098 m .45507 1.23963 L .45173 1.23652 L .313 .319 0 r
F
.46794 1.24361 m .45507 1.23963 L .46467 1.24098 L .303 .304 0 r
F
.332 1.19233 m .32032 1.17957 L .33161 1.18255 L .677 .668 0 r
F
.34324 1.19475 m .332 1.19233 L .33161 1.18255 L .649 .649 0 r
F
.59336 1.30624 m .59444 1.31359 L .58637 1.30543 L .288 .228 0 r
F
.59336 1.30624 m .60222 1.31435 L .59444 1.31359 L F
.60089 .7247 m .60459 .71951 L .63228 .72451 L .823 .861 0 r
F
.57328 .72196 m .60459 .71951 L .60089 .7247 L .844 .88 0 r
F
.60459 .71951 m .63711 .71944 L .63228 .72451 L .841 .868 0 r
F
.53063 1.26922 m .52953 1.27209 L .52629 1.26787 L .186 .147 0 r
F
.53063 1.26922 m .53495 1.27388 L .52953 1.27209 L F
.35383 .7848 m .37249 .76341 L .37814 .76938 L 1 .958 0 r
F
.35383 .7848 m .3472 .77873 L .37249 .76341 L F
.51438 .98924 m .52715 .99072 L .52585 .99248 L .095 .108 0 r
F
.51438 .98924 m .51451 .9877 L .52715 .99072 L F
.4799 1.24678 m .47167 1.24623 L .46794 1.24361 L .279 .267 0 r
F
.48321 1.24892 m .47167 1.24623 L .4799 1.24678 L .269 .253 0 r
F
.71634 1.37889 m .71376 1.39709 L .70434 1.3913 L .975 .744 0 r
F
.71634 1.37889 m .72639 1.38401 L .71376 1.39709 L F
.58548 1.00913 m .59222 1.00732 L .60292 1.01242 L .409 .484 0 r
F
.5749 1.00471 m .59222 1.00732 L .58548 1.00913 L .386 .439 0 r
F
.41414 1.22263 m .40083 1.21503 L .41198 1.21788 L .42 .486 0 r
F
.42505 1.22503 m .41414 1.22263 L .41198 1.21788 L .4 .452 0 r
F
.72881 1.03268 m .74812 1.04454 L .73723 1.04505 L .73 .748 0 r
F
.71831 1.0337 m .72881 1.03268 L .73723 1.04505 L .715 .738 0 r
F
.54826 .99907 m .55186 .99708 L .56366 1.0007 L .298 .279 0 r
F
.53718 .9957 m .55186 .99708 L .54826 .99907 L .247 .196 0 r
F
.8028 1.04067 m .82146 1.05694 L .81026 1.05731 L .816 .793 0 r
F
.79183 1.0416 m .8028 1.04067 L .81026 1.05731 L .807 .787 0 r
F
.27736 .79538 m .2934 .77187 L .30104 .77758 L 1 .896 0 r
F
.27736 .79538 m .26892 .78999 L .2934 .77187 L F
.77915 1.38669 m .77634 1.40601 L .76639 1.40199 L .956 .805 0 r
F
.77915 1.38669 m .78965 1.39019 L .77634 1.40601 L F
.65688 1.35571 m .65537 1.37227 L .64653 1.36264 L .86 .59 0 r
F
.65688 1.35571 m .66641 1.36376 L .65537 1.37227 L F
.3897 1.21237 m .377 1.20314 L .38827 1.20633 L .491 .551 0 r
F
.40083 1.21503 m .3897 1.21237 L .38827 1.20633 L .455 .521 0 r
F
.52585 .99248 m .53965 .99378 L .53718 .9957 L .18 .12 0 r
F
.52585 .99248 m .52715 .99072 L .53965 .99378 L F
.34324 1.19475 m .33161 1.18255 L .34291 1.18573 L .649 .649 0 r
F
.35449 1.19736 m .34324 1.19475 L .34291 1.18573 L .617 .627 0 r
F
.53718 .9957 m .53965 .99378 L .55186 .99708 L .247 .196 0 r
F
.54362 .72669 m .54496 .7214 L .57328 .72196 L .853 .895 0 r
F
.51611 .72848 m .54496 .7214 L .54362 .72669 L .903 .928 0 r
F
.62964 1.0151 m .64899 1.02069 L .63973 1.02196 L .515 .622 0 r
F
.62113 1.01664 m .62964 1.0151 L .63973 1.02196 L .489 .597 0 r
F
.50593 1.25705 m .50355 1.25924 L .49911 1.25726 L .233 .204 0 r
F
.50934 1.25851 m .50355 1.25924 L .50593 1.25705 L .228 .197 0 r
F
.50934 1.25851 m .50808 1.26115 L .50355 1.25924 L F
.68809 1.02534 m .70783 1.0346 L .69737 1.03537 L .658 .712 0 r
F
.67815 1.02656 m .68809 1.02534 L .69737 1.03537 L .638 .697 0 r
F
.5026 1.25553 m .49911 1.25726 L .49482 1.25523 L .238 .211 0 r
F
.50593 1.25705 m .49911 1.25726 L .5026 1.25553 L .233 .204 0 r
F
.64734 1.34731 m .64653 1.36264 L .63767 1.35259 L .777 .548 0 r
F
.64734 1.34731 m .65688 1.35571 L .64653 1.36264 L F
.51279 1.2599 m .50808 1.26115 L .50934 1.25851 L .223 .191 0 r
F
.51279 1.2599 m .51267 1.26298 L .50808 1.26115 L F
.49937 1.25396 m .49482 1.25523 L .49071 1.25316 L .244 .218 0 r
F
.5026 1.25553 m .49482 1.25523 L .49937 1.25396 L .238 .211 0 r
F
.31623 .78917 m .33386 .76674 L .34054 .77272 L 1 .92 0 r
F
.31623 .78917 m .30865 .78334 L .33386 .76674 L F
.70627 1.37346 m .70434 1.3913 L .69489 1.38511 L .957 .723 0 r
F
.70627 1.37346 m .71634 1.37889 L .70434 1.3913 L F
.58449 1.29872 m .58637 1.30543 L .57829 1.29799 L .259 .207 0 r
F
.58449 1.29872 m .59336 1.30624 L .58637 1.30543 L F
.5348 1.27039 m .53495 1.27388 L .53063 1.26922 L .189 .15 0 r
F
.5348 1.27039 m .54016 1.27546 L .53495 1.27388 L F
.60292 1.01242 m .61059 1.0107 L .62113 1.01664 L .444 .547 0 r
F
.59222 1.00732 m .61059 1.0107 L .60292 1.01242 L .427 .516 0 r
F
.47692 1.24464 m .46794 1.24361 L .46467 1.24098 L .288 .28 0 r
F
.4799 1.24678 m .46794 1.24361 L .47692 1.24464 L .279 .267 0 r
F
.40853 .76112 m .43099 .74358 L .43444 .74905 L 1 1 0 r
F
.40853 .76112 m .40395 .75544 L .43099 .74358 L F
.43841 1.23122 m .42505 1.22503 L .43598 1.22763 L .372 .409 0 r
F
.44901 1.23343 m .43841 1.23122 L .43598 1.22763 L .35 .374 0 r
F
.45173 1.23652 m .43841 1.23122 L .44901 1.23343 L .342 .364 0 r
F
.63778 1.33872 m .63767 1.35259 L .6288 1.34243 L .677 .503 0 r
F
.63778 1.33872 m .64734 1.34731 L .63767 1.35259 L F
.51624 1.26121 m .51267 1.26298 L .51279 1.2599 L .219 .186 0 r
F
.51624 1.26121 m .51726 1.26473 L .51267 1.26298 L F
.35449 1.19736 m .34291 1.18573 L .3542 1.18911 L .617 .627 0 r
F
.36574 1.20015 m .35449 1.19736 L .3542 1.18911 L .582 .604 0 r
F
.49628 1.25236 m .49071 1.25316 L .48683 1.25105 L .25 .226 0 r
F
.49937 1.25396 m .49071 1.25316 L .49628 1.25236 L .244 .218 0 r
F
.81379 1.03967 m .83268 1.05651 L .82146 1.05694 L .824 .799 0 r
F
.8028 1.04067 m .81379 1.03967 L .82146 1.05694 L .816 .793 0 r
F
.61059 1.0107 m .62964 1.0151 L .62113 1.01664 L .463 .577 0 r
F
.76863 1.38303 m .76639 1.40199 L .75642 1.39781 L .952 .795 0 r
F
.76863 1.38303 m .77915 1.38669 L .76639 1.40199 L F
.46189 1.23838 m .45173 1.23652 L .44901 1.23343 L .322 .331 0 r
F
.46467 1.24098 m .45173 1.23652 L .46189 1.23838 L .313 .319 0 r
F
.56211 1.28465 m .56423 1.28985 L .55699 1.28371 L .198 .154 0 r
F
.56211 1.28465 m .57021 1.29112 L .56423 1.28985 L F
.54973 1.27782 m .55143 1.28231 L .5451 1.27679 L .187 .145 0 r
F
.54973 1.27782 m .55699 1.28371 L .55143 1.28231 L F
.73933 1.03156 m .75902 1.04394 L .74812 1.04454 L .745 .758 0 r
F
.72881 1.03268 m .73933 1.03156 L .74812 1.04454 L .73 .748 0 r
F
.65828 1.01926 m .67815 1.02656 L .66823 1.02763 L .592 .675 0 r
F
.64899 1.02069 m .65828 1.01926 L .66823 1.02763 L .567 .656 0 r
F
.40083 1.21503 m .38827 1.20633 L .39956 1.20969 L .455 .521 0 r
F
.41198 1.21788 m .40083 1.21503 L .39956 1.20969 L .425 .489 0 r
F
.62823 1.33012 m .6288 1.34243 L .61994 1.33252 L .565 .455 0 r
F
.62823 1.33012 m .63778 1.33872 L .6288 1.34243 L F
.42505 1.22503 m .41198 1.21788 L .42315 1.22092 L .4 .452 0 r
F
.43598 1.22763 m .42505 1.22503 L .42315 1.22092 L .378 .416 0 r
F
.5749 1.00471 m .58067 1.0027 L .59222 1.00732 L .386 .439 0 r
F
.56366 1.0007 m .58067 1.0027 L .5749 1.00471 L .356 .379 0 r
F
.18473 1.15495 m .17342 1.15354 L .1753 1.13399 L .885 .808 0 r
F
.51967 1.26241 m .51726 1.26473 L .51624 1.26121 L .216 .182 0 r
F
.51967 1.26241 m .52182 1.26636 L .51726 1.26473 L F
.49337 1.25073 m .48683 1.25105 L .48321 1.24892 L .256 .234 0 r
F
.49628 1.25236 m .48683 1.25105 L .49337 1.25073 L .25 .226 0 r
F
.18473 1.15495 m .1753 1.13399 L .18661 1.13603 L .885 .808 0 r
F
.19604 1.15643 m .18473 1.15495 L .18661 1.13603 L .88 .803 0 r
F
.19604 1.15643 m .18661 1.13603 L .19792 1.13814 L F
.20735 1.15798 m .19604 1.15643 L .19792 1.13814 L .873 .796 0 r
F
.51611 .72848 m .51624 .72315 L .54496 .7214 L .903 .928 0 r
F
.48853 .73271 m .51624 .72315 L .51611 .72848 L .975 .968 0 r
F
.64196 .71427 m .67627 .71691 L .67035 .72185 L .855 .864 0 r
F
.63711 .71944 m .64196 .71427 L .67035 .72185 L .842 .859 0 r
F
.20735 1.15798 m .19792 1.13814 L .20922 1.14033 L .873 .796 0 r
F
.21865 1.15962 m .20735 1.15798 L .20922 1.14033 L .866 .79 0 r
F
.69619 1.3677 m .69489 1.38511 L .68541 1.37848 L .934 .698 0 r
F
.69619 1.3677 m .70627 1.37346 L .69489 1.38511 L F
.21865 1.15962 m .20922 1.14033 L .22052 1.14262 L .866 .79 0 r
F
.22996 1.16135 m .21865 1.15962 L .22052 1.14262 L .858 .782 0 r
F
.43444 .74905 m .45892 .73418 L .46121 .73955 L 1 1 0 r
F
.43444 .74905 m .43099 .74358 L .45892 .73418 L F
.61867 1.32169 m .61994 1.33252 L .61108 1.32312 L .458 .405 0 r
F
.61867 1.32169 m .62823 1.33012 L .61994 1.33252 L F
.36574 1.20015 m .3542 1.18911 L .3655 1.19268 L .582 .604 0 r
F
.377 1.20314 m .36574 1.20015 L .3655 1.19268 L .544 .578 0 r
F
.22996 1.16135 m .22052 1.14262 L .2318 1.145 L .858 .782 0 r
F
.24126 1.16318 m .22996 1.16135 L .2318 1.145 L .849 .774 0 r
F
.82479 1.03861 m .84391 1.05602 L .83268 1.05651 L .831 .804 0 r
F
.81379 1.03967 m .82479 1.03861 L .83268 1.05651 L .824 .799 0 r
F
.57328 .72196 m .57583 .7166 L .60459 .71951 L .844 .88 0 r
F
.54496 .7214 m .57583 .7166 L .57328 .72196 L .877 .905 0 r
F
.75809 1.37921 m .75642 1.39781 L .74643 1.39344 L .947 .783 0 r
F
.75809 1.37921 m .76863 1.38303 L .75642 1.39781 L F
.24126 1.16318 m .2318 1.145 L .24308 1.14749 L .849 .774 0 r
F
.25256 1.16511 m .24126 1.16318 L .24308 1.14749 L .839 .765 0 r
F
.3472 .77873 m .36682 .75742 L .37249 .76341 L 1 .957 0 r
F
.3472 .77873 m .34054 .77272 L .36682 .75742 L F
.4743 1.24252 m .46467 1.24098 L .46189 1.23838 L .296 .291 0 r
F
.47692 1.24464 m .46467 1.24098 L .4743 1.24252 L .288 .28 0 r
F
.52303 1.26351 m .52182 1.26636 L .51967 1.26241 L .214 .179 0 r
F
.52303 1.26351 m .52629 1.26787 L .52182 1.26636 L F
.53876 1.27135 m .54016 1.27546 L .5348 1.27039 L .197 .158 0 r
F
.53876 1.27135 m .5451 1.27679 L .54016 1.27546 L F
.37814 .76938 m .39937 .74963 L .40395 .75544 L 1 1 0 r
F
.37814 .76938 m .37249 .76341 L .39937 .74963 L F
.57562 1.2917 m .57829 1.29799 L .57021 1.29112 L .243 .198 0 r
F
.57562 1.2917 m .58449 1.29872 L .57829 1.29799 L F
.49065 1.24909 m .48321 1.24892 L .4799 1.24678 L .262 .243 0 r
F
.49337 1.25073 m .48321 1.24892 L .49065 1.24909 L .256 .234 0 r
F
.48853 .73271 m .48745 .72738 L .51624 .72315 L .975 .968 0 r
F
.46121 .73955 m .48745 .72738 L .48853 .73271 L 1 1 0 r
F
.67627 .71691 m .68222 .71189 L .71072 .72219 L .857 .856 0 r
F
.46121 .73955 m .45892 .73418 L .48745 .72738 L 1 1 0 r
F
.25256 1.16511 m .24308 1.14749 L .25435 1.1501 L .839 .765 0 r
F
.26385 1.16716 m .25256 1.16511 L .25435 1.1501 L .826 .754 0 r
F
.69806 1.02399 m .71831 1.0337 L .70783 1.0346 L .678 .725 0 r
F
.68809 1.02534 m .69806 1.02399 L .70783 1.0346 L .658 .712 0 r
F
.60911 1.31357 m .61108 1.32312 L .60222 1.31435 L .389 .357 0 r
F
.60911 1.31357 m .61867 1.32169 L .61108 1.32312 L F
.26385 1.16716 m .25435 1.1501 L .26562 1.15283 L .826 .754 0 r
F
.27515 1.16934 m .26385 1.16716 L .26562 1.15283 L .813 .743 0 r
F
.68608 1.36158 m .68541 1.37848 L .67592 1.37136 L .902 .671 0 r
F
.68608 1.36158 m .69619 1.3677 L .68541 1.37848 L F
.74987 1.03035 m .76994 1.04324 L .75902 1.04394 L .758 .766 0 r
F
.73933 1.03156 m .74987 1.03035 L .75902 1.04394 L .745 .758 0 r
F
.41198 1.21788 m .39956 1.20969 L .41085 1.21324 L .425 .489 0 r
F
.42315 1.22092 m .41198 1.21788 L .41085 1.21324 L .404 .454 0 r
F
.27515 1.16934 m .26562 1.15283 L .27688 1.15572 L .813 .743 0 r
F
.28644 1.17166 m .27515 1.16934 L .27688 1.15572 L .797 .731 0 r
F
.377 1.20314 m .3655 1.19268 L .37681 1.19645 L .544 .578 0 r
F
.38827 1.20633 m .377 1.20314 L .37681 1.19645 L .505 .55 0 r
F
.60831 .71419 m .64196 .71427 L .63711 .71944 L .857 .874 0 r
F
.60459 .71951 m .60831 .71419 L .63711 .71944 L .841 .868 0 r
F
.56366 1.0007 m .56838 .99859 L .58067 1.0027 L .356 .379 0 r
F
.55186 .99708 m .56838 .99859 L .56366 1.0007 L .315 .301 0 r
F
.57583 .7166 m .60831 .71419 L .60459 .71951 L .863 .888 0 r
F
.52629 1.26447 m .52629 1.26787 L .52303 1.26351 L .213 .178 0 r
F
.52629 1.26447 m .53063 1.26922 L .52629 1.26787 L F
.48816 1.24745 m .4799 1.24678 L .47692 1.24464 L .269 .252 0 r
F
.49065 1.24909 m .4799 1.24678 L .48816 1.24745 L .262 .243 0 r
F
.44901 1.23343 m .43598 1.22763 L .44693 1.23041 L .35 .374 0 r
F
.45963 1.23584 m .44901 1.23343 L .44693 1.23041 L .329 .34 0 r
F
.46189 1.23838 m .44901 1.23343 L .45963 1.23584 L .322 .331 0 r
F
.30865 .78334 m .32715 .7608 L .33386 .76674 L 1 .922 0 r
F
.30865 .78334 m .30104 .77758 L .32715 .7608 L F
.62964 1.0151 m .63819 1.01338 L .64899 1.02069 L .515 .622 0 r
F
.63819 1.01338 m .65828 1.01926 L .64899 1.02069 L .542 .645 0 r
F
.50186 .98446 m .51464 .98646 L .51451 .9877 L 0 .093 0 r
F
.50186 .98446 m .5008 .98373 L .51464 .98646 L F
.28644 1.17166 m .27688 1.15572 L .28813 1.15875 L .797 .731 0 r
F
.29773 1.17413 m .28644 1.17166 L .28813 1.15875 L .778 .717 0 r
F
.82479 1.03861 m .8358 1.03749 L .84391 1.05602 L .831 .804 0 r
F
.74754 1.37521 m .74643 1.39344 L .73642 1.38885 L .939 .77 0 r
F
.74754 1.37521 m .75809 1.37921 L .74643 1.39344 L F
.59222 1.00732 m .599 1.00531 L .61059 1.0107 L .427 .516 0 r
F
.58067 1.0027 m .599 1.00531 L .59222 1.00732 L .405 .473 0 r
F
.43598 1.22763 m .42315 1.22092 L .43433 1.22413 L .378 .416 0 r
F
.44693 1.23041 m .43598 1.22763 L .43433 1.22413 L .356 .38 0 r
F
.59955 1.30584 m .60222 1.31435 L .59336 1.30624 L .347 .314 0 r
F
.59955 1.30584 m .60911 1.31357 L .60222 1.31435 L F
.55399 1.2785 m .55699 1.28371 L .54973 1.27782 L .21 .17 0 r
F
.55399 1.2785 m .56211 1.28465 L .55699 1.28371 L F
.47376 .97509 m .48487 .98114 L .48712 .98029 L .461 0 0 r
F
.47376 .97509 m .47034 .97695 L .48487 .98114 L F
.67596 1.3551 m .67592 1.37136 L .66641 1.36376 L .861 .642 0 r
F
.67596 1.3551 m .68608 1.36158 L .67592 1.37136 L F
.29773 1.17413 m .28813 1.15875 L .29938 1.16196 L .778 .717 0 r
F
.30903 1.17676 m .29773 1.17413 L .29938 1.16196 L .757 .702 0 r
F
.66759 1.01766 m .68809 1.02534 L .67815 1.02656 L .615 .693 0 r
F
.65828 1.01926 m .66759 1.01766 L .67815 1.02656 L .592 .675 0 r
F
.47208 1.24044 m .46189 1.23838 L .45963 1.23584 L .303 .301 0 r
F
.4743 1.24252 m .46189 1.23838 L .47208 1.24044 L .296 .291 0 r
F
.54246 1.27208 m .5451 1.27679 L .53876 1.27135 L .208 .17 0 r
F
.54246 1.27208 m .54973 1.27782 L .5451 1.27679 L F
.56674 1.2851 m .57021 1.29112 L .56211 1.28465 L .236 .197 0 r
F
.56674 1.2851 m .57562 1.2917 L .57021 1.29112 L F
.30903 1.17676 m .29938 1.16196 L .31062 1.16535 L .757 .702 0 r
F
.32032 1.17957 m .30903 1.17676 L .31062 1.16535 L .734 .685 0 r
F
.83311 1.38242 m .8315 1.40305 L .82106 1.39999 L .924 .822 0 r
F
.83311 1.38242 m .84402 1.38498 L .8315 1.40305 L F
.38827 1.20633 m .37681 1.19645 L .38812 1.2004 L .505 .55 0 r
F
.39956 1.20969 m .38827 1.20633 L .38812 1.2004 L .465 .52 0 r
F
.55186 .99708 m .55549 .99499 L .56838 .99859 L .315 .301 0 r
F
.53965 .99378 m .55549 .99499 L .55186 .99708 L .261 .205 0 r
F
.45638 .96766 m .46689 .98127 L .47034 .97695 L .776 .029 0 r
F
.45638 .96766 m .45177 .97465 L .46689 .98127 L F
.48592 1.24582 m .47692 1.24464 L .4743 1.24252 L .275 .26 0 r
F
.48816 1.24745 m .47692 1.24464 L .48592 1.24582 L .269 .252 0 r
F
.52942 1.2653 m .53063 1.26922 L .52629 1.26447 L .215 .179 0 r
F
.52942 1.2653 m .5348 1.27039 L .53063 1.26922 L F
.61829 1.00879 m .63819 1.01338 L .62964 1.0151 L .488 .605 0 r
F
.61059 1.0107 m .61829 1.00879 L .62964 1.0151 L .463 .577 0 r
F
.66583 1.34828 m .66641 1.36376 L .65688 1.35571 L .81 .61 0 r
F
.66583 1.34828 m .67596 1.3551 L .66641 1.36376 L F
.599 1.00531 m .61829 1.00879 L .61059 1.0107 L .444 .549 0 r
F
.40395 .75544 m .42752 .73791 L .43099 .74358 L 1 1 0 r
F
.40395 .75544 m .39937 .74963 L .42752 .73791 L F
.54496 .7214 m .5463 .71594 L .57583 .7166 L .877 .905 0 r
F
.51624 .72315 m .5463 .71594 L .54496 .7214 L .926 .936 0 r
F
.73698 1.37101 m .73642 1.38885 L .72639 1.38401 L .929 .755 0 r
F
.73698 1.37101 m .74754 1.37521 L .73642 1.38885 L F
.51451 .9877 m .52847 .98905 L .52715 .99072 L .081 .109 0 r
F
.51451 .9877 m .51464 .98646 L .52847 .98905 L F
.58998 1.29852 m .59336 1.30624 L .58449 1.29872 L .313 .281 0 r
F
.58998 1.29852 m .59955 1.30584 L .59336 1.30624 L F
.42315 1.22092 m .41085 1.21324 L .42215 1.21694 L .404 .454 0 r
F
.43433 1.22413 m .42315 1.22092 L .42215 1.21694 L .382 .419 0 r
F
.76043 1.02904 m .78088 1.04246 L .76994 1.04324 L .77 .774 0 r
F
.74987 1.03035 m .76043 1.02904 L .76994 1.04324 L .758 .766 0 r
F
.32032 1.17957 m .31062 1.16535 L .32186 1.16893 L .734 .685 0 r
F
.33161 1.18255 m .32032 1.17957 L .32186 1.16893 L .706 .667 0 r
F
.70805 1.02251 m .72881 1.03268 L .71831 1.0337 L .695 .737 0 r
F
.69806 1.02399 m .70805 1.02251 L .71831 1.0337 L .678 .725 0 r
F
.53965 .99378 m .54214 .99184 L .55549 .99499 L .261 .205 0 r
F
.52715 .99072 m .54214 .99184 L .53965 .99378 L .185 .119 0 r
F
.5061 1.25371 m .5026 1.25553 L .49937 1.25396 L .246 .22 0 r
F
.50833 1.25474 m .5026 1.25553 L .5061 1.25371 L .244 .217 0 r
F
.50833 1.25474 m .50593 1.25705 L .5026 1.25553 L F
.51061 1.25573 m .50593 1.25705 L .50833 1.25474 L .241 .214 0 r
F
.51061 1.25573 m .50934 1.25851 L .50593 1.25705 L F
.52715 .99072 m .52847 .98905 L .54214 .99184 L .185 .119 0 r
F
.65568 1.34116 m .65688 1.35571 L .64734 1.34731 L .746 .576 0 r
F
.65568 1.34116 m .66583 1.34828 L .65688 1.35571 L F
.33161 1.18255 m .32186 1.16893 L .3331 1.17272 L .706 .667 0 r
F
.34291 1.18573 m .33161 1.18255 L .3331 1.17272 L .675 .647 0 r
F
.50394 1.25265 m .49937 1.25396 L .49628 1.25236 L .249 .224 0 r
F
.5061 1.25371 m .49937 1.25396 L .50394 1.25265 L .246 .22 0 r
F
.51291 1.25666 m .50934 1.25851 L .51061 1.25573 L .239 .211 0 r
F
.51291 1.25666 m .51279 1.2599 L .50934 1.25851 L F
.82218 1.37978 m .82106 1.39999 L .81061 1.39683 L .922 .816 0 r
F
.82218 1.37978 m .83311 1.38242 L .82106 1.39999 L F
.34054 .77272 m .36113 .7514 L .36682 .75742 L 1 .955 0 r
F
.34054 .77272 m .33386 .76674 L .36113 .7514 L F
.64683 .709 m .68222 .71189 L .67627 .71691 L .867 .869 0 r
F
.64196 .71427 m .64683 .709 L .67627 .71691 L .855 .864 0 r
F
.39956 1.20969 m .38812 1.2004 L .39943 1.20452 L .465 .52 0 r
F
.41085 1.21324 m .39956 1.20969 L .39943 1.20452 L .429 .487 0 r
F
.50188 1.25155 m .49628 1.25236 L .49337 1.25073 L .251 .228 0 r
F
.50394 1.25265 m .49628 1.25236 L .50188 1.25155 L .249 .224 0 r
F
.51522 1.25753 m .51279 1.2599 L .51291 1.25666 L .236 .207 0 r
F
.51522 1.25753 m .51624 1.26121 L .51279 1.2599 L F
.48396 1.24421 m .4743 1.24252 L .47208 1.24044 L .28 .268 0 r
F
.48592 1.24582 m .4743 1.24252 L .48396 1.24421 L .275 .26 0 r
F
.44693 1.23041 m .43433 1.22413 L .44553 1.2275 L .356 .38 0 r
F
.45791 1.23337 m .44693 1.23041 L .44553 1.2275 L .333 .345 0 r
F
.45963 1.23584 m .44693 1.23041 L .45791 1.23337 L .329 .34 0 r
F
.7264 1.36657 m .72639 1.38401 L .71634 1.37889 L .915 .739 0 r
F
.7264 1.36657 m .73698 1.37101 L .72639 1.38401 L F
.64553 1.33381 m .64734 1.34731 L .63778 1.33872 L .671 .54 0 r
F
.64553 1.33381 m .65568 1.34116 L .64734 1.34731 L F
.53239 1.26596 m .5348 1.27039 L .52942 1.2653 L .218 .184 0 r
F
.53239 1.26596 m .53876 1.27135 L .5348 1.27039 L F
.37249 .76341 m .39476 .74373 L .39937 .74963 L 1 .993 0 r
F
.37249 .76341 m .36682 .75742 L .39476 .74373 L F
.34291 1.18573 m .3331 1.17272 L .34433 1.17671 L .675 .647 0 r
F
.3542 1.18911 m .34291 1.18573 L .34433 1.17671 L .641 .625 0 r
F
.58067 1.0027 m .58646 1.0005 L .599 1.00531 L .405 .473 0 r
F
.56838 .99859 m .58646 1.0005 L .58067 1.0027 L .377 .414 0 r
F
.47027 1.23842 m .45963 1.23584 L .45791 1.23337 L .308 .308 0 r
F
.47208 1.24044 m .45963 1.23584 L .47027 1.23842 L .303 .301 0 r
F
.58041 1.2916 m .58449 1.29872 L .57562 1.2917 L .288 .257 0 r
F
.58041 1.2916 m .58998 1.29852 L .58449 1.29872 L F
.43099 .74358 m .45663 .72859 L .45892 .73418 L 1 1 0 r
F
.43099 .74358 m .42752 .73791 L .45663 .72859 L F
.49993 1.25044 m .49337 1.25073 L .49065 1.24909 L .254 .232 0 r
F
.50188 1.25155 m .49337 1.25073 L .49993 1.25044 L .251 .228 0 r
F
.51751 1.25832 m .51624 1.26121 L .51522 1.25753 L .234 .205 0 r
F
.51751 1.25832 m .51967 1.26241 L .51624 1.26121 L F
.51624 .72315 m .51637 .71764 L .5463 .71594 L .926 .936 0 r
F
.48745 .72738 m .51637 .71764 L .51624 .72315 L .993 .971 0 r
F
.30104 .77758 m .32043 .75487 L .32715 .7608 L 1 .922 0 r
F
.30104 .77758 m .2934 .77187 L .32043 .75487 L F
.54586 1.27256 m .54973 1.27782 L .54246 1.27208 L .222 .187 0 r
F
.54586 1.27256 m .55399 1.2785 L .54973 1.27782 L F
.55785 1.27881 m .56211 1.28465 L .55399 1.2785 L .236 .2 0 r
F
.55785 1.27881 m .56674 1.2851 L .56211 1.28465 L F
.63537 1.32636 m .63778 1.33872 L .62823 1.33012 L .587 .501 0 r
F
.63537 1.32636 m .64553 1.33381 L .63778 1.33872 L F
.81125 1.37704 m .81061 1.39683 L .80014 1.39357 L .92 .81 0 r
F
.81125 1.37704 m .82218 1.37978 L .81061 1.39683 L F
.77101 1.02764 m .79183 1.0416 L .78088 1.04246 L .781 .781 0 r
F
.76043 1.02904 m .77101 1.02764 L .78088 1.04246 L .77 .774 0 r
F
.43433 1.22413 m .42215 1.21694 L .43347 1.22079 L .382 .419 0 r
F
.44553 1.2275 m .43433 1.22413 L .43347 1.22079 L .358 .383 0 r
F
.64676 1.01149 m .66759 1.01766 L .65828 1.01926 L .568 .667 0 r
F
.63819 1.01338 m .64676 1.01149 L .65828 1.01926 L .542 .645 0 r
F
.3542 1.18911 m .34433 1.17671 L .35556 1.18092 L .641 .625 0 r
F
.3655 1.19268 m .3542 1.18911 L .35556 1.18092 L .602 .6 0 r
F
.57583 .7166 m .57838 .71111 L .60831 .71419 L .863 .888 0 r
F
.5463 .71594 m .57838 .71111 L .57583 .7166 L .896 .911 0 r
F
.67693 1.01592 m .69806 1.02399 L .68809 1.02534 L .637 .708 0 r
F
.66759 1.01766 m .67693 1.01592 L .68809 1.02534 L .615 .693 0 r
F
.49812 1.24933 m .49065 1.24909 L .48816 1.24745 L .258 .236 0 r
F
.49993 1.25044 m .49065 1.24909 L .49812 1.24933 L .254 .232 0 r
F
.51975 1.25904 m .51967 1.26241 L .51751 1.25832 L .233 .203 0 r
F
.51975 1.25904 m .52303 1.26351 L .51967 1.26241 L F
.7158 1.3619 m .71634 1.37889 L .70627 1.37346 L .897 .72 0 r
F
.7158 1.3619 m .7264 1.36657 L .71634 1.37889 L F
.45892 .73418 m .48636 .72183 L .48745 .72738 L 1 1 0 r
F
.45892 .73418 m .45663 .72859 L .48636 .72183 L F
.62521 1.3189 m .62823 1.33012 L .61867 1.32169 L .502 .459 0 r
F
.62521 1.3189 m .63537 1.32636 L .62823 1.33012 L F
.41085 1.21324 m .39943 1.20452 L .41076 1.20878 L .429 .487 0 r
F
.42215 1.21694 m .41085 1.21324 L .41076 1.20878 L .406 .452 0 r
F
.48745 .72738 m .48636 .72183 L .51637 .71764 L .993 .971 0 r
F
.49973 .98349 m .49866 .98349 L .49983 .98354 L .042 0 0 r
F
.49963 .98344 m .49973 .98349 L .5008 .98373 L .268 0 0 r
F
.49973 .98349 m .51489 .98428 L .51477 .98537 L .042 0 0 r
F
.49973 .98349 m .49983 .98354 L .51489 .98428 L F
.48712 .98029 m .49973 .98349 L .49963 .98344 L .268 0 0 r
F
.48712 .98029 m .48487 .98114 L .49973 .98349 L F
.71806 1.02092 m .73933 1.03156 L .72881 1.03268 L .712 .748 0 r
F
.70805 1.02251 m .71806 1.02092 L .72881 1.03268 L .695 .737 0 r
F
.61204 .70876 m .64683 .709 L .64196 .71427 L .87 .879 0 r
F
.60831 .71419 m .61204 .70876 L .64196 .71427 L .857 .874 0 r
F
.4823 1.24265 m .47208 1.24044 L .47027 1.23842 L .285 .275 0 r
F
.48396 1.24421 m .47208 1.24044 L .4823 1.24265 L .28 .268 0 r
F
.53516 1.26646 m .53876 1.27135 L .53239 1.26596 L .225 .191 0 r
F
.53516 1.26646 m .54246 1.27208 L .53876 1.27135 L F
.3655 1.19268 m .35556 1.18092 L .36678 1.18533 L .602 .6 0 r
F
.37681 1.19645 m .3655 1.19268 L .36678 1.18533 L .56 .574 0 r
F
.61504 1.31154 m .61867 1.32169 L .60911 1.31357 L .426 .417 0 r
F
.61504 1.31154 m .62521 1.3189 L .61867 1.32169 L F
.49646 1.24821 m .48816 1.24745 L .48592 1.24582 L .261 .241 0 r
F
.49812 1.24933 m .48816 1.24745 L .49646 1.24821 L .258 .236 0 r
F
.57084 1.28502 m .57562 1.2917 L .56674 1.2851 L .271 .241 0 r
F
.57084 1.28502 m .58041 1.2916 L .57562 1.2917 L F
.52193 1.25966 m .52303 1.26351 L .51975 1.25904 L .232 .202 0 r
F
.52193 1.25966 m .52629 1.26447 L .52303 1.26351 L F
.57838 .71111 m .61204 .70876 L .60831 .71419 L .879 .893 0 r
F
.8003 1.3742 m .80014 1.39357 L .78965 1.39019 L .916 .802 0 r
F
.8003 1.3742 m .81125 1.37704 L .80014 1.39357 L F
.599 1.00531 m .60579 1.00311 L .61829 1.00879 L .444 .549 0 r
F
.58646 1.0005 m .60579 1.00311 L .599 1.00531 L .425 .509 0 r
F
.70519 1.35695 m .70627 1.37346 L .69619 1.3677 L .874 .699 0 r
F
.70519 1.35695 m .7158 1.3619 L .70627 1.37346 L F
.56838 .99859 m .57313 .99631 L .58646 1.0005 L .377 .414 0 r
F
.55549 .99499 m .57313 .99631 L .56838 .99859 L .338 .333 0 r
F
.45791 1.23337 m .44553 1.2275 L .45674 1.23101 L .333 .345 0 r
F
.4689 1.23648 m .45791 1.23337 L .45674 1.23101 L .312 .313 0 r
F
.47027 1.23842 m .45791 1.23337 L .4689 1.23648 L .308 .308 0 r
F
.60487 1.30438 m .60911 1.31357 L .59955 1.30584 L .384 .376 0 r
F
.60487 1.30438 m .61504 1.31154 L .60911 1.31357 L F
.61829 1.00879 m .62602 1.00669 L .63819 1.01338 L .488 .605 0 r
F
.62602 1.00669 m .64676 1.01149 L .63819 1.01338 L .516 .631 0 r
F
.37681 1.19645 m .36678 1.18533 L .37801 1.18993 L .56 .574 0 r
F
.38812 1.2004 m .37681 1.19645 L .37801 1.18993 L .516 .545 0 r
F
.42215 1.21694 m .41076 1.20878 L .42209 1.21317 L .406 .452 0 r
F
.43347 1.22079 m .42215 1.21694 L .42209 1.21317 L .383 .416 0 r
F
.78162 1.02617 m .8028 1.04067 L .79183 1.0416 L .791 .788 0 r
F
.77101 1.02764 m .78162 1.02617 L .79183 1.0416 L .781 .781 0 r
F
.49497 1.24711 m .48592 1.24582 L .48396 1.24421 L .265 .245 0 r
F
.49646 1.24821 m .48592 1.24582 L .49497 1.24711 L .261 .241 0 r
F
.44553 1.2275 m .43347 1.22079 L .44481 1.22475 L .358 .383 0 r
F
.45674 1.23101 m .44553 1.2275 L .44481 1.22475 L .335 .347 0 r
F
.52402 1.26019 m .52629 1.26447 L .52193 1.25966 L .233 .202 0 r
F
.52402 1.26019 m .52942 1.2653 L .52629 1.26447 L F
.39937 .74963 m .42405 .73209 L .42752 .73791 L 1 1 0 r
F
.39937 .74963 m .39476 .74373 L .42405 .73209 L F
.54894 1.27278 m .55399 1.2785 L .54586 1.27256 L .238 .207 0 r
F
.54894 1.27278 m .55785 1.27881 L .55399 1.2785 L F
.60579 1.00311 m .62602 1.00669 L .61829 1.00879 L .462 .58 0 r
F
.78934 1.37124 m .78965 1.39019 L .77915 1.38669 L .912 .794 0 r
F
.78934 1.37124 m .8003 1.3742 L .78965 1.39019 L F
.69456 1.35172 m .69619 1.3677 L .68608 1.36158 L .846 .677 0 r
F
.69456 1.35172 m .70519 1.35695 L .69619 1.3677 L F
.33386 .76674 m .35542 .74537 L .36113 .7514 L 1 .952 0 r
F
.33386 .76674 m .32715 .7608 L .35542 .74537 L F
.48095 1.24114 m .47027 1.23842 L .4689 1.23648 L .289 .28 0 r
F
.4823 1.24265 m .47027 1.23842 L .48095 1.24114 L .285 .275 0 r
F
.5947 1.29747 m .59955 1.30584 L .58998 1.29852 L .351 .338 0 r
F
.5947 1.29747 m .60487 1.30438 L .59955 1.30584 L F
.53771 1.26678 m .54246 1.27208 L .53516 1.26646 L .233 .201 0 r
F
.53771 1.26678 m .54586 1.27256 L .54246 1.27208 L F
.38812 1.2004 m .37801 1.18993 L .38924 1.1947 L .516 .545 0 r
F
.39943 1.20452 m .38812 1.2004 L .38924 1.1947 L .472 .513 0 r
F
.56125 1.27875 m .56674 1.2851 L .55785 1.27881 L .261 .232 0 r
F
.56125 1.27875 m .57084 1.28502 L .56674 1.2851 L F
.5463 .71594 m .54765 .71032 L .57838 .71111 L .896 .911 0 r
F
.51637 .71764 m .54765 .71032 L .5463 .71594 L .944 .94 0 r
F
.5008 .98373 m .51477 .98537 L .51464 .98646 L 0 .093 0 r
F
.49366 1.24603 m .48396 1.24421 L .4823 1.24265 L .268 .25 0 r
F
.49497 1.24711 m .48396 1.24421 L .49366 1.24603 L .265 .245 0 r
F
.64683 .709 m .65172 .70363 L .68222 .71189 L .867 .869 0 r
F
.7281 1.01922 m .74987 1.03035 L .73933 1.03156 L .727 .758 0 r
F
.71806 1.02092 m .7281 1.01922 L .73933 1.03156 L .712 .748 0 r
F
.526 1.26061 m .52942 1.2653 L .52402 1.26019 L .234 .204 0 r
F
.526 1.26061 m .53239 1.26596 L .52942 1.2653 L F
.36682 .75742 m .39014 .73774 L .39476 .74373 L 1 .986 0 r
F
.36682 .75742 m .36113 .7514 L .39014 .73774 L F
.68629 1.01404 m .70805 1.02251 L .69806 1.02399 L .658 .723 0 r
F
.67693 1.01592 m .68629 1.01404 L .69806 1.02399 L .637 .708 0 r
F
.68393 1.34621 m .68608 1.36158 L .67596 1.3551 L .81 .652 0 r
F
.68393 1.34621 m .69456 1.35172 L .68608 1.36158 L F
.55549 .99499 m .55913 .99275 L .57313 .99631 L .338 .333 0 r
F
.54214 .99184 m .55913 .99275 L .55549 .99499 L .284 .229 0 r
F
.77837 1.36816 m .77915 1.38669 L .76863 1.38303 L .906 .785 0 r
F
.77837 1.36816 m .78934 1.37124 L .77915 1.38669 L F
.43347 1.22079 m .42209 1.21317 L .43343 1.21765 L .383 .416 0 r
F
.44481 1.22475 m .43347 1.22079 L .43343 1.21765 L .359 .38 0 r
F
.65535 1.00943 m .67693 1.01592 L .66759 1.01766 L .593 .686 0 r
F
.64676 1.01149 m .65535 1.00943 L .66759 1.01766 L .568 .667 0 r
F
.58453 1.29082 m .58998 1.29852 L .58041 1.2916 L .322 .307 0 r
F
.58453 1.29082 m .5947 1.29747 L .58998 1.29852 L F
.39943 1.20452 m .38924 1.1947 L .40048 1.1996 L .472 .513 0 r
F
.41076 1.20878 m .39943 1.20452 L .40048 1.1996 L .431 .48 0 r
F
.79224 1.02462 m .81379 1.03967 L .8028 1.04067 L .8 .794 0 r
F
.78162 1.02617 m .79224 1.02462 L .8028 1.04067 L .791 .788 0 r
F
.47034 .97695 m .48259 .98284 L .48487 .98114 L .456 0 0 r
F
.47034 .97695 m .46689 .98127 L .48259 .98284 L F
.67328 1.34041 m .67596 1.3551 L .66583 1.34828 L .767 .625 0 r
F
.67328 1.34041 m .68393 1.34621 L .67596 1.3551 L F
.50962 1.25183 m .5061 1.25371 L .50394 1.25265 L .251 .227 0 r
F
.51074 1.25235 m .5061 1.25371 L .50962 1.25183 L .25 .226 0 r
F
.51074 1.25235 m .50833 1.25474 L .5061 1.25371 L F
.51188 1.25285 m .50833 1.25474 L .51074 1.25235 L .25 .225 0 r
F
.51188 1.25285 m .51061 1.25573 L .50833 1.25474 L F
.42752 .73791 m .45433 .72283 L .45663 .72859 L 1 1 0 r
F
.42752 .73791 m .42405 .73209 L .45433 .72283 L F
.45674 1.23101 m .44481 1.22475 L .45616 1.22881 L .335 .347 0 r
F
.46798 1.23465 m .45674 1.23101 L .45616 1.22881 L .313 .314 0 r
F
.4689 1.23648 m .45674 1.23101 L .46798 1.23465 L .312 .313 0 r
F
.50854 1.25129 m .50394 1.25265 L .50188 1.25155 L .252 .228 0 r
F
.50962 1.25183 m .50394 1.25265 L .50854 1.25129 L .251 .227 0 r
F
.51303 1.25332 m .51061 1.25573 L .51188 1.25285 L .249 .223 0 r
F
.51303 1.25332 m .51291 1.25666 L .51061 1.25573 L F
.51464 .98646 m .52979 .98738 L .52847 .98905 L .091 .113 0 r
F
.51464 .98646 m .51477 .98537 L .52979 .98738 L F
.49255 1.24499 m .4823 1.24265 L .48095 1.24114 L .271 .254 0 r
F
.49366 1.24603 m .4823 1.24265 L .49255 1.24499 L .268 .25 0 r
F
.54214 .99184 m .54463 .98979 L .55913 .99275 L .284 .229 0 r
F
.52847 .98905 m .54463 .98979 L .54214 .99184 L .206 .124 0 r
F
.47993 1.23971 m .4689 1.23648 L .46798 1.23465 L .292 .284 0 r
F
.48095 1.24114 m .4689 1.23648 L .47993 1.23971 L .289 .28 0 r
F
.50751 1.25074 m .50188 1.25155 L .49993 1.25044 L .253 .229 0 r
F
.50854 1.25129 m .50188 1.25155 L .50751 1.25074 L .252 .228 0 r
F
.51419 1.25375 m .51291 1.25666 L .51303 1.25332 L .247 .222 0 r
F
.51419 1.25375 m .51522 1.25753 L .51291 1.25666 L F
.76739 1.36493 m .76863 1.38303 L .75809 1.37921 L .899 .774 0 r
F
.76739 1.36493 m .77837 1.36816 L .76863 1.38303 L F
.52785 1.26092 m .53239 1.26596 L .526 1.26061 L .237 .208 0 r
F
.52785 1.26092 m .53516 1.26646 L .53239 1.26596 L F
.58646 1.0005 m .59228 .99811 L .60579 1.00311 L .425 .509 0 r
F
.57313 .99631 m .59228 .99811 L .58646 1.0005 L .4 .454 0 r
F
.66262 1.33436 m .66583 1.34828 L .65568 1.34116 L .716 .596 0 r
F
.66262 1.33436 m .67328 1.34041 L .66583 1.34828 L F
.51637 .71764 m .5165 .71195 L .54765 .71032 L .944 .94 0 r
F
.48636 .72183 m .5165 .71195 L .51637 .71764 L 1 .971 0 r
F
.52847 .98905 m .52979 .98738 L .54463 .98979 L .206 .124 0 r
F
.54002 1.26692 m .54586 1.27256 L .53771 1.26678 L .243 .213 0 r
F
.54002 1.26692 m .54894 1.27278 L .54586 1.27256 L F
.50653 1.25017 m .49993 1.25044 L .49812 1.24933 L .254 .231 0 r
F
.50751 1.25074 m .49993 1.25044 L .50653 1.25017 L .253 .229 0 r
F
.55166 1.27271 m .55785 1.27881 L .54894 1.27278 L .255 .228 0 r
F
.55166 1.27271 m .56125 1.27875 L .55785 1.27881 L F
.57436 1.28444 m .58041 1.2916 L .57084 1.28502 L .3 .281 0 r
F
.57436 1.28444 m .58453 1.29082 L .58041 1.2916 L F
.51534 1.25414 m .51522 1.25753 L .51419 1.25375 L .246 .22 0 r
F
.51534 1.25414 m .51751 1.25832 L .51522 1.25753 L F
.41076 1.20878 m .40048 1.1996 L .41172 1.20461 L .431 .48 0 r
F
.42209 1.21317 m .41076 1.20878 L .41172 1.20461 L .405 .445 0 r
F
.57838 .71111 m .58094 .70548 L .61204 .70876 L .879 .893 0 r
F
.54765 .71032 m .58094 .70548 L .57838 .71111 L .912 .916 0 r
F
.65196 1.32808 m .65568 1.34116 L .64553 1.33381 L .657 .564 0 r
F
.65196 1.32808 m .66262 1.33436 L .65568 1.34116 L F
.44481 1.22475 m .43343 1.21765 L .44479 1.2222 L .359 .38 0 r
F
.45616 1.22881 m .44481 1.22475 L .44479 1.2222 L .335 .345 0 r
F
.50562 1.24961 m .49812 1.24933 L .49646 1.24821 L .255 .232 0 r
F
.50653 1.25017 m .49812 1.24933 L .50562 1.24961 L .254 .231 0 r
F
.45663 .72859 m .48527 .71611 L .48636 .72183 L 1 1 0 r
F
.45663 .72859 m .45433 .72283 L .48527 .71611 L F
.51646 1.2545 m .51751 1.25832 L .51534 1.25414 L .246 .219 0 r
F
.51646 1.2545 m .51975 1.25904 L .51751 1.25832 L F
.61579 .70322 m .65172 .70363 L .64683 .709 L .882 .883 0 r
F
.61204 .70876 m .61579 .70322 L .64683 .709 L .87 .879 0 r
F
.28813 1.15875 m .28109 1.14191 L .29218 1.14569 L .833 .733 0 r
F
.28813 1.15875 m .27688 1.15572 L .28109 1.14191 L F
.29938 1.16196 m .28813 1.15875 L .29218 1.14569 L .815 .718 0 r
F
.27688 1.15572 m .26998 1.1383 L .28109 1.14191 L .849 .746 0 r
F
.27688 1.15572 m .26562 1.15283 L .26998 1.1383 L F
.29938 1.16196 m .29218 1.14569 L .30326 1.14967 L .815 .718 0 r
F
.31062 1.16535 m .29938 1.16196 L .30326 1.14967 L .793 .702 0 r
F
.48636 .72183 m .48527 .71611 L .5165 .71195 L 1 .971 0 r
F
.26562 1.15283 m .25887 1.13486 L .26998 1.1383 L .863 .758 0 r
F
.26562 1.15283 m .25435 1.1501 L .25887 1.13486 L F
.75639 1.36154 m .75809 1.37921 L .74754 1.37521 L .89 .762 0 r
F
.75639 1.36154 m .76739 1.36493 L .75809 1.37921 L F
.31062 1.16535 m .30326 1.14967 L .31434 1.15386 L .793 .702 0 r
F
.32186 1.16893 m .31062 1.16535 L .31434 1.15386 L .767 .684 0 r
F
.64129 1.32164 m .64553 1.33381 L .63537 1.32636 L .59 .531 0 r
F
.64129 1.32164 m .65196 1.32808 L .64553 1.33381 L F
.25435 1.1501 m .24774 1.13157 L .25887 1.13486 L .874 .769 0 r
F
.25435 1.1501 m .24308 1.14749 L .24774 1.13157 L F
.49166 1.24399 m .48095 1.24114 L .47993 1.23971 L .274 .258 0 r
F
.49255 1.24499 m .48095 1.24114 L .49166 1.24399 L .271 .254 0 r
F
.32186 1.16893 m .31434 1.15386 L .3254 1.15827 L .767 .684 0 r
F
.3331 1.17272 m .32186 1.16893 L .3254 1.15827 L .738 .664 0 r
F
.73816 1.01742 m .76043 1.02904 L .74987 1.03035 L .741 .767 0 r
F
.7281 1.01922 m .73816 1.01742 L .74987 1.03035 L .727 .758 0 r
F
.63377 1.00442 m .65535 1.00943 L .64676 1.01149 L .543 .655 0 r
F
.62602 1.00669 m .63377 1.00442 L .64676 1.01149 L .516 .631 0 r
F
.50479 1.24904 m .49646 1.24821 L .49497 1.24711 L .256 .234 0 r
F
.50562 1.24961 m .49646 1.24821 L .50479 1.24904 L .255 .232 0 r
F
.24308 1.14749 m .2366 1.12841 L .24774 1.13157 L .884 .779 0 r
F
.24308 1.14749 m .2318 1.145 L .2366 1.12841 L F
.51755 1.2548 m .51975 1.25904 L .51646 1.2545 L .245 .218 0 r
F
.51755 1.2548 m .52193 1.25966 L .51975 1.25904 L F
.52955 1.26111 m .53516 1.26646 L .52785 1.26092 L .242 .213 0 r
F
.52955 1.26111 m .53771 1.26678 L .53516 1.26646 L F
.80288 1.02301 m .82479 1.03861 L .81379 1.03967 L .809 .799 0 r
F
.79224 1.02462 m .80288 1.02301 L .81379 1.03967 L .8 .794 0 r
F
.58094 .70548 m .61579 .70322 L .61204 .70876 L .893 .898 0 r
F
.3331 1.17272 m .3254 1.15827 L .33646 1.16291 L .738 .664 0 r
F
.34433 1.17671 m .3331 1.17272 L .33646 1.16291 L .704 .643 0 r
F
.63062 1.31511 m .63537 1.32636 L .62521 1.3189 L .521 .495 0 r
F
.63062 1.31511 m .64129 1.32164 L .63537 1.32636 L F
.42209 1.21317 m .41172 1.20461 L .42296 1.20969 L .405 .445 0 r
F
.43343 1.21765 m .42209 1.21317 L .42296 1.20969 L .38 .409 0 r
F
.2318 1.145 m .22545 1.12538 L .2366 1.12841 L .892 .788 0 r
F
.2318 1.145 m .22052 1.14262 L .22545 1.12538 L F
.56418 1.2783 m .57084 1.28502 L .56125 1.27875 L .283 .263 0 r
F
.56418 1.2783 m .57436 1.28444 L .57084 1.28502 L F
.32715 .7608 m .34969 .73931 L .35542 .74537 L 1 .95 0 r
F
.32715 .7608 m .32043 .75487 L .34969 .73931 L F
.60579 1.00311 m .61262 1.00072 L .62602 1.00669 L .462 .58 0 r
F
.59228 .99811 m .61262 1.00072 L .60579 1.00311 L .445 .546 0 r
F
.34433 1.17671 m .33646 1.16291 L .3475 1.16779 L .704 .643 0 r
F
.35556 1.18092 m .34433 1.17671 L .3475 1.16779 L .665 .619 0 r
F
.69568 1.01203 m .71806 1.02092 L .70805 1.02251 L .677 .736 0 r
F
.68629 1.01404 m .69568 1.01203 L .70805 1.02251 L .658 .723 0 r
F
.22052 1.14262 m .21429 1.12245 L .22545 1.12538 L .899 .795 0 r
F
.22052 1.14262 m .20922 1.14033 L .21429 1.12245 L F
.61995 1.30855 m .62521 1.3189 L .61504 1.31154 L .454 .457 0 r
F
.61995 1.30855 m .63062 1.31511 L .62521 1.3189 L F
.46798 1.23465 m .45616 1.22881 L .46752 1.23295 L .313 .314 0 r
F
.47924 1.23837 m .46798 1.23465 L .46752 1.23295 L .293 .285 0 r
F
.47993 1.23971 m .46798 1.23465 L .47924 1.23837 L .292 .284 0 r
F
.45177 .97465 m .46339 .98713 L .46689 .98127 L .55 .023 0 r
F
.45177 .97465 m .44704 .99042 L .46339 .98713 L F
.50404 1.24849 m .49497 1.24711 L .49366 1.24603 L .258 .236 0 r
F
.50479 1.24904 m .49497 1.24711 L .50404 1.24849 L .256 .234 0 r
F
.74539 1.35799 m .74754 1.37521 L .73698 1.37101 L .878 .749 0 r
F
.74539 1.35799 m .75639 1.36154 L .74754 1.37521 L F
.5186 1.25506 m .52193 1.25966 L .51755 1.2548 L .245 .218 0 r
F
.5186 1.25506 m .52402 1.26019 L .52193 1.25966 L F
.20922 1.14033 m .20312 1.11961 L .21429 1.12245 L .905 .802 0 r
F
.20922 1.14033 m .19792 1.13814 L .20312 1.11961 L F
.39476 .74373 m .42056 .72615 L .42405 .73209 L 1 1 0 r
F
.39476 .74373 m .39014 .73774 L .42056 .72615 L F
.61262 1.00072 m .63377 1.00442 L .62602 1.00669 L .488 .611 0 r
F
.35556 1.18092 m .3475 1.16779 L .35854 1.1729 L .665 .619 0 r
F
.36678 1.18533 m .35556 1.18092 L .35854 1.1729 L .622 .593 0 r
F
.45616 1.22881 m .44479 1.2222 L .45615 1.22679 L .335 .345 0 r
F
.46752 1.23295 m .45616 1.22881 L .45615 1.22679 L .313 .313 0 r
F
.60927 1.30206 m .61504 1.31154 L .60487 1.30438 L .406 .419 0 r
F
.60927 1.30206 m .61995 1.30855 L .61504 1.31154 L F
.54205 1.26686 m .54894 1.27278 L .54002 1.26692 L .253 .227 0 r
F
.54205 1.26686 m .55166 1.27271 L .54894 1.27278 L F
.19792 1.13814 m .19193 1.11687 L .20312 1.11961 L .91 .809 0 r
F
.19792 1.13814 m .18661 1.13603 L .19193 1.11687 L F
.36678 1.18533 m .35854 1.1729 L .36958 1.17821 L .622 .593 0 r
F
.37801 1.18993 m .36678 1.18533 L .36958 1.17821 L .574 .565 0 r
F
.49098 1.24305 m .47993 1.23971 L .47924 1.23837 L .276 .26 0 r
F
.49166 1.24399 m .47993 1.23971 L .49098 1.24305 L .274 .258 0 r
F
.66397 1.00722 m .68629 1.01404 L .67693 1.01592 L .617 .704 0 r
F
.65535 1.00943 m .66397 1.00722 L .67693 1.01592 L .593 .686 0 r
F
.43343 1.21765 m .42296 1.20969 L .43421 1.21481 L .38 .409 0 r
F
.44479 1.2222 m .43343 1.21765 L .43421 1.21481 L .356 .373 0 r
F
.57313 .99631 m .57789 .99384 L .59228 .99811 L .4 .454 0 r
F
.55913 .99275 m .57789 .99384 L .57313 .99631 L .366 .376 0 r
F
.50339 1.24795 m .49366 1.24603 L .49255 1.24499 L .259 .238 0 r
F
.50404 1.24849 m .49366 1.24603 L .50339 1.24795 L .258 .236 0 r
F
.18661 1.13603 m .18073 1.1142 L .19193 1.11687 L .915 .815 0 r
F
.18661 1.13603 m .1753 1.13399 L .18073 1.1142 L F
.51959 1.25526 m .52402 1.26019 L .5186 1.25506 L .245 .219 0 r
F
.51959 1.25526 m .526 1.26061 L .52402 1.26019 L F
.36113 .7514 m .3855 .73168 L .39014 .73774 L 1 .979 0 r
F
.36113 .7514 m .35542 .74537 L .3855 .73168 L F
.5986 1.29567 m .60487 1.30438 L .5947 1.29747 L .376 .381 0 r
F
.5986 1.29567 m .60927 1.30206 L .60487 1.30438 L F
.53108 1.26119 m .53771 1.26678 L .52955 1.26111 L .247 .22 0 r
F
.53108 1.26119 m .54002 1.26692 L .53771 1.26678 L F
.73437 1.35424 m .73698 1.37101 L .7264 1.36657 L .864 .735 0 r
F
.73437 1.35424 m .74539 1.35799 L .73698 1.37101 L F
.55399 1.27238 m .56125 1.27875 L .55166 1.27271 L .271 .25 0 r
F
.55399 1.27238 m .56418 1.2783 L .56125 1.27875 L F
.37801 1.18993 m .36958 1.17821 L .38062 1.18371 L .574 .565 0 r
F
.38924 1.1947 m .37801 1.18993 L .38062 1.18371 L .524 .534 0 r
F
.48487 .98114 m .49866 .98349 L .49973 .98349 L .258 0 0 r
F
.48487 .98114 m .48259 .98284 L .49866 .98349 L F
.81354 1.02133 m .8358 1.03749 L .82479 1.03861 L .817 .804 0 r
F
.80288 1.02301 m .81354 1.02133 L .82479 1.03861 L .809 .799 0 r
F
.58793 1.28944 m .5947 1.29747 L .58453 1.29082 L .347 .346 0 r
F
.58793 1.28944 m .5986 1.29567 L .5947 1.29747 L F
.54765 .71032 m .54901 .70457 L .58094 .70548 L .912 .916 0 r
F
.5165 .71195 m .54901 .70457 L .54765 .71032 L .957 .942 0 r
F
.50284 1.24742 m .49255 1.24499 L .49166 1.24399 L .261 .24 0 r
F
.50339 1.24795 m .49255 1.24499 L .50284 1.24742 L .259 .238 0 r
F
.52051 1.25541 m .526 1.26061 L .51959 1.25526 L .246 .22 0 r
F
.52051 1.25541 m .52785 1.26092 L .526 1.26061 L F
.38924 1.1947 m .38062 1.18371 L .39165 1.18935 L .524 .534 0 r
F
.40048 1.1996 m .38924 1.1947 L .39165 1.18935 L .473 .502 0 r
F
.74824 1.01553 m .77101 1.02764 L .76043 1.02904 L .754 .775 0 r
F
.73816 1.01742 m .74824 1.01553 L .76043 1.02904 L .741 .767 0 r
F
.72334 1.35029 m .7264 1.36657 L .7158 1.3619 L .846 .718 0 r
F
.72334 1.35029 m .73437 1.35424 L .7264 1.36657 L F
.44479 1.2222 m .43421 1.21481 L .44547 1.21992 L .356 .373 0 r
F
.45615 1.22679 m .44479 1.2222 L .44547 1.21992 L .332 .338 0 r
F
.46752 1.23295 m .45615 1.22679 L .46753 1.23141 L .313 .313 0 r
F
.47891 1.23714 m .46752 1.23295 L .46753 1.23141 L .293 .284 0 r
F
.47924 1.23837 m .46752 1.23295 L .47891 1.23714 L .293 .285 0 r
F
.57725 1.28338 m .58453 1.29082 L .57436 1.28444 L .322 .315 0 r
F
.57725 1.28338 m .58793 1.28944 L .58453 1.29082 L F
.49053 1.24217 m .47924 1.23837 L .47891 1.23714 L .277 .261 0 r
F
.49098 1.24305 m .47924 1.23837 L .49053 1.24217 L .276 .26 0 r
F
.40048 1.1996 m .39165 1.18935 L .40269 1.19508 L .473 .502 0 r
F
.41172 1.20461 m .40048 1.1996 L .40269 1.19508 L .428 .467 0 r
F
.50239 1.24693 m .49166 1.24399 L .49098 1.24305 L .262 .242 0 r
F
.50284 1.24742 m .49166 1.24399 L .50239 1.24693 L .261 .24 0 r
F
.42405 .73209 m .45202 .71692 L .45433 .72283 L 1 1 0 r
F
.42405 .73209 m .42056 .72615 L .45202 .71692 L F
.53244 1.26114 m .54002 1.26692 L .53108 1.26119 L .253 .228 0 r
F
.53244 1.26114 m .54205 1.26686 L .54002 1.26692 L F
.71231 1.34612 m .7158 1.3619 L .70519 1.35695 L .825 .7 0 r
F
.71231 1.34612 m .72334 1.35029 L .7158 1.3619 L F
.54379 1.26661 m .55166 1.27271 L .54205 1.26686 L .263 .241 0 r
F
.54379 1.26661 m .55399 1.27238 L .55166 1.27271 L F
.52136 1.2555 m .52785 1.26092 L .52051 1.25541 L .248 .222 0 r
F
.52136 1.2555 m .52955 1.26111 L .52785 1.26092 L F
.55913 .99275 m .56279 .99033 L .57789 .99384 L .366 .376 0 r
F
.54463 .98979 m .56279 .99033 L .55913 .99275 L .316 .269 0 r
F
.70509 1.0099 m .7281 1.01922 L .71806 1.02092 L .695 .747 0 r
F
.69568 1.01203 m .70509 1.0099 L .71806 1.02092 L .677 .736 0 r
F
.56658 1.2775 m .57436 1.28444 L .56418 1.2783 L .301 .289 0 r
F
.56658 1.2775 m .57725 1.28338 L .57436 1.28444 L F
.41172 1.20461 m .40269 1.19508 L .41372 1.20085 L .428 .467 0 r
F
.42296 1.20969 m .41172 1.20461 L .41372 1.20085 L .4 .431 0 r
F
.45615 1.22679 m .44547 1.21992 L .45673 1.22501 L .332 .338 0 r
F
.46753 1.23141 m .45615 1.22679 L .45673 1.22501 L .31 .307 0 r
F
.70126 1.34172 m .70519 1.35695 L .69456 1.35172 L .799 .68 0 r
F
.70126 1.34172 m .71231 1.34612 L .70519 1.35695 L F
.59228 .99811 m .59812 .99552 L .61262 1.00072 L .445 .546 0 r
F
.57789 .99384 m .59812 .99552 L .59228 .99811 L .424 .497 0 r
F
.64156 1.00196 m .66397 1.00722 L .65535 1.00943 L .57 .677 0 r
F
.63377 1.00442 m .64156 1.00196 L .65535 1.00943 L .543 .655 0 r
F
.5165 .71195 m .51663 .70612 L .54901 .70457 L .957 .942 0 r
F
.48527 .71611 m .51663 .70612 L .5165 .71195 L 1 .97 0 r
F
.81354 1.02133 m .82422 1.01959 L .8358 1.03749 L .817 .804 0 r
F
.51316 1.24991 m .50962 1.25183 L .50854 1.25129 L .254 .23 0 r
F
.51316 1.24991 m .51074 1.25235 L .50962 1.25183 L F
.51316 1.24991 m .51188 1.25285 L .51074 1.25235 L F
.51316 1.24991 m .50854 1.25129 L .50751 1.25074 L F
.51316 1.24991 m .51303 1.25332 L .51188 1.25285 L .253 .23 0 r
F
.50205 1.24646 m .49098 1.24305 L .49053 1.24217 L .263 .243 0 r
F
.50239 1.24693 m .49098 1.24305 L .50205 1.24646 L .262 .242 0 r
F
.61579 .70322 m .61955 .69759 L .65172 .70363 L .882 .883 0 r
F
.51316 1.24991 m .50751 1.25074 L .50653 1.25017 L .254 .23 0 r
F
.51316 1.24991 m .51419 1.25375 L .51303 1.25332 L .253 .229 0 r
F
.58094 .70548 m .58351 .69975 L .61579 .70322 L .893 .898 0 r
F
.54901 .70457 m .58351 .69975 L .58094 .70548 L .925 .919 0 r
F
.52213 1.25553 m .52955 1.26111 L .52136 1.2555 L .25 .225 0 r
F
.52213 1.25553 m .53108 1.26119 L .52955 1.26111 L F
.84205 1.36461 m .84402 1.38498 L .83311 1.38242 L .89 .813 0 r
F
.84205 1.36461 m .85334 1.36663 L .84402 1.38498 L F
.51316 1.24991 m .50653 1.25017 L .50562 1.24961 L .254 .23 0 r
F
.51316 1.24991 m .51534 1.25414 L .51419 1.25375 L .253 .229 0 r
F
.42296 1.20969 m .41372 1.20085 L .42476 1.20661 L .4 .431 0 r
F
.43421 1.21481 m .42296 1.20969 L .42476 1.20661 L .374 .395 0 r
F
.69021 1.33708 m .69456 1.35172 L .68393 1.34621 L .767 .658 0 r
F
.69021 1.33708 m .70126 1.34172 L .69456 1.35172 L F
.45433 .72283 m .48417 .71023 L .48527 .71611 L 1 .994 0 r
F
.45433 .72283 m .45202 .71692 L .48417 .71023 L F
.47891 1.23714 m .46753 1.23141 L .47892 1.23603 L .293 .284 0 r
F
.49031 1.24137 m .47891 1.23714 L .47892 1.23603 L .277 .261 0 r
F
.49053 1.24217 m .47891 1.23714 L .49031 1.24137 L F
.5559 1.27177 m .56418 1.2783 L .55399 1.27238 L .285 .269 0 r
F
.5559 1.27177 m .56658 1.2775 L .56418 1.2783 L F
.51316 1.24991 m .50562 1.24961 L .50479 1.24904 L .254 .23 0 r
F
.51316 1.24991 m .51646 1.2545 L .51534 1.25414 L .252 .228 0 r
F
.54463 .98979 m .54714 .98758 L .56279 .99033 L .316 .269 0 r
F
.52979 .98738 m .54714 .98758 L .54463 .98979 L .243 .144 0 r
F
.48527 .71611 m .48417 .71023 L .51663 .70612 L 1 .97 0 r
F
.53359 1.26098 m .54205 1.26686 L .53244 1.26114 L .258 .236 0 r
F
.53359 1.26098 m .54379 1.26661 L .54205 1.26686 L F
.51316 1.24991 m .50479 1.24904 L .50404 1.24849 L .254 .231 0 r
F
.67262 1.00486 m .69568 1.01203 L .68629 1.01404 L .639 .72 0 r
F
.66397 1.00722 m .67262 1.00486 L .68629 1.01404 L .617 .704 0 r
F
.51316 1.24991 m .51755 1.2548 L .51646 1.2545 L .252 .228 0 r
F
.67915 1.33219 m .68393 1.34621 L .67328 1.34041 L .73 .635 0 r
F
.67915 1.33219 m .69021 1.33708 L .68393 1.34621 L F
.46753 1.23141 m .45673 1.22501 L .46801 1.23006 L .31 .307 0 r
F
.47892 1.23603 m .46753 1.23141 L .46801 1.23006 L .291 .28 0 r
F
.75835 1.01355 m .78162 1.02617 L .77101 1.02764 L .766 .782 0 r
F
.74824 1.01553 m .75835 1.01355 L .77101 1.02764 L .754 .775 0 r
F
.58351 .69975 m .61955 .69759 L .61579 .70322 L .905 .901 0 r
F
.51477 .98537 m .53112 .98559 L .52979 .98738 L .129 .119 0 r
F
.51477 .98537 m .51489 .98428 L .53112 .98559 L F
.43421 1.21481 m .42476 1.20661 L .4358 1.21232 L .374 .395 0 r
F
.44547 1.21992 m .43421 1.21481 L .4358 1.21232 L .349 .359 0 r
F
.83076 1.36252 m .83311 1.38242 L .82218 1.37978 L .887 .807 0 r
F
.83076 1.36252 m .84205 1.36461 L .83311 1.38242 L F
.50183 1.24603 m .49053 1.24217 L .49031 1.24137 L .264 .244 0 r
F
.50205 1.24646 m .49053 1.24217 L .50183 1.24603 L .263 .243 0 r
F
.51316 1.24991 m .50404 1.24849 L .50339 1.24795 L .254 .231 0 r
F
.51316 1.24991 m .5186 1.25506 L .51755 1.2548 L .252 .227 0 r
F
.61262 1.00072 m .61947 .99813 L .63377 1.00442 L .488 .611 0 r
F
.59812 .99552 m .61947 .99813 L .61262 1.00072 L .464 .582 0 r
F
.39014 .73774 m .41705 .72009 L .42056 .72615 L 1 .997 0 r
F
.39014 .73774 m .3855 .73168 L .41705 .72009 L F
.61947 .99813 m .64156 1.00196 L .63377 1.00442 L .517 .639 0 r
F
.52979 .98738 m .53112 .98559 L .54714 .98758 L .243 .144 0 r
F
.66808 1.32708 m .67328 1.34041 L .66262 1.33436 L .687 .609 0 r
F
.66808 1.32708 m .67915 1.33219 L .67328 1.34041 L F
.5228 1.25551 m .53108 1.26119 L .52213 1.25553 L .253 .229 0 r
F
.5228 1.25551 m .53244 1.26114 L .53108 1.26119 L F
.54522 1.26618 m .55399 1.27238 L .54379 1.26661 L .273 .254 0 r
F
.54522 1.26618 m .5559 1.27177 L .55399 1.27238 L F
.51316 1.24991 m .50339 1.24795 L .50284 1.24742 L .255 .232 0 r
F
.65701 1.32174 m .66262 1.33436 L .65196 1.32808 L .638 .581 0 r
F
.65701 1.32174 m .66808 1.32708 L .66262 1.33436 L F
.51316 1.24991 m .51959 1.25526 L .5186 1.25506 L .252 .227 0 r
F
.35542 .74537 m .38085 .72556 L .3855 .73168 L 1 .973 0 r
F
.35542 .74537 m .34969 .73931 L .38085 .72556 L F
.64593 1.31623 m .65196 1.32808 L .64129 1.32164 L .584 .551 0 r
F
.64593 1.31623 m .65701 1.32174 L .65196 1.32808 L F
.44547 1.21992 m .4358 1.21232 L .44685 1.21795 L .349 .359 0 r
F
.45673 1.22501 m .44547 1.21992 L .44685 1.21795 L .325 .327 0 r
F
.63486 1.31057 m .64129 1.32164 L .63062 1.31511 L .526 .518 0 r
F
.63486 1.31057 m .64593 1.31623 L .64129 1.32164 L F
.81946 1.36034 m .82218 1.37978 L .81125 1.37704 L .883 .801 0 r
F
.81946 1.36034 m .83076 1.36252 L .82218 1.37978 L F
.51316 1.24991 m .50284 1.24742 L .50239 1.24693 L .255 .232 0 r
F
.51316 1.24991 m .52051 1.25541 L .51959 1.25526 L .252 .228 0 r
F
.62378 1.30482 m .63062 1.31511 L .61995 1.30855 L .469 .484 0 r
F
.62378 1.30482 m .63486 1.31057 L .63062 1.31511 L F
.47892 1.23603 m .46801 1.23006 L .47928 1.23507 L .291 .28 0 r
F
.49032 1.24066 m .47892 1.23603 L .47928 1.23507 L .275 .259 0 r
F
.49031 1.24137 m .47892 1.23603 L .49032 1.24066 L .277 .261 0 r
F
.61271 1.29903 m .61995 1.30855 L .60927 1.30206 L .42 .448 0 r
F
.61271 1.29903 m .62378 1.30482 L .61995 1.30855 L F
.50172 1.24563 m .49031 1.24137 L .49032 1.24066 L .264 .244 0 r
F
.50183 1.24603 m .49031 1.24137 L .50172 1.24563 L F
.60164 1.29325 m .60927 1.30206 L .5986 1.29567 L .391 .411 0 r
F
.60164 1.29325 m .61271 1.29903 L .60927 1.30206 L F
.46689 .98127 m .4803 .98477 L .48259 .98284 L .377 0 0 r
F
.46689 .98127 m .46339 .98713 L .4803 .98477 L F
.52338 1.25543 m .53244 1.26114 L .5228 1.25551 L .256 .232 0 r
F
.52338 1.25543 m .53359 1.26098 L .53244 1.26114 L F
.51316 1.24991 m .50239 1.24693 L .50205 1.24646 L .256 .233 0 r
F
.59057 1.28753 m .5986 1.29567 L .58793 1.28944 L .364 .375 0 r
F
.59057 1.28753 m .60164 1.29325 L .5986 1.29567 L F
.53454 1.2607 m .54379 1.26661 L .53359 1.26098 L .264 .243 0 r
F
.53454 1.2607 m .54522 1.26618 L .54379 1.26661 L F
.45673 1.22501 m .44685 1.21795 L .45789 1.22348 L .325 .327 0 r
F
.46801 1.23006 m .45673 1.22501 L .45789 1.22348 L .304 .298 0 r
F
.51316 1.24991 m .52136 1.2555 L .52051 1.25541 L .252 .228 0 r
F
.71452 1.00766 m .73816 1.01742 L .7281 1.01922 L .711 .758 0 r
F
.70509 1.0099 m .71452 1.00766 L .7281 1.01922 L .695 .747 0 r
F
.5795 1.28189 m .58793 1.28944 L .57725 1.28338 L .338 .341 0 r
F
.5795 1.28189 m .59057 1.28753 L .58793 1.28944 L F
.80815 1.35807 m .81125 1.37704 L .8003 1.3742 L .878 .794 0 r
F
.80815 1.35807 m .81946 1.36034 L .81125 1.37704 L F
.57789 .99384 m .58268 .99116 L .59812 .99552 L .424 .497 0 r
F
.56279 .99033 m .58268 .99116 L .57789 .99384 L .395 .427 0 r
F
.51316 1.24991 m .50205 1.24646 L .50183 1.24603 L .256 .233 0 r
F
.56844 1.27635 m .57725 1.28338 L .56658 1.2775 L .315 .311 0 r
F
.56844 1.27635 m .5795 1.28189 L .57725 1.28338 L F
.51316 1.24991 m .52213 1.25553 L .52136 1.2555 L .253 .229 0 r
F
.46801 1.23006 m .45789 1.22348 L .46894 1.22892 L .304 .298 0 r
F
.47928 1.23507 m .46801 1.23006 L .46894 1.22892 L .287 .274 0 r
F
.54901 .70457 m .55037 .69869 L .58351 .69975 L .925 .919 0 r
F
.51663 .70612 m .55037 .69869 L .54901 .70457 L .968 .943 0 r
F
.49032 1.24066 m .47928 1.23507 L .49057 1.24004 L .275 .259 0 r
F
.50173 1.24528 m .49032 1.24066 L .49057 1.24004 L .264 .243 0 r
F
.50172 1.24563 m .49032 1.24066 L .50173 1.24528 L .264 .244 0 r
F
.55738 1.27091 m .56658 1.2775 L .5559 1.27177 L .296 .286 0 r
F
.55738 1.27091 m .56844 1.27635 L .56658 1.2775 L F
.76848 1.01149 m .79224 1.02462 L .78162 1.02617 L .776 .789 0 r
F
.75835 1.01355 m .76848 1.01149 L .78162 1.02617 L .766 .782 0 r
F
.35854 1.1729 m .3475 1.16779 L .35242 1.15906 L .69 .61 0 r
F
.3475 1.16779 m .34167 1.15321 L .35242 1.15906 L .735 .636 0 r
F
.3475 1.16779 m .33646 1.16291 L .34167 1.15321 L F
.51316 1.24991 m .50183 1.24603 L .50172 1.24563 L .256 .234 0 r
F
.35854 1.1729 m .35242 1.15906 L .36315 1.16516 L .69 .61 0 r
F
.36958 1.17821 m .35854 1.1729 L .36315 1.16516 L .639 .581 0 r
F
.79684 1.35569 m .8003 1.3742 L .78934 1.37124 L .872 .786 0 r
F
.79684 1.35569 m .80815 1.35807 L .8003 1.3742 L F
.33646 1.16291 m .33092 1.14763 L .34167 1.15321 L .773 .66 0 r
F
.33646 1.16291 m .3254 1.15827 L .33092 1.14763 L F
.51316 1.24991 m .5228 1.25551 L .52213 1.25553 L .254 .23 0 r
F
.52385 1.25529 m .53359 1.26098 L .52338 1.25543 L .258 .236 0 r
F
.52385 1.25529 m .53454 1.2607 L .53359 1.26098 L F
.36958 1.17821 m .36315 1.16516 L .37388 1.17147 L .639 .581 0 r
F
.38062 1.18371 m .36958 1.17821 L .37388 1.17147 L .584 .551 0 r
F
.3254 1.15827 m .32015 1.14232 L .33092 1.14763 L .806 .681 0 r
F
.3254 1.15827 m .31434 1.15386 L .32015 1.14232 L F
.38062 1.18371 m .37388 1.17147 L .3846 1.17794 L .584 .551 0 r
F
.39165 1.18935 m .38062 1.18371 L .3846 1.17794 L .525 .518 0 r
F
.54632 1.26556 m .5559 1.27177 L .54522 1.26618 L .28 .265 0 r
F
.54632 1.26556 m .55738 1.27091 L .5559 1.27177 L F
.47928 1.23507 m .46894 1.22892 L .48 1.23426 L .287 .274 0 r
F
.49057 1.24004 m .47928 1.23507 L .48 1.23426 L .273 .255 0 r
F
.31434 1.15386 m .30937 1.13729 L .32015 1.14232 L .833 .701 0 r
F
.31434 1.15386 m .30326 1.14967 L .30937 1.13729 L F
.42056 .72615 m .4497 .71088 L .45202 .71692 L 1 .999 0 r
F
.42056 .72615 m .41705 .72009 L .4497 .71088 L F
.64936 .99935 m .67262 1.00486 L .66397 1.00722 L .595 .697 0 r
F
.64156 1.00196 m .64936 .99935 L .66397 1.00722 L .57 .677 0 r
F
.39165 1.18935 m .3846 1.17794 L .39532 1.18451 L .525 .518 0 r
F
.40269 1.19508 m .39165 1.18935 L .39532 1.18451 L .467 .483 0 r
F
.51316 1.24991 m .50172 1.24563 L .50173 1.24528 L .257 .234 0 r
F
.51316 1.24991 m .52338 1.25543 L .5228 1.25551 L .254 .231 0 r
F
.30326 1.14967 m .29857 1.13251 L .30937 1.13729 L .856 .719 0 r
F
.30326 1.14967 m .29218 1.14569 L .29857 1.13251 L F
.40269 1.19508 m .39532 1.18451 L .40604 1.19108 L .467 .483 0 r
F
.41372 1.20085 m .40269 1.19508 L .40604 1.19108 L .418 .446 0 r
F
.78552 1.3532 m .78934 1.37124 L .77837 1.36816 L .865 .777 0 r
F
.78552 1.3532 m .79684 1.35569 L .78934 1.37124 L F
.53527 1.2603 m .54522 1.26618 L .53454 1.2607 L .269 .25 0 r
F
.53527 1.2603 m .54632 1.26556 L .54522 1.26618 L F
.6813 1.00237 m .70509 1.0099 L .69568 1.01203 L .659 .734 0 r
F
.67262 1.00486 m .6813 1.00237 L .69568 1.01203 L .639 .72 0 r
F
.41372 1.20085 m .40604 1.19108 L .41676 1.19761 L .418 .446 0 r
F
.42476 1.20661 m .41372 1.20085 L .41676 1.19761 L .39 .409 0 r
F
.49057 1.24004 m .48 1.23426 L .49105 1.23952 L .273 .255 0 r
F
.50186 1.24498 m .49057 1.24004 L .49105 1.23952 L .262 .242 0 r
F
.50173 1.24528 m .49057 1.24004 L .50186 1.24498 L .264 .243 0 r
F
.29218 1.14569 m .28776 1.12796 L .29857 1.13251 L .875 .736 0 r
F
.29218 1.14569 m .28109 1.14191 L .28776 1.12796 L F
.51316 1.24991 m .50173 1.24528 L .50186 1.24498 L .256 .234 0 r
F
.51316 1.24991 m .52385 1.25529 L .52338 1.25543 L .255 .232 0 r
F
.42476 1.20661 m .41676 1.19761 L .42747 1.20402 L .39 .409 0 r
F
.4358 1.21232 m .42476 1.20661 L .42747 1.20402 L .363 .373 0 r
F
.52421 1.25509 m .53454 1.2607 L .52385 1.25529 L .261 .239 0 r
F
.52421 1.25509 m .53527 1.2603 L .53454 1.2607 L F
.77419 1.35058 m .77837 1.36816 L .76739 1.36493 L .856 .767 0 r
F
.77419 1.35058 m .78552 1.3532 L .77837 1.36816 L F
.4358 1.21232 m .42747 1.20402 L .43819 1.21027 L .363 .373 0 r
F
.44685 1.21795 m .4358 1.21232 L .43819 1.21027 L .337 .34 0 r
F
.28109 1.14191 m .27693 1.12362 L .28776 1.12796 L .891 .75 0 r
F
.28109 1.14191 m .26998 1.1383 L .27693 1.12362 L F
.59812 .99552 m .60398 .99272 L .61947 .99813 L .464 .582 0 r
F
.58268 .99116 m .60398 .99272 L .59812 .99552 L .447 .541 0 r
F
.51663 .70612 m .51676 .70015 L .55037 .69869 L .968 .943 0 r
F
.48417 .71023 m .51676 .70015 L .51663 .70612 L 1 .967 0 r
F
.56279 .99033 m .56647 .98769 L .58268 .99116 L .395 .427 0 r
F
.54714 .98758 m .56647 .98769 L .56279 .99033 L .354 .326 0 r
F
.50186 1.24498 m .49105 1.23952 L .5021 1.24473 L .262 .242 0 r
F
.51316 1.24991 m .50186 1.24498 L .5021 1.24473 L .256 .233 0 r
F
.44685 1.21795 m .43819 1.21027 L .44891 1.21636 L .337 .34 0 r
F
.45789 1.22348 m .44685 1.21795 L .44891 1.21636 L .315 .31 0 r
F
.51316 1.24991 m .52421 1.25509 L .52385 1.25529 L .256 .233 0 r
F
.58351 .69975 m .5861 .6939 L .61955 .69759 L .905 .901 0 r
F
.55037 .69869 m .5861 .6939 L .58351 .69975 L .936 .921 0 r
F
.45789 1.22348 m .44891 1.21636 L .45963 1.22227 L .315 .31 0 r
F
.46894 1.22892 m .45789 1.22348 L .45963 1.22227 L .296 .285 0 r
F
.48494 .98293 m .49757 .98339 L .49866 .98349 L .179 0 0 r
F
.48606 .98297 m .49757 .98339 L .48494 .98293 L F
.48259 .98284 m .48606 .98297 L .48494 .98293 L F
.48259 .98284 m .4803 .98477 L .49757 .98339 L F
.48647 .98428 m .49649 .98289 L .49757 .98339 L .024 0 0 r
F
.4803 .98477 m .48766 .98392 L .48647 .98428 L F
.48766 .98392 m .49649 .98289 L .48647 .98428 L F
.4803 .98477 m .478 .9862 L .49466 .98322 L F
.4803 .98477 m .49466 .98322 L .49387 .9832 L F
.46339 .98713 m .478 .9862 L .4803 .98477 L .21 0 0 r
F
.46339 .98713 m .45988 .9923 L .478 .9862 L F
.478 .9862 m .47568 .98662 L .49172 .98269 L .192 .129 0 r
F
.49106 .98288 m .49172 .98269 L .49539 .98178 L F
.478 .9862 m .49172 .98269 L .49106 .98288 L F
.49387 .9832 m .49466 .98322 L .49649 .98289 L .024 0 0 r
F
.45202 .71692 m .48307 .70421 L .48417 .71023 L 1 .988 0 r
F
.45202 .71692 m .4497 .71088 L .48307 .70421 L F
.46894 1.22892 m .45963 1.22227 L .47034 1.22801 L .296 .285 0 r
F
.48 1.23426 m .46894 1.22892 L .47034 1.22801 L .28 .265 0 r
F
.26998 1.1383 m .26609 1.11948 L .27693 1.12362 L .904 .763 0 r
F
.26998 1.1383 m .25887 1.13486 L .26609 1.11948 L F
.76285 1.34783 m .76739 1.36493 L .75639 1.36154 L .846 .756 0 r
F
.76285 1.34783 m .77419 1.35058 L .76739 1.36493 L F
.72399 1.00531 m .74824 1.01553 L .73816 1.01742 L .726 .767 0 r
F
.71452 1.00766 m .72399 1.00531 L .73816 1.01742 L .711 .758 0 r
F
.48 1.23426 m .47034 1.22801 L .48105 1.23362 L .28 .265 0 r
F
.49105 1.23952 m .48 1.23426 L .48105 1.23362 L .269 .25 0 r
F
.49105 1.23952 m .48105 1.23362 L .49176 1.23911 L F
.5021 1.24473 m .49105 1.23952 L .49176 1.23911 L .261 .239 0 r
F
.62634 .99537 m .64936 .99935 L .64156 1.00196 L .546 .665 0 r
F
.61947 .99813 m .62634 .99537 L .64156 1.00196 L .517 .639 0 r
F
.5021 1.24473 m .49176 1.23911 L .50246 1.24453 L .261 .239 0 r
F
.51316 1.24991 m .5021 1.24473 L .50246 1.24453 L .256 .233 0 r
F
.3855 .73168 m .41354 .71394 L .41705 .72009 L 1 .989 0 r
F
.3855 .73168 m .38085 .72556 L .41354 .71394 L F
.51316 1.24991 m .50246 1.24453 L .50293 1.24439 L .255 .232 0 r
F
.51316 1.24991 m .52446 1.25484 L .52421 1.25509 L .256 .233 0 r
F
.51316 1.24991 m .50293 1.24439 L .5035 1.2443 L .254 .231 0 r
F
.51316 1.24991 m .52459 1.25454 L .52446 1.25484 L .256 .234 0 r
F
.51316 1.24991 m .5035 1.2443 L .50417 1.24428 L .254 .23 0 r
F
.51316 1.24991 m .52461 1.25419 L .52459 1.25454 L .257 .234 0 r
F
.51316 1.24991 m .50417 1.24428 L .50493 1.24431 L .253 .229 0 r
F
.51316 1.24991 m .52451 1.2538 L .52461 1.25419 L .256 .234 0 r
F
.51316 1.24991 m .50493 1.24431 L .50578 1.2444 L .252 .228 0 r
F
.51316 1.24991 m .52429 1.25337 L .52451 1.2538 L .256 .233 0 r
F
.51316 1.24991 m .50578 1.2444 L .50671 1.24454 L .252 .228 0 r
F
.51316 1.24991 m .52395 1.2529 L .52429 1.25337 L .256 .233 0 r
F
.51316 1.24991 m .50671 1.24454 L .5077 1.24474 L .252 .227 0 r
F
.51316 1.24991 m .52351 1.2524 L .52395 1.2529 L .255 .232 0 r
F
.51316 1.24991 m .5077 1.24474 L .50875 1.245 L .252 .227 0 r
F
.51316 1.24991 m .52296 1.25188 L .52351 1.2524 L .255 .232 0 r
F
.51316 1.24991 m .50875 1.245 L .50984 1.2453 L .252 .228 0 r
F
.51316 1.24991 m .52231 1.25134 L .52296 1.25188 L .254 .231 0 r
F
.51316 1.24991 m .50984 1.2453 L .51097 1.24566 L .252 .228 0 r
F
.51316 1.24991 m .52156 1.25078 L .52231 1.25134 L .254 .231 0 r
F
.51316 1.24991 m .51097 1.24566 L .51212 1.24605 L .253 .229 0 r
F
.51316 1.24991 m .52073 1.25022 L .52156 1.25078 L .254 .23 0 r
F
.51316 1.24991 m .51212 1.24605 L .51328 1.24649 L .253 .229 0 r
F
.51316 1.24991 m .51982 1.24965 L .52073 1.25022 L .254 .23 0 r
F
.51316 1.24991 m .51328 1.24649 L .51444 1.24696 L .253 .23 0 r
F
.51316 1.24991 m .51884 1.24908 L .51982 1.24965 L .254 .23 0 r
F
.51316 1.24991 m .51444 1.24696 L .51559 1.24746 L F
.51316 1.24991 m .5178 1.24852 L .51884 1.24908 L F
.51316 1.24991 m .51559 1.24746 L .51671 1.24798 L F
.51316 1.24991 m .51671 1.24798 L .5178 1.24852 L F
.52446 1.25484 m .53527 1.2603 L .52421 1.25509 L .262 .242 0 r
F
.48417 .71023 m .48307 .70421 L .51676 .70015 L 1 .967 0 r
F
.53577 1.25979 m .54632 1.26556 L .53527 1.2603 L .273 .255 0 r
F
.52446 1.25484 m .53577 1.25979 L .53527 1.2603 L .262 .242 0 r
F
.77863 1.00935 m .80288 1.02301 L .79224 1.02462 L .786 .795 0 r
F
.76848 1.01149 m .77863 1.00935 L .79224 1.02462 L .776 .789 0 r
F
.54709 1.26478 m .55738 1.27091 L .54632 1.26556 L .287 .274 0 r
F
.53577 1.25979 m .54709 1.26478 L .54632 1.26556 L .273 .255 0 r
F
.60398 .99272 m .62634 .99537 L .61947 .99813 L .49 .616 0 r
F
.25887 1.13486 m .25523 1.11551 L .26609 1.11948 L .914 .775 0 r
F
.25887 1.13486 m .24774 1.13157 L .25523 1.11551 L F
.75151 1.34493 m .75639 1.36154 L .74539 1.35799 L .834 .744 0 r
F
.75151 1.34493 m .76285 1.34783 L .75639 1.36154 L F
.55841 1.26981 m .56844 1.27635 L .55738 1.27091 L .304 .298 0 r
F
.54709 1.26478 m .55841 1.26981 L .55738 1.27091 L .287 .274 0 r
F
.56974 1.27488 m .5795 1.28189 L .56844 1.27635 L .325 .327 0 r
F
.55841 1.26981 m .56974 1.27488 L .56844 1.27635 L .304 .298 0 r
F
.50246 1.24453 m .49269 1.23882 L .50293 1.24439 L .258 .236 0 r
F
.50246 1.24453 m .49176 1.23911 L .49269 1.23882 L F
.58108 1.28001 m .59057 1.28753 L .5795 1.28189 L .349 .36 0 r
F
.56974 1.27488 m .58108 1.28001 L .5795 1.28189 L .325 .327 0 r
F
.52459 1.25454 m .53577 1.25979 L .52446 1.25484 L .264 .243 0 r
F
.74016 1.34187 m .74539 1.35799 L .73437 1.35424 L .819 .731 0 r
F
.74016 1.34187 m .75151 1.34493 L .74539 1.35799 L F
.59242 1.28516 m .60164 1.29325 L .59057 1.28753 L .374 .395 0 r
F
.58108 1.28001 m .59242 1.28516 L .59057 1.28753 L .349 .36 0 r
F
.24774 1.13157 m .24436 1.11169 L .25523 1.11551 L .923 .785 0 r
F
.24774 1.13157 m .2366 1.12841 L .24436 1.11169 L F
.54714 .98758 m .54967 .98515 L .56647 .98769 L .354 .326 0 r
F
.53112 .98559 m .54967 .98515 L .54714 .98758 L .291 .191 0 r
F
.49176 1.23911 m .48244 1.23316 L .49269 1.23882 L .264 .243 0 r
F
.49176 1.23911 m .48105 1.23362 L .48244 1.23316 L F
.60377 1.29031 m .61271 1.29903 L .60164 1.29325 L .4 .431 0 r
F
.59242 1.28516 m .60377 1.29031 L .60164 1.29325 L .374 .395 0 r
F
.50293 1.24439 m .49383 1.23864 L .5035 1.2443 L .256 .232 0 r
F
.50293 1.24439 m .49269 1.23882 L .49383 1.23864 L F
.52459 1.25454 m .53604 1.25918 L .53577 1.25979 L .264 .243 0 r
F
.52461 1.25419 m .53604 1.25918 L .52459 1.25454 L .264 .244 0 r
F
.72881 1.33863 m .73437 1.35424 L .72334 1.35029 L .802 .716 0 r
F
.72881 1.33863 m .74016 1.34187 L .73437 1.35424 L F
.53604 1.25918 m .54709 1.26478 L .53577 1.25979 L .275 .259 0 r
F
.49866 .98349 m .51502 .98299 L .51489 .98428 L .036 .109 0 r
F
.49866 .98349 m .49757 .98339 L .51502 .98299 L F
.61513 1.29544 m .62378 1.30482 L .61271 1.29903 L .428 .467 0 r
F
.60377 1.29031 m .61513 1.29544 L .61271 1.29903 L .4 .431 0 r
F
.48105 1.23362 m .47218 1.22736 L .48244 1.23316 L .272 .254 0 r
F
.48105 1.23362 m .47034 1.22801 L .47218 1.22736 L F
.2366 1.12841 m .23346 1.108 L .24436 1.11169 L .93 .795 0 r
F
.2366 1.12841 m .22545 1.12538 L .23346 1.108 L F
.62649 1.30051 m .63486 1.31057 L .62378 1.30482 L .473 .501 0 r
F
.61513 1.29544 m .62649 1.30051 L .62378 1.30482 L .428 .467 0 r
F
.71745 1.3352 m .72334 1.35029 L .71231 1.34612 L .782 .7 0 r
F
.71745 1.3352 m .72881 1.33863 L .72334 1.35029 L F
.5035 1.2443 m .49516 1.23859 L .50417 1.24428 L .253 .229 0 r
F
.5035 1.2443 m .49383 1.23864 L .49516 1.23859 L F
.52461 1.25419 m .53608 1.25847 L .53604 1.25918 L .264 .244 0 r
F
.52451 1.2538 m .53608 1.25847 L .52461 1.25419 L F
.63786 1.30547 m .64593 1.31623 L .63486 1.31057 L .522 .534 0 r
F
.62649 1.30051 m .63786 1.30547 L .63486 1.31057 L .473 .501 0 r
F
.53112 .98559 m .53245 .98358 L .54967 .98515 L .291 .191 0 r
F
.51489 .98428 m .53245 .98358 L .53112 .98559 L .193 .127 0 r
F
.70609 1.33158 m .71231 1.34612 L .70126 1.34172 L .758 .682 0 r
F
.70609 1.33158 m .71745 1.3352 L .71231 1.34612 L F
.5475 1.26383 m .55841 1.26981 L .54709 1.26478 L .291 .281 0 r
F
.53604 1.25918 m .5475 1.26383 L .54709 1.26478 L .275 .259 0 r
F
.51489 .98428 m .51502 .98299 L .53245 .98358 L .193 .127 0 r
F
.47034 1.22801 m .46191 1.22139 L .47218 1.22736 L .284 .268 0 r
F
.47034 1.22801 m .45963 1.22227 L .46191 1.22139 L F
.64923 1.3103 m .65701 1.32174 L .64593 1.31623 L .571 .564 0 r
F
.63786 1.30547 m .64923 1.3103 L .64593 1.31623 L .522 .534 0 r
F
.69 .99976 m .71452 1.00766 L .70509 1.0099 L .678 .747 0 r
F
.6813 1.00237 m .69 .99976 L .70509 1.0099 L .659 .734 0 r
F
.6572 .99658 m .6813 1.00237 L .67262 1.00486 L .62 .715 0 r
F
.64936 .99935 m .6572 .99658 L .67262 1.00486 L .595 .697 0 r
F
.69472 1.32774 m .70126 1.34172 L .69021 1.33708 L .73 .662 0 r
F
.69472 1.32774 m .70609 1.33158 L .70126 1.34172 L F
.6606 1.31496 m .66808 1.32708 L .65701 1.32174 L .618 .592 0 r
F
.64923 1.3103 m .6606 1.31496 L .65701 1.32174 L .571 .564 0 r
F
.49269 1.23882 m .48414 1.23289 L .49383 1.23864 L .258 .235 0 r
F
.49269 1.23882 m .48244 1.23316 L .48414 1.23289 L F
.50417 1.24428 m .49669 1.23866 L .50493 1.24431 L .25 .225 0 r
F
.50417 1.24428 m .49516 1.23859 L .49669 1.23866 L F
.68335 1.32369 m .69021 1.33708 L .67915 1.33219 L .697 .641 0 r
F
.68335 1.32369 m .69472 1.32774 L .69021 1.33708 L F
.22545 1.12538 m .22256 1.10443 L .23346 1.108 L .936 .803 0 r
F
.22545 1.12538 m .21429 1.12245 L .22256 1.10443 L F
.67198 1.31943 m .67915 1.33219 L .66808 1.32708 L .66 .617 0 r
F
.6606 1.31496 m .67198 1.31943 L .66808 1.32708 L .618 .592 0 r
F
.52451 1.2538 m .53588 1.25768 L .53608 1.25847 L .264 .244 0 r
F
.52429 1.25337 m .53588 1.25768 L .52451 1.2538 L .263 .243 0 r
F
.67198 1.31943 m .68335 1.32369 L .67915 1.33219 L .66 .617 0 r
F
.45963 1.22227 m .45164 1.21519 L .46191 1.22139 L .3 .288 0 r
F
.45963 1.22227 m .44891 1.21636 L .45164 1.21519 L F
.53608 1.25847 m .5475 1.26383 L .53604 1.25918 L .276 .261 0 r
F
.58268 .99116 m .58749 .98826 L .60398 .99272 L .447 .541 0 r
F
.56647 .98769 m .58749 .98826 L .58268 .99116 L .424 .482 0 r
F
.7888 1.00714 m .81354 1.02133 L .80288 1.02301 L .796 .801 0 r
F
.77863 1.00935 m .7888 1.00714 L .80288 1.02301 L .786 .795 0 r
F
.55897 1.26849 m .56974 1.27488 L .55841 1.26981 L .31 .307 0 r
F
.5475 1.26383 m .55897 1.26849 L .55841 1.26981 L .291 .281 0 r
F
.55037 .69869 m .55174 .6927 L .5861 .6939 L .936 .921 0 r
F
.51676 .70015 m .55174 .6927 L .55037 .69869 L .976 .943 0 r
F
.73347 1.00287 m .75835 1.01355 L .74824 1.01553 L .74 .776 0 r
F
.72399 1.00531 m .73347 1.00287 L .74824 1.01553 L .726 .767 0 r
F
.50493 1.24431 m .49839 1.23884 L .50578 1.2444 L .248 .222 0 r
F
.50493 1.24431 m .49669 1.23866 L .49839 1.23884 L F
.44891 1.21636 m .44136 1.20875 L .45164 1.21519 L .321 .313 0 r
F
.44891 1.21636 m .43819 1.21027 L .44136 1.20875 L F
.52429 1.25337 m .53545 1.2568 L .53588 1.25768 L .263 .243 0 r
F
.52395 1.2529 m .53545 1.2568 L .52429 1.25337 L .262 .242 0 r
F
.41705 .72009 m .44738 .70473 L .4497 .71088 L 1 .991 0 r
F
.41705 .72009 m .41354 .71394 L .44738 .70473 L F
.21429 1.12245 m .21163 1.10097 L .22256 1.10443 L .94 .81 0 r
F
.21429 1.12245 m .20312 1.11961 L .21163 1.10097 L F
.43819 1.21027 m .43108 1.20204 L .44136 1.20875 L .345 .343 0 r
F
.43819 1.21027 m .42747 1.20402 L .43108 1.20204 L F
.44704 .99042 m .45988 .9923 L .46339 .98713 L .311 0 0 r
F
.44704 .99042 m .44227 1.00524 L .45988 .9923 L F
.43106 1.02326 m .44227 1.00524 L .43983 1.00524 L 0 0 0 r
F
.43106 1.02326 m .42503 1.0466 L .43933 1.01228 L F
.43328 1.01969 m .43933 1.01228 L .44227 1.00524 L F
.43106 1.02326 m .43933 1.01228 L .43328 1.01969 L F
.43879 1.01359 m .43756 1.01122 L .44227 1.00524 L 1 1 0 r
F
.42503 1.0466 m .43756 1.01122 L .43879 1.01359 L F
.43756 1.01122 m .43288 1.01171 L .43636 1.00891 L .798 .538 0 r
F
.44227 1.00524 m .43756 1.01122 L .44343 1.00523 L 0 0 0 r
F
.44343 1.00523 m .43756 1.01122 L .44457 1.00523 L F
.44227 1.00524 m .44457 1.00523 L .45636 .99518 L F
.43983 1.00524 m .44227 1.00524 L .44704 .99042 L F
.45018 .99942 m .45636 .99518 L .45988 .9923 L F
.44227 1.00524 m .45636 .99518 L .45018 .99942 L F
.45988 .9923 m .47568 .98662 L .478 .9862 L F
.45988 .9923 m .45636 .99518 L .47568 .98662 L F
.45636 .99518 m .45283 .99566 L .46206 .99125 L .469 .16 0 r
F
.45636 .99518 m .46206 .99125 L .47337 .98586 L F
.43756 1.01122 m .43636 1.00891 L .45283 .99566 L .798 .538 0 r
F
.43756 1.01122 m .45283 .99566 L .45293 .99564 L F
.44631 1.00375 m .45293 .99564 L .45636 .99518 L F
.43756 1.01122 m .45293 .99564 L .44631 1.00375 L F
.50578 1.2444 m .50024 1.23914 L .50671 1.24454 L .246 .22 0 r
F
.50578 1.2444 m .49839 1.23884 L .50024 1.23914 L F
.57046 1.27315 m .58108 1.28001 L .56974 1.27488 L .332 .338 0 r
F
.55897 1.26849 m .57046 1.27315 L .56974 1.27488 L .31 .307 0 r
F
.48244 1.23316 m .47444 1.22698 L .48414 1.23289 L .263 .24 0 r
F
.48244 1.23316 m .47218 1.22736 L .47444 1.22698 L F
.42747 1.20402 m .42079 1.19505 L .43108 1.20204 L .374 .378 0 r
F
.42747 1.20402 m .41676 1.19761 L .42079 1.19505 L F
.52395 1.2529 m .53478 1.25586 L .53545 1.2568 L .262 .242 0 r
F
.52351 1.2524 m .53478 1.25586 L .52395 1.2529 L .261 .24 0 r
F
.49383 1.23864 m .48614 1.2328 L .49516 1.23859 L .252 .227 0 r
F
.49383 1.23864 m .48414 1.23289 L .48614 1.2328 L F
.41676 1.19761 m .41051 1.18781 L .42079 1.19505 L .404 .416 0 r
F
.41676 1.19761 m .40604 1.19108 L .41051 1.18781 L F
.53608 1.25847 m .54757 1.26274 L .5475 1.26383 L .276 .261 0 r
F
.53588 1.25768 m .54757 1.26274 L .53608 1.25847 L .277 .261 0 r
F
.40604 1.19108 m .40022 1.18037 L .41051 1.18781 L .451 .455 0 r
F
.40604 1.19108 m .39532 1.18451 L .40022 1.18037 L F
.54757 1.26274 m .55897 1.26849 L .5475 1.26383 L .293 .284 0 r
F
.39532 1.18451 m .38993 1.17283 L .40022 1.18037 L .517 .493 0 r
F
.39532 1.18451 m .3846 1.17794 L .38993 1.17283 L F
.50671 1.24454 m .50222 1.23956 L .5077 1.24474 L .245 .219 0 r
F
.50671 1.24454 m .50024 1.23914 L .50222 1.23956 L F
.52351 1.2524 m .5339 1.25486 L .53478 1.25586 L .261 .24 0 r
F
.52296 1.25188 m .5339 1.25486 L .52351 1.2524 L .259 .238 0 r
F
.20312 1.11961 m .20069 1.09761 L .21163 1.10097 L .944 .817 0 r
F
.20312 1.11961 m .19193 1.11687 L .20069 1.09761 L F
.3846 1.17794 m .37964 1.16528 L .38993 1.17283 L .587 .53 0 r
F
.3846 1.17794 m .37388 1.17147 L .37964 1.16528 L F
.58195 1.27779 m .59242 1.28516 L .58108 1.28001 L .355 .372 0 r
F
.57046 1.27315 m .58195 1.27779 L .58108 1.28001 L .332 .338 0 r
F
.37388 1.17147 m .36934 1.15783 L .37964 1.16528 L .655 .564 0 r
F
.37388 1.17147 m .36315 1.16516 L .36934 1.15783 L F
.5077 1.24474 m .50432 1.24008 L .50875 1.245 L .245 .218 0 r
F
.5077 1.24474 m .50222 1.23956 L .50432 1.24008 L F
.36315 1.16516 m .35903 1.1506 L .36934 1.15783 L .716 .596 0 r
F
.36315 1.16516 m .35242 1.15906 L .35903 1.1506 L F
.52296 1.25188 m .5328 1.25381 L .5339 1.25486 L .259 .238 0 r
F
.52231 1.25134 m .5328 1.25381 L .52296 1.25188 L .258 .236 0 r
F
.63324 .99242 m .6572 .99658 L .64936 .99935 L .574 .689 0 r
F
.62634 .99537 m .63324 .99242 L .64936 .99935 L .546 .665 0 r
F
.47218 1.22736 m .46473 1.22087 L .47444 1.22698 L .27 .249 0 r
F
.47218 1.22736 m .46191 1.22139 L .46473 1.22087 L F
.60398 .99272 m .60987 .98973 L .62634 .99537 L .49 .616 0 r
F
.58749 .98826 m .60987 .98973 L .60398 .99272 L .469 .584 0 r
F
.49516 1.23859 m .48843 1.23292 L .49669 1.23866 L .247 .22 0 r
F
.49516 1.23859 m .48614 1.2328 L .48843 1.23292 L F
.51676 .70015 m .51689 .69407 L .55174 .6927 L .976 .943 0 r
F
.48307 .70421 m .51689 .69407 L .51676 .70015 L 1 .964 0 r
F
.35242 1.15906 m .34871 1.14366 L .35903 1.1506 L .769 .625 0 r
F
.35242 1.15906 m .34167 1.15321 L .34871 1.14366 L F
.50875 1.245 m .50651 1.24071 L .50984 1.2453 L .245 .218 0 r
F
.50875 1.245 m .50432 1.24008 L .50651 1.24071 L F
.4497 .71088 m .48197 .69808 L .48307 .70421 L 1 .982 0 r
F
.4497 .71088 m .44738 .70473 L .48197 .69808 L F
.52231 1.25134 m .53149 1.25273 L .5328 1.25381 L .258 .236 0 r
F
.52156 1.25078 m .53149 1.25273 L .52231 1.25134 L .256 .234 0 r
F
.53588 1.25768 m .54727 1.26152 L .54757 1.26274 L .277 .261 0 r
F
.53545 1.2568 m .54727 1.26152 L .53588 1.25768 L .276 .26 0 r
F
.19193 1.11687 m .18973 1.09432 L .20069 1.09761 L .947 .823 0 r
F
.19193 1.11687 m .18073 1.1142 L .18973 1.09432 L F
.59346 1.2824 m .60377 1.29031 L .59242 1.28516 L .38 .408 0 r
F
.58195 1.27779 m .59346 1.2824 L .59242 1.28516 L .355 .372 0 r
F
.55907 1.26698 m .57046 1.27315 L .55897 1.26849 L .313 .312 0 r
F
.54757 1.26274 m .55907 1.26698 L .55897 1.26849 L .293 .284 0 r
F
.34167 1.15321 m .33837 1.13704 L .34871 1.14366 L .813 .652 0 r
F
.34167 1.15321 m .33092 1.14763 L .33837 1.13704 L F
.50984 1.2453 m .50877 1.24142 L .51097 1.24566 L .246 .219 0 r
F
.50984 1.2453 m .50651 1.24071 L .50877 1.24142 L F
.52156 1.25078 m .53 1.25162 L .53149 1.25273 L .256 .234 0 r
F
.52073 1.25022 m .53 1.25162 L .52156 1.25078 L .255 .232 0 r
F
.48414 1.23289 m .4771 1.22687 L .48614 1.2328 L .253 .227 0 r
F
.48414 1.23289 m .47444 1.22698 L .4771 1.22687 L F
.79899 1.00487 m .82422 1.01959 L .81354 1.02133 L .804 .806 0 r
F
.7888 1.00714 m .79899 1.00487 L .81354 1.02133 L .796 .801 0 r
F
.60987 .98973 m .63324 .99242 L .62634 .99537 L .52 .648 0 r
F
.56647 .98769 m .57016 .98481 L .58749 .98826 L .424 .482 0 r
F
.54967 .98515 m .57016 .98481 L .56647 .98769 L .393 .394 0 r
F
.48307 .70421 m .48197 .69808 L .51689 .69407 L 1 .964 0 r
F
.51097 1.24566 m .51108 1.24222 L .51212 1.24605 L .246 .22 0 r
F
.51097 1.24566 m .50877 1.24142 L .51108 1.24222 L F
.52073 1.25022 m .52833 1.2505 L .53 1.25162 L .255 .232 0 r
F
.51982 1.24965 m .52833 1.2505 L .52073 1.25022 L .254 .231 0 r
F
.46191 1.22139 m .45501 1.21451 L .46473 1.22087 L .281 .261 0 r
F
.46191 1.22139 m .45164 1.21519 L .45501 1.21451 L F
.54727 1.26152 m .55907 1.26698 L .54757 1.26274 L .293 .285 0 r
F
.33092 1.14763 m .32802 1.13076 L .33837 1.13704 L .85 .677 0 r
F
.33092 1.14763 m .32015 1.14232 L .32802 1.13076 L F
.60498 1.28695 m .61513 1.29544 L .60377 1.29031 L .404 .444 0 r
F
.59346 1.2824 m .60498 1.28695 L .60377 1.29031 L .38 .408 0 r
F
.51212 1.24605 m .51341 1.24309 L .51328 1.24649 L .248 .222 0 r
F
.51212 1.24605 m .51108 1.24222 L .51341 1.24309 L F
.51982 1.24965 m .52651 1.24937 L .52833 1.2505 L .254 .231 0 r
F
.51884 1.24908 m .52651 1.24937 L .51982 1.24965 L .253 .229 0 r
F
.49669 1.23866 m .49097 1.23322 L .49839 1.23884 L .241 .213 0 r
F
.49669 1.23866 m .48843 1.23292 L .49097 1.23322 L F
.69872 .99702 m .72399 1.00531 L .71452 1.00766 L .696 .758 0 r
F
.69 .99976 m .69872 .99702 L .71452 1.00766 L .678 .747 0 r
F
.51328 1.24649 m .51573 1.24403 L .51444 1.24696 L .249 .223 0 r
F
.51328 1.24649 m .51341 1.24309 L .51573 1.24403 L F
.51884 1.24908 m .52454 1.24825 L .52651 1.24937 L .253 .229 0 r
F
.5178 1.24852 m .52454 1.24825 L .51884 1.24908 L .252 .228 0 r
F
.53545 1.2568 m .54663 1.26018 L .54727 1.26152 L .276 .26 0 r
F
.53478 1.25586 m .54663 1.26018 L .53545 1.2568 L .274 .258 0 r
F
.74298 1.00034 m .76848 1.01149 L .75835 1.01355 L .752 .784 0 r
F
.73347 1.00287 m .74298 1.00034 L .75835 1.01355 L .74 .776 0 r
F
.51444 1.24696 m .51804 1.24503 L .51559 1.24746 L .25 .225 0 r
F
.51444 1.24696 m .51573 1.24403 L .51804 1.24503 L F
.5178 1.24852 m .52246 1.24715 L .52454 1.24825 L .252 .228 0 r
F
.51671 1.24798 m .52246 1.24715 L .5178 1.24852 L .251 .227 0 r
F
.51559 1.24746 m .52029 1.24607 L .51671 1.24798 L .25 .226 0 r
F
.51559 1.24746 m .51804 1.24503 L .52029 1.24607 L F
.51671 1.24798 m .52029 1.24607 L .52246 1.24715 L .251 .227 0 r
F
.32015 1.14232 m .31765 1.12483 L .32802 1.13076 L .88 .7 0 r
F
.32015 1.14232 m .30937 1.13729 L .31765 1.12483 L F
.66505 .99367 m .69 .99976 L .6813 1.00237 L .642 .732 0 r
F
.6572 .99658 m .66505 .99367 L .6813 1.00237 L .62 .715 0 r
F
.57059 1.27117 m .58195 1.27779 L .57046 1.27315 L .335 .345 0 r
F
.55907 1.26698 m .57059 1.27117 L .57046 1.27315 L .313 .312 0 r
F
.61651 1.29142 m .62649 1.30051 L .61513 1.29544 L .43 .479 0 r
F
.60498 1.28695 m .61651 1.29142 L .61513 1.29544 L .404 .444 0 r
F
.45164 1.21519 m .44527 1.20783 L .45501 1.21451 L .298 .279 0 r
F
.45164 1.21519 m .44136 1.20875 L .44527 1.20783 L F
.49839 1.23884 m .49374 1.2337 L .50024 1.23914 L .237 .208 0 r
F
.49839 1.23884 m .49097 1.23322 L .49374 1.2337 L F
.47444 1.22698 m .46805 1.22074 L .4771 1.22687 L .254 .227 0 r
F
.47444 1.22698 m .46473 1.22087 L .46805 1.22074 L F
.30937 1.13729 m .30726 1.11921 L .31765 1.12483 L .905 .72 0 r
F
.30937 1.13729 m .29857 1.13251 L .30726 1.11921 L F
.48614 1.2328 m .48015 1.22704 L .48843 1.23292 L .242 .213 0 r
F
.48614 1.2328 m .4771 1.22687 L .48015 1.22704 L F
.53478 1.25586 m .54564 1.25875 L .54663 1.26018 L .274 .258 0 r
F
.5339 1.25486 m .54564 1.25875 L .53478 1.25586 L .271 .254 0 r
F
.62805 1.29577 m .63786 1.30547 L .62649 1.30051 L .469 .512 0 r
F
.61651 1.29142 m .62805 1.29577 L .62649 1.30051 L .43 .479 0 r
F
.54727 1.26152 m .55869 1.2653 L .55907 1.26698 L .293 .285 0 r
F
.54663 1.26018 m .55869 1.2653 L .54727 1.26152 L .292 .283 0 r
F
.44136 1.20875 m .43554 1.2008 L .44527 1.20783 L .32 .303 0 r
F
.44136 1.20875 m .43108 1.20204 L .43554 1.2008 L F
.54967 .98515 m .5522 .98246 L .57016 .98481 L .393 .394 0 r
F
.53245 .98358 m .5522 .98246 L .54967 .98515 L .346 .267 0 r
F
.55869 1.2653 m .57059 1.27117 L .55907 1.26698 L .313 .314 0 r
F
.58213 1.2753 m .59346 1.2824 L .58195 1.27779 L .358 .379 0 r
F
.57059 1.27117 m .58213 1.2753 L .58195 1.27779 L .335 .345 0 r
F
.29857 1.13251 m .29686 1.11388 L .30726 1.11921 L .924 .739 0 r
F
.29857 1.13251 m .28776 1.12796 L .29686 1.11388 L F
.63959 1.29997 m .64923 1.3103 L .63786 1.30547 L .513 .543 0 r
F
.62805 1.29577 m .63959 1.29997 L .63786 1.30547 L .469 .512 0 r
F
.79899 1.00487 m .80921 1.00253 L .82422 1.01959 L .804 .806 0 r
F
.50024 1.23914 m .49672 1.23436 L .50222 1.23956 L .234 .204 0 r
F
.50024 1.23914 m .49374 1.2337 L .49672 1.23436 L F
.5339 1.25486 m .54432 1.25724 L .54564 1.25875 L .271 .254 0 r
F
.5328 1.25381 m .54432 1.25724 L .5339 1.25486 L .268 .25 0 r
F
.43108 1.20204 m .42579 1.19335 L .43554 1.2008 L .348 .334 0 r
F
.43108 1.20204 m .42079 1.19505 L .42579 1.19335 L F
.58749 .98826 m .59232 .98514 L .60987 .98973 L .469 .584 0 r
F
.57016 .98481 m .59232 .98514 L .58749 .98826 L .452 .537 0 r
F
.65115 1.30401 m .6606 1.31496 L .64923 1.3103 L .556 .571 0 r
F
.63959 1.29997 m .65115 1.30401 L .64923 1.3103 L .513 .543 0 r
F
.84775 1.34666 m .85334 1.36663 L .84205 1.36461 L .859 .805 0 r
F
.84775 1.34666 m .8593 1.3481 L .85334 1.36663 L F
.46473 1.22087 m .45898 1.21433 L .46805 1.22074 L .259 .23 0 r
F
.46473 1.22087 m .45501 1.21451 L .45898 1.21433 L F
.53245 .98358 m .53379 .98128 L .5522 .98246 L .346 .267 0 r
F
.51502 .98299 m .53379 .98128 L .53245 .98358 L .272 .136 0 r
F
.28776 1.12796 m .28643 1.10882 L .29686 1.11388 L .939 .755 0 r
F
.28776 1.12796 m .27693 1.12362 L .28643 1.10882 L F
.48843 1.23292 m .48353 1.22749 L .49097 1.23322 L .233 .201 0 r
F
.48843 1.23292 m .48015 1.22704 L .48353 1.22749 L F
.42079 1.19505 m .41605 1.18548 L .42579 1.19335 L .381 .371 0 r
F
.42079 1.19505 m .41051 1.18781 L .41605 1.18548 L F
.49757 .98339 m .51515 .98137 L .51502 .98299 L .153 .125 0 r
F
.49757 .98339 m .49649 .98289 L .51515 .98137 L F
.50222 1.23956 m .49987 1.23518 L .50432 1.24008 L .233 .202 0 r
F
.50222 1.23956 m .49672 1.23436 L .49987 1.23518 L F
.8362 1.34514 m .84205 1.36461 L .83076 1.36252 L .855 .799 0 r
F
.8362 1.34514 m .84775 1.34666 L .84205 1.36461 L F
.5328 1.25381 m .54267 1.25567 L .54432 1.25724 L .268 .25 0 r
F
.53149 1.25273 m .54267 1.25567 L .5328 1.25381 L .264 .245 0 r
F
.59368 1.27934 m .60498 1.28695 L .59346 1.2824 L .382 .415 0 r
F
.58213 1.2753 m .59368 1.27934 L .59346 1.2824 L .358 .379 0 r
F
.54663 1.26018 m .55784 1.26347 L .55869 1.2653 L .292 .283 0 r
F
.54564 1.25875 m .55784 1.26347 L .54663 1.26018 L .289 .28 0 r
F
.66271 1.30787 m .67198 1.31943 L .6606 1.31496 L .596 .598 0 r
F
.65115 1.30401 m .66271 1.30787 L .6606 1.31496 L .556 .571 0 r
F
.64016 .98931 m .66505 .99367 L .6572 .99658 L .601 .71 0 r
F
.63324 .99242 m .64016 .98931 L .6572 .99658 L .574 .689 0 r
F
.51502 .98299 m .51515 .98137 L .53379 .98128 L .272 .136 0 r
F
.75252 .99772 m .77863 1.00935 L .76848 1.01149 L .764 .791 0 r
F
.74298 1.00034 m .75252 .99772 L .76848 1.01149 L .752 .784 0 r
F
.82464 1.34354 m .83076 1.36252 L .81946 1.36034 L .85 .793 0 r
F
.82464 1.34354 m .8362 1.34514 L .83076 1.36252 L F
.4771 1.22687 m .47185 1.22099 L .48015 1.22704 L .238 .205 0 r
F
.4771 1.22687 m .46805 1.22074 L .47185 1.22099 L F
.41051 1.18781 m .4063 1.17722 L .41605 1.18548 L .42 .413 0 r
F
.41051 1.18781 m .40022 1.18037 L .4063 1.17722 L F
.57013 1.26899 m .58213 1.2753 L .57059 1.27117 L .335 .346 0 r
F
.55869 1.2653 m .57013 1.26899 L .57059 1.27117 L .313 .314 0 r
F
.70747 .99418 m .73347 1.00287 L .72399 1.00531 L .712 .768 0 r
F
.69872 .99702 m .70747 .99418 L .72399 1.00531 L .696 .758 0 r
F
.67427 1.31154 m .68335 1.32369 L .67198 1.31943 L .633 .622 0 r
F
.66271 1.30787 m .67427 1.31154 L .67198 1.31943 L .596 .598 0 r
F
.81308 1.34186 m .81946 1.36034 L .80815 1.35807 L .843 .786 0 r
F
.81308 1.34186 m .82464 1.34354 L .81946 1.36034 L F
.50432 1.24008 m .50317 1.23614 L .50651 1.24071 L .232 .202 0 r
F
.50432 1.24008 m .49987 1.23518 L .50317 1.23614 L F
.27693 1.12362 m .27598 1.10398 L .28643 1.10882 L .951 .77 0 r
F
.27693 1.12362 m .26609 1.11948 L .27598 1.10398 L F
.53149 1.25273 m .54071 1.25405 L .54267 1.25567 L .264 .245 0 r
F
.53 1.25162 m .54071 1.25405 L .53149 1.25273 L .261 .241 0 r
F
.55784 1.26347 m .57013 1.26899 L .55869 1.2653 L .311 .312 0 r
F
.40022 1.18037 m .39656 1.16863 L .4063 1.17722 L .494 .456 0 r
F
.40022 1.18037 m .38993 1.17283 L .39656 1.16863 L F
.80152 1.34008 m .80815 1.35807 L .79684 1.35569 L .836 .779 0 r
F
.80152 1.34008 m .81308 1.34186 L .80815 1.35807 L F
.67427 1.31154 m .68584 1.315 L .68335 1.32369 L .633 .622 0 r
F
.68584 1.315 m .69472 1.32774 L .68335 1.32369 L .666 .644 0 r
F
.60987 .98973 m .61578 .98654 L .63324 .99242 L .52 .648 0 r
F
.59232 .98514 m .61578 .98654 L .60987 .98973 L .495 .624 0 r
F
.45501 1.21451 m .4499 1.20759 L .45898 1.21433 L .268 .238 0 r
F
.45501 1.21451 m .44527 1.20783 L .4499 1.20759 L F
.78996 1.33821 m .79684 1.35569 L .78552 1.3532 L .828 .77 0 r
F
.78996 1.33821 m .80152 1.34008 L .79684 1.35569 L F
.60525 1.28327 m .61651 1.29142 L .60498 1.28695 L .405 .45 0 r
F
.59368 1.27934 m .60525 1.28327 L .60498 1.28695 L .382 .415 0 r
F
.38993 1.17283 m .38681 1.15987 L .39656 1.16863 L .581 .498 0 r
F
.38993 1.17283 m .37964 1.16528 L .38681 1.15987 L F
.6974 1.31827 m .70609 1.33158 L .69472 1.32774 L .696 .664 0 r
F
.68584 1.315 m .6974 1.31827 L .69472 1.32774 L .666 .644 0 r
F
.61578 .98654 m .64016 .98931 L .63324 .99242 L .552 .677 0 r
F
.49097 1.23322 m .48723 1.22819 L .49374 1.2337 L .224 .191 0 r
F
.49097 1.23322 m .48353 1.22749 L .48723 1.22819 L F
.50651 1.24071 m .50656 1.23724 L .50877 1.24142 L .233 .203 0 r
F
.50651 1.24071 m .50317 1.23614 L .50656 1.23724 L F
.77839 1.33622 m .78552 1.3532 L .77419 1.35058 L .819 .761 0 r
F
.77839 1.33622 m .78996 1.33821 L .78552 1.3532 L F
.53 1.25162 m .53847 1.2524 L .54071 1.25405 L .261 .241 0 r
F
.52833 1.2505 m .53847 1.2524 L .53 1.25162 L .258 .236 0 r
F
.67294 .99062 m .69872 .99702 L .69 .99976 L .664 .746 0 r
F
.66505 .99367 m .67294 .99062 L .69 .99976 L .642 .732 0 r
F
.70897 1.32134 m .71745 1.3352 L .70609 1.33158 L .722 .682 0 r
F
.6974 1.31827 m .70897 1.32134 L .70609 1.33158 L .696 .664 0 r
F
.54564 1.25875 m .55653 1.26154 L .55784 1.26347 L .289 .28 0 r
F
.54432 1.25724 m .55653 1.26154 L .54564 1.25875 L .285 .274 0 r
F
.76683 1.33411 m .77419 1.35058 L .76285 1.34783 L .808 .751 0 r
F
.76683 1.33411 m .77839 1.33622 L .77419 1.35058 L F
.37964 1.16528 m .37705 1.15111 L .38681 1.15987 L .666 .538 0 r
F
.37964 1.16528 m .36934 1.15783 L .37705 1.15111 L F
.72055 1.32423 m .72881 1.33863 L .71745 1.3352 L .744 .699 0 r
F
.70897 1.32134 m .72055 1.32423 L .71745 1.3352 L .722 .682 0 r
F
.26609 1.11948 m .26551 1.09934 L .27598 1.10398 L .96 .783 0 r
F
.26609 1.11948 m .25523 1.11551 L .26551 1.09934 L F
.75526 1.33186 m .76285 1.34783 L .75151 1.34493 L .795 .74 0 r
F
.75526 1.33186 m .76683 1.33411 L .76285 1.34783 L F
.73212 1.32693 m .74016 1.34187 L .72881 1.33863 L .764 .714 0 r
F
.72055 1.32423 m .73212 1.32693 L .72881 1.33863 L .744 .699 0 r
F
.74369 1.32948 m .75151 1.34493 L .74016 1.34187 L .781 .728 0 r
F
.74369 1.32948 m .75526 1.33186 L .75151 1.34493 L F
.73212 1.32693 m .74369 1.32948 L .74016 1.34187 L .764 .714 0 r
F
.50877 1.24142 m .51003 1.23846 L .51108 1.24222 L .235 .205 0 r
F
.50877 1.24142 m .50656 1.23724 L .51003 1.23846 L F
.52833 1.2505 m .53597 1.25074 L .53847 1.2524 L .258 .236 0 r
F
.52651 1.24937 m .53597 1.25074 L .52833 1.2505 L .254 .232 0 r
F
.58159 1.27258 m .59368 1.27934 L .58213 1.2753 L .358 .381 0 r
F
.57013 1.26899 m .58159 1.27258 L .58213 1.2753 L .335 .346 0 r
F
.36934 1.15783 m .36729 1.14253 L .37705 1.15111 L .743 .575 0 r
F
.36934 1.15783 m .35903 1.1506 L .36729 1.14253 L F
.61683 1.28707 m .62805 1.29577 L .61651 1.29142 L .427 .485 0 r
F
.60525 1.28327 m .61683 1.28707 L .61651 1.29142 L .405 .45 0 r
F
.57016 .98481 m .57387 .9817 L .59232 .98514 L .452 .537 0 r
F
.5522 .98246 m .57387 .9817 L .57016 .98481 L .43 .467 0 r
F
.51108 1.24222 m .51353 1.23977 L .51341 1.24309 L .237 .208 0 r
F
.51108 1.24222 m .51003 1.23846 L .51353 1.23977 L F
.44527 1.20783 m .44081 1.20041 L .4499 1.20759 L .284 .252 0 r
F
.44527 1.20783 m .43554 1.2008 L .44081 1.20041 L F
.46805 1.22074 m .46353 1.21468 L .47185 1.22099 L .234 .199 0 r
F
.46805 1.22074 m .45898 1.21433 L .46353 1.21468 L F
.52651 1.24937 m .53323 1.24908 L .53597 1.25074 L .254 .232 0 r
F
.52454 1.24825 m .53323 1.24908 L .52651 1.24937 L .251 .228 0 r
F
.48015 1.22704 m .47608 1.22162 L .48353 1.22749 L .221 .186 0 r
F
.48015 1.22704 m .47185 1.22099 L .47608 1.22162 L F
.35903 1.1506 m .35751 1.13428 L .36729 1.14253 L .808 .61 0 r
F
.35903 1.1506 m .34871 1.14366 L .35751 1.13428 L F
.49374 1.2337 m .49121 1.22914 L .49672 1.23436 L .218 .184 0 r
F
.49374 1.2337 m .48723 1.22819 L .49121 1.22914 L F
.25523 1.11551 m .25502 1.09488 L .26551 1.09934 L .967 .794 0 r
F
.25523 1.11551 m .24436 1.11169 L .25502 1.09488 L F
.51341 1.24309 m .51703 1.24118 L .51573 1.24403 L .239 .211 0 r
F
.51341 1.24309 m .51353 1.23977 L .51703 1.24118 L F
.52454 1.24825 m .53028 1.24742 L .53323 1.24908 L .251 .228 0 r
F
.52246 1.24715 m .53028 1.24742 L .52454 1.24825 L .249 .224 0 r
F
.55784 1.26347 m .56908 1.26665 L .57013 1.26899 L .311 .312 0 r
F
.55653 1.26154 m .56908 1.26665 L .55784 1.26347 L .307 .307 0 r
F
.54432 1.25724 m .55477 1.25951 L .55653 1.26154 L .285 .274 0 r
F
.54267 1.25567 m .55477 1.25951 L .54432 1.25724 L .28 .268 0 r
F
.51573 1.24403 m .52049 1.24266 L .51804 1.24503 L .241 .214 0 r
F
.51573 1.24403 m .51703 1.24118 L .52049 1.24266 L F
.52246 1.24715 m .52715 1.2458 L .53028 1.24742 L .249 .224 0 r
F
.52029 1.24607 m .52715 1.2458 L .52246 1.24715 L .246 .221 0 r
F
.56908 1.26665 m .58159 1.27258 L .57013 1.26899 L .332 .344 0 r
F
.76208 .99502 m .7888 1.00714 L .77863 1.00935 L .775 .797 0 r
F
.75252 .99772 m .76208 .99502 L .77863 1.00935 L .764 .791 0 r
F
.51804 1.24503 m .52388 1.2442 L .52029 1.24607 L .244 .217 0 r
F
.51804 1.24503 m .52049 1.24266 L .52388 1.2442 L F
.52029 1.24607 m .52388 1.2442 L .52715 1.2458 L .246 .221 0 r
F
.34871 1.14366 m .34771 1.12646 L .35751 1.13428 L .862 .642 0 r
F
.34871 1.14366 m .33837 1.13704 L .34771 1.12646 L F
.62843 1.29072 m .63959 1.29997 L .62805 1.29577 L .461 .517 0 r
F
.61683 1.28707 m .62843 1.29072 L .62805 1.29577 L .427 .485 0 r
F
.43554 1.2008 m .43171 1.19271 L .44081 1.20041 L .309 .275 0 r
F
.43554 1.2008 m .42579 1.19335 L .43171 1.19271 L F
.59307 1.27604 m .60525 1.28327 L .59368 1.27934 L .38 .417 0 r
F
.58159 1.27258 m .59307 1.27604 L .59368 1.27934 L .358 .381 0 r
F
.24436 1.11169 m .24451 1.09057 L .25502 1.09488 L .972 .804 0 r
F
.24436 1.11169 m .23346 1.108 L .24451 1.09057 L F
.71625 .99123 m .74298 1.00034 L .73347 1.00287 L .728 .778 0 r
F
.70747 .99418 m .71625 .99123 L .73347 1.00287 L .712 .768 0 r
F
.33837 1.13704 m .3379 1.1191 L .34771 1.12646 L .904 .671 0 r
F
.33837 1.13704 m .32802 1.13076 L .3379 1.1191 L F
.49672 1.23436 m .49541 1.2303 L .49987 1.23518 L .215 .179 0 r
F
.49672 1.23436 m .49121 1.22914 L .49541 1.2303 L F
.54267 1.25567 m .55258 1.25741 L .55477 1.25951 L .28 .268 0 r
F
.54071 1.25405 m .55258 1.25741 L .54267 1.25567 L .274 .26 0 r
F
.64711 .98605 m .67294 .99062 L .66505 .99367 L .626 .728 0 r
F
.64016 .98931 m .64711 .98605 L .66505 .99367 L .601 .71 0 r
F
.45898 1.21433 m .4552 1.20804 L .46353 1.21468 L .234 .194 0 r
F
.45898 1.21433 m .4499 1.20759 L .4552 1.20804 L F
.5522 .98246 m .55474 .97949 L .57387 .9817 L .43 .467 0 r
F
.53379 .98128 m .55474 .97949 L .5522 .98246 L .4 .364 0 r
F
.64003 1.29419 m .65115 1.30401 L .63959 1.29997 L .5 .547 0 r
F
.62843 1.29072 m .64003 1.29419 L .63959 1.29997 L .461 .517 0 r
F
.48353 1.22749 m .4807 1.2226 L .48723 1.22819 L .207 .169 0 r
F
.48353 1.22749 m .47608 1.22162 L .4807 1.2226 L F
.42579 1.19335 m .42261 1.18439 L .43171 1.19271 L .342 .308 0 r
F
.42579 1.19335 m .41605 1.18548 L .42261 1.18439 L F
.55653 1.26154 m .56745 1.26418 L .56908 1.26665 L .307 .307 0 r
F
.55477 1.25951 m .56745 1.26418 L .55653 1.26154 L .302 .3 0 r
F
.59232 .98514 m .59716 .98181 L .61578 .98654 L .495 .624 0 r
F
.57387 .9817 m .59716 .98181 L .59232 .98514 L .478 .589 0 r
F
.32802 1.13076 m .32806 1.1122 L .3379 1.1191 L .937 .698 0 r
F
.32802 1.13076 m .31765 1.12483 L .32806 1.1122 L F
.23346 1.108 m .23398 1.08639 L .24451 1.09057 L .976 .813 0 r
F
.23346 1.108 m .22256 1.10443 L .23398 1.08639 L F
.47185 1.22099 m .4686 1.21555 L .47608 1.22162 L .209 .169 0 r
F
.47185 1.22099 m .46353 1.21468 L .4686 1.21555 L F
.49987 1.23518 m .49981 1.23165 L .50317 1.23614 L .213 .178 0 r
F
.49987 1.23518 m .49541 1.2303 L .49981 1.23165 L F
.58034 1.26969 m .59307 1.27604 L .58159 1.27258 L .354 .379 0 r
F
.56908 1.26665 m .58034 1.26969 L .58159 1.27258 L .332 .344 0 r
F
.68085 .98745 m .70747 .99418 L .69872 .99702 L .683 .759 0 r
F
.67294 .99062 m .68085 .98745 L .69872 .99702 L .664 .746 0 r
F
.54071 1.25405 m .54997 1.25526 L .55258 1.25741 L .274 .26 0 r
F
.53847 1.2524 m .54997 1.25526 L .54071 1.25405 L .268 .251 0 r
F
.60457 1.27935 m .61683 1.28707 L .60525 1.28327 L .402 .452 0 r
F
.59307 1.27604 m .60457 1.27935 L .60525 1.28327 L .38 .417 0 r
F
.65165 1.29748 m .66271 1.30787 L .65115 1.30401 L .538 .575 0 r
F
.64003 1.29419 m .65165 1.29748 L .65115 1.30401 L .5 .547 0 r
F
.41605 1.18548 m .41351 1.17541 L .42261 1.18439 L .384 .35 0 r
F
.41605 1.18548 m .4063 1.17722 L .41351 1.17541 L F
.56745 1.26418 m .58034 1.26969 L .56908 1.26665 L .328 .338 0 r
F
.62171 .98317 m .64711 .98605 L .64016 .98931 L .582 .702 0 r
F
.61578 .98654 m .62171 .98317 L .64016 .98931 L .552 .677 0 r
F
.53379 .98128 m .53514 .97864 L .55474 .97949 L .4 .364 0 r
F
.51515 .98137 m .53514 .97864 L .53379 .98128 L .355 .221 0 r
F
.31765 1.12483 m .3182 1.10572 L .32806 1.1122 L .963 .722 0 r
F
.31765 1.12483 m .30726 1.11921 L .3182 1.10572 L F
.77166 .99225 m .79899 1.00487 L .7888 1.00714 L .785 .803 0 r
F
.76208 .99502 m .77166 .99225 L .7888 1.00714 L .775 .797 0 r
F
.59716 .98181 m .62171 .98317 L .61578 .98654 L .53 .66 0 r
F
.22256 1.10443 m .22343 1.08234 L .23398 1.08639 L .979 .82 0 r
F
.22256 1.10443 m .21163 1.10097 L .22343 1.08234 L F
.50317 1.23614 m .50434 1.23316 L .50656 1.23724 L .214 .179 0 r
F
.50317 1.23614 m .49981 1.23165 L .50434 1.23316 L F
.4499 1.20759 m .44685 1.20096 L .4552 1.20804 L .239 .193 0 r
F
.4499 1.20759 m .44081 1.20041 L .44685 1.20096 L F
.478 .9862 m .49539 .98178 L .49649 .98289 L .192 .129 0 r
F
.53847 1.2524 m .54698 1.25309 L .54997 1.25526 L .268 .251 0 r
F
.53597 1.25074 m .54698 1.25309 L .53847 1.2524 L .262 .243 0 r
F
.4063 1.17722 m .40441 1.16578 L .41351 1.17541 L .448 .399 0 r
F
.4063 1.17722 m .39656 1.16863 L .40441 1.16578 L F
.66328 1.30058 m .67427 1.31154 L .66271 1.30787 L .574 .6 0 r
F
.65165 1.29748 m .66328 1.30058 L .66271 1.30787 L .538 .575 0 r
F
.48723 1.22819 m .48567 1.2239 L .49121 1.22914 L .196 .157 0 r
F
.48723 1.22819 m .4807 1.2226 L .48567 1.2239 L F
.55477 1.25951 m .56525 1.26162 L .56745 1.26418 L .302 .3 0 r
F
.55258 1.25741 m .56525 1.26162 L .55477 1.25951 L .295 .29 0 r
F
.51515 .98137 m .51528 .97932 L .53514 .97864 L .355 .221 0 r
F
.49649 .98289 m .51528 .97932 L .51515 .98137 L .287 .141 0 r
F
.49649 .98289 m .49539 .98178 L .51528 .97932 L F
.61608 1.28249 m .62843 1.29072 L .61683 1.28707 L .423 .486 0 r
F
.60457 1.27935 m .61608 1.28249 L .61683 1.28707 L .402 .452 0 r
F
.39656 1.16863 m .39531 1.15563 L .40441 1.16578 L .554 .45 0 r
F
.39656 1.16863 m .38681 1.15987 L .39531 1.15563 L F
.30726 1.11921 m .30831 1.09962 L .3182 1.10572 L .982 .744 0 r
F
.30726 1.11921 m .29686 1.11388 L .30831 1.09962 L F
.50656 1.23724 m .50898 1.23481 L .51003 1.23846 L .216 .182 0 r
F
.50656 1.23724 m .50434 1.23316 L .50898 1.23481 L F
.53597 1.25074 m .54364 1.25092 L .54698 1.25309 L .262 .243 0 r
F
.53323 1.24908 m .54364 1.25092 L .53597 1.25074 L .256 .234 0 r
F
.72505 .98818 m .75252 .99772 L .74298 1.00034 L .741 .786 0 r
F
.71625 .99123 m .72505 .98818 L .74298 1.00034 L .728 .778 0 r
F
.67492 1.30349 m .68584 1.315 L .67427 1.31154 L .607 .623 0 r
F
.66328 1.30058 m .67492 1.30349 L .67427 1.31154 L .574 .6 0 r
F
.59163 1.27257 m .60457 1.27935 L .59307 1.27604 L .376 .414 0 r
F
.58034 1.26969 m .59163 1.27257 L .59307 1.27604 L .354 .379 0 r
F
.21163 1.10097 m .21286 1.07838 L .22343 1.08234 L .981 .827 0 r
F
.21163 1.10097 m .20069 1.09761 L .21286 1.07838 L F
.38681 1.15987 m .38622 1.14523 L .39531 1.15563 L .667 .5 0 r
F
.38681 1.15987 m .37705 1.15111 L .38622 1.14523 L F
.46353 1.21468 m .46111 1.20921 L .4686 1.21555 L .196 .151 0 r
F
.46353 1.21468 m .4552 1.20804 L .46111 1.20921 L F
.47608 1.22162 m .47415 1.21689 L .4807 1.2226 L .185 .144 0 r
F
.47608 1.22162 m .4686 1.21555 L .47415 1.21689 L F
.51003 1.23846 m .51366 1.23658 L .51353 1.23977 L .22 .187 0 r
F
.51003 1.23846 m .50898 1.23481 L .51366 1.23658 L F
.53323 1.24908 m .53998 1.24875 L .54364 1.25092 L .256 .234 0 r
F
.53028 1.24742 m .53998 1.24875 L .53323 1.24908 L .25 .226 0 r
F
.57387 .9817 m .5776 .97833 L .59716 .98181 L .478 .589 0 r
F
.55474 .97949 m .5776 .97833 L .57387 .9817 L .464 .539 0 r
F
.44081 1.20041 m .4385 1.1933 L .44685 1.20096 L .253 .2 0 r
F
.44081 1.20041 m .43171 1.19271 L .4385 1.1933 L F
.56745 1.26418 m .5784 1.26667 L .58034 1.26969 L .328 .338 0 r
F
.56525 1.26162 m .5784 1.26667 L .56745 1.26418 L .321 .329 0 r
F
.67492 1.30349 m .68656 1.3062 L .68584 1.315 L .607 .623 0 r
F
.68656 1.3062 m .6974 1.31827 L .68584 1.315 L .637 .644 0 r
F
.49121 1.22914 m .49093 1.22547 L .49541 1.2303 L .189 .15 0 r
F
.49121 1.22914 m .48567 1.2239 L .49093 1.22547 L F
.37705 1.15111 m .37711 1.13492 L .38622 1.14523 L .77 .546 0 r
F
.37705 1.15111 m .36729 1.14253 L .37711 1.13492 L F
.29686 1.11388 m .2984 1.09384 L .30831 1.09962 L .996 .763 0 r
F
.29686 1.11388 m .28643 1.10882 L .2984 1.09384 L F
.5784 1.26667 m .59163 1.27257 L .58034 1.26969 L .349 .372 0 r
F
.55258 1.25741 m .56252 1.259 L .56525 1.26162 L .295 .29 0 r
F
.54997 1.25526 m .56252 1.259 L .55258 1.25741 L .287 .279 0 r
F
.51353 1.23977 m .51834 1.23845 L .51703 1.24118 L .224 .192 0 r
F
.51353 1.23977 m .51366 1.23658 L .51834 1.23845 L F
.53028 1.24742 m .53604 1.2466 L .53998 1.24875 L .25 .226 0 r
F
.52715 1.2458 m .53604 1.2466 L .53028 1.24742 L .244 .218 0 r
F
.62762 1.28546 m .64003 1.29419 L .62843 1.29072 L .45 .517 0 r
F
.61608 1.28249 m .62762 1.28546 L .62843 1.29072 L .423 .486 0 r
F
.65409 .98263 m .68085 .98745 L .67294 .99062 L .65 .745 0 r
F
.64711 .98605 m .65409 .98263 L .67294 .99062 L .626 .728 0 r
F
.20069 1.09761 m .20226 1.07451 L .21286 1.07838 L .982 .833 0 r
F
.20069 1.09761 m .18973 1.09432 L .20226 1.07451 L F
.51703 1.24118 m .52296 1.24039 L .52049 1.24266 L .228 .198 0 r
F
.51703 1.24118 m .51834 1.23845 L .52296 1.24039 L F
.52715 1.2458 m .53186 1.24448 L .53604 1.2466 L .244 .218 0 r
F
.52388 1.2442 m .53186 1.24448 L .52715 1.2458 L .239 .211 0 r
F
.78127 .98941 m .80921 1.00253 L .79899 1.00487 L .794 .808 0 r
F
.77166 .99225 m .78127 .98941 L .79899 1.00487 L .785 .803 0 r
F
.69821 1.30873 m .70897 1.32134 L .6974 1.31827 L .664 .663 0 r
F
.68656 1.3062 m .69821 1.30873 L .6974 1.31827 L .637 .644 0 r
F
.36729 1.14253 m .36799 1.12501 L .37711 1.13492 L .855 .589 0 r
F
.36729 1.14253 m .35751 1.13428 L .36799 1.12501 L F
.52049 1.24266 m .52749 1.24241 L .52388 1.2442 L .233 .204 0 r
F
.52049 1.24266 m .52296 1.24039 L .52749 1.24241 L F
.52388 1.2442 m .52749 1.24241 L .53186 1.24448 L .239 .211 0 r
F
.68878 .98415 m .71625 .99123 L .70747 .99418 L .701 .77 0 r
F
.68085 .98745 m .68878 .98415 L .70747 .99418 L .683 .759 0 r
F
.70987 1.31107 m .72055 1.32423 L .70897 1.32134 L .689 .681 0 r
F
.69821 1.30873 m .70987 1.31107 L .70897 1.32134 L .664 .663 0 r
F
.60294 1.27526 m .61608 1.28249 L .60457 1.27935 L .397 .448 0 r
F
.59163 1.27257 m .60294 1.27526 L .60457 1.27935 L .376 .414 0 r
F
.43171 1.19271 m .43014 1.18487 L .4385 1.1933 L .28 .219 0 r
F
.43171 1.19271 m .42261 1.18439 L .43014 1.18487 L F
.28643 1.10882 m .28846 1.08835 L .2984 1.09384 L 1 .779 0 r
F
.28643 1.10882 m .27598 1.10398 L .28846 1.08835 L F
.35751 1.13428 m .35885 1.11572 L .36799 1.12501 L .921 .629 0 r
F
.35751 1.13428 m .34771 1.12646 L .35885 1.11572 L F
.49541 1.2303 m .49643 1.22726 L .49981 1.23165 L .186 .148 0 r
F
.49541 1.2303 m .49093 1.22547 L .49643 1.22726 L F
.54997 1.25526 m .55926 1.25634 L .56252 1.259 L .287 .279 0 r
F
.54698 1.25309 m .55926 1.25634 L .54997 1.25526 L .278 .266 0 r
F
.63917 1.28823 m .65165 1.29748 L .64003 1.29419 L .484 .547 0 r
F
.62762 1.28546 m .63917 1.28823 L .64003 1.29419 L .45 .517 0 r
F
.72154 1.31325 m .73212 1.32693 L .72055 1.32423 L .71 .697 0 r
F
.70987 1.31107 m .72154 1.31325 L .72055 1.32423 L .689 .681 0 r
F
.4552 1.20804 m .4536 1.20249 L .46111 1.20921 L .184 .134 0 r
F
.4552 1.20804 m .44685 1.20096 L .4536 1.20249 L F
.4807 1.2226 m .48011 1.21864 L .48567 1.2239 L .167 .126 0 r
F
.4807 1.2226 m .47415 1.21689 L .48011 1.21864 L F
.59716 .98181 m .60203 .97827 L .62171 .98317 L .53 .66 0 r
F
.5776 .97833 m .60203 .97827 L .59716 .98181 L .509 .637 0 r
F
.56525 1.26162 m .57577 1.26356 L .5784 1.26667 L .321 .329 0 r
F
.56252 1.259 m .57577 1.26356 L .56525 1.26162 L .312 .317 0 r
F
.55474 .97949 m .5573 .97623 L .5776 .97833 L .464 .539 0 r
F
.53514 .97864 m .5573 .97623 L .55474 .97949 L .448 .466 0 r
F
.62766 .97963 m .65409 .98263 L .64711 .98605 L .611 .725 0 r
F
.62171 .98317 m .62766 .97963 L .64711 .98605 L .582 .702 0 r
F
.73388 .98505 m .76208 .99502 L .75252 .99772 L .754 .794 0 r
F
.72505 .98818 m .73388 .98505 L .75252 .99772 L .741 .786 0 r
F
.73321 1.31526 m .74369 1.32948 L .73212 1.32693 L .729 .711 0 r
F
.72154 1.31325 m .73321 1.31526 L .73212 1.32693 L .71 .697 0 r
F
.34771 1.12646 m .34969 1.10711 L .35885 1.11572 L .971 .665 0 r
F
.34771 1.12646 m .3379 1.1191 L .34969 1.10711 L F
.4686 1.21555 m .46757 1.21101 L .47415 1.21689 L .159 .116 0 r
F
.4686 1.21555 m .46111 1.20921 L .46757 1.21101 L F
.42261 1.18439 m .42177 1.17548 L .43014 1.18487 L .323 .254 0 r
F
.42261 1.18439 m .41351 1.17541 L .42177 1.17548 L F
.58937 1.26897 m .60294 1.27526 L .59163 1.27257 L .37 .406 0 r
F
.5784 1.26667 m .58937 1.26897 L .59163 1.27257 L .349 .372 0 r
F
.27598 1.10398 m .2785 1.08309 L .28846 1.08835 L 1 .793 0 r
F
.27598 1.10398 m .26551 1.09934 L .2785 1.08309 L F
.60203 .97827 m .62766 .97963 L .62171 .98317 L .565 .692 0 r
F
.74488 1.31712 m .75526 1.33186 L .74369 1.32948 L .746 .724 0 r
F
.73321 1.31526 m .74488 1.31712 L .74369 1.32948 L .729 .711 0 r
F
.57577 1.26356 m .58937 1.26897 L .5784 1.26667 L .341 .361 0 r
F
.54698 1.25309 m .55553 1.25367 L .55926 1.25634 L .278 .266 0 r
F
.54364 1.25092 m .55553 1.25367 L .54698 1.25309 L .269 .253 0 r
F
.49981 1.23165 m .50212 1.22923 L .50434 1.23316 L .187 .149 0 r
F
.49981 1.23165 m .49643 1.22726 L .50212 1.22923 L F
.65073 1.29081 m .66328 1.30058 L .65165 1.29748 L .518 .574 0 r
F
.63917 1.28823 m .65073 1.29081 L .65165 1.29748 L .484 .547 0 r
F
.75656 1.31884 m .76683 1.33411 L .75526 1.33186 L .761 .736 0 r
F
.74488 1.31712 m .75656 1.31884 L .75526 1.33186 L .746 .724 0 r
F
.61427 1.27777 m .62762 1.28546 L .61608 1.28249 L .417 .482 0 r
F
.60294 1.27526 m .61427 1.27777 L .61608 1.28249 L .397 .448 0 r
F
.78127 .98941 m .79091 .9865 L .80921 1.00253 L .794 .808 0 r
F
.3379 1.1191 m .3405 1.09918 L .34969 1.10711 L 1 .697 0 r
F
.3379 1.1191 m .32806 1.1122 L .3405 1.09918 L F
.76824 1.32043 m .77839 1.33622 L .76683 1.33411 L .774 .746 0 r
F
.75656 1.31884 m .76824 1.32043 L .76683 1.33411 L .761 .736 0 r
F
.41351 1.17541 m .41342 1.16495 L .42177 1.17548 L .381 .307 0 r
F
.41351 1.17541 m .40441 1.16578 L .41342 1.16495 L F
.53514 .97864 m .53649 .97565 L .5573 .97623 L .448 .466 0 r
F
.51528 .97932 m .53649 .97565 L .53514 .97864 L .429 .362 0 r
F
.77992 1.3219 m .78996 1.33821 L .77839 1.33622 L .786 .756 0 r
F
.76824 1.32043 m .77992 1.3219 L .77839 1.33622 L .774 .746 0 r
F
.54364 1.25092 m .55135 1.251 L .55553 1.25367 L .269 .253 0 r
F
.53998 1.24875 m .55135 1.251 L .54364 1.25092 L .259 .239 0 r
F
.44685 1.20096 m .44607 1.19524 L .4536 1.20249 L .178 .12 0 r
F
.44685 1.20096 m .4385 1.1933 L .44607 1.19524 L F
.48567 1.2239 m .48643 1.22072 L .49093 1.22547 L .154 .116 0 r
F
.48567 1.2239 m .48011 1.21864 L .48643 1.22072 L F
.50434 1.23316 m .50792 1.23134 L .50898 1.23481 L .191 .153 0 r
F
.50434 1.23316 m .50212 1.22923 L .50792 1.23134 L F
.56252 1.259 m .57249 1.26041 L .57577 1.26356 L .312 .317 0 r
F
.55926 1.25634 m .57249 1.26041 L .56252 1.259 L .302 .302 0 r
F
.79161 1.32326 m .80152 1.34008 L .78996 1.33821 L .796 .765 0 r
F
.77992 1.3219 m .79161 1.32326 L .78996 1.33821 L .786 .756 0 r
F
.26551 1.09934 m .26852 1.07804 L .2785 1.08309 L 1 .806 0 r
F
.26551 1.09934 m .25502 1.09488 L .26852 1.07804 L F
.8033 1.32452 m .81308 1.34186 L .80152 1.34008 L .805 .773 0 r
F
.79161 1.32326 m .8033 1.32452 L .80152 1.34008 L .796 .765 0 r
F
.66109 .97908 m .68878 .98415 L .68085 .98745 L .672 .76 0 r
F
.65409 .98263 m .66109 .97908 L .68085 .98745 L .65 .745 0 r
F
.66231 1.29319 m .67492 1.30349 L .66328 1.30058 L .551 .599 0 r
F
.65073 1.29081 m .66231 1.29319 L .66328 1.30058 L .518 .574 0 r
F
.69675 .98075 m .72505 .98818 L .71625 .99123 L .718 .78 0 r
F
.68878 .98415 m .69675 .98075 L .71625 .99123 L .701 .77 0 r
F
.40441 1.16578 m .40508 1.15325 L .41342 1.16495 L .489 .373 0 r
F
.40441 1.16578 m .39531 1.15563 L .40508 1.15325 L F
.81499 1.32568 m .82464 1.34354 L .81308 1.34186 L .812 .78 0 r
F
.8033 1.32452 m .81499 1.32568 L .81308 1.34186 L .805 .773 0 r
F
.51528 .97932 m .51542 .97679 L .53649 .97565 L .429 .362 0 r
F
.49539 .98178 m .51542 .97679 L .51528 .97932 L .409 .23 0 r
F
.32806 1.1122 m .33127 1.09184 L .3405 1.09918 L 1 .727 0 r
F
.32806 1.1122 m .3182 1.10572 L .33127 1.09184 L F
.82669 1.32675 m .8362 1.34514 L .82464 1.34354 L .819 .787 0 r
F
.81499 1.32568 m .82669 1.32675 L .82464 1.34354 L .812 .78 0 r
F
.83839 1.32775 m .84775 1.34666 L .8362 1.34514 L .826 .793 0 r
F
.82669 1.32675 m .83839 1.32775 L .8362 1.34514 L .819 .787 0 r
F
.85009 1.32867 m .8593 1.3481 L .84775 1.34666 L .831 .798 0 r
F
.83839 1.32775 m .85009 1.32867 L .84775 1.34666 L .826 .793 0 r
F
.53998 1.24875 m .54677 1.24836 L .55135 1.251 L .259 .239 0 r
F
.53604 1.2466 m .54677 1.24836 L .53998 1.24875 L .249 .225 0 r
F
.49539 .98178 m .4943 .97999 L .51542 .97679 L .409 .23 0 r
F
.47568 .98662 m .4943 .97999 L .49539 .98178 L .401 .154 0 r
F
.50898 1.23481 m .51379 1.23357 L .51366 1.23658 L .196 .159 0 r
F
.50898 1.23481 m .50792 1.23134 L .51379 1.23357 L F
.85009 1.32867 m .8618 1.32953 L .8593 1.3481 L .831 .798 0 r
F
.47568 .98662 m .47337 .98586 L .4943 .97999 L .401 .154 0 r
F
.45636 .99518 m .47337 .98586 L .47568 .98662 L .469 .16 0 r
F
.5776 .97833 m .58134 .97473 L .60203 .97827 L .509 .637 0 r
F
.5573 .97623 m .58134 .97473 L .5776 .97833 L .494 .605 0 r
F
.60037 1.27108 m .61427 1.27777 L .60294 1.27526 L .39 .44 0 r
F
.58937 1.26897 m .60037 1.27108 L .60294 1.27526 L .37 .406 0 r
F
.39531 1.15563 m .39674 1.14067 L .40508 1.15325 L .648 .442 0 r
F
.39531 1.15563 m .38622 1.14523 L .39674 1.14067 L F
.62562 1.28008 m .63917 1.28823 L .62762 1.28546 L .438 .513 0 r
F
.61427 1.27777 m .62562 1.28008 L .62762 1.28546 L .417 .482 0 r
F
.47415 1.21689 m .47453 1.21336 L .48011 1.21864 L .128 .095 0 r
F
.47415 1.21689 m .46757 1.21101 L .47453 1.21336 L F
.46111 1.20921 m .46098 1.20492 L .46757 1.21101 L .127 .09 0 r
F
.46111 1.20921 m .4536 1.20249 L .46098 1.20492 L F
.74274 .98183 m .77166 .99225 L .76208 .99502 L .766 .8 0 r
F
.73388 .98505 m .74274 .98183 L .76208 .99502 L .754 .794 0 r
F
.57577 1.26356 m .58632 1.26531 L .58937 1.26897 L .341 .361 0 r
F
.57249 1.26041 m .58632 1.26531 L .57577 1.26356 L .331 .347 0 r
F
.25502 1.09488 m .25851 1.07316 L .26852 1.07804 L 1 .817 0 r
F
.25502 1.09488 m .24451 1.09057 L .25851 1.07316 L F
.53604 1.2466 m .54183 1.24576 L .54677 1.24836 L .249 .225 0 r
F
.53186 1.24448 m .54183 1.24576 L .53604 1.2466 L .239 .211 0 r
F
.6739 1.29538 m .68656 1.3062 L .67492 1.30349 L .581 .622 0 r
F
.66231 1.29319 m .6739 1.29538 L .67492 1.30349 L .551 .599 0 r
F
.51366 1.23658 m .51965 1.23587 L .51834 1.23845 L .203 .167 0 r
F
.51366 1.23658 m .51379 1.23357 L .51965 1.23587 L F
.38622 1.14523 m .38841 1.12786 L .39674 1.14067 L .798 .505 0 r
F
.38622 1.14523 m .37711 1.13492 L .38841 1.12786 L F
.58632 1.26531 m .60037 1.27108 L .58937 1.26897 L .361 .394 0 r
F
.55926 1.25634 m .56859 1.25724 L .57249 1.26041 L .302 .302 0 r
F
.55553 1.25367 m .56859 1.25724 L .55926 1.25634 L .291 .285 0 r
F
.49093 1.22547 m .49304 1.22304 L .49643 1.22726 L .149 .112 0 r
F
.49093 1.22547 m .48643 1.22072 L .49304 1.22304 L F
.4385 1.1933 m .43854 1.18722 L .44607 1.19524 L .185 .114 0 r
F
.4385 1.1933 m .43014 1.18487 L .43854 1.18722 L F
.3182 1.10572 m .32202 1.08501 L .33127 1.09184 L 1 .752 0 r
F
.3182 1.10572 m .30831 1.09962 L .32202 1.08501 L F
.53186 1.24448 m .5366 1.2432 L .54183 1.24576 L .239 .211 0 r
F
.52749 1.24241 m .5366 1.2432 L .53186 1.24448 L .229 .198 0 r
F
.51834 1.23845 m .52544 1.23825 L .52296 1.24039 L .211 .176 0 r
F
.51834 1.23845 m .51965 1.23587 L .52544 1.23825 L F
.37711 1.13492 m .38007 1.11557 L .38841 1.12786 L .916 .562 0 r
F
.37711 1.13492 m .36799 1.12501 L .38007 1.11557 L F
.52749 1.24241 m .53111 1.2407 L .5366 1.2432 L .229 .198 0 r
F
.52296 1.24039 m .53111 1.2407 L .52749 1.24241 L .22 .187 0 r
F
.52296 1.24039 m .52544 1.23825 L .53111 1.2407 L F
.63364 .97592 m .66109 .97908 L .65409 .98263 L .638 .744 0 r
F
.62766 .97963 m .63364 .97592 L .65409 .98263 L .611 .725 0 r
F
.41935 1.04101 m .43288 1.01171 L .43756 1.01122 L 1 1 0 r
F
.42503 1.0466 m .41935 1.04101 L .43756 1.01122 L F
.6739 1.29538 m .68551 1.29738 L .68656 1.3062 L .581 .622 0 r
F
.68551 1.29738 m .69821 1.30873 L .68656 1.3062 L .61 .642 0 r
F
.60203 .97827 m .60691 .97454 L .62766 .97963 L .565 .692 0 r
F
.58134 .97473 m .60691 .97454 L .60203 .97827 L .549 .679 0 r
F
.63699 1.28218 m .65073 1.29081 L .63917 1.28823 L .467 .543 0 r
F
.62562 1.28008 m .63699 1.28218 L .63917 1.28823 L .438 .513 0 r
F
.36799 1.12501 m .3717 1.10433 L .38007 1.11557 L 1 .612 0 r
F
.36799 1.12501 m .35885 1.11572 L .3717 1.10433 L F
.24451 1.09057 m .24848 1.06842 L .25851 1.07316 L 1 .826 0 r
F
.24451 1.09057 m .23398 1.08639 L .24848 1.06842 L F
.60691 .97454 m .63364 .97592 L .62766 .97963 L .598 .72 0 r
F
.6114 1.27297 m .62562 1.28008 L .61427 1.27777 L .41 .474 0 r
F
.60037 1.27108 m .6114 1.27297 L .61427 1.27777 L .39 .44 0 r
F
.30831 1.09962 m .31274 1.07859 L .32202 1.08501 L 1 .774 0 r
F
.30831 1.09962 m .2984 1.09384 L .31274 1.07859 L F
.55553 1.25367 m .56411 1.25409 L .56859 1.25724 L .291 .285 0 r
F
.55135 1.251 m .56411 1.25409 L .55553 1.25367 L .278 .266 0 r
F
.5573 .97623 m .55987 .97269 L .58134 .97473 L .494 .605 0 r
F
.53649 .97565 m .55987 .97269 L .5573 .97623 L .49 .562 0 r
F
.49643 1.22726 m .49988 1.22553 L .50212 1.22923 L .15 .114 0 r
F
.49643 1.22726 m .49304 1.22304 L .49988 1.22553 L F
.43014 1.18487 m .43101 1.17808 L .43854 1.18722 L .214 .122 0 r
F
.43014 1.18487 m .42177 1.17548 L .43101 1.17808 L F
.69712 1.2992 m .70987 1.31107 L .69821 1.30873 L .635 .661 0 r
F
.68551 1.29738 m .69712 1.2992 L .69821 1.30873 L .61 .642 0 r
F
.57249 1.26041 m .5825 1.26163 L .58632 1.26531 L .331 .347 0 r
F
.56859 1.25724 m .5825 1.26163 L .57249 1.26041 L .319 .329 0 r
F
.70473 .97724 m .73388 .98505 L .72505 .98818 L .733 .789 0 r
F
.69675 .98075 m .70473 .97724 L .72505 .98818 L .718 .78 0 r
F
.48011 1.21864 m .48191 1.21609 L .48643 1.22072 L .107 .09 0 r
F
.48011 1.21864 m .47453 1.21336 L .48191 1.21609 L F
.40858 1.08923 m .41935 1.04101 L .42503 1.0466 L 1 .614 0 r
F
.41496 1.11571 m .42503 1.0466 L .43032 1.08134 L 1 .513 0 r
F
.41496 1.11571 m .40858 1.08923 L .42503 1.0466 L F
.35885 1.11572 m .36329 1.09427 L .3717 1.10433 L 1 .659 0 r
F
.35885 1.11572 m .34969 1.10711 L .36329 1.09427 L F
.4536 1.20249 m .45437 1.19849 L .46098 1.20492 L .092 .08 0 r
F
.4536 1.20249 m .44607 1.19524 L .45437 1.19849 L F
.66811 .9754 m .69675 .98075 L .68878 .98415 L .692 .773 0 r
F
.66109 .97908 m .66811 .9754 L .68878 .98415 L .672 .76 0 r
F
.75162 .97853 m .78127 .98941 L .77166 .99225 L .777 .807 0 r
F
.74274 .98183 m .75162 .97853 L .77166 .99225 L .766 .8 0 r
F
.23398 1.08639 m .23842 1.06381 L .24848 1.06842 L 1 .834 0 r
F
.23398 1.08639 m .22343 1.08234 L .23842 1.06381 L F
.59689 1.26685 m .6114 1.27297 L .60037 1.27108 L .381 .428 0 r
F
.58632 1.26531 m .59689 1.26685 L .60037 1.27108 L .361 .394 0 r
F
.64838 1.28409 m .66231 1.29319 L .65073 1.29081 L .498 .57 0 r
F
.63699 1.28218 m .64838 1.28409 L .65073 1.29081 L .467 .543 0 r
F
.46757 1.21101 m .46894 1.20806 L .47453 1.21336 L .077 .083 0 r
F
.46757 1.21101 m .46098 1.20492 L .46894 1.20806 L F
.5825 1.26163 m .59689 1.26685 L .58632 1.26531 L .35 .378 0 r
F
.55135 1.251 m .55909 1.25097 L .56411 1.25409 L .278 .266 0 r
F
.54677 1.24836 m .55909 1.25097 L .55135 1.251 L .264 .246 0 r
F
.70875 1.30085 m .72154 1.31325 L .70987 1.31107 L .659 .678 0 r
F
.69712 1.2992 m .70875 1.30085 L .70987 1.31107 L .635 .661 0 r
F
.2984 1.09384 m .30344 1.07253 L .31274 1.07859 L 1 .793 0 r
F
.2984 1.09384 m .28846 1.08835 L .30344 1.07253 L F
.50212 1.22923 m .50686 1.22812 L .50792 1.23134 L .155 .118 0 r
F
.50212 1.22923 m .49988 1.22553 L .50686 1.22812 L F
.42177 1.17548 m .42348 1.1673 L .43101 1.17808 L .275 .157 0 r
F
.42177 1.17548 m .41342 1.16495 L .42348 1.1673 L F
.34969 1.10711 m .35485 1.08529 L .36329 1.09427 L 1 .7 0 r
F
.34969 1.10711 m .3405 1.09918 L .35485 1.08529 L F
.53649 .97565 m .53785 .9723 L .55987 .97269 L .49 .562 0 r
F
.51542 .97679 m .53785 .9723 L .53649 .97565 L .489 .505 0 r
F
.62245 1.27466 m .63699 1.28218 L .62562 1.28008 L .428 .505 0 r
F
.6114 1.27297 m .62245 1.27466 L .62562 1.28008 L .41 .474 0 r
F
.72039 1.30234 m .73321 1.31526 L .72154 1.31325 L .68 .693 0 r
F
.70875 1.30085 m .72039 1.30234 L .72154 1.31325 L .659 .678 0 r
F
.54677 1.24836 m .55358 1.24791 L .55909 1.25097 L .264 .246 0 r
F
.54183 1.24576 m .55358 1.24791 L .54677 1.24836 L .25 .225 0 r
F
.56859 1.25724 m .57795 1.25796 L .5825 1.26163 L .319 .329 0 r
F
.56411 1.25409 m .57795 1.25796 L .56859 1.25724 L .305 .307 0 r
F
.41342 1.16495 m .41598 1.15424 L .42348 1.1673 L .369 .234 0 r
F
.41342 1.16495 m .40508 1.15325 L .41598 1.15424 L F
.22343 1.08234 m .22834 1.05931 L .23842 1.06381 L 1 .84 0 r
F
.22343 1.08234 m .21286 1.07838 L .22834 1.05931 L F
.58134 .97473 m .58509 .97091 L .60691 .97454 L .549 .679 0 r
F
.55987 .97269 m .58509 .97091 L .58134 .97473 L .536 .662 0 r
F
.50792 1.23134 m .51391 1.23079 L .51379 1.23357 L .165 .126 0 r
F
.50792 1.23134 m .50686 1.22812 L .51391 1.23079 L F
.48643 1.22072 m .48964 1.21905 L .49304 1.22304 L .098 .091 0 r
F
.48643 1.22072 m .48191 1.21609 L .48964 1.21905 L F
.65979 1.28579 m .6739 1.29538 L .66231 1.29319 L .528 .595 0 r
F
.64838 1.28409 m .65979 1.28579 L .66231 1.29319 L .498 .57 0 r
F
.51542 .97679 m .51555 .97379 L .53785 .9723 L .489 .505 0 r
F
.4943 .97999 m .51555 .97379 L .51542 .97679 L .5 .444 0 r
F
.3405 1.09918 m .34638 1.07719 L .35485 1.08529 L 1 .736 0 r
F
.3405 1.09918 m .33127 1.09184 L .34638 1.07719 L F
.44607 1.19524 m .44775 1.19155 L .45437 1.19849 L .057 .071 0 r
F
.44607 1.19524 m .43854 1.18722 L .44775 1.19155 L F
.28846 1.08835 m .2941 1.06674 L .30344 1.07253 L 1 .809 0 r
F
.28846 1.08835 m .2785 1.08309 L .2941 1.06674 L F
.73204 1.30368 m .74488 1.31712 L .73321 1.31526 L .698 .707 0 r
F
.72039 1.30234 m .73204 1.30368 L .73321 1.31526 L .68 .693 0 r
F
.63964 .97206 m .66811 .9754 L .66109 .97908 L .663 .761 0 r
F
.63364 .97592 m .63964 .97206 L .66109 .97908 L .638 .744 0 r
F
.40508 1.15325 m .40851 1.13861 L .41598 1.15424 L .571 .342 0 r
F
.40508 1.15325 m .39674 1.14067 L .40851 1.13861 L F
.54183 1.24576 m .54765 1.2449 L .55358 1.24791 L .25 .225 0 r
F
.5366 1.2432 m .54765 1.2449 L .54183 1.24576 L .235 .204 0 r
F
.4943 .97999 m .4932 .97751 L .51555 .97379 L .5 .444 0 r
F
.47337 .98586 m .4932 .97751 L .4943 .97999 L .542 .42 0 r
F
.51379 1.23357 m .52097 1.2335 L .51965 1.23587 L .176 .137 0 r
F
.51379 1.23357 m .51391 1.23079 L .52097 1.2335 L F
.39674 1.14067 m .40107 1.12143 L .40851 1.13861 L .823 .447 0 r
F
.39674 1.14067 m .38841 1.12786 L .40107 1.12143 L F
.47337 .98586 m .47104 .98402 L .4932 .97751 L .542 .42 0 r
F
.45283 .99566 m .47104 .98402 L .47337 .98586 L .665 .575 0 r
F
.38841 1.12786 m .39363 1.10501 L .40107 1.12143 L 1 .529 0 r
F
.38841 1.12786 m .38007 1.11557 L .39363 1.10501 L F
.71275 .97364 m .74274 .98183 L .73388 .98505 L .747 .797 0 r
F
.70473 .97724 m .71275 .97364 L .73388 .98505 L .733 .789 0 r
F
.6075 1.26817 m .62245 1.27466 L .6114 1.27297 L .4 .461 0 r
F
.59689 1.26685 m .6075 1.26817 L .6114 1.27297 L .381 .428 0 r
F
.5366 1.2432 m .54135 1.24196 L .54765 1.2449 L .235 .204 0 r
F
.53111 1.2407 m .54135 1.24196 L .5366 1.2432 L .219 .185 0 r
F
.76052 .97515 m .79091 .9865 L .78127 .98941 L .787 .812 0 r
F
.75162 .97853 m .76052 .97515 L .78127 .98941 L .777 .807 0 r
F
.5825 1.26163 m .59254 1.26264 L .59689 1.26685 L .35 .378 0 r
F
.57795 1.25796 m .59254 1.26264 L .5825 1.26163 L .337 .358 0 r
F
.74369 1.30488 m .75656 1.31884 L .74488 1.31712 L .715 .72 0 r
F
.73204 1.30368 m .74369 1.30488 L .74488 1.31712 L .698 .707 0 r
F
.51965 1.23587 m .52794 1.23627 L .52544 1.23825 L .19 .151 0 r
F
.51965 1.23587 m .52097 1.2335 L .52794 1.23627 L F
.60691 .97454 m .61182 .97062 L .63364 .97592 L .598 .72 0 r
F
.58509 .97091 m .61182 .97062 L .60691 .97454 L .588 .715 0 r
F
.45283 .99566 m .44931 .9943 L .47104 .98402 L .665 .575 0 r
F
.43288 1.01171 m .44931 .9943 L .45283 .99566 L 1 1 0 r
F
.21286 1.07838 m .21824 1.05489 L .22834 1.05931 L 1 .846 0 r
F
.21286 1.07838 m .20226 1.07451 L .21824 1.05489 L F
.38007 1.11557 m .38614 1.09098 L .39363 1.10501 L 1 .597 0 r
F
.38007 1.11557 m .3717 1.10433 L .38614 1.09098 L F
.53111 1.2407 m .53476 1.23909 L .54135 1.24196 L .219 .185 0 r
F
.52544 1.23825 m .53476 1.23909 L .53111 1.2407 L .204 .167 0 r
F
.61182 .97062 m .63964 .97206 L .63364 .97592 L .63 .744 0 r
F
.41935 1.04101 m .41366 1.0354 L .43288 1.01171 L 1 1 0 r
F
.47453 1.21336 m .47738 1.21165 L .48191 1.21609 L .042 .082 0 r
F
.47453 1.21336 m .46894 1.20806 L .47738 1.21165 L F
.40207 1.07192 m .41366 1.0354 L .41935 1.04101 L 1 .747 0 r
F
.40858 1.08923 m .40207 1.07192 L .41935 1.04101 L 1 .614 0 r
F
.52544 1.23825 m .52794 1.23627 L .53476 1.23909 L .204 .167 0 r
F
.63352 1.27614 m .64838 1.28409 L .63699 1.28218 L .449 .535 0 r
F
.62245 1.27466 m .63352 1.27614 L .63699 1.28218 L .428 .505 0 r
F
.67122 1.2873 m .68551 1.29738 L .6739 1.29538 L .556 .617 0 r
F
.65979 1.28579 m .67122 1.2873 L .6739 1.29538 L .528 .595 0 r
F
.56411 1.25409 m .57272 1.25435 L .57795 1.25796 L .305 .307 0 r
F
.55909 1.25097 m .57272 1.25435 L .56411 1.25409 L .29 .283 0 r
F
.46098 1.20492 m .46332 1.20275 L .46894 1.20806 L .01 .073 0 r
F
.46098 1.20492 m .45437 1.19849 L .46332 1.20275 L F
.59254 1.26264 m .6075 1.26817 L .59689 1.26685 L .369 .411 0 r
F
.67515 .9716 m .70473 .97724 L .69675 .98075 L .71 .784 0 r
F
.66811 .9754 m .67515 .9716 L .69675 .98075 L .692 .773 0 r
F
.33127 1.09184 m .33787 1.06978 L .34638 1.07719 L 1 .767 0 r
F
.33127 1.09184 m .32202 1.08501 L .33787 1.06978 L F
.49304 1.22304 m .49763 1.22212 L .49988 1.22553 L .099 .093 0 r
F
.49304 1.22304 m .48964 1.21905 L .49763 1.22212 L F
.75536 1.30595 m .76824 1.32043 L .75656 1.31884 L .73 .731 0 r
F
.74369 1.30488 m .75536 1.30595 L .75656 1.31884 L .715 .72 0 r
F
.2785 1.08309 m .28474 1.06118 L .2941 1.06674 L 1 .823 0 r
F
.2785 1.08309 m .26852 1.07804 L .28474 1.06118 L F
.3717 1.10433 m .37859 1.07939 L .38614 1.09098 L 1 .658 0 r
F
.3717 1.10433 m .36329 1.09427 L .37859 1.07939 L F
.55987 .97269 m .56244 .96888 L .58509 .97091 L .536 .662 0 r
F
.53785 .9723 m .56244 .96888 L .55987 .97269 L .53 .643 0 r
F
.43854 1.18722 m .44112 1.18376 L .44775 1.19155 L .033 .062 0 r
F
.43854 1.18722 m .43101 1.17808 L .44112 1.18376 L F
.43288 1.01171 m .42821 1.00957 L .44931 .9943 L 1 1 0 r
F
.41366 1.0354 m .42821 1.00957 L .43288 1.01171 L F
.76703 1.30689 m .77992 1.3219 L .76824 1.32043 L .743 .742 0 r
F
.75536 1.30595 m .76703 1.30689 L .76824 1.32043 L .73 .731 0 r
F
.67122 1.2873 m .68266 1.28863 L .68551 1.29738 L .556 .617 0 r
F
.68266 1.28863 m .69712 1.2992 L .68551 1.29738 L .583 .638 0 r
F
.55909 1.25097 m .56686 1.25081 L .57272 1.25435 L .29 .283 0 r
F
.55358 1.24791 m .56686 1.25081 L .55909 1.25097 L .272 .256 0 r
F
.36329 1.09427 m .371 1.06965 L .37859 1.07939 L 1 .712 0 r
F
.36329 1.09427 m .35485 1.08529 L .371 1.06965 L F
.77872 1.30773 m .79161 1.32326 L .77992 1.3219 L .755 .751 0 r
F
.76703 1.30689 m .77872 1.30773 L .77992 1.3219 L .743 .742 0 r
F
.32202 1.08501 m .32933 1.0629 L .33787 1.06978 L 1 .793 0 r
F
.32202 1.08501 m .31274 1.07859 L .32933 1.0629 L F
.64462 1.27741 m .65979 1.28579 L .64838 1.28409 L .477 .562 0 r
F
.63352 1.27614 m .64462 1.27741 L .64838 1.28409 L .449 .535 0 r
F
.57795 1.25796 m .58735 1.25848 L .59254 1.26264 L .337 .358 0 r
F
.57272 1.25435 m .58735 1.25848 L .57795 1.25796 L .322 .333 0 r
F
.61813 1.26928 m .63352 1.27614 L .62245 1.27466 L .418 .493 0 r
F
.6075 1.26817 m .61813 1.26928 L .62245 1.27466 L .4 .461 0 r
F
.49988 1.22553 m .50579 1.22522 L .50686 1.22812 L .108 .096 0 r
F
.49988 1.22553 m .49763 1.22212 L .50579 1.22522 L F
.26852 1.07804 m .27535 1.05581 L .28474 1.06118 L 1 .834 0 r
F
.26852 1.07804 m .25851 1.07316 L .27535 1.05581 L F
.76052 .97515 m .76945 .97171 L .79091 .9865 L .787 .812 0 r
F
.79041 1.30845 m .8033 1.32452 L .79161 1.32326 L .766 .76 0 r
F
.77872 1.30773 m .79041 1.30845 L .79161 1.32326 L .755 .751 0 r
F
.48191 1.21609 m .48622 1.21542 L .48964 1.21905 L .027 .084 0 r
F
.48191 1.21609 m .47738 1.21165 L .48622 1.21542 L F
.53785 .9723 m .53922 .96862 L .56244 .96888 L .53 .643 0 r
F
.51555 .97379 m .53922 .96862 L .53785 .9723 L .536 .626 0 r
F
.72078 .96994 m .75162 .97853 L .74274 .98183 L .76 .805 0 r
F
.71275 .97364 m .72078 .96994 L .74274 .98183 L .747 .797 0 r
F
.43101 1.17808 m .43448 1.17445 L .44112 1.18376 L .044 .055 0 r
F
.43101 1.17808 m .42348 1.1673 L .43448 1.17445 L F
.64566 .96806 m .67515 .9716 L .66811 .9754 L .686 .776 0 r
F
.63964 .97206 m .64566 .96806 L .66811 .9754 L .663 .761 0 r
F
.69412 1.28979 m .70875 1.30085 L .69712 1.2992 L .608 .657 0 r
F
.68266 1.28863 m .69412 1.28979 L .69712 1.2992 L .583 .638 0 r
F
.55358 1.24791 m .56043 1.24735 L .56686 1.25081 L .272 .256 0 r
F
.54765 1.2449 m .56043 1.24735 L .55358 1.24791 L .253 .228 0 r
F
.59254 1.26264 m .60261 1.26343 L .6075 1.26817 L .369 .411 0 r
F
.58735 1.25848 m .60261 1.26343 L .59254 1.26264 L .356 .389 0 r
F
.60261 1.26343 m .61813 1.26928 L .6075 1.26817 L .388 .444 0 r
F
.58509 .97091 m .58886 .96687 L .61182 .97062 L .588 .715 0 r
F
.56244 .96888 m .58886 .96687 L .58509 .97091 L .583 .71 0 r
F
.45437 1.19849 m .45768 1.19741 L .46332 1.20275 L 0 .059 0 r
F
.45437 1.19849 m .44775 1.19155 L .45768 1.19741 L F
.80211 1.30909 m .81499 1.32568 L .8033 1.32452 L .776 .768 0 r
F
.79041 1.30845 m .80211 1.30909 L .8033 1.32452 L .766 .76 0 r
F
.35485 1.08529 m .36337 1.06119 L .371 1.06965 L 1 .758 0 r
F
.35485 1.08529 m .34638 1.07719 L .36337 1.06119 L F
.39363 1.10501 m .40207 1.07192 L .40858 1.08923 L 1 .592 0 r
F
.39363 1.10501 m .38614 1.09098 L .40207 1.07192 L F
.40107 1.12143 m .39363 1.10501 L .40858 1.08923 L 1 .504 0 r
F
.50686 1.22812 m .51404 1.2283 L .51391 1.23079 L .124 .1 0 r
F
.50686 1.22812 m .50579 1.22522 L .51404 1.2283 L F
.41366 1.0354 m .40794 1.02977 L .42821 1.00957 L 1 1 0 r
F
.46894 1.20806 m .47282 1.20751 L .47738 1.21165 L 0 .071 0 r
F
.46894 1.20806 m .46332 1.20275 L .47282 1.20751 L F
.39545 1.06019 m .40794 1.02977 L .41366 1.0354 L 1 .844 0 r
F
.40207 1.07192 m .39545 1.06019 L .41366 1.0354 L 1 .747 0 r
F
.31274 1.07859 m .32076 1.05642 L .32933 1.0629 L 1 .815 0 r
F
.31274 1.07859 m .30344 1.07253 L .32076 1.05642 L F
.38614 1.09098 m .39545 1.06019 L .40207 1.07192 L 1 .674 0 r
F
.38614 1.09098 m .37859 1.07939 L .39545 1.06019 L F
.81382 1.30963 m .82669 1.32675 L .81499 1.32568 L .784 .775 0 r
F
.80211 1.30909 m .81382 1.30963 L .81499 1.32568 L .776 .768 0 r
F
.68223 .96768 m .71275 .97364 L .70473 .97724 L .727 .794 0 r
F
.67515 .9716 m .68223 .96768 L .70473 .97724 L .71 .784 0 r
F
.40107 1.12143 m .40858 1.08923 L .41496 1.11571 L 1 .504 0 r
F
.40851 1.13861 m .40107 1.12143 L .41496 1.11571 L .842 .363 0 r
F
.51555 .97379 m .51568 .97036 L .53922 .96862 L .536 .626 0 r
F
.4932 .97751 m .51568 .97036 L .51555 .97379 L .566 .627 0 r
F
.65574 1.27848 m .67122 1.2873 L .65979 1.28579 L .504 .587 0 r
F
.64462 1.27741 m .65574 1.27848 L .65979 1.28579 L .477 .562 0 r
F
.54765 1.2449 m .5535 1.244 L .56043 1.24735 L .253 .228 0 r
F
.54135 1.24196 m .5535 1.244 L .54765 1.2449 L .232 .199 0 r
F
.25851 1.07316 m .26594 1.0506 L .27535 1.05581 L 1 .843 0 r
F
.25851 1.07316 m .24848 1.06842 L .26594 1.0506 L F
.42788 1.16211 m .42135 1.14344 L .4252 1.15263 L 0 0 0 r
F
.43066 1.17197 m .42788 1.16211 L .43448 1.17445 L .133 .056 0 r
F
.44112 1.18376 m .43448 1.17445 L .44634 1.18668 L 0 .015 0 r
F
.43448 1.17445 m .44064 1.18129 L .44634 1.18668 L 0 0 0 r
F
.43448 1.17445 m .42788 1.16211 L .44064 1.18129 L F
.42788 1.16211 m .43492 1.17587 L .44064 1.18129 L F
.42788 1.16211 m .4252 1.15263 L .43492 1.17587 L F
.42348 1.1673 m .42788 1.16211 L .43066 1.17197 L .133 .056 0 r
F
.42348 1.1673 m .41598 1.15424 L .42788 1.16211 L F
.61674 .96653 m .64566 .96806 L .63964 .97206 L .658 .765 0 r
F
.61182 .97062 m .61674 .96653 L .63964 .97206 L .63 .744 0 r
F
.57272 1.25435 m .58137 1.25442 L .58735 1.25848 L .322 .333 0 r
F
.56686 1.25081 m .58137 1.25442 L .57272 1.25435 L .303 .304 0 r
F
.58886 .96687 m .61674 .96653 L .61182 .97062 L .625 .745 0 r
F
.7056 1.29078 m .72039 1.30234 L .70875 1.30085 L .63 .673 0 r
F
.69412 1.28979 m .7056 1.29078 L .70875 1.30085 L .608 .657 0 r
F
.82553 1.3101 m .83839 1.32775 L .82669 1.32675 L .792 .781 0 r
F
.81382 1.30963 m .82553 1.3101 L .82669 1.32675 L .784 .775 0 r
F
.51391 1.23079 m .52229 1.23137 L .52097 1.2335 L .143 .108 0 r
F
.51391 1.23079 m .51404 1.2283 L .52229 1.23137 L F
.40851 1.13861 m .41496 1.11571 L .42135 1.14344 L .842 .363 0 r
F
.41598 1.15424 m .40851 1.13861 L .42135 1.14344 L .343 .12 0 r
F
.62879 1.27017 m .64462 1.27741 L .63352 1.27614 L .435 .523 0 r
F
.61813 1.26928 m .62879 1.27017 L .63352 1.27614 L .418 .493 0 r
F
.4932 .97751 m .49209 .97442 L .51568 .97036 L .566 .627 0 r
F
.47104 .98402 m .49209 .97442 L .4932 .97751 L .657 .692 0 r
F
.41598 1.15424 m .42135 1.14344 L .42788 1.16211 L .343 .12 0 r
F
.54135 1.24196 m .54614 1.24074 L .5535 1.244 L .232 .199 0 r
F
.53476 1.23909 m .54614 1.24074 L .54135 1.24196 L .21 .171 0 r
F
.37859 1.07939 m .38877 1.05109 L .39545 1.06019 L 1 .747 0 r
F
.37859 1.07939 m .371 1.06965 L .38877 1.05109 L F
.83726 1.31049 m .85009 1.32867 L .83839 1.32775 L .799 .787 0 r
F
.82553 1.3101 m .83726 1.31049 L .83839 1.32775 L .792 .781 0 r
F
.47104 .98402 m .46871 .9813 L .49209 .97442 L .657 .692 0 r
F
.44931 .9943 m .46871 .9813 L .47104 .98402 L .91 .892 0 r
F
.52097 1.2335 m .53045 1.23445 L .52794 1.23627 L .165 .124 0 r
F
.52097 1.2335 m .52229 1.23137 L .53045 1.23445 L F
.48964 1.21905 m .49536 1.21914 L .49763 1.22212 L .03 .087 0 r
F
.48964 1.21905 m .48622 1.21542 L .49536 1.21914 L F
.34638 1.07719 m .35569 1.05359 L .36337 1.06119 L 1 .795 0 r
F
.34638 1.07719 m .33787 1.06978 L .35569 1.05359 L F
.53476 1.23909 m .53843 1.23756 L .54614 1.24074 L .21 .171 0 r
F
.52794 1.23627 m .53843 1.23756 L .53476 1.23909 L .187 .145 0 r
F
.52794 1.23627 m .53045 1.23445 L .53843 1.23756 L F
.44931 .9943 m .44578 .99165 L .46871 .9813 L .91 .892 0 r
F
.42821 1.00957 m .44578 .99165 L .44931 .9943 L 1 1 0 r
F
.84899 1.3108 m .8618 1.32953 L .85009 1.32867 L .806 .793 0 r
F
.83726 1.31049 m .84899 1.3108 L .85009 1.32867 L .799 .787 0 r
F
.71709 1.29161 m .73204 1.30368 L .72039 1.30234 L .651 .689 0 r
F
.7056 1.29078 m .71709 1.29161 L .72039 1.30234 L .63 .673 0 r
F
.39545 1.06019 m .38877 1.05109 L .40794 1.02977 L 1 .844 0 r
F
.30344 1.07253 m .31216 1.05026 L .32076 1.05642 L 1 .832 0 r
F
.30344 1.07253 m .2941 1.06674 L .31216 1.05026 L F
.56244 .96888 m .56503 .96481 L .58886 .96687 L .583 .71 0 r
F
.53922 .96862 m .56503 .96481 L .56244 .96888 L .588 .709 0 r
F
.58735 1.25848 m .59677 1.25879 L .60261 1.26343 L .356 .389 0 r
F
.58137 1.25442 m .59677 1.25879 L .58735 1.25848 L .339 .362 0 r
F
.24848 1.06842 m .25649 1.04551 L .26594 1.0506 L 1 .851 0 r
F
.24848 1.06842 m .23842 1.06381 L .25649 1.04551 L F
.84899 1.3108 m .86072 1.31106 L .8618 1.32953 L .806 .793 0 r
F
.66688 1.27936 m .68266 1.28863 L .67122 1.2873 L .532 .61 0 r
F
.65574 1.27848 m .66688 1.27936 L .67122 1.2873 L .504 .587 0 r
F
.72885 .96616 m .76052 .97515 L .75162 .97853 L .771 .811 0 r
F
.72078 .96994 m .72885 .96616 L .75162 .97853 L .76 .805 0 r
F
.44775 1.19155 m .45202 1.19206 L .45768 1.19741 L 0 .04 0 r
F
.44775 1.19155 m .44112 1.18376 L .45202 1.19206 L F
.61271 1.264 m .62879 1.27017 L .61813 1.26928 L .406 .476 0 r
F
.60261 1.26343 m .61271 1.264 L .61813 1.26928 L .388 .444 0 r
F
.42821 1.00957 m .42353 1.00609 L .44578 .99165 L 1 1 0 r
F
.40794 1.02977 m .42353 1.00609 L .42821 1.00957 L F
.56686 1.25081 m .57467 1.25048 L .58137 1.25442 L .303 .304 0 r
F
.56043 1.24735 m .57467 1.25048 L .56686 1.25081 L .283 .271 0 r
F
.371 1.06965 m .38205 1.04331 L .38877 1.05109 L 1 .805 0 r
F
.371 1.06965 m .36337 1.06119 L .38205 1.04331 L F
.59677 1.25879 m .61271 1.264 L .60261 1.26343 L .374 .421 0 r
F
.6517 .96392 m .68223 .96768 L .67515 .9716 L .707 .789 0 r
F
.64566 .96806 m .6517 .96392 L .67515 .9716 L .686 .776 0 r
F
.72859 1.2923 m .74369 1.30488 L .73204 1.30368 L .67 .703 0 r
F
.71709 1.29161 m .72859 1.2923 L .73204 1.30368 L .651 .689 0 r
F
.47738 1.21165 m .48278 1.21228 L .48622 1.21542 L 0 .073 0 r
F
.47738 1.21165 m .47282 1.20751 L .48278 1.21228 L F
.63948 1.27086 m .65574 1.27848 L .64462 1.27741 L .456 .551 0 r
F
.62879 1.27017 m .63948 1.27086 L .64462 1.27741 L .435 .523 0 r
F
.49763 1.22212 m .50471 1.22273 L .50579 1.22522 L .046 .092 0 r
F
.49763 1.22212 m .49536 1.21914 L .50471 1.22273 L F
.33787 1.06978 m .34799 1.04658 L .35569 1.05359 L 1 .825 0 r
F
.33787 1.06978 m .32933 1.0629 L .34799 1.04658 L F
.46332 1.20275 m .46824 1.20385 L .47282 1.20751 L 0 .054 0 r
F
.46332 1.20275 m .45768 1.19741 L .46824 1.20385 L F
.40794 1.02977 m .4022 1.02412 L .42353 1.00609 L 1 1 0 r
F
.38877 1.05109 m .4022 1.02412 L .40794 1.02977 L 1 .905 0 r
F
.68932 .96366 m .72078 .96994 L .71275 .97364 L .743 .803 0 r
F
.68223 .96768 m .68932 .96366 L .71275 .97364 L .727 .794 0 r
F
.2941 1.06674 m .30353 1.04434 L .31216 1.05026 L 1 .846 0 r
F
.2941 1.06674 m .28474 1.06118 L .30353 1.04434 L F
.42135 1.14344 m .41496 1.11571 L .42956 1.14047 L .133 .026 0 r
F
.56043 1.24735 m .56731 1.24668 L .57467 1.25048 L .283 .271 0 r
F
.5535 1.244 m .56731 1.24668 L .56043 1.24735 L .259 .235 0 r
F
.53922 .96862 m .54059 .96462 L .56503 .96481 L .588 .709 0 r
F
.51568 .97036 m .54059 .96462 L .53922 .96862 L .61 .719 0 r
F
.66688 1.27936 m .67805 1.28005 L .68266 1.28863 L .532 .61 0 r
F
.67805 1.28005 m .69412 1.28979 L .68266 1.28863 L .557 .631 0 r
F
.23842 1.06381 m .24703 1.04053 L .25649 1.04551 L 1 .858 0 r
F
.23842 1.06381 m .22834 1.05931 L .24703 1.04053 L F
.58886 .96687 m .59265 .96263 L .61674 .96653 L .625 .745 0 r
F
.56503 .96481 m .59265 .96263 L .58886 .96687 L .628 .749 0 r
F
.38877 1.05109 m .38205 1.04331 L .4022 1.02412 L 1 .905 0 r
F
.74011 1.29285 m .75536 1.30595 L .74369 1.30488 L .687 .715 0 r
F
.72859 1.2923 m .74011 1.29285 L .74369 1.30488 L .67 .703 0 r
F
.62169 .96228 m .6517 .96392 L .64566 .96806 L .684 .782 0 r
F
.61674 .96653 m .62169 .96228 L .64566 .96806 L .658 .765 0 r
F
.58137 1.25442 m .59005 1.25429 L .59677 1.25879 L .339 .362 0 r
F
.57467 1.25048 m .59005 1.25429 L .58137 1.25442 L .319 .329 0 r
F
.50579 1.22522 m .51417 1.22616 L .51404 1.2283 L .072 .097 0 r
F
.50579 1.22522 m .50471 1.22273 L .51417 1.22616 L F
.36337 1.06119 m .3753 1.03627 L .38205 1.04331 L 1 .848 0 r
F
.36337 1.06119 m .35569 1.05359 L .3753 1.03627 L F
.44112 1.18376 m .44634 1.18668 L .45202 1.19206 L 0 .015 0 r
F
.59265 .96263 m .62169 .96228 L .61674 .96653 L .659 .77 0 r
F
.62284 1.26436 m .63948 1.27086 L .62879 1.27017 L .423 .506 0 r
F
.61271 1.264 m .62284 1.26436 L .62879 1.27017 L .406 .476 0 r
F
.5535 1.244 m .55937 1.24303 L .56731 1.24668 L .259 .235 0 r
F
.54614 1.24074 m .55937 1.24303 L .5535 1.244 L .232 .197 0 r
F
.51568 .97036 m .51581 .96653 L .54059 .96462 L .61 .719 0 r
F
.49209 .97442 m .51581 .96653 L .51568 .97036 L .667 .755 0 r
F
.32933 1.0629 m .34025 1.03998 L .34799 1.04658 L 1 .848 0 r
F
.32933 1.0629 m .32076 1.05642 L .34025 1.03998 L F
.75165 1.29328 m .76703 1.30689 L .75536 1.30595 L .702 .727 0 r
F
.74011 1.29285 m .75165 1.29328 L .75536 1.30595 L .687 .715 0 r
F
.73694 .9623 m .76945 .97171 L .76052 .97515 L .782 .817 0 r
F
.72885 .96616 m .73694 .9623 L .76052 .97515 L .771 .811 0 r
F
.65019 1.27134 m .66688 1.27936 L .65574 1.27848 L .481 .577 0 r
F
.63948 1.27086 m .65019 1.27134 L .65574 1.27848 L .456 .551 0 r
F
.68923 1.28058 m .7056 1.29078 L .69412 1.28979 L .581 .65 0 r
F
.67805 1.28005 m .68923 1.28058 L .69412 1.28979 L .557 .631 0 r
F
.59677 1.25879 m .60623 1.25888 L .61271 1.264 L .374 .421 0 r
F
.59005 1.25429 m .60623 1.25888 L .59677 1.25879 L .357 .392 0 r
F
.51404 1.2283 m .52362 1.2295 L .52229 1.23137 L .104 .101 0 r
F
.51404 1.2283 m .51417 1.22616 L .52362 1.2295 L F
.22834 1.05931 m .23754 1.03564 L .24703 1.04053 L 1 .863 0 r
F
.22834 1.05931 m .21824 1.05489 L .23754 1.03564 L F
.48622 1.21542 m .49309 1.21672 L .49536 1.21914 L 0 .078 0 r
F
.48622 1.21542 m .48278 1.21228 L .49309 1.21672 L F
.28474 1.06118 m .29487 1.03861 L .30353 1.04434 L 1 .857 0 r
F
.28474 1.06118 m .27535 1.05581 L .29487 1.03861 L F
.60623 1.25888 m .62284 1.26436 L .61271 1.264 L .392 .453 0 r
F
.49209 .97442 m .49098 .97081 L .51581 .96653 L .667 .755 0 r
F
.46871 .9813 m .49098 .97081 L .49209 .97442 L .795 .848 0 r
F
.54614 1.24074 m .55094 1.23951 L .55937 1.24303 L .232 .197 0 r
F
.53843 1.23756 m .55094 1.23951 L .54614 1.24074 L .203 .159 0 r
F
.46871 .9813 m .46637 .97786 L .49098 .97081 L .795 .848 0 r
F
.44578 .99165 m .46637 .97786 L .46871 .9813 L 1 1 0 r
F
.76319 1.2936 m .77872 1.30773 L .76703 1.30689 L .716 .737 0 r
F
.75165 1.29328 m .76319 1.2936 L .76703 1.30689 L .702 .727 0 r
F
.52229 1.23137 m .53297 1.23279 L .53045 1.23445 L .137 .105 0 r
F
.52229 1.23137 m .52362 1.2295 L .53297 1.23279 L F
.53843 1.23756 m .54211 1.23611 L .55094 1.23951 L .203 .159 0 r
F
.53045 1.23445 m .54211 1.23611 L .53843 1.23756 L .171 .126 0 r
F
.44578 .99165 m .44224 .98812 L .46637 .97786 L 1 1 0 r
F
.42353 1.00609 m .44224 .98812 L .44578 .99165 L F
.38205 1.04331 m .39644 1.01845 L .4022 1.02412 L 1 .941 0 r
F
.38205 1.04331 m .3753 1.03627 L .39644 1.01845 L F
.57467 1.25048 m .5825 1.24998 L .59005 1.25429 L .319 .329 0 r
F
.56731 1.24668 m .5825 1.24998 L .57467 1.25048 L .296 .29 0 r
F
.53045 1.23445 m .53297 1.23279 L .54211 1.23611 L .171 .126 0 r
F
.65777 .95967 m .68932 .96366 L .68223 .96768 L .726 .8 0 r
F
.6517 .96392 m .65777 .95967 L .68223 .96768 L .707 .789 0 r
F
.56503 .96481 m .56763 .96051 L .59265 .96263 L .628 .749 0 r
F
.54059 .96462 m .56763 .96051 L .56503 .96481 L .643 .76 0 r
F
.42353 1.00609 m .41884 1.00185 L .44224 .98812 L 1 1 0 r
F
.4022 1.02412 m .41884 1.00185 L .42353 1.00609 L F
.35569 1.05359 m .36852 1.02966 L .3753 1.03627 L 1 .878 0 r
F
.35569 1.05359 m .34799 1.04658 L .36852 1.02966 L F
.69644 .95955 m .72885 .96616 L .72078 .96994 L .757 .811 0 r
F
.68932 .96366 m .69644 .95955 L .72078 .96994 L .743 .803 0 r
F
.45768 1.19741 m .46363 1.20101 L .46824 1.20385 L 0 .029 0 r
F
.45768 1.19741 m .45202 1.19206 L .46363 1.20101 L F
.4022 1.02412 m .39644 1.01845 L .41884 1.00185 L 1 1 0 r
F
.47282 1.20751 m .47932 1.20989 L .48278 1.21228 L 0 .056 0 r
F
.47282 1.20751 m .46824 1.20385 L .47932 1.20989 L F
.42135 1.14344 m .42956 1.14047 L .43492 1.17587 L .133 .026 0 r
F
.70043 1.28094 m .71709 1.29161 L .7056 1.29078 L .603 .668 0 r
F
.68923 1.28058 m .70043 1.28094 L .7056 1.29078 L .581 .65 0 r
F
.77475 1.2938 m .79041 1.30845 L .77872 1.30773 L .728 .747 0 r
F
.76319 1.2936 m .77475 1.2938 L .77872 1.30773 L .716 .737 0 r
F
.32076 1.05642 m .33249 1.03368 L .34025 1.03998 L 1 .866 0 r
F
.32076 1.05642 m .31216 1.05026 L .33249 1.03368 L F
.66093 1.27163 m .67805 1.28005 L .66688 1.27936 L .507 .601 0 r
F
.65019 1.27134 m .66093 1.27163 L .66688 1.27936 L .481 .577 0 r
F
.633 1.26451 m .65019 1.27134 L .63948 1.27086 L .439 .535 0 r
F
.62284 1.26436 m .633 1.26451 L .63948 1.27086 L .423 .506 0 r
F
.27535 1.05581 m .28619 1.03303 L .29487 1.03861 L 1 .866 0 r
F
.27535 1.05581 m .26594 1.0506 L .28619 1.03303 L F
.49536 1.21914 m .50363 1.22075 L .50471 1.22273 L 0 .085 0 r
F
.49536 1.21914 m .49309 1.21672 L .50363 1.22075 L F
.73694 .9623 m .74505 .95837 L .76945 .97171 L .782 .817 0 r
F
.56731 1.24668 m .57422 1.24587 L .5825 1.24998 L .296 .29 0 r
F
.55937 1.24303 m .57422 1.24587 L .56731 1.24668 L .269 .246 0 r
F
.59005 1.25429 m .59876 1.25396 L .60623 1.25888 L .357 .392 0 r
F
.5825 1.24998 m .59876 1.25396 L .59005 1.25429 L .337 .357 0 r
F
.59265 .96263 m .59645 .95821 L .62169 .96228 L .659 .77 0 r
F
.56763 .96051 m .59645 .95821 L .59265 .96263 L .668 .78 0 r
F
.78633 1.29391 m .80211 1.30909 L .79041 1.30845 L .74 .755 0 r
F
.77475 1.2938 m .78633 1.29391 L .79041 1.30845 L .728 .747 0 r
F
.62665 .95788 m .65777 .95967 L .6517 .96392 L .708 .797 0 r
F
.62169 .96228 m .62665 .95788 L .6517 .96392 L .684 .782 0 r
F
.54059 .96462 m .54196 .96035 L .56763 .96051 L .643 .76 0 r
F
.51581 .96653 m .54196 .96035 L .54059 .96462 L .678 .785 0 r
F
.71165 1.28114 m .72859 1.2923 L .71709 1.29161 L .624 .683 0 r
F
.70043 1.28094 m .71165 1.28114 L .71709 1.29161 L .603 .668 0 r
F
.61572 1.25876 m .633 1.26451 L .62284 1.26436 L .41 .484 0 r
F
.60623 1.25888 m .61572 1.25876 L .62284 1.26436 L .392 .453 0 r
F
.59645 .95821 m .62665 .95788 L .62169 .96228 L .689 .791 0 r
F
.59876 1.25396 m .61572 1.25876 L .60623 1.25888 L .376 .424 0 r
F
.3753 1.03627 m .39066 1.01276 L .39644 1.01845 L 1 .961 0 r
F
.3753 1.03627 m .36852 1.02966 L .39066 1.01276 L F
.34799 1.04658 m .36171 1.02334 L .36852 1.02966 L 1 .9 0 r
F
.34799 1.04658 m .34025 1.03998 L .36171 1.02334 L F
.79791 1.29393 m .81382 1.30963 L .80211 1.30909 L .75 .763 0 r
F
.78633 1.29391 m .79791 1.29393 L .80211 1.30909 L .74 .755 0 r
F
.50471 1.22273 m .5143 1.22443 L .51417 1.22616 L .011 .093 0 r
F
.50471 1.22273 m .50363 1.22075 L .5143 1.22443 L F
.31216 1.05026 m .3247 1.02759 L .33249 1.03368 L 1 .879 0 r
F
.31216 1.05026 m .30353 1.04434 L .3247 1.02759 L F
.66093 1.27163 m .67169 1.27173 L .67805 1.28005 L .507 .601 0 r
F
.67169 1.27173 m .68923 1.28058 L .67805 1.28005 L .532 .622 0 r
F
.55937 1.24303 m .56527 1.24196 L .57422 1.24587 L .269 .246 0 r
F
.55094 1.23951 m .56527 1.24196 L .55937 1.24303 L .237 .199 0 r
F
.26594 1.0506 m .27748 1.02757 L .28619 1.03303 L 1 .873 0 r
F
.26594 1.0506 m .25649 1.04551 L .27748 1.02757 L F
.51581 .96653 m .51595 .96234 L .54196 .96035 L .678 .785 0 r
F
.49098 .97081 m .51595 .96234 L .51581 .96653 L .752 .837 0 r
F
.64318 1.26445 m .66093 1.27163 L .65019 1.27134 L .459 .562 0 r
F
.633 1.26451 m .64318 1.26445 L .65019 1.27134 L .439 .535 0 r
F
.70359 .95534 m .73694 .9623 L .72885 .96616 L .769 .817 0 r
F
.69644 .95955 m .70359 .95534 L .72885 .96616 L .757 .811 0 r
F
.66386 .95529 m .69644 .95955 L .68932 .96366 L .743 .81 0 r
F
.65777 .95967 m .66386 .95529 L .68932 .96366 L .726 .8 0 r
F
.49842 1.21785 m .50145 1.21866 L .50255 1.21937 L .231 0 0 r
F
.4908 1.21505 m .50145 1.21866 L .49842 1.21785 L F
.50255 1.21937 m .50145 1.21866 L .51456 1.22218 L 0 .082 0 r
F
.50145 1.21866 m .50035 1.21861 L .5044 1.21944 L .169 0 0 r
F
.50145 1.21866 m .51469 1.22157 L .51456 1.22218 L F
.50145 1.21866 m .5044 1.21944 L .51469 1.22157 L F
.4908 1.21505 m .48849 1.21434 L .49792 1.21748 L .231 0 0 r
F
.4908 1.21505 m .49792 1.21748 L .50145 1.21866 L F
.4831 1.21242 m .4908 1.21505 L .49309 1.21672 L 0 .065 0 r
F
.48278 1.21228 m .4908 1.21505 L .4831 1.21242 L F
.48278 1.21228 m .47932 1.20989 L .4908 1.21505 L F
.80951 1.29386 m .82553 1.3101 L .81382 1.30963 L .759 .77 0 r
F
.79791 1.29393 m .80951 1.29386 L .81382 1.30963 L .75 .763 0 r
F
.72289 1.28121 m .74011 1.29285 L .72859 1.2923 L .643 .697 0 r
F
.71165 1.28114 m .72289 1.28121 L .72859 1.2923 L .624 .683 0 r
F
.45202 1.19206 m .45899 1.19966 L .46363 1.20101 L .542 .006 0 r
F
.45202 1.19206 m .44634 1.18668 L .45899 1.19966 L F
.39644 1.01845 m .41414 .99713 L .41884 1.00185 L 1 1 0 r
F
.39644 1.01845 m .39066 1.01276 L .41414 .99713 L F
.5825 1.24998 m .59037 1.24929 L .59876 1.25396 L .337 .357 0 r
F
.57422 1.24587 m .59037 1.24929 L .5825 1.24998 L .312 .314 0 r
F
.49098 .97081 m .48987 .96675 L .51595 .96234 L .752 .837 0 r
F
.46637 .97786 m .48987 .96675 L .49098 .97081 L .888 .928 0 r
F
.55094 1.23951 m .55577 1.23825 L .56527 1.24196 L .237 .199 0 r
F
.54211 1.23611 m .55577 1.23825 L .55094 1.23951 L .2 .151 0 r
F
.51417 1.22616 m .52496 1.2279 L .52362 1.2295 L .06 .099 0 r
F
.51417 1.22616 m .5143 1.22443 L .52496 1.2279 L F
.41884 1.00185 m .43869 .98398 L .44224 .98812 L 1 1 0 r
F
.41884 1.00185 m .41414 .99713 L .43869 .98398 L F
.46637 .97786 m .46402 .97387 L .48987 .96675 L .888 .928 0 r
F
.44224 .98812 m .46402 .97387 L .46637 .97786 L 1 1 0 r
F
.44224 .98812 m .43869 .98398 L .46402 .97387 L F
.56763 .96051 m .57024 .956 L .59645 .95821 L .668 .78 0 r
F
.54196 .96035 m .57024 .956 L .56763 .96051 L .691 .799 0 r
F
.82112 1.29371 m .83726 1.31049 L .82553 1.3101 L .768 .777 0 r
F
.80951 1.29386 m .82112 1.29371 L .82553 1.3101 L .759 .77 0 r
F
.46824 1.20385 m .47583 1.20861 L .47932 1.20989 L .376 0 0 r
F
.46824 1.20385 m .46363 1.20101 L .47583 1.20861 L F
.54211 1.23611 m .54582 1.23471 L .55577 1.23825 L .2 .151 0 r
F
.53297 1.23279 m .54582 1.23471 L .54211 1.23611 L .158 .113 0 r
F
.52362 1.2295 m .53551 1.23129 L .53297 1.23279 L .11 .105 0 r
F
.52362 1.2295 m .52496 1.2279 L .53551 1.23129 L F
.53297 1.23279 m .53551 1.23129 L .54582 1.23471 L .158 .113 0 r
F
.68247 1.27166 m .70043 1.28094 L .68923 1.28058 L .555 .642 0 r
F
.67169 1.27173 m .68247 1.27166 L .68923 1.28058 L .532 .622 0 r
F
.34025 1.03998 m .35487 1.01719 L .36171 1.02334 L 1 .914 0 r
F
.34025 1.03998 m .33249 1.03368 L .35487 1.01719 L F
.62524 1.25842 m .64318 1.26445 L .633 1.26451 L .426 .515 0 r
F
.61572 1.25876 m .62524 1.25842 L .633 1.26451 L .41 .484 0 r
F
.73415 1.28115 m .75165 1.29328 L .74011 1.29285 L .66 .71 0 r
F
.72289 1.28121 m .73415 1.28115 L .74011 1.29285 L .643 .697 0 r
F
.30353 1.04434 m .31688 1.02167 L .3247 1.02759 L 1 .889 0 r
F
.30353 1.04434 m .29487 1.03861 L .31688 1.02167 L F
.25649 1.04551 m .26874 1.02221 L .27748 1.02757 L 1 .879 0 r
F
.25649 1.04551 m .24703 1.04053 L .26874 1.02221 L F
.59876 1.25396 m .6075 1.25342 L .61572 1.25876 L .376 .424 0 r
F
.59037 1.24929 m .6075 1.25342 L .59876 1.25396 L .355 .388 0 r
F
.83275 1.29349 m .84899 1.3108 L .83726 1.31049 L .776 .783 0 r
F
.82112 1.29371 m .83275 1.29349 L .83726 1.31049 L .768 .777 0 r
F
.36852 1.02966 m .38486 1.00705 L .39066 1.01276 L 1 .971 0 r
F
.36852 1.02966 m .36171 1.02334 L .38486 1.00705 L F
.63163 .95335 m .66386 .95529 L .65777 .95967 L .729 .809 0 r
F
.62665 .95788 m .63163 .95335 L .65777 .95967 L .708 .797 0 r
F
.6075 1.25342 m .62524 1.25842 L .61572 1.25876 L .394 .456 0 r
F
.59645 .95821 m .60027 .95362 L .62665 .95788 L .689 .791 0 r
F
.57024 .956 m .60027 .95362 L .59645 .95821 L .703 .805 0 r
F
.57422 1.24587 m .58116 1.24489 L .59037 1.24929 L .312 .314 0 r
F
.56527 1.24196 m .58116 1.24489 L .57422 1.24587 L .283 .264 0 r
F
.6534 1.26419 m .67169 1.27173 L .66093 1.27163 L .482 .587 0 r
F
.64318 1.26445 m .6534 1.26419 L .66093 1.27163 L .459 .562 0 r
F
.49309 1.21672 m .50255 1.21937 L .50363 1.22075 L 0 .076 0 r
F
.49309 1.21672 m .4908 1.21505 L .50255 1.21937 L F
.84438 1.2932 m .86072 1.31106 L .84899 1.3108 L .783 .789 0 r
F
.83275 1.29349 m .84438 1.2932 L .84899 1.3108 L .776 .783 0 r
F
.60027 .95362 m .63163 .95335 L .62665 .95788 L .716 .808 0 r
F
.54196 .96035 m .54334 .95582 L .57024 .956 L .691 .799 0 r
F
.51595 .96234 m .54334 .95582 L .54196 .96035 L .735 .832 0 r
F
.74542 1.28096 m .76319 1.2936 L .75165 1.29328 L .676 .722 0 r
F
.73415 1.28115 m .74542 1.28096 L .75165 1.29328 L .66 .71 0 r
F
.71076 .95104 m .74505 .95837 L .73694 .9623 L .781 .823 0 r
F
.70359 .95534 m .71076 .95104 L .73694 .9623 L .769 .817 0 r
F
.69328 1.27143 m .71165 1.28114 L .70043 1.28094 L .578 .66 0 r
F
.68247 1.27166 m .69328 1.27143 L .70043 1.28094 L .555 .642 0 r
F
.66997 .95081 m .70359 .95534 L .69644 .95955 L .758 .818 0 r
F
.66386 .95529 m .66997 .95081 L .69644 .95955 L .743 .81 0 r
F
.84438 1.2932 m .85603 1.29284 L .86072 1.31106 L .783 .789 0 r
F
.39066 1.01276 m .40943 .99209 L .41414 .99713 L 1 1 0 r
F
.39066 1.01276 m .38486 1.00705 L .40943 .99209 L F
.44634 1.18668 m .4543 1.20137 L .45899 1.19966 L .742 .046 0 r
F
.44634 1.18668 m .44064 1.18129 L .4543 1.20137 L F
.24703 1.04053 m .25997 1.01692 L .26874 1.02221 L 1 .884 0 r
F
.24703 1.04053 m .23754 1.03564 L .25997 1.01692 L F
.29487 1.03861 m .30903 1.01587 L .31688 1.02167 L 1 .896 0 r
F
.29487 1.03861 m .28619 1.03303 L .30903 1.01587 L F
.56527 1.24196 m .57121 1.24076 L .58116 1.24489 L .283 .264 0 r
F
.55577 1.23825 m .57121 1.24076 L .56527 1.24196 L .247 .207 0 r
F
.33249 1.03368 m .34801 1.01118 L .35487 1.01719 L 1 .923 0 r
F
.33249 1.03368 m .3247 1.02759 L .34801 1.01118 L F
.51595 .96234 m .51608 .95785 L .54334 .95582 L .735 .832 0 r
F
.48987 .96675 m .51608 .95785 L .51595 .96234 L .816 .887 0 r
F
.50363 1.22075 m .51443 1.22311 L .5143 1.22443 L 0 .087 0 r
F
.50363 1.22075 m .50255 1.21937 L .51443 1.22311 L F
.59037 1.24929 m .59827 1.2484 L .6075 1.25342 L .355 .388 0 r
F
.58116 1.24489 m .59827 1.2484 L .59037 1.24929 L .331 .342 0 r
F
.63479 1.25788 m .6534 1.26419 L .64318 1.26445 L .442 .543 0 r
F
.62524 1.25842 m .63479 1.25788 L .64318 1.26445 L .426 .515 0 r
F
.75672 1.28066 m .77475 1.2938 L .76319 1.2936 L .69 .732 0 r
F
.74542 1.28096 m .75672 1.28066 L .76319 1.2936 L .676 .722 0 r
F
.41414 .99713 m .43513 .97938 L .43869 .98398 L 1 1 0 r
F
.41414 .99713 m .40943 .99209 L .43513 .97938 L F
.47932 1.20989 m .48849 1.21434 L .4908 1.21505 L .326 0 0 r
F
.47932 1.20989 m .47583 1.20861 L .48849 1.21434 L F
.36171 1.02334 m .37904 1.00132 L .38486 1.00705 L 1 .976 0 r
F
.36171 1.02334 m .35487 1.01719 L .37904 1.00132 L F
.6534 1.26419 m .66364 1.26376 L .67169 1.27173 L .482 .587 0 r
F
.66364 1.26376 m .68247 1.27166 L .67169 1.27173 L .506 .61 0 r
F
.48987 .96675 m .48875 .96232 L .51608 .95785 L .816 .887 0 r
F
.46402 .97387 m .48875 .96232 L .48987 .96675 L .946 .967 0 r
F
.43869 .98398 m .46167 .96944 L .46402 .97387 L 1 1 0 r
F
.43869 .98398 m .43513 .97938 L .46167 .96944 L F
.57024 .956 m .57286 .95129 L .60027 .95362 L .703 .805 0 r
F
.54334 .95582 m .57286 .95129 L .57024 .956 L .731 .828 0 r
F
.55577 1.23825 m .56063 1.23692 L .57121 1.24076 L .247 .207 0 r
F
.54582 1.23471 m .56063 1.23692 L .55577 1.23825 L .203 .149 0 r
F
.46402 .97387 m .46167 .96944 L .48875 .96232 L .946 .967 0 r
F
.70411 1.27105 m .72289 1.28121 L .71165 1.28114 L .598 .676 0 r
F
.69328 1.27143 m .70411 1.27105 L .71165 1.28114 L .578 .66 0 r
F
.6075 1.25342 m .61628 1.25267 L .62524 1.25842 L .394 .456 0 r
F
.59827 1.2484 m .61628 1.25267 L .6075 1.25342 L .374 .42 0 r
F
.46363 1.20101 m .47232 1.20898 L .47583 1.20861 L .557 0 0 r
F
.46363 1.20101 m .45899 1.19966 L .47232 1.20898 L F
.61628 1.25267 m .63479 1.25788 L .62524 1.25842 L .411 .488 0 r
F
.5143 1.22443 m .52631 1.22654 L .52496 1.2279 L .018 .097 0 r
F
.5143 1.22443 m .51443 1.22311 L .52631 1.22654 L F
.63663 .94868 m .66997 .95081 L .66386 .95529 L .748 .82 0 r
F
.63163 .95335 m .63663 .94868 L .66386 .95529 L .729 .809 0 r
F
.76803 1.28026 m .78633 1.29391 L .77475 1.2938 L .704 .742 0 r
F
.75672 1.28066 m .76803 1.28026 L .77475 1.2938 L .69 .732 0 r
F
.54582 1.23471 m .54954 1.23331 L .56063 1.23692 L .203 .149 0 r
F
.53551 1.23129 m .54954 1.23331 L .54582 1.23471 L .151 .111 0 r
F
.52496 1.2279 m .53806 1.22989 L .53551 1.23129 L .088 .105 0 r
F
.52496 1.2279 m .52631 1.22654 L .53806 1.22989 L F
.28619 1.03303 m .30115 1.01017 L .30903 1.01587 L 1 .902 0 r
F
.28619 1.03303 m .27748 1.02757 L .30115 1.01017 L F
.53551 1.23129 m .53806 1.22989 L .54954 1.23331 L .151 .111 0 r
F
.71076 .95104 m .71795 .94666 L .74505 .95837 L .781 .823 0 r
F
.60027 .95362 m .6041 .94888 L .63163 .95335 L .716 .808 0 r
F
.57286 .95129 m .6041 .94888 L .60027 .95362 L .733 .825 0 r
F
.58116 1.24489 m .58812 1.24373 L .59827 1.2484 L .331 .342 0 r
F
.57121 1.24076 m .58812 1.24373 L .58116 1.24489 L .3 .287 0 r
F
.3247 1.02759 m .34112 1.00526 L .34801 1.01118 L 1 .929 0 r
F
.3247 1.02759 m .31688 1.02167 L .34112 1.00526 L F
.6041 .94888 m .63663 .94868 L .63163 .95335 L .739 .822 0 r
F
.6761 .94623 m .71076 .95104 L .70359 .95534 L .772 .826 0 r
F
.66997 .95081 m .6761 .94623 L .70359 .95534 L .758 .818 0 r
F
.38486 1.00705 m .4047 .98682 L .40943 .99209 L 1 1 0 r
F
.38486 1.00705 m .37904 1.00132 L .4047 .98682 L F
.44064 1.18129 m .44951 1.20955 L .4543 1.20137 L 1 .08 0 r
F
.44064 1.18129 m .43492 1.17587 L .44951 1.20955 L F
.6739 1.26314 m .69328 1.27143 L .68247 1.27166 L .53 .631 0 r
F
.66364 1.26376 m .6739 1.26314 L .68247 1.27166 L .506 .61 0 r
F
.71496 1.27053 m .73415 1.28115 L .72289 1.28121 L .618 .691 0 r
F
.70411 1.27105 m .71496 1.27053 L .72289 1.28121 L .598 .676 0 r
F
.77936 1.27976 m .79791 1.29393 L .78633 1.29391 L .716 .751 0 r
F
.76803 1.28026 m .77936 1.27976 L .78633 1.29391 L .704 .742 0 r
F
.64436 1.25715 m .66364 1.26376 L .6534 1.26419 L .459 .57 0 r
F
.63479 1.25788 m .64436 1.25715 L .6534 1.26419 L .442 .543 0 r
F
.54334 .95582 m .54473 .95106 L .57286 .95129 L .731 .828 0 r
F
.51608 .95785 m .54473 .95106 L .54334 .95582 L .781 .864 0 r
F
.35487 1.01719 m .37319 .99557 L .37904 1.00132 L 1 .977 0 r
F
.35487 1.01719 m .34801 1.01118 L .37319 .99557 L F
.59827 1.2484 m .6062 1.24731 L .61628 1.25267 L .374 .42 0 r
F
.58812 1.24373 m .6062 1.24731 L .59827 1.2484 L .35 .374 0 r
F
.40943 .99209 m .43156 .97445 L .43513 .97938 L 1 1 0 r
F
.40943 .99209 m .4047 .98682 L .43156 .97445 L F
.57121 1.24076 m .57716 1.23941 L .58812 1.24373 L .3 .287 0 r
F
.56063 1.23692 m .57716 1.23941 L .57121 1.24076 L .262 .223 0 r
F
.79071 1.27917 m .80951 1.29386 L .79791 1.29393 L .727 .759 0 r
F
.77936 1.27976 m .79071 1.27917 L .79791 1.29393 L .716 .751 0 r
F
.62508 1.25172 m .64436 1.25715 L .63479 1.25788 L .428 .518 0 r
F
.61628 1.25267 m .62508 1.25172 L .63479 1.25788 L .411 .488 0 r
F
.51608 .95785 m .51621 .95309 L .54473 .95106 L .781 .864 0 r
F
.48875 .96232 m .51621 .95309 L .51608 .95785 L .862 .917 0 r
F
.27748 1.02757 m .29325 1.00454 L .30115 1.01017 L 1 .906 0 r
F
.27748 1.02757 m .26874 1.02221 L .29325 1.00454 L F
.6062 1.24731 m .62508 1.25172 L .61628 1.25267 L .393 .453 0 r
F
.72583 1.26988 m .74542 1.28096 L .73415 1.28115 L .635 .704 0 r
F
.71496 1.27053 m .72583 1.26988 L .73415 1.28115 L .618 .691 0 r
F
.43513 .97938 m .4593 .96466 L .46167 .96944 L 1 1 0 r
F
.43513 .97938 m .43156 .97445 L .4593 .96466 L F
.31688 1.02167 m .33421 .9994 L .34112 1.00526 L 1 .933 0 r
F
.31688 1.02167 m .30903 1.01587 L .33421 .9994 L F
.64165 .9439 m .6761 .94623 L .66997 .95081 L .764 .829 0 r
F
.63663 .94868 m .64165 .9439 L .66997 .95081 L .748 .82 0 r
F
.48875 .96232 m .48763 .95757 L .51621 .95309 L .862 .917 0 r
F
.46167 .96944 m .48763 .95757 L .48875 .96232 L .981 .984 0 r
F
.57286 .95129 m .57549 .94641 L .6041 .94888 L .733 .825 0 r
F
.54473 .95106 m .57549 .94641 L .57286 .95129 L .765 .85 0 r
F
.50255 1.21937 m .51456 1.22218 L .51443 1.22311 L 0 .082 0 r
F
.6842 1.26237 m .70411 1.27105 L .69328 1.27143 L .552 .65 0 r
F
.6739 1.26314 m .6842 1.26237 L .69328 1.27143 L .53 .631 0 r
F
.46167 .96944 m .4593 .96466 L .48763 .95757 L .981 .984 0 r
F
.47583 1.20861 m .48617 1.21478 L .48849 1.21434 L .453 0 0 r
F
.47583 1.20861 m .47232 1.20898 L .48617 1.21478 L F
.80207 1.27849 m .82112 1.29371 L .80951 1.29386 L .737 .766 0 r
F
.79071 1.27917 m .80207 1.27849 L .80951 1.29386 L .727 .759 0 r
F
.56063 1.23692 m .56551 1.23547 L .57716 1.23941 L .262 .223 0 r
F
.54954 1.23331 m .56551 1.23547 L .56063 1.23692 L .214 .154 0 r
F
.64436 1.25715 m .65397 1.25622 L .66364 1.26376 L .459 .57 0 r
F
.65397 1.25622 m .6739 1.26314 L .66364 1.26376 L .482 .595 0 r
F
.45899 1.19966 m .46877 1.21168 L .47232 1.20898 L .711 .023 0 r
F
.45899 1.19966 m .4543 1.20137 L .46877 1.21168 L F
.37904 1.00132 m .39995 .98139 L .4047 .98682 L 1 1 0 r
F
.37904 1.00132 m .37319 .99557 L .39995 .98139 L F
.43492 1.17587 m .44459 1.22719 L .44951 1.20955 L 1 .117 0 r
F
.43492 1.17587 m .42879 1.20069 L .44459 1.22719 L F
.68226 .94155 m .71795 .94666 L .71076 .95104 L .784 .832 0 r
F
.6761 .94623 m .68226 .94155 L .71076 .95104 L .772 .826 0 r
F
.6041 .94888 m .60794 .94399 L .63663 .94868 L .739 .822 0 r
F
.57549 .94641 m .60794 .94399 L .6041 .94888 L .759 .84 0 r
F
.60794 .94399 m .64165 .9439 L .63663 .94868 L .76 .834 0 r
F
.34801 1.01118 m .36733 .98979 L .37319 .99557 L 1 .976 0 r
F
.34801 1.01118 m .34112 1.00526 L .36733 .98979 L F
.51443 1.22311 m .52767 1.22537 L .52631 1.22654 L 0 .096 0 r
F
.51443 1.22311 m .51456 1.22218 L .52767 1.22537 L F
.58812 1.24373 m .59512 1.24237 L .6062 1.24731 L .35 .374 0 r
F
.57716 1.23941 m .59512 1.24237 L .58812 1.24373 L .32 .317 0 r
F
.73673 1.26911 m .75672 1.28066 L .74542 1.28096 L .652 .717 0 r
F
.72583 1.26988 m .73673 1.26911 L .74542 1.28096 L .635 .704 0 r
F
.54954 1.23331 m .55328 1.23186 L .56551 1.23547 L .214 .154 0 r
F
.53806 1.22989 m .55328 1.23186 L .54954 1.23331 L .153 .114 0 r
F
.81345 1.27774 m .83275 1.29349 L .82112 1.29371 L .746 .773 0 r
F
.80207 1.27849 m .81345 1.27774 L .82112 1.29371 L .737 .766 0 r
F
.26874 1.02221 m .28533 .99896 L .29325 1.00454 L 1 .908 0 r
F
.26874 1.02221 m .25997 1.01692 L .28533 .99896 L F
.52631 1.22654 m .54062 1.22853 L .53806 1.22989 L .077 .107 0 r
F
.52631 1.22654 m .52767 1.22537 L .54062 1.22853 L F
.53806 1.22989 m .54062 1.22853 L .55328 1.23186 L .153 .114 0 r
F
.54473 .95106 m .54612 .9461 L .57549 .94641 L .765 .85 0 r
F
.51621 .95309 m .54612 .9461 L .54473 .95106 L .817 .886 0 r
F
.63392 1.25056 m .65397 1.25622 L .64436 1.25715 L .444 .547 0 r
F
.62508 1.25172 m .63392 1.25056 L .64436 1.25715 L .428 .518 0 r
F
.69451 1.26144 m .71496 1.27053 L .70411 1.27105 L .574 .668 0 r
F
.6842 1.26237 m .69451 1.26144 L .70411 1.27105 L .552 .65 0 r
F
.30903 1.01587 m .32727 .99358 L .33421 .9994 L 1 .935 0 r
F
.30903 1.01587 m .30115 1.01017 L .32727 .99358 L F
.6062 1.24731 m .61416 1.24601 L .62508 1.25172 L .393 .453 0 r
F
.59512 1.24237 m .61416 1.24601 L .6062 1.24731 L .371 .409 0 r
F
.4047 .98682 m .42797 .96926 L .43156 .97445 L 1 1 0 r
F
.4047 .98682 m .39995 .98139 L .42797 .96926 L F
.82485 1.27691 m .84438 1.2932 L .83275 1.29349 L .754 .779 0 r
F
.81345 1.27774 m .82485 1.27691 L .83275 1.29349 L .746 .773 0 r
F
.61416 1.24601 m .63392 1.25056 L .62508 1.25172 L .411 .486 0 r
F
.74764 1.26822 m .76803 1.28026 L .75672 1.28066 L .667 .728 0 r
F
.73673 1.26911 m .74764 1.26822 L .75672 1.28066 L .652 .717 0 r
F
.6636 1.25512 m .6842 1.26237 L .6739 1.26314 L .505 .617 0 r
F
.65397 1.25622 m .6636 1.25512 L .6739 1.26314 L .482 .595 0 r
F
.48849 1.21434 m .50035 1.21861 L .50145 1.21866 L .315 0 0 r
F
.48849 1.21434 m .48617 1.21478 L .50035 1.21861 L F
.57716 1.23941 m .58315 1.23789 L .59512 1.24237 L .32 .317 0 r
F
.56551 1.23547 m .58315 1.23789 L .57716 1.23941 L .282 .247 0 r
F
.51621 .95309 m .51635 .9481 L .54612 .9461 L .817 .886 0 r
F
.48763 .95757 m .51635 .9481 L .51621 .95309 L .895 .935 0 r
F
.64669 .939 m .68226 .94155 L .6761 .94623 L .779 .837 0 r
F
.64165 .9439 m .64669 .939 L .6761 .94623 L .764 .829 0 r
F
.43156 .97445 m .45693 .95961 L .4593 .96466 L 1 1 0 r
F
.43156 .97445 m .42797 .96926 L .45693 .95961 L F
.83627 1.27602 m .85603 1.29284 L .84438 1.2932 L .762 .785 0 r
F
.82485 1.27691 m .83627 1.27602 L .84438 1.2932 L .754 .779 0 r
F
.57549 .94641 m .57813 .94136 L .60794 .94399 L .759 .84 0 r
F
.54612 .9461 m .57813 .94136 L .57549 .94641 L .793 .866 0 r
F
.34112 1.00526 m .36144 .984 L .36733 .98979 L 1 .973 0 r
F
.34112 1.00526 m .33421 .9994 L .36144 .984 L F
.37319 .99557 m .39519 .97582 L .39995 .98139 L 1 1 0 r
F
.37319 .99557 m .36733 .98979 L .39519 .97582 L F
.48763 .95757 m .4865 .95256 L .51635 .9481 L .895 .935 0 r
F
.4593 .96466 m .4865 .95256 L .48763 .95757 L 1 .991 0 r
F
.68226 .94155 m .68843 .93679 L .71795 .94666 L .784 .832 0 r
F
.4593 .96466 m .45693 .95961 L .4865 .95256 L 1 .991 0 r
F
.70486 1.26037 m .72583 1.26988 L .71496 1.27053 L .594 .683 0 r
F
.69451 1.26144 m .70486 1.26037 L .71496 1.27053 L .574 .668 0 r
F
.75858 1.26723 m .77936 1.27976 L .76803 1.28026 L .681 .738 0 r
F
.74764 1.26822 m .75858 1.26723 L .76803 1.28026 L .667 .728 0 r
F
.61181 .93897 m .64669 .939 L .64165 .9439 L .778 .843 0 r
F
.60794 .94399 m .61181 .93897 L .64165 .9439 L .76 .834 0 r
F
.56551 1.23547 m .57041 1.23387 L .58315 1.23789 L .282 .247 0 r
F
.55328 1.23186 m .57041 1.23387 L .56551 1.23547 L .232 .169 0 r
F
.57813 .94136 m .61181 .93897 L .60794 .94399 L .782 .853 0 r
F
.30115 1.01017 m .32031 .9878 L .32727 .99358 L 1 .936 0 r
F
.30115 1.01017 m .29325 1.00454 L .32031 .9878 L F
.63392 1.25056 m .64278 1.24921 L .65397 1.25622 L .444 .547 0 r
F
.64278 1.24921 m .6636 1.25512 L .65397 1.25622 L .459 .575 0 r
F
.83627 1.27602 m .8477 1.27507 L .85603 1.29284 L .762 .785 0 r
F
.59512 1.24237 m .60215 1.24081 L .61416 1.24601 L .371 .409 0 r
F
.58315 1.23789 m .60215 1.24081 L .59512 1.24237 L .343 .352 0 r
F
.47232 1.20898 m .48382 1.21642 L .48617 1.21478 L .513 0 0 r
F
.47232 1.20898 m .46877 1.21168 L .48382 1.21642 L F
.67327 1.25385 m .69451 1.26144 L .6842 1.26237 L .528 .638 0 r
F
.6636 1.25512 m .67327 1.25385 L .6842 1.26237 L .505 .617 0 r
F
.55328 1.23186 m .55705 1.23031 L .57041 1.23387 L .232 .169 0 r
F
.54062 1.22853 m .55705 1.23031 L .55328 1.23186 L .167 .117 0 r
F
.4543 1.20137 m .46518 1.21703 L .46877 1.21168 L .827 .034 0 r
F
.4543 1.20137 m .44951 1.20955 L .46518 1.21703 L F
.62216 1.2445 m .64278 1.24921 L .63392 1.25056 L .429 .518 0 r
F
.61416 1.24601 m .62216 1.2445 L .63392 1.25056 L .411 .486 0 r
F
.60215 1.24081 m .62216 1.2445 L .61416 1.24601 L .391 .444 0 r
F
.39995 .98139 m .42437 .96388 L .42797 .96926 L 1 1 0 r
F
.39995 .98139 m .39519 .97582 L .42437 .96388 L F
.54612 .9461 m .54752 .94096 L .57813 .94136 L .793 .866 0 r
F
.51635 .9481 m .54752 .94096 L .54612 .9461 L .845 .901 0 r
F
.51456 1.22218 m .52903 1.22431 L .52767 1.22537 L 0 .096 0 r
F
.51456 1.22218 m .51469 1.22157 L .52903 1.22431 L F
.76954 1.26614 m .79071 1.27917 L .77936 1.27976 L .694 .747 0 r
F
.75858 1.26723 m .76954 1.26614 L .77936 1.27976 L .681 .738 0 r
F
.71522 1.25917 m .73673 1.26911 L .72583 1.26988 L .612 .698 0 r
F
.70486 1.26037 m .71522 1.25917 L .72583 1.26988 L .594 .683 0 r
F
.54062 1.22853 m .5432 1.22716 L .55705 1.23031 L .167 .117 0 r
F
.52767 1.22537 m .5432 1.22716 L .54062 1.22853 L .08 .109 0 r
F
.52767 1.22537 m .52903 1.22431 L .5432 1.22716 L F
.33421 .9994 m .35553 .97818 L .36144 .984 L 1 .97 0 r
F
.33421 .9994 m .32727 .99358 L .35553 .97818 L F
.65175 .93401 m .68843 .93679 L .68226 .94155 L .793 .843 0 r
F
.64669 .939 m .65175 .93401 L .68226 .94155 L .779 .837 0 r
F
.36733 .98979 m .3904 .97015 L .39519 .97582 L 1 1 0 r
F
.36733 .98979 m .36144 .984 L .3904 .97015 L F
.58315 1.23789 m .58916 1.23616 L .60215 1.24081 L .343 .352 0 r
F
.57041 1.23387 m .58916 1.23616 L .58315 1.23789 L .306 .28 0 r
F
.42797 .96926 m .45455 .95433 L .45693 .95961 L 1 1 0 r
F
.42797 .96926 m .42437 .96388 L .45455 .95433 L F
.51635 .9481 m .51648 .9429 L .54752 .94096 L .845 .901 0 r
F
.4865 .95256 m .51648 .9429 L .51635 .9481 L .919 .945 0 r
F
.29325 1.00454 m .31332 .98204 L .32031 .9878 L 1 .936 0 r
F
.29325 1.00454 m .28533 .99896 L .31332 .98204 L F
.78052 1.26496 m .80207 1.27849 L .79071 1.27917 L .706 .755 0 r
F
.76954 1.26614 m .78052 1.26496 L .79071 1.27917 L .694 .747 0 r
F
.65167 1.24768 m .67327 1.25385 L .6636 1.25512 L .481 .6 0 r
F
.64278 1.24921 m .65167 1.24768 L .6636 1.25512 L .459 .575 0 r
F
.57813 .94136 m .58078 .93617 L .61181 .93897 L .782 .853 0 r
F
.54752 .94096 m .58078 .93617 L .57813 .94136 L .816 .878 0 r
F
.68296 1.25242 m .70486 1.26037 L .69451 1.26144 L .55 .657 0 r
F
.67327 1.25385 m .68296 1.25242 L .69451 1.26144 L .528 .638 0 r
F
.45693 .95961 m .48537 .94733 L .4865 .95256 L 1 .992 0 r
F
.45693 .95961 m .45455 .95433 L .48537 .94733 L F
.4865 .95256 m .48537 .94733 L .51648 .9429 L .919 .945 0 r
F
.48617 1.21478 m .49924 1.21908 L .50035 1.21861 L .353 0 0 r
F
.48617 1.21478 m .48382 1.21642 L .49924 1.21908 L F
.72562 1.25784 m .74764 1.26822 L .73673 1.26911 L .629 .711 0 r
F
.71522 1.25917 m .72562 1.25784 L .73673 1.26911 L .612 .698 0 r
F
.61568 .93383 m .65175 .93401 L .64669 .939 L .794 .851 0 r
F
.61181 .93897 m .61568 .93383 L .64669 .939 L .778 .843 0 r
F
.58078 .93617 m .61568 .93383 L .61181 .93897 L .801 .862 0 r
F
.60215 1.24081 m .6092 1.23904 L .62216 1.2445 L .391 .444 0 r
F
.58916 1.23616 m .6092 1.23904 L .60215 1.24081 L .366 .39 0 r
F
.57041 1.23387 m .57534 1.23209 L .58916 1.23616 L .306 .28 0 r
F
.55705 1.23031 m .57534 1.23209 L .57041 1.23387 L .258 .194 0 r
F
.62216 1.2445 m .63018 1.2428 L .64278 1.24921 L .429 .518 0 r
F
.63018 1.2428 m .65167 1.24768 L .64278 1.24921 L .445 .549 0 r
F
.79153 1.26369 m .81345 1.27774 L .80207 1.27849 L .716 .763 0 r
F
.78052 1.26496 m .79153 1.26369 L .80207 1.27849 L .706 .755 0 r
F
.39519 .97582 m .42076 .95833 L .42437 .96388 L 1 1 0 r
F
.39519 .97582 m .3904 .97015 L .42076 .95833 L F
.6092 1.23904 m .63018 1.2428 L .62216 1.2445 L .411 .48 0 r
F
.32727 .99358 m .3496 .97234 L .35553 .97818 L 1 .967 0 r
F
.32727 .99358 m .32031 .9878 L .3496 .97234 L F
.54752 .94096 m .54892 .93565 L .58078 .93617 L .816 .878 0 r
F
.51648 .9429 m .54892 .93565 L .54752 .94096 L .867 .911 0 r
F
.50035 1.21861 m .51483 1.22114 L .51469 1.22157 L .181 0 0 r
F
.50035 1.21861 m .49924 1.21908 L .51483 1.22114 L F
.65175 .93401 m .65683 .92892 L .68843 .93679 L .793 .843 0 r
F
.73603 1.2564 m .75858 1.26723 L .74764 1.26822 L .646 .722 0 r
F
.72562 1.25784 m .73603 1.2564 L .74764 1.26822 L .629 .711 0 r
F
.36144 .984 m .3856 .96439 L .3904 .97015 L 1 1 0 r
F
.36144 .984 m .35553 .97818 L .3856 .96439 L F
.69267 1.25084 m .71522 1.25917 L .70486 1.26037 L .57 .674 0 r
F
.68296 1.25242 m .69267 1.25084 L .70486 1.26037 L .55 .657 0 r
F
.55705 1.23031 m .56083 1.22861 L .57534 1.23209 L .258 .194 0 r
F
.5432 1.22716 m .56083 1.22861 L .55705 1.23031 L .192 .121 0 r
F
.66059 1.24597 m .68296 1.25242 L .67327 1.25385 L .503 .623 0 r
F
.65167 1.24768 m .66059 1.24597 L .67327 1.25385 L .481 .6 0 r
F
.80255 1.26235 m .82485 1.27691 L .81345 1.27774 L .726 .77 0 r
F
.79153 1.26369 m .80255 1.26235 L .81345 1.27774 L .716 .763 0 r
F
.46877 1.21168 m .48146 1.21897 L .48382 1.21642 L .493 0 0 r
F
.46877 1.21168 m .46518 1.21703 L .48146 1.21897 L F
.42437 .96388 m .45216 .94886 L .45455 .95433 L 1 1 0 r
F
.42437 .96388 m .42076 .95833 L .45216 .94886 L F
.51469 1.22157 m .5304 1.22324 L .52903 1.22431 L 0 .099 0 r
F
.51469 1.22157 m .51483 1.22114 L .5304 1.22324 L F
.5432 1.22716 m .54579 1.22568 L .56083 1.22861 L .192 .121 0 r
F
.52903 1.22431 m .54579 1.22568 L .5432 1.22716 L .101 .113 0 r
F
.58916 1.23616 m .5952 1.23423 L .6092 1.23904 L .366 .39 0 r
F
.57534 1.23209 m .5952 1.23423 L .58916 1.23616 L .333 .319 0 r
F
.51648 .9429 m .51662 .93753 L .54892 .93565 L .867 .911 0 r
F
.48537 .94733 m .51662 .93753 L .51648 .9429 L .936 .95 0 r
F
.52903 1.22431 m .5304 1.22324 L .54579 1.22568 L .101 .113 0 r
F
.58078 .93617 m .58344 .93085 L .61568 .93383 L .801 .862 0 r
F
.54892 .93565 m .58344 .93085 L .58078 .93617 L .835 .887 0 r
F
.45455 .95433 m .48424 .94191 L .48537 .94733 L 1 .99 0 r
F
.45455 .95433 m .45216 .94886 L .48424 .94191 L F
.61958 .92858 m .65683 .92892 L .65175 .93401 L .808 .858 0 r
F
.61568 .93383 m .61958 .92858 L .65175 .93401 L .794 .851 0 r
F
.48537 .94733 m .48424 .94191 L .51662 .93753 L .936 .95 0 r
F
.74648 1.25485 m .76954 1.26614 L .75858 1.26723 L .66 .733 0 r
F
.73603 1.2564 m .74648 1.25485 L .75858 1.26723 L .646 .722 0 r
F
.63822 1.24091 m .66059 1.24597 L .65167 1.24768 L .46 .578 0 r
F
.63018 1.2428 m .63822 1.24091 L .65167 1.24768 L .445 .549 0 r
F
.8136 1.26094 m .83627 1.27602 L .82485 1.27691 L .736 .776 0 r
F
.80255 1.26235 m .8136 1.26094 L .82485 1.27691 L .726 .77 0 r
F
.58344 .93085 m .61958 .92858 L .61568 .93383 L .817 .87 0 r
F
.32031 .9878 m .34365 .96648 L .3496 .97234 L 1 .964 0 r
F
.32031 .9878 m .31332 .98204 L .34365 .96648 L F
.6092 1.23904 m .61629 1.23707 L .63018 1.2428 L .411 .48 0 r
F
.5952 1.23423 m .61629 1.23707 L .6092 1.23904 L .389 .43 0 r
F
.70242 1.24913 m .72562 1.25784 L .71522 1.25917 L .59 .69 0 r
F
.69267 1.25084 m .70242 1.24913 L .71522 1.25917 L .57 .674 0 r
F
.44951 1.20955 m .46155 1.22404 L .46518 1.21703 L .58 .027 0 r
F
.44951 1.20955 m .44459 1.22719 L .46155 1.22404 L F
.3904 .97015 m .41714 .95264 L .42076 .95833 L 1 1 0 r
F
.3904 .97015 m .3856 .96439 L .41714 .95264 L F
.61629 1.23707 m .63822 1.24091 L .63018 1.2428 L .43 .515 0 r
F
.66954 1.2441 m .69267 1.25084 L .68296 1.25242 L .526 .644 0 r
F
.66059 1.24597 m .66954 1.2441 L .68296 1.25242 L .503 .623 0 r
F
.57534 1.23209 m .58028 1.23011 L .5952 1.23423 L .333 .319 0 r
F
.56083 1.22861 m .58028 1.23011 L .57534 1.23209 L .289 .231 0 r
F
.35553 .97818 m .38078 .95856 L .3856 .96439 L 1 .993 0 r
F
.35553 .97818 m .3496 .97234 L .38078 .95856 L F
.48382 1.21642 m .49812 1.21981 L .49924 1.21908 L .335 0 0 r
F
.48382 1.21642 m .48146 1.21897 L .49812 1.21981 L F
.82466 1.25945 m .8477 1.27507 L .83627 1.27602 L .744 .782 0 r
F
.8136 1.26094 m .82466 1.25945 L .83627 1.27602 L .736 .776 0 r
F
.54892 .93565 m .55033 .9302 L .58344 .93085 L .835 .887 0 r
F
.51662 .93753 m .55033 .9302 L .54892 .93565 L .884 .918 0 r
F
.75694 1.2532 m .78052 1.26496 L .76954 1.26614 L .674 .743 0 r
F
.74648 1.25485 m .75694 1.2532 L .76954 1.26614 L .66 .733 0 r
F
.42076 .95833 m .44976 .94323 L .45216 .94886 L 1 1 0 r
F
.42076 .95833 m .41714 .95264 L .44976 .94323 L F
.56083 1.22861 m .56463 1.22671 L .58028 1.23011 L .289 .231 0 r
F
.54579 1.22568 m .56463 1.22671 L .56083 1.22861 L .227 .137 0 r
F
.71219 1.24729 m .73603 1.2564 L .72562 1.25784 L .609 .704 0 r
F
.70242 1.24913 m .71219 1.24729 L .72562 1.25784 L .59 .69 0 r
F
.5952 1.23423 m .60126 1.23208 L .61629 1.23707 L .389 .43 0 r
F
.58028 1.23011 m .60126 1.23208 L .5952 1.23423 L .36 .365 0 r
F
.6463 1.23883 m .66954 1.2441 L .66059 1.24597 L .481 .604 0 r
F
.63822 1.24091 m .6463 1.23883 L .66059 1.24597 L .46 .578 0 r
F
.51662 .93753 m .51676 .932 L .55033 .9302 L .884 .918 0 r
F
.48424 .94191 m .51676 .932 L .51662 .93753 L .948 .952 0 r
F
.82466 1.25945 m .83575 1.2579 L .8477 1.27507 L .744 .782 0 r
F
.49988 1.21916 m .51496 1.22071 L .51483 1.22114 L .151 0 0 r
F
.50038 1.2192 m .51496 1.22071 L .49988 1.21916 L F
.49924 1.21908 m .50038 1.2192 L .49988 1.21916 L F
.49924 1.21908 m .49812 1.21981 L .51496 1.22071 L F
.5013 1.21998 m .51509 1.22007 L .51496 1.22071 L .076 0 0 r
F
.49812 1.21981 m .50288 1.21988 L .5013 1.21998 L F
.50288 1.21988 m .51509 1.22007 L .5013 1.21998 L F
.49812 1.21981 m .497 1.22045 L .51382 1.2201 L F
.49812 1.21981 m .51382 1.2201 L .51292 1.22004 L F
.51292 1.22004 m .51382 1.2201 L .51509 1.22007 L F
.497 1.22045 m .51523 1.21907 L .51509 1.22007 L 0 0 0 r
F
.497 1.22045 m .49587 1.22066 L .5126 1.21929 L F
.51142 1.21936 m .5126 1.21929 L .51523 1.21907 L F
.497 1.22045 m .5126 1.21929 L .51142 1.21936 L F
.61958 .92858 m .62348 .92322 L .65683 .92892 L .808 .858 0 r
F
.58344 .93085 m .58611 .9254 L .61958 .92858 L .817 .87 0 r
F
.55033 .9302 m .58611 .9254 L .58344 .93085 L .851 .894 0 r
F
.45216 .94886 m .4831 .93633 L .48424 .94191 L 1 .986 0 r
F
.45216 .94886 m .44976 .94323 L .4831 .93633 L F
.54579 1.22568 m .5484 1.22403 L .56463 1.22671 L .227 .137 0 r
F
.5304 1.22324 m .5484 1.22403 L .54579 1.22568 L .14 .119 0 r
F
.48424 .94191 m .4831 .93633 L .51676 .932 L .948 .952 0 r
F
.67852 1.24207 m .70242 1.24913 L .69267 1.25084 L .548 .664 0 r
F
.66954 1.2441 m .67852 1.24207 L .69267 1.25084 L .526 .644 0 r
F
.76743 1.25145 m .79153 1.26369 L .78052 1.26496 L .687 .752 0 r
F
.75694 1.2532 m .76743 1.25145 L .78052 1.26496 L .674 .743 0 r
F
.58611 .9254 m .62348 .92322 L .61958 .92858 L .831 .876 0 r
F
.51483 1.22114 m .53178 1.22205 L .5304 1.22324 L .015 .105 0 r
F
.51483 1.22114 m .51496 1.22071 L .53178 1.22205 L F
.61629 1.23707 m .6234 1.2349 L .63822 1.24091 L .43 .515 0 r
F
.60126 1.23208 m .6234 1.2349 L .61629 1.23707 L .411 .471 0 r
F
.3856 .96439 m .4135 .94684 L .41714 .95264 L 1 1 0 r
F
.3856 .96439 m .38078 .95856 L .4135 .94684 L F
.6234 1.2349 m .6463 1.23883 L .63822 1.24091 L .447 .549 0 r
F
.5304 1.22324 m .53178 1.22205 L .5484 1.22403 L .14 .119 0 r
F
.3496 .97234 m .37595 .95267 L .38078 .95856 L 1 .986 0 r
F
.3496 .97234 m .34365 .96648 L .37595 .95267 L F
.46518 1.21703 m .47908 1.22178 L .48146 1.21897 L .414 0 0 r
F
.46518 1.21703 m .46155 1.22404 L .47908 1.22178 L F
.72198 1.24533 m .74648 1.25485 L .73603 1.2564 L .626 .717 0 r
F
.71219 1.24729 m .72198 1.24533 L .73603 1.2564 L .609 .704 0 r
F
.58028 1.23011 m .58525 1.2279 L .60126 1.23208 L .36 .365 0 r
F
.56463 1.22671 m .58525 1.2279 L .58028 1.23011 L .322 .279 0 r
F
.55033 .9302 m .55175 .92462 L .58611 .9254 L .851 .894 0 r
F
.51676 .932 m .55175 .92462 L .55033 .9302 L .898 .922 0 r
F
.77795 1.24962 m .80255 1.26235 L .79153 1.26369 L .698 .76 0 r
F
.76743 1.25145 m .77795 1.24962 L .79153 1.26369 L .687 .752 0 r
F
.41714 .95264 m .44735 .93746 L .44976 .94323 L 1 1 0 r
F
.41714 .95264 m .4135 .94684 L .44735 .93746 L F
.65441 1.23658 m .67852 1.24207 L .66954 1.2441 L .504 .629 0 r
F
.6463 1.23883 m .65441 1.23658 L .66954 1.2441 L .481 .604 0 r
F
.68753 1.2399 m .71219 1.24729 L .70242 1.24913 L .569 .681 0 r
F
.67852 1.24207 m .68753 1.2399 L .70242 1.24913 L .548 .664 0 r
F
.60126 1.23208 m .60735 1.22972 L .6234 1.2349 L .411 .471 0 r
F
.58525 1.2279 m .60735 1.22972 L .60126 1.23208 L .388 .413 0 r
F
.51676 .932 m .51689 .92633 L .55175 .92462 L .898 .922 0 r
F
.4831 .93633 m .51689 .92633 L .51676 .932 L .957 .953 0 r
F
.56463 1.22671 m .56845 1.22458 L .58525 1.2279 L .322 .279 0 r
F
.5484 1.22403 m .56845 1.22458 L .56463 1.22671 L .27 .175 0 r
F
.58611 .9254 m .5888 .91984 L .62348 .92322 L .831 .876 0 r
F
.55175 .92462 m .5888 .91984 L .58611 .9254 L .864 .898 0 r
F
.48146 1.21897 m .497 1.22045 L .49812 1.21981 L .261 0 0 r
F
.48146 1.21897 m .47908 1.22178 L .497 1.22045 L F
.44976 .94323 m .48196 .9306 L .4831 .93633 L 1 .982 0 r
F
.44976 .94323 m .44735 .93746 L .48196 .9306 L F
.73181 1.24326 m .75694 1.2532 L .74648 1.25485 L .642 .729 0 r
F
.72198 1.24533 m .73181 1.24326 L .74648 1.25485 L .626 .717 0 r
F
.63053 1.23253 m .65441 1.23658 L .6463 1.23883 L .464 .58 0 r
F
.6234 1.2349 m .63053 1.23253 L .6463 1.23883 L .447 .549 0 r
F
.38078 .95856 m .40984 .94094 L .4135 .94684 L 1 .997 0 r
F
.38078 .95856 m .37595 .95267 L .40984 .94094 L F
.4831 .93633 m .48196 .9306 L .51689 .92633 L .957 .953 0 r
F
.78849 1.24772 m .8136 1.26094 L .80255 1.26235 L .709 .767 0 r
F
.77795 1.24962 m .78849 1.24772 L .80255 1.26235 L .698 .76 0 r
F
.60735 1.22972 m .63053 1.23253 L .6234 1.2349 L .432 .511 0 r
F
.5484 1.22403 m .55102 1.22214 L .56845 1.22458 L .27 .175 0 r
F
.53178 1.22205 m .55102 1.22214 L .5484 1.22403 L .194 .126 0 r
F
.53178 1.22205 m .53317 1.22063 L .55102 1.22214 L F
.51496 1.22071 m .53317 1.22063 L .53178 1.22205 L .081 .115 0 r
F
.51496 1.22071 m .51509 1.22007 L .53317 1.22063 L F
.69656 1.23759 m .72198 1.24533 L .71219 1.24729 L .589 .697 0 r
F
.68753 1.2399 m .69656 1.23759 L .71219 1.24729 L .569 .681 0 r
F
.66254 1.23416 m .68753 1.2399 L .67852 1.24207 L .527 .651 0 r
F
.65441 1.23658 m .66254 1.23416 L .67852 1.24207 L .504 .629 0 r
F
.58525 1.2279 m .59025 1.22547 L .60735 1.22972 L .388 .413 0 r
F
.56845 1.22458 m .59025 1.22547 L .58525 1.2279 L .357 .335 0 r
F
.79905 1.24573 m .82466 1.25945 L .8136 1.26094 L .719 .774 0 r
F
.78849 1.24772 m .79905 1.24573 L .8136 1.26094 L .709 .767 0 r
F
.55175 .92462 m .55317 .91891 L .5888 .91984 L .864 .898 0 r
F
.51689 .92633 m .55317 .91891 L .55175 .92462 L .908 .924 0 r
F
.74166 1.24108 m .76743 1.25145 L .75694 1.2532 L .656 .739 0 r
F
.73181 1.24326 m .74166 1.24108 L .75694 1.2532 L .642 .729 0 r
F
.4135 .94684 m .44494 .93158 L .44735 .93746 L 1 .994 0 r
F
.4135 .94684 m .40984 .94094 L .44494 .93158 L F
.44459 1.22719 m .45789 1.23031 L .46155 1.22404 L .333 0 0 r
F
.44459 1.22719 m .43963 1.24382 L .45789 1.23031 L F
.42801 1.26202 m .43963 1.24382 L .43711 1.24291 L 0 0 0 r
F
.42801 1.26202 m .42174 1.2878 L .43659 1.25131 L F
.43031 1.25842 m .43659 1.25131 L .43963 1.24382 L F
.42801 1.26202 m .43659 1.25131 L .43031 1.25842 L F
.43602 1.2527 m .43473 1.25095 L .43963 1.24382 L 1 1 0 r
F
.42174 1.2878 m .43473 1.25095 L .43602 1.2527 L F
.43473 1.25095 m .42987 1.25218 L .43348 1.24925 L .717 .345 0 r
F
.43963 1.24382 m .43895 1.24481 L .44001 1.24396 L 0 0 0 r
F
.44136 1.24444 m .43473 1.25095 L .44201 1.24468 L F
.43963 1.24382 m .44201 1.24468 L .45424 1.23413 L F
.44783 1.23776 m .45424 1.23413 L .45789 1.23031 L F
.43963 1.24382 m .45424 1.23413 L .44783 1.23776 L F
.45789 1.23031 m .45424 1.23413 L .47429 1.22524 L F
.45424 1.23413 m .45058 1.23538 L .46014 1.23079 L .374 .148 0 r
F
.46155 1.22404 m .45789 1.23031 L .47669 1.22405 L .265 0 0 r
F
.45789 1.23031 m .47429 1.22524 L .47669 1.22405 L 0 0 0 r
F
.45424 1.23413 m .46014 1.23079 L .47188 1.22517 L .374 .148 0 r
F
.43473 1.25095 m .43348 1.24925 L .45058 1.23538 L .717 .345 0 r
F
.43473 1.25095 m .45058 1.23538 L .45068 1.23534 L F
.44381 1.24312 m .45068 1.23534 L .45424 1.23413 L F
.43473 1.25095 m .45068 1.23534 L .44381 1.24312 L F
.43711 1.24291 m .43963 1.24382 L .44459 1.22719 L 0 0 0 r
F
.6377 1.22997 m .66254 1.23416 L .65441 1.23658 L .483 .609 0 r
F
.63053 1.23253 m .6377 1.22997 L .65441 1.23658 L .464 .58 0 r
F
.60735 1.22972 m .61346 1.22715 L .63053 1.23253 L .432 .511 0 r
F
.59025 1.22547 m .61346 1.22715 L .60735 1.22972 L .414 .462 0 r
F
.51689 .92633 m .51703 .92053 L .55317 .91891 L .908 .924 0 r
F
.48196 .9306 m .51703 .92053 L .51689 .92633 L .963 .952 0 r
F
.44735 .93746 m .48081 .92475 L .48196 .9306 L 1 .977 0 r
F
.44735 .93746 m .44494 .93158 L .48081 .92475 L F
.80964 1.24368 m .83575 1.2579 L .82466 1.25945 L .729 .78 0 r
F
.79905 1.24573 m .80964 1.24368 L .82466 1.25945 L .719 .774 0 r
F
.61346 1.22715 m .6377 1.22997 L .63053 1.23253 L .452 .549 0 r
F
.56845 1.22458 m .57228 1.22219 L .59025 1.22547 L .357 .335 0 r
F
.55102 1.22214 m .57228 1.22219 L .56845 1.22458 L .315 .234 0 r
F
.48196 .9306 m .48081 .92475 L .51703 .92053 L .963 .952 0 r
F
.70562 1.23516 m .73181 1.24326 L .72198 1.24533 L .608 .711 0 r
F
.69656 1.23759 m .70562 1.23516 L .72198 1.24533 L .589 .697 0 r
F
.46155 1.22404 m .47669 1.22405 L .47908 1.22178 L .265 0 0 r
F
.75154 1.23881 m .77795 1.24962 L .76743 1.25145 L .67 .749 0 r
F
.74166 1.24108 m .75154 1.23881 L .76743 1.25145 L .656 .739 0 r
F
.6707 1.23159 m .69656 1.23759 L .68753 1.2399 L .549 .671 0 r
F
.66254 1.23416 m .6707 1.23159 L .68753 1.2399 L .527 .651 0 r
F
.55102 1.22214 m .55365 1.21998 L .57228 1.22219 L .315 .234 0 r
F
.53317 1.22063 m .55365 1.21998 L .55102 1.22214 L .255 .133 0 r
F
.47908 1.22178 m .47669 1.22405 L .49587 1.22066 L .121 0 0 r
F
.48548 1.22131 m .49587 1.22066 L .497 1.22045 L F
.48671 1.22127 m .49587 1.22066 L .48548 1.22131 L F
.47669 1.22405 m .49473 1.22022 L .49587 1.22066 L 0 0 0 r
F
.47669 1.22405 m .47429 1.22524 L .49092 1.22116 L F
.49024 1.22118 m .49092 1.22116 L .49473 1.22022 L F
.47669 1.22405 m .49092 1.22116 L .49024 1.22118 L F
.47908 1.22178 m .48671 1.22127 L .48548 1.22131 L .121 0 0 r
F
.80964 1.24368 m .82025 1.24156 L .83575 1.2579 L .729 .78 0 r
F
.59025 1.22547 m .59526 1.2228 L .61346 1.22715 L .414 .462 0 r
F
.57228 1.22219 m .59526 1.2228 L .59025 1.22547 L .39 .395 0 r
F
.53317 1.22063 m .53456 1.21891 L .55365 1.21998 L .255 .133 0 r
F
.51509 1.22007 m .53456 1.21891 L .53317 1.22063 L .167 .126 0 r
F
.64489 1.22724 m .6707 1.23159 L .66254 1.23416 L .507 .635 0 r
F
.6377 1.22997 m .64489 1.22724 L .66254 1.23416 L .483 .609 0 r
F
.51509 1.22007 m .51523 1.21907 L .53456 1.21891 L .167 .126 0 r
F
.76144 1.23645 m .78849 1.24772 L .77795 1.24962 L .683 .757 0 r
F
.75154 1.23881 m .76144 1.23645 L .77795 1.24962 L .67 .749 0 r
F
.71471 1.23261 m .74166 1.24108 L .73181 1.24326 L .625 .724 0 r
F
.70562 1.23516 m .71471 1.23261 L .73181 1.24326 L .608 .711 0 r
F
.61346 1.22715 m .6196 1.22438 L .6377 1.22997 L .452 .549 0 r
F
.59526 1.2228 m .6196 1.22438 L .61346 1.22715 L .438 .509 0 r
F
.6196 1.22438 m .64489 1.22724 L .6377 1.22997 L .469 .584 0 r
F
.67889 1.22888 m .70562 1.23516 L .69656 1.23759 L .571 .689 0 r
F
.6707 1.23159 m .67889 1.22888 L .69656 1.23759 L .549 .671 0 r
F
.57228 1.22219 m .57613 1.21955 L .59526 1.2228 L .39 .395 0 r
F
.55365 1.21998 m .57613 1.21955 L .57228 1.22219 L .36 .306 0 r
F
.77137 1.234 m .79905 1.24573 L .78849 1.24772 L .695 .765 0 r
F
.76144 1.23645 m .77137 1.234 L .78849 1.24772 L .683 .757 0 r
F
.72383 1.22996 m .75154 1.23881 L .74166 1.24108 L .641 .736 0 r
F
.71471 1.23261 m .72383 1.22996 L .74166 1.24108 L .625 .724 0 r
F
.65211 1.22434 m .67889 1.22888 L .6707 1.23159 L .531 .659 0 r
F
.64489 1.22724 m .65211 1.22434 L .6707 1.23159 L .507 .635 0 r
F
.55365 1.21998 m .55629 1.21752 L .57613 1.21955 L .36 .306 0 r
F
.53456 1.21891 m .55629 1.21752 L .55365 1.21998 L .318 .197 0 r
F
.59526 1.2228 m .60029 1.2199 L .6196 1.22438 L .438 .509 0 r
F
.57613 1.21955 m .60029 1.2199 L .59526 1.2228 L .421 .455 0 r
F
.68711 1.22603 m .71471 1.23261 L .70562 1.23516 L .591 .705 0 r
F
.67889 1.22888 m .68711 1.22603 L .70562 1.23516 L .571 .689 0 r
F
.62576 1.22141 m .65211 1.22434 L .64489 1.22724 L .489 .616 0 r
F
.6196 1.22438 m .62576 1.22141 L .64489 1.22724 L .469 .584 0 r
F
.53456 1.21891 m .53596 1.21682 L .55629 1.21752 L .318 .197 0 r
F
.51523 1.21907 m .53596 1.21682 L .53456 1.21891 L .26 .137 0 r
F
.78133 1.23148 m .80964 1.24368 L .79905 1.24573 L .705 .772 0 r
F
.77137 1.234 m .78133 1.23148 L .79905 1.24573 L .695 .765 0 r
F
.60029 1.2199 m .62576 1.22141 L .6196 1.22438 L .459 .553 0 r
F
.51523 1.21907 m .51536 1.21762 L .53596 1.21682 L .26 .137 0 r
F
.49587 1.22066 m .51536 1.21762 L .51523 1.21907 L .18 .129 0 r
F
.49587 1.22066 m .49473 1.22022 L .51536 1.21762 L F
.73297 1.22719 m .76144 1.23645 L .75154 1.23881 L .656 .746 0 r
F
.72383 1.22996 m .73297 1.22719 L .75154 1.23881 L .641 .736 0 r
F
.57613 1.21955 m .58 1.21665 L .60029 1.2199 L .421 .455 0 r
F
.55629 1.21752 m .58 1.21665 L .57613 1.21955 L .401 .384 0 r
F
.65935 1.22128 m .68711 1.22603 L .67889 1.22888 L .555 .68 0 r
F
.65211 1.22434 m .65935 1.22128 L .67889 1.22888 L .531 .659 0 r
F
.79131 1.22888 m .82025 1.24156 L .80964 1.24368 L .716 .779 0 r
F
.78133 1.23148 m .79131 1.22888 L .80964 1.24368 L .705 .772 0 r
F
.69535 1.22306 m .72383 1.22996 L .71471 1.23261 L .61 .72 0 r
F
.68711 1.22603 m .69535 1.22306 L .71471 1.23261 L .591 .705 0 r
F
.60029 1.2199 m .60535 1.21679 L .62576 1.22141 L .459 .553 0 r
F
.58 1.21665 m .60535 1.21679 L .60029 1.2199 L .449 .513 0 r
F
.55629 1.21752 m .55895 1.21475 L .58 1.21665 L .401 .384 0 r
F
.53596 1.21682 m .55895 1.21475 L .55629 1.21752 L .377 .292 0 r
F
.63194 1.21825 m .65935 1.22128 L .65211 1.22434 L .515 .645 0 r
F
.62576 1.22141 m .63194 1.21825 L .65211 1.22434 L .489 .616 0 r
F
.74214 1.22434 m .77137 1.234 L .76144 1.23645 L .67 .756 0 r
F
.73297 1.22719 m .74214 1.22434 L .76144 1.23645 L .656 .746 0 r
F
.60535 1.21679 m .63194 1.21825 L .62576 1.22141 L .479 .593 0 r
F
.79131 1.22888 m .80132 1.22621 L .82025 1.24156 L .716 .779 0 r
F
.53596 1.21682 m .53737 1.21435 L .55895 1.21475 L .377 .292 0 r
F
.51536 1.21762 m .53737 1.21435 L .53596 1.21682 L .347 .187 0 r
F
.66662 1.21808 m .69535 1.22306 L .68711 1.22603 L .577 .699 0 r
F
.65935 1.22128 m .66662 1.21808 L .68711 1.22603 L .555 .68 0 r
F
.70362 1.21997 m .73297 1.22719 L .72383 1.22996 L .628 .733 0 r
F
.69535 1.22306 m .70362 1.21997 L .72383 1.22996 L .61 .72 0 r
F
.51536 1.21762 m .5155 1.21566 L .53737 1.21435 L .347 .187 0 r
F
.49473 1.22022 m .5155 1.21566 L .51536 1.21762 L .316 .145 0 r
F
.49473 1.22022 m .49359 1.21904 L .5155 1.21566 L F
.47429 1.22524 m .49359 1.21904 L .49473 1.22022 L .302 .143 0 r
F
.47429 1.22524 m .47188 1.22517 L .49359 1.21904 L F
.45424 1.23413 m .47188 1.22517 L .47429 1.22524 L .374 .148 0 r
F
.58 1.21665 m .58389 1.2135 L .60535 1.21679 L .449 .513 0 r
F
.55895 1.21475 m .58389 1.2135 L .58 1.21665 L .438 .461 0 r
F
.75134 1.22139 m .78133 1.23148 L .77137 1.234 L .682 .764 0 r
F
.74214 1.22434 m .75134 1.22139 L .77137 1.234 L .67 .756 0 r
F
.63815 1.21492 m .66662 1.21808 L .65935 1.22128 L .541 .67 0 r
F
.63194 1.21825 m .63815 1.21492 L .65935 1.22128 L .515 .645 0 r
F
.41584 1.28245 m .42987 1.25218 L .43473 1.25095 L 1 1 0 r
F
.42174 1.2878 m .41584 1.28245 L .43473 1.25095 L F
.60535 1.21679 m .61042 1.21347 L .63194 1.21825 L .479 .593 0 r
F
.58389 1.2135 m .61042 1.21347 L .60535 1.21679 L .473 .565 0 r
F
.61042 1.21347 m .63815 1.21492 L .63194 1.21825 L .501 .629 0 r
F
.55895 1.21475 m .56162 1.21168 L .58389 1.2135 L .438 .461 0 r
F
.53737 1.21435 m .56162 1.21168 L .55895 1.21475 L .427 .396 0 r
F
.71192 1.21676 m .74214 1.22434 L .73297 1.22719 L .644 .744 0 r
F
.70362 1.21997 m .71192 1.21676 L .73297 1.22719 L .628 .733 0 r
F
.67392 1.21473 m .70362 1.21997 L .69535 1.22306 L .598 .716 0 r
F
.66662 1.21808 m .67392 1.21473 L .69535 1.22306 L .577 .699 0 r
F
.76057 1.21836 m .79131 1.22888 L .78133 1.23148 L .694 .772 0 r
F
.75134 1.22139 m .76057 1.21836 L .78133 1.23148 L .682 .764 0 r
F
.53737 1.21435 m .53878 1.2115 L .56162 1.21168 L .427 .396 0 r
F
.5155 1.21566 m .53878 1.2115 L .53737 1.21435 L .42 .32 0 r
F
.58389 1.2135 m .58779 1.21011 L .61042 1.21347 L .473 .565 0 r
F
.56162 1.21168 m .58779 1.21011 L .58389 1.2135 L .469 .531 0 r
F
.5155 1.21566 m .51564 1.2132 L .53878 1.2115 L .42 .32 0 r
F
.49359 1.21904 m .51564 1.2132 L .5155 1.21566 L .427 .249 0 r
F
.64439 1.21143 m .67392 1.21473 L .66662 1.21808 L .566 .693 0 r
F
.63815 1.21492 m .64439 1.21143 L .66662 1.21808 L .541 .67 0 r
F
.49359 1.21904 m .49245 1.21714 L .51564 1.2132 L .427 .249 0 r
F
.47188 1.22517 m .49245 1.21714 L .49359 1.21904 L .47 .222 0 r
F
.47188 1.22517 m .46946 1.22394 L .49245 1.21714 L F
.45058 1.23538 m .46946 1.22394 L .47188 1.22517 L .601 .365 0 r
F
.72025 1.21346 m .75134 1.22139 L .74214 1.22434 L .659 .755 0 r
F
.71192 1.21676 m .72025 1.21346 L .74214 1.22434 L .644 .744 0 r
F
.76983 1.21526 m .80132 1.22621 L .79131 1.22888 L .705 .779 0 r
F
.76057 1.21836 m .76983 1.21526 L .79131 1.22888 L .694 .772 0 r
F
.61042 1.21347 m .61552 1.20995 L .63815 1.21492 L .501 .629 0 r
F
.58779 1.21011 m .61552 1.20995 L .61042 1.21347 L .494 .611 0 r
F
.45058 1.23538 m .44691 1.23464 L .46946 1.22394 L .601 .365 0 r
F
.42987 1.25218 m .44691 1.23464 L .45058 1.23538 L 1 .972 0 r
F
.61552 1.20995 m .64439 1.21143 L .63815 1.21492 L .53 .66 0 r
F
.41584 1.28245 m .40992 1.27709 L .42987 1.25218 L 1 1 0 r
F
.68124 1.21127 m .71192 1.21676 L .70362 1.21997 L .618 .731 0 r
F
.67392 1.21473 m .68124 1.21127 L .70362 1.21997 L .598 .716 0 r
F
.56162 1.21168 m .56429 1.20833 L .58779 1.21011 L .469 .531 0 r
F
.53878 1.2115 m .56429 1.20833 L .56162 1.21168 L .469 .493 0 r
F
.42987 1.25218 m .42502 1.25059 L .44691 1.23464 L 1 .972 0 r
F
.40992 1.27709 m .42502 1.25059 L .42987 1.25218 L 1 1 0 r
F
.76983 1.21526 m .77911 1.21208 L .80132 1.22621 L .705 .779 0 r
F
.53878 1.2115 m .5402 1.2083 L .56429 1.20833 L .469 .493 0 r
F
.51564 1.2132 m .5402 1.2083 L .53878 1.2115 L .477 .457 0 r
F
.7286 1.21006 m .76057 1.21836 L .75134 1.22139 L .673 .764 0 r
F
.72025 1.21346 m .7286 1.21006 L .75134 1.22139 L .659 .755 0 r
F
.65064 1.20779 m .68124 1.21127 L .67392 1.21473 L .589 .713 0 r
F
.64439 1.21143 m .65064 1.20779 L .67392 1.21473 L .566 .693 0 r
F
.58779 1.21011 m .59171 1.20649 L .61552 1.20995 L .494 .611 0 r
F
.56429 1.20833 m .59171 1.20649 L .58779 1.21011 L .495 .592 0 r
F
.40992 1.27709 m .40398 1.2717 L .42502 1.25059 L 1 1 0 r
F
.68859 1.20768 m .72025 1.21346 L .71192 1.21676 L .636 .744 0 r
F
.68124 1.21127 m .68859 1.20768 L .71192 1.21676 L .618 .731 0 r
F
.51564 1.2132 m .51577 1.21027 L .5402 1.2083 L .477 .457 0 r
F
.49245 1.21714 m .51577 1.21027 L .51564 1.2132 L .505 .444 0 r
F
.62064 1.20625 m .65064 1.20779 L .64439 1.21143 L .558 .688 0 r
F
.61552 1.20995 m .62064 1.20625 L .64439 1.21143 L .53 .66 0 r
F
.59171 1.20649 m .62064 1.20625 L .61552 1.20995 L .524 .651 0 r
F
.49245 1.21714 m .4913 1.21458 L .51577 1.21027 L .505 .444 0 r
F
.46946 1.22394 m .4913 1.21458 L .49245 1.21714 L .569 .506 0 r
F
.46946 1.22394 m .46703 1.22176 L .4913 1.21458 L F
.44691 1.23464 m .46703 1.22176 L .46946 1.22394 L .778 .751 0 r
F
.44691 1.23464 m .44324 1.23253 L .46703 1.22176 L F
.42502 1.25059 m .44324 1.23253 L .44691 1.23464 L 1 1 0 r
F
.56429 1.20833 m .56698 1.2047 L .59171 1.20649 L .495 .592 0 r
F
.5402 1.2083 m .56698 1.2047 L .56429 1.20833 L .502 .577 0 r
F
.73698 1.20657 m .76983 1.21526 L .76057 1.21836 L .686 .773 0 r
F
.7286 1.21006 m .73698 1.20657 L .76057 1.21836 L .673 .764 0 r
F
.42502 1.25059 m .42016 1.24755 L .44324 1.23253 L 1 1 0 r
F
.40398 1.2717 m .42016 1.24755 L .42502 1.25059 L F
.65692 1.20401 m .68859 1.20768 L .68124 1.21127 L .611 .73 0 r
F
.65064 1.20779 m .65692 1.20401 L .68124 1.21127 L .589 .713 0 r
F
.40398 1.2717 m .39802 1.26629 L .42016 1.24755 L 1 1 0 r
F
.69597 1.20398 m .7286 1.21006 L .72025 1.21346 L .652 .755 0 r
F
.68859 1.20768 m .69597 1.20398 L .72025 1.21346 L .636 .744 0 r
F
.5402 1.2083 m .54162 1.20476 L .56698 1.2047 L .502 .577 0 r
F
.51577 1.21027 m .54162 1.20476 L .5402 1.2083 L .52 .574 0 r
F
.59171 1.20649 m .59564 1.20266 L .62064 1.20625 L .524 .651 0 r
F
.56698 1.2047 m .59564 1.20266 L .59171 1.20649 L .524 .644 0 r
F
.62578 1.20238 m .65692 1.20401 L .65064 1.20779 L .585 .711 0 r
F
.62064 1.20625 m .62578 1.20238 L .65064 1.20779 L .558 .688 0 r
F
.59564 1.20266 m .62578 1.20238 L .62064 1.20625 L .556 .685 0 r
F
.51577 1.21027 m .51591 1.20691 L .54162 1.20476 L .52 .574 0 r
F
.4913 1.21458 m .51591 1.20691 L .51577 1.21027 L .556 .605 0 r
F
.74539 1.203 m .77911 1.21208 L .76983 1.21526 L .698 .78 0 r
F
.73698 1.20657 m .74539 1.203 L .76983 1.21526 L .686 .773 0 r
F
.4913 1.21458 m .49014 1.21145 L .51591 1.20691 L .556 .605 0 r
F
.46703 1.22176 m .49014 1.21145 L .4913 1.21458 L .669 .712 0 r
F
.46703 1.22176 m .4646 1.21881 L .49014 1.21145 L F
.44324 1.23253 m .4646 1.21881 L .46703 1.22176 L .932 .926 0 r
F
.44324 1.23253 m .43956 1.22947 L .4646 1.21881 L F
.42016 1.24755 m .43956 1.22947 L .44324 1.23253 L 1 1 0 r
F
.66323 1.20009 m .69597 1.20398 L .68859 1.20768 L .631 .745 0 r
F
.65692 1.20401 m .66323 1.20009 L .68859 1.20768 L .611 .73 0 r
F
.56698 1.2047 m .56968 1.20082 L .59564 1.20266 L .524 .644 0 r
F
.54162 1.20476 m .56968 1.20082 L .56698 1.2047 L .536 .645 0 r
F
.42016 1.24755 m .41529 1.24369 L .43956 1.22947 L 1 1 0 r
F
.39802 1.26629 m .41529 1.24369 L .42016 1.24755 L F
.70337 1.20017 m .73698 1.20657 L .7286 1.21006 L .668 .766 0 r
F
.69597 1.20398 m .70337 1.20017 L .7286 1.21006 L .652 .755 0 r
F
.39802 1.26629 m .39204 1.26087 L .41529 1.24369 L 1 1 0 r
F
.74539 1.203 m .75383 1.19934 L .77911 1.21208 L .698 .78 0 r
F
.59564 1.20266 m .5996 1.19863 L .62578 1.20238 L .556 .685 0 r
F
.56968 1.20082 m .5996 1.19863 L .59564 1.20266 L .562 .687 0 r
F
.63094 1.19835 m .66323 1.20009 L .65692 1.20401 L .609 .732 0 r
F
.62578 1.20238 m .63094 1.19835 L .65692 1.20401 L .585 .711 0 r
F
.54162 1.20476 m .54305 1.20093 L .56968 1.20082 L .536 .645 0 r
F
.51591 1.20691 m .54305 1.20093 L .54162 1.20476 L .566 .664 0 r
F
.5996 1.19863 m .63094 1.19835 L .62578 1.20238 L .586 .714 0 r
F
.51591 1.20691 m .51605 1.20318 L .54305 1.20093 L .566 .664 0 r
F
.49014 1.21145 m .51605 1.20318 L .51591 1.20691 L .633 .718 0 r
F
.7108 1.19627 m .74539 1.203 L .73698 1.20657 L .682 .775 0 r
F
.70337 1.20017 m .7108 1.19627 L .73698 1.20657 L .668 .766 0 r
F
.66956 1.19606 m .70337 1.20017 L .69597 1.20398 L .65 .758 0 r
F
.66323 1.20009 m .66956 1.19606 L .69597 1.20398 L .631 .745 0 r
F
.39204 1.26087 m .4104 1.23932 L .41529 1.24369 L 1 1 0 r
F
.39204 1.26087 m .38603 1.25542 L .4104 1.23932 L F
.49014 1.21145 m .48899 1.20785 L .51605 1.20318 L .633 .718 0 r
F
.4646 1.21881 m .48899 1.20785 L .49014 1.21145 L .772 .831 0 r
F
.41529 1.24369 m .43587 1.22575 L .43956 1.22947 L 1 1 0 r
F
.41529 1.24369 m .4104 1.23932 L .43587 1.22575 L F
.4646 1.21881 m .46216 1.21527 L .48899 1.20785 L .772 .831 0 r
F
.43956 1.22947 m .46216 1.21527 L .4646 1.21881 L 1 .994 0 r
F
.43956 1.22947 m .43587 1.22575 L .46216 1.21527 L F
.56968 1.20082 m .5724 1.19672 L .5996 1.19863 L .562 .687 0 r
F
.54305 1.20093 m .5724 1.19672 L .56968 1.20082 L .581 .699 0 r
F
.63612 1.19417 m .66956 1.19606 L .66323 1.20009 L .632 .749 0 r
F
.63094 1.19835 m .63612 1.19417 L .66323 1.20009 L .609 .732 0 r
F
.5996 1.19863 m .60356 1.19443 L .63094 1.19835 L .586 .714 0 r
F
.5724 1.19672 m .60356 1.19443 L .5996 1.19863 L .597 .722 0 r
F
.60356 1.19443 m .63612 1.19417 L .63094 1.19835 L .615 .738 0 r
F
.54305 1.20093 m .54449 1.19682 L .5724 1.19672 L .581 .699 0 r
F
.51605 1.20318 m .54449 1.19682 L .54305 1.20093 L .622 .731 0 r
F
.71825 1.19228 m .75383 1.19934 L .74539 1.203 L .695 .783 0 r
F
.7108 1.19627 m .71825 1.19228 L .74539 1.203 L .682 .775 0 r
F
.67591 1.19191 m .7108 1.19627 L .70337 1.20017 L .666 .77 0 r
F
.66956 1.19606 m .67591 1.19191 L .70337 1.20017 L .65 .758 0 r
F
.38603 1.25542 m .4055 1.23461 L .4104 1.23932 L 1 1 0 r
F
.38603 1.25542 m .38 1.24995 L .4055 1.23461 L F
.51605 1.20318 m .51619 1.19912 L .54449 1.19682 L .622 .731 0 r
F
.48899 1.20785 m .51619 1.19912 L .51605 1.20318 L .702 .793 0 r
F
.4104 1.23932 m .43217 1.22154 L .43587 1.22575 L 1 1 0 r
F
.4104 1.23932 m .4055 1.23461 L .43217 1.22154 L F
.48899 1.20785 m .48783 1.20385 L .51619 1.19912 L .702 .793 0 r
F
.46216 1.21527 m .48783 1.20385 L .48899 1.20785 L .842 .896 0 r
F
.43587 1.22575 m .45971 1.21127 L .46216 1.21527 L 1 1 0 r
F
.43587 1.22575 m .43217 1.22154 L .45971 1.21127 L F
.5724 1.19672 m .57512 1.19241 L .60356 1.19443 L .597 .722 0 r
F
.54449 1.19682 m .57512 1.19241 L .5724 1.19672 L .623 .742 0 r
F
.46216 1.21527 m .45971 1.21127 L .48783 1.20385 L .842 .896 0 r
F
.64132 1.18986 m .67591 1.19191 L .66956 1.19606 L .652 .764 0 r
F
.63612 1.19417 m .64132 1.18986 L .66956 1.19606 L .632 .749 0 r
F
.71825 1.19228 m .72574 1.1882 L .75383 1.19934 L .695 .783 0 r
F
.60356 1.19443 m .60755 1.19006 L .63612 1.19417 L .615 .738 0 r
F
.57512 1.19241 m .60755 1.19006 L .60356 1.19443 L .63 .751 0 r
F
.60755 1.19006 m .64132 1.18986 L .63612 1.19417 L .64 .758 0 r
F
.68229 1.18765 m .71825 1.19228 L .7108 1.19627 L .682 .78 0 r
F
.67591 1.19191 m .68229 1.18765 L .7108 1.19627 L .666 .77 0 r
F
.38 1.24995 m .40058 1.22966 L .4055 1.23461 L 1 1 0 r
F
.38 1.24995 m .37395 1.24446 L .40058 1.22966 L F
.54449 1.19682 m .54593 1.19247 L .57512 1.19241 L .623 .742 0 r
F
.51619 1.19912 m .54593 1.19247 L .54449 1.19682 L .672 .779 0 r
F
.4055 1.23461 m .42846 1.21698 L .43217 1.22154 L 1 1 0 r
F
.4055 1.23461 m .40058 1.22966 L .42846 1.21698 L F
.51619 1.19912 m .51633 1.19477 L .54593 1.19247 L .672 .779 0 r
F
.48783 1.20385 m .51633 1.19477 L .51619 1.19912 L .756 .842 0 r
F
.43217 1.22154 m .45726 1.20689 L .45971 1.21127 L 1 1 0 r
F
.43217 1.22154 m .42846 1.21698 L .45726 1.20689 L F
.64654 1.18542 m .68229 1.18765 L .67591 1.19191 L .671 .777 0 r
F
.64132 1.18986 m .64654 1.18542 L .67591 1.19191 L .652 .764 0 r
F
.48783 1.20385 m .48666 1.19952 L .51633 1.19477 L .756 .842 0 r
F
.45971 1.21127 m .48666 1.19952 L .48783 1.20385 L .887 .931 0 r
F
.57512 1.19241 m .57786 1.18792 L .60755 1.19006 L .63 .751 0 r
F
.54593 1.19247 m .57786 1.18792 L .57512 1.19241 L .66 .774 0 r
F
.45971 1.21127 m .45726 1.20689 L .48666 1.19952 L .887 .931 0 r
F
.37395 1.24446 m .39564 1.22453 L .40058 1.22966 L 1 1 0 r
F
.37395 1.24446 m .36787 1.23895 L .39564 1.22453 L F
.6887 1.1833 m .72574 1.1882 L .71825 1.19228 L .696 .789 0 r
F
.68229 1.18765 m .6887 1.1833 L .71825 1.19228 L .682 .78 0 r
F
.60755 1.19006 m .61155 1.18554 L .64132 1.18986 L .64 .758 0 r
F
.57786 1.18792 m .61155 1.18554 L .60755 1.19006 L .658 .774 0 r
F
.61155 1.18554 m .64654 1.18542 L .64132 1.18986 L .663 .775 0 r
F
.54593 1.19247 m .54738 1.1879 L .57786 1.18792 L .66 .774 0 r
F
.51633 1.19477 m .54738 1.1879 L .54593 1.19247 L .712 .814 0 r
F
.40058 1.22966 m .42473 1.21214 L .42846 1.21698 L 1 1 0 r
F
.40058 1.22966 m .39564 1.22453 L .42473 1.21214 L F
.51633 1.19477 m .51647 1.19018 L .54738 1.1879 L .712 .814 0 r
F
.48666 1.19952 m .51647 1.19018 L .51633 1.19477 L .796 .874 0 r
F
.65178 1.18087 m .6887 1.1833 L .68229 1.18765 L .688 .788 0 r
F
.64654 1.18542 m .65178 1.18087 L .68229 1.18765 L .671 .777 0 r
F
.42846 1.21698 m .45479 1.20222 L .45726 1.20689 L 1 1 0 r
F
.42846 1.21698 m .42473 1.21214 L .45479 1.20222 L F
.57786 1.18792 m .5806 1.18325 L .61155 1.18554 L .658 .774 0 r
F
.54738 1.1879 m .5806 1.18325 L .57786 1.18792 L .691 .8 0 r
F
.36787 1.23895 m .39069 1.21926 L .39564 1.22453 L 1 1 0 r
F
.36787 1.23895 m .36177 1.23342 L .39069 1.21926 L F
.48666 1.19952 m .48549 1.19491 L .51647 1.19018 L .796 .874 0 r
F
.45726 1.20689 m .48549 1.19491 L .48666 1.19952 L .916 .95 0 r
F
.6887 1.1833 m .69512 1.17885 L .72574 1.1882 L .696 .789 0 r
F
.45726 1.20689 m .45479 1.20222 L .48549 1.19491 L .916 .95 0 r
F
.61557 1.18088 m .65178 1.18087 L .64654 1.18542 L .683 .789 0 r
F
.61155 1.18554 m .61557 1.18088 L .64654 1.18542 L .663 .775 0 r
F
.5806 1.18325 m .61557 1.18088 L .61155 1.18554 L .683 .792 0 r
F
.39564 1.22453 m .42098 1.20709 L .42473 1.21214 L 1 1 0 r
F
.39564 1.22453 m .39069 1.21926 L .42098 1.20709 L F
.54738 1.1879 m .54883 1.18315 L .5806 1.18325 L .691 .8 0 r
F
.51647 1.19018 m .54883 1.18315 L .54738 1.1879 L .745 .839 0 r
F
.65704 1.17621 m .69512 1.17885 L .6887 1.1833 L .703 .798 0 r
F
.65178 1.18087 m .65704 1.17621 L .6887 1.1833 L .688 .788 0 r
F
.36177 1.23342 m .38571 1.21388 L .39069 1.21926 L 1 1 0 r
F
.36177 1.23342 m .35565 1.22787 L .38571 1.21388 L F
.42473 1.21214 m .45231 1.1973 L .45479 1.20222 L F
.42473 1.21214 m .42098 1.20709 L .45231 1.1973 L F
.51647 1.19018 m .51661 1.18537 L .54883 1.18315 L .745 .839 0 r
F
.48549 1.19491 m .51661 1.18537 L .51647 1.19018 L .826 .894 0 r
F
.5806 1.18325 m .58336 1.17843 L .61557 1.18088 L .683 .792 0 r
F
.54883 1.18315 m .58336 1.17843 L .5806 1.18325 L .718 .819 0 r
F
.45479 1.20222 m .48431 1.19006 L .48549 1.19491 L .934 .959 0 r
F
.45479 1.20222 m .45231 1.1973 L .48431 1.19006 L F
.48549 1.19491 m .48431 1.19006 L .51661 1.18537 L .826 .894 0 r
F
.6196 1.17609 m .65704 1.17621 L .65178 1.18087 L .701 .801 0 r
F
.61557 1.18088 m .6196 1.17609 L .65178 1.18087 L .683 .789 0 r
F
.58336 1.17843 m .6196 1.17609 L .61557 1.18088 L .705 .808 0 r
F
.39069 1.21926 m .41723 1.20187 L .42098 1.20709 L 1 1 0 r
F
.39069 1.21926 m .38571 1.21388 L .41723 1.20187 L F
.54883 1.18315 m .55029 1.17822 L .58336 1.17843 L .718 .819 0 r
F
.51661 1.18537 m .55029 1.17822 L .54883 1.18315 L .772 .857 0 r
F
.65704 1.17621 m .66233 1.17145 L .69512 1.17885 L .703 .798 0 r
F
.35565 1.22787 m .38072 1.20841 L .38571 1.21388 L 1 1 0 r
F
.35565 1.22787 m .3495 1.2223 L .38072 1.20841 L F
.42098 1.20709 m .44983 1.19219 L .45231 1.1973 L F
.42098 1.20709 m .41723 1.20187 L .44983 1.19219 L F
.51661 1.18537 m .51675 1.18037 L .55029 1.17822 L .772 .857 0 r
F
.48431 1.19006 m .51675 1.18037 L .51661 1.18537 L .847 .907 0 r
F
.58336 1.17843 m .58613 1.17347 L .6196 1.17609 L .705 .808 0 r
F
.55029 1.17822 m .58613 1.17347 L .58336 1.17843 L .74 .834 0 r
F
.45231 1.1973 m .48313 1.18501 L .48431 1.19006 L .944 .962 0 r
F
.45231 1.1973 m .44983 1.19219 L .48313 1.18501 L F
.62365 1.17119 m .66233 1.17145 L .65704 1.17621 L .717 .811 0 r
F
.6196 1.17609 m .62365 1.17119 L .65704 1.17621 L .701 .801 0 r
F
.48431 1.19006 m .48313 1.18501 L .51675 1.18037 L .847 .907 0 r
F
.58613 1.17347 m .62365 1.17119 L .6196 1.17609 L .724 .82 0 r
F
.38571 1.21388 m .41345 1.1965 L .41723 1.20187 L 1 1 0 r
F
.38571 1.21388 m .38072 1.20841 L .41345 1.1965 L F
.3495 1.2223 m .3757 1.20286 L .38072 1.20841 L F
.3495 1.2223 m .34333 1.2167 L .3757 1.20286 L F
.55029 1.17822 m .55176 1.17313 L .58613 1.17347 L .74 .834 0 r
F
.51675 1.18037 m .55176 1.17313 L .55029 1.17822 L .793 .87 0 r
F
.41723 1.20187 m .44733 1.1869 L .44983 1.19219 L 1 1 0 r
F
.41723 1.20187 m .41345 1.1965 L .44733 1.1869 L F
.51675 1.18037 m .51689 1.17521 L .55176 1.17313 L .793 .87 0 r
F
.48313 1.18501 m .51689 1.17521 L .51675 1.18037 L .864 .915 0 r
F
.62365 1.17119 m .62772 1.16617 L .66233 1.17145 L .717 .811 0 r
F
.58613 1.17347 m .58891 1.16838 L .62365 1.17119 L .724 .82 0 r
F
.55176 1.17313 m .58891 1.16838 L .58613 1.17347 L .759 .846 0 r
F
.44983 1.19219 m .48195 1.17978 L .48313 1.18501 L .951 .962 0 r
F
.44983 1.19219 m .44733 1.1869 L .48195 1.17978 L F
.48313 1.18501 m .48195 1.17978 L .51689 1.17521 L .864 .915 0 r
F
.58891 1.16838 m .62772 1.16617 L .62365 1.17119 L .74 .83 0 r
F
.38072 1.20841 m .40967 1.19101 L .41345 1.1965 L 1 1 0 r
F
.38072 1.20841 m .3757 1.20286 L .40967 1.19101 L F
.34333 1.2167 m .37067 1.19724 L .3757 1.20286 L 1 .994 0 r
F
.34333 1.2167 m .33714 1.21109 L .37067 1.19724 L F
.55176 1.17313 m .55323 1.16791 L .58891 1.16838 L .759 .846 0 r
F
.51689 1.17521 m .55323 1.16791 L .55176 1.17313 L .81 .88 0 r
F
.41345 1.1965 m .44482 1.18147 L .44733 1.1869 L 1 .994 0 r
F
.41345 1.1965 m .40967 1.19101 L .44482 1.18147 L F
.51689 1.17521 m .51704 1.16989 L .55323 1.16791 L .81 .88 0 r
F
.48195 1.17978 m .51704 1.16989 L .51689 1.17521 L .876 .92 0 r
F
.58891 1.16838 m .59171 1.16316 L .62772 1.16617 L .74 .83 0 r
F
.55323 1.16791 m .59171 1.16316 L .58891 1.16838 L .775 .855 0 r
F
.44733 1.1869 m .48076 1.17441 L .48195 1.17978 L .954 .961 0 r
F
.44733 1.1869 m .44482 1.18147 L .48076 1.17441 L F
.3757 1.20286 m .40586 1.18542 L .40967 1.19101 L 1 .999 0 r
F
.3757 1.20286 m .37067 1.19724 L .40586 1.18542 L F
.48195 1.17978 m .48076 1.17441 L .51704 1.16989 L .876 .92 0 r
F
.55323 1.16791 m .55471 1.16255 L .59171 1.16316 L .775 .855 0 r
F
.51704 1.16989 m .55471 1.16255 L .55323 1.16791 L .823 .887 0 r
F
.40967 1.19101 m .44231 1.17591 L .44482 1.18147 L 1 .987 0 r
F
.40967 1.19101 m .40586 1.18542 L .44231 1.17591 L F
.51704 1.16989 m .51718 1.16444 L .55471 1.16255 L .823 .887 0 r
F
.48076 1.17441 m .51718 1.16444 L .51704 1.16989 L .884 .923 0 r
F
.44482 1.18147 m .47956 1.1689 L .48076 1.17441 L .955 .959 0 r
F
.44482 1.18147 m .44231 1.17591 L .47956 1.1689 L F
.48076 1.17441 m .47956 1.1689 L .51718 1.16444 L .884 .923 0 r
F
0 g
.64785 0 m
.92348 .39072 L
s
.92348 .39072 m
1 1.47188 L
s
1 1.47188 m
.67613 1.13533 L
s
.67613 1.13533 m
.64785 0 L
s
.0843 .2212 m
0 1.32748 L
s
0 1.32748 m
.67613 1.13533 L
s
.67613 1.13533 m
.64785 0 L
s
.64785 0 m
.0843 .2212 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{357.5, 580.625},
  ImageMargins->{{0, 0}, {0, 0.625}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008H0003IQ000`40O003h00OogooFWoo0P00_Goo
003oOomHOol200000goo0000002lOol00?mooeEoo`<000=oo`800;aoo`00ogooDgoo0P001Woo00<0
07oo0000^goo003oOom@Ool30008Ool01000Oomoo`00^Woo003oOom=Ool3000;Ool01@00Oomoogoo
0000^Goo003oOom;Ool2000>Ool01@00Oomoogoo0000^Goo003oOom8Ool3000@Ool00`00Oomoo`02
Ool00`00Oomoo`2fOol00?moodIoo`8001=oo`03001oogoo00=oo`03001oogoo0;Eoo`00ogoo@goo
0`005Goo00<007ooOol00goo00<007ooOol0]Goo003oOom1Ool2000HOol00`00Oomoo`04Ool00`00
Oomoo`2dOol00?moocioo`<001Yoo`03001oogoo00Eoo`03001oogoo0;=oo`00ogoo?7oo0P007Goo
00<007ooOol01Goo00<007ooOol0/goo003oOoliOol3000OOol00`00Oomoo`06Ool00`00Oomoo`2b
Ool00?moocMoo`80029oo`03001oogoo00Moo`03001oogoo0;5oo`00ogoo=7oo0`0097oo00<007oo
Ool027oo00<007ooOol0/7oo003oOolaOol3000WOol00`00Oomoo`08Ool00`00Oomoo`2`Ool00?mo
obmoo`8002Yoo`03001oogoo00Uoo`03001oogoo0:moo`00ogoo;7oo0`00;7oo00<007ooOol02Woo
00<007ooOol0[Woo003oOolZOol2000_Ool00`00Oomoo`0:Ool00`00Oomoo`2^Ool00?moobMoo`<0
035oo`03001oogoo00]oo`03001oogoo0:eoo`00ogoo9Goo0P00=Goo00<007ooOol02goo00<007oo
Ool0[7oo003oOolROol3000gOol00`00Oomoo`0<Ool00`00Oomoo`2[Ool00?moob1oo`8003Yoo`03
001oogoo00aoo`03001oogoo0:]oo`00ogoo7Goo0`00?7oo00<007ooOol03Goo00<007ooOol0ZWoo
003oOolJOol3000oOol00`00Oomoo`0>Ool00`00Oomoo`2YOol00?mooaQoo`80049oo`03001oogoo
00ioo`03001oogoo0:Uoo`00ogoo5Goo0`00A7oo00<007ooOol03goo00<007ooOol0Z7oo003oOolC
Ool20017Ool00`00Oomoo`0@Ool00`00Oomoo`2WOol00?mooa1oo`<004Uoo`03001oogoo015oo`03
001oogoo0:Ioo`00ogoo3Woo0P00C7oo00<007ooOol04Goo00<007ooOol0YWoo003oOol;Ool3001>
Ool00`00Oomoo`0BOol00`00Oomoo`2UOol00?moo`Uoo`80055oo`03001oogoo01=oo`03001oogoo
0:Aoo`00ogoo1Woo0`00Dgoo00<007ooOol04goo00<007ooOol0Y7oo003oOol3Ool3001FOol00`00
Oomoo`0DOol00`00Oomoo`2SOol00?moo`5oo`8005Uoo`03001oogoo01Eoo`03001oogoo0:9oo`00
oGoo0`00Fgoo00<007ooOol05Goo00<007ooOol0XWoo003kOol2001NOol00`00Oomoo`0FOol00`00
Oomoo`2QOol00?Qoo`<0061oo`03001oogoo01Moo`03001oogoo0:1oo`00mWoo0P00Hgoo00<007oo
Ool067oo00<007ooOol0Wgoo003cOol3001UOol00`00Oomoo`0HOol00`00Oomoo`2OOol00?5oo`80
06Qoo`03001oogoo01Uoo`03001oogoo09ioo`00kWoo0`00JWoo00<007ooOol06Woo00<007ooOol0
WGoo003/Ool2001]Ool00`00Oomoo`0JOol00`00Oomoo`2MOol00>Uoo`<006moo`03001oogoo01]o
o`03001oogoo09aoo`00iWoo0`00LWoo00<007ooOol077oo00<007ooOol0Vgoo003TOol2001eOol0
0`00Oomoo`0MOol00`00Oomoo`2JOol00>5oo`<007Moo`03001oogoo01eoo`03001oogoo09Yoo`00
ggoo0P00NWoo00<007ooOol07Woo00<007ooOol0VGoo003LOol3001lOol00`00Oomoo`0OOol00`00
Oomoo`2HOol00=Yoo`8007moo`03001oogoo01moo`03001oogoo09Qoo`00egoo0`00PGoo00<007oo
Ool087oo00<007ooOol0Ugoo003EOol20024Ool00`00Oomoo`0QOol00`00Oomoo`2FOol00=9oo`<0
08Ioo`03001oogoo029oo`03001oogoo09Eoo`00cgoo0`00RGoo00<007ooOol08Woo00<007ooOol0
UGoo003=Ool2002<Ool00`00Oomoo`0SOol00`00Oomoo`2DOol00<Yoo`<008ioo`03001oogoo02Ao
o`03001oogoo09=oo`00b7oo0P00TGoo00<007ooOol097oo00<007ooOol0Tgoo0035Ool3002COol0
0`00Oomoo`0UOol00`00Oomoo`2BOol00<=oo`8009Ioo`03001oogoo02Ioo`03001oogoo095oo`00
`7oo0`00V7oo00<007ooOol09Woo00<007ooOol0TGoo002nOol2002LOol00`00Oomoo`0VOol00`00
Oomoo`2@Ool00;]oo`<009ioo`03001oogoo02Moo`03001oogoo08moo`00^Goo0P00XGoo00<007oo
Ool0:7oo00<007ooOol0SWoo002fOol3002SOol00`00Oomoo`0XOol00`00Oomoo`2>Ool00;=oo`<0
0:Ioo`03001oogoo02Uoo`03001oogoo08eoo`00/Goo0P00ZGoo00<007ooOol0:Woo00<007ooOol0
S7oo002^Ool3002[Ool00`00Oomoo`0ZOol00`00Oomoo`2<Ool00:aoo`800:ioo`03001oogoo02]o
o`03001oogoo08]oo`00ZGoo0`00/7oo00<007ooOol0;7oo00<007ooOol0RWoo002WOol2002cOol0
0`00Oomoo`0]Ool00`00Oomoo`29Ool00:Aoo`<00;Eoo`03001oogoo02eoo`03001oogoo08Uoo`00
XWoo0P00^7oo00<007ooOol0;Woo00<007ooOol0R7oo002OOol3002jOol00`00Oomoo`0_Ool00`00
Oomoo`27Ool009aoo`<00;eoo`03001oogoo02moo`03001oogoo08Moo`00VWoo0P00`7oo00<007oo
Ool0<7oo00<007ooOol0QWoo002GOol30032Ool00`00Oomoo`0aOol00`00Oomoo`25Ool009Eoo`80
0<Eoo`03001oogoo039oo`03001oogoo08Aoo`00TWoo0`00agoo00<007ooOol0<Woo00<007ooOol0
Q7oo002@Ool2000`Ool2Oh2HOol00`00Oomoo`0cOol00`00Oomoo`23Ool008eoo`<0031oo`EoP9Mo
o`03001oogoo03Aoo`03001oogoo089oo`00Rgoo0P00<Goo27n0UWoo00<007ooOol0=7oo00<007oo
Ool0PWoo0028Ool3000aOol9Oh02Oj2EOol00`00Oomoo`0eOol00`00Oomoo`21Ool008Ioo`8003=o
o`QoP0EoX9Aoo`03001oogoo03Ioo`03001oogoo081oo`00Pgoo0`00<goo27n027nPTgoo00<007oo
Ool0=Woo00<007ooOol0P7oo0020Ool3000dOol8Oh0:Oj2COol00`00Oomoo`0gOol00`00Oomoo`1o
Ool007ioo`8003Eoo`UoP0aoX99oo`03001oogoo03Qoo`03001oogoo07ioo`00Ngoo0`00=Woo27n0
3gnPTGoo00<007ooOol0>Goo00<007ooOol0OGoo001iOol2000hOol7Oh0AOj2AOol00`00Oomoo`0i
Ool00`00Oomoo`1mOol007Ioo`<003Qoo`MoP1AoX91oo`03001oogoo03Yoo`03001oogoo07aoo`00
M7oo0P00>Woo2Gn057nPSgoo00<007ooOol0>goo00<007ooOol0Ngoo001aOol3000jOol<Oh0DOj2>
Ool00`00Oomoo`0kOol00`00Oomoo`1kOol006moo`8003aoo`ioP1AoX8eoo`03001oogoo03aoo`03
001oogoo07Yoo`00K7oo0`00?7oo47n05GnPS7oo00<007ooOol0?Goo00<007ooOol0NGoo001YOol3
000nOolCOh0DOj2;Ool00`00Oomoo`0nOol00`00Oomoo`1hOol006Moo`8003mooaIoP1=oX8]oo`03
001oogoo03ioo`03001oogoo07Qoo`00I7oo0`00@7oo0gmP5Gn04gnPRWoo00<007ooOol0?goo00<0
07ooOol0Mgoo001ROol20012Ool5Of0COh02Of0COj29Ool00`00Oomoo`10Ool00`00Oomoo`1fOol0
05moo`<004=oo`MoH15oP0AoH1=oX8Qoo`03001oogoo041oo`03001oogoo07Ioo`00GGoo0P00AGoo
2GmP3Wn01gmP4GnP0Wn0Qgoo00<007ooOol0@Goo00<007ooOol0MGoo001JOol30015Ool<Of0<Oh09
Of0>Oj04Oh27Ool00`00Oomoo`12Ool00`00Oomoo`1dOol005Qoo`8004Moo`ioH0YoP0]oH0aoX0Io
P8Ioo`03001oogoo04=oo`03001oogoo07=oo`00EGoo0`00B7oo47mP1gn03WmP2GnP27n0Qgoo00<0
07ooOol0@Woo00<007ooOol0Lgoo001BOol3001:OolBOf05Oh0?Of08Oj0:Oh26Ool00`00Oomoo`13
Ool00`00Oomoo`1bOol0051oo`8004aooaAoH0=oP15oH0EoX0eoP8Eoo`03001oogoo04Aoo`03001o
ogoo075oo`00CGoo0`00C7oo:gmP0gnP3gn0Q7oo00<007ooOol0A7oo00<007ooOol0LGoo001;Ool2
001>Ool3Od0ZOf0BOh23Ool00`00Oomoo`15Ool00`00Oomoo`1`Ool004Qoo`<004moo`Eo@2YoH19o
P89oo`03001oogoo04Ioo`03001oogoo06moo`00AWoo0P00DGoo1gm0:WmP4Wn0PGoo00<007ooOol0
AWoo00<007ooOol0Kgoo0013Ool3001BOol:Od0DOf02Od0COf0BOh20Ool00`00Oomoo`17Ool00`00
Oomoo`1^Ool0045oo`8005Aoo`ao@19oH0Ao@19oH19oP81oo`03001oogoo04Qoo`03001oogoo06eo
o`00?Woo0`00EGoo3Wm047mP1Wm047mP0gm04Gn0Ogoo00<007ooOol0BGoo00<007ooOol0K7oo000l
Ool2001GOolAOd0=Of08Od0>Of05Od0@Oh1oOol00`00Oomoo`19Ool00`00Oomoo`1/Ool003Uoo`<0
05Qooa=o@0YoH0]o@0aoH0Mo@0ioP09oH7ioo`03001oogoo04Yoo`03001oogoo06]oo`00=Woo0`00
FWoo5Gm027mP3Gm02GmP2Wm037n017mPOGoo00<007ooOol0Bgoo00<007ooOol0JWoo000dOol2001K
OolIOd05Of0?Od07Of0<Od0:Oh06Of1lOol00`00Oomoo`1;Ool00`00Oomoo`1ZOol0035oo`<005eo
oaYo@0=oH15o@0EoH0io@0QoP0MoH003Ob1oogoo07Uoo`03001oogoo04aoo`03001oogoo06Uoo`00
;goo0P00Ggoo<7m00gmP3gm01gn01gmP0glPNWoo00<007ooOol0CGoo00<007ooOol0J7oo000]Ool2
001POom2Od02Ob05Oh07Of05Ob1iOol00`00Oomoo`1>Ool00`00Oomoo`1WOol002eoo`8005mooc9o
@09o80io@0Ao80=oP0MoH0Io8003O^1oogoo07Ioo`03001oogoo04ioo`03001oogoo06Moo`00;Goo
00<007oo0000GGoo<Wm017lP37m01WlP00=oP7mPOf001GmP1WlP0WkPN7oo00<007ooOol0Cgoo00<0
07ooOol0IWoo000]Ool01000Oomoo`00G7oo8Wm00glP37m01WlP2Wm01glP1gmP1WlP17kPMgoo00<0
07ooOol0D7oo00<007ooOol0IGoo000]Ool01@00Oomoogoo0000FWoo8Wm01GlP2Wm027lP27m01glP
0Wl01GmP1WlP1GkPMgoo00<007ooOol0D7oo00<007ooOol0IGoo000]Ool01@00Oomoogoo0000FGoo
8Wm01glP27m027lP0gl01Gm01glP17l00gmP1WlP1WkP00=nH7ooOol0M7oo00<007ooOol0DGoo00<0
07ooOol0I7oo000]Ool00`00Oomoo`02Ool00`00Oomoo`1EOolEOd02Ob0;Od09Ob06Od08Ob05O`03
Od07Ob06O`000gmPOb1o8005Ob05O^03OV1eOol00`00Oomoo`1BOol00`00Oomoo`1SOol002aoo`03
001oogoo00Aoo`03001oogoo05=ooaEo@0Ao80Uo@0]o80Ao@0Qo80Mo00Qo80Mo00Mo80Inh0AnH7Ao
o`03001oogoo05=oo`03001oogoo069oo`00;7oo00<007ooOol01Goo00<007ooOol0DGoo5Gm01WlP
1gm03GlP0Wm027lP2Gl01WlP27l000=n`7lPOb000glP1WkP1GiP00=n07ooOol0LGoo00<007ooOol0
Dgoo00<007ooOol0HWoo000/Ool00`00Oomoo`06Ool00`00Oomoo`1@OolDOd09Ob04Od0GOb0;O`04
Ob08O`03O/03Ob06O^06OV000gh0Oomoo`1aOol00`00Oomoo`1DOol00`00Oomoo`1QOol002aoo`03
001oogoo00Moo`03001oogoo04iooaAo@0]o809o@0mo80=o00Eo80eo009o80Qo00En`003Ob1nh7kP
00Enh0EnH09n07=oo`03001oogoo05Eoo`03001oogoo061oo`00;7oo00<007ooOol027oo00<007oo
Ool0CGoo1Wm00WlP2gm077lP1Gl00glP5gl01Wk01gkP1WiP0Wh0Lgoo00<007ooOol0EGoo00<007oo
Ool0H7oo000/Ool00`00Oomoo`09Ool00`00Oomoo`1;Ool6Od05Ob08Od0LOb0GO`000gkPO`1o0005
O`07O/000gjPO^1nh004O^05OV03OP1cOol00`00Oomoo`1FOol00`00Oomoo`1OOol002aoo`03001o
ogoo00Uoo`03001oogoo04Yoo`Mo@0Io80Io@1ao81Mo00=nh0Eo00Mn`09nX0Enh0InH0=n07=oo`03
001oogoo05Moo`03001oogoo05ioo`00;7oo00<007ooOol02Woo00<007ooOol0BGoo1Wm02GlP0gm0
77lP5gl01GkP0gl01gk017jP0gkP1WiP17h0Lgoo00<007ooOol0Egoo00<007ooOol0GWoo000/Ool0
0`00Oomoo`0;Ool00`00Oomoo`17Ool6Od0ROb02O`04Ob0GO`07O^000gl0O/1n`005O/05OZ03O^06
OV05OP1bOol00`00Oomoo`1HOol00`00Oomoo`1MOol002aoo`03001oogoo00aoo`03001oogoo04Eo
o`Mo@25o80Ao009o81Mo00Qnh0Mn`0MnX003O^1nH7iP00AnH0In079oo`03001oogoo05Uoo`03001o
ogoo05aoo`00;7oo00<007ooOol03Goo00<007ooOol0A7oo1Wm08GlP5Wl000=nh7l0O`0017l027kP
27k01gjP1giP1Wh0LWoo00<007ooOol0FWoo00<007ooOol0Fgoo000/Ool00`00Oomoo`0>Ool00`00
Oomoo`12Ool6Od0QOb0FO`03O^04O`08O^08O/08OZ000gi0OV1nH004OV06OP1bOol00`00Oomoo`1J
Ool00`00Oomoo`1KOol002aoo`03001oogoo00moo`03001oogoo041oo`Mo@21o81Io00Enh09o00Qn
h0Qn`0QnX09n@0EnH0Mn079oo`03001oogoo05]oo`03001oogoo05Yoo`00:goo00<007ooOol04Goo
00<007ooOol0?goo0glP0gm087lP5Wl03gkP27k027jP17i017iP1gh0LWoo00<007ooOol0G7oo00<0
07ooOol0FGoo000[Ool00`00Oomoo`0BOol00`00Oomoo`0mOolPOb02O`04Ob0>O`02O^06O`07O^02
O/06O^08O/08OZ05OT03OV08OP1bOol00`00Oomoo`1LOol00`00Oomoo`1IOol002]oo`03001oogoo
019oo`03001oogoo03eooamo80Ao009o80io00Anh0Ao00Mnh0An`0Anh0Qn`09nP0MnX0En@0=nH0Qn
079oo`03001oogoo05eoo`03001oogoo05Qoo`00:goo00<007ooOol04goo00<007ooOol0>goo7glP
57l01WkP0Wl01gkP1Wk00WkP27k017j01GjP1gi000=nH7h0OP001gh0LWoo00<007ooOol0GWoo00<0
07ooOol0Egoo000[Ool00`00Oomoo`0DOol00`00Oomoo`0jOolOOb0DO`0>O^0@O/06OX03OZ08OT00
0giPOP1n0007OP1cOol00`00Oomoo`1NOol00`00Oomoo`1FOol002]oo`03001oogoo01Eoo`03001o
ogoo03Qooamo81Ao00inh0Qn`09nX0In`0QnP003OZ1n@7i000Mn@0Un07Aoo`03001oogoo05ioo`03
001oogoo05Ioo`00:goo00<007ooOol05Woo00<007ooOol0=goo7WlP57l03WkP27k017jP17k02Gj0
2Wi02Gh0M7oo00<007ooOol0Ggoo00<007ooOol0EGoo000[Ool00`00Oomoo`0GOol00`00Oomoo`0e
OolOOb0DO`0=O^08O/06OZ02O/09OX02OV08OT09OP1eOol00`00Oomoo`1POol00`00Oomoo`1DOol0
02]oo`03001oogoo01Qoo`03001oogoo03Aooaio81Ao00inh0Mn`0QnX0UnP0=nH0Mn@0Yn07Eoo`03
001oogoo061oo`03001oogoo05Aoo`00:goo00<007ooOol06Goo00<007ooOol0<Woo67lP0gl00glP
57l03WkP1gk02GjP27j01GiP1Gi02Wh0MWoo00<007ooOol0HGoo00<007ooOol0Dgoo000[Ool00`00
Oomoo`0JOol00`00Oomoo`0`OolHOb0KO`0=O^07O/09OZ08OX06OV04OT0;OP1fOol00`00Oomoo`1R
Ool00`00Oomoo`1BOol002]oo`03001oogoo01Yoo`03001oogoo031ooaQo81Yo00enh0Mn`0UnX0Qn
P0QnH09n@0]n07Moo`03001oogoo06=oo`03001oogoo055oo`00:goo00<007ooOol06goo00<007oo
Ool0;goo5glP6Wl03WkP1gk027jP27j02GiP00=n@7h0OP002Wh0Mgoo00<007ooOol0Hgoo00<007oo
Ool0DGoo000ZOol00`00Oomoo`0MOol00`00Oomoo`0]OolHOb0IO`0>O^07O/08OZ08OX0:OV0<OP1h
Ool00`00Oomoo`1TOol00`00Oomoo`1@Ool002Yoo`03001oogoo01ioo`03001oogoo02aooaMo81Yo
00enh0Mn`0QnX0QnP0YnH09n80]n07Qoo`03001oogoo06Eoo`03001oogoo04moo`00:Woo00<007oo
Ool07goo00<007ooOol0:Woo67lP6Gl03GkP27k01gjP27j02WiP17hP2Gh0NGoo00<007ooOol0IGoo
00<007ooOol0Cgoo000ZOol00`00Oomoo`0POol00`00Oomoo`0YOolGOb0IO`0>O^07O/09OZ06OX0:
OV05OR09OP0WOolIOl0HOj0QOol00`00Oomoo`1VOol00`00Oomoo`1>Ool002Yoo`03001oogoo025o
o`03001oogoo02QooaIo81Uo00inh0Mn`0]nX0AnP0YnH0Mn80Mn01moob9o`1eoX1aoo`03001oogoo
06Moo`03001oogoo04eoo`00:Woo00<007ooOol08Woo00<007ooOol09Woo5glP6Gl03GkP1gk03GjP
0Wj02GiP2GhP1Gh00gF067oo1WoP8Wo08WnP5goo00<007ooOol0Igoo00<007ooOol0CGoo000ZOol0
0`00Oomoo`0ROol00`00Oomoo`0VOolGOb0IO`0=O^08O/0=OZ09OV02OT09OR02OP05MH000a`POomo
o`0?Ool<On0ROl0ROj06Oh0AOol00`00Oomoo`1XOol00`00Oomoo`1<Ool002Yoo`03001oogoo02=o
o`03001oogoo02AooaMo81Uo00enh0Yn`0anX003OX1nH7iP00EnH0An@0Qn80MeP08L80Yooa9oh29o
`25oX0aoP0aoo`03001oogoo06Uoo`03001oogoo04]oo`00:Woo00<007ooOol097oo00<007ooOol0
8goo5glP6Gl037kP37k02WjP0gj01GiP1Gi01ghP0WGP1WF00a`P1Woo5GoP8Go08GnP4Wn01goo00<0
07ooOol0JWoo00<007ooOol0BWoo000ZOol00`00Oomoo`0UOol00`00Oomoo`0QOolGOb0IO`0<O^0>
O/08OZ05OX03OV07OT04OR04MN07MH027203OolIOn0POl0QOj0FOh03Ool00`00Oomoo`1ZOol00`00
Oomoo`1:Ool002Yoo`03001oogoo02Ioo`03001oogoo021ooaMo81Uo00anh0in`0MnX0MnP003OV1n
@7i000Mn@09n80Ieh0IeP003721oh7oP01]oh0Qo`0Qoh11o`25oX1UoP003001oogoo06]oo`03001o
ogoo04Uoo`00:Woo00<007ooOol09goo00<007ooOol07goo5glP67l037kP3Wk01gjP27j02Wi027GP
17F0<7oP47o087nP6Wn000<007n0Oh00K7oo00<007ooOol0B7oo000ZOol00`00Oomoo`0XOol00`00
Oomoo`0NOolFOb0IO`0<O^0=O/07OZ08OX03NV07OT02LR07MN0dOn0?Ol0QOj0AOh03Nh06Oh000`00
Oh1oP003Oh1YOol00`00Oomoo`18Ool002Yoo`03001oogoo02Uoo`03001oogoo01eooaIo81Qo00an
h0in`0MnX0MnP0EjH0En@0Ab80Aeh0=o`3=oh0mo`21oX15oP0MkP0=oP003001oP7n000IoP6Moo`03
001oogoo04Moo`00:Goo00<007ooOol0:goo00<007ooOol077oo5GlP6Gl037kP3Gk01gjP1gj01gYP
0gi01G8P00=eh7o0Ol0017o0<goP3go07gnP4Gn02g^000<007n0Oh001Gn017]PIGoo00<007ooOol0
AWoo000YOol00`00Oomoo`0[Ool00`00Oomoo`0KOolFOb0HO`0<O^0=O/07OZ07OX09NV05LR0:Ol0b
On0?Ol0OOj05Nh0;Oh0<Nh000`00Nh1kP004Oh07Nf1TOol00`00Oomoo`15Ool002Uoo`03001oogoo
02aoo`03001oogoo01YooaIo81Qo00anh0en`0InX0MnP0UjH09b@09b80ao`39oh0mo`1ioX0]kP0Eo
P0ekP003001kP7^000=kP0YkH69oo`03001oogoo04Eoo`00:Goo00<007ooOol0;Goo00<007ooOol0
6Goo5WlP5gl037kP3Gk01WjP27j00WJ01WYP0W903Go0=7oP3go07GnP7W^000<007^0Nh000W^03W]P
H7oo00<007ooOol0A7oo000YOol00`00Oomoo`0^Ool00`00Oomoo`0HOolFOb0GO`0?O^0:O/05OZ08
OX04MX04NV0=Ol0gOn0>Ol0NOj0NNh001000Nh1kP7^04G]PGgoo00<007ooOol0@goo000YOol00`00
Oomoo`0_Ool00`00Oomoo`0GOolEOb0GO`0BO^07O/06OZ02NZ05OX06MX000gYPOl1o`00:Ol0jOn0>
Ol0MOj0ONh000`00Nh1kP00DNf1MOol00`00Oomoo`13Ool002Uoo`03001oogoo031oo`03001oogoo
01EooaIo81Mo019nh0Mn`0EnX0EjX09nP0IfP0ao`3aoh0io`0ioX0ikX21kP003001kP7]P01IkH5ao
o`03001oogoo049oo`00:Goo00<007ooOol0<Goo00<007ooOol057oo5WlP5Wl04gkP1Wk01WjP1WZP
1GJ02go0?goP3Go03gnP3W^P1GN02W^01GMP37^000<007]PNf0067]PFgoo00<007ooOol0@Goo000Y
Ool00`00Oomoo`0bOol00`00Oomoo`0COolFOb0FO`0BO^06O/06OZ07NZ03MX0:Ol12On0=Ol0LNj0:
Mh05Nh09Mf09Nh000`00Nf1kH00JNf1JOol00`00Oomoo`10Ool002Uoo`03001oogoo039oo`03001o
ogoo01=ooaIo81Io019nh0In`0=j`0=nX0IjX09fP0eo`45oh0eo`0ikX1agP0egH0EkP004Mf0007MP
Mf0LNf1HOol00`00Oomoo`10Ool002Uoo`03001oogoo03=oo`03001oogoo019ooaEo81Mo015nh0In
`0Ij`0MjX11o`41oh0eo`0ikX1agP1=gH003001gH7MP00=gH1]kH5Moo`03001oogoo03moo`00:Goo
00<007ooOol0=7oo00<007ooOol04Goo5GlP5Wl04WkP1Wk01W[00WJP0gZP4go0?goP3Go03GNP77N0
57MP00<007MPMf001GMP6g]PEWoo00<007ooOol0?Woo000YOol00`00Oomoo`0eOol00`00Oomoo`0@
OolEOb0FO`0AO^06O/07N/03MZ0FOl0nOn0=Ol0=Mj0KMh0EMf000`00Mf1gH008Mf0INf1EOol00`00
Oomoo`0nOol002Qoo`03001oogoo03Moo`03001oogoo00mooaEo81Io015nh0=j`0=n`0Ij`0=fX09o
X1Eo`3ioh0ao`0egX0egP0EcH0YgP0=cH19gH003001gH7MP00YgH1UkH5Aoo`03001oogoo03eoo`00
:7oo00<007ooOol0>7oo00<007ooOol03Woo5GlP5Wl04GkP37[000=fX7nPOj000gnP5Go0?GoP37_0
37>P3WN02G=P1GN01g=P3gMP00<007MPMf0037MP6G]PDgoo00<007ooOol0?7oo000XOol00`00Oomo
o`0iOol00`00Oomoo`0=OolEOb0EO`0BO^05N/02M/04N/08Oj0DOl0mOn0<Nl0<Lj0=Lh0ILf0<Mf00
0`00Mf1gH00>Mf0INf1AOol00`00Oomoo`0lOol002Qoo`03001oogoo03Yoo`03001oogoo00aooaEo
81Qo00inh0Ij`0Af`0]oX1Ao`3aoh0]k`0acX0icP0A_H1QcH0UgH003001gH7MP011gH1QkH55oo`03
001oogoo03]oo`00:7oo00<007ooOol0>goo00<007ooOol02goo5GlP6Wl037kP1W[00gK03GnP57o0
>WoP37>P36n01VmP1g>02FmP5g=P1WMP00<007MPMf004WMP67]PD7oo00<007ooOol0>Woo000XOol0
0`00Oomoo`0kOol00`00Oomoo`0:OolFOb0JO`06N^06O^05N/02M/0@Oj0COl0dOn06Nl0<Lj0<Kh0I
Kf0GLf04Mf000`00Mf1gH00CMf0HNf1?Ool00`00Oomoo`0iOol002Qoo`03001oogoo03aoo`03001o
ogoo00UooaIo81Yo00Ujh0=nh0Ej`1=oX1=o`2eoh0ak`0acX0]_P0a_H0M[H0]_H1IcH004Mf0007MP
Mf05Md0?Mf0HNf1>Ool00`00Oomoo`0iOol002Qoo`03001oogoo03eoo`03001oogoo00QooaEo81]o
00]jh0Aj`1IoX1=o`2eoh0Ik`0EcX0a[P0][H0]WH0e[H0Y_H1=cH003001g@7M000Mg@0agH0=g@1Ek
H0=k@4eoo`03001oogoo03Qoo`00:7oo00<007ooOol0?Woo00<007ooOol01goo6WlP5Wl02g[P0gKP
0Wn05WnP4go0;7oP2g>P2f^036]P2fMP16M026]P1F]02FmP47=P00<007=0Ld002GM027MP1gM04W]P
1G]0CGoo00<007ooOol0=goo000XOol00`00Oomoo`0oOol00`00Oomoo`06OolKOb0EO`0;N^000gKP
Oh1oP003Oh0EOj0BOl0^On0:Lj0;Hf0;Hd0;If08Id04Jf09Jd05Kf04Kd0<Lf000g=0001c@003Ld09
Md04Mf0:Md0?Nf08Nd1<Ool00`00Oomoo`0gOol002Qoo`03001oogoo041oo`03001oogoo00Eooa]o
81Eo00]jh0MoP1EoX0mo`31oh1ESH1ES@0aW@0e[@0U_@0QcH09c@003001c@7=000Ac@1Mg@0]kH0]k
@4aoo`03001oogoo03Ioo`00:7oo00<007ooOol0@Goo00<007ooOol017oo6glP5Gl02G[P2gn057nP
37o0<7oP0V^056=P6f=01VM04F]02Fm017=P0g=000<007=0Ld001W=05WM01g]P3g]0C7oo00<007oo
Ool0=Goo000XOol00`00Oomoo`12Ool00`00Oomoo`03OolKOb0@O`05N`08N^0=Oh0DOj09Ol0_On05
Jh0:C^0:E`0:Eb0:Fb0<Hd0DJd09Kd05Ld000`00Ld1c@008Ld0FMd03Nf0BNd1<Ool00`00Oomoo`0d
Ool002Moo`03001oogoo04Aoo`03001oogoo009ooa]o811o00Ek00Ijh11oP1AoX0Io`2ioh0E[P0A>
P0U>h0YG00UG80]K80AO80QS@0AW81=[@0Q_@0=c@003001c@7=000Uc@1Ig@1Ek@4]oo`03001oogoo
03Aoo`009goo00<007ooOol0A7oo00<007ooOol00Woo6glP47l01G/01G[P4Wn057nP0go0;GoP1F^0
1dj02D8P2TJP2DkP1E<01U/P1elP16=026LP4V]026m000=c@000Ld0037=05WM057]0Bgoo00<007oo
Ool0<goo000WOol00`00Oomoo`15Ool01000Oomoogoo6glP47l01G/00g[P5Gn057nP<7oP1Tj01CT0
2D8P2DJP2TkP2U<02elP36LP3V]02Vm000<007=0Ld0037=05WM057]0Bgoo00<007ooOol0<Woo000W
Ool00`00Oomoo`16Ool00`00Oomoo`0KOb0@O`05N`000g[POh1oP00FOh0DOj0]On03ET0:>@09=D09
?T09AZ0:D`05F`06Gb06Hb0:Ib0:Jd0;Kd000`00Kd1_@00>Ld0EMd0DNd1:Ool00`00Oomoo`0bOol0
02Moo`03001oogoo04Moo`03001oogoo01Yo811o00Ek00=oH1IoP1AoX2]oh0AF@08`P0XTP0PX`0Pe
`0Y6X0U>`0YK00aS80QW80M[@0a_@004001_@6m0Kd0>Ld0FMd0CNd1:Ool00`00Oomoo`0aOol002Mo
o`03001oogoo04Qoo`03001ooglP01Uo811o00Ak00EoH1IoP1AoX2Qoh0AF@003<80DH1AP0080@088
H0L0H0PX`0Pe`0TnH0U>`0EBh0UK00]S80QW80A[@0A[80U_@003001_@6m000=_@0ic@1Eg@1=k@4Yo
o`03001oogoo031oo`009goo00<007ooOol0BGoo00<007lPOb007WlP3G/01gmP5Wn04gnP9WoP15I0
00@Th2308<0P`0<DH0D8H0D<H0LLP0PaP0TnH0Q6X0YBh0QK00YS80QW80Q[80M_@003001_@6m000A_
@0ic@1Eg@1=k@4Yoo`03001oogoo02moo`009goo00<007ooOol0BWoo00<007lPOb007GlP37/02WmP
5Gn04gnP8goP15I000@Y82CP9>0Th0<P`08Ph003560HX1RP00<8H08DP0<<H0<LX0<LP0L]H0Tj80Q6
X0E>`0EBh0AFh0QK00US80QW80Q[80A_@003Kb0006lP00M_@0ic@1Ag@1=k@4Uoo`03001oogoo02mo
o`009goo00<007ooOol0Bgoo7glP2W/03GmP5Wn04WnP8GoP0go000@aP2e0;D0]@08Y80@P`0<Ph0@H
X0DDP0HLX0L]H0Leh0TnH0Y>`0QFh0AK00AO00QS80QW80Q[80=_8004001_86lPKb06Kd0>Ld0DMd0C
Nd19Ool00`00Oomoo`0^Ool002Moo`03001oogoo04]ooamo80Uk00moH1IoP19oX1moh0=o`0<aP0<]
@0DY80@Ph0@Q00@Lh0HPh0LY@0Leh0@j@0@nH0E6X0E>`0ABh0MFh0UO00MS80QW80Q[8003Kb0006lP
00A_80I_@0=c@0Ac80Ic@1Ag@1=k@4Uoo`03001oogoo02eoo`009goo00<007ooOol0Bgoo87lP1g/0
4WmP5Gn04WnP77oP17o00SFP0c600be02BTP12400RDP0QcP0RDP0b3P1RUP1c7023Y02DJP25;P15KP
15/025l01f<P26LP1f/P00<006lPKb001FlP1Fm01g<P1g=04gM04g]0B7oo00<007ooOol0;Goo000W
Ool00`00Oomoo`1<OolOOb06N`0DOf0EOh0BOj0JOn04Ol0013g0=L0e`3G00c6P0S602RTP00<Y@240
8@002BDP1RUP1c7013XP13Y014:014JP14k01e;P2E/015l00f<01f<P16LP2F/P00<006/PKb0036lP
1W<P1g=04gM04g]0B7oo00<007ooOol0;7oo000WOol00`00Oomoo`1<OolOOb05N`0FOf0EOh0BOj0G
On04Ol05>L02=L03<J02<H06;F03:B03:D049B05:F05;H07<L08>R08@X07C/04D^04E^08F`07H`07
Hb0;Jb000`00Jb1[800=Kb07Lb06Ld0CMd0CNd18Ool00`00Oomoo`0[Ool002Ioo`03001oogoo04eo
oamo80=k01UoH1EoP19oX1Eoh0Ao`0<mh0@i`08e`0<aX08aP0P]H0@Y@0PYH0<]X08]P0La`0<f00@j
80@nH0A2P0E:X0E>`0QFh0AK00EO00IS00=S80AW00U[8004001[86/PJb0=Kb07Lb06Ld0CMd0CNd17
Ool00`00Oomoo`0[Ool002Ioo`03001oogoo04eooamo809k01]oH1AoP1=oX19oh0Eo`0=200<mh0<i
`08e`08aX0<aP0P]H0<]P0@YH0@]P0D]X0Ha`0Lf00PnH0U:X0IB`0IFh0UO00ES00QW00M[8003001[
86/P00=[80e_80ac81=g@1=k@4Moo`03001oogoo02Yoo`009Woo00<007ooOol0CWoo6WlP1G/P7GmP
4Wn00WmP4gnP5WoP00A68480@P1200<mh0<ih0<e`08eX0DaX08aP0<]H0X]P08aX0<]X0Da`0Hf00Dj
@0@nH0A6P0E:X0=>X0MB`0IJh0QO00ES00QW00E[8003001[86/P00A[80e_80ac81=g@1=k@4Moo`03
001oogoo02Uoo`009Woo00<007ooOol0CWoo6WlP17/P7WmP4Gn017mP4WnP5GoP14HP0T8013gP0SWP
0cG00SFP136P0c600S6P1Rf0236P1C701SH013XP1CY024J01djP15;00eK01U[P15l015kP1F<01fL0
16/000<006/0Jb001F/P3FlP37<P4WM04g]0B7oo00<007ooOol0:7oo000VOol00`00Oomoo`1?OolI
Ob03Nb0QOf0=Oh07Of0@Oj02Oh0DOn02BR03AR03@P03?N02>N03=L02=J04<J03<H0;<J02<L02<J04
<N06=P07>R06@V04AX03BZ07CZ06E/07F^07G^06H`06I`03J`000`00J`1[0006Jb07Kb0BLb0=Md0H
Nd17Ool00`00Oomoo`0XOol002Ioo`03001oogoo04mooaYo8003Nb1oH7mP025oH0]oP0UoH0ioX0Ao
P19oh0E:80I2008mh0Dih0De`0<aP0PaX0Ha`0Dah0Hf00Hj80@n@0E2H0M:X0=>X0AB`0IF`0=Jh0YN
h0IS00IW009[0003001[06/0009[00E[80M_819c80Yg@0=g81Qk@4Ioo`8002Uoo`009Woo00<007oo
Ool0Cgoo6WlP9GmP2Gn02gmP37nP1Wn04GoP1DXP0THP1D800cgP13WP33G00c6P0c700SGP00<a`3GP
=N000SGP1SH01SXP1ci01TJ01DZP25;01EK03EkP0f<02FL000=[0000J`0016/01F/P1flP4W<P1WM0
1gLP67]0@Woo0`0000=oo`00Ool0:7oo000VOol00`00Oomoo`1@OolHOb0>Of03Od0DOf03Od05Oh0>
Of09Oj07Oh02Of0@On02BT02BR05AR02@P03?P03?N03>N0>=L03<L07=N04=P06>P08?T03@V06AX05
CZ07D/06F/0<G^0<I`000`00J`1[0004J`0<Kb0BLb0<Mb0INd0nOol30004Ool00`00Oomoo`0WOol0
02Ioo`03001oogoo051ooaMo80ioH0Io@15oH0Eo@0=oP0moH0QoX0MoP0AoH0ioh0E:@0I680=200<n
008mh0<ih0de`0Teh0@f00Hj00<j80Dn@0I2H0=6P0=:P0E>X0AB`0=F`0IJ`0INh0IRh0YW0003001[
06/000E[00a_80ac819g81Qk@3]oo`<000Moo`03001oogoo02Moo`009Woo00<007ooOol0DGoo5GlP
3WmP27m03gmP1gm047mP0gm01GnP1gn01GmP3WoP1DY01THP1D800Sh01SWP0SGP13G00cGP0SG02CGP
0cH01SX01SXP1D901D9P1dZ01DjP1UK01e[01UkP1F;P2FL000<006L0J`001V/036lP37<P4WLP67]0
>7oo0P002Woo00<007ooOol09goo000VOol00`00Oomoo`1AOolCOb0?Of0;Od0<Of09Od0>Of05Od03
Oj07Oh06Of000glPOn1oh00:On000di0BT1:@003BT05AR04@R03@P03?P05>N02=N04=L0<=N04=P05
>P06>R03?T05@T05AV06BX06DZ05E/07F/06G^05H^06I`02J`000`00J`1[0007J`0<Kb0<Lb0AMb0H
Nd0eOol3000<Ool00`00Oomoo`0WOol002Ioo`03001oogoo055ooa1o80=k809o@0aoH0eo@0YoH0]o
@0aoH0Mo@0QoP0IoH0=o80]oh003CV1:@4Y000=:@0E680I280Hn00@ih08eh0<e`0Heh0<ih0<eh0Lj
00Hj80Hn@0]6H0I>P0EBX0EF`0MJ`0INh0ERh0IW0003J`0006/000U[00]_80ec815g81Qk@35oo`<0
00moo`03001oogoo02Moo`009Woo00<007ooOol0DWoo1Gm02WlP0W/P1Gm02GmP3gm027mP3Gm02GmP
27m00WlP1Wn01WmP1GlP2GoP0diP14Y01DHP1T8P1ch00cX023WP0cGP1CWP2cX01ChP0ci00d901TIP
1DZ01Dj01E:P35[01UkP1F;P1VL000<006/0J`002F/01FlP4W<P4WLP5g]0;Woo0`004Woo00<007oo
Ool09goo000UOol00`00Oomoo`1COol5Od0;Ob07Od07Of0BOd05Of0?Od07Of08Od04Ob04Oh06Of06
Ob09On03CV05BT05AT05@R03@P06?P02>P0?>N0:>P07?R07@T05AV05BX05CX06EZ0;F/0;H^05I`00
0`00J`1[000:J`05K`0BLb0AMb06Nb0BNd0ZOol3000FOol00`00Oomoo`0VOol002Eoo`03001oogoo
05Aoo`Eo@0Uo80Yo@0AoH1Ao@0=oH0mo@09o80EoH0Qo@0Io809oP0IoH0Mo8003O^1oh7oP00Ioh0A>
H0A:@0E6@0Q2809200Hn0003>P0ih3WP00Tih0`j00Dn80Hn@0E6@0E6H0E:P0IBX0IFX0EJ`0EN`0]R
h0AW0003001W06/000E[00]_019c80]g80ak815k@2Moo`<001Uoo`03001oogoo02Ioo`009Goo00<0
07ooOol0E7oo1Gm027lP=7m017lP0gmP27m01glP1gmP1glP0gkP1WoP1DiP1DY014I02T8P1ch00cX0
23WP3SX01ShP14901DI01DIP1Tj01E:P1UJP1E[01Ek02f;P0fL000<006L0I`001V/02fl04W<P2gLP
2g/P4W]08goo0`0077oo00<007ooOol09Woo000UOol00`00Oomoo`1EOol5Od07Ob0cOd06Ob09Od07
Ob02O`05Of07Ob05O^05On000e9PCV1>H003CV04BT05AT09@R08?P03>P05>N0=>P0:?R04@T05AT05
BV06CX05DZ06EZ05F/05G/0;H^02I^001000I^1Vh6KP1V/02fl04G<P37LP2g/P4G]087oo0`007goo
00<007ooOol09Woo000UOol00`00Oomoo`1EOol5Od06Ob0bOd09Ob07Od07Ob04O`03Of07Ob06O^00
17iPOn1oh7oP0e9P1DiP14Y01DI02D8P2Ch00SX013WP2SX013h02ShP14901TIP14YP1Tj01E:P1UJP
1E[01Ek01F;P1fKP00<006KPI^000VKP1F/036l02g<P4GLP2g/P4W]07Goo0P008Woo00<007ooOol0
9Woo000UOol00`00Oomoo`1FOol5Od04Ob0bOd0;Ob05Od07Ob06O`000gmPOb1o8005Ob06O^03OV02
On04CV05BV08AT05@R04?R0:?P0@>P05?P04?R05@R04AT06AV04BV06DX05DZ06EZ05F/05G/05H^06
I^000`00I^1Vh003I^05J`0;K`07L`05Lb0AMb0;Nb0ANd0JOol3000TOol00`00Oomoo`0VOol002Eo
o`03001oogoo05Ioo`Eo@0=o82Yo@0=o80Eo@0eo80=o@0Mo80Mo00Qo80Inh0AnH003DX1>H4iP00=>
H0A:H0U6@0E280@n80Tn00`j00Xn00Dn80A280A6@0I:H0E>H0EBP0EBX0EFX0]N`0ERh0IVh003001V
h6KP00=Vh0E[00]_00Ic00Ic815g80Yk815k@1Moo`<002Moo`03001oogoo02Ioo`009Goo00<007oo
Ool0Egoo1Gm000=o87m0Od00:7m01GlP0gm05glP27l000=nh7lPOb0017lP1WkP1GiP00=n04iPCV00
0diP14YP1TI014901D8P0chP1Ch04SX023h01T8P14901DI01DYP1DiP1E:01EJP1EZP2ek01F;P1FKP
00<006KPI^000fKP1F/036l01W<01G<P4GLP2g/P1W]01W/P1Gm04goo0`00:Woo00<007ooOol09Woo
000UOol00`00Oomoo`1GOol_Od0HOb000gl0Ob1o8004Ob08O`03O^04Ob07O^05OV000gh0DX1>H004
CV05BV05AT04@T04@R09?P0=>P0>?P04@R05@T05AT04BV06CV05DX05EZ05FZ0;G/05H^04I^000`00
J^1Zh009J^0;K`06L`06Lb0AMb0FNb05Od0@Ool3000]Ool00`00Oomoo`0VOol002Eoo`03001oogoo
05Moob1o@09o80ao@1Qo80=o00Ao80Qo00Anh0=o80Mnh0EnH09n009BP0E>H0E:H0E6@0E280@n80Dn
00lj00Xn00Dn80A280Y6@0A:H0I>H0EBP0EFX0EJX0YN`0ERh0AVh003001Vh6[P00YZh0]_00Ic00Ec
815g81Mk80Eo@0aoo`<0031oo`03001oogoo02Ioo`009Goo00<007ooOol0F7oo7Wm01GlP2Gm067lP
1Gl00WlP27l01WkP00=o87kPO^001GkP1WiP0Wh00e:01TYP14IP1DI02ChP1Ch03SX02Sh01ChP1D8P
2DI01DYP1DiP1E:01EJP1EZP1Uk01F;01FK00fKP00<006KPI^002V[P2fl01W<01W<P2WLP7G/P1Gm0
2Goo0`00<goo00<007ooOol09Woo000UOol00`00Oomoo`1IOolLOd07Ob07Od0HOb0?O`0?O^05OV03
OP000e:PCX1>P002CX05BV04AV05@T0:?R0=>P05>N02>P08?P0:@R04AT05BT05CV05DV05EX05EZ05
FZ06G/05H/05I/02I^000`00I^1Vh00;J^0;K`06L`05Lb0;Mb0LNb05Od06Ool3000fOol00`00Oomo
o`0VOol002Eoo`03001oogoo05YooaYo@0Yo80Ao@1Qo80Mo009nh0Mo00Mnh003OZ1nh7kP00Anh0In
H0=n009BX0A>P0E6H0E6@0A2@0Hn810j00Hih0<j00Hn00Y280E6@0E:@0E>H0EBH0EFP0AFX0IJX0EN
`0ER`0EV`09Vh004001Vh6KPI^0;J^0:K`06L`06M`0:Mb0MNb05Od03Ool2000iOol00`00Oomoo`0V
Ool002Aoo`03001oogoo05YooaYo@0ao809o@0mo80=o00Io80Mo00Anh0Eo00Mnh0=nX0Enh0InH0=n
00=BX0E:P0A6H0E6@0Hn@0@n80dj00Tih08j00Hn00=200M280I6@0E:@0A>H0EBH0EFP0EFX0IJX0EN
`0ER`0EV`003I^0006KP009Vh0]Zh0E_00ac00Eg00]g81ak80Eo@0<003]oo`03001oogoo02Ioo`00
97oo00<007ooOol0FGoo3Wm00WlP2gm077lP1Gl017lP1gl01WkP0gl01gkP17jP17kP1WiP17h014jP
1DZ014IP1T900ci01ShP2SX03SWP00<j03h0?P001Ch00d801D8P1DI01DY01DiP1E9P1EJ015Z01UZP
1Ek01F;01FK000=Zh000J^002F[P1FkP1Fl02g<01WL02WLP77/P1Wm0?Woo00<007ooOol09Goo000T
Ool00`00Oomoo`1HOol>Od05Ob08Od0LOb07O`02Ob07O`08O^000gl0O^1nh005O^06OZ03O^06OV05
OP04CZ05BX05AV05@T05?R0<>P02>N02=N0=>N000cX0?P0n0006?P05@R05AR05BT05CV05DV05EX05
FX06GZ05HZ05H/05I/000`00J^1Zh008J^05K^05K`0<L`05M`0;Mb0LNb05Od0nOol00`00Oomoo`0U
Ool002Aoo`03001oogoo05Qoo`eo@0Qo80Eo@1ao811o011nh0QnX003O^1nH7iP00AnH0In0003DZ1>
X4jP009>X0]6H0Hn@0Dj80Tj00Leh0/ih003>P0n03h000@n00I280E680I:@0E>H0ABH0IFP0EJP0EN
X0ERX0ER`0EV`003001Zh6[P00QZh0E^h0I_00]c00Eg00]g81ak80Eo@3ioo`03001oogoo02Eoo`00
97oo00<007ooOol0Egoo3Gm02glP0Wm077lP2Gl00gkP17l02GkP0Wk01WkP27jP1giP1Wh00U:P1TZ0
1DIP1D900ci01CXP1CX013H033GP0SG000@ih3GP=N0eh0@ih0@n00=200=280E680I:@0E>H0EBH0EF
P0EJP0ENX0IRX0ER`0AV`003001Zh6[P00UZh0E^h0E_00ac00Eg00]g81]k80Io83eoo`03001oogoo
02Eoo`0097oo00<007ooOol0EWoo3Gm08glP0Wl017lP2Gl01GkP0Wl02GkP17k017kP2GjP00=n@7iP
OV000giP1gh014jP1TZ01D9P14901SXP1CX013H03SGP0SG013GP1CWP00<n0480@P001D801DHP1TY0
1Di01E9P1UJ01EZ015jP1V:P1F;016K000<006[PJ^002F[P1FkP1Vl02g<01GL02gLP47/P4GlP?Goo
00<007ooOol09Goo000TOol00`00Oomoo`1EOol>Od0ROb04O`02Ob09O`0@O^05O/03O^09OZ02OT05
OV07OP000e;0CZ1>X003CZ03BX03AX05@V06?T06>P08=N03=L03=N03=L02=N03=L04=N03>N03?N00
0ch0@P120002@P06AR06BT05CT05DV06EX05FX05GZ06HZ08I/000`00J^1Zh009J^05K^06K`0;L`05
M`05Mb0GNb0@Ob0mOol00`00Oomoo`0UOol002Aoo`03001oogoo05Eoo`eo@29o80mo00Mnh09n`0Mn
h0Mn`003O^1nX7jP00MnX0An@0AnH0Mn00=B`0A>X0M6P0Pn@0<j80<j00Teh0<e`0<a`0Te`0@eh0@i
h0<mh003?P120480009200A680=:80=:@0E>@0IBH0EFH0EJP0ENX0IRX0QV`003001V`6[000EZ`0Y^
h0Ibh0Ec011g01Ik815o83aoo`03001oogoo02Eoo`0097oo00<007ooOol0E7oo3Gm08WlP3gl01gkP
17k01GkP27k02GjP1Gi00giP27h015;01TZP0dJ0149P13i01SXP2SGP0S7000@e`370<L0a`08aX0`e
`0Dih08mh003?P12048000=2009680I:80E>@0IBH0EFH0EJP0INX0ERX0QV`003001V`6[000EZ`0Y^
h0Ibh0Ec011g01Ik815o83aoo`03001oogoo02Eoo`0097oo00<007ooOol0E7oo1Wm00glP0gm08glP
3Wl01gkP1Wk00gkP27k00Wj01gjP1Wi00giP27h000=F`4jPCZ0014jP1DZP1d9P23XP0SH00cGP2c70
1C6P2SG01CWP0cgP1D801dXP1Di01U9P1EIP1UZ01Ej01F:P26K000<006K0I/001F[02VkP1W;P1G<0
47L05W/P4GlP?7oo00<007ooOol09Goo000TOol00`00Oomoo`1COol6Od0YOb0>O`07O^08O/000gkP
O/1n`006O/04OX05OZ08OT000giPOP1n0007OP03D/06CZ06AX03@V04>T04>R05=P05<L02<J02<L0;
<J02<H06=L06>N03?N02@P03AR04BR06CT06DV05EV06FX05GX05HZ08I/000`00I/1V`005J/0;K^05
L^06L`0?M`0GNb0@Ob0lOol00`00Oomoo`0UOol002Aoo`03001oogoo05=oo`Io@25o809o00Eo80io
00Mnh15n`0InP0=nX0Un@003OV1n07h000Mn00EB`0=>X0=:X0I6P0Lj@0Hf00Da`0TaX08]P0HaX08a
P0DaX08eX08e`0<ih0<mh0=200=6809:80=>80=>@0=B@0=BH0EFH0IJP0ENP0ERX0EVX0=V`003001V
`6K000EZ`0]^h0Ebh0Ic011g01Ik815o83]oo`03001oogoo02Eoo`0097oo00<007ooOol0DWoo1Wm0
8GlP1Gl00WlP3gl01WkP2Gk00WjP1Wk027j000=nX7i0OT0027i02Gh000=Fh5;0D/001E;01TZP0dJ0
13iP0cY01cH01C703bf00ReP0c601C6P0SFP0SG00cWP13gP0d800THP1dhP1U901EIP1UZ01Ej01F:P
1VJP0V[000<006[0J/001F[02fkP1G;P1W<047L05W/P4GlP>goo00<007ooOol09Goo000SOol00`00
Oomoo`1COol6Od0POb0FO`06O^09O/04OZ04O/09OX0:OT0:OP03E^04D/04C/05BZ07?V07=P06<L05
;H02:F02;H03:F04;H04;F06<J02=J02=L04>L03?N03@P04BR04CR06DT05EV06FX05GX05HZ06IZ02
J/000`00J/1Z`006J/05K/0:L^06L`0@M`0FNb0AOb0kOol00`00Oomoo`0UOol002=oo`03001oogoo
059oo`Io@25o81Eo00Inh0Un`0InX09n`0UnP09nH0Qn@0Yn0003F`1Fh5KP00=Fh0U>`0Q2P0Lj80Ha
`0H]H0PYH0<Y@0P]H0<aP08aX0<e`0<i`0<mh092009600E:80IB@0IFH0IJP0ENP0ERX0IVX09Z`003
001Z`6[000IZ`0E^`0]bh0Ifh0mg01Ik815o83]oo`03001oogoo02Eoo`008goo00<007ooOol0DWoo
1Wm087lP5Gl01gkP27k027jP2Gj00giP1gi02gh015/01U;P14k014JP14:013Y013XP1S700bU00beP
0RDP0RUP12DP12U00RTP1ReP0c600S6P0cG00cW00cgP1DH00TXP0dhP15900UI015IP1EiP1Uj01F:P
1VJP0V[000<006[0J/001V[01Fk02g;P1WKP2WL02g/01W/P6glP?7oo00<007ooOol097oo000SOol0
0`00Oomoo`1AOol6Od0POb0EO`07O^08O/08OZ09OX05OV05OT0;OP04F`04E`06D^08AZ08>T07<L06
:D099B038>06:B03;F03<H02<J03=L03>L04@N04AP06CR02DT04ET02EV05GV03HX03GX05HZ06IZ02
JZ000`00J/1Z`006J/05K/0;L^06M^0:M`0;N`06Nb0KOb0lOol00`00Oomoo`0TOol002=oo`03001o
ogoo051oo`Mo@21o80eo009nh0Eo00Mnh0Qn`0QnX0UnP0InH0An@0an009O00QG00=Bh0E>`0A6X0Ln
H0Leh0LY@0DP`0@L`0@Ph0038<0Y82TP00HY808]@0<aX0@eX0<m`0=1h09600=:80E>80IF@0INH0IR
P0ERX0IVX09ZX003001ZX6ZP00IZ`0E^`0]bh0Ifh0Yg00]k00Ik81]o83aoo`03001oogoo02Aoo`00
8goo00<007ooOol0D7oo0glP0gm06GlP0gl017lP3Gl01GkP0Wl01gkP27k027jP2Gj027iP0Wi03Gh0
1El01eL02Dk023iP13X00cGP1RU01Qb00aAP0Qc00QB00R3P0R301bTP0be00c600cFP0cg00d7P1TXP
0ThP1eI00eYP0eiP1V:00fJ00V:P1VJP0VZP00<006ZPJZ002fk02g;P1WKP2WL02g/01W/P6glP?7oo
00<007ooOol097oo000SOol00`00Oomoo`1@OolNOb0EO`0>O^09O/06OZ09OX09OV000gi0OP1n000;
OP000f<PG`1O0006G`03E`08D^09AZ08>P06:D0766022602560458068<04:B03;D03<H03=J03?L04
AP05BR08ET06FV06HX05IX06IZ02JZ000`00JZ1ZX00;K/0;L^06M^0:M`0;N`06Nb0KOb0lOol00`00
Oomoo`0TOol002=oo`03001oogoo04mooamo81Ao00inh0]n`0AnX0UnP0YnH0in00ES80IO00QBh0E>
h0E6X0LnH0L]H0LHH0<0H088H084H08DP0<@H0<P`0<Th0@]@0<aP0<eX0@m`0A6009:80=B80EF@0MJ
H0=RH0=RP0EVP0QZX003001ZX6ZP00]^`0Ibh0]fh0Yg00]k00Ik81]o83aoo`03001oogoo02Aoo`00
8goo00<007ooOol0Cgoo7WlP57l03WkP3Gk00WjP2Gj02WiP0WhP37h02V<P2E/02TkP23iP1cFP21b0
1@000P1000<4H11P46000Q1P0QAP00@P`2CP9>0Th0@Y80<aH0<eX0@m`0A600IB809F@0AJ@0=JH0IR
H0IVP0QZX003001ZX6ZP00]^`0Ibh0]fh0Yg00]k00Ik81]o83aoo`03001oogoo02Aoo`008goo00<0
07ooOol0CWoo7glP57l03GkP3gk02Gj02WiP0ghP37h016M01F<P1ElP1E/01EL01DkP1dJP23FP22BP
1Ab00cS00`100Q1P0aAP0bCP12TP0c5P0cFP13g00TH00dh01E8P1eY01f9P1VJ026ZP00<006ZPJZ00
2fk01W;P2gKP1G[P47/01W/P6glP?7oo00<007ooOol097oo000SOol00`00Oomoo`1>OolNOb0DO`0>
O^0?O/02OZ06OX0:OV05OR0:OP09Id0:Gb0:E`08AZ08?R09<B05><05BV000`0P040DH00356037804
:B03<F03=J04?L05CP04DR02ER05FT02GV04HV06IX09JZ000`00JZ1ZX00;K/06L^0;M^05N^0@N`06
Nb0KOb0lOol00`00Oomoo`0TOol002=oo`03001oogoo04eooamo81=o00inh0mn`0AnX0AnP0YnH0In
80Yn0003Jd1W@6M000YW@0]O80EG00Q>h0Q6X0U200I:H0E[H004On0080100402560378039>04<F03
=J05AL04CP02DR05ER02FT05GV02HV06IX03JX06JZ000`00JZ1ZX005K/03L/03K/06L^0;M^05N^0;
N`0;O`0KOb0lOol00`00Oomoo`0TOol002=oo`03001oogoo04eooaio81Ao00enh0mn`0InX09nP0Yn
H0Qn80Qn00E[@0eW@0]O80Q>h0U6X0Y>`0M[H0Ioh0<0@0@LP0<Th0@a@0<iP0E5`0A>00MF80MNH0MV
P0IZP0=ZX003001ZX6ZP00E^`0Ib`0Ibh0]fh0Ejh0]k00]o01]o83aoo`03001oogoo02Aoo`008goo
00<007ooOol0C7oo7WlP57l03WkP3Wk027jP2WiP2GhP1Wh00g601f]02VM01F=01UlP25/P2E<01Dk0
1F=P16]P2goP0P100Q100Qb00bCP13500cV01DG01E801EHP0Ui01EiP0fIP16J01VZ00fjP00<006ZP
JZ001Fk01W;01GK037KP1G[P2g/02gl06glP?7oo00<007ooOol097oo000ROol00`00Oomoo`1=OolN
Ob0DO`0=O^0>O/08OZ02OX08OV02OT09OR03OP05LH000aPPKd1[@003Jd0:Jf0;Hd09Fb09D`0:Hf0A
On001010440@@11012CP13500cV00dG00dgP1E800UHP1Ei00UiP1fIP1fZ00fjP00<006jPK/001Fk0
1W;01GK037KP1G[P2g/02gl06glP?7oo00<007ooOol097oo000ROol00`00Oomoo`1<OolOOb0CO`0=
O^0>O/08OZ04OX06OV04OT08OR08LH026203Kd0@Jf0?Hd09Hf0:Lj0BOn00100P440@@1100b2P1350
13V01TgP1E801ei026IP1VZ016jP00<006jPLZ000W:P0fk01G;01WK01WKP2g[P2g/02gl06glP?7oo
00<007ooOol097oo000ROol00`00Oomoo`1<OolNOb0CO`0=O^0>O/08OZ06OX04OV05OT07OR02LN07
LH026202Kd06Kf0?Jf0:Hd04Kh0KOl0BOj000c4P@J11X002@J06CN03DP02FR06GT02IT05IV07JX04
KZ000`00KZ1bX004LZ06L/06M/06M^0:N^0<N`0;O`0KOb0mOol00`00Oomoo`0SOol0029oo`03001o
ogoo04aooaio81=o00enh0in`0MnX0QnP09nH0Mn@0An80Aah0QaP08H80]_H0][H0E[P2Ao`19oX0Uk
X0==h0EJ80AN@0EV@09VH0MZP0E^X003001bX7:P00AbX0Ib`0If`0Ifh0Yjh0ak00]o01]o83eoo`03
001oogoo02=oo`008Woo00<007ooOol0C7oo7GlP4gl03GkP3Wk01gjP2Gj02Wi00WhP1W7P1g600aPP
17=P1VmP2Vn00V^01GoP8Wo04gnP4G^P00=J85i0GT001fI026Z00fj00VjP00<007:PLZ0017:P1G;0
1gK01GKP2g[P1W/04Gl06glP?Goo00<007ooOol08goo000ROol00`00Oomoo`1<OolMOb0BO`0>O^0=
O/07OZ09OX02NV09OT08LN07LH036209Lf08Kh0:On0ROl0BOj0BNj06Nh04IT02JV05JX06KX000`00
LZ1bX003LZ06L/06M/06M^0;N^06N`0AO`0KOb0mOol00`00Oomoo`0SOol0029oo`03001oogoo04ao
oaeo819o00enh0in`0MnX09jP0InP0AjH0Mn@09b00Qah0IaP0@H8003Mh1cH7=P00AcH0EcP0ioh0Uo
`0Qoh15o`19oX15kX0ekP09ZH09ZP0M^P003001bX7:P00=bX0Ib`0If`0=j`0=fh0]jh0Ik011o01ao
83eoo`03001oogoo02=oo`008Woo00<007ooOol0Bgoo7GlP4gl037kP3Wk01gjP17Z017j01WYP17i0
1G801g7P1g6011PP1GN000=cP7oPOn008WoP4Go04GnP4G^P4g^01Fj00W:P00<007:PLZ000W:P1G;0
1gK01G[037[P1G/04Gl077lP?Goo00<007ooOol08goo000ROol00`00Oomoo`1;OolMOb0BO`0=O^0=
O/07OZ06NX02OX08NV02OT06LP08LN06LH046203Mh0WOn0AOl0@Oj0BNj06Mh0<Nh05Mh0016j0LZ1b
X0000g:P1W;01WK01W[037[P1G/04Gl077lP?Goo00<007ooOol08goo000ROol00`00Oomoo`1;OolL
Ob0CO`0<O^0>O/02NZ05OZ07NX09NV09LP07LN06LH04620ZOn0AOl0@Oj0ANj0<Mh06Nh09Mh001000
LZ1bX7:P0gJP0g;01WK01W[037[P1G/04Gl06glP?Woo00<007ooOol08goo000ROol00`00Oomoo`1;
OolLOb0CO`0;O^0>O/05NZ02OZ08NX02MV06NV02KT09LP03LN04EH02=<03LH0^On0AOl0@Oj0@Nj0L
Mh000`00Mh1gP006MZ06M/07N/05N^06O^06N`0AO`0KOb0nOol00`00Oomoo`0SOol0029oo`03001o
ogoo04]ooaao819o00anh0=jh0]n`0IjX0QjP0AfH0AjH0A^@0Qb00MEP08d`35oh11o`11oX15kX1ag
P003001gP7N000=gP0=fX0=j`0=f`0Ij`0Ijh0]nh15o01ao83ioo`03001oogoo02=oo`008Woo00<0
07ooOol0Bgoo77lP4Wl037kP1W[P1gk01gZP0WJP1GZ01WIP0WYP1Vi01W800V7P15F0=GoP47o047^P
27N027^P7GN000<007N0Mh001WN037[01W[P2gkP4Gl077lP?Woo00<007ooOol08goo000QOol00`00
Oomoo`1;OolMOb0BO`0;O^07N^02N/05O/06NZ04MZ04NX07MV08KT03LP05HN000eF0On1oh00eOn0@
Ol0@Nj0]Mh000`00Mh1gP004Mh05Mf02N/03O/04N/05N^0<O^0AO`0KOb0oOol00`00Oomoo`0SOol0
025oo`03001oogoo04]ooaao819o00anh0Mjh0Aj`09n`0IjX0IfX09jP0QfH003KV1^@6i000I^@0EQ
h3Yoh0mo`11kX25gP0EcH0QgP003001gP7N0009gP0YgH0En`0Ijh0]nh19o01]o83moo`03001oogoo
02=oo`008Goo00<007ooOol0Bgoo77lP4Wl01G[P1WkP1g[P1W[01gZP1gJP27IP0fiP1Vi00VHP00=Q
h7oPOn00>goP3go047^P87N02G=P1GN000@007N0Mh1gP0igH09n`0=nh0=jh0]nh15o01ao83moo`03
001oogoo02=oo`008Goo00<007ooOol0Bgoo77lP4Wl027[P0gkP1g[P1W[00gK00gZP27JP0W:01GIP
1FiP16i000=V87oPOn00?WoP3go03g^P87N03W=P00AgP000Mh1gP19gH11nh1Io01Mo841oo`03001o
ogoo029oo`008Goo00<007ooOol0Bgoo77lP4Gl04W[P1W[01WK027JP1G:00WIP1fiP00=^@7oPOn00
@GoP3go03W^P47N01G>037N03g=P00<007=PMf0057MP3GkP5gl05WlP@Goo00<007ooOol08Woo000Q
Ool00`00Oomoo`1;OolKOb0BO`0BN^06N/06M/02LZ05MZ07LX06KV16On0?Ol0>Mj08Lh08Mh0:Lh06
Mh0@Lf000`00Lf1cH002Lf0DMf0;O^0GO`0FOb11Ool00`00Oomoo`0ROol0025oo`03001oogoo04]o
oa]o819o015jh0Ij`0Mf`0AbX09fX0QbP0A^H0=o`4Eoh0mo`0igX1mcP15cH003001cH7=P00EcH1=g
H0Qnh1Qo01Io845oo`03001oogoo029oo`008Goo00<007ooOol0Bgoo6glP1Wl00g/027l04W[P0gK0
0g[01WK01W:P27:00fiP1Wo0A7oP3Wo03WNP47>01FmP2W>04W=P00<007=PLf0027=P4WMP1WkP5gl0
5WlP@Woo00<007ooOol08Woo000QOol00`00Oomoo`1;OolKOb06O`05N`06O`0BN^0<M/06LZ02KZ05
LX02KV08Ol14On0>Nl0>Lj07Kh08Lh0:Kf05Lh0CLf000`00Lf1cH00;Lf04Mf05Lf08Mf03O^0HO`0F
Ob12Ool00`00Oomoo`0ROol0025oo`03001oogoo04]ooa]o80Io00Yk01=jh0Ef`09b`0Af`0MbX0A^
X09bP0ao`4=oh0ik`0icX0i_P0m_H1AcH003001cH7=P01IcH0QgH003O^1o07l001Io01Io849oo`03
001oogoo029oo`008Goo00<007ooOol0Bgoo6glP1Wl047/037[P1WK017;00WK01W:P1FjP3go0@WoP
3G_03W>P3Vn05FmP3g=P00<007=PLf0067=P27MP5Wl05WlP@goo00<007ooOol08Woo000QOol00`00
Oomoo`1:OolLOb06O`0@N`03M^09N^06M/05L/07LZ03KZ0BOl11On0=Mj0>Kh0=Jh0JKf06Lf05Kf00
0`00Lf1cH00JLf08Mf0DO`0FOb13Ool00`00Oomoo`0ROol0025oo`03001oogoo04Yooaao80Io011k
00Efh0Mjh0Ef`0Ub`0AbX1Eo`45oh0egX0e_P0i[P0A[H25_H003001_H6mP01acH0QgH19o01Io84=o
o`03001oogoo029oo`0087oo00<007ooOol0Bgoo77lP1Wl047/02gKP1WK037;00WnP4Wo0@goP3FnP
6V^02F]P7FmP00<006mPKf000fmP6g=P1gMP47l05WlPA7oo00<007ooOol08Woo000POol00`00Oomo
o`1;OolLOb06O`0@N`0;M^03L^03M/0:L/05Oj0?Ol0oOn06Nl0=Kj0<Jh0=If0>Jf0IKf000`00Kf1_
H006Kf0JLf07Mf0>O`0FOb14Ool00`00Oomoo`0ROol0021oo`03001oogoo04]ooaIo80Ek80Io015k
00]fh0Ebh0Ub`0QoX0ao`3Yoh0ek`0a_X0a[P19WH0Y[H0A[@1E_H003001_H6mP00E_H0=_@1UcH0Mg
H0ao01Mo84Aoo`03001oogoo029oo`0087oo00<007ooOol0Bgoo5WlP1W/P5W/02gKP1G;P27;02GnP
2Wo0?7oP37_03F^036MP1V=046MP1F]P2F]01VmP16]01fmP00<006mPKf0016mP1Vm06G=P1gMP2Wl0
5WlPAGoo00<007ooOol08Woo000POol00`00Oomoo`1;OolFOb06Nb0:N`06M`06N`0;M^05L^06L/0<
Oj07Ol0nOn06Nl06Lj0=Jh0<If0<Hd0>If0GJd04Kf000`00Kf1_H003Kf09Kd0<Lf04Ld08Lf07Mf08
O`0GOb16Ool00`00Oomoo`0QOol0021oo`03001oogoo04]ooaIo80Ik80Yk00]g00afh0Ebh0Ab`0mo
X0Ao`41oh0acX0a[P0aWH1=S@0MWH0EW@1I[@003Kf0006mP009_H0e_@0QcH0Qc@0QcH0MgH0Io01Io
84Moo`03001oogoo025oo`0087oo00<007ooOol0Bgoo5WlP1W/P2W/02gL037KP1G;P0g;04GnPA7oP
1W>P1FMP8em03F=02fM04f]000<006]0Kd0046m017=P2g=027=P1gMP17l05glPAgoo00<007ooOol0
8Goo000POol00`00Oomoo`1;OolFOb06Nb0:N`0;M`06M^0;L^000g;0Oj1oX00@Oj02Ol13On0;If0S
Gd06Gb0;Hd0:Id0@Jd000`00Jd1[@002Jd0@Kd0?Ld08Lf03Mf04Md02O`0FOb18Ool00`00Oomoo`0Q
Ool0021oo`03001oogoo04]ooaIo80Ik80Yk00]g00Ifh0Ybh19oX0Eo`3moh0=cX0]WH0]C00]G00IG
80IO@0aO80YS@0UW@0e[@003001[@6]000A[@11_@0ic@0QcH0Mg@1Mo84Qoo`03001oogoo025oo`00
87oo00<007ooOol0Bgoo5WlP1W/P2W/02gL01WKP2G;P4GnP27o0>goP1W>P2eL02e<02eL02eLP4ElP
2F=02FM02V]000<006]0Jd001V]03fm03g=017=P17=01gM057lPBGoo00<007ooOol08Goo000POol0
0`00Oomoo`1<OolEOb06Nb0:N`0;M`06M^07L^0AOj0;Ol0gOn07Lj03F`0:E`0;AZ0:B/0;Eb07Fb0>
Gb05Hd04Hb09Id07Jd000`00Jd1[@008Jd0?Kd0FLd07Md0COb19Ool00`00Oomoo`0QOol0021oo`03
001oogoo04aoo`]o811k80Yk00]g00Ifh0Ibh11oX0io`3=oh0McX0IK00Y6@0Y6X0]:`0Y>h0eK80aO
80US80QW@0E[@003001[@6]000Y[@0i_@1Ic@0Mg@15o84Yoo`03001oogoo025oo`0087oo00<007oo
Ool0C7oo2glP5W/P3gL01WKP17;P47nP47o0=7oP0g>P1U/00dG02TI02ShP2T:02TkP1U<02e/P25lP
3F<P16M00fLP0f]000<006]0Jd0036]03Vm05G=027M03glPBWoo00<007ooOol08Goo000OOol00`00
Oomoo`1>Ool:Ob0FNb0?M`06M^03L^0?Oj0COl0cOn05F`07AL0:>F09?R0;@X09B/0<D`09Fb04Gb0@
Hb07Ib000f]0001[@00?Jd0=Kd0FLd07Md0=Ob1;Ool00`00Oomoo`0QOol001moo`03001oogoo04io
o`Yo81Ik811g00Ec0003L^1oX7nP00eoX1Io`31oh0=gP0I5`0H`P0T/X0TeX0Xn@0Y:`0E>h0IC00AG
00UK80mS80YW8003001[@6]000m[@0e_@1Ic@0Mg@0ao84]oo`03001oogoo025oo`007goo00<007oo
Ool0CWoo2WlP5W/P47L01G<03gnP0gn05Go0;GoP0gN00df01c2011B02BbP2CFP2Ci02T:02dkP25L0
1E/P1El02F<P36LP00<006LPIb0016]016/P2F]03Fm05G=01gM02WlPC7oo00<007ooOol08Goo000O
Ool00`00Oomoo`1>Ool;Ob0FNb0?M`03L`0@Oj05Oh0DOl0[On03Mh03CH0010P0980TP2B00PP00PaP
00@0@01P0600H080@0PDH0P]80Teh0Y2P0E6X0I>h0ABh0QG00YO00US80UW8003001W86LP009W80Q[
80U[@0a_@1Ec@0Mg@0Qo84eoo`03001oogoo025oo`007goo00<007ooOol0Cgoo2WlP5W/P3gL000=c
07nPOj003WnP27n057o0:7oP0gN00df000<802B098001QR00`aP0`QP0P1P1a1P22SP136P1CGP2Ci0
2TJP2E;P15L015/02Ul026<P1fLP00<006LPIb0016LP26/P26]03Fm057=01gM01glPCGoo00<007oo
Ool08Goo000OOol00`00Oomoo`1?Ool:Ob0FNb0?M`03Oh0=Oj0:Oh0DOl0TOn04Mh03CH0298039>03
8>0468000aRP360<H0025803260646079<09<J09?T05@X05AZ04C/08D^09F`09G`08Hb05Ib000`00
Ib1W8006Ib08Jb04Jd04Kb0<Kd0DLd07Md05Ob1?Ool00`00Oomoo`0POol001moo`03001oogoo04mo
o`Yo81Ik80ig00EoP0YoX0eoP1Ao`2Eoh09=P08TP004;D0Y82TP:B039>048>0268036:0558066807
8<08;F09>R0:@X08C/04D^04E^09F`08G`08Hb03Ib000`00Ib1W8008Ib07Jb08Kb0=Kd0CLd07Md03
Ob1@Ool00`00Oomoo`0POol001moo`03001oogoo04moo`Yo81Ik80ag00QoP0QoX0moP1Ao`2=oh09o
H0800004<H0]H2eP;F02:D03:B058>046:027<0358027<0368038>048<08;F04=N04>R05?V05@X04
AZ08C/08E^08F`08G`08Hb000fLP001W800;Ib07Jb07Kb0=Kd0CLd07Md02Ob1@Ool00`00Oomoo`0P
Ool001moo`03001oogoo051ooaEk811g80Ec00YoP0EoX15oP1Eo`25oh09oH003000eX360008aP0<]
H08Y@0<Y808U80LPh0TL`0HPh0P]H0Peh0XnH0Q6X0A>`0AB`0QFh0MK00QO00QS8003001W86LP00YW
80M[80M_80e_@1=c@0Mg@55oo`03001oogoo021oo`007goo00<007ooOol0D7oo5G/P47LP0g<03Gn0
0gnP57n057o07goP0WmP00@003G0=J0eX0<aP0<]H08Y@0<Y80DU80@Ph0<U00DQ00HU00HYH0Pa`0Hj
80DnH0E2P0I6X0QB`0QFh0MK00AO00AS00IS8003001W86LP00QW80Y[80M_80Y_@1Ic@0Mg@51oo`03
001oogoo021oo`007goo00<007ooOol0DGoo57/P4GLP00=c07n0Oh0097n04Wo00WnP77oP0gmP00@i
h3G0=L0e`08eX0<aX0<aP004;F0Y82TP:B069B03:B049@029D028@039D039@06:F04<J04<L04=P05
>R0:@X06C/07D/08E^07F`08H`04Hb000`00Hb1S8005Ib0>Jb07Kb06Kd0JLd07Md1?Ool00`00Oomo
o`0POol001moo`03001oogoo055ooaEk80mg811oP0=oH1IoP11o`0AoX1Yoh0=oH003?P0ih3WP00@e
`08eX08aX0<aP0H]H0<U80@Y80<Y@0TU@0HYH0PaX0Pf00HnH0E2P0=6X0I>`0AB`0ABh0MFh0=K00AO
00MS00=S8004001S86<PHb06Ib0=Jb0>Kb0ILd07Md1>Ool00`00Oomoo`0POol001moo`03001oogoo
055ooaEk80ig811oP0EoH1IoP0io`0IoX1Qoh0=oH0<n00<ih0@e`003=J0aX36P00<aP0P]H0@Y80<Y
@08YH08U@0@YH0H]H0PaX0@eh0@f00<j@0LnH0M6X0I>`0QBh0IFh0QO00MS0003Hb0006<P00AW00EW
80e[80i_81Uc@0Mg@4eoo`03001oogoo021oo`007Woo00<007ooOol0Dgoo57/P37LP4Gn01gmP5Wn0
37o01gnP5goP0WmP00Aoh480@P1200Hih0<e`003=J0aX36P008aP0`]H0<Y@0PYH0<]P0<]H0LaX0Le
h0Lj@0@nH0=2P0M6X0M>`0MBh0IJh0MO00MS0003001W06L000AW00EW80e[80i_81=c@0eg@4aoo`03
001oogoo021oo`007Woo00<007ooOol0Dgoo5G/P2WLP0gmP3Wn02WmP5Gn02Go02WnP57oP0WmP0goP
0d800Sh01CWP1CG0136P0S600bf022eP12UP2Bf01S6P1cGP1CXP1SY01d:014JP14jP1Tk015;P0eKP
1U[P1el01F<000<006<0I`001FL01VLP3F/P3FlP4g=03GM0Bgoo00<007ooOol087oo000NOol00`00
Oomoo`1DOolDNb09Mb05Of0;Oh0=Of0EOh07Ol0<Oj0GOn000d8P@P120005?P02>N08=L03<J02<H08
;H03;F07;H02;J03;H05<J04<L03=N03=P06>R06?V06@X08CZ06C/07E^06F^06G`04H`000`00H`1S
0006I`06Ib0=Jb0=Kb0CLd0<Md1;Ool00`00Oomoo`0POol001ioo`03001oogoo05AooaAk80Qg80Mo
H0UoP0moH1EoP0Eo`0ioX1Ioh0=280Hn00<ih0Le`0<aX08aP10]P0D]X0DaX0La`0Hf00<j80<n@0Ln
H0E:P0Q>X0IB`0MFh0EJh0MO009S0003001S06<0009S00EW00IW80e[80e_81=c@0ag@4Yoo`03001o
ogoo021oo`007Woo00<007ooOol0E7oo47/P2gLP2WmP1Wn04GmP5Gn00go03WnP0Wn057oP148P1Sh0
1CWP1cG01c6P1Rf00S6P12f0236P1S702SH01ci00ciP14J01DZ024jP1E;01eKP1UkP1Ul000=S0000
H`0016<01FL01f/036/P3FlP1W<P3G=037M0BGoo00<007ooOol087oo000NOol00`00Oomoo`1EOol5
Nd0;Nb09Mb0=Of03Oh0COf0EOh0?Oj04Oh0COn04@R06?P06>N07=L0:<J02;H09<J02<L03<J05<L03
=N05=P06>R05?T08AX05BX07CZ06D/03E^04F^05G^06G`000`00H`1S0004H`06I`06J`0<Jb07Kb0<
Lb0<Ld0=Md18Ool00`00Oomoo`0POol001ioo`03001oogoo05Eoo`Ik@0Yk80Qg82EoH1=oP09oH0eo
X0IoP15oh003AT12848P009280Hn00<j008ih0<eh0He`1<aX0Xa`0Heh0Hj00Dj80I2H0I6P0a>X0IB
`0MJh0ENh0EO0003001S06<000ES00IW00I[00a[80M_80ac80ac@0eg@4Qoo`03001oogoo01moo`00
7Woo00<007ooOol0EWoo1G]02g/P1WLP9gmP4Gn017mP2gnP1Wn00WmP47oP00=6@48P@R000T8P1Sh0
1CX00SWP0cGP1CG01370236P0c700c6P23701SGP13H01SX01Ci01T9P1TZ02djP1eK01U[P1EkP15l0
00<005l0H`001V<01VL01V/036/P1flP2g<P3G=037M0B7oo00<007ooOol07goo000NOol00`00Oomo
o`1FOol6Nd0:Nb05Mb0ZOf0=Oh07Of08Oj07Oh04Of0>On03AT04@R05?P05>P04>N03=N04=L04<L03
<J03<L000c6P<L0a`009<L0;=N04=P06>R05?T06AV06BX05CZ06D/06E/06F^05G^03H^001000H^1R
h6;P1V<01VL01V/01V/P3FlP2g<P3G=037M0Agoo00<007ooOol07goo000NOol00`00Oomoo`1GOol5
Nd0;Nb03Mb0/Of0;Oh09Of06Oj07Oh06Of0=On03AT05@R04?P05>P06>N02=N04=L04<L03<J0=<L03
=L0:=N0;>R05@T06AV05BX06CZ05D/06E/06F^06G^000f;P001Rh003H^06H`06I`06J`06Jb0<Kb0<
Lb0<Ld0<Md17Ool00`00Oomoo`0OOol001ioo`03001oogoo05Moo`Ik@0Yk809g81IoH0=o@1EoH0Uo
P0]oH0AoX0MoP0MoH003Od1oh7oP00Yoh0=6@0E280Dn00Dj00Dih0@eh0Pe`003<J0a`37000Ha`0Te
`0Heh0Df00Dj80Dn@0E2@0I6H0E:P0I>X0EB`0IF`0IJh0INh003001Rh6;P00=Rh0IS00IW00I[00I[
80a_80ac80Ic@0Ig80ag@4Ioo`03001oogoo01moo`007Woo00<007ooOol0F7oo1G]02g/P5WmP1Gm0
4gmP0gm01Gn03WmP0WnP1gn01gmP0gm02WoP00=:H4I0AT000TI01D8P13h01CX01CWP1CGP2cG01370
1cG02SGP1CH01CXP1Ci01D902dZ01TjP1E;01e[01E[P1EkP00<006;PH^0016;P1V<01VL01V/01V/P
36lP4W<P1GLP37M0AWoo00<007ooOol07goo000NOol00`00Oomoo`1HOol6Nd09Nb0FOf07Od0AOf05
Od03Oh0?Of08Oh07Of05Od09On02AV04@T04@R05?P04>P05>N05=N0C=L0>=N06>P04>R05?T06AV0:
BX06CZ06E/06F/05F^04G^000`00G^1Rh005H^0<I`06J`05Jb0=Kb0BLb05Mb0<Md15Ool00`00Oomo
o`0OOol001eoo`03001oogoo05Yoo`Ek@0Ek80=g@1IoH0Yo@0ioH0Mo@11oH09o@0IoP0MoH0Io@003
O^1oh7oP00Eoh0A6H0A2@0@n80Dn00@j00Teh1De`0Teh0Df00Dj00@j80I2@0E6H0Y:P0IBX0IF`0IJ
`0EJh0=Nh003001Nh5kP00IRh0aW00E[00I[80a_819c80Eg80ag@4Eoo`03001oogoo01moo`007Goo
00<007ooOol0FWoo1W]01WM01gmP0Wm03GmP37m037mP2Gm03WmP17m017n01gmP1Wm00WkP1goP14IP
14901ChP1Ch013X02CGP5CG02SGP13H01CXP1ChP1T9014IP1TZ01Dj01E:P1UK01U[01E[P0V;P00<0
06;PH^001f;P36L01F/01V/P36lP4W<P1GLP37M0A7oo00<007ooOol07goo000MOol00`00Oomoo`1K
Ool6Nd04Md07Of05Od0:Of0>Od0:Of0;Od0<Of06Od02Oh07Of06Od04O^05On000dIPAT16@003AT05
@T04?R0:>P08=N0A=L0>=N05>P04>R05?R06@T04AV06BX05CX05DZ06E/06F/05G^000f;P001Rh008
H^0=I`05J`05Jb0=Kb0ALb05Mb0<Md14Ool00`00Oomoo`0OOol001eoo`03001oogoo05aoo`Ik@09g
@0MoH0Mo@0QoH11o@0QoH0eo@0YoH0Qo@0MoH0Io@0Enh0Eoh096H0E6@0E2@0@n80@j00heh14e`0de
h0Hj00Dn80Y2@0A6H0I:P0E>P0EBX0aJ`0ENh003001Rh6;P00QRh0aW00E[00I_00a_819c80Eg80ag
@4=oo`03001oogoo01moo`007Goo00<007ooOol0GGoo1G]000=g@7mPOf001GmP2Wm01GmP4gm01GmP
3gm027mP27m00WlP1GmP1gm01GkP00AnH7oPOn1oh0A6H0E2@0Dn80Dj80@j00Teh1De`0Teh0Xj00Dn
80U2@0E6H0E:P0IBP0EFX0aJ`0ANh003001Rh6;P00URh0EW00a[00I_00a_815c80Eg80ag@4=oo`03
001oogoo01moo`007Goo00<007ooOol0GGoo1G]01gmP3Gm00WmP5Gm00gmP3gm00WlP1WmP27m017lP
0gmP1gm01GkP0giP0WoP00=:P4IPAV000dIP14901ChP1SX013H02CGP53G02CGP2SX01ChP14901DI0
1DYP1Dj01U:01EJP35[00ekP00<005kPH^002F;P1VL036/01Vl036lP4G<P1GLP37M0@Woo00<007oo
Ool07goo000MOol00`00Oomoo`1NOol3Nd08Of0eOd04Ob04Of08Od06Ob000gmPOd1o@005Od06O^04
OV03BX05AV04@T06>R05>P0==N0C=L0:=N09>P06?R04@T05AT05BV05CX06DX05EZ0;F/03G^000`00
G^1Rh005H^05I^06I`0;J`06K`0<Kb0ALb0<Mb05Md12Ool00`00Oomoo`0OOol001eoo`03001oogoo
05moo`03Nd1oH7mP00IoH2Eo@0=o80eo@0Io809oH0Qo@0Mo80Mo@0Inh0EnH004OP1:P4Z0BX06@V04
?T05>R05=P09=N09=L000c70=L0e`002=L000c70=L0e`005=L06=N05>N04>P05?P05@R05@T05AT05
BV05CX05DX05EZ06F/06G/02H/000`00H/1R`006H^05I^05I`0<J`06K`0<Kb0:Lb0BMb06Md11Ool0
0`00Oomoo`0OOol001eoo`03001oogoo05moo`QoH2Eo@0Eo80]o@0Qo80Qo@0Mo809nh0Io@0Inh0En
H003OP16H4IP00=6H0E2H0@n@0Hj80@f00Heh0Xe`0@a`0<e`003<L0e`3G000@e`0Heh0Dih0Dj00Dn
00E280E6@0E6H0E:H0E>P0EBP0EFX0IJ`0IN`003H/0006;0009R`0ERh0EVh0IW00][00M_00]_80]c
819g80Eg@49oo`03001oogoo01ioo`007Goo00<007ooOol0Ggoo0Wm01GmP9Gm01glP2Gm027lP0Wl0
1Wm01glP17kP17m01WkP1GiP0Wh000=:P4IPAV000dIP1D9P2SXP2SGP0SG03c702CG00cGP1CWP1CX0
1Sh0148P1DI01TIP1DYP14j01U:01EJP1E[01Uk000=R`000H/000V;01V;P1FKP1VL02f/01Vl01FlP
4G<P4WLP1WM0@Goo00<007ooOol07Woo000MOol00`00Oomoo`1NOol5Od02Of0UOd09Ob07Od08Ob04
O`04Od07Ob05O^03Od07O^05OV02OP03BX04AV06?T05>R05=P09=N0@<L02<J04<L05=L000cGP>N0i
h003>N06>P05?P05@R05AT0:BV05CX06DX05EZ05F/06G/000`00H/1R`002H/06H^05I^05I`0;J`07
K`05L`0ALb0AMb06Md11Ool00`00Oomoo`0NOol001eoo`03001oogoo05eoobao@0]o80Eo@0Qo80Io
009o@0Mo80Mnh003Od1nh7kP00Enh0EnH0=n00A:P0I2H0Dn@0Dj80@f00Heh0Pa`0<aX08a`0<aX08a
`0<aX0@a`0@e`0@eh08ih0Hj00Dn00E280I6@0E:H0E>H0YBP0EFX0EJ`0IN`003001R`6;0009R`0IR
h0EVh0IZh0I[00]_00Ec015c819g80Ig@41oo`03001oogoo01ioo`007Goo00<007ooOol0GGoo:gm0
3GlP0gm027lP1gl027lP47kP1GiP17h01TJ01D9P2SXP1SGP2C703c6P13701SG00cGP0cWP0cX01Ch0
1T8P1DI01DYP1DiP1E:01UJ01EZP1EjP1Ek000<006;0H/000f;02fKP1F[P1V/036l01G<04G<P4GLP
1WM0@7oo00<007ooOol07Woo000MOol00`00Oomoo`1LOolTOd02Ob05Od0HOb07O`02O^06Ob09O^00
0gjPO^1nh004O^06OV04OP02BZ06AX05?T05>R07=P06<L03<J02<L0E<J06=L000cGP>N0ih004>N06
?P05@R05AT05BT05CV06DX05EX05FZ05GZ05G/000`00H/1R`004H/0:I^06J^06J`0;K`05L`0ALb0B
Mb06Md0oOol00`00Oomoo`0NOol001aoo`03001oogoo05aoobAo@0Eo809o@0mo80=o00Io80Mo00An
h0Ao80Unh0=nX0Enh0EnH0En00E:X0I2H0@n@0Tf00Ha`0TaX0<]P0<aX0@]P0TaX0@e`0<eh0Dih0Hn
00E280E6@0I:@0A>H0IBP0EFP0IJX0ENX0AN`003001N`6;000AR`0]Vh0EZh0I[00]_00Ec019c815g
80Ig@3moo`03001oogoo01ioo`0077oo00<007ooOol0Fgoo97m05WlP1Wl00glP1gl01WkP0WlP2GkP
17jP17kP1WiP1Gh00dZP14J01T9P1CXP13H01c701C6P4bf01S6P1CG00cGP0SWP1Sh01T8P1TI01DY0
1DiP1U:015J01UZP1EjP15k000<005k0H/001F;02VKP1V[P1V/02fl01G<04G<P4GLP1WM0?goo00<0
07ooOol07Woo000LOol00`00Oomoo`1KOolSOd0FOb0@O`0AO^06OZ03O^05OV06OP000djPAX16P006
AX03@V04>T04>R05<N03<L03;J03<J0;;H02;F09;H02<H03<J05=L02=N03>N04?P03@P03@R03AR03
AT05BT05CV06DX05EX06FZ04GZ04G/000`00G/1R`005H/0;I^05J^06J`0;K`05L`0ALb0<Mb0<Nb0n
Ool00`00Oomoo`0NOol001aoo`03001oogoo05YooaEo@0=o80]o@1Io811o00Qnh09n`0Mnh0QnX003
O^1nH7iP00AnH0In00E:X0E6P0Pj@0Deh0@ah0H]X0T]P0<YH0D]H0L]P08aP0@aX0@e`0Hih08n00I2
00I680E:@0E>H0IBP0EFP0IJX0ENX0=R`003001R`6;000IV`0YVh0EZh0I[00]_00ac01Ig80ak83io
o`03001oogoo01ioo`0077oo00<007ooOol0FGoo5Gm01WlP27m05WlP47l027kP17k01GkP2GjP1giP
1gh01dZP1CiP13Y013H013GP1bfP3RUP0RU01beP0bf00S60136P1CG01CWP1d801THP1DY01TiP1EIP
1UJ01EZP1EjP0f;000<006;0H/001VK01FKP2f[P1VkP1Fl04G<05WLP37/P?Woo00<007ooOol07Woo
000LOol00`00Oomoo`1HOolEOd09Ob05Od0?Ob02O`05Ob0@O`08O^06O/03O^0:OZ000gi0OV1nH003
OV08OP02C/04BZ04@X05?V08=P04<J04;J05:F039B02:F049B03:D03:B09;F02<H03<J000cFP=L0e
`002=L02>N03?P04@P07AR05BT03DV03CV05EV06FX05FZ06GZ02H/000`00H/1R`006I/05I^0;J^06
K^05K`0AL`0GMb0;Nb0nOol00`00Oomoo`0NOol001aoo`03001oogoo05QooaEo@0]o809o@0mo80Eo
009o811o00Qnh0Qn`003O^1nX7jP00QnX09n@0EnH0Qn00A>`0U2P0Dj80@f00@a`0@aX0HYH0TU80<U
00@Y808U80L]H08aP0<aX08eX0<e`0<ih0<n009200M680E:@0IBH0EFH0IJP0]NX09R`003001R`6;0
00IV`0EVh0]Zh0I^h0E_015c01Mg80]k83ioo`03001oogoo01ioo`0077oo00<007ooOol0Egoo5Gm0
77lP5gl027kP2Gk02WjP17i00giP2Gh000=Bh4ZPBZ001DZP14:01CiP13XP23701RU01RD0124012D0
00<Ph2TP:B001BDP1BeP0S600c6P0SFP13W00cWP0ch01THP1TY01U9P1EIP1UZ02ejP0V;000<006;0
H/001VK01VKP2f[P1FkP1Vl04G<05WLP37/P?Goo00<007ooOol07Woo000LOol00`00Oomoo`1GOolD
Od0LOb0GO`08O^09O/02OX08OZ05OT03OV09OP04C/07BZ09?V07=N08:D038>039@037:028@000ac0
9@0U00038>069B03:B02:D02;F03<H03=J04>L02>N05@P03AR02BR04BT03DT03DV05EV06FX0;GZ03
HZ000`00HZ1RX005I/06I^0;J^05K^06K`0AL`0GMb0;Nb0nOol00`00Oomoo`0MOol001aoo`03001o
ogoo05IooaEo@1]o81Mo00Qnh0Un`0AnP0InX0In@0=nH0Un00M>`0=:X0E2P0@nH0@j00@eh0@]H0@Y
@0<P`0<Ph0DLX0<L`0LPh0<U80<Y808Y@0<]H08aP0@eX0<i`0<mh0E200E:809:@0IB@0EFH0IJP0]N
X0=RX003001RX6:P00IV`0EZ`0]Zh0E^h0I_015c01Mg80]k83ioo`03001oogoo01eoo`0077oo00<0
07ooOol0EWoo3Gm00WlP1Gm06glP5gl027kP2Gk01Gj01GjP27i000=nH7h0OP0027h00e;P1Tk02D:0
23X022eP1b302QAP0aRP1B3P12TP0RU00beP0S6013FP13W00cgP0T801dXP1e901EIP1UZ01Uj01EjP
0f:P00<006:PHZ001VK01F[01V[P2VkP1Vl04G<05gLP2g/P?Woo00<007ooOol07Goo000LOol00`00
Oomoo`1EOol=Od05Ob02Od0EOb03O`03Ob0@O`000gkPO`1o0004O`09O^08O/07OX03OZ09OT000giP
OP1n0007OP08D^09BZ09?T08<J078:074602260356000`aP6:0HX00368028>049>02:B03;F02<H04
=J04>L03?N08BR03CT04DT05EV06FX06GX08HZ000`00HZ1RX006I/05J/06J^0;K^0FL`0GMb0;Nb0n
Ool00`00Oomoo`0MOol001aoo`03001oogoo05Eoo`eo@1]o81Io00=nh0Ao00Unh0Qn`0UnP003OZ1n
@7i000Qn@0Yn0003F`1Bh5;P00ABh0E>h0E:X0A2P0Dn@0Peh0LT`0L<H0<0H088H0<<H0DHP0038>0T
h2CP008Th08Y80<]@0<aP0<eX0@i`08mh09600E:80M>@0IFH0=JH0=JP0INP0ERX0=VX003001RX6:P
00IV`0EZ`0IZh0]^h0]c00ag00]g81Ik83ioo`03001oogoo01eoo`006goo00<007ooOol0EGoo3Gm0
6glP5Wl01GkP0Wl02GkP27k02Wj02gi02Gh01U/02dkP2D:023GP22dP1a1P1P`00P1000<<H0Q02400
11R012CP0RTP0be013600SFP13W01DH00dXP0ThP1Di00eI00eIP1UYP1Uj01F:P0fJP00<006JPIZ00
1VK01F[01V[P2fkP2g<037L02gLP5W/P?Woo00<007ooOol07Goo000KOol00`00Oomoo`1EOol=Od0K
Ob0EO`0@O^08O/0:OX02OV09OT0:OP05F`06E`05C^09B/09?R08=H0868034603;803040324036803
7:03:B03;D04<H02=J05?N05AP05CR03CT05ET07FV06GX05HZ03IZ000`00IZ1VX006I/05J/06J^0;
K^0;L`0<M`0;Mb0FNb0nOol00`00Oomoo`0MOol001]oo`03001oogoo05Aoo`eo@1]o81Eo00Qnh09n
`0Inh0Qn`0YnP0AnH0Mn@0Yn00EO80]G00Y:`0U2P0PeP0Ti@0I5X09K00<0@004240<@0a068037:03
9>03;B04<F03>J05?N02AP03BP05CR06ET07FV05GX06HZ03IZ000`00IZ1VX006I/05J/06J^0;K^0;
L`0<M`0;Mb0FNb0nOol00`00Oomoo`0MOol001]oo`03001oogoo05=oo`io@1Yo81Eo00Qnh0An`0An
h0Un`0UnP0EnH0In@0]n00AO80IK80IG00UBh0Y2P0Pn80Y6@0MK00=cX080@0<<@0<LX0<Th0@]80<a
H0@iX0@mh0I:009>80=B@0AF@0MJH0ENP0IRP0=VX003001VX6JP00IV`0EZ`0I^`0]^h0]c00ag00]g
81Ik83ioo`03001oogoo01eoo`006goo00<007ooOol0Dgoo3Gm06glP57l027kP1Wk00WkP2Gk02Gj0
1giP17i02gh016<P35/P2U;P2DkP2DJP1DI01EL015/01g>P00=oh01002000Pa00aAP0bCP12dP0c5P
13VP14GP1TX01U900UI01UYP1Uj01V:00fJP00<006JPIZ001VK01F[01Vk01FkP1W;P2g<037L02gLP
5W/P?Woo00<007ooOol07Goo000KOol00`00Oomoo`1COol=Od0JOb0DO`08O^0AO/09OX08OV03OT0<
OP03Hb06Hd0@Fb09C^0:AZ0:E`08Lj06On02020010a0560DH1AP0b2P12dP0c5P1Cg00dGP14X00e8P
1E901eYP0eiP0ej01V:00fJP00<006JPIZ001VK01F[01Vk01FkP37;P1G<037L02gLP5W/P?Woo00<0
07ooOol07Goo000KOol00`00Oomoo`1BOol6Od03Ob04Od0JOb0EO`07O^0AO/09OX0:OV000gi0OP1n
000:OP03Id0<Hd0;Fb09Eb0?E`06If04Lj0;On000`0P560DH00256038:04;B03=F05?L03AN02BP05
DR04DT03FT03FV06GV07HX03IZ000`00IZ1VX005JZ06J/06K/05K^0<L^0AM`0;Mb0FNb0nOol00`00
Oomoo`0MOol001]oo`03001oogoo059oo`Io@25o81Ao00Mnh15n`0UnP0]nH0en00QW@0IS@0]O@0YG
80YG00]WH11oh0030208@0Q0008DH0<PX0@]80<eH0Dm`0=5h0MB809B@0IJ@0MNH0=VP0ARP0=VX003
001VX6JP00EZX0=^`0=Z`0I^`0E^h0abh15g00]g81Ik83ioo`03001oogoo01eoo`006goo00<007oo
Ool0DGoo1Wm08GlP57l01gkP4Gk02Gj02giP0WhP2gh00V]036M05Um02V=P1VMP1G>P4WoP0`Q0122P
12dP0cEP1Cg014h01U8P1eY01eiP1VJ016JP00<006JPJZ001FZP36k01FkP37;P4GL01G/077/P?Woo
00<007ooOol07Goo000KOol00`00Oomoo`1AOol6Od0POb0DO`08O^0@O/09OX0;OV03OR0;OP000f]0
Jf1[H005Jf06Id0;If0:Gd0;Hf0;Lj0COn0324037805;B03=F05AL05CP03DR03FR04FT08GV06IX03
JX000fJP001VX006JZ0;K/06K^0<L^0AM`05N`0ANb06Ob05Nb0oOol00`00Oomoo`0LOol001]oo`03
001oogoo051oo`Mo@1mo81Eo00Mnh11n`09nX0MnP0]nH0En80Un00i[H1IWH0][P0IcX0Ik`1=oh003
0208@0Q000<LP0@]00@iP0E5`0E>00MJ809J@0MNH0MVP0AZP003001ZX6ZP00EZX0]^`19bh15g00Ek
015k80]o83moo`03001oogoo01aoo`006goo00<007ooOol0D7oo1Wm087lP57l01gkP47k017jP1Gj0
2giP1WhP2Gh01fmP4V]P2fMP2f^037_057oP0P0P00@8@1b0780LP0@]00@iP0E5`0=>00=F00IJ80QN
H09VH0AVP0EZP004001^X6jPKZ04JZ0;K/06L^06M^06L^0AM`05N`0ANb0;Ob0oOol00`00Oomoo`0L
Ool001]oo`03001oogoo04moo`Mo@1mo80io00=nh0=o00Mnh11n`0InX0=nP0]nH0Mn80Qn00e_H0e[
H0]_P0]cX0Ik`1]oh003000081b000<LP0@]00@iP0E5`0IF00AJ80=N@0ENH0EVH09VP0EZP003001^
X6jP00A^X0a^`0Ibh0Ufh0=bh15g00Ek015k80]o83moo`03001oogoo01aoo`006Woo00<007ooOol0
D7oo1gm067lP0gl00glP3Wl03WkP3gk027jP2giP2WhP1Gh00g6036mP66n02g>P8WoP00@0000P760L
H08LP0@]00@iP0=5`0==h0EF009J80IN@09NH0MVH0IZP003001^X6jP00M^X0U^`0Ibh0]fh19g00Ek
015k80]o83moo`03001oogoo01aoo`006Woo00<007ooOol0Cgoo1gm06GlP57l03GkP3gk02GjP00=n
P7iPOV001giP0WY02GhP0gh01G6000<D86mPKf002FmP36n02g>P37O08goP00<0000P76000QaP12d0
1CV01TgP1EH025i026IP1VZ000<006jPKZ002FjP1fk01G;P37KP4WL01G/04G/P2glP?goo00<007oo
Ool077oo000JOol00`00Oomoo`1?Ool3Ob04Od0HOb0DO`0=O^0?O/09OZ03OX07OV04NT08OR08LH00
0a@PKf1_H008Kf0=Kh0;Lj0<Ml0TOn000`00020LH0027604<B05AJ06CN03EP03GR06GT07IV06JX00
0fjP001^X00:KZ06L/06L^0<M^06M`05N`06M`06N`0ANb0;Ob0oOol00`00Oomoo`0LOol001Yoo`03
001oogoo04mooamo81=o00enh11n`09jX0InX0EnP0EnH0Ej@0Mn809]`0MaP08D8003Lh1_H6mP00E_
H0ecP0acX0ao`2Eoh003000LH1aP008LH0@a80E5X0I=h0IN80AN@0MVH0MZP003KZ0006jP00Y^X0Ib
`0=f`0=bh0afh0Ig011k019k80]o83moo`03001oogoo01aoo`006Woo00<007ooOol0Cgoo7WlP57l0
3gkP3Gk017ZP17jP1gj00giP1gY017hP16g027600Q@P4g>03GNP37o09GoP0P0000<PH1aP76001C4P
1DFP0dgP0eX01UhP0Ui01fIP26Z000=^X000KZ002FjP1g;01GK037KP1gL047/01WlP37/P2glP?goo
00<007ooOol077oo000JOol00`00Oomoo`1>OolOOb0CO`0BO^0:O/06NZ02OZ09OX0:NT02OR06KL07
LH025206Lh0<Mh0=Mj0=Ol0VOn001@00860PH21P76001C4P1DFP1UX01UhP26IP0ViP1FZ00VjP00<0
06jPKZ000VjP0W:P16jP1W;01WK037KP1WL04G/037lP1W/P2glP?goo00<007ooOol077oo000JOol0
0`00Oomoo`1>OolOOb0BO`0EO^08O/07NZ09OX02MV09NT08KL07LH03520AMh0=Nj0=Ol0VOn020003
8605<B06DL06FP04GR03IT05IV05KV03JX02KZ001000KZ1^X6jP1G:P0VjP1W;01WK037KP1WL04G/0
7GlP?goo00<007ooOol077oo000JOol00`00Oomoo`1>OolNOb0CO`03N^0BO^02N/05O/08NZ000gJ0
OX1nP005OX04MV07NT02KP08KL06LH04520@Mh0=Nj0=Ol0VOn000a`P000PH0038605@D06DL06FP02
GR06IT02IV08KV03KZ001000KZ1^X6jP1W:P1W;01gK01WKP1G[P1gL04G/077lP@7oo00<007ooOol0
77oo000JOol00`00Oomoo`1>OolNOb0CO`06N^0>O^05N/02O/08NZ03MX05OX06MV04NT05KP07KL06
LH04520?Mh0>Nj0=Ol0VOn000a`P000000048605@D06DL05FP09IT09KV02LX0016jP001^X6jP1g:P
0gK00g;01WK01gKP27[P17L047/07GlP@7oo00<007ooOol077oo000JOol00`00Oomoo`1=OolNOb0C
O`0:N^0:O^07N/08NZ05MX03OX08MV02NT06KP08KL06LH04520>Mh0>Oj0=Ol0VOn0272000`00860P
H0028605@D07DL02FP04IR06IT09KV04LX000`00KZ1^X006LZ0=M/06M^0<N^0AN`0MOb10Ool00`00
Oomoo`0LOol001Yoo`03001oogoo04eooaio80Ik00eo00ajh0Qnh0Mj`09fX0EjX0MfP0YfH0U^00M]
`0IaP0@D80ekX0ioX2Ao`19gX0UcP091@0IA`0MV80AV@0U^H0EbP003001bP7:P00IbX0If`0=j`0Af
`0Ifh0ajh0Eo00ak01eo845oo`03001oogoo01]oo`006Woo00<007ooOol0CGoo7WlP2G/02Wl037[P
0WKP1GkP1g[01GJP0WZP27J00W9P1gIP0VY02Fh01Vg01W601A@P37^P37nP9Wo04WNP4W>01fHP0VI0
2FiP1W:000@007:0MZ1fX0AbX0If`0Mj`0Ifh0ejh0]o00Ik01eo845oo`03001oogoo01]oo`006Woo
00<007ooOol0CGoo7WlP2g/01gl03G[P17KP0WkP1g[01gJP27J0179P1GIP16Y026h01e600S2P0g60
1A@P37^P27nP1GoP97o04WNP6G>00VHP2FiP1g:000<007JPMZ000gJP0W:P1WK01g[00g[P0gKP37[P
4Gl07WlP@Goo00<007ooOol06goo000IOol00`00Oomoo`1=OolOOb0>N`04O`0<N^06M^08N/07MZ02
LZ05MX06LV03MV06JT06KP02GN06DH05<:05520;Nj04Oj0:On0BOl0BNl0BMj0OLh04KV03MV05LX00
0`00MZ1fX004MZ06M/07N/0CN^0AO`0MOb12Ool00`00Oomoo`0KOol001Uoo`03001oogoo04eooaio
819k00ejh0Ifh0=f`0Aj`0MfX0EbX09fP0QbH0UZ@0=^00EMh0IAP0D`X0@D80]kX0ioh19o`19k`15g
X2EcP0AfH09bP003MZ0007JP00EfX0=jX0=f`0Mj`0Ijh0=nh0Yjh15o01eo849oo`03001oogoo01]o
o`006Goo00<007ooOol0CGoo7WlP4W/00gL02W[P1WKP1WK01gJP1g:P2G9P00=ZH6Y0JT001fY01egP
1U601C2P11@P1WnP4goP4Wo04G_04GNP4g>01Vn03G>016mP00AfH7JPMZ0000EfX0IjX0Mj`0Ijh0In
h0Mjh15o01io849oo`03001oogoo01]oo`006Goo00<007ooOol0CGoo37lP1G/P3GlP4W/01GL01g[P
1WKP1gK00W;01GJP1g:P0Vj01W9P0fYP1fY00V801egP1U601C2P11@P0WnP5goP4Go04G_04GNP4W>0
3Fn01W>026mP00<007JPMZ000WJP1gZP0Wk01G[01W[P2GkP17[P4Gl07WlP@Woo00<007ooOol06goo
000IOol00`00Oomoo`1=Ool<Ob0;Nb07Ob0AN`06M`03M^04N^06M^07M/04L/02MZ07LZ04KX04LV05
JV05JT04HP06GN06DH05<:02520KOn09Ol08On0ANl0AMj0ALh0CKh09Kf001000Kf1_H6mP1gZP1Gk0
0W[01W[P3GkP4Wl07WlP@Woo00<007ooOol06goo000IOol00`00Oomoo`1=Ool<Ob0ANb0BN`06M`0<
M^07M/06L/07LZ06KX02LV07JV03JT05HP07GN06DH03<:0_On0ANl0@Mj0BLh06Kf0<Kh0:Kf000`00
Kf1_H004Kf03NZ07O/07N^0=O^0AO`0NOb13Ool00`00Oomoo`0KOol001Uoo`03001oogoo04eoo`ao
815k819k00Ig00Ifh0=bh0=fh0Mf`0Ib`09^X0EbX0M^P0UZH0QR00IMh0EAP3=oh15k`11cX0Q_P0Uc
P0a_H0I_P0]_H003001_H6mP00M_H0Yn`0=jh0enh19o01io84=oo`03001oogoo01]oo`006Goo00<0
07ooOol0CGoo37lP4G/P1G/00gL02G/01WL01gKP1G;P1gK01W;01FjP0W:P26j00VIP1VYP0f901f80
0egP0dVP=goP4G_047>P46n07VmP00<006mPKf002VmP2Gk03WkP4Wl07WlP@goo00<007ooOol06goo
000IOol00`00Oomoo`1=Ool<Ob0ANb05N`06M`06N`06M`07M^05L^03L/04M/06L/06KZ08KX04IV04
JV05HT06HP03BJ0jOn0@Nl0@Lj0AKh06Jf0<Kf04Jf08Kf000`00Kf1_H00=Kf06O/0=O^0BO`0NOb14
Ool00`00Oomoo`0KOol001Uoo`03001oogoo04eoo`ao815k80Ek019g00Ifh0Ibh0ab`0M^X09ZP0I^
P0EVH09ZH0MR@0=R009Eh3eoh11gX11cP11_P0a[H0I_H0U[H0A_H003001_H6mP011_H09n`0inh19o
01io84Aoo`03001oogoo01]oo`006Goo00<007ooOol0CGoo37lP4G/P1G/04WL01WKP1W;P1W;00fk0
0g;01fjP16Z00fj01fIP2F9000=Eh7oPOn00?WoP47NP3g>046n086]P00=_H000Kf004fmP37kP4Wl0
7WlPAGoo00<007ooOol06goo000IOol00`00Oomoo`1<Ool=Ob0ANb05N`0AM`07M^05L^07L/05K/07
KZ07JX08IV07HT13On0?Mj0?Lh0AKh0QJf000`00Jf1_H00EKf08O^0CO`0NOb16Ool00`00Oomoo`0J
Ool001Uoo`03001oogoo04eooaek80Ek015g00abh0Ib`0I^`0=ZX0A^X0MZP09VP0EVH0ER@4Ioh0mc
X0m_P0Q[H0Q_P29[H003001[H6]P009[H1E_H0Inh19o01io84Moo`03001oogoo01Yoo`0067oo00<0
07ooOol0CWoo7G/P1G/04GL037;P1W;01Vk01VZP1fZ01FJ00VIP0f90@GoP27o03g>P3fn0<V]P00<0
06]PJf001F]P56mP0gkP4gl07WlPAgoo00<007ooOol06Woo000HOol00`00Oomoo`1>OolANb05Mb06
Nb06N`0AM`0;L^07L/06K/06JZ02IZ05JX06IX02HT0kOn0@Ol0>Lj0?Kh0?Jf08If09Jf06If0=Jf00
0`00Jf1[H008Jf0CKf0CO`0NOb18Ool00`00Oomoo`0JOol001Qoo`03001oogoo04iooa5k80]g81Mg
00]bh0I^h0M^`0IZX0AVX09ZP0MVP3ioh0mo`0i_X0m[P2]WH0I[H09[@003001[@6]P00][H0E_H0A[
@0U_H15o01Qo80=o@0=o84Qoo`03001oogoo01Yoo`0067oo00<007ooOol0CWoo4G/P2gLP5gL02g;P
1VkP0f[016k01FZP1VJP1VJ0@7oP27o01g_03VnP3f^03VMP1F=02fMP16M03FMP16]000<006]0Jd00
0V]036]P26]02FmP3Wl067lP1Wm0BGoo00<007ooOol06Woo000HOol00`00Oomoo`1>OolANb0;Mb0;
M`06L`06M`0;L^06K^06J/06JZ06IZ03HX13On0?Nl0>Jh0LIf0;Hd05If08Id09If04Id000f]0001[
@006Jd08Jf0;Jd09Kf0;O`0IOb06Od19Ool00`00Oomoo`0JOol001Qoo`03001oogoo04iooa5k80]g
80]g00]c00abh0I^h0UZ`0=ZX0IVX003HX1oh7oP04Aoh0Yk`0Ag`0i[P0eWH1iS@0eW@0AWH0IW@003
001W@6]000Q[@0A[H0m[@0Q_H0Uo01Qo80Io@4Yoo`03001oogoo01Yoo`0067oo00<007ooOol0CWoo
4G/P2gLP2gL037<01FkP1W;P1VkP2f[01VJPB7oP1G_02GO03F^03FMP96=04VM000@006M0Id1W@1a[
@0A_H0A_@0Io01Qo80Mo@4Yoo`03001oogoo01Yoo`0067oo00<007ooOol0CWoo4G/P2gLP2gL037<0
26kP0g;P1VkP2f[00fJPBgoP3WO03FMP55m08F=03VM000<006M0Id0016M06f]026m00gl06GlP1Wm0
Bgoo00<007ooOol06Woo000HOol00`00Oomoo`1>OolANb0;Mb0;M`0<L`0AK^0;J/02IZ02Ol1:On07
Ml07Kj0=If0JGd0?Hd04Gd0<Hd0:Id000`00Id1W@006Id0KJd08Kd000gl0Ob1o800FOb06Od1<Ool0
0`00Oomoo`0JOol001Qoo`03001oogoo04mooa1k80]g80]g00ac00]^h0EZh0aZ`0Eo`4Uoh0i_X0aW
H1YO@0QO80MS@0QO@0aS@0MW@003001W@6M000QW@1][@0Q_@1Mo80Io@4aoo`03001oogoo01Yoo`00
67oo00<007ooOol0Cgoo1W/P5GLP2gL037<02fkP1F[P2V[027o0BGoP2FnP16=P35m03E/P35LP3elP
35m036=016M000<006M0Id002VM06f]026m057lP1Wm0CGoo00<007ooOol06Woo000HOol00`00Oomo
o`1?Ool6Nb0FMb05Lb05M`0<L`0;K^05J^06J/02I/0:Ol19On05Kj08Hf0<Gd0<Fb0CEb0=Gb0;Gd0<
Hd000fM0001W@00=Id0JJd09Kd0<Ob0<Od1=Ool00`00Oomoo`0JOol001Qoo`03001oogoo051oo`Ek
81Ig80Ic811c00]^h0EZh0IZ`003I/1o`7o000Yo`4Qoh0aSH2AC00iG80]O80IO@0AO80YS@003001S
@6M000iW@1Y[@0Q_@0Yo80ao@4moo`03001oogoo01Uoo`005goo00<007ooOol0DGoo1G/P5WLP1W<P
2g<01Fl02fkP1F[P1F[03go0@goP17?01V=P1UL0:U<01eLP1E/055lP1f=000@006<PHb1S80mW@1Y[
@0Q_@0Mo80ao@51oo`03001oogoo01Uoo`005goo00<007ooOol0DGoo1G/P5WLP1W<P2g<02Vl01VkP
1F[P0f[04Wo0?WoP27?035L034JP4D[04e<02U/04elP16=000<006<PHb000f<P3fM06F]026m01GlP
3Gm0D7oo00<007ooOol06Goo000GOol00`00Oomoo`1AOol6Nb0FMb05Lb0;L`0;K`0:J^000f[0Ol1o
`00COl0hOn09Ll05Hd06E`05AV0;AZ0GB/0=D`05E`09F`0BGb02Hb000`00Hb1S8005Hb0?Id0EJd0<
Kd03Ob0<Od1AOol00`00Oomoo`0IOol001Moo`03001oogoo059oo`Ek81Ig80Ic80Yc00]_00UZh1Qo
`3Qoh0Ac`0US@0]6H0/n80]2H0]:`0M>h0IC00UG00UK00iO80=S8003001S86<P00MS80mW@11[@11_
@003Ob1o@7m000Yo@59oo`03001oogoo01Uoo`005goo00<007ooOol0DWoo1G/P5WLP1W<P2g<02Vl0
26[P0gnP5go0=goP2F=014iP2cfP2chP2T9P2d:P3DkP3EL02E/02ElP1F<P00<006<PHb002F<P0fM0
16LP26M046]03fm037m0DWoo00<007ooOol06Goo000GOol00`00Oomoo`1BOol5Nb0FMb06Lb0;L`0;
K`05J^06Oj0GOl0gOn04Hd05CV04?@05?J05<<0;=H09>P06?V06@Z06AZ0<C^0;E`09F`09Gb02Hb00
0`00Hb1S800:Hb08Ib08Id0?Jd0@Kd09Od1COol00`00Oomoo`0IOol001Moo`03001oogoo059oo`Ek
81Ig80Ic80]c00]_00AZh0QoX1Mo`3Ioh0I>H0Lm00X``0XeP0Tj00`nH0a6X0a>h0QG00UK00UO8003
001S86<P00aS80QW80QW@0m[@0m_@0Mo@5Aoo`03001oogoo01Uoo`005goo00<007ooOol0Dgoo47LP
4G<P16l01W<02fl00V[P2gnP5go0<goP16L01Sd01P002B202Bd02SFP1CXP1SiP1T:01TJP1T[01TkP
15;P25L02E/01UlP00<005lPGb003V<P26LP1fM03f]03fm01Wm0E7oo00<007ooOol06Goo000GOol0
0`00Oomoo`1COol@Mb0ALb0@K`05J`000f[POj1oX00;Oj0GOl0`On04I`03A<0012B0000@00a02010
20QP22BP2Re02cXP2d:034[025;P25L02E/015lP00<005lPGb000UlP3V<P26LP0fM016/P3V]03fm0
17m0EGoo00<007ooOol06Goo000GOol00`00Oomoo`1DOol@Mb0@Lb0@K`04J`0@Oj0GOl0]On04I`03
A<0011bP6:0HX1RP0QR000<<@11P46000Q1P0PQP0P101`AP21b01BT01Be02CGP1ciP1D:01TJP1T[0
14k025;P15L03E/000=O8000Gb001ElP3V<P1fLP1f/P3f]03Vm00Wm0EWoo00<007ooOol06Goo000G
Ool00`00Oomoo`1DOol@Mb0ALb0@K`02J`0COj0FOl0ZOn04I`02A<000`009@0U00028>036:036804
460256022603360316086609:@09=N05>R07?V0;AZ08C/08D^0@F`000`00Gb1O8005Gb0?Hb07Ib07
Jb0>Jd0>Kd1GOol00`00Oomoo`0IOol001Moo`03001oogoo05Aooa5g811c811_01IoX1Eo`2Moh0EW
0094`0<Y80<U00DPh0<HP0<HX0@DH0<@H0<<H0LDH0PTh0XaX0Xj80M2P0I6X0A:`0M>`0ABh0EFh0aK
0004G`0005l0G`07Gb0;Hb0:Ib07Jb0>Jd0>Kd1FOol00`00Oomoo`0IOol001Moo`03001oogoo05Eo
oa1g811c80i_01UoX1Eo`2Qoh094`004000]P2e0;D03:B039@078>046:027<0256026:0346066808
8>05;F05<J05=P05>R04?V08@X09B/06C/09E^08F`03G`000`00G`1O0002G`06Gb08Hb0>Ib07Jb0>
Jd0=Kd1EOol00`00Oomoo`0IOol001Ioo`03001oogoo05Iooa5g811c80a_00=oP1QoX1Eo`2Ioh09f
`003000aP360008]P08]H0<Y@08Y808U80PPh0@L`0/HX0PPh0@Y@0D]H0Xf00PnH0A2P0A6X0U:`0IB
h0QFh0QK0003G`0005l000EO00IO80QS80eW80M[80A[@0=[80M[@0e_@5Eoo`03001oogoo01Qoo`00
5Woo00<007ooOol0Egoo47LP47<P2fl01Gn067nP5Go097oP0WK000<0036P<H000c600Rf00ReP0RU0
0RTP0RDP1BD0123P0Qc01AcP0ac00aRP1b3P22U02C701cXP1SiP2DJP14[014k01e;P1eKP1e/000<0
05l0G`001Ul01ElP26<P3VLP3F/P1f]03Fm0E7oo00<007ooOol067oo000FOol00`00Oomoo`1GOol@
Mb0@Lb05K`04J`08Oh0HOj0EOl0ROn02M/02=L03<J03<H02;H02;F02:D02:B029B059@039B028>05
7>028@037<078>07:D06<J04<L04=P07>R06@X08AZ08C/08D^06E^05F`000`00F`1O0007G`06H`07
Hb0>Ib0=Jb07Jd0=Kd1COol00`00Oomoo`0HOol001Ioo`03001oogoo05Moo`Yg815c80]_809[00]o
P1IoX1Io`21oh09f`0De`0<aX0<aP08]P08]H004:F0Y@2U0:D069@049B000b3P8@0Q00068@069@08
:D04;H06<J07=P04>R04?V06@X04AZ04BZ07C/08D^06E^03F`001000F`1K05/025l01F<026<P3FLP
3F/P1f]03Fm0DWoo00<007ooOol067oo000FOol00`00Oomoo`1HOol5Md0FLb0:Kb0>Oh0GOj0EOl0N
On02M/02=N05=L04<J02<H02;H02;F000bUP:D0Y@006:D059B048@079B039@07:D08;H06=N06=P08
?V06@X09BZ06C/07D^07E^000e/0001K0003F`08G`05H`08Hb0=Ib0=Jb07Jd0=Kd1AOol00`00Oomo
o`0HOol001Ioo`03001oogoo05Qoo`Ig@1Ec80U_811oP1MoX1Eo`1aoh09f`003>N0eh3GP008eh0<e
`0HaX003<H0]P2f0008]H003:F0Y@2U000PY@0XU808Y@0<U80HY@0T]P0@a`0Heh0Lj@0HnH0M6P0Q:
X0IB`0MBh0IFh003001K05/000AK00MO00IS00MS80eW80e[80M[@0e_@51oo`03001oogoo01Qoo`00
5Woo00<007ooOol0FGoo1GM05W<P1flP4gn05WnP5Go06WoP0WK00SX01SGP1370136P00@aP2f0;H0]
P0@]H003:F0Y@2U000LY@0<U80hY@0T]P0Pa`0Df80Pj@0I2H0I6P0A:X0A>`0IB`0IBh0AFh004F^00
05[PF^06F`06G`06H`04Hb0@Ib0=Jb07Jd0=Kd1?Ool00`00Oomoo`0HOol001Ioo`03001oogoo05Uo
o`Ig@1Ic80A_81IoP1IoX1Eo`1Qoh09f`0<j00Heh0<e`0<a`0@aX0<]P0@]H0DYH0XY@0LYH0<Y@0<]
H0@]P0Xa`0<f00Df80@j@0@nH0I2H0I6P0M>`0MB`0EBh0AJh004001Jh5[PF^06F`06G`06H`0DIb0=
Jb07Kb0=Kd1>Ool00`00Oomoo`0HOol001Ioo`03001oogoo05Yoo`Ig@1Ec80=_81QoP1IoX1Eo`1Eo
h09f`09oh0<j00Heh0He`0HaX08]P0@]H0LYH003;F0Y@2U000dYH0H]H0D]X0Da`0Lf00Df80PnH0I2
H0I:X0M>`0IB`0IFh09Jh003001Jh5[P00=Jh0IK00EO00MS01=W80e[80M_80a_@4ioo`03001oogoo
01Qoo`005Woo00<007ooOol0FWoo1WM05W<P77n05GnP5Go05goP00<n83X0>P000SX01CGP1CG0236P
1Bf01bUP0beP0bUP0beP1BUP1Rf02BfP1SGP1SH01CY023iP1TJ01DZP1dk01e;01EKP00=Jh000F^00
1E[P1U/036<04fLP3F/P1flP36m0CGoo00<007ooOol067oo000FOol00`00Oomoo`1KOol6Md0DLb04
Of0JOh0COj03Oh0DOl0FOn000chP>P0j0002>P06=N04=L09<J000c60;H0]P002;H0B;F0:;H04;J06
<L05=N06>R05>T04?V04@V05AX06BZ03C/0:D/05E^000`00F^1Jh005F^06G`0<H`0CIb0=Jb07Kb0<
Kd1<Ool00`00Oomoo`0HOol001Ioo`03001oogoo05]oo`Mg@0mc80=_80MoH1UoP15oX0EoP19o`09o
X1Eoh08j80@j00Deh0De`08a`0PaX004<H0]P2f0;H06;F02;H03;F02;H03;F0<;H0;<L06=P05>R05
>T07@V05AX06BZ0=D/05E^000`00F^1Jh005F^06G`0<H`0=Ib0CJb06Kb0=Kd1;Ool00`00Oomoo`0H
Ool001Ioo`03001oogoo05aoo`Ig@0]c80I_80YoH1IoP09oH0moX0MoP11o`0AoX1=oh0<j80Dj00@e
h0De`0Da`0HaX004<H0]P2f0;H05;F0C;H05<J05<L06=N06=P04>R06?T06@V05AX07CZ0<D/04E^00
0`00E^1Jh006F^06G`0<H`0=Ib0BJb07Kb0=Kd1:Ool00`00Oomoo`0HOol001Ioo`03001oogoo05ao
o`ac@0Ic80A_80aoH1AoP0AoH0eoX0UoP0io`0IoX19oh0Pj00Deh0Da`0XaX1T]P0D]X0DaX0Da`0He
h0Xj80Hn@0E2H0I:P0I>X0aB`0=Jh003001Jh5[P00MJh0IO00aS00IW00MW819[80M_80a_@4Yoo`03
001oogoo01Qoo`005Goo00<007ooOol0GWoo37=01G<P0flP3WmP4Gn01gmP2WnP37n037o01WnP0Wn0
47oP00<n83X0>P000SX02SGP1C70336P52f022fP2c701SH02SXP1Ci01TJ01TZ01DjP1U;01UK00U[P
00<005[PF^0025[P1Ul01V<036L01fLP4V/P1flP1Fm01g=0BWoo00<007ooOol05goo000EOol00`00
Oomoo`1OOol<Ld05Lb000flPOf1oH00?Of0>Oh09Of08Oj0>Oh0:Ol06Oj04Oh0?On02?R04>P0:=N05
<L0><J0C;H09<J04<L06=N05=P05>R06?T05@V06AX06BX04CZ07D/05E/000e[P001Jh00:F^06G`06
H`0<I`07Ib0BJb0<Kb07Ld19Ool00`00Oomoo`0GOol001Eoo`03001oogoo061oo`]c@0Ec81AoH0]o
P0aoH0EoX0moP0Uo`0IoX0IoP0ioh0<j80Dj00@eh0De`0@a`0TaX08]P08aX10]P0D]X0@aX0Xa`0De
h0Df00Hj80Dn@0E2H0I6P0]>X0IB`0EF`003001Jh5[P00YJh0IO00IS00aW00MW815[80e_80Ic@4Uo
o`03001oogoo01Moo`005Goo00<007ooOol0HGoo2g=00g<P5WmP27n03gmP0gnP3gn00WmP1go01WnP
1gn03GoP00<n@3XP>R000SXP1CX013GP1CG01370236P5Rf02C6P2C701CH01SX01CXP1Ci01D9P1TZ0
2djP1U;015K000<005[PF^001E[P1UkP1Ul01V<036L01fLP2f/P4VlP1g=0B7oo00<007ooOol05goo
000EOol00`00Oomoo`1ROol;Ld000g<POf1oH00GOf05Oh0AOf0@Oh04Of05Ol06Oj07Oh02Od0<On02
>R05>P04=P05=N09<L04<J04;J0A;H04;J05<J09<L05=N04=P06>P05>R05@T06AV05BX0;CZ06D/03
E/000`00E/1Jh006F^06G^06G`06H`0<I`06Ib0<Jb0BKb06Ld18Ool00`00Oomoo`0GOol001Eoo`03
001oogoo06=oo`Uc@1aoH0=oP1AoH0eoP0IoH0=o`0IoX0MoP0Ao@0Yoh0@j80Dj00@f00Ta`0TaX1D]
P0TaX0Ta`0Deh0@f00Hj80Dn@0E2@0I6H0E:P0]>X0IF`09J`003001J`5[000MJh0INh0IO00IS00aW
019[819_80Ic@4Moo`03001oogoo01Moo`005Goo00<007ooOol0I7oo1g=0=GmP2gn027mP1gnP1gn0
1Wm02GoP00<n@3XP>R000SXP1SH013GP23701S6P4bf03S6P1C7013G01CGP1CH01CXP1Ci01D901TIP
1DZ01DjP1U:P1UK000=J`000F/000U[01e[P1UkP1Ul01V<036L04F/P4VlP1g=0AWoo00<007ooOol0
5goo000EOol00`00Oomoo`1UOol5Ld0gOf09Oh08Of02Od05Oj07Oh07Od000gkPOn1oh006On03>T04
>R05=P04=N06<L04<J05;J0C;H000c60<J0aX00:<J05<L09=N05=P05>R05?T05@T06AV05BX05CZ06
DZ06E/000`00F/1J`002F/07F^06G^05G`06H`0<I`0BJb0BKb06Ld16Ool00`00Oomoo`0GOol001Eo
o`03001oogoo06Eoo`Ac@3MoH09o@0MoP0QoH0Ao@0=oX0MoP0Mo@0=nh0Ioh0Dj@0Dj80Deh0Ta`0D]
X1P]P003<H0aX36P00TaX0@a`0Xeh0Dj00Dn80E2@0]6H0E:P0E>X0IBX0EF`003001J`5[000=J`0IJ
h0INh0IRh19W019[819_80Ic@4Eoo`03001oogoo01Moo`005Goo00<007ooOol0IWoo0W=0=gmP17m0
1Gn027mP1Wm027n01gm01GkP1GoP0SiP13Y01SH01CGP1C70136P72f01S6P1C701CG01CGP1CH01CX0
1ChP1D902dIP1DZ01DjP1U:P15K000<005K0F/0015[035kP1V;P4FL04V/P4VlP1W=0AGoo00<007oo
Ool05goo000EOol00`00Oomoo`1WOolgOf06Od03Oh08Of07Od000glPOh1oP004Oh07Od06O^0017iP
On1oh7oP13iP1SXP1CH02S705Rf00beP1Rf000<aP36P<J000S6P1S701CG01CGP1CH01CX013hP1T90
2TIP1TZ01DjP1E:P15[000<005[0F/001E[035kP1F;P4VL04V/P36lP1W<P1W=0A7oo00<007ooOol0
5goo000EOol00`00Oomoo`1VOol?Of03Od0EOf03Od0=Of08Od09Of07Od03Ob04Oh07Od06O^03OV02
On06>T06>R05=N05<L05;J08;H04;F03;H04;F000bf0;F0]H004;F05;H000c60<J0aX003<J03<L05
=L06=N0:>P04?R06@T05AV05BV06CX05DZ05EZ03F/000`00F/1J`006F/0;G^06H^0AI`0BJb0=Kb05
Lb06Ld14Ool00`00Oomoo`0GOol001Eoo`03001oogoo06Eoo`moH0Eo@1=oH0Eo@0]oH0Yo@0MoH0Mo
@0Eo809oP0Mo@0Mnh0AnH0@nH0Dj@0Hf00Deh0T]X0H]P0XYH0@]H003:F0]H2eP00<]H0D]P003<H0a
X36P00DaX0He`0Deh0Dj00Xn80I2@0E6H0E:H0E>P0IBX0EFX09J`003001J`5[000MJ`0]Nh0ERh19W
00a[819_80Ic80Ic@4=oo`03001oogoo01Moo`0057oo00<007ooOol0IGoo3gmP1gm04GmP1gm02GmP
37m01GmP1gm01glP27m01WkP1GiP00=n03iP?V000ciP1SXP1CH01S7012fP1ReP1RUP0bU00bUP0RU0
0ReP12UP0beP1Rf01S6P1SG01CGP1CX01ShP1D8P1DI01DIP1TYP1Dj01U:P1EJP00=J`000F/002E[0
2ekP1F;P4FL01f/066lP1G<P1W=0@goo00<007ooOol05goo000DOol00`00Oomoo`1TOol?Of0:Od0>
Of0:Od06Of0>Od03Of07Od08Ob000gkPOd1o@004Od06O^06OV000gh0@X12P005>T07>R0:<L07;F03
:D03:F0;:D07:F03;F05;H03<J03<L04=L05=N06>P05?R06@R05AT05BV0:CX06DZ05EZ000e[0001J
`009F/0;G^05H^07I`0AJ`0HKb05Lb06Ld13Ool00`00Oomoo`0GOol001Aoo`03001oogoo06=oo`mo
H0eo@0]oH0eo@0=oH1Qo@0Qo80=nh0Ao@0Mnh0EnH09n0004@X0nH3iP?V05>T04>R04=N05<L05;H03
;F0>:D039B04:D05:F04;F05;H03<J03<L02=L06=N05>P06?R05@R05AT05BV06CX05DX0;EZ000`00
F/1J`003F/06G/05G^06H^05I^06I`0BJ`0GKb06Lb06Ld13Ool00`00Oomoo`0FOol001Aoo`03001o
ogoo06=oo`9o@0aoH0mo@0UoH21o@09o80Io@0Qo80Anh0=o@0Mnh0InH09n00HnH0Dj@0Peh0X]P0HY
@0lU80LY@0@]H08]P0@aP0<aX08a`0Leh0<ih08j00<n00<n80I280A6@0I:H0E>P0EBP0]FX003001J
`5[000=J`0IN`0ENh0IRh0EVh0MW015[01Q_80Ec80Ic@4=oo`03001oogoo01Ioo`0057oo00<007oo
Ool0HWoo1Gm02GmP4Wm01WmP3gm00WlP3gm017lP17m027lP1WkP00=o@7kPO^001WkP1GiP0gh00d:0
1CiP1SH013GP136P1Bf01bU00b400bDP0R400RDP0b401BDP22U00bUP00<]H2f0<H000c600c6P0cG0
13GP1CWP1Sh01T8P1DI01DYP1Tj01E:02UJP00<005[0F/000e[01Uk01UkP1V;P1FKP1VL04F/066lP
1W<P1W=0@Woo00<007ooOol05Woo000DOol00`00Oomoo`1QOol7Od07Of0EOd03Of0?Od04Ob0=Od06
Ob02Od08Ob0?O^06OV03OP06@X06>T05=P08<J08:D0?8@000b3P9B0U80029B029@06:D03:F02;F00
1Bf0<H0aP360<J001cG01SWP1Sh01T8P1DI01TYP1DiP1E:02UJP00<005JPF/0015[01Uk01EkP1V;P
1FKP1VL04V/066lP1G<P1W=0@Woo00<007ooOol05Woo000DOol00`00Oomoo`1QOol:Od03Of0WOd06
Ob0;Od0@Ob08O^000gjPO^1nh004O^06OV04OP000dJP@X12P002@X05?V05>T08<L09:D078>097<03
8>039B059@000bDP:D0Y@003:F02;F000bf0<H0aP002<H000c6P=L0e`003=L06>N06?P06@R05AT06
BV06CV05DX09EZ000`00EZ1J`004F/06G/06G^06H^05I^06I`0AJ`0HKb05Lb06Ld12Ool00`00Oomo
o`0FOol001Aoo`03001oogoo061oocAo@0Qo80Uo@0Qo809nh0Io80Qnh0=nX0Enh0InH0An00=6X0Xn
H0Hf00@a`0@]H0@Y@0LP`0@HP08L`08HP08L`08HX0@Ph0HU00049B0Y82TP:B02:D03;F0012f0<H0a
P3600S6P0SG01cWP1Sh01T8P1TI00TiP0dYP1TiP1E:01UJP0eZP00<005ZPFZ002Uk01UkP1V;P1FKP
1VL04F/066lP37<P@Goo00<007ooOol05Woo000DOol00`00Oomoo`1OOoldOd0;Ob06Od08Ob04O^04
Ob08O^04OZ04O^07OV05OP06@X05?V05>R05=P08;F078<04560768046:058>039@029B03:B02:D03
;F02;H02<H02<J04=L04>N06?P06@R06AT0;CV06DX05EZ03FZ000`00FZ1JX00;G/06H^0:I^06I`0=
J`05K`0<Kb0GLb11Ool00`00Oomoo`0FOol001Aoo`03001oogoo05ioocAo@0io80=o@0Qo80Inh09o
80Qnh0InX0=nh0InH0In00=6X0M2P0Tj80TaX0PTh0LDH0L@H0DHX0LPh0<Y808Y@0<]H08]P08aP0Pe
`0@mh0<n00I280I:@0I>H0EBH0IBP0EFX0=JX003001JX5ZP00]N`0IRh0]Vh19[00E_00a_81Mc845o
o`03001oogoo01Ioo`0057oo00<007ooOol0GWoo:gm00glP1Gm06GlP47kP27jP00=nh7iPOV001GiP
1Wh01dJP1ciP1CXP23GP22T021AP0`QP0Q1P0`QP00<@H1RP6:000QRP0QR01B3P0bD00RTP0be00bf0
0S6P1SG00SWP13gP1d8P1TY00di00diP1E9P1UJ01EJP0eZP00<005ZPFZ002ek01V;P2fKP4V/01Fl0
36lP67<P@7oo00<007ooOol05Woo000DOol00`00Oomoo`1MOol[Od06Ob02Od0@Ob02O`07Ob08O^02
O/07O^08OZ07OV07OP000dk0AZ16X003AZ06@X06?V09=N07;D08680606052603360368036:028>03
9@03:B02;D03;H03<J03=L05>N02?N02@P05@R03BR03BT06CT05DV06EX05FX03FZ000`00FZ1JX00<
G/06H^0:I^0BJ`06K`0;Kb0HLb10Ool00`00Oomoo`0FOol001Aoo`03001oogoo05aoob]o@1Qo80Ao
00Eo80Qnh0An`0Enh0UnX003OT1nH7iP00AnH0Mn00E>`0]2P0Xj80P]@0PPP0L4H0L0@004360<@0a0
68036:027:039@03:B02;D03;H03<J04=L04>N05@P03@R06BR06CT05DV06EX06FX02GZ001000GZ1N
X5jP2ek01V;P2fKP4V/01Fl036lP5g<P@7oo00<007ooOol05Woo000COol00`00Oomoo`1LOolMOd02
Ob0<Od0HOb06O`03Ob08O^06O/03O^09OZ02OT05OV08OP04C/06B/05@X09?V0:=J08880936024005
040334036:037:028>03:B02;D03;H04=J04=L02>N02?P05@P07BR06CT05DV06EX06FX02GZ001000
GZ1NX5jP1Uk01F;01V;P2fKP4V/01Fl036lP67<P?goo00<007ooOol05Woo000COol00`00Oomoo`1L
OolLOd05Ob09Od0HOb08O`09O^08O/000gkPOZ1nX007OZ03OT05OV08OP03D^0;B/0:?V09>P09;>0:
;:04>>000cP00400@002040010a0440@@1100abP0R3P0bD00be00c6013FP0cG01Ch00d800dHP14XP
1Di01U9P1UJ01UZ00UjP00@005jPGZ1NX0IN`0ER`0IV`0]Vh19[00I_00]_81Qc83moo`03001oogoo
01Ioo`004goo00<007ooOol0Fgoo77m01glP1gm067lP27l02GkP2Gk02GjP1Gi017iP27h00U;P2dkP
2TJP2SX02CF02Sf01DiP0VM010100a100aAP0R3P0bD00be013600cFP13gP1Ch01dHP1Ti01U9P1UJ0
1UZ00UjP00@005jPGZ1NX0IN`0ER`0IV`0IVh0]Zh0a[00I_00]_81Qc83moo`03001oogoo01Ioo`00
4goo00<007ooOol0Fgoo6gm02glP0gm047lP0gl01GlP27l02GkP2Gk00Wj01gjP1Wi00giP2Gh000=G
04kPC^003dkP1DJP2T9P2ChP2dIP26M000@080100400@08@@0<DH08LX0<U00<]@0@aP0@e`0@mh08n
00=600E680I>@0IBH0IFP0IJP09NX004001NX5jPGZ06G/05H/06I/06I^0<J^0AK`0;Kb0HLb10Ool0
0`00Oomoo`0EOol001=oo`03001oogoo05Yooa]o@1io80Eo00=o80Qo00Unh0Un`0AnP0InX0In@0=n
H0Un00]G00]>h0Y2H0Y6X0I6H0EK00AW@0Eg`003On00800P0080@0@DH08LX0<U00<]@0@aP0o00<007ooOol0CWoo0`00
>goo3UlP25/P1e/01eL02U<01E;P2dk01T[02D:01GoP23i01SXP2cWP2S4P2cE01SD0147000<P0010
040010100Pa00a1P0QB00QRP0Qc00R3P0RD00RDP0bTP1beP1S6P1S701SGP1CX01cXP1ChP1D901TIP
1TJ01TZ02djP1e;01UK01eKP35[P1U/03El000<005l0G`000el01V<01V<PBGoo00<007ooOol01Goo
0002Ool00`00Oomoo`1:Ool4000oOol?Gb08Fb08F`07E`09D`07C^0;C/08A/04@X03On07@X07?T0;
>N0;=J0;=D06@L06BX000f]P0400@00304000`A0340@H002460256026:027<028>039@000bDP:D0Y
@002:D05;F06<J07<L05=N06>P06>R06?R05@T06AV06AX05BX0<CZ07D/06E/06E^0<F^07F`0=G`00
0`00G`1O0002G`06H`07Hb18Ool00`00Oomoo`05Ool0009oo`03001oogoo04Moo`<004Ioo`iO80QK
80UK00MG00UC00Q>h0I>`0E:`0U6`09oh0a2P0`n80`n00/mh0I:P0MG00=[H0<0@084@0<@H0<DH08H
P0037<0Ph23P00@U00DY@0<]H0HaX0La`0Deh0Lj00Hj80Dn@0I2@0E6H0I6P0I:P0a>X0IB`0IF`0MF
h0aJh0IK00iO0003001O05l0009O00IS00IS84Qoo`03001oogoo00Eoo`000Woo00<007ooOol0@goo
1000Bgoo3UlP2E/P25/025L02E<02DkP2d[01DK01dJP1T:0349P33h0349P3EL01G>P00@/00101404
@0<8@0<DH08HP08L`08Ph0<U00HY@0@]P0<aX0La`0Heh0Hj00Hj80Hn@0E2H0I6H0I6P0E:P0a>X0MB
`0IF`0IFh0aJh0MK00iO0004001O05l0G`06H`07Hb17Ool00`00Oomoo`05Ool0009oo`03001oogoo
041oo`<0055oo`iO80UK80UK00QG00UC00Y>h0Y:`0i6X1U2H0a>`0MG00IO@0AcX0=g`0030200@0A0
00<8@0<@@08HP0<L`08Ph08U00<Y@0@]H0D]P0La`0Heh0Hj00<n80<j80Hn@0I2H0E6H0I6P0I:P0a>
X0IB`0IF`0MFh0aJh0IK00mO0004001O05l0G`06H`06Hb17Ool00`00Oomoo`05Ool00003Ool007oo
03ioo`@005Moo`mO80QK80QK00UG00UC00]>h1=:`1Y6X0a>`0eO@0Qg`003Nn00@01000<8@0<@@08H
P0<L`08Ph08U00P]H0<]P08aX0@a`0Leh0Hj00Hn80Hn@0I2H0I6H0I:P15>X0MB`0IF`0IFh0aJh0MK
00mO0003001O05l000IS00MS84Ioo`03001oogoo00Eoo`0000=oo`00Ool0>goo0`00GGoo45lP1e/P
15/01e/P1eL03E<024kP3T[03DkP3DJP3EL01em01fN017O01W_P00@080100400@0<@@08HP0<L`0<U
008Y80P]H0DaX08a`0Leh0Hj00Hn80I2@0I2H0I6H0I:P0I>X0IBX0IB`0aF`0IFh0aJh0MK011O0003
001O06<000ES00MS84Ioo`03001oogoo00Eoo`0000=oo`00Ool0=goo1000HWoo4ElP4e/P1UL045<0
:TkP3EL03VN027_P17oP00@08010040<@08@@08HP0<L`0<U00<Y80@]H0TaX0Leh0Hj00Hn80M2@0]6
H0M:P0E>X0IBX0IB`0eF`0aJh0INh0eO00YS0003001S06<P00ES80MW84Eoo`03001oogoo00Eoo`00
00=oo`00Ool0=7oo0`00JGoo4ElP55/P2EL045<01dkP3U<03DkP3U]01fN01f^017_P2GoP0P0P00<0
@0a034000aR00ac00bD012TP13601S6P0cG01CGP0Sh013X01ShP1d901TIP1DYP1dZ01TjP1E:P1U;0
3EK035[P1UkP3El02f<000<006<PHb0016<P1fLPAGoo00<007ooOol01Goo00000goo001oo`0`Ool4
001_OolBGb0EFb0;E`0ND`0=E`0>Fd0>Jh0?On020203340258037<039@05;D03<H04<J06=L03=N04
?P02>P06?R04AT03@T06AV06BV06CX06CZ06DZ06D/0<E/0<F^07G^0<G`0<H`000`00Hb1S8003Hb07
Ib15Ool00`00Oomoo`05Ool00003Ool007oo02eoo`<007Iooa9O81IK80IG00QG80MC00mG80iG00iS
H0M[P0Q_X0moh08080<<@0<DP0<P`0<Y00@]@0@aP08aX0Pe`0Ln00Hn80M6@0I6H0I:H0I>P0aBX0IB
`0eF`0]Jh0MNh0aO00eS0003001S86<P00=S80IW84Eoo`03001oogoo00Eoo`0000=oo`00Ool0:Goo
1000O7oo4elP5U/P85LP3U/P3V=P3fnP47oP0P0P0`Q00aB00b300bT012e0136023G023h00d8P0chP
1dI034YP1Tj01U:P1UJP1U;03EK035[P1UkP3El036<000=S8000Hb000f<P1VLPAWoo00<007ooOol0
17oo00000goo001oo`0VOol30022OolDGb0KFb08Eb0MFb0?If08Kj07Lj0AOn020203240366038<03
:@04;D05<J05=L09?P06@R07AT06BV03CV03BV06CX06DZ07EZ0BE/0<F^07G^0<G`0<H`000f<P001S
8003Hb07Ib15Ool00`00Oomoo`04Ool00003Ool007oo029oo`@008Uoo`mO80IO@2aK80mO@0mWH0mc
X19oh08080<8@0<HH0<Th0<Y00DaP0DaX08e`0<mh0Hn00M280M6@0I:H0I>H0I>P0IBX0MFX0IF`0IJ
`19Jh0MNh0aO00eS0003Hb0006<P00=S80IW84Eoo`03001oogoo00Aoo`0000=oo`00Ool07goo0`00
TGoo2UlP35m01U/P2Em025/P7Um046^01g>P2GO04WoP00D0000P1404@0Q000<HH0@Th0<]@0@aP0Da
X0Hmh0<n00Q280I6@0M:H0I>H0IBP0IBX0MFX0IF`0IJ`0IJh1=Nh0aO00eS009S8004001S86<PHb06
Ib15Ool00`00Oomoo`04Ool00003Ool007oo01]oo`@009Qoo`EO83=O@0mSH0m[P15g`1=oh0030000
80A00084@0<HH0@Th0<]@0DaP08aX0<i`0Hmh0Q280M6@0=>H0A:H0I>H0IBP0=FX0=BX0MFX0IF`0IJ
`0IJh0eNh1mS00=S8003001S86<P00IW84Eoo`03001oogoo00Aoo`0000=oo`00Ool067oo0`00Wgoo
95m046=046=P3f^04GO057oP00<0000P14000PA00Qb000<HH2CP9>000RCP12e013601CW01CgP0T80
1T8P0TY01DI03DiP1U:03EJP1UK01U[01U[P3EkP4f<036L016LP00<006LPIb001FLPAGoo00<007oo
Ool017oo00000goo001oo`0DOol4002XOolMGd0AHd0@If0?Jh0AMl0BOn03Ool00`001404@0021403
78049>04;D05=J05>L02?N05@P03@R05BT03AT06CV04DV03CV06DX06EZ07FZ06E/06F/06F^0=G^0C
H`0<I`05Ib000`00Ib1W8005Ib14Ool00`00Oomoo`04Ool00003001oogoo015oo`<00;5oo`IO@0US
@0UO@11SH11WH11_P15g`0eoh0Uoo`03000880A00084@0<LP0@Y00DaH0@eX0Di`0Q200Q:@0M>H0MB
H0IBP0IFX0MJX0aJ`0IJh0eNh1=S00aW00IW8003001W86LP00AW84Aoo`03001oogoo00Aoo`0000<0
07ooOol03Goo1000^7oo00<006=0Hd0046=04F=P46MP46n04WO01WoP47oo00<000PP22000PA00ab0
12T01C5P13FP0cW00d7P1T800TXP1TY00di014iP1e9P1UJ01UJP1eZP1U[01Uk01U[P3EkP4f<036L0
1fLP00<006LPIb000fLPA7oo00<007ooOol017oo00000`00Oomoo`0:Ool3002lOol00`00Oomoo`04
Ool<Hd08If09Hf0@If0@Kh0BMl0GOol01000220880PP11b012T01C5P13FP1d7P0d801DXP0dY01di0
1e9P1eJ00eZP0eJP1eZP1U[01Uk04ekP4f<036L026LP00<006LPIb000VLPA7oo00<007ooOol017oo
00000`00Oomoo`06Ool4002oOol00`00Oomoo`09Ool6Hd0RIf0@Kj09Ml0QOol01000220880PP0RBP
0Qb012T01C5P1D701d7P24XP24i00eIP159P1eJ03EZP1U[01Uk01UkP1f;P1UkP4f<036L02FLP00@0
06LPIb1W84Aoo`03001oogoo00Aoo`0000<007ooOol00goo0`00`goo00<007ooOol03Woo4VMP4F^0
46nP:Woo00<000PP22000PPP0bBP1BT01CV01D701D7P0dX01TXP0U901Di01eIP1eJ01eZP0ejP15ZP
1U[01Uk01UkP3F;P1VL03F<036L02VLP00<006LPIb00A7oo00<007ooOol017oo00000`00Ool00003
0036Ool00`00Oomoo`0OOolAJh0lOol01000520880PP12BP1C501CV01T700T7P1DX014XP1E900di0
1eIP0eZ015J01eZP1UjP1e[01Uk01UkP3F;P36L01f<036L02fLP00<006LPOol0@goo00<007ooOol0
17oo0002003:Ool00`00Oomoo`1/Ool3520222049:05<D05>H06@L07BP02BR08DT08EV06FX07FZ07
GZ0=G/06G^0=H^0OI`0<Ib000`00Oomoo`12Ool00`00Oomoo`04Ool00003Ool007oo0<Uoo`03001o
ogoo06aoo`03520001@P008D8003220TX2BP008TX0Da@0DiP0=1`0Y:00UB@0MFH0MJP0=NX0AJX0MN
X0IN`0MR`0INh0eRh1UW00e[80IW8003001oogoo049oo`03001oogoo00=oo`000Woo0P00b7oo00<0
07ooOol0K7oo1Q@P1BBP1C501CV02dX00eI01U9025IP1eZ03UjP1Uk01f;00f;P0ekP3F;P6FL04f/P
00=oo`00Ool0@Woo00<007ooOol00goo0004Ool00`00Oomoo`35Ool00`00Oomoo`1]Ool65204<>05
<D07BL08BP06ET03DT08EV07FX07GZ04HZ04GZ06G/07H/0CH^0II`0CJb02Ool00`00Oomoo`10Ool0
0`00Oomoo`03Ool000Eoo`03001oogoo0<Aoo`03001oogoo06eoo`LD80@`h0E1P0M9`0I:00UF@0UF
H0=NP0AJP0MNX0MRX0MN`0MR`0IRh0IVh0MRh1UW01=[80=oo`03001oogoo03moo`03001oogoo00=o
o`001Woo00<007ooOol0`goo00<007ooOol0KGoo0Q@P00<002b052000Q@P1C3P1D601dW00dX015HP
1UI00eYP1UIP1ej01ejP26:P0fK015k01V;01f;P1VKP86L04f/P17oo00<007ooOol0?Woo00<007oo
Ool00goo0007Ool20033Ool00`00Oomoo`1]Ool35203;8025205<>05@H07BL07ER04ET06FV03EV08
GX02HZ05GZ07HZ07I/07H/07H^06I^06I`06J`0DI`0BJb06Ool00`00Oomoo`0mOol00`00Oomoo`03
Ool000Uoo`03001oogoo0<1oo`03001oogoo06eoo`<D8003000/P2b0008/P003520`h33P00<`h0E1
P0A9`0=F00MF809F@0UJH0QNP0ERX0=NX0MRX0YV`0AR`0IRh0MVh0IW00e[00eW019[80Moo`03001o
ogoo03aoo`03001oogoo00=oo`002Woo00<007ooOol0_goo00<007ooOol0KGoo11@P1Bb01S3P1D60
1eH01eHP2EYP0f9P1Uj03V:P3VK01f;P1VKP1fL04f/01fL04V/P27oo00<007ooOol0>goo00<007oo
Ool00goo000;Ool2002oOol00`00Oomoo`1^Ool35206;805CF06EL07EP05ER03GT06FV06HV03GX08
HZ03IZ04HZ0>I/03J^04H^06I^06I`0DJ`0IJb09Ool00`00Oomoo`0jOol00`00Oomoo`03Ool000eo
o`03001oogoo0;aoo`03001oogoo06ioo`@D80D/P0I=H0IE`0MF00=F80IN@0=JH0URH0QRX0MVX0mV
`0IZh0MVh0IW01A[00I[80I_80e[80Yoo`03001oogoo03Uoo`03001oogoo00=oo`003Woo00<007oo
Ool0^goo00<007ooOol0KWoo11@P1Rb01TeP1UG01eH02Ui02F9P0fJ01F:P26JP0V[036K03F[P1fL0
4f/01f/P36lP1V/P37oo00<007ooOol0>7oo00<007ooOol00goo000?Ool00`00Oomoo`2jOol00`00
Oomoo`1^Ool55205;806CF07EL05EP03HR07GT03IV06HV06IX02HZ08IZ05J/0:I/0=J^03K`04I`0C
J`06Jb0CKb0=Ool00`00Oomoo`0gOol00`00Oomoo`03Ool0011oo`800;Yoo`03001oogoo06ioo`DD
80H/P0I=H0ME`09F00IR80EN@0EVH0ARH0QVP0QVX0QZ`0MV`0eZh0M_01A[00I[81=_80ioo`03001o
ogoo03Ioo`03001oogoo00=oo`004Woo00<007ooOol0]goo00<007ooOol0KWoo1A@P1Rb01TeP1eG0
2F8P0ei01fIP0V9P2FJ00VjP1VJP26[00fk016K03F[P3Fl03F/01f/P4flP3Woo00<007ooOol0=Woo
00<007ooOol00goo000COol00`00Oomoo`2fOol00`00Oomoo`1^Ool65202KF04;806CF03EL04IP09
HR0:IV09IX05KZ03IZ08J/07K/0=J^0DK`07J`06Jb0CKb0@Ool00`00Oomoo`0fOol00`00Oomoo`02
Ool001Aoo`03001oogoo0;Eoo`03001oogoo06moo`DD80A]H08/P0I=H0QV00MR809^@0QVH0=^P0IV
P0Q^X0QZ`0Q^`0=^h0YZh1A_00=_80A[00I[81=_815oo`03001oogoo03Eoo`03001oogoo009oo`00
5Goo0P00]Goo00<007ooOol0L7oo11@P1VeP1fW026H01F8P16i01VIP1Fj01FJ026jP0Vk01V[01fk0
1VkP1f[P5Fl01VlP1f/P4flP4Woo00<007ooOol0=7oo00<007ooOol00Woo000GOol00`00Oomoo`2b
Ool00`00Oomoo`1`Ool45207KF07JL08IP03HR06KT04IV08KX02IX08KZ05K/03J/07K/07K^03L^04
J^0DK`07Kb06Lb0CKb0DOol00`00Oomoo`0cOol00`00Oomoo`02Ool001Qoo`03001oogoo0;5oo`03
001oogoo075oo`@D80I]H0MY`0UV00U^@09VH0Y^P0Q^X0m^`0M^h0Mbh1E_00I_80ec80e_81Eoo`03
001oogoo039oo`03001oogoo009oo`006Goo00<007ooOol0/7oo00<007ooOol0LWoo0a@P1VeP26W0
1fH00WI02Fi02Vj00g:P1FjP2Fk00g;P0fk026kP1g;P1W<03Vl01flP4g<P1flP5Woo00<007ooOol0
<Goo00<007ooOol00Woo000JOol2002`Ool00`00Oomoo`1bOol35207KF07JL05IP05MT07KT03MX07
KX06LZ02KZ09K/06L^08K^07L^0:L`0;K`06Kb0DLb06Ld0HOol00`00Oomoo`0`Ool00`00Oomoo`02
Ool001aoo`03001oogoo0:eoo`03001oogoo07=oo`8D80M]H0QY`09V00Qf@0A^@0IfP0E^P0QbX0U^
`0Mbh09fh0I^h0Mbh0ec00M_00M_81=c80Mc@1Uoo`03001oogoo02moo`03001oogoo009oo`007Goo
00<007ooOol0[7oo00<007ooOol0Lgoo0Q@P1feP26W02gI00Vi027J00fj027:P0gK01Vk01g;P1GKP
0fkP1g;P3W<00g<P16l01VlP57<P1W=06goo00<007ooOol0;Woo00<007ooOol00Woo000NOol00`00
Oomoo`2[Ool00`00Oomoo`1dOol25207KF05JL03OP0:MT0;MX09LZ06M/03K/07L^08M^08L^0=L`07
Lb07Kb0CLb07Ld0LOol00`00Oomoo`0]Ool00`00Oomoo`02Ool001moo`800:]oo`03001oogoo07Eo
o`03521]H6eP00E]H0=Y`0In00Qf@09nH0UfP0=nX0IbX0Uf`0Qbh0Qfh0=g00Abh0ic00Mc80Ig81Ac
80Ic@1ioo`03001oogoo02aoo`03001oogoo009oo`008Goo00<007ooOol0Z7oo00<007ooOol0MGoo
00<D86ePKF001FeP2Wh01WI017iP1gJ01GjP17:P2GK00g[P1G;P27KP1gL03W<01g<P2WLP47<P1g=0
7goo00<007ooOol0:goo00<007ooOol00Woo000ROol00`00Oomoo`2WOol00`00Oomoo`1fOol4KF0>
OP04MT06OV05MX07OZ02LZ09M/06N^02L^08M^08M`03N`0:L`08Lb0=Mb0=Lb06Ld0QOol00`00Oomo
o`0ZOol00`00Oomoo`02Ool002=oo`800:Moo`03001oogoo07Iooa=n009f@0QnH0=fP0UnX0Uf`0Qj
h0Qfh0Qg00Ik00Qc00Mc81Ag80Ic80Mc@29oo`03001oogoo02Uoo`03001oogoo009oo`009Goo00<0
07ooOol0Y7oo00<007ooOol0MWoo4gh02giP2WjP0gk01WK027[P0gkP1GKP27L01g/00g/P17<01g<P
5GLP0gM00g<P1W=097oo00<007ooOol0:Goo00<007ooOol00Goo000VOol00`00Oomoo`2SOol00`00
Oomoo`1fOolBOP0;OV0:OZ06O/03M/08N^06O^02M^08M`07N`07Nb08Lb0DMb06Md07Ld0UOol00`00
Oomoo`0XOol00`00Oomoo`01Ool002Moo`03001oogoo0:9oo`03001oogoo07Eooa5n00anH0YnX0Qn
`0Ujh0Qnh0Qg00Mk00]k80Ac81Ag80eg@2Moo`03001oogoo02Moo`03001oogoo005oo`00:7oo0P00
XGoo00<007ooOol0MWoo47h037iP2WjP27k00gkP1W[P2GkP0gl017L01g/03g/P57LP3WM0:7oo00<0
07ooOol09Woo00<007ooOol00Goo000ZOol00`00Oomoo`2NOol00`00Oomoo`1eOol?OP0=OV0:OZ08
O/06O^03N^09O^07O`08N`0BNb0AMb0=Md0ZOol00`00Oomoo`0UOol00`00Oomoo`01Ool002]oo`03
001oogoo09eoo`03001oogoo07Eoo`en00inH0YnX0Qn`19nh0Yo00Ek01Ek80ig80ig@2]oo`03001o
ogoo02Aoo`03001oogoo005oo`00;7oo00<007ooOol0W7oo00<007ooOol0MGoo3Gh000=n@7iPOV00
2GiP2gjP27k027kP0gl01gkP3Gl00W/05W/P0g]02WLP3WM0;Goo00<007ooOol08goo00<007ooOol0
0Goo000]Ool2002LOol00`00Oomoo`1dOol=OP03OT09OV0;OZ08O/08O^05O`05O^0?O`0FNb07Nd06
Mb0>Md0_Ool00`00Oomoo`0ROol00`00Oomoo`01Ool002moo`03001oogoo09Uoo`03001oogoo07Ao
o`an00An@0QnH0YnX0Un`0Qnh0Qo009nh0mo00Ao819k80ek@0mg@31oo`03001oogoo025oo`03001o
ogoo005oo`00<7oo00<007ooOol0V7oo00<007ooOol0Lgoo37h01Wi01GiP2gjP2Gk027kP6Gl01glP
3g/P4G]02gM0<Woo00<007ooOol087oo00<007ooOol00Goo000aOol00`00Oomoo`2GOol00`00Oomo
o`1cOol;OP07OT04OV0;OZ09O/08O^0IO`0;Ob0;Nb0ENd08Md0cOol00`00Oomoo`0OOol00`00Oomo
o`01Ool0039oo`8009Moo`03001oogoo079oo`]n00Un@09nH0YnX0Yn`0Qnh1Uo00mo80Mk81Uk@0Ag
@3Aoo`03001oogoo01moo`03001oogoo005oo`00=7oo00<007ooOol0U7oo00<007ooOol0LWoo2Wh0
2Wi02gjP2Wk027kP4Gl00glP1Gl03glP17m00g/P7G]0=Woo00<007ooOol07Woo00<007ooOol00Goo
000eOol00`00Oomoo`2COol00`00Oomoo`1bOol9OP0;OT0:OZ0:O/08O^0AO`06Ob02O`0?Ob07Od0M
Nd0hOol00`00Oomoo`0MOol00`00Oomoo`01Ool003Ioo`03001oogoo099oo`03001oogoo075oo`Yn
0003OV1n@7i000Mn@0YnX0Yn`0Qnh15o01Mo80]o@1Uk@3Yoo`03001oogoo01eoo`40005oo`5oo`00
=goo0P00TWoo00<007ooOol0LGoo2Wh000=nH7i0OT001Wi02WjP2Gk02GkP4Gl05glP3Wm05W]0?7oo
00<007ooOol077oo0@000Goo0Goo000iOol00`00Oomoo`2?Ool00`00Oomoo`1`Ool:OP02OV07OT0:
OZ09O/02O`07O^0AO`0GOb0BOd0BNd0nOol00`00Oomoo`0KOol10001Ool1Ool003Yoo`03001oogoo
08ioo`03001oogoo071oo`Yn00=nH0En@0YnX0Un`0Ao00Enh0Uo00=o80Eo01Mo81Io@0ik@41oo`03
001oogoo01Yoo`40005oo`5oo`00>goo0P00SWoo00<007ooOol0Kgoo2gh00giP1Gi027jP2Wk01Wl0
0gkP2Gl01GlP0gl047lP17m00glP6Wm02W]0@Woo00<007ooOol06Goo0@000Goo0Goo000mOol00`00
Oomoo`2;Ool00`00Oomoo`1`Ool9OP04OV04OT09OZ000gkPO/1n`006O/08O`000gkPO`1o0007O`0H
Ob0TOd07Nd14Ool00`00Oomoo`0HOol10001Ool1Ool003ioo`03001oogoo08Yoo`03001oogoo071o
o`Un00EnH09n@0UnX0=nh0In`15o00Qo80=o@0io82Ao@0AoH0=k@4Ioo`03001oogoo01Moo`40005o
o`5oo`00?goo00<007ooOol0RGoo00<007ooOol0L7oo27h01WiP00=n@7jPOZ001gjP1GkP17k02Gl0
0glP1Gl027lP1Wm02glP97m01gmPB7oo00<007ooOol05Woo0@000Goo0Goo0010Ool20029Ool00`00
Oomoo`1`Ool8OP06OV09OZ07O^02O/09O`05Ob03O`08Ob08Od09Ob0TOd07Of1:Ool00`00Oomoo`0E
Ool10001Ool1Ool0049oo`03001oogoo08Ioo`03001oogoo071oo`Qn00InH003O^1nX7jP00EnX0Qn
h0Yo011o80]o@0Io80mo@0AoH15o@0MoH4aoo`03001oogoo01Aoo`40005oo`5oo`00@goo00<007oo
Ool0QGoo00<007ooOol0L7oo1gh01WiP0WkP1WjP2GkP00=o87l0O`001Gl027lP0Wm01glP3Wm00glP
3gm01gmP3Wm01gmPCWoo00<007ooOol04goo0@000Goo0Goo0014Ool00`00Oomoo`24Ool00`00Oomo
o`1aOol6OP06OV03O^04OZ09O^03Ob05O`08Ob04Od05Ob0POd0;Of0:Od07Of1@Ool00`00Oomoo`0B
Ool10001Ool1Ool004Eoo`8008Aoo`03001oogoo075oo`En00InH0Anh0=nX0Unh0Eo80=o00Qo80Io
@0=o811o@0=oH0ao@0moH0Mo@0MoH59oo`03001oogoo015oo`40005oo`5oo`00Agoo00<007ooOol0
PGoo00<007ooOol0LGoo1Gh01WiP1GkP00=nX7kPO^001gkP47lP6Gm01WmP2Gm04WmP17m01gmPE7oo
00<007ooOol047oo0@000Goo0Goo0018Ool00`00Oomoo`20Ool00`00Oomoo`1aOol5OP05OV0?O^07
Ob02Of07Ob08Od03Of0>Od09Of06Od0MOf1FOol00`00Oomoo`0@Ool10001Ool004Uoo`03001oogoo
07moo`03001oogoo075oo`An00InH0Inh003Of1nh7kP00Enh0Mo80AoH0Eo80Qo@0IoH0Yo@0eoH0=o
@1eoH5Qoo`03001oogoo00moo`40005oo`00BWoo0P00Ogoo00<007ooOol0LGoo17h01GiP1WkP0gmP
1GkP1glP1WmP0glP27m027mP27m0;7mPFgoo00<007ooOol03Woo0@000Goo001<Ool00`00Oomoo`1l
Ool00`00Oomoo`1bOol2OP06OV05O^05Of03O^07Ob08Of08Od0<Of05Od0/Of1MOol00`00Oomoo`0=
Ool10001Ool004eoo`03001oogoo07]oo`03001oogoo079oo`9n00EnH0Inh0IoH003O^1o87lP00Eo
80QoH09oP0Io@0ioH0=o@2aoH5moo`03001oogoo00aoo`40005oo`00CWoo0P00Ngoo00<007ooOol0
LWoo0Wh01GiP1GkP1gmP1glP27mP17n017m09WmP0gn057mPHGoo00<007ooOol02goo0@000Goo001@
Ool00`00Oomoo`1hOol00`00Oomoo`1bOol00gh0OV1nH003OV05O^08Of000gnPOb1o8003Ob08Of06
Oh02Od0@Of03Oh0COf06Oh0AOf1SOol00`00Oomoo`0:Ool10001Ool0055oo`03001oogoo07Moo`03
001oogoo079oo`03OP1nH7iP00=nH0Enh0MoH0=oX0=o80QoH0MoP15oH0IoP11oH0QoP0ioH6Ioo`03
001oogoo00Uoo`40005oo`00DWoo00<007ooOol0MWoo00<007ooOol0LWoo1GiP1GkP1gmP1GnP00=o
87mPOf001GmP27n00gnP3GmP2Wn03GmP37n02WmPJ7oo00<007ooOol027oo0@000Goo001COol2001f
Ool00`00Oomoo`1cOol4OV04O^07Of06Oj07Of08Oh05Oj0;Of0<Oh0:Of0@Oh07Of1YOol00`00Oomo
o`08Ool10001Ool005Eoo`03001oogoo07=oo`03001oogoo07Aoo`9nH0Enh0IoH0IoX09o`0EoH0Mo
P0QoX0UoH0ioP0QoH1=oP0AoH6]oo`03001oogoo00Moo`40005oo`00EWoo00<007ooOol0LWoo00<0
07ooOol0MGoo1GkP1WmP1WnP17o00gmP1gn02gnP1GmP4Wn01GmP5Wn0KWoo00<007ooOol01Woo0@00
0Goo001GOol00`00Oomoo`1aOol00`00Oomoo`1gOol2O^06Of06Oj06Ol08Oh0=Oj03Of0DOh03Of0F
Oh1`Ool00`00Oomoo`05Ool10001Ool005Qoo`80075oo`03001oogoo07Qoo`IoH0IoX0Io`09oh0Eo
P11oX2ioP79oo`03001oogoo00Aoo`40005oo`00FWoo00<007ooOol0KWoo00<007ooOol0NGoo17mP
1GnP1go017oP0gn04gnP57n00gnP4gn0MGoo00<007ooOol017oo0@00001KOol00`00Oomoo`1]Ool0
0`00Oomoo`1jOol2Of05Oj07Ol06On0GOj0@Oh07Oj0@Oh1gOol00`00Oomoo`03Ool1000005aoo`03
001oogoo06aoo`03001oogoo07]oo`EoX0Mo`0Uoh1AoX09o`0ioP0YoX0eoP7Uoo`03001oogoo009o
o`400000GGoo0P00K7oo00<007ooOol0O7oo0gnP1Wo037oP4GnP1Go02gn03WnP2Gn0O7oo00@007oo
Oomoo`400000Ggoo00<007ooOol0JGoo00<007ooOol0OGoo1go03WoP3gnP1go02Gn047nP1gn0OWoo
00<007ooOol00@00001POol00`00Oomoo`1XOol00`00Oomoo`1nOol5Ol0@On0<Oj0;Ol05Oh0DOj04
Oh20Ool10001Ool10000065oo`03001oogoo06Moo`03001oogoo07moo`=o`19oh0UoX0io`0=oP1Mo
X8=oo`800000HWoo0P00Igoo00<007ooOol0P7oo5GoP1gnP47o067nPPgoo0`00001TOol00`00Oomo
o`1TOol00`00Oomoo`22OolEOn03Oj0DOl0DOj21Ool40003Ool006Eoo`03001oogoo06=oo`03001o
ogoo08=ooaEoh1Qo`11oX7moo`@000Moo`00IWoo0P00Hgoo00<007ooOol0Q7oo5GoP67o03GnPOGoo
10002goo001XOol00`00Oomoo`1POol00`00Oomoo`25OolEOn0HOl0;Oj1jOol4000?Ool006Uoo`03
001oogoo05ioo`03001oogoo08MooaEoh1Qo`0QoX7Qoo`@001=oo`00JWoo00<007ooOol0GGoo00<0
07ooOol0R7oo5WoP67o017nPMWoo10005goo001[Ool2001MOol00`00Oomoo`29OolGOn0HOl1dOol4
000KOol006eoo`03001oogoo05Yoo`03001oogoo08YooaMoh1Io`71oo`D001moo`00KWoo00<007oo
Ool0FGoo00<007ooOol0Rgoo5goP4go0KWoo100097oo001_Ool00`00Oomoo`1HOol00`00Oomoo`2<
OolGOn0@Ol1/Ool4000XOol0071oo`8005Qoo`03001oogoo08iooaMoh0ao`6Yoo`@002aoo`00LWoo
00<007ooOol0EGoo00<007ooOol0Sgoo5goP2Go0J7oo1000<7oo001cOol00`00Oomoo`1DOol00`00
Oomoo`2@OolGOn06Ol1VOol4000dOol007Aoo`03001oogoo05=oo`03001oogoo095ooaMoh0=o`6Ao
o`@003Qoo`00MGoo0P00Dgoo00<007ooOol0TWoo5goPHWoo1000?7oo001gOol00`00Oomoo`1@Ool0
0`00Oomoo`2COolDOn1OOol50010Ool007Qoo`03001oogoo04moo`03001oogoo09Aooa5oh5eoo`@0
04Eoo`00NGoo00<007ooOol0CWoo00<007ooOol0UGoo3WoPFgoo1000BGoo001jOol2001>Ool00`00
Oomoo`2FOol;On1IOol4001=Ool007aoo`03001oogoo04]oo`03001oogoo09Moo`Qoh5Moo`@0055o
o`00OGoo00<007ooOol0BWoo00<007ooOol0VGoo17oPEGoo1000EGoo001nOol2001:Ool00`00Oomo
o`3^Ool4001IOol0081oo`03001oogoo04Moo`03001oogoo0>Yoo`@005eoo`00PGoo00<007ooOol0
AWoo00<007ooOol0iGoo1@00HGoo0022Ool00`00Oomoo`15Ool00`00Oomoo`3QOol4001VOol008=o
o`8004Eoo`03001oogoo0=eoo`@006Yoo`00QGoo00<007ooOol0@Woo00<007ooOol0fGoo1000KWoo
0026Ool00`00Oomoo`11Ool00`00Oomoo`3EOol4001bOol008Moo`03001oogoo041oo`03001oogoo
0=5oo`@007Ioo`00R7oo0P00@7oo00<007ooOol0cGoo1000NWoo002:Ool00`00Oomoo`0mOol00`00
Oomoo`39Ool4001nOol008]oo`03001oogoo03aoo`03001oogoo0<Aoo`D0089oo`00S7oo00<007oo
Ool0>goo00<007ooOol0`7oo1000Qgoo002=Ool2000kOol00`00Oomoo`2lOol4002;Ool008moo`03
001oogoo03Qoo`03001oogoo0;Qoo`@008moo`00T7oo00<007ooOol0=goo00<007ooOol0]7oo1000
Tgoo002AOol2000gOol00`00Oomoo`2`Ool4002GOol009=oo`03001oogoo03Aoo`03001oogoo0:ao
o`@009]oo`00U7oo00<007ooOol0<goo00<007ooOol0Z7oo1000Wgoo002EOol00`00Oomoo`0bOol0
0`00Oomoo`2TOol4002SOol009Ioo`80039oo`03001oogoo09moo`D00:Moo`00V7oo00<007ooOol0
;goo00<007ooOol0Vgoo1000[7oo002IOol00`00Oomoo`0^Ool00`00Oomoo`2GOol4002`Ool009Yo
o`03001oogoo02eoo`03001oogoo09=oo`@00;Aoo`00Vgoo0P00;Goo00<007ooOol0Sgoo1000^7oo
002MOol00`00Oomoo`0ZOol00`00Oomoo`2;Ool4002lOol009ioo`03001oogoo02Uoo`03001oogoo
08Moo`@00<1oo`00Wgoo00<007ooOol0:7oo00<007ooOol0Pgoo1000a7oo002POol2000XOol00`00
Oomoo`1nOol50038Ool00:9oo`03001oogoo02Eoo`03001oogoo07Yoo`@00<eoo`00Xgoo00<007oo
Ool097oo00<007ooOol0MWoo1000dGoo002TOol00`00Oomoo`0SOol00`00Oomoo`1bOol4003EOol0
0:Eoo`8002=oo`03001oogoo06ioo`@00=Uoo`00Ygoo00<007ooOol087oo00<007ooOol0JWoo1000
gGoo002XOol00`00Oomoo`0OOol00`00Oomoo`1VOol4003QOol00:Uoo`8001ioo`03001oogoo06=o
o`@00>Eoo`00Zgoo00<007ooOol06goo00<007ooOol0GWoo1@00jGoo002/Ool00`00Oomoo`0JOol0
0`00Oomoo`1JOol4003^Ool00:eoo`03001oogoo01Uoo`03001oogoo05Ioo`@00?9oo`00[Woo0P00
6Goo00<007ooOol0DWoo1000mWoo002`Ool00`00Oomoo`0FOol00`00Oomoo`1>Ool4003jOol00;5o
o`03001oogoo01Eoo`03001oogoo04Yoo`@00?ioo`00/Woo00<007ooOol057oo00<007ooOol0AWoo
1000ogoo0goo002cOol2000DOol00`00Oomoo`12Ool4003oOol7Ool00;Eoo`03001oogoo015oo`03
001oogoo03eoo`D00?moo`]oo`00]Woo00<007ooOol047oo00<007ooOol0>Goo1000ogoo47oo002g
Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol4003oOolDOol00;Qoo`8000moo`03001oogoo035oo`@0
0?mooaQoo`00^Woo00<007ooOol037oo00<007ooOol0;Goo1000ogoo77oo002kOol00`00Oomoo`0;
Ool00`00Oomoo`0YOol4003oOolPOol00;aoo`03001oogoo00Yoo`03001oogoo02Eoo`@00?moobAo
o`00_Goo0P002Woo00<007ooOol08Goo1000ogoo:7oo002oOol00`00Oomoo`07Ool00`00Oomoo`0L
Ool5003oOol/Ool00<1oo`03001oogoo00Ioo`03001oogoo01Qoo`@00?mooc5oo`00`Goo0P001Woo
00<007ooOol057oo1000ogoo=Goo0033Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool4003oOoliOol0
0<Aoo`03001oogoo009oo`03001oogoo00aoo`@00?mooceoo`00aGoo00D007ooOomoo`0000Yoo`@0
0?mood5oo`00aWoo0P0000=oo`00Ool01Goo1000ogooAGoo0038Ool20002Ool4003oOom9Ool00<Uo
o`<00?moodeoo`00\
\>"],
  ImageRangeCache->{{{0, 535.25}, {869.938, 0}} -> {0.186172, 0.00626965, \
0.00171385, 0.00171385}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wExample = ArcSin[z\^3 + 3\ z - 7]\/\(z - 1\); \)], "Input",
  FontSize->12],
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
ScreenStyleEnvironment->"Presentation",
Evaluator->"Local",
WindowSize->{1016, 668},
WindowMargins->{{Automatic, 0}, {Automatic, 27}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "usr1", "danl"}, \
"IWU_Talk.nb.ps", CharacterEncoding -> "ISO8859-1"],
"Magnification"->1},
Magnification->2,
StyleDefinitions -> Notebook[{
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CellularAutomaton"->{
    Cell[15772836, 581169, 413, 8, 310, "Input",
      CellTags->"CellularAutomaton"],
    Cell[15994741, 584256, 225, 6, 298, "Input",
      CellTags->"CellularAutomaton"]},
  "S5.18.1"->{
    Cell[17154922, 635268, 117, 3, 160, "Input",
      CellTags->"S5.18.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CellularAutomaton", 2470573, 85868},
  {"S5.18.1", 2470763, 85873}
  }
*)

(*NotebookFileOutline
Notebook[{
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)
o`03001oogoo00io
o`002goo00<007ooOol0JWoo;WmP0gn047mP0Wm01Wn027mP1WlP0Wn01gmP1WkP1GiP00=n03iP?V00
0ciP1cXP2C6P1RT01B3P21AP20aP0QAP0Q1P0QR00QB01ac00R4000<U02DP9B000bTP0RU000@YH2f0
;H0]P08aP0<aX0Ha`0Heh0Dj00Hn80]2@0E6H0I:P0E>P003001BX5:P00=BX0IFX0IF`0EJ`19Nh0eS
00]W00IW81=[84Eoo`03001oogoo00ioo`002goo00<007ooOol0JGoo@GmP17m017n027mP27lP1gmP
1gkP1GiP00=n03iP?V001ciP1cGP1C6P12e01BT021QP10AP10QP0`AP00<<H11P46000Q1P1QB011c0
0R3P00<Q02DP9B0012TP0RU000@]H2f0;H0]P08aP0La`0Heh0Dj00Hn80I2@0E6@0I6H0I:P0A>P003
001BX5:P00ABX0IFX0EF`0IJ`19Nh0aS00aW00IW819[84Eoo`03001oogoo00ioo`002goo00<007oo
Ool0J7oo67mP0Wm05WmP0gm03WmP1Wm00Wn027mP27lP0WkP1WmP1WkP1GiP0Wh00d:01CiP1SXP1SGP
2Be02Ab01`QP101010AP0Q1P0`aP0aB00QR00Qc00R3P0R400RDP0bTP0bU000<]H2f0;H00136P1370
1SGP1SX01ChP1T901TI01DYP1TZ014j000<004j0DZ0015:P1UJP1UK01E[04UkP36<036L01VLP4f/P
A7oo00<007ooOol03Woo000;Ool00`00Oomoo`1VOolIOf05Od0COf05Od0<Of08Od08Of08Ob04O^04
Of07O^05OV02OP000dJP@X12P004@X0;>R0:<H099:083604300504000`AP360<H00236000`a0580D
P00268026:028>028@039B02:B03:D000beP<J0aX006<J04=L03=N06>P06?R05@T06AT06BV09CX00
0`00CX1BX005DZ06EZ05E/06F/0BG^0<H`0<I`06Ib0BJb14Ool00`00Oomoo`0>Ool000]oo`03001o
ogoo06IooaQoH0Mo@15oH0Mo@0YoH0Qo@09o80IoH0Qo80Enh0=oH0Mnh0InH09n00E6X0/nH0/eh0XY
00PDH0L000@0@0@4@08<@0<HP08HX08L`08Q00<U808Y80@]H003;H0aX36P00@aX0Le`0Hj00Hn80E2
@0I6@0I:H0I>P0=BP003001BP5:000]FX0EF`0IJ`19Nh0aS00aW00IW819[84Aoo`03001oogoo00io
o`002goo00<007ooOol0IGoo67mP2Wm03WmP2Wm01gmP27m017lP17mP27lP1gkP00=oH7kPO^001WkP
1GiP0gh014JP1T:01SiP2ShP2S5P2B2000<<H22088000R201C3010100PA000<0@0a046000Q1P0QRP
0ac00R3P0bD00RU00beP0Rf00c6P23G00cWP0cX01ShP1T901DI01TYP1Tj00e:000<005:0DX0035JP
1E[01Ek04UkP36<036L01VLP3F/P1VlP@goo00<007ooOol03Woo000;Ool00`00Oomoo`1TOolHOf0=
Od0;Of0<Od05Of08Od06Ob02Of08Ob0@O^06OV04OP02B/0<@X0;?R09>N0:;<05<<06@L02E/000`0P
0400@0030403460256037<038>029@03:D02;F03;H04=J04=L07>N06?R03AR03@T06AT05CV06CX03
DX000`00DX1BP00<EZ05F/06G/06G^0<H^0BI`06J`0BJb06Kb13Ool00`00Oomoo`0>Ool000]oo`03
001oogoo06Aoo`QoH0=o@0aoH0mo@0UoH0io@0=oH0Mo@15o80Unh003OZ1nh7kP00Enh0EnH0En00M:
`0I2P0]2H0Xih0XeH0I1`0E:P0=F`09[H0@0@003140@H11P008DH0<HP0<Ph08U00<Y@08]H0@aX0De
X0Pih0<n00<n80I680I6@0I>H0QBP003001BP5:000aFX0EJ`0IN`0INh0aRh19W00I[019[80I_84=o
o`03001oogoo00ioo`002goo00<007ooOol0Hgoo27mP1Wm02GmP4Wm01WmP67m02GlP0Wl01WlP2GkP
0gjP1GkP1WiP1Gh034[02d9P2ci02Sh02dZ01F]P0WO00`100PA00aAP0aR00b300bD00bU00ReP136P
0SFP0cG01CWP1ch01THP0dY00dI01TiP25:000<005:0DX0035JP1U[01Ek01UkP36;P4VL01V/04f/P
1VlP@Woo00<007ooOol03Woo000;Ool00`00Oomoo`1ROol8Of09Od06Of0EOd03Of0@Od03Ob05Od09
Ob04O`04Ob09O^04OZ05O^06OV05OP0:C^0<AZ0;?T0;AX06BX06F`09Ml02040010A0340<@0a00aR0
0b300bD00bU00beP0c6P1SG00cWP1ch01THP1TY01TiP25:000@005:0DX1BP0]FX0IJ`0IN`0INh0aR
h15W00I[01=[80I_84=oo`03001oogoo00eoo`002goo00<007ooOol0HGoo27mP37m00gmP:7m01GlP
0gm02GlP1Wl00WlP2GkP1WjP0gkP1WiP1Wh05DkP34JP2dJ01U/01VMP1GO01WoP0P100`a00aAP0b30
0bD00bU00beP13FP1SG023h01THP1TY01TiP25:000@005:0DX1BP0IFX0EJX0IJ`0IN`0INh0aRh19W
00I[019[80I_84=oo`03001oogoo00eoo`002Woo00<007ooOol0HWoo1gmP9Wm00glP3Wm04GlP27l0
2GkP1gjP0gkP1WiP1Wh02E<064kP2e;P36MP3GoP00@0@0a0340<@0<DH0<L`0<U00<Y@0@aP0@eX0<e
`0<mh0Dn00M680I:@0I>H0QBP004001BP5:0DX06EZ06FZ0;G/06G^0<H^0BI`06J`0CJb06Kb12Ool0
0`00Oomoo`0=Ool000Yoo`03001oogoo065oo`MoH2Io@0Io80]o@0Qo809o00Mo80Qo009n`0Qnh0Qn
X003O^1nH7iP00AnH0Qn01=C00a>h0aK80IWH0M_X0eoh0040200@010340356037<04:@03;D03<H05
=J06?N02?P08AR05BT07CV08DX001000DX1BP5:01UJP1UZP35k04F;P4VL01V/04f/P1VlP@Woo00<0
07ooOol03Goo000:Ool00`00Oomoo`1POol7Of0VOd08Ob09Od08Ob04O`05Ob08O`04O/06O^09OZ07
OV08OP06Fb0=D`0<Eb0<Fb0=Kj0?On000`0P0400@00356037<04:@03;D04<H02=J03>L05?N08AR06
BT07CV06DX02EX001000EX1FP5J01UJP1UZP35k036;P1VKP4FL01V/04f/P1VlP@Woo00<007ooOol0
3Goo000:Ool00`00Oomoo`1OOol7Of0VOd0;Ob06Od08Ob06O`03Ob08O`05O/05O^0:OZ000gi0OV1n
H004OV08OP0BFb0<Eb0=Hf07Kj06Ll0@On0202001010440@@1100ac012T00be013601CW013gP0TH0
1THP1TY01TiP1e:00UJ000@005J0EX1FP0aJX0aN`0aRh0IVh0IW00a[01Q[80I_849oo`03001oogoo
00eoo`002Woo00<007ooOol0Ggoo0gm00gmP9Wm03WlP0gm027lP4Gl01gk00gkP2WjP0Wi01GiP2Gh0
15lP3U/P35m03F=P3G?04GoP00<0000P02000a100b2P12T00be01CFP13W00SgP1DH00dHP1dY01TiP
0eIP15:00UJ000@005J0EX1FP0IJX0INX0aN`0aRh0IVh0IW00a[00I[81Q_849oo`03001oogoo00eo
o`002Woo00<007ooOol0GWoo;7m06GlP27l00WkP1gl02Gk000=nh7jPOZ0027jP0gi01GiP2Gh015lP
6Um03F^01g?01gO04GoP00<0000P02000a100b2P12TP135P1CFP0cW024H01dY01diP1UIP0eJ000@0
05J0EX1FP0IJX0INX0IR`0IN`0aRh0IVh0IW00a[00I[81Q_849oo`03001oogoo00eoo`002Woo00<0
07ooOol0GGoo9Gm00glP17m047lP0gl01WlP27l017kP1Gl02Wk02WjP1Gi00giP2Wh04Em03F=P3F^0
3WO04WoP0P0000@080a0340@@0<PX0@Y80@aH0DeX0A1h0I6009:80E:@0=B@0A>H0IFH0=JP004001F
P5J0EX06FZ06GZ0<H/0<H^06I^06I`0<J`06Jb0HKb12Ool00`00Oomoo`0=Ool000Yoo`03001oogoo
05eoobAo@1Mo80Eo00Ao80Qo00Inh0=o00Yn`0YnX0In@0=nH0Yn009O@1]SH0i_P0Yg`0Ak`1=oh080
0004020<@0a034038:04:B04<F03=J03?L04@N03AP05BR03BT06DT07EV03FX000`00FX1JP007FZ06
GZ0<H/06I^06H^06I^06I`0<J`06Jb0HKb12Ool00`00Oomoo`0=Ool000Yoo`03001oogoo05aoobAo
@1Mo80Mo009o80Qo00Qnh003O`1n`7k000Qn`0YnX0Mn@0=nH0Yn0003Hd1SH6=P00eSH0eWH0i_P0Eg
`0Uk`1Aoh0800004020<@0a034038:04:B04<F06?L05@N08BR07DT07EV03FX000`00FX1JP003GZ04
FZ06GZ0<H/0BI^06I`0<J`06Jb0HKb12Ool00`00Oomoo`0=Ool000Yoo`03001oogoo05]oobAo@1Mo
815o00Unh0Yn`0YnX0Un@003OV1n07h000Un0003Hd1WH6MP01YWH0i_P0ik`1Eoh08000@<@0<PX0@]
80DeP0Dm`0=1h0=:00E:80QB@0MFH0=JP003001JP5Z000eNX0aR`0aVh0IZh0IW00a[00I[81Q_849o
o`03001oogoo00eoo`002Woo00<007ooOol0Fgoo97m05WlP4Gl02GkP2Wk02WjP2Wi000=nH7h0OP00
27h000=S@6MPIf003FMP3V^03W>P1g_027o05GoP0P0000<@@0a03400122P12dP1CF01Cg01dX00TXP
2E901UIP15Z000<005Z0FX001UjP1V:P3F;036KP1V[P4V/01V/P66lP@Woo00<007ooOol03Goo000:
Ool00`00Oomoo`1JOolTOd0?Ob02O`05Ob0AO`09O^0:O/0:OZ0;OT0;OP0?If0?Jh0>Lj0?Ol0FOn02
000244000`a08:0PX0028:04;B05=H03?L03BN06BP09DT07EV03GX0015Z0001JP5Z01UjP1V:P3F;0
36KP1V[P1V/036l01V/P66lP@Woo00<007ooOol03Goo000:Ool00`00Oomoo`1IOolLOd02Ob06Od0?
Ob05O`02Ob0AO`09O^0:O/0:OZ0;OT0;OP000fMPJf1[H00<Jf0?Jh0?Lj0?Ol0GOn001000440@@110
1B2P12dP1CF01TWP14X00e8P1e900UYP15IP1Ej000<005j0GZ001UjP1V:P3F;036KP1V[P1V/036l0
7VlP@goo00<007ooOol037oo000:Ool00`00Oomoo`1HOolLOd05Ob03Od0?Ob0IO`08O^09O/0;OZ02
OV09OT0<OP0?Jf0?Kh0?Lj0?Ol0HOn001000440@@11012S01BdP1T6P1DWP0TX01E8P1E901EYP0UIP
1Ej000<005j0HX000V:015jP1V:P1V;01VK03FKP1V[P1V/036l036lP1W<P36lP@goo00<007ooOol0
37oo0009Ool00`00Oomoo`1IOol3Nd0IOd0FOb0IO`08O^09O/0;OZ04OV07OT0<OP0?Jh0?Kh0@Mj0?
Ol0FOn03Ool44404:<05=F06@J05BN08DR02DT07FV06GX000`00GX1RP005HX07HZ06H/06I/06J^07
I^06J^06J`0<K`0<Kb0BLb13Ool00`00Oomoo`0<Ool000Uoo`03001oogoo05Uoo`Ik@1Eo@0Qo80=k
80ao81Qo00Qnh0Un`0]nX0EnH0In@0en00m[P0m_P11gX11o`15oh0Qoo`04640@@1104404:<05=F06
@J03BN03DP07DR08FV02GV05GX000`00HX1RP004HX03IZ04HZ06H/06I/0CJ^06J`0<K`0<Kb0BLb13
Ool00`00Oomoo`0<Ool000Uoo`03001oogoo05Qoo`Yk@15o@0Qo80Mk80Qo81Qo00Qnh0Un`0]nX0Mn
H0An@0en01m_P0mgX15o`0eoh0aoo`03000H@1Q0008@@0@X`0DeH0I1X0IB00EB80=J@0EJH0ENH0=N
P003001RP6:000ARP0IVX0MR`0IV`0aZh0=^h0AZh0I[00a_00a_819c84=oo`03001oogoo00aoo`00
2Goo00<007ooOol0F7oo3G]03Wm01glP2W/P1GlP47l00WkP1Wl027kP2Gk02gjP27iP0gi03Wh03fn0
47>P3g^P4Go02GoP47oo00<H81Q064000QQ01BS01CEP0d6P0dgP1e800U8P1UY00UYP25iP00=RP000
HX0016:01fJP0fK016;01VK036[P1VkP1f/036l036lP4W<P@goo00<007ooOol037oo0009Ool00`00
Oomoo`1GOol>Nd03Nb0:Od08Ob0<Nb02Ob0@O`04O^04O`08O^09O/0;OZ0:OV000gi0OP1n000=OP0?
Kh0@Lj0?Nj0AOl05On0DOol262046405=@04=F07CN07DP08FT09GV000fJ0001VP004HX06IZ0>I/0<
J^06K^0CK`0<Kb0BLb13Ool00`00Oomoo`0<Ool000Uoo`03001oogoo05Moo`ek@0Mk80Mo@0Mo80ik
811o00Inh09o00Qnh0Un`0YnX0anH0mn00m_P11cX11kX15o`1Uoo`8H8003000H@1Q0008H@0De00A5
P0M=h0EB00=N80IJ@09RH0INH09VP003001VP6J0009VP0MVX0MV`0IZ`0aZh0M^h1=_00a_819c84=o
o`03001oogoo00aoo`002Goo00<007ooOol0EWoo3W]01g/P0gLP0gm01glP3g/P0g/037l047kP2Gk0
2WjP37iP47h03fn047>P47^P2Go08Woo0QPP11Q01SD014F01dgP0e801EhP15Y01F9P0eiP0fJ000<0
06J0IX000VJ00fZP0fJP1fK01f[00fkP2F[P1fkP36l01W<03FlP4W<P@goo00<007ooOol037oo0009
Ool00`00Oomoo`1FOol=Nd07Nb06Mb08Ob0>Nb07N`08O`09O^02N^05O^09O/0:OZ0<OV0@OP0?OolA
Lj0@Nj0[Ool262000`00<:0H@0026405=@05AH07CN08GR02FT08HV04IX001000IX1VP6J01VZP26K0
1f[01FkP1f[P1VkP3Fl01W<01W<P1VlP4g<P@goo00<007ooOol037oo0009Ool00`00Oomoo`1EOol>
Nd07Nb09Mb04Ob0?Nb09N`05O`09O^05N^02O^09O/0:OZ0<OV0AOP1KOol262000`00<:0`X0026406
=@05AH04CN04GP07GR09HV02JX02IX000`00IX1VP007JZ02KZ05I/07J/09K^04J^06K^0=K`06L`0O
Lb13Ool00`00Oomoo`0<Ool000Uoo`03001oogoo05Eoo`ek@0Mk80eg80mk80ak009o00Unh0Mjh0Un
`0YnX0anH15n05aoo`<H80@`X003640e03D000@e00E5P0QN00EN80=V@0IRH0EZP003001VP6ZP00IZ
X0E^X0=V`0MZ`1=^h0a_00Mc019c80Ig80Mc84=oo`03001oogoo00aoo`002Goo00<007ooOol0E7oo
3W]01g/P47LP2g/P3W/02GkP27[P0WK01Wk02WjP37iP4Wh0G7oo0aPP00<0032P<:000S2P1SD01UW0
25h00ehP1FI0169P1VZ000<006ZPJZ001VZP1fjP1f[03FkP1W;P3Fl01W<04g<P37LPA7oo00<007oo
Ool037oo0009Ool00`00Oomoo`1DOol3Md0:Nd07Nb0DMb08Nb0>N`02M^06O^08N^04M/04O/0:OZ0;
OV0COP1MOol46205<:06DF06FL08GP08IT02HV07JX000`00KZ1^X005JZ08KZ03K/04J/0=K^06L^03
L`0:K`06L`0CLb0<Mb14Ool00`00Oomoo`0<Ool000Uoo`03001oogoo05Aoo`Ig@0Mk@0Mk81Ag80=g
00Ak80ik00Efh0=nh0Qjh0If`09n`0YnX09fP0UnH09f811n00=YH5eoo`<H80D`X0MAH0II`0IN009Z
80QV@0QZP003001^X6jP009^X0=ZX0M^X0M^`0e^h0Mbh0Ic00M_00Ic019c80eg84Eoo`03001oogoo
00]oo`0027oo00<007ooOol0EGoo1WM01WLP1g/P57LP1gL03g/01gKP2G[P1gK02WjP17J01giP17HP
37h01VUP00<@07ooOol0FWoo11PP1C2P1U5P1eW00eh01FXP1VI00fiP1FZ000=^X000KZ0036jP26k0
0g;P2VkP1W;P57<04W<P3GLPAGoo00<007ooOol02goo0008Ool00`00Oomoo`1DOol7Md06Mb03Lb04
Nb0DMb07M`03L`0;N`08M^02L^06N^08M/02LZ07OZ06MX04OV06MR09OP09JF000a00Oomoo`1JOol4
6205<:07DF07FL08JR04IT06KV02JX02KZ000`00KZ1^X004KZ02LZ05KZ07K/06L^07K^07L^0=L`06
M`0CLb0<Mb16Ool00`00Oomoo`0;Ool000Qoo`03001oogoo05Aoo`Mg@0Ig80Ic81Ag80Mg00Mc00Qk
00Mfh0Ebh0=jh0Qf`0AbX0EnX0QfP09nH0Qf80In00=Y`0QYH08@05]oo`@H80H`X0IAH0EI`0=Z00QZ
809V@0Q^H0=^X003001^X6jP00=^X0EbX09^X0M^`0Mbh0=fh0A^h0Mbh0ac00Mg00=g80mc80eg84Io
o`03001oogoo00]oo`0027oo00<007ooOol0E7oo1WM01gLP37<P3WLP1gL01g<00W;P1G/01gKP27;P
27K01g:P0WjP2GJ02gHP0gh01FW026UP0Q00Fgoo1APP0W600c2P1e5P0UW01VX01fXP2FiP0g:000=^
X000KZ000fjP1g:P26k01W;P1gKP1g;P3G<01gL01WLP37<P3GLPAWoo00<007ooOol02goo0008Ool0
0`00Oomoo`1DOol6Md06Mb0@Lb0:Mb07M`07L`05L^03N`07M^08L^02L/05M/09LZ09MX02KT0:MR09
JL08JF02401JOol56204LH02<:06DF08JP06JR03LV06KV05LX000`00KZ1^X002KZ07LZ03M/04K/07
L^07M^03M`04L^0<L`07M`0<Mb07Lb0<Mb17Ool00`00Oomoo`0;Ool000Qoo`03001oogoo05=oo`Mg
@0Ig81=c80Mg80Mg00Mc00Mbh0Mfh0Qbh0Eb`09f`0UbX0=^P0IfP0A^@0Qf809V00QY`0QYH08@05]o
o`@H80IaP0M]`0QZ00AZ80EbH0A^H0IbP004001bP6jPKZ07LZ07M/07L^07M^07M`0=L`07M`0OMb17
Ool00`00Oomoo`0;Ool000Qoo`03001oogoo05=oo`Ig@0Mg81=c80Ic00Mg00Mc00Qbh0=^h0=fh0Qb
h0Mb`0UbX0E^P0AfP0I^@0Ef80EV00QY`0MYH0<@05]oo`<H80MaP0M]`0QZ009Z80MbH09^H0MbP003
001bP7:000MbX0Qf`09fh0Ebh0Mfh0Yg00Uc00Mg021g84Moo`03001oogoo00]oo`0027oo00<007oo
Ool0Dgoo1WM01WLP57<P1W<00fl017L01g<01g;P1VkP27;P27;00VjP1W:P1fj00WJ026i00gHP1fH0
1fW01fUP0a00Fgoo11PP1W601fg026X02W9P27:000<007:0MZ000WJP1G:P1gK01GKP0W;P1gKP3WL0
1W<01gL06GLP1W]0B7oo00<007ooOol02goo0008Ool00`00Oomoo`1BOol7Md06Mb0DLb06L`06K`07
L`08L^09K^04L^08L/05KZ03LZ09KX0:KT09IP08JL06JF04401KOol36207LH07KL05JP03NT08LV03
NX05LX020006MZ02LZ07M/0?M^0>M`05N`07M`0JMb06Nd18Ool00`00Oomoo`0;Ool000Qoo`03001o
ogoo059oo`Ic80Mg81Ac80Ic00U_00Ac00Mbh0e^h0Qb`0Q^X0U^P0=VH0M^@09R80UV00MY`0MYH0<@
05]oo`<H80MaP0Q]`09Z00Ij@0IbH0EjP0@00003LX1fX00000IfX0Qf`0Mfh0=jh0Afh0ig00Ik00=k
80Ag01Ug80Ik@4Uoo`03001oogoo00]oo`0027oo00<007ooOol0DWoo87<P1g<036l027;P3FkP0V[0
1W;026jP0VZ01Vj01FIP1Fi0168P2FH01VW01fUP1100Fgoo0QPP1g6026g02GY0179P0gZ00`0000Aj
P7:0LX1bP0=fX003001fX7JP009fX0=j`0Ef`0Mfh0Mjh0ig00Ik00Mk81Yg80Ik@4Uoo`03001oogoo
00]oo`0027oo00<007ooOol0DWoo37<P1VlP3W<P1W<03Fl00fkP17;P3VkP16[00g;026jP16Z016j0
1fIP0fi01V8P26H01dU00RQP16UP1100G7oo00<H8760LH001W601Fg00ghP2GY00W9P10001GZ01WJP
00<007JPMZ001W[00WK01gKP27[P0g/02gL01W/02W/P5WLP1W]0BWoo00<007ooOol02goo0008Ool0
0`00Oomoo`1BOol<Lb0=Kb07Lb06L`0=K`0DK^07J/08KZ06JX02KX09IV09HR05IP03DL06BD04:602
JF05401KOol26207LH03KL06OR07NT030008NX03OZ05MZ000`00N/1j`006N/08M^07N^06N`08M`06
N`0>Nb0CMb06Nd1:Ool00`00Oomoo`0;Ool000Moo`03001oogoo05=oo`ac811_80Ac80Ic00e_00I^
h0=Zh0]^h0MZ`09VX0I^X0MZP0YVH003GT1R868P00MR809V00IA`0I9@0DXH0D@05aoo`03621aP760
00EaP0Un80=j@0@00003NT1nH7iP00MjP0EnX0AfX003N/0007[000Ej`0=nh0Efh0Mjh0Mk00=o00Ag
00Mk01=k80ig80Ek@4aoo`03001oogoo00Yoo`001goo00<007ooOol0Dgoo37<P4flP1g<036l01fkP
1V[P1fkP1f[01FJP0fjP26Z00V9P1fIP0ei0268P25701TU01RQP1100G7oo00<H8760LH000g600gh0
27hP0`000gY01GiP1GZ01gjP0WJP0g[000<007[0N/000W[01WkP0WKP1g[P1g/01gl01g/06W/P1gLP
1W]0C7oo00<007ooOol02Woo0007Ool00`00Oomoo`1COol<Lb0CKb0CK`07K^06J^03J/04K^07J/07
IZ08JX04HV05IV05GT06HR02EN08DL06BD05:604401MOol3LH05OP04OR040002OR02NT08OV03NX09
OZ05N/000`00N/1j`008O^07N^08N`09O`05N`0JNb03Nd04Mb05Nd1=Ool00`00Oomoo`0:Ool000Mo
o`03001oogoo05=oo`ac81=_80I_00I[00M_00I^h0MZh0eZ`0QVX09RX0EZP0MRH09VH0MN@0=R80EE
h0MA`0I9@0HXH0<@05eoo`Un00<000In80]nH0YnX0=n`0Aj`003001nh7kP00Ynh0=jh0Qk00ao009k
01Yk80ek@4eoo`03001oogoo00Yoo`001goo00<007ooOol0Dgoo37<P4flP1Vl02F/016l01VkP1f[P
1V[00fK016[01fJP1F:P0VZ02F9P2Ei025GP1e701TU01BQP0a00GGoo1Gh0100027hP2giP0Wj027jP
1Wk00W[000=nh000O^0037kP27/03Wl06g/P1g]01Gm0CWoo00<007ooOol02Woo0007Ool00`00Oomo
o`1BOol=Lb0CKb06K`0<J`07K^06J^07J/06I/08IZ06HZ09HV03FV06GT03ER07EN06DL06BD05:600
17oo400@0100G7oo0Wh00`001Gh01WhP2giP17j01WjP27k00gkP00<007kPO^002WkP0Wl01W/03Wl0
1WlP57/P1g]01Wm0CWoo00<007ooOol02Woo0007Ool00`00Oomoo`1COol5Kb07Lb0CKb06K`0<J`0=
J^07J/06I/02HZ05IZ07HZ02GX06HV06FV03GT05ER07EN06?F05;>06:603401JOol40008OP05OR0;
OV06OX04OZ08O/05O^000`00O^1nh008O^05O`03N`0>O`0:Ob0@Nb07Nd06Od1?Ool00`00Oomoo`0:
Ool000Moo`03001oogoo05=ooam_80I_00a[00IZh0=Vh0AZh0IZ`0MV`0ARX0=VX0MRX0ANP0=RH0QJ
H0QF80EEh095`0HmH0D/h003420XH2QP008XH0<@05Moo`<00003Oomn07h000Yn00=n80]nH0QnP09n
X0Qn`0Mnh003001nh7kP00Inh1Io00eo80ik80Mk@0Io@4moo`03001oogoo00Yoo`001goo00<007oo
Ool0Dgoo7flP1Vl036/01V[P1VKP1f[01fK03F:P1ej02EYP0U901eHP0eGP14G01SeP1BcP0Q0P0bQP
0Q00Dgoo100017oo37h00WhP2giP2Wj027k027kP00<007kPO^001GkP5Wl04GlP2W/P1g]01Wm0D7oo
00<007ooOol02Woo0007Ool00`00Oomoo`1COolBKb06Jb06J`07K`0<J`06J^06I^03H/04J/06I/07
HZ03GZ04HZ07GX08FV04DT07ER07AL06?F04;>0442000bQP400@001@Ool30007Ool=OP0;OV0;OX08
O/0:O^000`00O^1nh003O^0GO`0DOb07Nb06Nd06Od1AOol00`00Oomoo`0:Ool000Moo`03001oogoo
05=ooa9_80I[81U[00IZh0IVh0IR`0MV`0MRX0INX0QNP0MJH0MB@0=F80A9h0I5`0HmH0@/h0@@8003
000@07oo04]oo`@000Yoo`en0003OT1nH7iP00MnH0]nP0Qn`0anh004001nh7kPO^0@O`02Ob05O`0E
Ob03Od03Nb07Nd06Od1AOol00`00Oomoo`0:Ool000Moo`03001oogoo05=ooa9_80I[80a[00IW00M[
00IZh0IVh0UR`0AV`0IRX0MNX09JP0ENP0MJH0UB@0M9h0I5`0DmH0@/h0D@808@02aooaA[P0QSH0<0
00USH0YO@0Mn00=n@0MnH0]nP0Qn`0inh003001nh7l000mo00Eo809o01Eo80Io@0Mk@0Io@59oo`03
001oogoo00Yoo`001goo00<007ooOol0Dgoo4VlP1V/P36/036L01f[P1VKP36;01f:P1ejP15Z00ej0
1eYP2E9000=:04WPBN001DWP1DG01S4P0R2P0RcP110P0Q008Woo2W>P56^016=P100036=P4em000=n
@7iPOV0017iP2gj027k047kP00<007l0O`003Gl077lP2Wm00g]01gm0DWoo00<007ooOol02Woo0006
Ool00`00Oomoo`1DOolBKb06Jb0<J`0<I`03H^04J^06I^0<H/0=GZ07FX07FV09DT03BP07BN05>H06
<B038:0542000a00Oomoo`0FOolDLj0DJh0016=P000000003f=P55m01e/P2Wj027k047kP0Wl000<0
07l0O`002gl077lP57m0Dgoo00<007ooOol02Woo0006Ool00`00Oomoo`1DOolBKb06Jb0<J`0<I`06
H^07I^0<H/06GZ03FZ04GZ07FX02EV05FV08DT05BP05BN02?L05>H05<B048:001@@P420@810P4000
4goo1W_04g>P4FN010004V=P4em03U/P0Wj02Gk047kP17l000<007l0O`002Gl077lP57m0EGoo00<0
07ooOol02Goo0006Ool00`00Oomoo`1DOolBKb06Jb0<J`0<I`0<H^0=H/06GZ06FZ08FX04EV02FV08
DT07BP03BN04?L05>H05<B048:021202420>Ool;Nl0CLj0>Ih030003Ih0BHf0CGd0EFb04O/0@O^06
O`000`00O`1o8002Ob05O`0>Ob04Od0:Ob0EOd1EOol00`00Oomoo`09Ool000Ioo`03001oogoo05Eo
o`E[80a_80I[80a[00aW00aRh0IN`0MR`0INX0IJX09FP0EJP0IFH0QB@0=:80I:00Lm`0DiP0Da80@P
X0<48003001oogoo00Iooa1k`1=cX0YWP0@000EWP19SH1=O@1]K80Inh09o00Inh0Qo0003001o87lP
00=o809o00io80Mo@0Mo81Eo@5Ioo`03001oogoo00Uoo`001Woo00<007ooOol0EGoo5f/P36/036L0
36;P2Ek016;01UjP1UZP15J00eZ01UIP0di015901TXP0dX00d7P1Sg01CV0134P1B2P0P@P0P000Woo
5G_04g>P1fMP0`002FMP4Um0<U/P00=nh7l0O`000Wl017kP27l00WlP00<007lPOb004GlP2gm00glP
5Gm0Egoo00<007ooOol02Goo0006Ool00`00Oomoo`1EOolBJb0;I`06J`0<I`0<H^0<G/07GZ06FZ06
EX07EV06CT08BR06@N06?L05<F04:@04660212000gaPOn1oh002On0DNl0:Lj09Kj03If04000;If0C
Gd0BFb06Eb0OFb000gl0O^1nh008O`04Ob000`00Ob1o800?Ob0SOd1HOol00`00Oomoo`09Ool000Io
o`03001oogoo05Iooa5[81eW00aRh0aN`0eJX0IFP0=BH0AFH0I>@09:@0I:809200I1h0<m`0<eX0@a
H0@Y008HH0Uoh1=k`1=_X0<000IWH0USH19K@19K80eG81eK80Io00Io8003001o87lP00eo82=o@5Uo
o`03001oogoo00Uoo`001Woo00<007ooOol0EWoo4F/P4VL01V<04F;P35k01UZP0eJP15ZP1UJ01U9P
1di014Y00dXP14801T7P1SFP135P00<Y07oPOn002goP57_03VnP10004V=P4E]09ELP75/P00=o07lP
Ob001WlP00<007lPOb002glP97m0FGoo00<007ooOol02Goo0006Ool00`00Oomoo`1FOolBJb0AI`06
H`0AH^0<G/06FZ06EZ07EX06DV03CV04CT06BT07@P03@N03>L05=J0BOn0CNl0;Kj030004Kj0AHf0A
Fd0BEb0:E`09Eb07E`0IFb07Ob000`00Ob1o8002Ob04Od03Ob0TOd1JOol00`00Oomoo`09Ool000Io
o`03001oogoo05Mooa5[815W00IS00aRh0ENh0aN`0IJX0IFX0IBP0MBH0I>H0M:@09280I200Hi`1Io
h1=k`0M_X0@000M_X15O@15K839G00MK80EG00YK80Eo8003001o87lP02]o@5]oo`03001oogoo00Uo
o`001Woo00<007ooOol0Egoo4F/P4FL01V<036;P1UkP1E[01Uk01UZP1UJP1U:00dj0159P1TiP0TI0
1DY0148P0d800cWP0SW067oP57_00fnP0`001VnP1F^04Em04E/P4EL01U<035L01E<06EL02U/P0glP
00<007m0Od00:Gm0G7oo00<007ooOol02Goo0006Ool00`00Oomoo`1GOolBJb0AI`06H`0;H^06G^0;
F/06FZ06EZ06DX06CX07CV04AT03BT06@R03>N0LOn0BNl040003Kj0;Jh0@Gd0AFb0AE`0<D`06E`0:
D`0HE`0:Fb000gm0001o@00XOd1MOol00`00Oomoo`09Ool000Ioo`03001oogoo05Mooa9[815W00IS
00aRh0ENh0aJ`0]FX0IBP0I>P0=:H0A>H0I6@0M281moh0mk`0<00003Nl1[P6^000m[P11K@11G039C
01MG00UK8003001o@7m002Eo@5ioo`03001oogoo00Uoo`001Goo00<007ooOol0FGoo4F/P4FL01V<0
36;P1UkP2e[01UJP1E:P1U:01Tj01TYP1dI01D8P8GoP2g_0100017O02F^026MP45]03eL04E<02DkP
2E<01U;P3E<05eL01e/P00<005/POd008gm0Ggoo00<007ooOol02Goo0005Ool00`00Oomoo`1IOol6
Jb0<Ib05I`0AH`0<H^06G^0;F/06EZ06DZ0;CX06BV07AT02@R0UOn07Nl030008Ml0AIf0@E`0`C^0=
D^0<D`0FE`05Fb001000Fb1K85/P87m0H7oo00<007ooOol02Goo0005Ool00`00Oomoo`1JOol5Jb0<
Ib05I`0BH`0AG^0<F/05EZ06DZ06CX02BX03CX06BV06AT0YOn02Nl04000<Ml0;If05Hd0?E`0OC^08
B/0?C^0=D^0;D`0DE`04Fb000`00Fb1K8002Fb08Od04Of0AOd1ROol00`00Oomoo`08Ool000Eoo`03
001oogoo05Yoo`I[80aW80EW015S00aNh0IJh0]J`0EFX0IBX0I>P0E:P0I:H0=6@2]oh0<0011g`0IW
H0YS@0QG00M>h0m:`0i6X15:`0e>h0aBh0]C019G00=K8003001K85/P00AK80Ao@0MoH0io@6=oo`03
001oogoo00Qoo`001Goo00<007ooOol0FWoo1V/P36LP1FL04V<02ekP1U[P1U[01EK01EJP1U:P1Tj0
1TZ01DIP00=6@7oPOn009goP10000WoP4GO046=03dkP3T[05TJP3d[034kP2e;P2e<04UL000=K8000
Fb001U/P00=o@7mPOf0027mP2gm0I7oo00<007ooOol027oo0005Ool00`00Oomoo`1KOol6Jb0;Ib06
I`0AH`0<G^06F^05F/06E/05DZ05CZ06CX06BX03AV0YOn030006On0=Ml05Lj08Hd07Fb0>C^0>B/0N
AZ0=B/0;C^0;D^0:D`0AE`000`00Fb1K8002Fb04F`0;Of08Od1UOol00`00Oomoo`08Ool000Eoo`03
001oogoo05]oo`I[80aW80EW019S00]Nh0IJh0EJ`0IF`0EBX0I>X0E>P0I:P003AV1oh7oP02Eoh0@0
00Yoh0Qg`0UcX0mK80i:X0i6P1E2P0Q6X0I6`0a:`0Y>h0]Bh0YC00mG0003001K05/000MK00]oH0Eo
@6Ioo`03001oogoo00Qoo`001Goo00<007ooOol0G7oo1V/P2fLP1VL04F<035kP1U[P1E[01UK01E:P
1TjP1Dj00dYP9goP0`003WoP17O02W>P0f^025/P1e;03DZP3TJ07D:034K02d[02TkP2U;P2E<03UL0
00<005L0E`0025/02gmP0Wm0Igoo00<007ooOol027oo0005Ool00`00Oomoo`1LOol6Jb0;Ib06I`0A
H`0<G^06F^05F/06E/05DZ06CZ05CX000dYPOn1oh00SOn04000AOn0:Lj07Jh0?D/0K@T0=?T0?@X05
@Z0<A/0:B/0:C^0:D^09D`0;E`000`00E`1G0002E`08F`0:Of1XOol00`00Oomoo`08Ool000Eoo`03
001oogoo05aoo`I[80IW80IS80aS00]O015Jh0EJ`0IF`0IBX0I>X09>P2Eoh0<001Ioh0EcX0Q[P0AS
@0MB`0M6H1Y2@0`n@0lnH0]2X0I6`0m:`0Y>h0UBh0UC00YG0003001G05L000=G00QK00MoH6Uoo`03
001oogoo00Qoo`001Goo00<007ooOol0GGoo36LP1V<P36<02el02e[P1UKP1EK01U;02TjP97oP1000
6WoP26^026=03TIP33g033gP3Ch01ci023iP1D:02d:P54[02TkP2E;P15<03EL000<005L0E`001EL0
1e/017mPJWoo00<007ooOol027oo0005Ool00`00Oomoo`1NOol<Ib05Hb0<H`0<G`0;F^05E^06E/06
D/0:CZ0POn03000OOn04Jh08Hd03E/07AV06@L0==D0<=H0<>L0>?T0;@X06@Z04AZ0?B/05C/09C^09
D^0@E`000`00E`1G0006E`07F`000gmPOomoo`1YOol00`00Oomoo`08Ool000Eoo`03001oogoo05mo
o`aW80ES80aS00]O00]Jh0IFh0EF`0IB`0]>X1]oh0@0029oh0QS@0MF`0M1`0Hdh0`e@0`eP0`i`0Lj
00`n@0]2P0U6X0Y:`0U>`0Y>h0QBh0mG0003001G05L000MG00MK06Yoo`03001oogoo00Qoo`0017oo
00<007ooOol0HGoo2fLP1V<P36<02el02e[P1EKP1UK01U;02djP5goP0`009goP16=01eK014X01cCP
1BR02bbP2c4P3C603SX02Si02d:024JP2T[02Dk02DkP25;P3UL000<005L0E`0015L02e/0J7oo00<0
07ooOol027oo0004Ool00`00Oomoo`1QOol<Ib05Hb0<H`0<G`0;F^05E^06E/06D/0;CZ000dZ0On1o
h00?On04000ZOn08E/04BP04?>06:805580;880;:<06;B06<H07=L07>P05>R0:?T0;@X07AZ0:B/08
C/05C^0<D^0=E`000`00E`1G000?F`1WOol00`00Oomoo`08Ool000Aoo`03001oogoo069oo`aW80ES
80aS00]O00]Jh0EFh0IF`0IB`0]>X09:P0eoh0<002aoh0=gX0AF`0A:00@lh0<TP003580<00`000P0
00XDP0/PP0`]80de`0Xj80Dn@0HnH0Y2P0M6X0Y:`0M>`15Bh0aG0004001G05L0E`0?F`1UOol00`00
Oomoo`08Ool000Aoo`03001oogoo06=oo`aW80ES80]S00EO00aJh0IFh0EF`0IB`0]>X0I:P096P0Qo
h0@002eoh0EgX0E:00@lh0<TP08@H0<<@0@4@0D0@0T0H0XHP0`Xh0`aP0Pj00Pj80`nH0E2P0A2X0M6
X0Y:`0M>h11Bh0]G0003001G05L0009G00iK06Eoo`03001oogoo00Moo`0017oo00<007ooOol0I7oo
2fLP1F<P4El035[P1UKP1EK01U;02djP1TZ00TJ017oP0`00;goP1GNP16<013cP0RB00QRP1Q1P0Pa0
00<<H0A014000`QP0P10201P2Q1P2b2P1be01S601CG02CX01ci02ciP24:P24JP2D[01dkP45;P2UL0
00<005L0E`000UL03e/0Hgoo00<007ooOol01goo0004Ool00`00Oomoo`1TOol5Ib07Hb05H`0AG`0<
F^06E^05E/06D/0;CZ06BX000dJ000000002000`On05Mj04H`03CF001BB08>0Ph1c07:000aRP0QR0
1A1P0`aP1@QP0`AP101P1@QP1@aP2Qb01bT01Re02SG01CX01CXP1ci01CiP1D:01d:P24JP2D[01dkP
45;P2EL000<005L0E`000eL03U/0HWoo00<007ooOol01goo0004Ool00`00Oomoo`1UOol<Hb05H`0A
G`0<F^06E^05E/06D/0;CZ03BX030002AX0`On04Mj05H`03CF000bb09@0Ph0048>0011bP6:0HX1RP
0aR000<DP11P4600111P1`aP0PAP2PQP2QQP1RCP1bT01c6P23G02SXP1ci02D:01d:P14JP34[024kP
3e;P2EL000<005L0E`000eL03e/0H7oo00<007ooOol01goo0004Ool00`00Oomoo`1VOol<Hb05H`0A
G`0<F^06E^05E/06D/09CZ040003BX03AX0/On05Mj05H`03CF039B038@048>047<03680358034602
58023602460636042606460556068<069>07;F08<J08=P08>R07?V08@X07@Z0@B/08C^0?D^08E`00
0`00E`1G0004E`0>F`1OOol00`00Oomoo`07Ool000Aoo`03001oogoo06Moo`aS80ES015O00aJh0EF
h0IF`0I>`0A>X0@000=:X0I6P092H2eoh0IS00==H0@Y@0@U008Q00<Ph0@L`0@HX08DP08HP0@DP0P@
H0<<H0X@H0HLX0DP`0LY@0L]H0Leh0Tf00Lj@0LnH0M2P0Q6X0m:`0Q>h0iBh0QG0003001G05L000AG
00mK05eoo`03001oogoo00Moo`0017oo00<007ooOol0J7oo36<P1F<04El02e[P1eKP1U;01Dk00`00
0djP1DZP1TJ00T9P;GoP0f<00deP00<Y@2E09D000bU00bDP0bD00R400R3P11c01ARP0aR00aRP0aB0
0aAP111P11AP1A1P1AR01QbP1RD01bU01S6P1cGP13H013XP1cY023iP1d:01dJP3T[024kP3e;P1eL0
00<005/0F`004e/0G7oo00<007ooOol01goo0004Ool00`00Oomoo`1XOol=Hb05H`0AG`07F^0;E^06
D/0400000dk0CZ1>X004CZ06BZ05AX02@V0]On02CF000eUP:D0Y@002:D029B029D069B028@048>00
0acP7<0L`0027<0;6:0468000aAP580DP0055802560:68079>069@06;H06<J06=N08>R07>T04?V0;
@X07AZ07B/07C/08C^0>D^07E`000`00F`1K000CF`1KOol00`00Oomoo`07Ool000Aoo`03001oogoo
06Uoo`eS80ES00aO00IK00IJh0]Fh09B`0<00003D/1>`4k000=>`0I>X0I:X0E6P092H2eoh003FF0Y
@2U000@Y@0TU80@Q00@Ph0LL`0036:0LX1bP00HHX08HP08HX0@DP0@HX0PHP0DPh0LTh0HYH0H]P0Da
X0Lf00Lj80Lj@112P0I6X0M:`0M>`0M>h0iBh0MG0003001K05/001AK05Uoo`03001oogoo00Moo`00
17oo00<007ooOol0JWoo36<P1F<03El01U/01U[P25KP10001E;01Dk01TjP1dJ01D:000<nH7oPOn00
:GoP00AIH2UP:F0YH0@Y@0@U80DU00HQ00<Ph0LL`08LX0<L`14HX0<HP0HL`0DPh0HY@0HYH0H]P0He
h0Lf00Hj80LnH112P0I:X0M:`0M>`0M>h0MBh0MFh0IG0003001K05/001AK05Qoo`03001oogoo00Mo
o`000goo00<007ooOol0K7oo36<P4Ul01U/01U[P15KP0`0015KP1U;01Dk01dZP1TJ01D:00SiP:7oP
00=IH2U0:D000bU022DP1BD01B401B3P0QcP2Qc02AbP11RP3Ac01RDP1BU01RUP1c701SGP1SH01SY0
1ciP34:014JP1TZP1d[01dk01TkP25;P1UKP1UL000<005/0F`0055/0Egoo00<007ooOol01goo0003
Ool00`00Oomoo`1/Ool=Hb0BG`06F`05F^040008E^0<C/06BZ06AX05@X02?V0VOn000`00:D0Y@005
:D059B039@098@068>027>027<000acP7<0L`00<7<027:0=7<069@069B04:D06;J07<L06=N06>R06
>T07?V07@X08AZ07BZ07B/06C/0>D^06E^06E`000`00E`1K000=F`07G`1FOol00`00Oomoo`07Ool0
00=oo`03001oogoo06ioo`aS819O00IK0004F^0000000002F^05E^07D^0;C/06BZ06AX05@X02?V0S
On0015UP:F0YH2UP12U022DP22402R3P0QcP00<L`1cP7>000QcP51c02B3P1RD01BU01BeP1BfP1c70
1cH01CXP1SY01ciP1d:024JP1dZP1T[01e;03E;P1eKP1EL000<005L0F`002E/02el0EGoo00<007oo
Ool01goo0003Ool00`00Oomoo`1_Ool<Hb0BG`02F`040007E^0;D^0<C/05BZ06AX06?V000ci0On1o
h00OOn000eUP:D0Y@004:D0;9B088@0=8>097>087<057>0<8>069D05:D06;F04;J07=N07=P05>R06
>T07@V07@X07AZ07BZ07C/06D/0=D^07E^05E`000`00E`1K0005F`0?G`1DOol00`00Oomoo`07Ool0
00=oo`03001oogoo071oo`aS811O00<000IK00IFh0aBh0]>`0E:X0M2P0HnH1moh004FF0YH2UP:F05
:D089B088@0K8>0;7>058@049@049B069D05:D06;J04<L07=N07=P04>R07?V07@V07@X06AZ08B/06
C/06D/0=D^07E^05E`000`00E`1K0005F`0?G`1DOol00`00Oomoo`06Ool000=oo`03001oogoo075o
o`aS80]O00@000YK00IFh0aBh0I>`0I:X0E6X0I2P0HnH1moh004;H0YH2UP:F069B049@048@0_8>04
8@049@049B06:F05;H06;J04<L07=N07>R04>T07?V07@V06@X07BZ07B/06C/07D/0<D^07E^05F`00
0`00F`1K0005F`0?G`1COol00`00Oomoo`06Ool000=oo`03001oogoo07=oo`]S80IO0004F`000000
000?F`07E^0;D^07C/06BZ05AZ06@X05?V0MOn04:F04:D059B049@038@048>0;7>0H8>088@099B04
:D06:F05;H05;J05<L07=P06>R05>T07?V06@V07AZ06BZ07B/06C/07D/0<D^07E`05F`000`00F`1K
0005F`0?G`1BOol00`00Oomoo`06Ool000=oo`03001oogoo07Aoo`]S809O00@00003G`1K05/0015K
00IFh0IBh0e>`0E:X0I6X0E2P0DnH1aoh003;H0YH2UP00<YH0@Y@0dPh0HLh0DL`0LLh0lPh0`Q00XU
80@Y@0DYH0D]P0Ha`0Deh0Hf00Lj80Dj@0HnH0M2P0I6X0I:X0M:`0I>`0MB`0IBh0IFh0MG00EK0003
001K05/000EK00mO055oo`03001oogoo00Ioo`000goo00<007ooOol0MGoo1V<P0elP0`001Ul04e/0
1UKP1e;P34k01TZP1DJP2SiP6goP0bf01RDP0bD0223P51c011cP2B3P0R400R3P2B402BDP1BU012UP
1Bf01C6P1S701CGP1CH01cXP1CY01d9P1T:01dJP1DZP1d[01Tk01e;P35KP1eL015/000<005/0F`00
1U/03el0D7oo00<007ooOol01Woo0003Ool00`00Oomoo`1fOol4Hb040004Gb07G`0BF`07E^07D^0<
C/05BZ07@X08?V0IOn000c6P:D0Y@004:D069B029@0=7<046:0;7<037>000ac07>0Lh0058>098@05
9@099B05:D04:F05;H05<J06<L05=N05=P08>T05?V06@V06@X07AZ05BZ07B/06D/07D^0<E^07E`04
F`000`00F`1K0006F`0>G`1@Ool00`00Oomoo`06Ool000=oo`03001oogoo07Moo`<000AS80IO80IO
00eK00IG00MFh0IBh0a>`0I6X0Q2P0HnH1Qoh0@]H0HY@0HPh0TL`0PHX0@LX0/L`0<Lh0<Ph0HQ00@U
00XU80@Y@0DYH0T]P0DaX0Heh0Hf00Dj80Lj@0DnH0M2H0E2P0M6X0E:X0M>`0IB`0MBh0aFh0MG00AK
0003001K05/000IK00MO00MO84moo`03001oogoo00Ioo`000goo00<007ooOol0Lgoo10000Woo1f<P
1ElP1el03E/01UL01eKP1U;P1Tk01d[01DJP24:01CiP5WoP0bf01BeP1RCP1B3P0Qc01AR011RP11B0
1QRP0ac00QbP1Ac00acP123P12400bDP0RD01BDP1BE02BUP1Bf01BfP1C701CGP1SH01SXP1SY01CiP
1d9P1D:01dZP1TjP1Tk01U;01e;P35KP1eL015/000<005/0F`001U/01el01elPCWoo00<007ooOol0
1Woo0003Ool00`00Oomoo`1`Ool30008Ool6Hb06Gb06G`0>F`05E`08E^05D^08C/06B/05AZ09@X04
?V0DOn05;H069B069>0;68045603580568036:027:036:067<000acP8>0Ph0028>038@0:9B05:D04
:F0:;H05;J05<L05=N06=P06>R06>T05?V07@X05AX07BZ06CZ06C/06D/07D^0<E^07E`04F`000`00
F`1K000=G`06Gb1>Ool00`00Oomoo`06Ool000=oo`03001oogoo06aoo`@000aoo`MS80EO80IO00iK
00IG00MFh0M>h0M>`0I:`0E6X0U2P0<nH1=oh08a`0LY@0DU80HLX0HHP0D@H0PDH0@DP0LHX0DL`08L
h0@Ph0<U00TU80DY@0@YH0D]P0D]X0Da`0Dah0Deh0Hf00Hj80Hn@0I2H0I2P0E6P0M:X0I>X0I>`0IB
`0MBh0aFh0]K0003001K05/000aO00MO84eoo`03001oogoo00Ioo`000Woo00<007ooOol0JWoo0`00
4Woo1V<P35lP3U/01UL00eKP15;P1dkP1dk01T[01T:P24:00SiP4GoP1bf01RU01R301AbP4Q1P0QB0
0aAP0QR01aRP00<L`1cP7>000R3P0b400bD00RDP0bU00RDP1BU01BUP1Bf01BfP1C701C7P1SH02cXP
1Si01T9P1T:01DJ01dZP1TjP1Tk01U;01e;P1UKP1U[P2e/000<005/0G`0035l01elPC7oo00<007oo
Ool01Woo0002Ool00`00Oomoo`1VOol4000FOol6Hb0=Gb0>F`05E`08D^08C^06C/07AZ06@Z07@X02
>T0?On04<J07;H099>028<0556054604260636024603560246000aR0580DP00258036:047<028>03
8@039@03:B03:D05:F05;F05;H05<J05<L05<N06=P0;>R06?T06@V06@X05AX07BZ06CZ06C/06D/0=
E^06F^0;F`000`00F`1O000<G`06Gb1<Ool00`00Oomoo`06Ool0009oo`03001oogoo06=oo`<001]o
oaAO80eK00MG00MBh0Q>h0M:`0M6X0I2X0LnH0eoh0<eh0HaX0/Y80DLP0HDH0P8H0@4H0D<H0<@H0DD
P003680HX1RP00@L`0<Ph0<Q00@U80<Y80HYH08]P0<]H0D]P0DaX0Da`0Deh0Hf00/j80Hn@0I2H0I2
P0E6P0I:X0M>`0aB`0eFh0IJh0]K0003001K05l000]O00MO84]oo`03001oogoo00Ioo`000Woo00<0
07ooOol0Ggoo100087oo55lP1e/03UL01U;P2DkP1T[024JP1d:013iP37oP00<j03GP=N0013GP2beP
1R2P1Ab02@QP101P0`AP0PQP1@aP0Q1P0aB00QR00QRP0ac00b3P0bD01RDP1RUP2bf02S701CGP1SH0
1SXP1Ci01T9P1TIP1TJ01DZP1TjP1dk035;035KP1e[P2e/000<005l0G`002el01elPBWoo00<007oo
Ool01Woo0002Ool00`00Oomoo`1LOol3000VOolDGb08F`0>E`05D^09C^07B/09AZ06@X02?V0:On06
>P0;<J06:>068:0946040404060304000`QP360<H002360010a0460@H11P0aR00aRP0QbP00@L`23P
8>0Ph08U00@U80<Y@0@YH0H]P0DaX0Ha`0Xeh0Hf00Dj80Hn@0I2H0I6H0I6P0E:X0I>X0I>`0eB`0aF
h0MJh0]K0003001O05l000]O00IO84Yoo`03001oogoo00Ioo`000Woo00<007ooOol0F7oo1000:goo
4elP2E/03UL01U;P2DkP1T[02TJP1T:02GoP0ci023GP1C6P1Re01BSP2QAP201P1P100`A00`a01A1P
00<DP1RP6:000QbP0Qc00b3P0RD00RDP1BU00RUP1Rf01S6P1C701SGP2cH01CXP1Ci01T9P1TIP1TJ0
1TZP1DjP1dk03E;035KP1e[P2e/000<005l0G`002Ul01f<PBWoo00<007ooOol01Goo0002Ool00`00
Oomoo`1EOol3000`Ool>Gb07Fb08F`0:E`05D`06D^08C^08B/09AZ04?V08On02?T06>R07=N0;;D0:
880:46033004040214000`10340<@0023403460358027:027<038>029@03:B05:D06;H06<J05<L06
=N06=P06>R04?R06?T06@V06AV06AX06BZ05CZ07C/0=D/0<E^06F^0<F`000`00G`1O0004G`06H`06
Hb1:Ool00`00Oomoo`05Ool0009oo`03001oogoo055oo`@003Eoo`iO80MK80QK00IG00YC00IBh0A>
h0E>`0M:`0E6X0I2P0Ioh08nH0`j80`eP0XX`0XPP0Le008P00@0@0D<@0DDP08HX08L`08Ph0039@0U
82DP00<Y80<Y@0<]H0<]P0HaX0Ha`0Deh0Hf00Hj80Dn80E2@0I2H0I6H0I6P0I:X0I>X0I>`0eB`0aF
h0MK00aO0003001O05l000=O00IS00MS84Uoo`03001oogoo00Eoo`000Woo00<007ooOol0CWoo0`00
>goo3UlP25/P1e/01eL02U<01E;P2dk01T[02D:01GoP23i01SXP2cWP2S4P2cE01SD0147000<P0010
040010100Pa00a1P0QB00QRP0Qc00R3P0RD00RDP0bTP1beP1S6P1S701SGP1CX01cXP1ChP1D901TIP
1TJ01TZ02djP1e;01UK01eKP35[P1U/03El000<005l0G`000el01V<01V<PBGoo00<007ooOol01Goo
0002Ool00`00Oomoo`1:Ool4000oOol?Gb08Fb08F`07E`09D`07C^0;C/08A/04@X03On07@X07?T0;
>N0;=J0;=D06@L06BX000f]P0400@00304000`A0340@H002460256026:027<028>039@000bDP:D0Y
@002:D05;F06<J07<L05=N06>P06>R06?R05@T06AV06AX05BX0<CZ07D/06E/06E^0<F^07F`0=G`00
0`00G`1O0002G`06H`07Hb18Ool00`00Oomoo`05Ool0009oo`03001oogoo04Moo`<004Ioo`iO80QK
80UK00MG00UC00Q>h0I>`0E:`0U6`09oh0a2P0`n80`n00/mh0I:P0MG00=[H0<0@084@0<@H0<DH08H
P0037<0Ph23P00@U00DY@0<]H0HaX0La`0Deh0Lj00Hj80Dn@0I2@0E6H0I6P0I:P0a>X0IB`0IF`0MF
h0aJh0IK00iO0003001O05l0009O00IS00IS84Qoo`03001oogoo00Eoo`000Woo00<007ooOol0@goo
1000Bgoo3UlP2E/P25/025L02E<02DkP2d[01DK01dJP1T:0349P33h0349P3EL01G>P00@/00101404
@0<8@0<DH08HP08L`08Ph0<U00HY@0@]P0<aX0La`0Heh0Hj00Hj80Hn@0E2H0I6H0I6P0E:P0a>X0MB
`0IF`0IFh0aJh0MK00iO0004001O05l0G`06H`07Hb17Ool00`00Oomoo`05Ool0009oo`03001oogoo
041oo`<0055oo`iO80UK80UK00QG00UC00Y>h0Y:`0i6X1U2H0a>`0MG00IO@0AcX0=g`0030200@0A0
00<8@0<@@08HP0<L`08Ph08U00<Y@0@]H0D]P0La`0Heh0Hj00<n80<j80Hn@0I2H0E6H0I6P0I:P0a>
X0IB`0IF`0MFh0aJh0IK00mO0004001O05l0G`06H`06Hb17Ool00`00Oomoo`05Ool00003Ool007oo
03ioo`@005Moo`mO80QK80QK00UG00UC00]>h1=:`1Y6X0a>`0eO@0Qg`003Nn00@01000<8@0<@@08H
P0<L`08Ph08U00P]H0<]P08aX0@a`0Leh0Hj00Hn80Hn@0I2H0I6H0I:P15>X0MB`0IF`0IFh0aJh0MK
00mO0003001O05l000IS00MS84Ioo`03001oogoo00Eoo`0000=oo`00Ool0>goo0`00GGoo45lP1e/P
15/01e/P1eL03E<024kP3T[03DkP3DJP3EL01em01fN017O01W_P00@080100400@0<@@08HP0<L`0<U
008Y80P]H0DaX08a`0Leh0Hj00Hn80I2@0I2H0I6H0I:P0I>X0IBX0IB`0aF`0IFh0aJh0MK011O0003
001O06<000ES00MS84Ioo`03001oogoo00Eoo`0000=oo`00Ool0=goo1000HWoo4ElP4e/P1UL045<0
:TkP3EL03VN027_P17oP00@08010040<@08@@08HP0<L`0<U00<Y80@]H0TaX0Leh0Hj00Hn80M2@0]6
H0M:P0E>X0IBX0IB`0eF`0aJh0INh0eO00YS0003001S06<P00ES80MW84Eoo`03001oogoo00Eoo`00
00=oo`00Ool0=7oo0`00JGoo4ElP55/P2EL045<01dkP3U<03DkP3U]01fN01f^017_P2GoP0P0P00<0
@0a034000aR00ac00bD012TP13601S6P0cG01CGP0Sh013X01ShP1d901TIP1DYP1dZ01TjP1E:P1U;0
3EK035[P1UkP3El02f<000<006<PHb0016<P1fLPAGoo00<007ooOol01Goo00000goo001oo`0`Ool4
001_OolBGb0EFb0;E`0ND`0=E`0>Fd0>Jh0?On020203340258037<039@05;D03<H04<J06=L03=N04
?P02>P06?R04AT03@T06AV06BV06CX06CZ06DZ06D/0<E/0<F^07G^0<G`0<H`000`00Hb1S8003Hb07
Ib15Ool00`00Oomoo`05Ool00003Ool007oo02eoo`<007Iooa9O81IK80IG00QG80MC00mG80iG00iS
H0M[P0Q_X0moh08080<<@0<DP0<P`0<Y00@]@0@aP08aX0Pe`0Ln00Hn80M6@0I6H0I:H0I>P0aBX0IB
`0eF`0]Jh0MNh0aO00eS0003001S86<P00=S80IW84Eoo`03001oogoo00Eoo`0000=oo`00Ool0:Goo
1000O7oo4elP5U/P85LP3U/P3V=P3fnP47oP0P0P0`Q00aB00b300bT012e0136023G023h00d8P0chP
1dI034YP1Tj01U:P1UJP1U;03EK035[P1UkP3El036<000=S8000Hb000f<P1VLPAWoo00<007ooOol0
17oo00000goo001oo`0VOol30022OolDGb0KFb08Eb0MFb0?If08Kj07Lj0AOn020203240366038<03
:@04;D05<J05=L09?P06@R07AT06BV03CV03BV06CX06DZ07EZ0BE/0<F^07G^0<G`0<H`000f<P001S
8003Hb07Ib15Ool00`00Oomoo`04Ool00003Ool007oo029oo`@008Uoo`mO80IO@2aK80mO@0mWH0mc
X19oh08080<8@0<HH0<Th0<Y00DaP0DaX08e`0<mh0Hn00M280M6@0I:H0I>H0I>P0IBX0MFX0IF`0IJ
`19Jh0MNh0aO00eS0003Hb0006<P00=S80IW84Eoo`03001oogoo00Aoo`0000=oo`00Ool07goo0`00
TGoo2UlP35m01U/P2Em025/P7Um046^01g>P2GO04WoP00D0000P1404@0Q000<HH0@Th0<]@0@aP0Da
X0Hmh0<n00Q280I6@0M:H0I>H0IBP0IBX0MFX0IF`0IJ`0IJh1=Nh0aO00eS009S8004001S86<PHb06
Ib15Ool00`00Oomoo`04Ool00003Ool007oo01]oo`@009Qoo`EO83=O@0mSH0m[P15g`1=oh0030000
80A00084@0<HH0@Th0<]@0DaP08aX0<i`0Hmh0Q280M6@0=>H0A:H0I>H0IBP0=FX0=BX0MFX0IF`0IJ
`0IJh0eNh1mS00=S8003001S86<P00IW84Eoo`03001oogoo00Aoo`0000=oo`00Ool067oo0`00Wgoo
95m046=046=P3f^04GO057oP00<0000P14000PA00Qb000<HH2CP9>000RCP12e013601CW01CgP0T80
1T8P0TY01DI03DiP1U:03EJP1UK01U[01U[P3EkP4f<036L016LP00<006LPIb001FLPAGoo00<007oo
Ool017oo00000goo001oo`0DOol4002XOolMGd0AHd0@If0?Jh0AMl0BOn03Ool00`001404@0021403
78049>04;D05=J05>L02?N05@P03@R05BT03AT06CV04DV03CV06DX06EZ07FZ06E/06F/06F^0=G^0C
H`0<I`05Ib000`00Ib1W8005Ib14Ool00`00Oomoo`04Ool00003001oogoo015oo`<00;5oo`IO@0US
@0UO@11SH11WH11_P15g`0eoh0Uoo`03000880A00084@0<LP0@Y00DaH0@eX0Di`0Q200Q:@0M>H0MB
H0IBP0IFX0MJX0aJ`0IJh0eNh1=S00aW00IW8003001W86LP00AW84Aoo`03001oogoo00Aoo`0000<0
07ooOol03Goo1000^7oo00<006=0Hd0046=04F=P46MP46n04WO01WoP47oo00<000PP22000PA00ab0
12T01C5P13FP0cW00d7P1T800TXP1TY00di014iP1e9P1UJ01UJP1eZP1U[01Uk01U[P3EkP4f<036L0
1fLP00<006LPIb000fLPA7oo00<007ooOol017oo00000`00Oomoo`0:Ool3002lOol00`00Oomoo`04
Ool<Hd08If09Hf0@If0@Kh0BMl0GOol01000220880PP11b012T01C5P13FP1d7P0d801DXP0dY01di0
1e9P1eJ00eZP0eJP1eZP1U[01Uk04ekP4f<036L026LP00<006LPIb000VLPA7oo00<007ooOol017oo
00000`00Oomoo`06Ool4002oOol00`00Oomoo`09Ool6Hd0RIf0@Kj09Ml0QOol01000220880PP0RBP
0Qb012T01C5P1D701d7P24XP24i00eIP159P1eJ03EZP1U[01Uk01UkP1f;P1UkP4f<036L02FLP00@0
06LPIb1W84Aoo`03001oogoo00Aoo`0000<007ooOol00goo0`00`goo00<007ooOol03Woo4VMP4F^0
46nP:Woo00<000PP22000PPP0bBP1BT01CV01D701D7P0dX01TXP0U901Di01eIP1eJ01eZP0ejP15ZP
1U[01Uk01UkP3F;P1VL03F<036L02VLP00<006LPIb00A7oo00<007ooOol017oo00000`00Ool00003
0036Ool00`00Oomoo`0OOolAJh0lOol01000520880PP12BP1C501CV01T700T7P1DX014XP1E900di0
1eIP0eZ015J01eZP1UjP1e[01Uk01UkP3F;P36L01f<036L02fLP00<006LPOol0@goo00<007ooOol0
17oo0002003:Ool00`00Oomoo`1/Ool3520222049:05<D05>H06@L07BP02BR08DT08EV06FX07FZ07
GZ0=G/06G^0=H^0OI`0<Ib000`00Oomoo`12Ool00`00Oomoo`04Ool00003Ool007oo0<Uoo`03001o
ogoo06aoo`03520001@P008D8003220TX2BP008TX0Da@0DiP0=1`0Y:00UB@0MFH0MJP0=NX0AJX0MN
X0IN`0MR`0INh0eRh1UW00e[80IW8003001oogoo049oo`03001oogoo00=oo`000Woo0P00b7oo00<0
07ooOol0K7oo1Q@P1BBP1C501CV02dX00eI01U9025IP1eZ03UjP1Uk01f;00f;P0ekP3F;P6FL04f/P
00=oo`00Ool0@Woo00<007ooOol00goo0004Ool00`00Oomoo`35Ool00`00Oomoo`1]Ool65204<>05
<D07BL08BP06ET03DT08EV07FX07GZ04HZ04GZ06G/07H/0CH^0II`0CJb02Ool00`00Oomoo`10Ool0
0`00Oomoo`03Ool000Eoo`03001oogoo0<Aoo`03001oogoo06eoo`LD80@`h0E1P0M9`0I:00UF@0UF
H0=NP0AJP0MNX0MRX0MN`0MR`0IRh0IVh0MRh1UW01=[80=oo`03001oogoo03moo`03001oogoo00=o
o`001Woo00<007ooOol0`goo00<007ooOol0KGoo0Q@P00<002b052000Q@P1C3P1D601dW00dX015HP
1UI00eYP1UIP1ej01ejP26:P0fK015k01V;01f;P1VKP86L04f/P17oo00<007ooOol0?Woo00<007oo
Ool00goo0007Ool20033Ool00`00Oomoo`1]Ool35203;8025205<>05@H07BL07ER04ET06FV03EV08
GX02HZ05GZ07HZ07I/07H/07H^06I^06I`06J`0DI`0BJb06Ool00`00Oomoo`0mOol00`00Oomoo`03
Ool000Uoo`03001oogoo0<1oo`03001oogoo06eoo`<D8003000/P2b0008/P003520`h33P00<`h0E1
P0A9`0=F00MF809F@0UJH0QNP0ERX0=NX0MRX0YV`0AR`0IRh0MVh0IW00e[00eW019[80Moo`03001o
ogoo03aoo`03001oogoo00=oo`002Woo00<007ooOol0_goo00<007ooOol0KGoo11@P1Bb01S3P1D60
1eH01eHP2EYP0f9P1Uj03V:P3VK01f;P1VKP1fL04f/01fL04V/P27oo00<007ooOol0>goo00<007oo
Ool00goo000;Ool2002oOol00`00Oomoo`1^Ool35206;805CF06EL07EP05ER03GT06FV06HV03GX08
HZ03IZ04HZ0>I/03J^04H^06I^06I`0DJ`0IJb09Ool00`00Oomoo`0jOol00`00Oomoo`03Ool000eo
o`03001oogoo0;aoo`03001oogoo06ioo`@D80D/P0I=H0IE`0MF00=F80IN@0=JH0URH0QRX0MVX0mV
`0IZh0MVh0IW01A[00I[80I_80e[80Yoo`03001oogoo03Uoo`03001oogoo00=oo`003Woo00<007oo
Ool0^goo00<007ooOol0KWoo11@P1Rb01TeP1UG01eH02Ui02F9P0fJ01F:P26JP0V[036K03F[P1fL0
4f/01f/P36lP1V/P37oo00<007ooOol0>7oo00<007ooOol00goo000?Ool00`00Oomoo`2jOol00`00
Oomoo`1^Ool55205;806CF07EL05EP03HR07GT03IV06HV06IX02HZ08IZ05J/0:I/0=J^03K`04I`0C
J`06Jb0CKb0=Ool00`00Oomoo`0gOol00`00Oomoo`03Ool0011oo`800;Yoo`03001oogoo06ioo`DD
80H/P0I=H0ME`09F00IR80EN@0EVH0ARH0QVP0QVX0QZ`0MV`0eZh0M_01A[00I[81=_80ioo`03001o
ogoo03Ioo`03001oogoo00=oo`004Woo00<007ooOol0]goo00<007ooOol0KWoo1A@P1Rb01TeP1eG0
2F8P0ei01fIP0V9P2FJ00VjP1VJP26[00fk016K03F[P3Fl03F/01f/P4flP3Woo00<007ooOol0=Woo
00<007ooOol00goo000COol00`00Oomoo`2fOol00`00Oomoo`1^Ool65202KF04;806CF03EL04IP09
HR0:IV09IX05KZ03IZ08J/07K/0=J^0DK`07J`06Jb0CKb0@Ool00`00Oomoo`0fOol00`00Oomoo`02
Ool001Aoo`03001oogoo0;Eoo`03001oogoo06moo`DD80A]H08/P0I=H0QV00MR809^@0QVH0=^P0IV
P0Q^X0QZ`0Q^`0=^h0YZh1A_00=_80A[00I[81=_815oo`03001oogoo03Eoo`03001oogoo009oo`00
5Goo0P00]Goo00<007ooOol0L7oo11@P1VeP1fW026H01F8P16i01VIP1Fj01FJ026jP0Vk01V[01fk0
1VkP1f[P5Fl01VlP1f/P4flP4Woo00<007ooOol0=7oo00<007ooOol00Woo000GOol00`00Oomoo`2b
Ool00`00Oomoo`1`Ool45207KF07JL08IP03HR06KT04IV08KX02IX08KZ05K/03J/07K/07K^03L^04
J^0DK`07Kb06Lb0CKb0DOol00`00Oomoo`0cOol00`00Oomoo`02Ool001Qoo`03001oogoo0;5oo`03
001oogoo075oo`@D80I]H0MY`0UV00U^@09VH0Y^P0Q^X0m^`0M^h0Mbh1E_00I_80ec80e_81Eoo`03
001oogoo039oo`03001oogoo009oo`006Goo00<007ooOol0/7oo00<007ooOol0LWoo0a@P1VeP26W0
1fH00WI02Fi02Vj00g:P1FjP2Fk00g;P0fk026kP1g;P1W<03Vl01flP4g<P1flP5Woo00<007ooOol0
<Goo00<007ooOol00Woo000JOol2002`Ool00`00Oomoo`1bOol35207KF07JL05IP05MT07KT03MX07
KX06LZ02KZ09K/06L^08K^07L^0:L`0;K`06Kb0DLb06Ld0HOol00`00Oomoo`0`Ool00`00Oomoo`02
Ool001aoo`03001oogoo0:eoo`03001oogoo07=oo`8D80M]H0QY`09V00Qf@0A^@0IfP0E^P0QbX0U^
`0Mbh09fh0I^h0Mbh0ec00M_00M_81=c80Mc@1Uoo`03001oogoo02moo`03001oogoo009oo`007Goo
00<007ooOol0[7oo00<007ooOol0Lgoo0Q@P1feP26W02gI00Vi027J00fj027:P0gK01Vk01g;P1GKP
0fkP1g;P3W<00g<P16l01VlP57<P1W=06goo00<007ooOol0;Woo00<007ooOol00Woo000NOol00`00
Oomoo`2[Ool00`00Oomoo`1dOol25207KF05JL03OP0:MT0;MX09LZ06M/03K/07L^08M^08L^0=L`07
Lb07Kb0CLb07Ld0LOol00`00Oomoo`0]Ool00`00Oomoo`02Ool001moo`800:]oo`03001oogoo07Eo
o`03521]H6eP00E]H0=Y`0In00Qf@09nH0UfP0=nX0IbX0Uf`0Qbh0Qfh0=g00Abh0ic00Mc80Ig81Ac
80Ic@1ioo`03001oogoo02aoo`03001oogoo009oo`008Goo00<007ooOol0Z7oo00<007ooOol0MGoo
00<D86ePKF001FeP2Wh01WI017iP1gJ01GjP17:P2GK00g[P1G;P27KP1gL03W<01g<P2WLP47<P1g=0
7goo00<007ooOol0:goo00<007ooOol00Woo000ROol00`00Oomoo`2WOol00`00Oomoo`1fOol4KF0>
OP04MT06OV05MX07OZ02LZ09M/06N^02L^08M^08M`03N`0:L`08Lb0=Mb0=Lb06Ld0QOol00`00Oomo
o`0ZOol00`00Oomoo`02Ool002=oo`800:Moo`03001oogoo07Iooa=n009f@0QnH0=fP0UnX0Uf`0Qj
h0Qfh0Qg00Ik00Qc00Mc81Ag80Ic80Mc@29oo`03001oogoo02Uoo`03001oogoo009oo`009Goo00<0
07ooOol0Y7oo00<007ooOol0MWoo4gh02giP2WjP0gk01WK027[P0gkP1GKP27L01g/00g/P17<01g<P
5GLP0gM00g<P1W=097oo00<007ooOol0:Goo00<007ooOol00Goo000VOol00`00Oomoo`2SOol00`00
Oomoo`1fOolBOP0;OV0:OZ06O/03M/08N^06O^02M^08M`07N`07Nb08Lb0DMb06Md07Ld0UOol00`00
Oomoo`0XOol00`00Oomoo`01Ool002Moo`03001oogoo0:9oo`03001oogoo07Eooa5n00anH0YnX0Qn
`0Ujh0Qnh0Qg00Mk00]k80Ac81Ag80eg@2Moo`03001oogoo02Moo`03001oogoo005oo`00:7oo0P00
XGoo00<007ooOol0MWoo47h037iP2WjP27k00gkP1W[P2GkP0gl017L01g/03g/P57LP3WM0:7oo00<0
07ooOol09Woo00<007ooOol00Goo000ZOol00`00Oomoo`2NOol00`00Oomoo`1eOol?OP0=OV0:OZ08
O/06O^03N^09O^07O`08N`0BNb0AMb0=Md0ZOol00`00Oomoo`0UOol00`00Oomoo`01Ool002]oo`03
001oogoo09eoo`03001oogoo07Eoo`en00inH0YnX0Qn`19nh0Yo00Ek01Ek80ig80ig@2]oo`03001o
ogoo02Aoo`03001oogoo005oo`00;7oo00<007ooOol0W7oo00<007ooOol0MGoo3Gh000=n@7iPOV00
2GiP2gjP27k027kP0gl01gkP3Gl00W/05W/P0g]02WLP3WM0;Goo00<007ooOol08goo00<007ooOol0
0Goo000]Ool2002LOol00`00Oomoo`1dOol=OP03OT09OV0;OZ08O/08O^05O`05O^0?O`0FNb07Nd06
Mb0>Md0_Ool00`00Oomoo`0ROol00`00Oomoo`01Ool002moo`03001oogoo09Uoo`03001oogoo07Ao
o`an00An@0QnH0YnX0Un`0Qnh0Qo009nh0mo00Ao819k80ek@0mg@31oo`03001oogoo025oo`03001o
ogoo005oo`00<7oo00<007ooOol0V7oo00<007ooOol0Lgoo37h01Wi01GiP2gjP2Gk027kP6Gl01glP
3g/P4G]02gM0<Woo00<007ooOol087oo00<007ooOol00Goo000aOol00`00Oomoo`2GOol00`00Oomo
o`1cOol;OP07OT04OV0;OZ09O/08O^0IO`0;Ob0;Nb0ENd08Md0cOol00`00Oomoo`0OOol00`00Oomo
o`01Ool0039oo`8009Moo`03001oogoo079oo`]n00Un@09nH0YnX0Yn`0Qnh1Uo00mo80Mk81Uk@0Ag
@3Aoo`03001oogoo01moo`03001oogoo005oo`00=7oo00<007ooOol0U7oo00<007ooOol0LWoo2Wh0
2Wi02gjP2Wk027kP4Gl00glP1Gl03glP17m00g/P7G]0=Woo00<007ooOol07Woo00<007ooOol00Goo
000eOol00`00Oomoo`2COol00`00Oomoo`1bOol9OP0;OT0:OZ0:O/08O^0AO`06Ob02O`0?Ob07Od0M
Nd0hOol00`00Oomoo`0MOol00`00Oomoo`01Ool003Ioo`03001oogoo099oo`03001oogoo075oo`Yn
0003OV1n@7i000Mn@0YnX0Yn`0Qnh15o01Mo80]o@1Uk@3Yoo`03001oogoo01eoo`40005oo`5oo`00
=goo0P00TWoo00<007ooOol0LGoo2Wh000=nH7i0OT001Wi02WjP2Gk02GkP4Gl05glP3Wm05W]0?7oo
00<007ooOol077oo0@000Goo0Goo000iOol00`00Oomoo`2?Ool00`00Oomoo`1`Ool:OP02OV07OT0:
OZ09O/02O`07O^0AO`0GOb0BOd0BNd0nOol00`00Oomoo`0KOol10001Ool1Ool003Yoo`03001oogoo
08ioo`03001oogoo071oo`Yn00=nH0En@0YnX0Un`0Ao00Enh0Uo00=o80Eo01Mo81Io@0ik@41oo`03
001oogoo01Yoo`40005oo`5oo`00>goo0P00SWoo00<007ooOol0Kgoo2gh00giP1Gi027jP2Wk01Wl0
0gkP2Gl01GlP0gl047lP17m00glP6Wm02W]0@Woo00<007ooOol06Goo0@000Goo0Goo000mOol00`00
Oomoo`2;Ool00`00Oomoo`1`Ool9OP04OV04OT09OZ000gkPO/1n`006O/08O`000gkPO`1o0007O`0H
Ob0TOd07Nd14Ool00`00Oomoo`0HOol10001Ool1Ool003ioo`03001oogoo08Yoo`03001oogoo071o
o`Un00EnH09n@0UnX0=nh0In`15o00Qo80=o@0io82Ao@0AoH0=k@4Ioo`03001oogoo01Moo`40005o
o`5oo`00?goo00<007ooOol0RGoo00<007ooOol0L7oo27h01WiP00=n@7jPOZ001gjP1GkP17k02Gl0
0glP1Gl027lP1Wm02glP97m01gmPB7oo00<007ooOol05Woo0@000Goo0Goo0010Ool20029Ool00`00
Oomoo`1`Ool8OP06OV09OZ07O^02O/09O`05Ob03O`08Ob08Od09Ob0TOd07Of1:Ool00`00Oomoo`0E
Ool10001Ool1Ool0049oo`03001oogoo08Ioo`03001oogoo071oo`Qn00InH003O^1nX7jP00EnX0Qn
h0Yo011o80]o@0Io80mo@0AoH15o@0MoH4aoo`03001oogoo01Aoo`40005oo`5oo`00@goo00<007oo
Ool0QGoo00<007ooOol0L7oo1gh01WiP0WkP1WjP2GkP00=o87l0O`001Gl027lP0Wm01glP3Wm00glP
3gm01gmP3Wm01gmPCWoo00<007ooOol04goo0@000Goo0Goo0014Ool00`00Oomoo`24Ool00`00Oomo
o`1aOol6OP06OV03O^04OZ09O^03Ob05O`08Ob04Od05Ob0POd0;Of0:Od07Of1@Ool00`00Oomoo`0B
Ool10001Ool1Ool004Eoo`8008Aoo`03001oogoo075oo`En00InH0Anh0=nX0Unh0Eo80=o00Qo80Io
@0=o811o@0=oH0ao@0moH0Mo@0MoH59oo`03001oogoo015oo`40005oo`5oo`00Agoo00<007ooOol0
PGoo00<007ooOol0LGoo1Gh01WiP1GkP00=nX7kPO^001gkP47lP6Gm01WmP2Gm04WmP17m01gmPE7oo
00<007ooOol047oo0@000Goo0Goo0018Ool00`00Oomoo`20Ool00`00Oomoo`1aOol5OP05OV0?O^07
Ob02Of07Ob08Od03Of0>Od09Of06Od0MOf1FOol00`00Oomoo`0@Ool10001Ool004Uoo`03001oogoo
07moo`03001oogoo075oo`An00InH0Inh003Of1nh7kP00Enh0Mo80AoH0Eo80Qo@0IoH0Yo@0eoH0=o
@1eoH5Qoo`03001oogoo00moo`40005oo`00BWoo0P00Ogoo00<007ooOol0LGoo17h01GiP1WkP0gmP
1GkP1glP1WmP0glP27m027mP27m0;7mPFgoo00<007ooOol03Woo0@000Goo001<Ool00`00Oomoo`1l
Ool00`00Oomoo`1bOol2OP06OV05O^05Of03O^07Ob08Of08Od0<Of05Od0/Of1MOol00`00Oomoo`0=
Ool10001Ool004eoo`03001oogoo07]oo`03001oogoo079oo`9n00EnH0Inh0IoH003O^1o87lP00Eo
80QoH09oP0Io@0ioH0=o@2aoH5moo`03001oogoo00aoo`40005oo`00CWoo0P00Ngoo00<007ooOol0
LWoo0Wh01GiP1GkP1gmP1glP27mP17n017m09WmP0gn057mPHGoo00<007ooOol02goo0@000Goo001@
Ool00`00Oomoo`1hOol00`00Oomoo`1bOol00gh0OV1nH003OV05O^08Of000gnPOb1o8003Ob08Of06
Oh02Od0@Of03Oh0COf06Oh0AOf1SOol00`00Oomoo`0:Ool10001Ool0055oo`03001oogoo07Moo`03
001oogoo079oo`03OP1nH7iP00=nH0Enh0MoH0=oX0=o80QoH0MoP15oH0IoP11oH0QoP0ioH6Ioo`03
001oogoo00Uoo`40005oo`00DWoo00<007ooOol0MWoo00<007ooOol0LWoo1GiP1GkP1gmP1GnP00=o
87mPOf001GmP27n00gnP3GmP2Wn03GmP37n02WmPJ7oo00<007ooOol027oo0@000Goo001COol2001f
Ool00`00Oomoo`1cOol4OV04O^07Of06Oj07Of08Oh05Oj0;Of0<Oh0:Of0@Oh07Of1YOol00`00Oomo
o`08Ool10001Ool005Eoo`03001oogoo07=oo`03001oogoo07Aoo`9nH0Enh0IoH0IoX09o`0EoH0Mo
P0QoX0UoH0ioP0QoH1=oP0AoH6]oo`03001oogoo00Moo`40005oo`00EWoo00<007ooOol0LWoo00<0
07ooOol0MGoo1GkP1WmP1WnP17o00gmP1gn02gnP1GmP4Wn01GmP5Wn0KWoo00<007ooOol01Woo0@00
0Goo001GOol00`00Oomoo`1aOol00`00Oomoo`1gOol2O^06Of06Oj06Ol08Oh0=Oj03Of0DOh03Of0F
Oh1`Ool00`00Oomoo`05Ool10001Ool005Qoo`80075oo`03001oogoo07Qoo`IoH0IoX0Io`09oh0Eo
P11oX2ioP79oo`03001oogoo00Aoo`40005oo`00FWoo00<007ooOol0KWoo00<007ooOol0NGoo17mP
1GnP1go017oP0gn04gnP57n00gnP4gn0MGoo00<007ooOol017oo0@00001KOol00`00Oomoo`1]Ool0
0`00Oomoo`1jOol2Of05Oj07Ol06On0GOj0@Oh07Oj0@Oh1gOol00`00Oomoo`03Ool1000005aoo`03
001oogoo06aoo`03001oogoo07]oo`EoX0Mo`0Uoh1AoX09o`0ioP0YoX0eoP7Uoo`03001oogoo009o
o`400000GGoo0P00K7oo00<007ooOol0O7oo0gnP1Wo037oP4GnP1Go02gn03WnP2Gn0O7oo00@007oo
Oomoo`400000Ggoo00<007ooOol0JGoo00<007ooOol0OGoo1go03WoP3gnP1go02Gn047nP1gn0OWoo
00<007ooOol00@00001POol00`00Oomoo`1XOol00`00Oomoo`1nOol5Ol0@On0<Oj0;Ol05Oh0DOj04
Oh20Ool10001Ool10000065oo`03001oogoo06Moo`03001oogoo07moo`=o`19oh0UoX0io`0=oP1Mo
X8=oo`800000HWoo0P00Igoo00<007ooOol0P7oo5GoP1gnP47o067nPPgoo0`00001TOol00`00Oomo
o`1TOol00`00Oomoo`22OolEOn03Oj0DOl0DOj21Ool40003Ool006Eoo`03001oogoo06=oo`03001o
ogoo08=ooaEoh1Qo`11oX7moo`@000Moo`00IWoo0P00Hgoo00<007ooOol0Q7oo5GoP67o03GnPOGoo
10002goo001XOol00`00Oomoo`1POol00`00Oomoo`25OolEOn0HOl0;Oj1jOol4000?Ool006Uoo`03
001oogoo05ioo`03001oogoo08MooaEoh1Qo`0QoX7Qoo`@001=oo`00JWoo00<007ooOol0GGoo00<0
07ooOol0R7oo5WoP67o017nPMWoo10005goo001[Ool2001MOol00`00Oomoo`29OolGOn0HOl1dOol4
000KOol006eoo`03001oogoo05Yoo`03001oogoo08YooaMoh1Io`71oo`D001moo`00KWoo00<007oo
Ool0FGoo00<007ooOol0Rgoo5goP4go0KWoo100097oo001_Ool00`00Oomoo`1HOol00`00Oomoo`2<
OolGOn0@Ol1/Ool4000XOol0071oo`8005Qoo`03001oogoo08iooaMoh0ao`6Yoo`@002aoo`00LWoo
00<007ooOol0EGoo00<007ooOol0Sgoo5goP2Go0J7oo1000<7oo001cOol00`00Oomoo`1DOol00`00
Oomoo`2@OolGOn06Ol1VOol4000dOol007Aoo`03001oogoo05=oo`03001oogoo095ooaMoh0=o`6Ao
o`@003Qoo`00MGoo0P00Dgoo00<007ooOol0TWoo5goPHWoo1000?7oo001gOol00`00Oomoo`1@Ool0
0`00Oomoo`2COolDOn1OOol50010Ool007Qoo`03001oogoo04moo`03001oogoo09Aooa5oh5eoo`@0
04Eoo`00NGoo00<007ooOol0CWoo00<007ooOol0UGoo3WoPFgoo1000BGoo001jOol2001>Ool00`00
Oomoo`2FOol;On1IOol4001=Ool007aoo`03001oogoo04]oo`03001oogoo09Moo`Qoh5Moo`@0055o
o`00OGoo00<007ooOol0BWoo00<007ooOol0VGoo17oPEGoo1000EGoo001nOol2001:Ool00`00Oomo
o`3^Ool4001IOol0081oo`03001oogoo04Moo`03001oogoo0>Yoo`@005eoo`00PGoo00<007ooOol0
AWoo00<007ooOol0iGoo1@00HGoo0022Ool00`00Oomoo`15Ool00`00Oomoo`3QOol4001VOol008=o
o`8004Eoo`03001oogoo0=eoo`@006Yoo`00QGoo00<007ooOol0@Woo00<007ooOol0fGoo1000KWoo
0026Ool00`00Oomoo`11Ool00`00Oomoo`3EOol4001bOol008Moo`03001oogoo041oo`03001oogoo
0=5oo`@007Ioo`00R7oo0P00@7oo00<007ooOol0cGoo1000NWoo002:Ool00`00Oomoo`0mOol00`00
Oomoo`39Ool4001nOol008]oo`03001oogoo03aoo`03001oogoo0<Aoo`D0089oo`00S7oo00<007oo
Ool0>goo00<007ooOol0`7oo1000Qgoo002=Ool2000kOol00`00Oomoo`2lOol4002;Ool008moo`03
001oogoo03Qoo`03001oogoo0;Qoo`@008moo`00T7oo00<007ooOol0=goo00<007ooOol0]7oo1000
Tgoo002AOol2000gOol00`00Oomoo`2`Ool4002GOol009=oo`03001oogoo03Aoo`03001oogoo0:ao
o`@009]oo`00U7oo00<007ooOol0<goo00<007ooOol0Z7oo1000Wgoo002EOol00`00Oomoo`0bOol0
0`00Oomoo`2TOol4002SOol009Ioo`80039oo`03001oogoo09moo`D00:Moo`00V7oo00<007ooOol0
;goo00<007ooOol0Vgoo1000[7oo002IOol00`00Oomoo`0^Ool00`00Oomoo`2GOol4002`Ool009Yo
o`03001oogoo02eoo`03001oogoo09=oo`@00;Aoo`00Vgoo0P00;Goo00<007ooOol0Sgoo1000^7oo
002MOol00`00Oomoo`0ZOol00`00Oomoo`2;Ool4002lOol009ioo`03001oogoo02Uoo`03001oogoo
08Moo`@00<1oo`00Wgoo00<007ooOol0:7oo00<007ooOol0Pgoo1000a7oo002POol2000XOol00`00
Oomoo`1nOol50038Ool00:9oo`03001oogoo02Eoo`03001oogoo07Yoo`@00<eoo`00Xgoo00<007oo
Ool097oo00<007ooOol0MWoo1000dGoo002TOol00`00Oomoo`0SOol00`00Oomoo`1bOol4003EOol0
0:Eoo`8002=oo`03001oogoo06ioo`@00=Uoo`00Ygoo00<007ooOol087oo00<007ooOol0JWoo1000
gGoo002XOol00`00Oomoo`0OOol00`00Oomoo`1VOol4003QOol00:Uoo`8001ioo`03001oogoo06=o
o`@00>Eoo`00Zgoo00<007ooOol06goo00<007ooOol0GWoo1@00jGoo002/Ool00`00Oomoo`0JOol0
0`00Oomoo`1JOol4003^Ool00:eoo`03001oogoo01Uoo`03001oogoo05Ioo`@00?9oo`00[Woo0P00
6Goo00<007ooOol0DWoo1000mWoo002`Ool00`00Oomoo`0FOol00`00Oomoo`1>Ool4003jOol00;5o
o`03001oogoo01Eoo`03001oogoo04Yoo`@00?ioo`00/Woo00<007ooOol057oo00<007ooOol0AWoo
1000ogoo0goo002cOol2000DOol00`00Oomoo`12Ool4003oOol7Ool00;Eoo`03001oogoo015oo`03
001oogoo03eoo`D00?moo`]oo`00]Woo00<007ooOol047oo00<007ooOol0>Goo1000ogoo47oo002g
Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol4003oOolDOol00;Qoo`8000moo`03001oogoo035oo`@0
0?mooaQoo`00^Woo00<007ooOol037oo00<007ooOol0;Goo1000ogoo77oo002kOol00`00Oomoo`0;
Ool00`00Oomoo`0YOol4003oOolPOol00;aoo`03001oogoo00Yoo`03001oogoo02Eoo`@00?moobAo
o`00_Goo0P002Woo00<007ooOol08Goo1000ogoo:7oo002oOol00`00Oomoo`07Ool00`00Oomoo`0L
Ool5003oOol/Ool00<1oo`03001oogoo00Ioo`03001oogoo01Qoo`@00?mooc5oo`00`Goo0P001Woo
00<007ooOol057oo1000ogoo=Goo0033Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool4003oOoliOol0
0<Aoo`03001oogoo009oo`03001oogoo00aoo`@00?mooceoo`00aGoo00D007ooOomoo`0000Yoo`@0
0?mood5oo`00aWoo0P0000=oo`00Ool01Goo1000ogooAGoo0038Ool20002Ool4003oOom9Ool00<Uo
o`<00?moodeoo`00\
\>"],
  ImageRangeCache->{{{0, 535.25}, {869.938, 0}} -> {0.186172, 0.00626965, \
0.00171385, 0.00171385}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wExample = ArcSin[z\^3 + 3\ z - 7]\/\(z - 1\); \)], "Input",
  FontSize->12],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.62453 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.30443 1.63518 -0.0106411 1.63518 [
[ 0 0 0 0 ]
[ 1 1.62453 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.62453 L
0 1.62453 L
closepath
clip
newpath
.64863 .32516 m .65092 .36035 L .64961 .32474 L 0 .484 .275 r
F
.64863 .32516 m .64837 .33324 L .65092 .36035 L F
.64961 .32474 m .65505 .37387 L .65039 .3244 L F
.64961 .32474 m .65092 .36035 L .65505 .37387 L F
.65039 .3244 m .65884 .37032 L .65125 .32385 L F
.65039 .3244 m .65505 .37387 L .65884 .37032 L F
.65125 .32385 m .65975 .35207 L .65228 .32302 L F
.65125 .32385 m .65884 .37032 L .65975 .35207 L F
.65228 .32302 m .65717 .32495 L .65497 .32104 L F
.65228 .32302 m .65975 .35207 L .65717 .32495 L F
.65497 .32104 m .65717 .32495 L .65606 .32034 L F
.65606 .32034 m .65717 .32495 L .65664 .31988 L 0 .289 .251 r
F
.65664 .31988 m .66068 .32657 L .65921 .31694 L F
.65664 .31988 m .65717 .32495 L .66068 .32657 L F
0 g
.0001 w
[ ] 0 setdash
.65717 .32495 m
.65807 .32536 L
s
.65921 .31694 m .66068 .32657 L .66094 .31432 L 0 .289 .251 r
F
.66094 .31432 m .66366 .35042 L .66122 .314 L 0 .245 .246 r
F
.66094 .31432 m .66068 .32657 L .66366 .35042 L F
0 g
.65807 .32536 m
.66068 .32657 L
s
.66122 .314 m .66799 .36652 L .66139 .31382 L 0 .245 .246 r
F
.66122 .314 m .66366 .35042 L .66799 .36652 L F
.66139 .31382 m .67162 .36991 L .66152 .31362 L F
.66139 .31382 m .66799 .36652 L .67162 .36991 L F
.66152 .31362 m .67211 .35827 L .66162 .31341 L F
.66152 .31362 m .67162 .36991 L .67211 .35827 L F
.66162 .31341 m .66909 .33429 L .6618 .31309 L F
.66162 .31341 m .67211 .35827 L .66909 .33429 L F
.6618 .31309 m .66461 .31407 L .66247 .31213 L F
.6618 .31309 m .66909 .33429 L .66461 .31407 L F
.59106 .31007 m .59874 .31228 L .59852 .31092 L 0 .827 .257 r
F
.59905 .31088 m .60648 .31018 L .60619 .30935 L 0 .665 .257 r
F
.59905 .31088 m .59874 .31228 L .60648 .31018 L F
.59874 .31228 m .60992 .34193 L .60648 .31018 L F
.59874 .31228 m .60999 .37178 L .60992 .34193 L F
.59874 .31228 m .60671 .38682 L .60999 .37178 L F
.59874 .31228 m .60227 .37684 L .60671 .38682 L F
.59874 .31228 m .59886 .3448 L .60227 .37684 L F
.59106 .31007 m .58818 .32186 L .59874 .31228 L 0 .827 .257 r
F
.58818 .32186 m .59886 .3448 L .59874 .31228 L F
0 g
.59852 .31092 m
.59874 .31228 L
s
.59874 .31228 m
.59905 .31088 L
s
.58968 .30991 m .58818 .32186 L .59106 .31007 L 0 .827 .257 r
F
.66392 .30967 m .66461 .31407 L .66405 .30916 L 0 0 .136 r
F
.64683 .36659 m .65505 .37387 L .65092 .36035 L 0 .651 .287 r
F
0 g
.64837 .33324 m
.65092 .36035 L
s
.60619 .30935 m .60648 .31018 L .6064 .30932 L 0 .592 .248 r
F
.64683 .36659 m .65701 .39805 L .65505 .37387 L 0 .651 .287 r
F
.64683 .36659 m .65548 .41676 L .65701 .39805 L F
.64683 .36659 m .65137 .42304 L .65548 .41676 L F
.64683 .36659 m .64744 .41267 L .65137 .42304 L F
.64683 .36659 m .6455 .38845 L .64744 .41267 L F
0 g
.64683 .36659 m
.65092 .36035 L
s
.6064 .30932 m .60648 .31018 L .6066 .30927 L 0 .592 .248 r
F
0 g
.60648 .31018 m
.6066 .30927 L
s
.66405 .30916 m .66909 .33429 L .66475 .30637 L 0 0 .136 r
F
.66405 .30916 m .66461 .31407 L .66909 .33429 L F
0 g
.66392 .30967 m
.66461 .31407 L
s
.66247 .31213 m
.66461 .31407 L
s
.58092 .30627 m .58513 .31725 L .58565 .3087 L 0 1 .237 r
F
.61095 .3082 m .61338 .33709 L .61182 .30787 L 0 .426 .244 r
F
.61182 .30787 m .61811 .36044 L .61361 .30721 L F
.61182 .30787 m .61338 .33709 L .61811 .36044 L F
.61361 .30721 m .62131 .35749 L .61533 .30605 L F
.61361 .30721 m .61811 .36044 L .62131 .35749 L F
.66475 .30637 m .67247 .34565 L .66499 .30436 L 0 0 .136 r
F
.66475 .30637 m .66909 .33429 L .67247 .34565 L F
.5795 .30563 m .57762 .32183 L .58092 .30627 L 0 1 .237 r
F
.58092 .30627 m .57762 .32183 L .58513 .31725 L F
.61533 .30605 m .62082 .3302 L .61696 .30438 L 0 .426 .244 r
F
.61533 .30605 m .62131 .35749 L .62082 .3302 L F
.57894 .30534 m .57762 .32183 L .5795 .30563 L 0 1 .237 r
F
.57866 .3051 m .57762 .32183 L .57894 .30534 L F
.65975 .35207 m .66799 .36652 L .66366 .35042 L 0 .426 .281 r
F
0 g
.66068 .32657 m
.66366 .35042 L
s
.65975 .35207 m .67044 .38977 L .66799 .36652 L 0 .426 .281 r
F
.65975 .35207 m .66935 .40463 L .67044 .38977 L F
.65975 .35207 m .66541 .40623 L .66935 .40463 L F
.65975 .35207 m .66126 .39353 L .66541 .40623 L F
.65975 .35207 m .65884 .37032 L .66126 .39353 L F
0 g
.65
}, Open  ]],

Cell[CellGroupData[{

 .35207 m
.66366 .35042 L
s
.61696 .30438 m .62082 .3302 L .6185 .30308 L 0 .426 .244 r
F
.66499,

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.62453 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.30443 1.63518 -0.0106411 1.63518 [
[ 0 0 0 0 ]
[ 1 1.62453 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.62453 L
0 1.62453 L
closepath
clip
newpath
.64863 .32516 m .65092 .36035 L .64961 .32474 L 0 .484 .275 r
F
.64863 .32516 m .64837 .33324 L .65092 .36035 L F
.64961 .32474 m .65505 .37387 L .65039 .3244 L F
.64961 .32474 m .65092 .36035 L .65505 .37387 L F
.65039 .3244 m .65884 .37032 L .65125 .32385 L F
.65039 .3244 m .65505 .37387 L .65884 .37032 L F
.65125 .32385 m .65975 .35207 L .65228 .32302 L F
.65125 .32385 m .65884 .37032 L .65975 .35207 L F
.65228 .32302 m .65717 .32495 L .65497 .32104 L F
.65228 .32302 m .65975 .35207 L .65717 .32495 L F
.65497 .32104 m .65717 .32495 L .65606 .32034 L F
.65606 .32034 m .65717 .32495 L .65664 .31988 L 0 .289 .251 r
F
.65664 .31988 m .66068 .32657 L .65921 .31694 L F
.65664 .31988 m .65717 .32495 L .66068 .32657 L F
0 g
.0001 w
[ ] 0 setdash
.65717 .32495 m
.65807 .32536 L
s
.65921 .31694 m .66068 .32657 L .66094 .31432 L 0 .289 .251 r
F
.66094 .31432 m .66366 .35042 L .66122 .314 L 0 .245 .246 r
F
.66094 .31432 m .66068 .32657 L .66366 .35042 L F
0 g
.65807 .32536 m
.66068 .32657 L
s
.66122 .314 m .66799 .36652 L .66139 .31382 L 0 .245 .246 r
F
.66122 .314 m .66366 .35042 L .66799 .36652 L F
.66139 .31382 m .67162 .36991 L .66152 .31362 L F
.66139 .31382 m .66799 .36652 L .67162 .36991 L F
.66152 .31362 m .67211 .35827 L .66162 .31341 L F
.66152 .31362 m .67162 .36991 L .67211 .35827 L F
.66162 .31341 m .66909 .33429 L .6618 .31309 L F
.66162 .31341 m .67211 .35827 L .66909 .33429 L F
.6618 .31309 m .66461 .31407 L .66247 .31213 L F
.6618 .31309 m .66909 .33429 L .66461 .31407 L F
.59106 .31007 m .59874 .31228 L .59852 .31092 L 0 .827 .257 r
F
.59905 .31088 m .60648 .31018 L .60619 .30935 L 0 .665 .257 r
F
.59905 .31088 m .59874 .31228 L .60648 .31018 L F
.59874 .31228 m .60992 .34193 L .60648 .31018 L F
.59874 .31228 m .60999 .37178 L .60992 .34193 L F
.59874 .31228 m .60671 .38682 L .60999 .37178 L F
.59874 .31228 m .60227 .37684 L .60671 .38682 L F
.59874 .31228 m .59886 .3448 L .60227 .37684 L F
.59106 .31007 m .58818 .32186 L .59874 .31228 L 0 .827 .257 r
F
.58818 .32186 m .59886 .3448 L .59874 .31228 L F
0 g
.59852 .31092 m
.59874 .31228 L
s
.59874 .31228 m
.59905 .31088 L
s
.58968 .30991 m .58818 .32186 L .59106 .31007 L 0 .827 .257 r
F
.66392 .30967 m .66461 .31407 L .66405 .30916 L 0 0 .136 r
F
.64683 .36659 m .65505 .37387 L .65092 .36035 L 0 .651 .287 r
F
0 g
.64837 .33324 m
.65092 .36035 L
s
.60619 .30935 m .60648 .31018 L .6064 .30932 L 0 .592 .248 r
F
.64683 .36659 m .65701 .39805 L .65505 .37387 L 0 .651 .287 r
F
.64683 .36659 m .65548 .41676 L .65701 .39805 L F
.64683 .36659 m .65137 .42304 L .65548 .41676 L F
.64683 .36659 m .64744 .41267 L .65137 .42304 L F
.64683 .36659 m .6455 .38845 L .64744 .41267 L F
0 g
.64683 .36659 m
.65092 .36035 L
s
.6064 .30932 m .60648 .31018 L .6066 .30927 L 0 .592 .248 r
F
0 g
.60648 .31018 m
.6066 .30927 L
s
.66405 .30916 m .66909 .33429 L .66475 .30637 L 0 0 .136 r
F
.66405 .30916 m .66461 .31407 L .66909 .33429 L F
0 g
.66392 .30967 m
.66461 .31407 L
s
.66247 .31213 m
.66461 .31407 L
s
.58092 .30627 m .58513 .31725 L .58565 .3087 L 0 1 .237 r
F
.61095 .3082 m .61338 .33709 L .61182 .30787 L 0 .426 .244 r
F
.61182 .30787 m .61811 .36044 L .61361 .30721 L F
.61182 .30787 m .61338 .33709 L .61811 .36044 L F
.61361 .30721 m .62131 .35749 L .61533 .30605 L F
.61361 .30721 m .61811 .36044 L .62131 .35749 L F
.66475 .30637 m .67247 .34565 L .66499 .30436 L 0 0 .136 r
F
.66475 .30637 m .66909 .33429 L .67247 .34565 L F
.5795 .30563 m .57762 .32183 L .58092 .30627 L 0 1 .237 r
F
.58092 .30627 m .57762 .32183 L .58513 .31725 L F
.61533 .30605 m .62082 .3302 L .61696 .30438 L 0 .426 .244 r
F
.61533 .30605 m .62131 .35749 L .62082 .3302 L F
.57894 .30534 m .57762 .32183 L .5795 .30563 L 0 1 .237 r
F
.57866 .3051 m .57762 .32183 L .57894 .30534 L F
.65975 .35207 m .66799 .36652 L .66366 .35042 L 0 .426 .281 r
F
0 g
.66068 .32657 m
.66366 .35042 L
s
.65975 .35207 m .67044 .38977 L .66799 .36652 L 0 .426 .281 r
F
.65975 .35207 m .66935 .40463 L .67044 .38977 L F
.65975 .35207 m .66541 .40623 L .66935 .40463 L F
.65975 .35207 m .66126 .39353 L .66541 .40623 L F
.65975 .35207 m .65884 .37032 L .66126 .39353 L F
0 g
.65717 .32495 m
.65975 .35207 L
s
.65975 .35207 m
.66366 .35042 L
s
.61696 .30438 m .62082 .3302 L .6185 .30308 L 0 .426 .244 r
F
.66499 .30436 m .67245 .34045 L .66503 .30278 L 0 0 .136 r
F
.66499 .30436 m .67247 .34565 L .67245 .34045 L F
.57801 .36973 m .58513 .31725 L .58109 .3392 L 0 1 .251 r
F
.57801 .36973 m .58818 .32186 L .58513 .31725 L F
.57762 .32183 m .58109 .3392 L .58513 .31725 L 0 1 .237 r
F
0 g
.58513 .31725 m
.58565 .3087 L
s
.57638 .30292 m .57456 .33874 L .5766 .30327 L 0 .95 .098 r
F
.58818 .32186 m .59575 .36994 L .59886 .3448 L 0 .827 .257 r
F
.58818 .32186 m .59149 .37069 L .59575 .36994 L F
.58818 .32186 m .58824 .34999 L .59149 .37069 L F
.57801 .36973 m .58824 .34999 L .58818 .32186 L 0 1 .251 r
F
0 g
.58818 .32186 m
.58968 .30991 L
s
.58513 .31725 m
.58818 .32186 L
s
.57493 .30136 m .56721 .40897 L .57638 .30292 L 0 .95 .098 r
F
.57638 .30292 m .56721 .40897 L .57456 .33874 L F
.66503 .30278 m .66895 .31799 L .66517 .30104 L 0 0 .136 r
F
.66503 .30278 m .67245 .34045 L .66895 .31799 L F
0 g
.65644 .37256 m
.65884 .37032 L
s
.65505 .37387 m
.65644 .37256 L
s
.57426 .30044 m .56721 .40897 L .57493 .30136 L 0 .95 .098 r
F
.66517 .30104 m .66895 .31799 L .66547 .29952 L 0 0 .136 r
F
.57426 .30044 m .5735 .30761 L .56721 .40897 L 0 .95 .098 r
F
.62085 .30026 m .62423 .33839 L .62157 .29938 L 0 .138 .181 r
F
.57348 .29849 m .5735 .30761 L .57388 .29992 L 0 .665 .032 r
F
.60992 .34193 m .61811 .36044 L .61338 .33709 L 0 .53 .258 r
F
.60992 .34193 m .62164 .39525 L .61811 .36044 L F
.60992 .34193 m .62158 .41826 L .62164 .39525 L F
.60992 .34193 m .61808 .42315 L .62158 .41826 L F
.60908 .29969 m .61407 .37574 L .61029 .29956 L 0 .608 .244 r
F
.60908 .29969 m .60957 .32061 L .61407 .37574 L F
.60304 .29842 m .60957 .32061 L .60908 .29969 L 0 .854 .242 r
F
.61029 .29956 m .61852 .38125 L .61178 .29939 L 0 .608 .244 r
F
.61029 .29956 m .61407 .37574 L .61852 .38125 L F
.66547 .29952 m .66895 .31799 L .66355 .29515 L 0 .593 .03 r
F
.61178 .29939 m .62081 .34693 L .61419 .29874 L 0 .608 .244 r
F
.61178 .29939 m .61852 .38125 L .62081 .34693 L F
.62157 .29938 m .62933 .37687 L .62235 .2984 L 0 .138 .181 r
F
.62157 .29938 m .62423 .33839 L .62933 .37687 L F
.61419 .29874 m .62081 .34693 L .61942 .29673 L 0 .608 .244 r
F
.56557 .42277 m .56665 .4111 L .5662 .41641 L 0 0 .023 r
F
.5655 .42334 m .56665 .4111 L .56557 .42277 L F
.56481 .42988 m .56524 .42548 L .56525 .42605 L F
.56524 .42548 m .56665 .4111 L .5655 .42334 L F
.56524 .42548 m .5655 .42334 L .56525 .42605 L F
.55745 .50206 m .56262 .45546 L .56326 .44667 L 0 0 0 r
F
.55645 .50938 m .55752 .50421 L .55748 .50306 L F
.5657 .42083 m .56401 .43672 L .56665 .4111 L 0 0 .023 r
F
.57284 .29717 m .5662 .41641 L .57348 .29849 L 0 .665 .032 r
F
.57348 .29849 m .5662 .41641 L .5735 .30761 L F
.56877 .37478 m .56807 .38778 L .56872 .37556 L 0 0 .028 r
F
.56877 .37478 m .56872 .37556 L .56978 .35586 L F
.56984 .35493 m .56877 .37478 L .56978 .35586 L F
.56348 .44769 m .56466 .43967 L .56749 .41143 L 0 0 0 r
F
.56287 .45327 m .56332 .44987 L .56348 .44769 L F
.56332 .44987 m .56466 .43967 L .56348 .44769 L F
.5635 .44433 m .56749 .41143 L .56721 .40897 L F
.56345 .44507 m .56749 .41143 L .5635 .44433 L F
.56262 .45546 m .56287 .45327 L .56326 .44667 L F
.56287 .45327 m .56749 .41143 L .56345 .44507 L F
.56287 .45327 m .56345 .44507 L .56326 .44667 L F
.5662 .41641 m .56981 .36406 L .57093 .34697 L 0 .665 .032 r
F
.57112 .34306 m .57093 .34697 L .5735 .30761 L F
.5662 .41641 m .57093 .34697 L .57112 .34306 L F
.57349 .28918 m .57332 .29944 L .57337 .28992 L 0 0 .038 r
F
.56721 .40897 m .5735 .30761 L .56981 .36406 L 0 .95 .098 r
F
.57332 .29944 m .57261 .3413 L .57319 .30191 L 0 0 .038 r
F
.57332 .29944 m .57319 .30191 L .57337 .28992 L F
.5662 .41641 m .56665 .4111 L .56981 .36406 L 0 .665 .032 r
F
.54672 .56762 m .55182 .53906 L .55435 .52358 L 0 0 0 r
F
.55487 .52008 m .55437 .52345 L .55729 .50556 L F
.55729 .50556 m .55574 .51505 L .55752 .50421 L F
.55574 .51505 m .55573 .51514 L .55752 .50421 L F
.55595 .51596 m .55744 .50758 L .55611 .51449 L F
.55592 .5138 m .55752 .50421 L .55645 .50938 L F
.55545 .51872 m .5573 .51092 L .55744 .50758 L F
.54672 .56762 m .55488 .52389 L .55545 .51872 L F
.55488 .52389 m .5573 .51092 L .55545 .51872 L F
.5635 .44433 m .56436 .43615 L .56418 .43526 L F
.56436 .43615 m .56721 .40897 L .56479 .42991 L F
.56436 .43615 m .56479 .42991 L .56418 .43526 L F
.57243 .29607 m .5662 .41641 L .57284 .29717 L 0 .665 .032 r
F
.57243 .29607 m .57205 .30168 L .5662 .41641 L F
.5662 .41641 m .57205 .30168 L .56855 .36894 L F
.56795 .38464 m .56855 .36894 L .57205 .30168 L 0 0 .028 r
F
.5664 .41602 m .5676 .38964 L .56795 .38464 L F
.5676 .38964 m .56855 .36894 L .56795 .38464 L F
.56326 .44667 m .56345 .44507 L .5635 .44433 L 0 0 0 r
F
.5623 .45663 m .5662 .41641 L .56294 .45024 L 0 0 .023 r
F
.55847 .49304 m .56235 .45976 L .56287 .45327 L 0 0 0 r
F
.55751 .50183 m .5573 .5036 L .55781 .49917 L F
.55726 .50395 m .55814 .49636 L .55847 .49304 L F
.55802 .4974 m .55781 .49917 L .56056 .47523 L F
.55814 .49636 m .56235 .45976 L .55847 .49304 L F
.55751 .50183 m .55781 .49917 L .55802 .4974 L F
.55709 .50549 m .55724 .50412 L .55751 .50183 L F
.55724 .50412 m .5573 .5036 L .55751 .50183 L F
.55748 .50306 m .56466 .43967 L .56056 .47523 L 0 .757 .07 r
F
.55721 .50446 m .56056 .47523 L .56466 .43967 L 0 0 0 r
F
.55709 .50549 m .5572 .5046 L .55721 .50446 L F
.5572 .5046 m .56056 .47523 L .55721 .50446 L F
.55915 .48765 m .56466 .43967 L .55918 .48735 L F
.55915 .48765 m .55918 .48735 L .55726 .50395 L F
.55721 .50446 m .55915 .48765 L .55726 .50395 L F
.55896 .48953 m .55926 .48594 L .55954 .48364 L 0 0 .023 r
F
.55748 .50306 m .56778 .4186 L .56466 .43967 L 0 .757 .07 r
F
.55748 .50306 m .56787 .42571 L .56778 .4186 L F
.55812 .49813 m .55878 .49106 L .55896 .48953 L 0 0 .023 r
F
.55878 .49106 m .55926 .48594 L .55896 .48953 L F
.55726 .50395 m .56262 .45546 L .55745 .50206 L 0 0 0 r
F
.55907 .48861 m .56001 .47881 L .56028 .47634 L 0 0 .023 r
F
.5578 .50071 m .56485 .45306 L .56787 .42571 L 0 .757 .07 r
F
.55748 .50306 m .55776 .5012 L .5578 .50071 L F
.55776 .5012 m .56485 .45306 L .5578 .50071 L F
.57 .38224 m .57067 .38109 L .57456 .33874 L 0 .95 .098 r
F
.56721 .40897 m .56976 .38836 L .57 .38224 L F
.56976 .38836 m .57067 .38109 L .57 .38224 L F
.57361 .2884 m .57357 .29137 L .57349 .28918 L 0 0 .038 r
F
.56778 .4186 m .57762 .32183 L .57456 .33874 L 0 1 .144 r
F
.56778 .4186 m .57786 .34118 L .57762 .32183 L F
.56778 .4186 m .57504 .37815 L .57786 .34118 L F
.56778 .4186 m .57456 .33874 L .57067 .38109 L F
.56904 .41157 m .571 .40826 L .57504 .37815 L F
.56778 .4186 m .56892 .41495 L .56904 .41157 L F
.56892 .41495 m .571 .40826 L .56904 .41157 L F
.57346 .29071 m .57204 .39562 L .57261 .3413 L 0 0 .038 r
F
.57349 .28918 m .57347 .29049 L .57346 .29071 L F
.57347 .29049 m .57204 .39562 L .57346 .29071 L F
.57357 .29137 m .57204 .39562 L .5734 .29574 L F
.57357 .29137 m .5734 .29574 L .57349 .28918 L F
.56721 .40897 m .56749 .41143 L .57067 .38109 L 0 .95 .098 r
F
.55744 .50758 m .56785 .43807 L .56485 .45306 L 0 1 .113 r
F
.55744 .50758 m .56773 .44746 L .56785 .43807 L F
.55744 .50758 m .56453 .47205 L .56773 .44746 L F
.55696 .51698 m .56737 .46211 L .56453 .47205 L 0 1 .139 r
F
.55696 .51698 m .56702 .47226 L .56737 .46211 L F
.55696 .51698 m .56367 .49344 L .56702 .47226 L F
.55696 .51698 m .56453 .47205 L .56035 .49562 L F
.55744 .50758 m .56035 .49562 L .56453 .47205 L 0 1 .113 r
F
.55603 .52947 m .56632 .48745 L .56367 .49344 L 0 1 .185 r
F
.55603 .52947 m .56573 .49755 L .56632 .48745 L F
.55603 .52947 m .56367 .49344 L .55953 .5116 L F
.55696 .51698 m .55953 .5116 L .56367 .49344 L 0 1 .139 r
F
.56308 .50489 m .56702 .4113 L .57 .35675 L 0 0 .076 r
F
.57015 .355 m .57 .35675 L .57048 .34794 L F
.56308 .50489 m .57 .35675 L .57015 .355 L F
.55748 .50306 m .56069 .48267 L .56485 .45306 L 0 .757 .07 r
F
.55748 .50306 m .55752 .50421 L .56069 .48267 L F
.55387 .52514 m .55592 .5138 L .55645 .50938 L 0 0 0 r
F
.55095 .54536 m .55372 .53136 L .55374 .53074 L F
.54742 .56394 m .55009 .55016 L .54974 .55187 L 0 .76 .069 r
F
.54632 .56969 m .54735 .56436 L .54742 .56394 L F
.54735 .56436 m .55009 .55016 L .54742 .56394 L F
.54676 .56738 m .5466 .56813 L .54974 .55187 L 0 0 0 r
F
.54672 .56762 m .5467 .56769 L .54676 .56738 L F
.5467 .56769 m .5466 .56813 L .54676 .56738 L F
.54806 .56068 m .54974 .55187 L .55006 .55022 L F
.55009 .55016 m .55151 .5428 L .55006 .55021 L 0 .76 .069 r
F
.55009 .55016 m .55006 .55021 L .54974 .55187 L F
.55151 .5428 m .55401 .52984 L .55141 .54328 L F
.55151 .5428 m .55141 .54328 L .54974 .55187 L F
.54955 .55296 m .55006 .55022 L .55382 .53085 L 0 0 0 r
F
.54806 .56068 m .55006 .55022 L .54955 .55296 L F
.54954 .55302 m .55382 .53085 L .55372 .53136 L F
.54672 .56762 m .54955 .55296 L .54954 .55302 L F
.54955 .55296 m .55382 .53085 L .54954 .55302 L F
.54672 .56762 m .55514 .52336 L .55539 .52117 L F
.54947 .55339 m .55696 .51698 L .55401 .52984 L 0 .76 .069 r
F
.54632 .56969 m .54917 .55557 L .54947 .55339 L F
.54917 .55557 m .55696 .51698 L .54947 .55339 L F
.55744 .50758 m .56485 .45306 L .56069 .48267 L 0 1 .113 r
F
.55744 .50758 m .5573 .51092 L .56035 .49562 L F
.54632 .56969 m .55664 .52174 L .55696 .51698 L 0 .76 .069 r
F
.54888 .55778 m .55326 .53936 L .55664 .52174 L F
.54632 .56969 m .54861 .55968 L .54888 .55778 L F
.54861 .55968 m .55326 .53936 L .54888 .55778 L F
.54772 .56448 m .55603 .52947 L .55326 .53936 L 0 .841 .102 r
F
.54558 .5742 m .54754 .56582 L .54772 .56448 L F
.54754 .56582 m .55603 .52947 L .54772 .56448 L F
.56169 .46419 m .56149 .46506 L .56185 .46246 L 0 0 .057 r
F
.54558 .5742 m .55553 .53504 L .55603 .52947 L 0 .841 .102 r
F
.54735 .56723 m .55209 .55089 L .55553 .53504 L F
.54558 .5742 m .54716 .56856 L .54735 .56723 L F
.54716 .56856 m .55209 .55089 L .54735 .56723 L F
.56056 .47678 m .56136 .46658 L .56169 .46419 L 0 0 .057 r
F
.55508 .53781 m .5603 .47853 L .56056 .47678 L F
.5603 .47853 m .56136 .46658 L .56056 .47678 L F
.56136 .46658 m .56149 .46506 L .56169 .46419 L F
.55508 .53781 m .559 .49048 L .55999 .48042 L F
.56038 .4777 m .55999 .48042 L .56149 .46506 L F
.55508 .53781 m .55999 .48042 L .56038 .4777 L F
.56185 .46246 m .56149 .46506 L .56294 .45024 L F
.54796 .56116 m .54974 .55187 L .54806 .56068 L 0 0 0 r
F
.5481 .56045 m .55077 .54665 L .54822 .55971 L F
.55259 .53403 m .55005 .54845 L .55435 .52358 L F
.54822 .55971 m .55077 .54665 L .55095 .54536 L F
.54677 .56734 m .55077 .54665 L .54677 .56731 L F
.54785 .56219 m .55005 .54845 L .55259 .53403 L F
.54779 .56232 m .55005 .54845 L .54785 .56219 L F
.54991 .54924 m .55435 .52358 L .55005 .54845 L F
.54975 .55013 m .55435 .52358 L .54991 .54924 L F
.54685 .56683 m .54974 .55016 L .54687 .56671 L F
.54974 .55016 m .55435 .52358 L .54975 .55013 L F
.54974 .55016 m .54975 .55013 L .54687 .56671 L F
.55137 .5417 m .55166 .53982 L .55172 .53973 L 0 0 .027 r
F
.55238 .53426 m .55385 .52621 L .55387 .52514 L 0 0 0 r
F
.54782 .56219 m .55044 .54651 L .55238 .53426 L F
.55044 .54651 m .55385 .52621 L .55238 .53426 L F
.54799 .56128 m .55385 .52621 L .54782 .56219 L F
.55021 .54796 m .55435 .52358 L .55437 .52345 L F
.55021 .54796 m .55437 .52345 L .55487 .52008 L F
.54952 .55227 m .55435 .52358 L .55021 .54796 L F
.55166 .53982 m .55514 .51747 L .55191 .53847 L 0 0 .027 r
F
.55166 .53982 m .55191 .53847 L .55172 .53973 L F
.55385 .52621 m .55592 .5138 L .55387 .52514 L 0 0 0 r
F
.55194 .53833 m .55514 .51747 L .55709 .50549 L 0 0 .027 r
F
.55172 .53973 m .55191 .53847 L .55194 .53833 L F
.55191 .53847 m .55514 .51747 L .55194 .53833 L F
.54687 .56671 m .54975 .55013 L .54991 .54924 L 0 0 0 r
F
.54672 .56762 m .54685 .56683 L .54687 .56671 L F
.55387 .52514 m .55721 .5047 L .55453 .52058 L F
.55721 .5047 m .55748 .50306 L .55722 .50459 L F
.55721 .5047 m .55722 .50459 L .55453 .52058 L F
.55769 .49953 m .56401 .43672 L .55999 .47663 L F
.55709 .50549 m .55768 .49971 L .55769 .49953 L F
.55768 .49971 m .56401 .43672 L .55769 .49953 L F
.55166 .53982 m .55527 .51602 L .55691 .50613 L 0 0 .027 r
F
.54632 .56969 m .54905 .5582 L .54973 .55514 L 0 .76 .069 r
F
.5496 .55536 m .54973 .55514 L .55326 .53936 L F
.54632 .56969 m .54973 .55514 L .5496 .55536 L F
.54672 .56762 m .54796 .56116 L .54806 .56068 L 0 0 0 r
F
.54677 .56731 m .5481 .56045 L .54822 .55971 L F
.54632 .56969 m .54606 .57125 L .54905 .5582 L 0 .76 .069 r
F
.54677 .56861 m .54679 .56782 L .55005 .54845 L 0 0 0 r
F
.54866 .55687 m .54942 .5524 L .54929 .55298 L F
.54677 .56861 m .54869 .55682 L .54866 .55687 L F
.54869 .55682 m .54942 .5524 L .54866 .55687 L F
.54837 .56098 m .55133 .5417 L .55166 .53982 L 0 0 .027 r
F
.55133 .5417 m .55527 .51602 L .55166 .53982 L F
.5445 .58054 m .55464 .54365 L .55209 .55089 L 0 1 .127 r
F
.54558 .5742 m .55326 .53936 L .54905 .5582 L 0 .841 .102 r
F
.5445 .58054 m .55209 .55089 L .54799 .56654 L 0 1 .127 r
F
.54558 .5742 m .54799 .56654 L .55209 .55089 L 0 .841 .102 r
F
.54558 .5742 m .54519 .57656 L .54799 .56654 L F
.54647 .57318 m .54834 .56105 L .54837 .56098 L 0 0 .027 r
F
.54834 .56105 m .55527 .51602 L .54837 .56098 L F
.54677 .56861 m .54779 .56232 L .54785 .56219 L 0 0 0 r
F
.54799 .56128 m .54975 .55084 L .54973 .55088 L F
.54677 .56861 m .54805 .56095 L .54799 .56128 L F
.54805 .56095 m .54975 .55084 L .54799 .56128 L F
.54805 .56095 m .54952 .55227 L .54975 .55084 L F
.54677 .56861 m .54809 .56073 L .54805 .56095 L F
.54809 .56073 m .54952 .55227 L .54805 .56095 L F
.54959 .55334 m .55137 .5417 L .55172 .53973 L 0 0 .027 r
F
.54647 .57318 m .54948 .55383 L .54959 .55334 L F
.54948 .55383 m .55137 .5417 L .54959 .55334 L F
.55372 .53136 m .55382 .53085 L .55401 .52984 L 0 0 0 r
F
.54677 .56861 m .54799 .56128 L .54782 .56219 L F
.54929 .55298 m .55387 .52514 L .55427 .52214 L F
.54942 .5524 m .55387 .52514 L .54929 .55298 L F
.55387 .52514 m .55453 .52058 L .55427 .52214 L F
.54934 .55454 m .55427 .52214 L .55527 .51602 L 0 0 .027 r
F
.54647 .57318 m .54925 .55499 L .54934 .55454 L F
.54925 .55499 m .55427 .52214 L .54934 .55454 L F
.54973 .55088 m .54975 .55084 L .55021 .54796 L 0 0 0 r
F
.55691 .50613 m .55527 .51602 L .5573 .5036 L 0 0 .027 r
F
.54672 .56762 m .54677 .56734 L .54677 .56731 L 0 0 0 r
F
.55077 .54665 m .55372 .53136 L .55095 .54536 L F
.55374 .53074 m .55401 .52984 L .55514 .52336 L F
.55372 .53136 m .55401 .52984 L .55374 .53074 L F
.55539 .52117 m .55514 .52336 L .5573 .51092 L F
.55903 .48899 m .55896 .48953 L .55907 .48861 L 0 0 .023 r
F
.55629 .51676 m .55889 .49027 L .55903 .48899 L F
.55889 .49027 m .55896 .48953 L .55903 .48899 L F
.55896 .48953 m .56001 .47881 L .55907 .48861 L F
.5593 .4867 m .56161 .46291 L .5623 .45663 L F
.55629 .51676 m .55907 .48861 L .5593 .4867 L F
.55907 .48861 m .56161 .46291 L .5593 .4867 L F
.55709 .50549 m .5635 .44433 L .56401 .43672 L 0 0 0 r
F
.5635 .44433 m .56418 .43526 L .56401 .43672 L F
.56161 .46291 m .5662 .41641 L .5623 .45663 L 0 0 .023 r
F
.55629 .51676 m .55666 .51113 L .55753 .50215 L F
.55782 .50019 m .55753 .50215 L .55999 .47663 L F
.55629 .51676 m .55753 .50215 L .55782 .50019 L F
.55514 .51747 m .55725 .50391 L .55712 .50524 L 0 0 .027 r
F
.55514 .51747 m .55712 .50524 L .55709 .50549 L F
.55727 .50378 m .5573 .5036 L .55709 .50549 L F
.56984 .35493 m .57048 .34794 L .56984 .35928 L 0 0 .028 r
F
.569 .37057 m .56984 .35928 L .56483 .44785 L F
.56984 .35493 m .56984 .35928 L .569 .37057 L F
.57323 .29228 m .57081 .34133 L .56984 .35493 L F
.57081 .34133 m .57048 .34794 L .56984 .35493 L F
.56483 .44785 m .56862 .38089 L .56702 .4113 L F
.56862 .38089 m .57048 .34794 L .56885 .37792 L F
.56862 .38089 m .56885 .37792 L .56702 .4113 L F
.56807 .38778 m .56483 .44785 L .56804 .38817 L F
.56807 .38778 m .56804 .38817 L .56978 .35586 L F
.56235 .45976 m .56466 .43967 L .56287 .45327 L 0 0 0 r
F
.55709 .50549 m .55721 .50446 L .55726 .50395 L F
.55954 .48364 m .56282 .44915 L .5657 .42083 L 0 0 .023 r
F
.56282 .44915 m .56401 .43672 L .5657 .42083 L F
.55629 .51676 m .55802 .49882 L .55812 .49813 L F
.55802 .49882 m .55926 .48594 L .55812 .49813 L F
.55574 .51505 m .55435 .52358 L .55573 .51514 L 0 0 0 r
F
.55182 .53906 m .55595 .51596 L .55435 .52358 L F
.55595 .51596 m .55611 .51449 L .55435 .52358 L F
.56028 .47634 m .56481 .42988 L .56525 .42605 L 0 0 .023 r
F
.56001 .47881 m .56481 .42988 L .56028 .47634 L F
.55709 .50549 m .55726 .50395 L .55745 .50206 L 0 0 0 r
F
.55926 .48594 m .56401 .43672 L .55954 .48364 L 0 0 .023 r
F
.57323 .29228 m .56984 .35493 L .5732 .29243 L 0 0 .028 r
F
.56984 .35493 m .56978 .35586 L .5732 .29243 L F
.5732 .29243 m .56978 .35586 L .57275 .29419 L F
.56978 .35586 m .56483 .44785 L .56903 .36631 L F
.56978 .35586 m .56903 .36631 L .57275 .29419 L F
.56483 .44785 m .56542 .43213 L .56609 .41852 L F
.56628 .41699 m .56609 .41852 L .56855 .36894 L F
.56483 .44785 m .56609 .41852 L .56628 .41699 L F
.56483 .44785 m .56628 .41699 L .5664 .41602 L F
.56628 .41699 m .56855 .36894 L .5664 .41602 L F
.56525 .42605 m .5655 .42334 L .56557 .42277 L 0 0 .023 r
F
.57275 .29419 m .56652 .41496 L .57205 .30168 L 0 0 .028 r
F
.56652 .41496 m .56483 .44785 L .5664 .41602 L F
.56652 .41496 m .5664 .41602 L .57205 .30168 L F
0 g
.5735 .30761 m
.57426 .30044 L
s
.5735 .30761 m
.57388 .29992 L
s
.60076 .29791 m .59869 .33723 L .60304 .29842 L 0 .854 .242 r
F
.60304 .29842 m .59869 .33723 L .60957 .32061 L F
.62235 .2984 m .63269 .39945 L .62264 .29734 L 0 .138 .181 r
F
.62235 .2984 m .62933 .37687 L .63269 .39945 L F
.59981 .29762 m .59869 .33723 L .60076 .29791 L 0 .854 .242 r
F
.62264 .29734 m .62973 .36777 L .6226 .29637 L 0 .138 .181 r
F
.62973 .36777 m .62931 .3634 L .6226 .29637 L F
.62264 .29734 m .63269 .39945 L .63236 .39503 L F
.62931 .36345 m .63109 .38188 L .63182 .38042 L 0 .444 .244 r
F
.63772 .46998 m .64613 .47016 L .64241 .46203 L 0 .912 .305 r
F
.63772 .46998 m .64684 .4891 L .64613 .47016 L F
.63772 .46998 m .64406 .50625 L .64684 .4891 L F
.64304 .42017 m .64241 .46203 L .64613 .47016 L 0 .789 .296 r
F
.64304 .42017 m .64109 .44058 L .64241 .46203 L F
.63182 .38044 m .639 .44121 L .64472 .46848 L 0 .283 .24 r
F
.63162 .38734 m .63236 .39503 L .63225 .39197 L 0 .444 .244 r
F
.639 .44121 m .63685 .42963 L .64176 .46131 L 0 0 .083 r
F
.63182 .38044 m .63353 .40135 L .639 .44121 L 0 .283 .24 r
F
.63353 .40135 m .63388 .40562 L .639 .44121 L F
.63388 .40562 m .6327 .39946 L .63685 .42963 L 0 0 .083 r
F
.6334 .41725 m .64176 .46131 L .63685 .42963 L 0 .125 .189 r
F
.6334 .41725 m .64555 .49022 L .64176 .46131 L F
.64684 .4891 m .64406 .50625 L .64458 .52412 L 0 .89 .314 r
F
.6334 .41725 m .64565 .49677 L .64555 .49022 L 0 .125 .189 r
F
.6334 .41725 m .64214 .48406 L .64565 .49677 L F
.63388 .40562 m .63291 .40967 L .6372 .44612 L 0 .283 .24 r
F
.63182 .38044 m .63236 .39505 L .63388 .40562 L F
.63236 .39505 m .6327 .39946 L .63388 .40562 L 0 0 .083 r
F
.63236 .39505 m .63291 .40967 L .63388 .40562 L 0 .283 .24 r
F
.63203 .39062 m .63236 .39505 L .63388 .40562 L 0 0 .083 r
F
.63203 .39062 m .63388 .40562 L .639 .44121 L F
.63388 .40562 m .63685 .42963 L .639 .44121 L F
.63388 .40562 m .6372 .44612 L .639 .44121 L 0 .283 .24 r
F
.63438 .40773 m .639 .44121 L .63884 .44059 L 0 0 .083 r
F
.639 .44121 m .64176 .46131 L .64129 .45794 L F
.639 .44121 m .6372 .44612 L .64185 .46542 L 0 .283 .24 r
F
.639 .44121 m .64185 .46542 L .64238 .46598 L F
.639 .44121 m .64129 .45794 L .63884 .44059 L 0 0 .083 r
F
.64112 .45672 m .64176 .46131 L .64238 .46598 L F
.639 .44121 m .64238 .46598 L .64472 .46848 L 0 .283 .24 r
F
.63884 .44059 m .64112 .45672 L .64513 .48666 L 0 0 .083 r
F
.64112 .45672 m .64238 .46598 L .64513 .48666 L F
.63203 .39062 m .63438 .40773 L .63884 .44059 L F
.63109 .38188 m .63162 .38734 L .63218 .39011 L 0 .444 .244 r
F
.63162 .38734 m .63225 .39197 L .63218 .39011 L F
.63109 .38188 m .63218 .39011 L .63182 .38042 L F
.6334 .41725 m .6374 .46071 L .64214 .48406 L 0 .125 .189 r
F
.6334 .41725 m .63367 .43214 L .6374 .46071 L F
.63412 .45203 m .64185 .46542 L .6372 .44612 L 0 .51 .269 r
F
.6337 .45506 m .64214 .48406 L .6374 .46071 L 0 .274 .252 r
F
.64684 .4891 m .64807 .53077 L .65297 .52397 L 0 .89 .314 r
F
.64684 .4891 m .64458 .52412 L .64807 .53077 L F
.64555 .49022 m .64565 .49677 L .64925 .51675 L 0 0 .128 r
F
.63412 .45203 m .64564 .49418 L .64185 .46542 L 0 .51 .269 r
F
.63203 .39062 m .63884 .44059 L .64465 .48848 L 0 0 .083 r
F
.63884 .44059 m .64513 .48666 L .64499 .48716 L F
.63884 .44059 m .64499 .48716 L .64465 .48848 L F
.62973 .36777 m .63236 .39503 L .63203 .3906 L 0 .138 .181 r
F
.62264 .29734 m .63236 .39503 L .62973 .36777 L F
.62082 .3302 m .62933 .37687 L .62423 .33839 L 0 .271 .233 r
F
.62082 .3302 m .6334 .41723 L .62933 .37687 L F
.61946 .29671 m .6329 .40965 L .63236 .39503 L 0 .444 .244 r
F
.61946 .29671 m .63236 .39503 L .62931 .36345 L F
.61946 .29671 m .62931 .36345 L .61947 .2967 L F
.62931 .36345 m .63182 .38042 L .62931 .3634 L F
.62931 .36345 m .62931 .3634 L .61947 .2967 L F
.62973 .36777 m .63203 .3906 L .62931 .3634 L 0 .138 .181 r
F
.62082 .3302 m .63367 .43213 L .6334 .41723 L 0 .271 .233 r
F
.62082 .3302 m .63019 .42359 L .63367 .43213 L F
.62082 .3302 m .62532 .3975 L .63019 .42359 L F
.62082 .3302 m .62131 .35749 L .62532 .3975 L F
.62164 .39525 m .63019 .42359 L .62532 .3975 L 0 .389 .258 r
F
.61942 .29673 m .6254 .39921 L .61944 .29672 L 0 .444 .244 r
F
.61942 .29673 m .62081 .34693 L .6254 .39921 L F
.61944 .29672 m .63015 .41774 L .61945 .29672 L F
.61944 .29672 m .6254 .39921 L .63015 .41774 L F
.61945 .29672 m .6329 .40965 L .61946 .29671 L F
.61945 .29672 m .63015 .41774 L .6329 .40965 L F
.6226 .29637 m .626 .32628 L .62275 .29518 L 0 .138 .181 r
F
.626 .32628 m .62561 .32187 L .62275 .29518 L F
.62592 .3232 m .63182 .38042 L .62717 .32832 L 0 .444 .244 r
F
.6265 .33033 m .63182 .38042 L .62592 .3232 L F
.62561 .32192 m .62717 .32832 L .62561 .32187 L F
.6226 .29637 m .62931 .3634 L .626 .32628 L 0 .138 .181 r
F
.62275 .29518 m .62561 .32187 L .62332 .29389 L F
.62561 .32187 m .62592 .32317 L .62523 .31669 L 0 .444 .244 r
F
.62592 .32317 m .62717 .32832 L .62462 .30817 L F
.62561 .32187 m .62462 .30817 L .62332 .29389 L 0 .138 .181 r
F
.62592 .32317 m .62462 .30817 L .62282 .29395 L 0 .444 .244 r
F
.62561 .32192 m .6265 .33033 L .62592 .3232 L F
.62561 .32187 m .62737 .33836 L .62462 .30817 L 0 .138 .181 r
F
.6195 .29667 m .62561 .32187 L .62282 .29395 L 0 .444 .244 r
F
.62561 .32187 m .62523 .31669 L .62282 .29395 L F
.62334 .29361 m .62717 .32832 L .62477 .29269 L 0 .264 .216 r
F
.62332 .29389 m .62462 .30817 L .62334 .29361 L 0 0 .064 r
F
.62282 .29395 m .62462 .30817 L .62334 .29361 L 0 .264 .216 r
F
.62462 .30817 m .62717 .32832 L .62334 .29361 L F
.62334 .29361 m .62462 .30817 L .62335 .29352 L 0 0 .064 r
F
.62335 .29352 m .62538 .3165 L .62343 .29253 L F
.62462 .30817 m .62538 .3165 L .62335 .29352 L F
.62343 .29253 m .62737 .33836 L .62347 .29208 L F
.62538 .3165 m .62737 .33836 L .62343 .29253 L F
.61947 .2967 m .62931 .3634 L .62561 .32192 L 0 .444 .244 r
F
.62931 .3634 m .63182 .38042 L .62561 .32192 L F
.61947 .2967 m .62561 .32192 L .6195 .29667 L F
.62561 .32192 m .62561 .32187 L .6195 .29667 L F
.62324 .2913 m .63095 .39265 L .62281 .28989 L 0 0 .064 r
F
.62347 .29208 m .62437 .30417 L .62324 .2913 L F
.626 .32628 m .63097 .37934 L .62737 .33836 L 0 .138 .181 r
F
.62931 .3634 m .63148 .38518 L .626 .32628 L F
.63148 .38518 m .63203 .3906 L .63097 .37934 L F
.63148 .38518 m .63097 .37934 L .626 .32628 L F
.626 .32628 m .62737 .33836 L .62561 .32187 L F
.62437 .30417 m .62737 .33836 L .63095 .39265 L 0 0 .064 r
F
.62347 .29208 m .62737 .33836 L .62437 .30417 L F
.62437 .30417 m .63095 .39265 L .62324 .2913 L F
.63097 .37934 m .63203 .3906 L .62737 .33836 L 0 .138 .181 r
F
.59498 .29524 m .59559 .36532 L .596 .29636 L 0 .674 .037 r
F
.57275 .29419 m .57205 .30168 L .57242 .29565 L 0 0 .028 r
F
0 g
.57205 .30168 m
.57242 .29565 L
s
.58803 .38811 m .59575 .36994 L .59149 .37069 L 0 .873 .264 r
F
.58803 .38811 m .59867 .38789 L .59575 .36994 L F
.58803 .38811 m .5983 .41271 L .59867 .38789 L F
.58803 .38811 m .59484 .43032 L .5983 .41271 L F
.58803 .38811 m .5906 .42885 L .59484 .43032 L F
.58688 .44157 m .59484 .43032 L .5906 .42885 L 0 .926 .272 r
F
.58688 .44157 m .59741 .44617 L .59484 .43032 L F
.58688 .44157 m .59658 .4659 L .59741 .44617 L F
.58688 .44157 m .59286 .47874 L .59658 .4659 L F
.58688 .44157 m .58871 .47604 L .59286 .47874 L F
.58479 .48557 m .59286 .47874 L .58871 .47604 L 0 .984 .281 r
F
.58479 .48557 m .59503 .49285 L .59286 .47874 L F
.58479 .48557 m .59379 .50903 L .59503 .49285 L F
.58479 .48557 m .58987 .51863 L .59379 .50903 L F
.58479 .48557 m .58588 .5152 L .58987 .51863 L F
.58182 .52243 m .58987 .51863 L .58588 .5152 L 0 1 .29 r
F
.58182 .52243 m .59164 .53135 L .58987 .51863 L F
.58182 .52243 m .59 .54491 L .59164 .53135 L F
.58182 .52243 m .58594 .55218 L .59 .54491 L F
.59255 .29365 m .58916 .54315 L .59498 .29524 L 0 .674 .037 r
F
.59344 .36084 m .58916 .54315 L .59458 .39334 L F
.58803 .38811 m .58768 .41071 L .5906 .42885 L 0 .873 .264 r
F
.59124 .29247 m .58916 .54315 L .59255 .29365 L 0 .674 .037 r
F
.59117 .29212 m .58916 .54315 L .59124 .29247 L F
.59117 .29212 m .59009 .40679 L .58916 .54315 L F
.59141 .2915 m .59009 .40679 L .59117 .29212 L 0 0 .087 r
F
.59258 .44936 m .59252 .45611 L .59429 .40362 L 0 .674 .037 r
F
.59428 .40331 m .59429 .40362 L .59457 .39545 L F
.59258 .44936 m .59429 .40362 L .59428 .40331 L F
.59498 .29524 m .59344 .36084 L .59559 .36532 L F
.59454 .39554 m .59457 .39545 L .59494 .38447 L F
.59258 .44936 m .59457 .39545 L .59454 .39554 L F
.59458 .39334 m .59494 .38447 L .59559 .36532 L F
.59449 .39566 m .59494 .38447 L .59458 .39334 L F
.59259 .44823 m .59453 .39555 L .59449 .39566 L F
.59453 .39555 m .59494 .38447 L .59449 .39566 L F
.58916 .54315 m .59239 .45446 L .59241 .45334 L F
.58916 .54315 m .59228 .4622 L .59239 .45446 L F
.58916 .54315 m .58973 .53337 L .59252 .45611 L F
.59141 .2915 m .59029 .47903 L .59009 .40679 L 0 0 .087 r
F
.59107 .56028 m .59545 .56598 L .59164 .55976 L 0 1 .307 r
F
.58729 .56376 m .59113 .5648 L .59107 .56028 L F
.59113 .5648 m .59545 .56598 L .59107 .56028 L F
.59113 .5648 m .59662 .57908 L .59545 .56598 L F
.58729 .56376 m .5912 .57018 L .59113 .5648 L F
.5912 .57018 m .59662 .57908 L .59113 .5648 L F
.58729 .56376 m .59437 .59034 L .59662 .57908 L F
.58729 .56376 m .59001 .59436 L .59437 .59034 L F
.58729 .56376 m .58646 .58845 L .59001 .59436 L F
.58206 .59149 m .59001 .59436 L .58646 .58845 L 0 1 .317 r
F
.58206 .59149 m .59071 .60612 L .59001 .59436 L F
.58206 .59149 m .58808 .6159 L .59071 .60612 L F
.58206 .59149 m .58368 .61896 L .58808 .6159 L F
.5839 .62964 m .59182 .63458 L .58856 .6281 L 0 1 .337 r
F
.5839 .62964 m .59179 .64559 L .59182 .63458 L F
.5839 .62964 m .58849 .6538 L .59179 .64559 L F
.58576 .6277 m .58776 .58917 L .58759 .58642 L 0 0 .064 r
F
.58776 .58917 m .58877 .56962 L .58768 .58502 L F
.58877 .56962 m .58873 .56898 L .58768 .58502 L F
.58575 .62865 m .58688 .60663 L .58576 .6277 L F
.58688 .60663 m .5891 .56328 L .58688 .60615 L F
.58688 .60663 m .58688 .60615 L .58576 .6277 L F
.58882 .5533 m .58973 .53337 L .58916 .54315 L 0 0 .1 r
F
.58776 .58917 m .58768 .58502 L .58759 .58642 L 0 0 .064 r
F
.5891 .56328 m .58907 .56073 L .58759 .58642 L F
.59164 .53135 m .59 .54491 L .59164 .55976 L 0 .96 .296 r
F
.5839 .62964 m .58382 .65535 L .58849 .6538 L 0 1 .337 r
F
.58493 .65223 m .59054 .53515 L .58553 .63302 L 0 0 .064 r
F
.58724 .60123 m .58759 .58642 L .58767 .58441 L 0 0 .1 r
F
.5878 .58452 m .58767 .58441 L .58845 .56498 L F
.58724 .60123 m .58767 .58441 L .5878 .58452 L F
.59259 .44837 m .59494 .38447 L .59259 .44823 L 0 .674 .037 r
F
.59239 .45446 m .59494 .38447 L .59241 .45334 L F
.59344 .36084 m .59458 .39334 L .59559 .36532 L F
.59054 .53515 m .59869 .33723 L .59559 .36532 L 0 1 .128 r
F
.59867 .38789 m .60671 .38682 L .60227 .37684 L 0 .739 .267 r
F
.59867 .38789 m .60971 .41164 L .60671 .38682 L F
.59867 .38789 m .60925 .43484 L .60971 .41164 L F
.59867 .38789 m .60563 .44604 L .60925 .43484 L F
.59867 .38789 m .60128 .43768 L .60563 .44604 L F
.59867 .38789 m .5983 .41271 L .60128 .43768 L F
.59054 .53515 m .59984 .38886 L .59869 .33723 L 0 1 .128 r
F
.59054 .53515 m .59559 .36532 L .59252 .45611 L F
.59535 .43375 m .59269 .2839 L .59372 .28334 L 0 .267 .202 r
F
.59535 .43375 m .59372 .28334 L .59374 .28438 L F
.5947 .42541 m .59269 .2839 L .59535 .43375 L F
.59669 .36618 m .59529 .28249 L .5959 .28111 L F
.61725 .82834 m .59964 .84549 L .6093 .8439 L 0 1 .458 r
F
.61725 .82834 m .59843 .8416 L .59964 .84549 L F
.61725 .82834 m .60598 .83424 L .59843 .8416 L F
.61351 .81862 m .59662 .8357 L .60598 .83424 L 0 1 .455 r
F
.61351 .81862 m .5954 .83172 L .59662 .8357 L F
.61351 .81862 m .60264 .8244 L .5954 .83172 L F
.60976 .80879 m .60264 .8244 L .61351 .81862 L 0 1 .453 r
F
.60976 .80879 m .59358 .82571 L .60264 .8244 L F
.60976 .80879 m .59237 .82166 L .59358 .82571 L F
.60976 .80879 m .5993 .81441 L .59237 .82166 L F
.606 .79889 m .5993 .81441 L .60976 .80879 L 0 1 .451 r
F
.606 .79889 m .59054 .81554 L .5993 .81441 L F
.606 .79889 m .58932 .81144 L .59054 .81554 L F
.606 .79889 m .59595 .8043 L .58932 .81144 L F
.60223 .78901 m .59595 .8043 L .606 .79889 L F
.60223 .78901 m .606 .79889 L .61232 .79192 L F
.60223 .78901 m .61232 .79192 L .61069 .78805 L F
.59846 .77933 m .60223 .78901 L .60824 .7823 L 0 1 .454 r
F
.59846 .77933 m .60824 .7823 L .60661 .7785 L F
.59468 .77013 m .59846 .77933 L .60416 .77292 L 0 1 .463 r
F
.59468 .77013 m .60416 .77292 L .60253 .76927 L F
.61607 .75456 m .60253 .76927 L .60416 .77292 L 0 1 .448 r
F
.61607 .75456 m .60763 .7614 L .60253 .76927 L F
.61128 .74543 m .60008 .76397 L .60763 .7614 L 0 1 .447 r
F
.61128 .74543 m .59844 .76056 L .60008 .76397 L F
.61128 .74543 m .60324 .75261 L .59844 .76056 L F
.60539 .73472 m .59571 .75512 L .60324 .75261 L 0 1 .439 r
F
.60539 .73472 m .5937 .75128 L .59571 .75512 L F
.60539 .73472 m .59785 .74254 L .5937 .75128 L F
.6009 .72688 m .60539 .73472 L .60961 .72636 L 0 1 .427 r
F
.6009 .72688 m .59785 .74254 L .60539 .73472 L F
.6009 .72688 m .60961 .72636 L .6077 .72305 L F
.5964 .71924 m .6009 .72688 L .60483 .71812 L 0 1 .411 r
F
.5964 .71924 m .60483 .71812 L .60291 .71487 L F
.61861 .90966 m .60069 .92147 L .61048 .92087 L 0 1 .504 r
F
.61861 .90966 m .59948 .91839 L .60069 .92147 L F
.60723 .68622 m .60004 .71005 L .60627 .705 L 0 1 .384 r
F
.61861 .90966 m .61048 .92087 L .62235 .917 L 0 1 .504 r
F
.61865 .91203 m .60074 .925 L .61053 .92391 L 0 1 .506 r
F
.61865 .91203 m .59953 .92213 L .60074 .925 L F
.61861 .90966 m .60715 .91333 L .59948 .91839 L 0 1 .504 r
F
.60723 .68622 m .59812 .70687 L .60004 .71005 L 0 1 .384 r
F
.60723 .68622 m .6012 .69665 L .59812 .70687 L F
.60179 .67753 m .6012 .69665 L .60723 .68622 L 0 1 .37 r
F
.60261 .62967 m .59862 .6581 L .60401 .65126 L 0 1 .336 r
F
.60261 .62967 m .59633 .65479 L .59862 .6581 L F
.60261 .62967 m .59805 .64259 L .59633 .65479 L F
.58973 .91837 m .59244 .92622 L .60069 .92147 L 0 1 .498 r
F
.58973 .91837 m .60069 .92147 L .59948 .91839 L F
.61865 .91203 m .6072 .91657 L .59953 .92213 L 0 1 .506 r
F
.59636 .66912 m .60432 .66671 L .60204 .66321 L 0 1 .356 r
F
.59636 .66912 m .60179 .67753 L .60432 .66671 L F
.60179 .67753 m .59524 .70214 L .6012 .69665 L 0 1 .37 r
F
.61486 .90228 m .59766 .91375 L .60715 .91333 L 0 1 .503 r
F
.61486 .90228 m .59644 .91062 L .59766 .91375 L F
.60179 .67753 m .59332 .69902 L .59524 .70214 L 0 1 .37 r
F
.60179 .67753 m .59613 .68846 L .59332 .69902 L F
.59636 .66912 m .59613 .68846 L .60179 .67753 L 0 1 .356 r
F
.61486 .90228 m .60715 .91333 L .61861 .90966 L 0 1 .503 r
F
.61489 .90431 m .59771 .9178 L .6072 .91657 L 0 1 .502 r
F
.61486 .90228 m .60381 .90571 L .59644 .91062 L 0 1 .503 r
F
.61489 .90431 m .5965 .91489 L .59771 .9178 L 0 1 .502 r
F
.61489 .90431 m .60386 .90911 L .5965 .91489 L F
.6111 .8949 m .60381 .90571 L .61486 .90228 L 0 1 .503 r
F
.60722 .90065 m .59462 .90592 L .60381 .90571 L F
.6111 .8949 m .60706 .89759 L .60722 .90065 L F
.60706 .89759 m .59462 .90592 L .60722 .90065 L F
.58493 .65223 m .59106 .54728 L .59054 .53515 L 0 0 .064 r
F
.58736 .7043 m .57952 .7267 L .58548 .72139 L 0 1 .376 r
F
.58283 .69705 m .59043 .69441 L .58851 .69138 L 0 1 .359 r
F
.58283 .69705 m .58736 .7043 L .59043 .69441 L F
.58736 .7043 m .57797 .72409 L .57952 .7267 L 0 1 .376 r
F
.58736 .7043 m .58134 .71448 L .57797 .72409 L F
.58283 .69705 m .58134 .71448 L .58736 .7043 L 0 1 .359 r
F
.58283 .69705 m .57565 .72018 L .58134 .71448 L F
.5783 .69011 m .58562 .68695 L .58369 .68407 L 0 1 .342 r
F
.5783 .69011 m .58283 .69705 L .58562 .68695 L F
.58283 .69705 m .5741 .71758 L .57565 .72018 L 0 1 .359 r
F
.58283 .69705 m .57718 .70765 L .5741 .71758 L F
.5783 .69011 m .57718 .70765 L .58283 .69705 L 0 1 .342 r
F
.59091 .66117 m .59105 .68053 L .59636 .66912 L 0 1 .341 r
F
.59091 .66117 m .58562 .68695 L .59105 .68053 L F
.59091 .66117 m .58369 .68407 L .58562 .68695 L F
.59091 .66117 m .58596 .67301 L .58369 .68407 L F
.58329 .66539 m .59113 .67123 L .5882 .66479 L 0 1 .357 r
F
.58329 .66539 m .59032 .68126 L .59113 .67123 L F
.58329 .66539 m .58632 .6882 L .59032 .68126 L F
.58329 .66539 m .58141 .6888 L .58632 .6882 L F
.58009 .69798 m .58761 .70384 L .58516 .69787 L 0 1 .376 r
F
.58736 .7043 m .59524 .70214 L .59332 .69902 L F
.58736 .7043 m .59188 .71172 L .59524 .70214 L F
.58736 .7043 m .58548 .72139 L .59188 .71172 L F
.58009 .69798 m .58592 .71272 L .58761 .70384 L F
.59188 .71172 m .58183 .73061 L .58337 .7332 L 0 1 .393 r
F
.59188 .71172 m .58548 .72139 L .58183 .73061 L F
.57565 .73564 m .58337 .7332 L .58183 .73061 L 0 1 .382 r
F
.58592 .71272 m .57926 .72732 L .58132 .73306 L 0 1 .383 r
F
.57208 .72943 m .57952 .7267 L .57797 .72409 L 0 1 .368 r
F
.57208 .72943 m .57565 .73564 L .57952 .7267 L F
.58592 .71272 m .58123 .71861 L .57926 .72732 L 0 1 .383 r
F
.58009 .69798 m .58123 .71861 L .58592 .71272 L 0 1 .376 r
F
.57801 .36973 m .58519 .38059 L .58824 .34999 L 0 1 .251 r
F
.58688 .44157 m .58615 .46008 L .58871 .47604 L 0 .926 .272 r
F
.58788 .31743 m .58823 .46658 L .58832 .49872 L 0 0 .087 r
F
.58788 .31743 m .58832 .49872 L .58837 .50223 L F
.5878 .28685 m .58837 .50223 L .58783 .28743 L F
.58837 .50223 m .58838 .5037 L .58783 .28743 L F
.59071 .60612 m .58808 .6159 L .58856 .6281 L 0 1 .326 r
F
.58838 .50594 m .58849 .54904 L .58839 .50741 L 0 0 .087 r
F
.58928 .58233 m .58862 .59927 L .58933 .58421 L 0 0 .064 r
F
.58274 .68779 m .58785 .6192 L .58862 .59927 L 0 0 .001 r
F
.58273 .68805 m .58946 .5975 L .58274 .68779 L F
.5826 .69084 m .58946 .5975 L .58266 .68896 L F
.58809 .6021 m .58862 .59927 L .58939 .5796 L 0 0 .064 r
F
.58934 .57901 m .58939 .5796 L .5896 .57421 L F
.58809 .6021 m .58939 .5796 L .58934 .57901 L F
.58785 .6192 m .58946 .5975 L .58862 .59927 L 0 0 .001 r
F
.58946 .5975 m .58939 .59132 L .58862 .59927 L F
.58686 .54089 m .58792 .56299 L .58793 .562 L 0 .091 .152 r
F
.58686 .54089 m .58724 .54832 L .58686 .54086 L F
.59071 .60612 m .59182 .63458 L .59646 .63245 L 0 1 .326 r
F
.59071 .60612 m .58856 .6281 L .59182 .63458 L F
.58724 .54832 m .58771 .55776 L .58724 .54828 L 0 .091 .152 r
F
.58934 .61331 m .58901 .62621 L .59072 .60081 L 0 0 .001 r
F
.58934 .61331 m .59072 .60081 L .59058 .59883 L F
.58896 .62833 m .59137 .61151 L .58901 .62621 L 0 .742 .063 r
F
.58851 .63424 m .59137 .61151 L .58847 .63174 L F
.59137 .61151 m .59133 .61098 L .58901 .62621 L F
.5938 .60794 m .5994 .62314 L .59892 .61096 L 0 1 .326 r
F
.59071 .60612 m .59376 .61211 L .5938 .60794 L F
.59376 .61211 m .5994 .62314 L .5938 .60794 L F
.58706 .65167 m .59139 .61192 L .58723 .64438 L 0 .742 .063 r
F
.59376 .61211 m .59646 .63245 L .5994 .62314 L 0 1 .326 r
F
.59071 .60612 m .5937 .6198 L .59376 .61211 L F
.5937 .6198 m .59646 .63245 L .59376 .61211 L F
.59587 .86042 m .60548 .86251 L .60382 .85839 L 0 1 .448 r
F
.61725 .82834 m .6093 .8439 L .62098 .8379 L 0 1 .458 r
F
.61269 .83384 m .60132 .85192 L .609 .85091 L 0 1 .433 r
F
.61269 .83384 m .59964 .84742 L .60132 .85192 L F
.61269 .83384 m .60452 .83967 L .59964 .84742 L F
.60666 .81897 m .59684 .83944 L .60452 .83966 L 0 1 .421 r
F
.5861 .83262 m .58881 .84268 L .59662 .8357 L 0 1 .453 r
F
.5861 .83262 m .59662 .8357 L .5954 .83172 L F
.60666 .81897 m .59478 .83333 L .59684 .83944 L 0 1 .421 r
F
.60666 .81897 m .59898 .82455 L .59478 .83333 L F
.60204 .80688 m .59898 .82455 L .60665 .81897 L 0 1 .412 r
F
.58337 .8223 m .59358 .82571 L .59237 .82166 L 0 1 .448 r
F
.60204 .80688 m .59204 .82496 L .59898 .82455 L 0 1 .412 r
F
.60204 .80688 m .59046 .81993 L .59204 .82496 L F
.60204 .80688 m .59474 .81218 L .59046 .81993 L F
.60223 .78901 m .58754 .80521 L .59595 .8043 L 0 1 .451 r
F
.58754 .80521 m .58749 .80526 L .58754 .80526 L F
.58754 .80521 m .58754 .80526 L .59595 .8043 L F
.60223 .78901 m .58627 .80114 L .58749 .80526 L F
.59741 .79426 m .59474 .81218 L .60204 .80688 L 0 1 .407 r
F
.59741 .79426 m .60204 .80688 L .60604 .79917 L F
.61758 .84505 m .60382 .85839 L .60548 .86251 L 0 1 .445 r
F
.61758 .84505 m .609 .85091 L .60382 .85839 L F
.60709 .84783 m .5971 .85912 L .60478 .8578 L 0 1 .52 r
F
.58881 .84268 m .59152 .85249 L .59964 .84549 L 0 1 .457 r
F
.59201 .84914 m .59587 .86042 L .60132 .85192 L 0 1 .426 r
F
.60709 .84783 m .59508 .85698 L .5971 .85912 L 0 1 .52 r
F
.59201 .84914 m .60132 .85192 L .59964 .84742 L 0 1 .426 r
F
.60709 .84783 m .59936 .85214 L .59508 .85698 L 0 1 .52 r
F
.60257 .84372 m .59936 .85214 L .60709 .84783 L 0 1 .503 r
F
.58881 .84268 m .57949 .85794 L .59152 .85249 L 0 1 .457 r
F
.59201 .84914 m .58694 .86724 L .59587 .86042 L 0 1 .426 r
F
.60257 .84372 m .59241 .85435 L .59936 .85214 L 0 1 .503 r
F
.59201 .84914 m .5795 .86866 L .58694 .86724 L 0 1 .426 r
F
.5795 .86866 m .5793 .86877 L .5801 .86879 L 0 1 .542 r
F
.5795 .86866 m .5793 .86897 L .5801 .86879 L 0 1 .426 r
F
.5795 .86866 m .5801 .86879 L .58694 .86724 L F
.57325 .86868 m .57602 .87691 L .58237 .87498 L 0 .976 .444 r
F
.57325 .86868 m .58237 .87498 L .58114 .87229 L F
.59587 .86042 m .58694 .86724 L .58476 .87024 L 0 1 .448 r
F
.58731 .87219 m .58114 .87229 L .58237 .87498 L 0 1 .528 r
F
.58551 .87082 m .58114 .87229 L .58731 .87219 L F
.59587 .86042 m .58476 .87024 L .58551 .87082 L 0 1 .448 r
F
.59587 .86042 m .59128 .87415 L .59971 .87044 L F
.59128 .87415 m .59034 .87551 L .59303 .87494 L 0 1 .528 r
F
.59128 .87415 m .59303 .87494 L .59324 .8749 L F
.57602 .87691 m .58544 .8823 L .58421 .87927 L 0 1 .464 r
F
.57878 .88539 m .58851 .89009 L .58728 .88693 L 0 1 .477 r
F
.59624 .87892 m .58544 .8823 L .59372 .88277 L 0 1 .513 r
F
.59971 .87044 m .59658 .87839 L .60353 .87959 L 0 1 .466 r
F
.60152 .88168 m .58728 .88693 L .58851 .89009 L 0 1 .506 r
F
.58153 .89386 m .59157 .89801 L .59035 .89483 L 0 1 .484 r
F
.60732 .88756 m .59035 .89483 L .59157 .89801 L 0 1 .503 r
F
.60732 .88756 m .59709 .89035 L .59035 .89483 L F
.60634 .88568 m .59709 .89035 L .60732 .88756 L 0 1 .506 r
F
.60565 .88438 m .60232 .88228 L .60634 .88568 L F
.60232 .88228 m .59709 .89035 L .60634 .88568 L F
.60565 .88438 m .60225 .88243 L .60692 .88725 L 0 1 .48 r
F
.60523 .88342 m .60234 .88222 L .60565 .88438 L F
.60353 .87959 m .60248 .88191 L .60523 .88342 L F
.60248 .88191 m .60234 .88222 L .60523 .88342 L F
.60214 .88256 m .58851 .89009 L .59709 .89035 L 0 1 .506 r
F
.60206 .88242 m .58851 .89009 L .60214 .88256 L F
.60164 .88161 m .58851 .89009 L .60206 .88242 L F
.60164 .88161 m .60206 .88242 L .60232 .88228 L F
.60118 .88133 m .58728 .88693 L .60152 .88168 L F
.60144 .88124 m .59376 .88556 L .58735 .89238 L 0 1 .48 r
F
.60023 .8803 m .60115 .88096 L .60139 .8809 L 0 1 .513 r
F
.59658 .87839 m .60139 .8809 L .60353 .87959 L 0 1 .466 r
F
.59713 .87876 m .60115 .88096 L .59859 .87912 L 0 1 .513 r
F
.59645 .87858 m .59825 .87949 L .59713 .87876 L F
.59825 .87949 m .60115 .88096 L .59713 .87876 L F
.59645 .87858 m .60088 .88103 L .60115 .88096 L F
.60353 .87959 m .60139 .8809 L .60158 .88114 L 0 1 .48 r
F
.60353 .87959 m .60149 .8812 L .60164 .88161 L F
.60353 .87959 m .60181 .88143 L .60248 .88191 L F
.60354 .88038 m .60137 .88125 L .60164 .88161 L 0 1 .506 r
F
.60149 .8812 m .60144 .88124 L .60164 .88161 L 0 1 .48 r
F
.60149 .8812 m .59372 .88277 L .58728 .88693 L 0 1 .506 r
F
.60354 .88038 m .60139 .8809 L .60149 .8812 L F
.60139 .8809 m .59372 .88277 L .60149 .8812 L F
.59976 .87352 m .59645 .87858 L .60354 .88038 L 0 1 .513 r
F
.59645 .87858 m .59372 .88277 L .60088 .88103 L F
.59658 .87839 m .59498 .87742 L .59624 .87892 L F
.59444 .87678 m .58544 .8823 L .59624 .87892 L F
.59658 .87839 m .5855 .88754 L .59376 .88556 L 0 1 .466 r
F
.59513 .8773 m .59444 .87678 L .59498 .87742 L 0 1 .513 r
F
.59971 .87044 m .59444 .87678 L .59658 .87839 L 0 1 .466 r
F
.59976 .87352 m .59444 .87678 L .59513 .8773 L 0 1 .513 r
F
.59976 .87352 m .59498 .87742 L .59658 .87839 L F
.59444 .87678 m .59434 .87691 L .59658 .87839 L 0 1 .466 r
F
.59434 .87691 m .5855 .88754 L .59658 .87839 L F
.59658 .87839 m .60106 .8811 L .60139 .8809 L F
.59859 .87912 m .60023 .8803 L .60139 .8809 L 0 1 .513 r
F
.6003 .87956 m .60139 .8809 L .60354 .88038 L F
.59859 .87912 m .60139 .8809 L .6003 .87956 L F
.60158 .88114 m .60129 .88096 L .60144 .88124 L 0 1 .48 r
F
.60139 .8809 m .60129 .88096 L .60158 .88114 L F
.60129 .88096 m .59376 .88556 L .60144 .88124 L F
.60164 .88161 m .58735 .89238 L .58857 .89549 L F
.60164 .88161 m .60118 .88133 L .60152 .88168 L 0 1 .506 r
F
.60137 .88125 m .60118 .88133 L .60164 .88161 L F
.60144 .88124 m .58735 .89238 L .60164 .88161 L 0 1 .48 r
F
.60232 .88228 m .60206 .88242 L .60214 .88256 L 0 1 .506 r
F
.60248 .88191 m .60164 .88161 L .60232 .88228 L 0 1 .48 r
F
.60181 .88143 m .60164 .88161 L .60248 .88191 L F
.60354 .88038 m .60164 .88161 L .60232 .88228 L 0 1 .506 r
F
.60232 .88228 m .60164 .88161 L .60225 .88243 L 0 1 .48 r
F
.60353 .87959 m .60565 .88438 L .61375 .88137 L F
.60565 .88438 m .60732 .88756 L .60884 .88658 L 0 1 .506 r
F
.60732 .88756 m .60046 .89804 L .6111 .8949 L 0 1 .503 r
F
.60732 .88756 m .59157 .89801 L .60046 .89804 L F
.60732 .88756 m .6111 .8949 L .61636 .89141 L F
.6136 .88926 m .61636 .89141 L .61649 .89129 L 0 1 .49 r
F
.6136 .88926 m .61649 .89129 L .61785 .89 L F
.61076 .88757 m .61785 .89 L .61621 .8866 L F
.60732 .88756 m .6136 .88926 L .61076 .88757 L 0 1 .503 r
F
.60732 .88756 m .61636 .89141 L .6136 .88926 L F
.60733 .88818 m .6136 .88926 L .61076 .88757 L 0 1 .49 r
F
.6136 .88926 m .61785 .89 L .61076 .88757 L F
.61076 .88757 m .6136 .88926 L .61119 .88757 L 0 1 .503 r
F
.61119 .88757 m .61786 .89042 L .61623 .88759 L F
.6136 .88926 m .61786 .89042 L .61119 .88757 L F
.6136 .88926 m .61636 .89141 L .61786 .89042 L F
.6111 .8949 m .5934 .90276 L .59462 .90592 L F
.6111 .8949 m .61486 .90228 L .62193 .89756 L F
.6111 .8949 m .60046 .89804 L .5934 .90276 L F
.6111 .8949 m .62193 .89756 L .62031 .89469 L F
.60733 .88818 m .61112 .89639 L .61636 .89141 L 0 1 .49 r
F
.60733 .88818 m .61636 .89141 L .6136 .88926 L F
.60565 .88438 m .60733 .88818 L .60884 .88658 L 0 1 .48 r
F
.60565 .88438 m .60884 .88658 L .61375 .88137 L F
.60565 .88438 m .60884 .88658 L .60893 .88653 L 0 1 .506 r
F
.60354 .88038 m .60565 .88438 L .61378 .8834 L F
.60565 .88438 m .60893 .88653 L .61378 .8834 L F
.60234 .88222 m .60232 .88228 L .60565 .88438 L 0 1 .48 r
F
.60232 .88228 m .60225 .88243 L .60565 .88438 L F
.60354 .88038 m .60232 .88228 L .60565 .88438 L 0 1 .506 r
F
.60182 .88185 m .58857 .89549 L .60225 .88243 L 0 1 .48 r
F
.60164 .88161 m .60159 .88166 L .60182 .88185 L F
.60159 .88166 m .58857 .89549 L .60182 .88185 L F
.60225 .88243 m .58857 .89549 L .59714 .8937 L F
.60692 .88725 m .59714 .8937 L .60733 .88818 L F
.60225 .88243 m .59714 .8937 L .60692 .88725 L F
.59658 .87839 m .59376 .88556 L .60106 .8811 L 0 1 .466 r
F
.59971 .87044 m .59377 .87574 L .59444 .87678 L F
.59444 .87678 m .58421 .87927 L .58544 .8823 L 0 1 .513 r
F
.59976 .87352 m .59377 .87574 L .59444 .87678 L F
.59377 .87574 m .58421 .87927 L .59444 .87678 L F
.59377 .87574 m .59034 .87551 L .58421 .87927 L F
.59377 .87574 m .59036 .87688 L .58427 .88422 L 0 1 .466 r
F
.59971 .87044 m .59324 .8749 L .59403 .87551 L F
.59198 .87405 m .59324 .8749 L .59971 .87044 L 0 1 .448 r
F
.59217 .87408 m .59324 .8749 L .59976 .87352 L 0 1 .528 r
F
.59119 .87442 m .59324 .8749 L .59198 .87405 L 0 1 .448 r
F
.59128 .87415 m .59324 .8749 L .59217 .87408 L 0 1 .528 r
F
.59403 .87551 m .59324 .8749 L .59377 .87574 L 0 1 .466 r
F
.59366 .87556 m .59034 .87551 L .59377 .87574 L 0 1 .513 r
F
.59324 .8749 m .59034 .87551 L .59422 .87557 L F
.59324 .8749 m .59036 .87688 L .59377 .87574 L 0 1 .466 r
F
.59377 .87574 m .59365 .87585 L .59444 .87678 L F
.59365 .87585 m .58427 .88422 L .59444 .87678 L F
.59444 .87678 m .58427 .88422 L .5855 .88754 L F
.59422 .87557 m .59366 .87556 L .59377 .87574 L 0 1 .513 r
F
.59976 .87352 m .59324 .8749 L .59422 .87557 L F
.59119 .87442 m .59278 .87521 L .59324 .8749 L 0 1 .448 r
F
.59128 .87415 m .58237 .87498 L .59034 .87551 L 0 1 .528 r
F
.59587 .86042 m .58731 .87219 L .59128 .87415 L 0 1 .448 r
F
.59596 .86729 m .58731 .87219 L .59128 .87415 L 0 1 .528 r
F
.58731 .87219 m .58237 .87498 L .59039 .87423 L F
.58731 .87219 m .58117 .87517 L .58241 .87891 L 0 1 .448 r
F
.59587 .86042 m .58551 .87082 L .58731 .87219 L F
.59596 .86729 m .58696 .86899 L .58476 .87024 L 0 1 .528 r
F
.58501 .87043 m .58476 .87024 L .58383 .87077 L F
.59596 .86729 m .58476 .87024 L .58501 .87043 L F
.58551 .87082 m .5854 .87093 L .58731 .87219 L 0 1 .448 r
F
.5854 .87093 m .58117 .87517 L .58731 .87219 L F
.58731 .87219 m .59039 .87423 L .59128 .87415 L 0 1 .528 r
F
.58731 .87219 m .58722 .87231 L .59128 .87415 L 0 1 .448 r
F
.59128 .87415 m .58241 .87891 L .59036 .87688 L F
.58722 .87231 m .58241 .87891 L .59128 .87415 L F
.59128 .87415 m .59119 .87442 L .59155 .87425 L F
.59128 .87415 m .59155 .87425 L .59971 .87044 L F
.59596 .86729 m .59128 .87415 L .59976 .87352 L 0 1 .528 r
F
.58457 .87113 m .58383 .87077 L .58114 .87229 L F
.59596 .86729 m .58383 .87077 L .58457 .87113 L F
.59119 .87442 m .59036 .87688 L .59278 .87521 L 0 1 .448 r
F
.58551 .87082 m .58476 .87024 L .58117 .87517 L F
.59596 .86729 m .58551 .87082 L .58731 .87219 L 0 1 .528 r
F
.59217 .86209 m .5795 .86866 L .58696 .86899 L 0 1 .542 r
F
.5795 .86866 m .5801 .86879 L .58696 .86899 L F
.60257 .84372 m .59087 .853 L .59241 .85435 L 0 1 .503 r
F
.60257 .84372 m .59522 .84844 L .59087 .853 L F
.58881 .84268 m .59964 .84549 L .59843 .8416 L 0 1 .457 r
F
.59803 .83993 m .59522 .84844 L .60257 .84372 L 0 1 .484 r
F
.61351 .81862 m .60598 .83424 L .61725 .82834 L 0 1 .455 r
F
.60666 .81897 m .60452 .83966 L .61269 .83384 L 0 1 .421 r
F
.59803 .83993 m .60257 .84372 L .60664 .83894 L 0 1 .484 r
F
.59803 .83993 m .60664 .83894 L .60471 .8373 L F
.58723 .83317 m .59684 .83944 L .59478 .83333 L 0 1 .402 r
F
.59349 .83636 m .59803 .83993 L .60181 .83491 L 0 1 .468 r
F
.59349 .83636 m .60181 .83491 L .59988 .83338 L F
.61351 .81862 m .61725 .82834 L .62449 .82102 L 0 1 .455 r
F
.60666 .81897 m .61269 .83384 L .6169 .82507 L 0 1 .421 r
F
.60932 .82158 m .59988 .83338 L .60181 .83491 L 0 1 .474 r
F
.60932 .82158 m .60309 .82766 L .59988 .83338 L F
.60383 .8176 m .59697 .83114 L .60309 .82766 L 0 1 .46 r
F
.60383 .8176 m .59503 .8297 L .59697 .83114 L F
.60383 .8176 m .59797 .82389 L .59503 .8297 L F
.60976 .80879 m .61351 .81862 L .62045 .81137 L 0 1 .453 r
F
.60204 .80688 m .60665 .81897 L .61094 .81122 L 0 1 .412 r
F
.59834 .81393 m .60383 .8176 L .6065 .81174 L 0 1 .445 r
F
.59834 .81393 m .59797 .82389 L .60383 .8176 L F
.59834 .81393 m .6065 .81174 L .60419 .81022 L F
.58064 .81174 m .59054 .81554 L .58932 .81144 L 0 1 .443 r
F
.59741 .79426 m .58809 .81224 L .59474 .81218 L 0 1 .407 r
F
.59306 .81059 m .59834 .81393 L .60073 .80808 L 0 1 .429 r
F
.59283 .81067 m .59305 .8108 L .59306 .81059 L F
.59305 .8108 m .59834 .81393 L .59306 .81059 L F
.59306 .8105 m .60073 .80808 L .59842 .80674 L F
.59283 .81067 m .59306 .81059 L .59306 .8105 L F
.59306 .81059 m .60073 .80808 L .59306 .8105 L F
.59741 .79426 m .60604 .79917 L .60408 .79421 L 0 1 .407 r
F
.606 .79889 m .60976 .80879 L .61639 .80165 L 0 1 .451 r
F
.606 .79889 m .61639 .80165 L .61476 .79775 L F
.62563 .7736 m .61069 .78805 L .61232 .79192 L 0 1 .448 r
F
.62563 .7736 m .61639 .78019 L .61069 .78805 L F
.61405 .78095 m .60408 .79421 L .60604 .79917 L 0 1 .41 r
F
.60503 .79303 m .59842 .80674 L .60073 .80808 L 0 1 .423 r
F
.60503 .79303 m .60026 .80029 L .59842 .80674 L F
.60223 .78901 m .59259 .79418 L .58627 .80114 L 0 1 .451 r
F
.59846 .77933 m .59259 .79418 L .60223 .78901 L 0 1 .454 r
F
.59846 .77933 m .58444 .79501 L .59259 .79418 L F
.59846 .77933 m .58322 .79097 L .58444 .79501 L F
.59846 .77933 m .58922 .78425 L .58322 .79097 L F
.59468 .77013 m .58922 .78425 L .59846 .77933 L 0 1 .463 r
F
.59278 .78128 m .59741 .79426 L .60113 .78663 L 0 1 .404 r
F
.59836 .78999 m .60026 .80029 L .60384 .79484 L 0 1 .406 r
F
.61405 .78095 m .60751 .7864 L .60408 .79421 L 0 1 .41 r
F
.60364 .79239 m .60384 .79484 L .60503 .79303 L 0 1 .406 r
F
.59836 .78999 m .60384 .79484 L .60364 .79239 L F
.59139 .61192 m .59137 .61151 L .58723 .64438 L 0 .742 .063 r
F
.58652 .63751 m .59184 .58406 L .59161 .56823 L 0 0 .001 r
F
.58432 .67409 m .58706 .65167 L .58723 .64438 L 0 .742 .063 r
F
.58417 .67802 m .58706 .65167 L .58432 .67409 L F
.58189 .69904 m .58706 .65167 L .58191 .69868 L F
.58191 .69868 m .58417 .67802 L .58432 .67409 L F
.58176 .70021 m .59179 .62211 L .59191 .60715 L F
.58172 .70056 m .58176 .70028 L .58176 .70021 L F
.58176 .70028 m .59179 .62211 L .58176 .70021 L F
.58318 .68301 m .58659 .64552 L .58652 .63751 L 0 0 .001 r
F
.58399 .68287 m .58709 .66427 L .58709 .66371 L 0 .742 .063 r
F
.59179 .64559 m .58849 .6538 L .5882 .66479 L 0 1 .346 r
F
.58399 .68287 m .58879 .65318 L .58873 .64591 L 0 .742 .063 r
F
.58386 .68634 m .58861 .65514 L .58399 .68287 L F
.58186 .69968 m .58821 .65775 L .58187 .6994 L F
.58821 .65775 m .58861 .65514 L .58821 .65774 L F
.58821 .65775 m .58821 .65774 L .58187 .6994 L F
.58716 .63884 m .58901 .62621 L .58934 .61331 L 0 0 .001 r
F
.58187 .6994 m .58386 .68634 L .58399 .68287 L 0 .742 .063 r
F
.58437 .67322 m .58723 .64438 L .58497 .66701 L F
.58192 .69852 m .58432 .67406 L .58437 .67322 L F
.58432 .67406 m .58723 .64438 L .58437 .67322 L F
.58191 .69868 m .58723 .64438 L .58192 .69852 L F
.58723 .64438 m .58712 .64531 L .58497 .66701 L F
.58723 .64438 m .58901 .62621 L .58712 .64531 L F
.58441 .67421 m .58497 .66701 L .58735 .64295 L 0 0 .001 r
F
.58441 .67421 m .58735 .64295 L .58718 .64537 L F
.58297 .68788 m .58507 .66658 L .58526 .66107 L F
.58507 .66658 m .58659 .6512 L .58526 .66107 L F
.58526 .66107 m .58659 .6512 L .58678 .64333 L F
.58297 .68788 m .58659 .64552 L .58318 .68301 L F
.58487 .66491 m .58533 .64924 L .58789 .61032 L 0 0 .064 r
F
.58763 .61662 m .58789 .61032 L .58862 .59927 L F
.58487 .66491 m .58789 .61032 L .58763 .61662 L F
.58549 .6541 m .58724 .62349 L .58563 .64982 L F
.58383 .68691 m .58446 .68442 L .58716 .66534 L 0 .742 .063 r
F
.58374 .68868 m .58446 .68442 L .58383 .68691 L F
.58385 .68651 m .58716 .66534 L .58708 .6652 L F
.58172 .70056 m .58383 .68691 L .58385 .68651 L F
.58383 .68691 m .58716 .66534 L .58385 .68651 L F
.58172 .70056 m .58374 .68868 L .58383 .68691 L F
.58184 .69988 m .58149 .704 L .58446 .68442 L F
.58172 .70056 m .58157 .70282 L .58184 .69988 L F
.58157 .70282 m .58149 .704 L .58184 .69988 L F
.58214 .69794 m .5844 .67325 L .58441 .67421 L 0 0 .001 r
F
.58211 .69816 m .5844 .67325 L .58214 .69794 L F
.5844 .67325 m .58497 .66701 L .58441 .67421 L F
.58188 .70058 m .58189 .6991 L .5825 .6928 L F
.58274 .69127 m .5825 .6928 L .58497 .66701 L F
.58188 .70058 m .5825 .6928 L .58274 .69127 L F
.58283 .69068 m .58718 .64537 L .58297 .68788 L F
.58718 .64537 m .58718 .64529 L .58297 .68788 L F
.58549 .6541 m .58501 .65991 L .58497 .66132 L 0 0 .064 r
F
.58549 .6541 m .58563 .64982 L .58501 .65991 L F
.58192 .70025 m .5844 .67325 L .58192 .70021 L 0 0 .001 r
F
.58372 .68487 m .58533 .64924 L .58487 .66491 L 0 0 .064 r
F
.58496 .66327 m .58549 .6541 L .58466 .6658 L F
.58724 .62349 m .58726 .62236 L .58451 .66814 L F
.58808 .60877 m .58809 .60812 L .58451 .66814 L F
.58331 .68868 m .58533 .64924 L .58372 .68487 L F
.58849 .54904 m .58852 .562 L .5885 .54954 L 0 0 .087 r
F
.58719 .66542 m .5901 .64978 L .58861 .65514 L 0 .902 .101 r
F
.5901 .64978 m .59008 .64867 L .58861 .65514 L F
.58717 .67025 m .59132 .64325 L .58719 .66542 L F
.58476 .66035 m .58491 .65562 L .58533 .64924 L 0 0 .064 r
F
.58117 .70904 m .58717 .67025 L .58719 .66542 L 0 .902 .101 r
F
.58094 .71071 m .58116 .70926 L .58117 .70904 L F
.58116 .70926 m .58717 .67025 L .58117 .70904 L F
.59091 .66117 m .59862 .6581 L .59633 .65479 L 0 1 .341 r
F
.59091 .66117 m .59636 .66912 L .59862 .6581 L F
.59179 .64559 m .5882 .66479 L .59113 .67123 L 0 1 .346 r
F
.58094 .71071 m .59083 .65646 L .59132 .64325 L 0 .902 .101 r
F
.58712 .60493 m .58786 .58263 L .5875 .59803 L 0 0 .1 r
F
.58749 .59503 m .58749 .59503 L .5869 .61258 L F
.58094 .71071 m .58711 .68357 L .58709 .6777 L 0 .902 .101 r
F
.58094 .71071 m .59027 .66062 L .59026 .65974 L F
.59024 .65967 m .59026 .65974 L .59025 .65962 L F
.58094 .71071 m .59026 .65974 L .59024 .65967 L F
.58533 .64905 m .58793 .60967 L .58533 .64923 L 0 0 .001 r
F
.58346 .67695 m .58793 .60967 L .58357 .67564 L F
.58793 .60967 m .58789 .61032 L .5848 .65738 L F
.58343 .67736 m .58793 .6096 L .58346 .67696 L F
.58793 .6096 m .58793 .60967 L .58346 .67695 L F
.58346 .67696 m .58346 .67695 L .58237 .69337 L F
.58793 .6096 m .58346 .67695 L .58346 .67696 L F
.58541 .65581 m .5856 .65001 L .58544 .65538 L 0 0 .1 r
F
.58451 .66814 m .58811 .60785 L .58809 .6021 L 0 0 .064 r
F
.58582 .64407 m .59106 .54728 L .58635 .62794 L F
.58582 .64407 m .58635 .62794 L .58512 .64895 L F
.58357 .67564 m .58533 .64905 L .5848 .65738 L 0 0 .001 r
F
.58533 .64905 m .58533 .64923 L .5848 .65738 L F
.58451 .66814 m .58582 .64407 L .58512 .64895 L 0 0 .064 r
F
.5856 .65001 m .58698 .60883 L .58563 .64961 L 0 0 .1 r
F
.58698 .60883 m .58735 .59784 L .587 .60843 L F
.58698 .60883 m .587 .60843 L .58563 .64961 L F
.5856 .65001 m .58563 .64961 L .58544 .65538 L F
.58709 .6777 m .58736 .68246 L .59027 .66062 L 0 .902 .101 r
F
.5901 .64978 m .59132 .64325 L .59008 .64867 L F
.58873 .64591 m .58879 .65318 L .59179 .62211 L 0 .742 .063 r
F
.58786 .58263 m .58845 .56498 L .58838 .57247 L 0 0 .1 r
F
.58757 .59058 m .5885 .56738 L .58838 .56629 L F
.58755 .59134 m .58795 .57921 L .58769 .58753 L F
.58795 .57921 m .58838 .56629 L .58798 .57864 L F
.58838 .56629 m .58838 .56639 L .58798 .57864 L F
.5875 .59803 m .58786 .58263 L .58838 .57247 L F
.58659 .64552 m .59184 .58406 L .58652 .63751 L 0 0 .001 r
F
.58708 .6652 m .58716 .66534 L .58861 .65514 L 0 .742 .063 r
F
.58709 .66371 m .58861 .65514 L .58879 .65318 L F
.58709 .66427 m .58861 .65514 L .58709 .66371 L F
.59032 .68127 m .58632 .6882 L .58516 .69787 L 0 1 .366 r
F
.58094 .71071 m .58694 .66724 L .58446 .68442 L 0 .902 .101 r
F
.58343 .68903 m .58433 .67276 L .58344 .68788 L 0 0 .064 r
F
.58345 .68862 m .58416 .67733 L .58433 .67276 L F
.58345 .68973 m .58416 .67733 L .58345 .68862 L F
.58694 .66724 m .58692 .66727 L .58446 .68442 L 0 .902 .101 r
F
.58719 .66542 m .58716 .66534 L .58446 .68442 L F
.58907 .59165 m .58897 .59052 L .58903 .58175 L 0 0 .087 r
F
.58915 .59267 m .58903 .58175 L .58916 .58482 L F
.58911 .59215 m .58903 .58175 L .58915 .59267 L F
.58908 .59647 m .58903 .58175 L .58914 .59665 L F
.58854 .5678 m .58845 .56498 L .58973 .53337 L 0 0 .1 r
F
.58838 .56629 m .58893 .55665 L .58882 .5533 L F
.58853 .56185 m .58862 .5594 L .58838 .5667 L F
.58914 .59665 m .58916 .58482 L .58918 .59678 L 0 0 .087 r
F
.58916 .58482 m .58921 .58581 L .5892 .59333 L F
.58918 .59301 m .5892 .59333 L .58919 .60505 L F
.58916 .58482 m .5892 .59333 L .58918 .59301 L F
.59091 .7618 m .59468 .77013 L .60008 .76397 L 0 1 .479 r
F
.59091 .7618 m .60008 .76397 L .59844 .76056 L F
.6009 .72688 m .59105 .74638 L .59785 .74254 L 0 1 .427 r
F
.6009 .72688 m .58981 .74325 L .59105 .74638 L F
.58981 .74325 m .58951 .74368 L .58978 .74415 L F
.58981 .74325 m .58978 .74415 L .59105 .74638 L F
.61269 .83384 m .609 .85091 L .61758 .84505 L 0 1 .433 r
F
.60257 .84372 m .60709 .84783 L .61145 .84327 L 0 1 .503 r
F
.60257 .84372 m .61145 .84327 L .60952 .8415 L F
.60932 .82158 m .60181 .83491 L .6082 .83168 L 0 1 .474 r
F
.61758 .84505 m .60548 .86251 L .61346 .86127 L 0 1 .445 r
F
.59587 .86042 m .59971 .87044 L .60548 .86251 L 0 1 .448 r
F
.61301 .85389 m .60149 .86443 L .60919 .86319 L 0 1 .527 r
F
.61301 .85389 m .59985 .86232 L .60149 .86443 L F
.61301 .85389 m .60478 .8578 L .59985 .86232 L F
.60709 .84783 m .60478 .8578 L .61301 .85389 L 0 1 .52 r
F
.60261 .84791 m .60291 .856 L .60805 .8597 L 0 .6 .424 r
F
.62245 .85549 m .61346 .86127 L .60797 .86846 L 0 1 .457 r
F
.61758 .84505 m .61346 .86127 L .62245 .85549 L 0 1 .445 r
F
.61301 .85389 m .60919 .86319 L .61782 .85942 L 0 1 .527 r
F
.60261 .84791 m .60805 .8597 L .60847 .85971 L 0 .6 .424 r
F
.60787 .85493 m .60847 .85971 L .61155 .85985 L F
.60261 .84791 m .60847 .85971 L .60787 .85493 L F
.60328 .78798 m .60503 .79303 L .60653 .78666 L 0 1 .406 r
F
.59836 .78999 m .60364 .79239 L .60328 .78798 L F
.60364 .79239 m .60503 .79303 L .60328 .78798 L F
.62085 .76398 m .60661 .7785 L .60824 .7823 L 0 1 .448 r
F
.62085 .76398 m .61201 .77065 L .60661 .7785 L F
.61607 .75456 m .60416 .77292 L .61201 .77065 L F
.60849 .76813 m .60113 .78663 L .60751 .7864 L 0 1 .405 r
F
.60312 .78596 m .60653 .78666 L .60376 .78542 L 0 1 .406 r
F
.59836 .78999 m .60328 .78798 L .60312 .78596 L F
.60328 .78798 m .60653 .78666 L .60312 .78596 L F
.58838 .5664 m .58838 .5667 L .588 .57828 L 0 0 .1 r
F
.58838 .5664 m .588 .57828 L .58799 .5786 L F
.58893 .55665 m .58973 .53337 L .58882 .5533 L F
.5891 .56328 m .59054 .53515 L .58907 .56073 L 0 0 .064 r
F
.58924 .58655 m .58924 .54656 L .58935 .54362 L 0 0 .087 r
F
.58921 .59688 m .58921 .58581 L .58924 .58655 L F
.5892 .59683 m .58921 .58581 L .58921 .59688 L F
.5896 .57421 m .58928 .58233 L .59106 .54728 L 0 0 .064 r
F
.58928 .58233 m .58933 .58421 L .59106 .54728 L F
.58938 .58969 m .58943 .51538 L .58969 .50854 L 0 0 .087 r
F
.59278 .78128 m .60113 .78663 L .59916 .78149 L 0 1 .404 r
F
.60292 .75488 m .5962 .77367 L .60231 .77356 L 0 1 .399 r
F
.60292 .75488 m .59423 .7684 L .5962 .77367 L F
.60292 .75488 m .59711 .76034 L .59423 .7684 L F
.59734 .74129 m .59711 .76034 L .60292 .75488 L 0 1 .394 r
F
.58628 .75315 m .59091 .7618 L .59571 .75512 L 0 1 .474 r
F
.58628 .75315 m .59571 .75512 L .5937 .75128 L F
.59734 .74129 m .59127 .7604 L .59711 .76034 L 0 1 .394 r
F
.59278 .78128 m .5905 .7993 L .59741 .79426 L 0 1 .404 r
F
.59278 .78128 m .58412 .7991 L .5905 .7993 L F
.59168 .78794 m .59836 .78999 L .59959 .78387 L 0 1 .387 r
F
.59168 .78794 m .59959 .78387 L .59681 .78305 L F
.60849 .76813 m .59916 .78149 L .60113 .78663 L 0 1 .405 r
F
.60849 .76813 m .60231 .77356 L .59916 .78149 L F
.60121 .76805 m .59681 .78305 L .59959 .78387 L 0 1 .378 r
F
.60121 .76805 m .5975 .77627 L .59681 .78305 L F
.59454 .76678 m .60121 .76805 L .60156 .76178 L 0 1 .358 r
F
.59091 .7618 m .58586 .77493 L .59468 .77013 L 0 1 .479 r
F
.59337 .76761 m .59451 .76767 L .59454 .76678 L 0 1 .358 r
F
.59451 .76767 m .60121 .76805 L .59454 .76678 L F
.6009 .72688 m .59374 .73532 L .58981 .74309 L 0 1 .427 r
F
.58981 .74325 m .58981 .74309 L .58951 .74368 L F
.6009 .72688 m .58981 .74309 L .58981 .74325 L F
.59741 .79426 m .5865 .80701 L .58809 .81224 L 0 1 .407 r
F
.5779 .80096 m .58064 .81174 L .58749 .80526 L 0 1 .437 r
F
.5779 .80096 m .58749 .80526 L .58627 .80114 L F
.59741 .79426 m .5905 .7993 L .5865 .80701 L 0 1 .407 r
F
.59836 .78999 m .59486 .80487 L .60026 .80029 L 0 1 .406 r
F
.58337 .8223 m .5861 .83262 L .59358 .82571 L 0 1 .448 r
F
.59834 .81393 m .59212 .82761 L .59797 .82389 L 0 1 .445 r
F
.59679 .81922 m .60354 .82936 L .60002 .82305 L 0 .316 .339 r
F
.60354 .82936 m .60352 .82915 L .60002 .82305 L F
.59678 .81956 m .60354 .8294 L .59679 .81922 L F
.60354 .8294 m .60427 .83046 L .60354 .82936 L F
.60354 .8294 m .60354 .82936 L .59679 .81922 L F
.5964 .71924 m .59374 .73532 L .6009 .72688 L 0 1 .411 r
F
.5964 .71924 m .58721 .73971 L .59374 .73532 L F
.5964 .71924 m .58568 .7371 L .58721 .73971 L F
.5964 .71924 m .58961 .72833 L .58568 .7371 L F
.59188 .71172 m .58961 .72833 L .5964 .71924 L 0 1 .393 r
F
.59734 .74129 m .5893 .75502 L .59127 .7604 L 0 1 .394 r
F
.59188 .71172 m .60004 .71005 L .59812 .70687 L 0 1 .393 r
F
.59188 .71172 m .5964 .71924 L .60004 .71005 L F
.59708 .69669 m .59373 .71869 L .59911 .71837 L 0 1 .373 r
F
.59188 .71172 m .58337 .7332 L .58961 .72833 L 0 1 .393 r
F
.59708 .69669 m .59128 .71276 L .59373 .71869 L 0 1 .373 r
F
.59734 .74129 m .5919 .74683 L .5893 .75502 L 0 1 .394 r
F
.59176 .72741 m .5919 .74683 L .59734 .74129 L 0 1 .389 r
F
.59176 .72741 m .59734 .74129 L .59967 .73293 L F
.59176 .72741 m .59967 .73293 L .59733 .72734 L F
.59468 .77013 m .58138 .78511 L .58922 .78425 L 0 1 .463 r
F
.59468 .77013 m .58016 .78135 L .58138 .78511 L F
.59468 .77013 m .58586 .77493 L .58016 .78135 L F
.59091 .7618 m .57833 .77617 L .58586 .77493 L 0 1 .479 r
F
.58814 .76803 m .5962 .77367 L .59423 .7684 L 0 1 .402 r
F
.59337 .76761 m .5975 .77627 L .60121 .76805 L 0 1 .358 r
F
.59337 .76761 m .60156 .76178 L .59833 .76163 L F
.60539 .73472 m .60324 .75261 L .61128 .74543 L 0 1 .439 r
F
.59734 .74129 m .60292 .75488 L .60553 .74669 L 0 1 .394 r
F
.59734 .74129 m .60553 .74669 L .60318 .74123 L F
.5997 .74056 m .60115 .74542 L .60075 .73944 L 0 1 .326 r
F
.59254 .74823 m .60009 .74577 L .5997 .74056 L F
.60009 .74577 m .60115 .74542 L .5997 .74056 L F
.58935 .59732 m .58924 .58655 L .58938 .58969 L 0 0 .087 r
F
.58933 .60257 m .5893 .59716 L .58935 .59732 L F
.5893 .59716 m .58924 .58655 L .58935 .59732 L F
.60976 .80879 m .62045 .81137 L .61882 .80749 L 0 1 .453 r
F
.60204 .80688 m .61094 .81122 L .60898 .80647 L 0 1 .412 r
F
.60503 .79303 m .60073 .80808 L .6063 .80374 L 0 1 .423 r
F
.59795 .79931 m .60165 .81001 L .59799 .79803 L 0 .137 .22 r
F
.60165 .81001 m .60164 .80983 L .59799 .79803 L F
.60383 .8176 m .60309 .82766 L .60932 .82158 L 0 1 .46 r
F
.60666 .81897 m .6169 .82507 L .61434 .8192 L 0 1 .421 r
F
.60383 .8176 m .60932 .82158 L .61226 .81578 L 0 1 .46 r
F
.60383 .8176 m .61226 .81578 L .60996 .81412 L F
.59795 .79931 m .60343 .81665 L .60206 .8112 L 0 .137 .22 r
F
.60343 .81665 m .60412 .81882 L .60324 .81556 L F
.60343 .81665 m .60324 .81556 L .60206 .8112 L F
.60027 .79877 m .60263 .81148 L .6021 .80841 L 0 0 .141 r
F
.60085 .80204 m .6027 .81187 L .60027 .79877 L F
.59789 .7999 m .60315 .81597 L .59795 .79931 L 0 .137 .22 r
F
.60315 .81597 m .60508 .82187 L .60297 .81521 L F
.60315 .81597 m .60297 .81521 L .59795 .79931 L F
.60315 .81597 m .60427 .82046 L .60508 .82187 L F
.59789 .7999 m .60362 .81841 L .60315 .81597 L F
.59781 .80012 m .60362 .81841 L .59789 .7999 L F
.59818 .79442 m .6016 .80931 L .60137 .80684 L 0 .051 .169 r
F
.59811 .79481 m .6016 .80931 L .59818 .79442 L F
.59836 .78999 m .59244 .80371 L .59486 .80487 L 0 1 .406 r
F
.59836 .78999 m .59394 .79733 L .59244 .80371 L F
.59168 .78794 m .59394 .79733 L .59836 .78999 L 0 1 .387 r
F
.59551 .78429 m .5981 .79491 L .59557 .78424 L 0 .051 .169 r
F
.5981 .79491 m .6016 .80931 L .59811 .79481 L F
.5981 .79491 m .59811 .79481 L .59557 .78424 L F
.6016 .80931 m .60206 .8112 L .60137 .80684 L F
.60137 .80684 m .60206 .8112 L .605 .82144 L F
.60132 .80724 m .60325 .8142 L .60319 .81467 L F
.59557 .78424 m .59811 .79481 L .59818 .79442 L F
.59563 .78459 m .60137 .80684 L .60132 .80724 L F
.57515 .79005 m .5779 .80096 L .58444 .79501 L 0 1 .429 r
F
.57515 .79005 m .58444 .79501 L .58322 .79097 L F
.59278 .78128 m .58254 .79378 L .58412 .7991 L 0 1 .404 r
F
.59278 .78128 m .58625 .78614 L .58254 .79378 L F
.58814 .76803 m .58625 .78614 L .59278 .78128 L 0 1 .402 r
F
.58814 .76803 m .59278 .78128 L .5962 .77367 L F
.59337 .76761 m .59255 .78225 L .5975 .77627 L 0 1 .358 r
F
.59416 .77876 m .59551 .78429 L .59557 .78424 L 0 .051 .169 r
F
.59416 .77876 m .59557 .78424 L .59563 .78459 L F
.59557 .78424 m .60137 .80684 L .59563 .78459 L F
.60137 .80684 m .605 .82144 L .60445 .81885 L F
.60137 .80684 m .60325 .8142 L .60132 .80724 L F
.59589 .77574 m .59808 .79237 L .60115 .80558 L 0 0 .141 r
F
.59589 .77574 m .60115 .80558 L .60097 .80268 L F
.60132 .80724 m .60196 .80979 L .6013 .80712 L 0 .051 .169 r
F
.60196 .80979 m .60184 .80916 L .60127 .80688 L F
.6013 .80712 m .60127 .80688 L .59908 .79811 L F
.60196 .80979 m .60127 .80688 L .6013 .80712 L F
.59597 .77613 m .60085 .80204 L .60027 .79877 L 0 0 .141 r
F
.59422 .7669 m .59589 .77574 L .59597 .77613 L F
.59589 .77574 m .60085 .80204 L .59597 .77613 L F
.60362 .81841 m .60427 .82046 L .60315 .81597 L 0 .137 .22 r
F
.61725 .82834 m .62098 .8379 L .62853 .83055 L 0 1 .458 r
F
.61269 .83384 m .61758 .84505 L .62246 .8373 L 0 1 .433 r
F
.61269 .83384 m .62246 .8373 L .62038 .83283 L F
.62024 .83037 m .60952 .8415 L .61145 .84327 L 0 1 .497 r
F
.62024 .83037 m .61329 .83597 L .60952 .8415 L F
.61479 .82584 m .60664 .83894 L .61329 .83597 L 0 1 .487 r
F
.61479 .82584 m .60471 .8373 L .60664 .83894 L F
.61479 .82584 m .6082 .83168 L .60471 .8373 L F
.60932 .82158 m .6082 .83168 L .61479 .82584 L 0 1 .474 r
F
.60277 .81894 m .60852 .83252 L .6129 .84042 L 0 .025 .167 r
F
.60277 .81894 m .6118 .83671 L .60715 .82681 L F
.62024 .83037 m .61145 .84327 L .61837 .84056 L 0 1 .497 r
F
.61427 .84254 m .6129 .84042 L .61521 .8437 L 0 .17 0 r
F
.60277 .81894 m .61427 .84254 L .6118 .83671 L 0 .025 .167 r
F
.60277 .81894 m .6129 .84042 L .61427 .84254 L F
.60508 .82187 m .60427 .82046 L .60715 .82681 L 0 0 .1 r
F
.6032 .81473 m .60348 .81574 L .60645 .82766 L 0 .051 .169 r
F
.60196 .80979 m .6032 .81473 L .60184 .80916 L F
.6032 .81473 m .60645 .82766 L .60316 .81446 L F
.60319 .81467 m .6032 .81471 L .6032 .81473 L F
.6032 .81473 m .60316 .81446 L .60184 .80916 L F
.60508 .82187 m .60715 .82681 L .6118 .83671 L 0 0 .1 r
F
.6032 .81471 m .60403 .81773 L .6032 .81473 L 0 .051 .169 r
F
.60709 .84783 m .61301 .85389 L .6173 .84905 L 0 1 .52 r
F
.60709 .84783 m .6173 .84905 L .61478 .84651 L F
.61758 .84505 m .62245 .85549 L .62764 .84801 L 0 1 .445 r
F
.61758 .84505 m .62764 .84801 L .62557 .8438 L F
.64464 .81221 m .62853 .83055 L .63815 .82836 L 0 1 .456 r
F
.61725 .82834 m .62853 .83055 L .62692 .82675 L 0 1 .458 r
F
.64464 .81221 m .62692 .82675 L .62853 .83055 L 0 1 .456 r
F
.64464 .81221 m .63382 .8189 L .62692 .82675 L F
.63239 .8197 m .62246 .8373 L .63012 .83647 L 0 1 .436 r
F
.62568 .83517 m .61478 .84651 L .6173 .84905 L 0 1 .503 r
F
.62568 .83517 m .61837 .84056 L .61478 .84651 L F
.62568 .83517 m .6173 .84905 L .62502 .84708 L F
.61055 .83798 m .61486 .84659 L .61953 .85232 L 0 .112 .186 r
F
.61301 .85389 m .62277 .8549 L .62072 .85265 L 0 1 .527 r
F
.61055 .83798 m .61953 .85232 L .62152 .85391 L 0 .112 .186 r
F
.61055 .83798 m .61967 .85022 L .61521 .8437 L F
.63826 .83089 m .62764 .84801 L .63558 .84701 L 0 1 .445 r
F
.63826 .83089 m .62557 .8438 L .62764 .84801 L F
.63281 .8419 m .62072 .85265 L .62277 .8549 L 0 1 .508 r
F
.63281 .8419 m .62502 .84708 L .62072 .85265 L F
.61055 .83798 m .62152 .85391 L .61967 .85022 L 0 .112 .186 r
F
.60644 .82527 m .617 .85086 L .6141 .84448 L 0 0 .1 r
F
.60508 .82187 m .60645 .82521 L .60644 .82527 L F
.60645 .82521 m .617 .85086 L .60644 .82527 L F
.60508 .82187 m .61603 .84702 L .617 .85086 L F
.60642 .82496 m .6118 .83671 L .61603 .84702 L F
.60508 .82187 m .6065 .82501 L .60642 .82496 L F
.6065 .82501 m .6118 .83671 L .60642 .82496 L F
.60578 .82453 m .60601 .82496 L .60621 .8262 L 0 .051 .169 r
F
.60406 .81787 m .60592 .82462 L .60578 .82453 L F
.60592 .82462 m .60601 .82496 L .60578 .82453 L F
.60615 .82645 m .60621 .8262 L .60645 .82766 L F
.60406 .81787 m .60621 .8262 L .60615 .82645 L F
.60403 .81773 m .60601 .82496 L .60402 .81771 L F
.60403 .81773 m .60402 .81771 L .6032 .81473 L F
.60631 .82488 m .6141 .84448 L .60929 .83215 L 0 0 .1 r
F
.60508 .82187 m .60644 .82527 L .60631 .82488 L F
.60644 .82527 m .6141 .84448 L .60631 .82488 L F
.60445 .81885 m .605 .82144 L .60601 .82496 L 0 .051 .169 r
F
.60325 .8142 m .60601 .82496 L .60319 .81467 L F
.60412 .81882 m .60397 .81794 L .60206 .8112 L 0 .137 .22 r
F
.60281 .81215 m .60416 .81947 L .60482 .82273 L 0 0 .141 r
F
.6021 .80841 m .60287 .81254 L .60281 .81215 L F
.60316 .81446 m .60645 .82766 L .60303 .81365 L 0 .051 .169 r
F
.60287 .81254 m .60416 .81947 L .60281 .81215 L 0 0 .141 r
F
.60122 .80649 m .60316 .81446 L .60303 .81365 L 0 .051 .169 r
F
.59908 .79811 m .60127 .80688 L .60122 .80649 L F
.60127 .80688 m .60316 .81446 L .60122 .80649 L F
.59422 .7669 m .59585 .77768 L .59589 .77574 L 0 0 .141 r
F
.59585 .77768 m .59808 .79237 L .59589 .77574 L F
.59862 .79162 m .60083 .80175 L .60092 .80457 L F
.59857 .79047 m .60083 .80175 L .59862 .79162 L F
.59722 .78273 m .60083 .80175 L .5972 .78365 L F
.59608 .76514 m .59795 .78626 L .60081 .8039 L 0 .009 .137 r
F
.6027 .81187 m .60263 .81148 L .60027 .79877 L 0 0 .141 r
F
.59606 .76363 m .60081 .8039 L .60044 .79754 L 0 .009 .137 r
F
.59254 .74823 m .59815 .75462 L .60026 .74813 L 0 1 .326 r
F
.60009 .74577 m .60026 .74813 L .60115 .74542 L F
.59254 .74823 m .60026 .74813 L .60009 .74577 L F
.59608 .76501 m .60081 .8039 L .59606 .76363 L 0 .009 .137 r
F
.59254 .74823 m .5997 .74056 L .59722 .74066 L 0 1 .326 r
F
.5997 .74056 m .60075 .73944 L .59965 .73982 L F
.5997 .74056 m .59965 .73982 L .59722 .74066 L F
.59636 .66912 m .59043 .69441 L .59613 .68846 L 0 1 .356 r
F
.59636 .66912 m .58851 .69138 L .59043 .69441 L F
.59636 .66912 m .59105 .68053 L .58851 .69138 L F
.59179 .64559 m .59998 .65144 L .59671 .64458 L 0 1 .346 r
F
.59179 .64559 m .5997 .66242 L .59998 .65144 L F
.59179 .64559 m .59606 .67022 L .5997 .66242 L F
.59179 .64559 m .59113 .67123 L .59606 .67022 L F
.59032 .68127 m .59824 .68702 L .59543 .68076 L 0 1 .366 r
F
.59032 .68127 m .59708 .69669 L .59824 .68702 L F
.59032 .68127 m .59272 .70333 L .59708 .69669 L F
.59708 .69669 m .59272 .70333 L .59128 .71276 L 0 1 .373 r
F
.59662 .57908 m .6035 .60822 L .60603 .59764 L 0 .973 .315 r
F
.59662 .57908 m .59892 .61096 L .6035 .60822 L F
.59662 .57908 m .59535 .60401 L .59892 .61096 L F
.59071 .60612 m .59892 .61096 L .59535 .60401 L 0 1 .326 r
F
.5962 .61271 m .60171 .59375 L .59898 .59536 L 0 1 .222 r
F
.59132 .64325 m .59619 .62005 L .5962 .61271 L F
.59619 .62005 m .60171 .59375 L .5962 .61271 L F
.59608 .76514 m .60081 .8039 L .59608 .76501 L 0 .009 .137 r
F
.60019 .83459 m .60224 .8439 L .6071 .84833 L 0 .414 .38 r
F
.60019 .83459 m .6071 .84833 L .60991 .84872 L F
.60019 .83459 m .60904 .84473 L .60506 .83901 L F
.60019 .83459 m .60991 .84872 L .60904 .84473 L F
.60584 .83563 m .60506 .83901 L .60904 .84473 L 0 .287 .306 r
F
.60584 .83563 m .60369 .83511 L .60506 .83901 L F
.58064 .81174 m .58337 .8223 L .59054 .81554 L 0 1 .443 r
F
.58357 .81984 m .58723 .83316 L .59204 .82496 L 0 1 .391 r
F
.58357 .81984 m .59204 .82496 L .59046 .81993 L F
.59834 .81393 m .59018 .82626 L .59212 .82761 L 0 1 .445 r
F
.59834 .81393 m .59284 .8204 L .59018 .82626 L F
.59542 .81759 m .60584 .83563 L .60427 .83046 L 0 .316 .339 r
F
.59542 .81759 m .60369 .83511 L .60584 .83563 L F
.59954 .81775 m .60427 .83046 L .60833 .83623 L 0 .206 .261 r
F
.60827 .83582 m .60833 .83623 L .60878 .83686 L F
.59954 .81775 m .60833 .83623 L .60827 .83582 L F
.59624 .76547 m .60012 .79505 L .59965 .79229 L 0 .009 .137 r
F
.59606 .76363 m .60012 .79505 L .59624 .76547 L F
.59966 .80063 m .60132 .80724 L .59908 .79811 L 0 .051 .169 r
F
.60132 .80724 m .6013 .80712 L .59908 .79811 L F
.5987 .7921 m .60073 .80349 L .59867 .79234 L 0 0 .141 r
F
.59862 .79174 m .59867 .79234 L .59814 .78951 L F
.5987 .7921 m .59867 .79234 L .59862 .79174 L F
.60073 .80349 m .6004 .80205 L .59868 .79247 L F
.59867 .79234 m .59868 .79247 L .59814 .78951 L F
.60073 .80349 m .59868 .79247 L .59867 .79234 L F
.60165 .81001 m .60206 .8112 L .60164 .80983 L 0 .137 .22 r
F
.59416 .77876 m .5983 .79504 L .59808 .79237 L 0 .051 .169 r
F
.5983 .79504 m .60303 .81365 L .59835 .79355 L F
.5983 .79504 m .59835 .79355 L .59808 .79237 L F
.59982 .79881 m .60091 .8049 L .59984 .79928 L 0 0 .141 r
F
.60091 .8049 m .6009 .80515 L .59984 .79928 L F
.59254 .74823 m .59348 .76219 L .59815 .75462 L 0 1 .326 r
F
.60584 .83563 m .60904 .84473 L .61382 .84965 L 0 .287 .306 r
F
.60584 .83563 m .61382 .84965 L .61623 .85049 L F
.60584 .83563 m .61486 .84659 L .61063 .84055 L F
.60584 .83563 m .61623 .85049 L .61486 .84659 L F
.59954 .81775 m .60753 .83089 L .60405 .82414 L 0 .206 .261 r
F
.60753 .83089 m .60852 .83252 L .60749 .83059 L F
.60753 .83089 m .60749 .83059 L .60405 .82414 L F
.60261 .84791 m .61155 .85985 L .61143 .85639 L 0 .6 .424 r
F
.60261 .84791 m .61143 .85639 L .60776 .85161 L F
.60356 .83122 m .60671 .84783 L .60641 .85594 L 0 .009 .137 r
F
.60753 .83089 m .61055 .83798 L .60852 .83252 L 0 .206 .261 r
F
.59954 .81775 m .60783 .83299 L .60753 .83089 L F
.60783 .83299 m .61055 .83798 L .60753 .83089 L F
.59121 .29958 m .59131 .30516 L .59135 .301 L 0 0 .087 r
F
.59022 .28957 m .59131 .30516 L .59121 .29958 L F
.58969 .50854 m .58943 .51538 L .59009 .40679 L F
.58981 .55962 m .5895 .55956 L .58986 .46536 L F
.58999 .46042 m .58986 .46536 L .59009 .40679 L F
.58981 .55962 m .58986 .46536 L .58999 .46042 L F
.59029 .47903 m .58994 .49054 L .59009 .40679 L F
.59022 .28957 m .58952 .51592 L .59131 .30516 L F
.59029 .47903 m .58981 .55962 L .58994 .49054 L F
.58952 .51592 m .59017 .50024 L .59135 .301 L F
.59099 .29083 m .59135 .301 L .59141 .2915 L F
.59022 .28957 m .59135 .301 L .59099 .29083 L F
.59094 .28493 m .59346 .42013 L .59342 .42129 L 0 0 .08 r
F
.58924 .58655 m .58943 .51538 L .58938 .58969 L 0 0 .087 r
F
.59139 .61192 m .59191 .60715 L .59137 .61151 L 0 .742 .063 r
F
.59058 .59883 m .59072 .60081 L .59184 .58406 L 0 0 .001 r
F
.59137 .61151 m .59191 .60715 L .59133 .61098 L 0 .742 .063 r
F
.58935 .54362 m .58924 .54656 L .58943 .51538 L 0 0 .087 r
F
.58783 .28743 m .58852 .55798 L .58872 .28844 L F
.59132 .64325 m .59083 .65646 L .5936 .65476 L 0 1 .222 r
F
.58933 .60257 m .58885 .61117 L .59131 .66295 L 0 .091 .152 r
F
.58921 .58581 m .58924 .54656 L .58924 .58655 L 0 0 .087 r
F
.58711 .68357 m .58736 .68246 L .58709 .6777 L 0 .902 .101 r
F
.59032 .68127 m .58761 .70384 L .59272 .70333 L 0 1 .366 r
F
.59032 .68127 m .58516 .69787 L .58761 .70384 L F
.5997 .66242 m .59543 .68076 L .59824 .68702 L 0 1 .355 r
F
.5997 .66242 m .59606 .67022 L .59543 .68076 L F
.58743 .70268 m .59758 .67621 L .59551 .67515 L 0 1 .236 r
F
.58743 .70268 m .59624 .68901 L .59758 .67621 L F
.58743 .70268 m .59551 .67515 L .59142 .68656 L F
.58743 .70268 m .59228 .7051 L .59624 .68901 L F
.58009 .69798 m .57616 .71872 L .58123 .71861 L 0 1 .376 r
F
.57959 .7243 m .58982 .675 L .58736 .68246 L 0 1 .122 r
F
.57947 .72499 m .57959 .72441 L .57959 .7243 L F
.57959 .72441 m .58982 .675 L .57959 .7243 L F
.5866 .62421 m .58712 .60493 L .5875 .59803 L 0 0 .1 r
F
.58925 .62469 m .58919 .60505 L .58933 .60257 L 0 0 .087 r
F
.57947 .72499 m .58897 .68651 L .58982 .675 L 0 1 .122 r
F
.58592 .71272 m .59373 .71869 L .59128 .71276 L 0 1 .383 r
F
.58743 .70268 m .58832 .71376 L .59228 .7051 L 0 1 .236 r
F
.57958 .72454 m .58527 .7073 L .58897 .68651 L 0 1 .122 r
F
.57947 .72499 m .57957 .72469 L .57958 .72454 L F
.57957 .72469 m .58527 .7073 L .57958 .72454 L F
.58623 .63508 m .58637 .62757 L .5866 .62421 L 0 0 .1 r
F
.58484 .67014 m .58509 .67244 L .58532 .66154 L 0 .238 .216 r
F
.58509 .67244 m .58576 .67881 L .58532 .66154 L F
.58508 .6686 m .58603 .63778 L .58623 .63508 L 0 0 .1 r
F
.58603 .63778 m .58637 .62757 L .58623 .63508 L F
.58735 .59784 m .58737 .59752 L .58512 .66512 L F
.58735 .59784 m .58512 .66514 L .58512 .66514 L F
.58735 .59784 m .58511 .66537 L .58511 .66539 L F
.5796 .72424 m .58712 .68374 L .5832 .70404 L 0 1 .122 r
F
.58712 .68374 m .58736 .68246 L .58712 .68371 L F
.58712 .68374 m .58712 .68371 L .5832 .70404 L F
.58484 .67014 m .58424 .68117 L .58482 .68468 L 0 .238 .216 r
F
.57959 .7243 m .58712 .68374 L .5796 .72424 L 0 1 .122 r
F
.58712 .68374 m .58736 .68246 L .58712 .68374 L F
.58712 .68374 m .58712 .68374 L .5796 .72424 L F
.58494 .67055 m .58603 .63778 L .58505 .66947 L 0 0 .1 r
F
.58526 .66108 m .58512 .66518 L .58532 .66154 L 0 .238 .216 r
F
.58735 .59784 m .58512 .66508 L .58512 .66517 L 0 0 .1 r
F
.58484 .67007 m .58543 .65214 L .58495 .6681 L F
.58484 .67014 m .58482 .68468 L .58509 .67244 L 0 .238 .216 r
F
.58543 .65214 m .58552 .65108 L .58461 .67948 L 0 0 .1 r
F
.58461 .67948 m .58552 .65108 L .5856 .65001 L F
.58266 .68896 m .58273 .68805 L .58274 .68779 L 0 0 .001 r
F
.58235 .69352 m .58343 .67736 L .58237 .69337 L F
.58343 .67736 m .58346 .67696 L .58237 .69337 L F
.58237 .69337 m .58346 .67695 L .58357 .67564 L F
.58212 .69733 m .58297 .68788 L .58318 .68301 L F
.58192 .70011 m .58214 .69759 L .58212 .69733 L F
.58214 .69759 m .58297 .68788 L .58212 .69733 L F
.58094 .71071 m .5832 .70404 L .58712 .68371 L 0 .902 .101 r
F
.58711 .68357 m .58712 .68371 L .58736 .68246 L F
.58094 .71071 m .58712 .68371 L .58711 .68357 L F
.58332 .68288 m .58493 .65223 L .58552 .63335 L 0 0 .064 r
F
.58543 .65214 m .58705 .60292 L .58552 .65108 L 0 0 .1 r
F
.58321 .69059 m .58491 .65562 L .58476 .66035 L 0 0 .064 r
F
.57565 .73564 m .5792 .74162 L .58337 .7332 L 0 1 .382 r
F
.57565 .73564 m .5721 .75026 L .5792 .74162 L F
.57398 .72685 m .57884 .74106 L .58132 .73306 L 0 1 .393 r
F
.57565 .73564 m .56591 .75531 L .5721 .75026 L 0 1 .382 r
F
.57565 .73564 m .56476 .75339 L .56591 .75531 L F
.57565 .73564 m .56894 .74495 L .56476 .75339 L F
.57208 .72943 m .56894 .74495 L .57565 .73564 L 0 1 .368 r
F
.57398 .72685 m .57346 .746 L .57884 .74106 L 0 1 .393 r
F
.57398 .72685 m .58132 .73306 L .57926 .72732 L F
.57729 .74059 m .58743 .70268 L .58527 .7073 L 0 1 .133 r
F
.57856 .73502 m .58527 .7073 L .58118 .72359 L F
.57729 .74059 m .57851 .73551 L .57856 .73502 L F
.57851 .73551 m .58527 .7073 L .57856 .73502 L F
.58465 .68097 m .58494 .67055 L .58505 .66947 L 0 0 .1 r
F
.58403 .69126 m .58467 .6974 L .58469 .69555 L 0 .238 .224 r
F
.584 .69181 m .58467 .6974 L .58403 .69126 L F
.58364 .68905 m .58467 .6974 L .58365 .68885 L F
.58514 .66371 m .58515 .66363 L .58484 .67304 L 0 0 .1 r
F
.5835 .69092 m .58464 .69969 L .58362 .68926 L 0 .238 .224 r
F
.58464 .69969 m .58467 .6974 L .58364 .68908 L F
.58362 .68921 m .58364 .68908 L .58346 .68762 L F
.58541 .65581 m .58544 .65538 L .58487 .67266 L 0 0 .1 r
F
.58464 .69969 m .58364 .68908 L .58363 .68914 L 0 .238 .224 r
F
.58464 .69969 m .58363 .68914 L .58362 .68926 L F
.5841 .68954 m .5847 .69356 L .58471 .69301 L F
.58484 .67304 m .58487 .67266 L .58469 .67795 L 0 0 .1 r
F
.58409 .68977 m .5847 .69383 L .5841 .68954 L 0 .238 .224 r
F
.58275 .74736 m .58628 .75314 L .59105 .74638 L 0 1 .424 r
F
.58275 .74736 m .59105 .74638 L .58951 .74368 L F
.59176 .72741 m .58633 .7469 L .5919 .74683 L 0 1 .389 r
F
.5792 .74162 m .58275 .74736 L .58721 .73971 L 0 1 .397 r
F
.5792 .74162 m .58721 .73971 L .58568 .7371 L F
.59176 .72741 m .58436 .74145 L .58633 .7469 L 0 1 .389 r
F
.58592 .71272 m .59176 .72741 L .59373 .71869 L 0 1 .383 r
F
.59176 .72741 m .58668 .7331 L .58436 .74145 L 0 1 .389 r
F
.58592 .71272 m .58668 .73309 L .59176 .72741 L 0 1 .383 r
F
.60383 .71201 m .59911 .71837 L .59733 .72734 L 0 1 .381 r
F
.58938 .73269 m .59864 .72373 L .59756 .71896 L 0 1 .29 r
F
.61265 .69509 m .60291 .71487 L .60483 .71812 L 0 1 .396 r
F
.61265 .69509 m .60627 .705 L .60291 .71487 L F
.60383 .71201 m .59733 .72734 L .59967 .73293 L 0 1 .381 r
F
.58938 .73269 m .59631 .73392 L .59864 .72373 L 0 1 .29 r
F
.58938 .73269 m .59756 .71896 L .59378 .7228 L F
.58938 .73269 m .59192 .74381 L .59631 .73392 L F
.58592 .71272 m .58132 .73306 L .58668 .73309 L 0 1 .383 r
F
.58419 .72691 m .59395 .70673 L .59228 .7051 L 0 1 .238 r
F
.58419 .72691 m .59223 .71756 L .59395 .70673 L F
.58419 .72691 m .59228 .7051 L .58832 .71376 L F
.58419 .72691 m .58812 .73069 L .59223 .71756 L F
.58743 .70268 m .58623 .71273 L .58832 .71376 L 0 1 .236 r
F
.57729 .74059 m .58623 .71273 L .58743 .70268 L 0 1 .133 r
F
.5847 .69383 m .59376 .75376 L .5847 .69356 L 0 .238 .224 r
F
.5847 .69383 m .5847 .69356 L .5841 .68954 L F
.58541 .65581 m .58487 .67266 L .58484 .67304 L 0 0 .1 r
F
.58504 .66742 m .58504 .66706 L .58481 .67406 L F
.58484 .67304 m .58469 .67795 L .58467 .67818 L F
.58315 .69079 m .58491 .65562 L .58321 .69059 L 0 0 .064 r
F
.58332 .68285 m .58552 .63335 L .58551 .63333 L F
.58329 .66539 m .57886 .68266 L .58141 .6888 L 0 1 .357 r
F
.58329 .66539 m .57967 .67263 L .57886 .68266 L F
.58098 .67171 m .58318 .68429 L .58332 .68285 L 0 .238 .224 r
F
.57947 .72499 m .58118 .72359 L .58527 .7073 L 0 1 .122 r
F
.58094 .71071 m .58043 .71621 L .5832 .70404 L 0 .902 .101 r
F
.5783 .69011 m .57178 .71373 L .57718 .70765 L 0 1 .342 r
F
.5783 .69011 m .57022 .71119 L .57178 .71373 L F
.5783 .69011 m .57302 .70106 L .57022 .71119 L F
.57401 .68282 m .58141 .6888 L .57886 .68266 L 0 1 .368 r
F
.57401 .68282 m .58009 .69798 L .58141 .6888 L F
.56793 .66819 m .57401 .68282 L .57503 .67363 L 0 1 .359 r
F
.58009 .69798 m .57409 .71299 L .57616 .71872 L 0 1 .376 r
F
.58009 .69798 m .57578 .7041 L .57409 .71299 L F
.57401 .68282 m .57578 .7041 L .58009 .69798 L 0 1 .368 r
F
.57401 .68282 m .57093 .70426 L .57578 .7041 L F
.57401 .68282 m .56877 .69836 L .57093 .70426 L F
.57401 .68282 m .5701 .68917 L .56877 .69836 L F
.56793 .66819 m .5701 .68917 L .57401 .68282 L 0 1 .359 r
F
.57019 .6753 m .58075 .70505 L .57832 .69072 L 0 .396 .268 r
F
.57239 .77929 m .55786 .79082 L .56561 .79287 L 0 1 .419 r
F
.57239 .77929 m .55705 .78526 L .55786 .79082 L F
.57239 .77929 m .56327 .78032 L .55705 .78526 L F
.56965 .76989 m .56327 .78032 L .57239 .77929 L 0 1 .428 r
F
.56965 .76989 m .57239 .77929 L .57833 .77617 L F
.56965 .76989 m .57833 .77617 L .57711 .77304 L F
.56634 .76679 m .56965 .76989 L .57507 .76874 L 0 0 0 r
F
.56634 .76679 m .57507 .76874 L .57358 .76616 L F
.58275 .74736 m .57161 .76315 L .57838 .75947 L 0 1 .424 r
F
.58275 .74736 m .57048 .76174 L .57161 .76315 L F
.58275 .74736 m .57525 .75497 L .57048 .76174 L F
.5792 .74162 m .56877 .7595 L .57525 .75497 L 0 1 .397 r
F
.5792 .74162 m .56763 .75793 L .56877 .7595 L F
.5792 .74162 m .5721 .75026 L .56763 .75793 L F
.57515 .79005 m .56561 .79287 L .55908 .79881 L 0 1 .429 r
F
.57239 .77929 m .56561 .79287 L .57515 .79005 L 0 1 .419 r
F
.57239 .77929 m .57515 .79005 L .58138 .78511 L F
.57239 .77929 m .58138 .78511 L .58016 .78135 L F
.57256 .77929 m .56221 .79005 L .5634 .79546 L 0 1 .407 r
F
.57256 .77929 m .56613 .78313 L .56221 .79005 L F
.56965 .76989 m .55583 .77718 L .56327 .78032 L 0 1 .428 r
F
.56965 .76989 m .55502 .77197 L .55583 .77718 L F
.56965 .76989 m .56093 .76884 L .55502 .77197 L F
.56634 .76679 m .56093 .76884 L .56965 .76989 L 0 0 0 r
F
.56888 .766 m .56613 .78313 L .57256 .77929 L 0 1 .409 r
F
.56888 .766 m .57256 .77929 L .57618 .77241 L F
.58628 .75315 m .57507 .76874 L .5825 .76687 L 0 1 .474 r
F
.58628 .75315 m .57358 .76616 L .57507 .76874 L F
.56888 .766 m .57618 .77241 L .57459 .76706 L 0 1 .409 r
F
.5792 .74162 m .57525 .75497 L .58275 .74736 L 0 1 .397 r
F
.57884 .74107 m .57221 .75905 L .57773 .75943 L F
.57884 .74107 m .57062 .75371 L .57221 .75905 L F
.57884 .74107 m .57346 .746 L .57062 .75371 L F
.58275 .74736 m .57838 .75947 L .58628 .75314 L 0 1 .424 r
F
.57884 .74107 m .57773 .75943 L .58349 .75461 L 0 1 .397 r
F
.578 .75165 m .58014 .74829 L .5787 .74972 L 0 1 .144 r
F
.58129 .70659 m .58139 .71163 L .58194 .70839 L 0 .396 .268 r
F
.57989 .71718 m .57816 .72915 L .58149 .704 L 0 0 .081 r
F
.57899 .72339 m .58149 .704 L .58172 .70056 L F
.5782 .72915 m .58043 .71621 L .58094 .71071 L 0 0 .054 r
F
.57818 .73089 m .57756 .73435 L .58043 .71621 L F
.57818 .73089 m .58043 .71621 L .5782 .72915 L F
.57782 .73157 m .58094 .71071 L .57816 .72915 L F
.57884 .74107 m .58349 .75461 L .58633 .7469 L 0 1 .397 r
F
.57884 .74107 m .58633 .7469 L .58436 .74145 L F
.58014 .74829 m .58938 .73269 L .58812 .73069 L 0 1 .237 r
F
.58014 .74829 m .58731 .74203 L .58938 .73269 L F
.58014 .74829 m .58311 .75293 L .58731 .74203 L F
.58014 .74829 m .58812 .73069 L .58435 .73737 L F
.57729 .74059 m .58237 .72964 L .58623 .71273 L 0 1 .133 r
F
.57442 .7562 m .58419 .72691 L .58237 .72964 L 0 1 .14 r
F
.57442 .7562 m .58266 .73576 L .58419 .72691 L F
.57442 .7562 m .5787 .74972 L .58266 .73576 L F
.57442 .7562 m .58237 .72964 L .57841 .74218 L F
.57729 .74059 m .57841 .74218 L .58237 .72964 L 0 1 .133 r
F
.57093 .7711 m .57272 .76668 L .57284 .76586 L 0 1 .144 r
F
.57091 .77117 m .57093 .77112 L .57093 .7711 L F
.57093 .77112 m .57272 .76668 L .57093 .7711 L F
.57573 .74667 m .57663 .74191 L .57713 .73932 L 0 0 .024 r
F
.57593 .74421 m .57868 .73121 L .57947 .72499 L F
.5709 .77118 m .57274 .76664 L .57091 .77117 L 0 1 .144 r
F
.57274 .76664 m .57798 .75365 L .57274 .76664 L F
.57274 .76664 m .57274 .76664 L .57091 .77117 L F
.57817 .73096 m .57756 .73435 L .57818 .73089 L 0 0 .054 r
F
.57593 .74421 m .57676 .73973 L .57691 .73841 L 0 0 .024 r
F
.57676 .73973 m .57722 .73718 L .57691 .73841 L F
.57088 .77123 m .5783 .75615 L .58014 .74829 L 0 1 .144 r
F
.58628 .75315 m .57838 .75947 L .57358 .76616 L 0 1 .474 r
F
.57088 .77123 m .57429 .76782 L .5783 .75615 L 0 1 .144 r
F
.58349 .75461 m .57459 .76706 L .57618 .77241 L 0 1 .4 r
F
.56997 .77787 m .57534 .76732 L .57429 .76782 L 0 1 .146 r
F
.56774 .78306 m .56817 .78239 L .56833 .7817 L F
.57515 .79005 m .56795 .80483 L .5779 .80096 L 0 1 .429 r
F
.57515 .79005 m .55988 .80392 L .56795 .80483 L F
.57515 .79005 m .55908 .79881 L .55988 .80392 L F
.5779 .80096 m .5619 .81607 L .57027 .81626 L 0 1 .437 r
F
.5779 .80096 m .56109 .81132 L .5619 .81607 L F
.5779 .80096 m .56795 .80483 L .56109 .81132 L F
.57623 .7927 m .56637 .80938 L .57268 .81045 L 0 1 .402 r
F
.57623 .7927 m .56518 .80374 L .56637 .80938 L F
.57623 .7927 m .5694 .79659 L .56518 .80374 L F
.57256 .77929 m .5694 .79659 L .57623 .7927 L 0 1 .407 r
F
.57256 .77929 m .5634 .79546 L .5694 .79659 L F
.5779 .80096 m .57027 .81626 L .58064 .81174 L 0 1 .437 r
F
.57623 .7927 m .57268 .81045 L .5799 .80624 L 0 1 .402 r
F
.56917 .80541 m .57632 .80015 L .57378 .80048 L 0 1 .321 r
F
.57072 .79247 m .56997 .80165 L .57438 .7955 L 0 1 .28 r
F
.57072 .79247 m .56742 .80289 L .56997 .80165 L F
.57072 .79247 m .56774 .79896 L .56742 .80289 L F
.56371 .7998 m .57072 .79247 L .57077 .78997 L 0 1 .198 r
F
.56371 .7998 m .56774 .79896 L .57072 .79247 L F
.56371 .7998 m .57077 .78997 L .56786 .79312 L F
.56984 .78439 m .56786 .79312 L .57077 .78997 L 0 1 .218 r
F
.57429 .75397 m .57622 .74689 L .57729 .74059 L 0 0 0 r
F
.56769 .78339 m .57292 .77483 L .57311 .772 L 0 1 .146 r
F
.56764 .78351 m .56769 .78343 L .56769 .78339 L F
.56769 .78343 m .57292 .77483 L .56769 .78339 L F
.57208 .72943 m .56303 .75032 L .56894 .74495 L 0 1 .368 r
F
.57208 .72943 m .56187 .74814 L .56303 .75032 L F
.57208 .72943 m .56576 .73918 L .56187 .74814 L F
.5685 .72314 m .56576 .73918 L .57208 .72943 L 0 1 .352 r
F
.57398 .72685 m .56818 .74553 L .57346 .746 L 0 1 .393 r
F
.57398 .72685 m .56652 .73997 L .56818 .74553 L F
.5685 .72314 m .57208 .72943 L .57565 .72018 L 0 1 .352 r
F
.57398 .72685 m .569 .73196 L .56652 .73997 L 0 1 .393 r
F
.5685 .72314 m .57565 .72018 L .5741 .71758 L 0 1 .352 r
F
.5685 .72314 m .56014 .74477 L .56576 .73918 L F
.56491 .71697 m .57178 .71373 L .57022 .71119 L 0 1 .335 r
F
.56491 .71697 m .5685 .72314 L .57178 .71373 L F
.5685 .72314 m .55898 .74247 L .56014 .74477 L 0 1 .352 r
F
.5685 .72314 m .56256 .73319 L .55898 .74247 L F
.56491 .71697 m .56256 .73319 L .5685 .72314 L 0 1 .335 r
F
.56911 .71267 m .56402 .73165 L .569 .73196 L 0 1 .387 r
F
.56851 .7301 m .57065 .74607 L .574 .75421 L 0 .512 .31 r
F
.57418 .75566 m .57622 .74689 L .57429 .75397 L 0 0 0 r
F
.57368 .75784 m .573 .76087 L .57622 .74689 L F
.57479 .75145 m .57729 .74059 L .57501 .75034 L F
.57548 .74793 m .57501 .75034 L .57663 .74191 L 0 0 .024 r
F
.57373 .75649 m .57434 .75378 L .57405 .75468 L 0 0 0 r
F
.57434 .75378 m .57729 .74059 L .57479 .75145 L F
.57434 .75378 m .57479 .75145 L .57405 .75468 L F
.57406 .75464 m .57479 .75145 L .57406 .75463 L F
.57427 .75354 m .57434 .75384 L .57497 .7499 L 0 .512 .31 r
F
.57434 .75384 m .57459 .75485 L .57498 .7506 L F
.57459 .75485 m .575 .75189 L .57498 .7506 L F
.57472 .75191 m .57548 .74793 L .57489 .75102 L 0 0 .024 r
F
.57548 .74793 m .57551 .74776 L .57488 .75107 L F
.57487 .75113 m .57488 .75107 L .57446 .75331 L F
.57548 .74793 m .57488 .75107 L .57487 .75113 L F
.57767 .73268 m .58094 .71071 L .57782 .73157 L 0 0 .054 r
F
.57861 .72767 m .57816 .72915 L .57989 .71718 L 0 0 .081 r
F
.57722 .73718 m .57947 .72499 L .57754 .7351 L 0 0 .024 r
F
.57548 .74793 m .57562 .74717 L .57551 .74776 L F
.57476 .7517 m .57501 .75034 L .57548 .74793 L F
.57446 .75331 m .57562 .74717 L .57573 .74667 L F
.57562 .74717 m .57663 .74191 L .57573 .74667 L F
.57713 .73932 m .57663 .74191 L .57868 .73121 L F
.57502 .75038 m .57518 .74953 L .57519 .74878 L F
.57518 .74953 m .57868 .73121 L .57535 .74799 L F
.57518 .74953 m .57535 .74799 L .57519 .74878 L F
.57521 .74865 m .57868 .73121 L .57593 .74421 L F
.57521 .7487 m .57868 .73121 L .57521 .74865 L F
.57679 .73556 m .57706 .7368 L .57711 .73643 L 0 .462 .294 r
F
.57672 .73537 m .57678 .7356 L .57679 .73556 L F
.57678 .7356 m .57706 .7368 L .57679 .73556 L F
.57641 .73824 m .57673 .73927 L .57672 .73537 L F
.57593 .74379 m .57593 .74421 L .57691 .73841 L 0 0 .024 r
F
.56911 .71267 m .569 .73196 L .57398 .72685 L 0 1 .387 r
F
.57507 .74677 m .57496 .74989 L .57534 .74744 L 0 .512 .31 r
F
.57447 .7484 m .57496 .74989 L .57507 .74677 L F
.56851 .7301 m .57534 .74744 L .57565 .7446 L F
.57437 .74808 m .57427 .75354 L .57497 .7499 L F
.56851 .7301 m .57349 .75038 L .57437 .74808 L F
.57349 .75038 m .57427 .75354 L .57437 .74808 L F
.57496 .74989 m .57506 .75018 L .57534 .74744 L F
.57519 .74878 m .57521 .7487 L .57521 .74865 L 0 0 .024 r
F
.57472 .75191 m .57474 .75181 L .57476 .7517 L F
.57474 .75181 m .57501 .75034 L .57476 .7517 L F
.57455 .75276 m .57501 .75034 L .57472 .75191 L F
.57406 .75463 m .57479 .75145 L .57501 .75034 L 0 0 0 r
F
.57434 .75384 m .57498 .7506 L .57497 .7499 L 0 .512 .31 r
F
.57472 .75191 m .57489 .75102 L .57446 .75331 L 0 0 .024 r
F
.57497 .7499 m .57498 .7506 L .57506 .75018 L 0 .512 .31 r
F
.57446 .75331 m .57502 .75038 L .57519 .74878 L 0 0 .024 r
F
.57575 .74481 m .57551 .74649 L .57593 .74379 L F
.57567 .7453 m .57551 .74649 L .57575 .74481 L F
.57426 .75433 m .57472 .75191 L .57446 .75331 L F
.57426 .75433 m .57455 .75276 L .57472 .75191 L F
.57405 .75468 m .57406 .75464 L .57406 .75463 L 0 0 0 r
F
.57417 .75314 m .574 .75421 L .57412 .7545 L 0 .512 .31 r
F
.57356 .75724 m .57418 .75566 L .57429 .75397 L 0 0 0 r
F
.57402 .7548 m .57439 .75607 L .57444 .75561 L 0 .568 .326 r
F
.574 .75485 m .57439 .75615 L .57402 .7548 L F
.57898 .72354 m .58149 .704 L .57899 .72339 L 0 0 .081 r
F
.57931 .72071 m .58172 .70056 L .57959 .71879 L F
.57889 .72425 m .58149 .704 L .57891 .72407 L F
.57757 .73309 m .57734 .73482 L .57816 .72915 L 0 0 .054 r
F
.56911 .71267 m .57398 .72685 L .57616 .71872 L 0 1 .387 r
F
.56972 .71641 m .57711 .73643 L .57756 .73319 L 0 .462 .294 r
F
.56972 .71641 m .57756 .73319 L .57353 .72167 L F
.57727 .73528 m .57782 .73157 L .57816 .72915 L 0 0 .054 r
F
.57757 .73309 m .57763 .73287 L .57762 .73296 L F
.57767 .73268 m .57782 .73157 L .57727 .73528 L F
.57722 .73718 m .57754 .7351 L .57691 .73841 L 0 0 .024 r
F
.57684 .73964 m .57729 .73618 L .57817 .73096 L 0 0 .054 r
F
.57798 .75365 m .58014 .74829 L .578 .75165 L 0 1 .144 r
F
.58349 .75461 m .57773 .75943 L .57459 .76706 L 0 1 .4 r
F
.58014 .74829 m .57958 .75813 L .58311 .75293 L 0 1 .237 r
F
.58014 .74829 m .5783 .75615 L .57958 .75813 L F
.57729 .74059 m .57622 .74689 L .57841 .74218 L 0 1 .133 r
F
.57684 .73964 m .577 .74736 L .58083 .75268 L 0 .462 .294 r
F
.57673 .74026 m .57674 .7402 L .57684 .73964 L 0 0 .054 r
F
.57718 .73596 m .57818 .73089 L .5782 .72915 L F
.57613 .74363 m .57637 .74466 L .57684 .73964 L 0 .462 .294 r
F
.57634 .74271 m .57657 .74112 L .57659 .74125 L 0 0 .054 r
F
.57657 .74112 m .57729 .73618 L .57674 .7402 L F
.57657 .74112 m .57674 .7402 L .57659 .74125 L F
.57616 .7434 m .57595 .74395 L .57691 .73841 L F
.57579 .74459 m .57691 .73841 L .5759 .74425 L 0 0 .024 r
F
.57587 .74506 m .57551 .74788 L .57601 .74534 L 0 .512 .31 r
F
.57575 .74481 m .57562 .74644 L .57587 .74506 L F
.57562 .74644 m .57551 .74788 L .57587 .74506 L F
.57613 .74363 m .57595 .74395 L .57616 .7434 L 0 0 .054 r
F
.57589 .74436 m .57587 .74442 L .57595 .74464 L 0 .462 .294 r
F
.57613 .74363 m .57595 .74464 L .577 .74736 L F
.57589 .74435 m .57595 .74395 L .57613 .74363 L 0 0 .054 r
F
.57551 .74649 m .57593 .74421 L .57593 .74379 L 0 0 .024 r
F
.57589 .74435 m .57587 .74442 L .57595 .74395 L 0 0 .054 r
F
.56972 .71641 m .57589 .74436 L .57613 .74363 L 0 .462 .294 r
F
.57589 .74436 m .57595 .74464 L .57613 .74363 L F
.56851 .7301 m .57574 .74479 L .57243 .73554 L 0 .512 .31 r
F
.57633 .74244 m .57657 .74112 L .57655 .74127 L 0 0 .054 r
F
.57632 .74256 m .57655 .74127 L .5757 .74707 L F
.57633 .74244 m .57655 .74127 L .57632 .74256 L F
.57571 .74504 m .57575 .74481 L .57581 .74476 L 0 0 .024 r
F
.57575 .74481 m .57579 .74459 L .57579 .74466 L F
.57575 .74481 m .57587 .74506 L .57587 .74442 L 0 .512 .31 r
F
.57575 .74481 m .57579 .74466 L .57581 .74476 L 0 0 .024 r
F
.57579 .74459 m .5759 .74425 L .57581 .74476 L F
.57574 .74479 m .57575 .74481 L .57587 .74442 L 0 .512 .31 r
F
.57587 .74506 m .577 .74736 L .57595 .74464 L F
.57587 .74506 m .57595 .74464 L .57587 .74442 L F
.57574 .74479 m .57587 .74442 L .57243 .73554 L F
.57611 .74371 m .57589 .74435 L .57613 .74363 L 0 0 .054 r
F
.57439 .75615 m .57439 .75607 L .57402 .7548 L 0 .568 .326 r
F
.56666 .74069 m .57311 .75965 L .57356 .75724 L F
.57311 .75965 m .5732 .75989 L .57356 .75724 L F
.57402 .7548 m .57373 .75649 L .57405 .75468 L 0 0 0 r
F
.57393 .75526 m .57373 .75649 L .57402 .7548 L F
.57356 .75724 m .57373 .75649 L .57398 .75499 L F
.57352 .75754 m .57418 .75566 L .57356 .75724 L F
.57343 .75787 m .57418 .75566 L .57345 .75773 L F
.57695 .73741 m .57729 .73517 L .5773 .73509 L 0 0 .054 r
F
.5734 .75797 m .57418 .75566 L .5734 .75795 L 0 0 0 r
F
.57305 .76051 m .5732 .75989 L .5734 .75798 L F
.5732 .75989 m .57418 .75566 L .57354 .75756 L F
.5732 .75989 m .57354 .75756 L .5734 .75798 L F
.57252 .76289 m .57245 .76325 L .573 .76087 L F
.56634 .76679 m .5537 .76947 L .56093 .76884 L F
.56634 .76679 m .55275 .77137 L .5537 .76947 L F
.56383 .76762 m .56634 .76684 L .57161 .76315 L 0 0 .058 r
F
.56383 .76762 m .57161 .76315 L .57048 .76174 L F
.56127 .76402 m .56877 .7595 L .56763 .75793 L 0 1 .301 r
F
.56127 .76402 m .56383 .76762 L .56877 .7595 L F
.56521 .75277 m .56888 .766 L .57221 .75905 L 0 1 .408 r
F
.56521 .75277 m .57221 .75905 L .57062 .75371 L F
.56136 .73903 m .56521 .75277 L .56818 .74553 L 0 1 .404 r
F
.56136 .73903 m .56818 .74553 L .56652 .73997 L F
.57231 .76376 m .57442 .7562 L .57245 .76325 L 0 0 0 r
F
.57088 .77123 m .5787 .74972 L .57492 .75951 L 0 1 .144 r
F
.57131 .76537 m .5716 .76682 L .57172 .76631 L 0 .626 .341 r
F
.57172 .76631 m .57308 .7623 L .57442 .7562 L 0 0 0 r
F
.5716 .76682 m .57161 .76688 L .57172 .76631 L 0 .626 .341 r
F
.57119 .76914 m .57308 .7623 L .57172 .76631 L 0 0 0 r
F
.57079 .76798 m .57115 .76902 L .57145 .76608 L 0 .626 .341 r
F
.56754 .78404 m .57321 .77435 L .56764 .78351 L 0 1 .146 r
F
.56977 .77903 m .57534 .76732 L .56997 .77787 L F
.56751 .78394 m .56732 .78515 L .56754 .78402 L 0 .675 .379 r
F
.5673 .78331 m .56717 .7843 L .56737 .78353 L F
.56668 .78147 m .56711 .78395 L .5673 .78331 L F
.56711 .78395 m .56717 .7843 L .5673 .78331 L F
.56634 .76679 m .55817 .77022 L .55275 .77137 L 0 0 0 r
F
.56383 .76762 m .55817 .77035 L .56634 .76684 L 0 0 .058 r
F
.55869 .75923 m .56591 .75531 L .56476 .75339 L 0 1 .347 r
F
.55869 .75923 m .56127 .76402 L .56591 .75531 L F
.56888 .766 m .56042 .78206 L .56613 .78313 L 0 1 .409 r
F
.56888 .766 m .55923 .77681 L .56042 .78206 L F
.56888 .766 m .56286 .76992 L .55923 .77681 L F
.56383 .76762 m .55151 .77623 L .55817 .77035 L 0 0 .058 r
F
.56383 .76762 m .5508 .78058 L .55151 .77623 L F
.56383 .76762 m .55609 .77689 L .5508 .78058 L F
.56127 .76402 m .55609 .77689 L .56383 .76762 L 0 1 .301 r
F
.56521 .75277 m .56286 .76992 L .56888 .766 L 0 1 .408 r
F
.56127 .76402 m .54971 .783 L .55609 .77689 L 0 1 .301 r
F
.56127 .76402 m .54896 .78188 L .54971 .783 L F
.56127 .76402 m .55392 .77374 L .54896 .78188 L F
.55869 .75923 m .55392 .77374 L .56127 .76402 L 0 1 .347 r
F
.56521 .75277 m .55745 .76899 L .56286 .76992 L 0 1 .408 r
F
.55869 .75923 m .54784 .77961 L .55392 .77374 L 0 1 .347 r
F
.56521 .75277 m .55626 .76382 L .55745 .76899 L 0 1 .408 r
F
.5561 .75376 m .55869 .75923 L .56303 .75032 L 0 1 .347 r
F
.55869 .75923 m .54708 .7777 L .54784 .77961 L F
.55869 .75923 m .55174 .76896 L .54708 .7777 L F
.5561 .75376 m .55174 .76896 L .55869 .75923 L F
.56521 .75277 m .55958 .75687 L .55626 .76382 L 0 1 .408 r
F
.5561 .75376 m .56303 .75032 L .56187 .74814 L 0 1 .347 r
F
.56136 .73903 m .55958 .75687 L .56521 .75277 L 0 1 .404 r
F
.56122 .75553 m .56973 .77493 L .56919 .7697 L 0 .684 .355 r
F
.56779 .78281 m .57429 .76782 L .57075 .77555 L 0 1 .146 r
F
.56771 .78313 m .57429 .76782 L .56779 .78281 L F
.57088 .77123 m .56929 .77702 L .57075 .77555 L 0 1 .144 r
F
.5693 .77676 m .56929 .77702 L .56976 .77533 L 0 0 0 r
F
.56668 .78147 m .56594 .78926 L .56618 .7898 L 0 .675 .379 r
F
.56668 .78147 m .56618 .7898 L .56635 .78922 L F
.56585 .79095 m .56984 .78439 L .56919 .78422 L 0 1 .145 r
F
.56185 .78442 m .56583 .79098 L .56594 .78926 L 0 .744 .39 r
F
.56555 .79201 m .56984 .78439 L .56585 .79095 L 0 1 .145 r
F
.56185 .78442 m .56539 .79236 L .56583 .79098 L 0 .744 .39 r
F
.56539 .79236 m .56543 .79245 L .56583 .79098 L F
.56668 .78147 m .56634 .78947 L .56732 .78515 L 0 .675 .379 r
F
.56732 .78515 m .56621 .78986 L .56628 .78972 L 0 1 .146 r
F
.56732 .78515 m .56628 .78972 L .56919 .78422 L F
.56585 .79095 m .56919 .78422 L .56621 .78986 L 0 1 .145 r
F
.56543 .79245 m .56984 .78439 L .56555 .79201 L F
.56754 .78404 m .56919 .78422 L .57321 .77435 L 0 1 .146 r
F
.56727 .78489 m .56732 .78515 L .56751 .78394 L 0 .675 .379 r
F
.56672 .78545 m .56732 .78515 L .56754 .78404 L 0 1 .146 r
F
.56733 .78514 m .56919 .78422 L .56754 .78404 L F
.56668 .78147 m .56754 .78404 L .56764 .78355 L 0 .675 .379 r
F
.55634 .7879 m .559 .80112 L .5634 .79546 L 0 1 .423 r
F
.55634 .7879 m .5634 .79546 L .56221 .79005 L F
.559 .80112 m .56167 .81498 L .56637 .80938 L 0 1 .417 r
F
.559 .80112 m .56637 .80938 L .56518 .80374 L F
.5631 .8082 m .56997 .80165 L .56742 .80289 L 0 1 .262 r
F
.56371 .7998 m .5636 .80563 L .56774 .79896 L 0 1 .198 r
F
.55367 .77503 m .55634 .7879 L .56042 .78206 L 0 1 .425 r
F
.56371 .7998 m .56104 .80804 L .5636 .80563 L 0 1 .198 r
F
.56371 .7998 m .56165 .80431 L .56104 .80804 L F
.56165 .80431 m .56108 .80439 L .56107 .80597 L 0 .783 .412 r
F
.56165 .80431 m .56107 .80597 L .56107 .80673 L F
.55451 .81437 m .55639 .82007 L .55804 .81593 L 0 1 .296 r
F
.55451 .81437 m .55341 .82299 L .55639 .82007 L F
.55451 .81437 m .55804 .81593 L .55724 .81333 L F
.559 .80112 m .55421 .81681 L .56167 .81498 L 0 1 .417 r
F
.55828 .82702 m .55398 .83627 L .55691 .83678 L 0 1 .454 r
F
.55828 .82702 m .55332 .83342 L .55398 .83627 L F
.55828 .82702 m .55516 .82946 L .55332 .83342 L F
.55639 .82007 m .55828 .82702 L .56002 .823 L 0 1 .422 r
F
.55639 .82007 m .55516 .82946 L .55828 .82702 L F
.55639 .82007 m .55233 .82946 L .55516 .82946 L F
.55639 .82007 m .56002 .823 L .55923 .82008 L F
.54391 .82982 m .54525 .83568 L .55232 .82946 L 0 1 .465 r
F
.55639 .82007 m .55167 .82702 L .55233 .82946 L 0 1 .422 r
F
.54391 .82982 m .55232 .82946 L .55166 .82702 L 0 1 .465 r
F
.55639 .82007 m .55341 .82299 L .55167 .82702 L 0 1 .422 r
F
.56167 .81498 m .54998 .8288 L .55647 .83188 L 0 1 .398 r
F
.55451 .81437 m .55068 .82404 L .55341 .82299 L 0 1 .296 r
F
.54258 .82594 m .54391 .82982 L .55043 .82426 L 0 1 .426 r
F
.55045 .8241 m .55043 .82426 L .55067 .82405 L F
.54258 .82594 m .55043 .82426 L .55045 .8241 L F
.55264 .81221 m .55136 .81665 L .55166 .81838 L 0 0 0 r
F
.54258 .82594 m .55067 .82405 L .55002 .82253 L 0 1 .426 r
F
.55136 .81665 m .54906 .82462 L .55093 .82013 L 0 0 0 r
F
.55136 .81665 m .55093 .82013 L .55166 .81838 L F
.55451 .81437 m .55002 .82253 L .55068 .82404 L 0 1 .296 r
F
.55451 .81437 m .55166 .81838 L .55002 .82253 L F
.55264 .81221 m .54843 .82895 L .54906 .82462 L 0 0 0 r
F
.55264 .81221 m .54997 .82362 L .54843 .82895 L F
.56167 .81498 m .5492 .82274 L .54998 .8288 L 0 1 .398 r
F
.56167 .81498 m .55421 .81681 L .5492 .82274 L F
.55264 .81221 m .55451 .81437 L .55604 .80907 L 0 0 0 r
F
.55264 .81221 m .55166 .81838 L .55451 .81437 L F
.55264 .81221 m .55604 .80907 L .55524 .80598 L F
.559 .80112 m .54803 .8142 L .55421 .81681 L 0 1 .417 r
F
.58064 .81174 m .5639 .82753 L .57259 .82722 L 0 1 .443 r
F
.58064 .81174 m .5631 .82302 L .5639 .82753 L F
.58064 .81174 m .57027 .81626 L .5631 .82302 L F
.55828 .82702 m .56016 .83463 L .56201 .83067 L 0 1 .454 r
F
.55828 .82702 m .55691 .83678 L .56016 .83463 L F
.55828 .82702 m .56201 .83067 L .56121 .82754 L F
.56167 .81498 m .55647 .83188 L .56434 .82992 L 0 1 .398 r
F
.55596 .82151 m .56 .82059 L .56126 .81698 L 0 1 .235 r
F
.54658 .84251 m .55563 .84374 L .55497 .84069 L 0 1 .491 r
F
.56434 .82992 m .55647 .83188 L .55118 .84205 L 0 .829 .324 r
F
.56016 .83463 m .55691 .83678 L .55497 .84069 L 0 1 .466 r
F
.54792 .84988 m .54925 .85757 L .55727 .85157 L 0 1 .494 r
F
.54792 .84988 m .55727 .85157 L .55662 .84841 L F
.56016 .83463 m .56205 .8426 L .56399 .8387 L 0 1 .466 r
F
.56016 .83463 m .55866 .84456 L .56205 .8426 L F
.56016 .83463 m .55563 .84374 L .55866 .84456 L F
.56016 .83463 m .56399 .8387 L .5632 .83545 L F
.54658 .84251 m .54792 .84988 L .55563 .84374 L 0 1 .491 r
F
.56016 .83463 m .55497 .84069 L .55563 .84374 L 0 1 .466 r
F
.55285 .84792 m .5485 .84185 L .54922 .85352 L 0 .209 .239 r
F
.55287 .84789 m .55281 .84781 L .55285 .84792 L F
.55281 .84781 m .5485 .84185 L .55285 .84792 L F
.54525 .83568 m .54658 .84251 L .55397 .83627 L 0 1 .484 r
F
.54525 .83568 m .55397 .83627 L .55331 .83343 L F
.54792 .84988 m .53788 .86241 L .54925 .85757 L 0 1 .494 r
F
.54792 .84988 m .52917 .8639 L .53788 .86241 L F
.54792 .84988 m .52893 .86103 L .52917 .8639 L F
.54792 .84988 m .53697 .85502 L .52893 .86103 L F
.54658 .84251 m .53697 .85502 L .54792 .84988 L 0 1 .491 r
F
.54658 .84251 m .52857 .85685 L .53697 .85502 L F
.54658 .84251 m .52834 .85414 L .52857 .85685 L F
.54658 .84251 m .53606 .84799 L .52834 .85414 L F
.54525 .83568 m .53606 .84799 L .54658 .84251 L 0 1 .484 r
F
.54525 .83568 m .52798 .85025 L .53606 .84799 L F
.54132 .83916 m .54922 .85342 L .54849 .84163 L 0 1 .386 r
F
.55287 .84789 m .55006 .83943 L .5485 .84185 L 0 .209 .239 r
F
.54925 .85757 m .55058 .86544 L .55892 .85959 L 0 1 .496 r
F
.54925 .85757 m .55892 .85959 L .55826 .85637 L F
.55286 .84796 m .54922 .85352 L .55194 .8631 L 0 .209 .239 r
F
.55287 .84789 m .55285 .84792 L .55286 .84796 L F
.55285 .84792 m .54922 .85352 L .55286 .84796 L F
.55061 .85592 m .54737 .83558 L .54857 .8373 L 0 .676 .064 r
F
.55011 .84113 m .54857 .8373 L .55006 .83941 L F
.55061 .85592 m .54857 .8373 L .55011 .84113 L F
.55006 .83942 m .55006 .83941 L .55006 .83942 L F
.55061 .85592 m .55006 .83941 L .55006 .83942 L F
.55061 .85592 m .55006 .83942 L .55287 .84788 L F
.55287 .84789 m .55194 .8631 L .55484 .86418 L 0 .209 .239 r
F
.55287 .84789 m .55484 .86418 L .55641 .86177 L F
.55061 .85592 m .55287 .84788 L .55427 .85661 L 0 .676 .064 r
F
.55287 .84789 m .55641 .86177 L .55559 .85747 L 0 .209 .239 r
F
.56434 .82992 m .55118 .84205 L .55199 .85367 L 0 .829 .324 r
F
.55432 .83489 m .55832 .83654 L .56068 .83195 L 0 1 .33 r
F
.55432 .83489 m .56068 .83195 L .55895 .83134 L F
.56167 .81498 m .56434 .82992 L .56935 .82399 L 0 1 .398 r
F
.56507 .82057 m .55895 .83134 L .56068 .83195 L 0 1 .349 r
F
.56507 .82057 m .56083 .82646 L .55895 .83134 L F
.56 .82059 m .55635 .83076 L .56083 .82646 L 0 1 .303 r
F
.55113 .83385 m .55432 .83489 L .55635 .83076 L 0 1 .277 r
F
.55089 .83441 m .55432 .83489 L .55113 .83385 L F
.5503 .8326 m .55089 .83441 L .55113 .83385 L 0 .957 .446 r
F
.55089 .83441 m .55113 .83385 L .55113 .83385 L 0 1 .277 r
F
.56392 .85078 m .55827 .85636 L .55892 .85959 L 0 1 .477 r
F
.56392 .85078 m .56041 .85258 L .55827 .85636 L F
.56205 .8426 m .55728 .85157 L .56041 .85258 L 0 1 .473 r
F
.56205 .8426 m .55662 .8484 L .55728 .85157 L F
.56205 .8426 m .55866 .84456 L .55662 .8484 L F
.56434 .82992 m .55199 .85367 L .5588 .85672 L 0 .829 .324 r
F
.55832 .83654 m .55197 .84793 L .55687 .84445 L 0 1 .366 r
F
.54871 .8325 m .55199 .85348 L .55117 .84197 L 0 .855 .434 r
F
.54871 .8325 m .55061 .8559 L .55199 .85348 L F
.55832 .83654 m .55073 .84694 L .55197 .84793 L 0 1 .366 r
F
.55832 .83654 m .55345 .84206 L .55073 .84694 L F
.55432 .83489 m .55345 .84206 L .55832 .83654 L 0 1 .33 r
F
.55061 .85592 m .54658 .83892 L .54737 .83558 L 0 .676 .064 r
F
.55061 .85592 m .54796 .84763 L .54658 .83892 L F
.54871 .8325 m .54796 .84762 L .55061 .8559 L 0 .855 .434 r
F
.55432 .83489 m .54883 .84562 L .55345 .84206 L 0 1 .33 r
F
.54525 .83568 m .52774 .84778 L .52798 .85025 L 0 1 .484 r
F
.54525 .83568 m .53515 .84153 L .52774 .84778 L F
.54391 .82982 m .53515 .84153 L .54525 .83568 L 0 1 .465 r
F
.54391 .82982 m .52738 .84434 L .53515 .84153 L F
.53968 .83773 m .54129 .83297 L .54736 .83531 L 0 .467 .351 r
F
.53968 .83773 m .54736 .83531 L .54657 .8388 L F
.54871 .8325 m .5455 .83816 L .54796 .84762 L 0 .855 .434 r
F
.55432 .83489 m .54753 .84485 L .54883 .84562 L 0 1 .33 r
F
.55432 .83489 m .54989 .84025 L .54753 .84485 L F
.5503 .8326 m .54556 .84027 L .54755 .84219 L 0 .957 .446 r
F
.55089 .83441 m .54989 .84025 L .55432 .83489 L 0 1 .277 r
F
.55089 .83441 m .54989 .84025 L .55089 .83441 L F
.55019 .83605 m .54989 .84025 L .55089 .83441 L F
.55019 .83605 m .54755 .84219 L .54991 .84448 L 0 .957 .446 r
F
.5503 .8326 m .54755 .84219 L .55019 .83605 L F
.55089 .83441 m .55089 .83441 L .55089 .83441 L 0 1 .277 r
F
.5503 .8326 m .55019 .8361 L .55089 .83441 L 0 .957 .446 r
F
.55031 .83433 m .55019 .83605 L .55089 .83441 L 0 1 .277 r
F
.55113 .83385 m .55439 .84516 L .55643 .84187 L 0 .957 .446 r
F
.55113 .83385 m .55113 .83386 L .55113 .83385 L F
.55113 .83386 m .55439 .84516 L .55113 .83385 L F
.55089 .83441 m .55439 .84516 L .55113 .83385 L F
.55125 .83352 m .55635 .83076 L .55462 .8306 L 0 1 .277 r
F
.55031 .83433 m .55113 .83385 L .55125 .83352 L F
.55113 .83385 m .55635 .83076 L .55125 .83352 L F
.55125 .83352 m .55113 .83385 L .55126 .83353 L 0 .957 .446 r
F
.5503 .8326 m .55113 .83385 L .55125 .83352 L F
.55126 .83353 m .55643 .84187 L .55466 .83682 L F
.55113 .83385 m .55643 .84187 L .55126 .83353 L F
.55031 .83433 m .55089 .83441 L .55113 .83385 L 0 1 .277 r
F
.55089 .83441 m .54991 .84448 L .55439 .84516 L 0 .957 .446 r
F
.55019 .8361 m .54991 .84448 L .55089 .83441 L F
.56 .82059 m .55462 .8306 L .55635 .83076 L 0 1 .303 r
F
.56 .82059 m .55618 .82625 L .55462 .8306 L F
.55574 .82211 m .55618 .82625 L .56 .82059 L 0 1 .235 r
F
.55491 .81992 m .55525 .8234 L .55574 .82211 L 0 .901 .434 r
F
.55493 .82239 m .55525 .8234 L .55574 .82211 L 0 1 .235 r
F
.55525 .8234 m .55618 .82625 L .55574 .82211 L F
.55525 .8234 m .55526 .82343 L .55574 .82211 L 0 .901 .434 r
F
.55491 .81992 m .552 .82899 L .55288 .82988 L F
.55491 .81992 m .55288 .82988 L .5529 .82982 L F
.55491 .81992 m .55289 .82989 L .55526 .82343 L F
.55493 .82239 m .55201 .83084 L .55288 .82988 L 0 1 .235 r
F
.55525 .8234 m .55288 .82988 L .55618 .82625 L F
.55493 .82239 m .55288 .82988 L .55525 .8234 L F
.5529 .82982 m .55288 .82988 L .55289 .82989 L 0 .901 .434 r
F
.55574 .82211 m .55623 .83328 L .5601 .83362 L F
.55526 .82343 m .55623 .83328 L .55574 .82211 L F
.55574 .82211 m .56 .82059 L .55596 .82151 L 0 1 .235 r
F
.55595 .82151 m .5601 .83362 L .56135 .82974 L 0 .901 .434 r
F
.55491 .81992 m .55574 .82211 L .55595 .82151 L F
.55595 .82151 m .55574 .82211 L .55596 .82151 L 0 1 .235 r
F
.55589 .82169 m .55574 .82211 L .55595 .82151 L F
.55574 .82211 m .55574 .82211 L .55595 .82152 L F
.55574 .82211 m .5601 .83362 L .55595 .82151 L 0 .901 .434 r
F
.55595 .82152 m .55589 .82169 L .55595 .82151 L 0 1 .235 r
F
.55493 .82239 m .55574 .82211 L .55595 .82152 L F
.55526 .82343 m .55289 .82989 L .55623 .83328 L 0 .901 .434 r
F
.55609 .82112 m .56126 .81698 L .5591 .81781 L 0 1 .235 r
F
.55493 .82239 m .55595 .82151 L .55609 .82112 L F
.55595 .82151 m .56126 .81698 L .55609 .82112 L F
.55609 .82112 m .56135 .82974 L .55915 .82422 L 0 .901 .434 r
F
.55491 .81992 m .55595 .82151 L .55609 .82112 L F
.55595 .82151 m .56135 .82974 L .55609 .82112 L F
.56167 .81498 m .56935 .82399 L .56816 .81806 L 0 1 .398 r
F
.5631 .8082 m .5591 .81781 L .56126 .81698 L 0 1 .262 r
F
.5631 .8082 m .55989 .81404 L .5591 .81781 L F
.55964 .81137 m .55989 .81404 L .5631 .8082 L 0 1 .179 r
F
.55695 .80483 m .55583 .81561 L .5575 .81742 L 0 .845 .418 r
F
.55695 .80483 m .5575 .81742 L .55751 .81738 L F
.55873 .81394 m .55751 .81744 L .55753 .8174 L 0 1 .179 r
F
.55873 .81394 m .55753 .8174 L .55989 .81404 L F
.55873 .81394 m .55989 .81404 L .55964 .81137 L F
.56 .82059 m .56507 .82057 L .56663 .81622 L 0 1 .303 r
F
.56 .82059 m .56663 .81622 L .56448 .8163 L F
.5631 .8082 m .56126 .81698 L .56557 .81167 L 0 1 .262 r
F
.55962 .81137 m .55994 .82009 L .5632 .82011 L 0 .845 .418 r
F
.55695 .80483 m .55873 .81394 L .55962 .81137 L F
.55873 .81394 m .55994 .82009 L .55962 .81137 L F
.55873 .81394 m .55751 .81744 L .55874 .81396 L F
.55695 .80483 m .55751 .81742 L .55873 .81394 L F
.55751 .81742 m .55751 .81744 L .55873 .81394 L F
.55701 .81378 m .55586 .81978 L .55751 .81744 L 0 1 .179 r
F
.55751 .81738 m .5575 .81742 L .55751 .81744 L 0 .845 .418 r
F
.55701 .81378 m .55751 .81744 L .55873 .81394 L 0 1 .179 r
F
.55964 .81137 m .5631 .8082 L .56017 .80988 L F
.56015 .8099 m .5632 .82011 L .56368 .81549 L 0 .845 .418 r
F
.56015 .8099 m .55964 .81137 L .56017 .80988 L 0 1 .179 r
F
.55695 .80483 m .55963 .81138 L .56015 .8099 L 0 .845 .418 r
F
.55701 .81378 m .55963 .81138 L .56015 .8099 L 0 1 .179 r
F
.55963 .81138 m .55964 .81137 L .56015 .8099 L F
.56015 .8099 m .55963 .81138 L .56015 .8099 L 0 .845 .418 r
F
.55963 .81138 m .5632 .82011 L .56015 .8099 L F
.55963 .81138 m .55873 .81394 L .55964 .81137 L 0 1 .179 r
F
.55701 .81378 m .55872 .81394 L .55963 .81138 L F
.55872 .81394 m .55873 .81394 L .55963 .81138 L F
.55874 .81396 m .55751 .81744 L .55994 .82009 L 0 .845 .418 r
F
.56017 .80988 m .5631 .8082 L .5636 .80563 L 0 1 .179 r
F
.56015 .8099 m .5636 .80563 L .56054 .80876 L F
.56054 .80876 m .56368 .81549 L .56105 .80932 L 0 .845 .418 r
F
.55695 .80483 m .56015 .8099 L .56054 .80876 L F
.56015 .8099 m .56368 .81549 L .56054 .80876 L F
.56054 .80876 m .5636 .80563 L .56104 .80804 L 0 1 .179 r
F
.55701 .81378 m .56015 .8099 L .56054 .80876 L F
.5649 .79448 m .56376 .79854 L .56745 .79073 L 0 1 .145 r
F
.5649 .79448 m .56745 .79073 L .56545 .7924 L F
.5631 .8082 m .56917 .80541 L .56997 .80165 L 0 1 .262 r
F
.56545 .7925 m .56756 .80328 L .57 .80271 L 0 .744 .39 r
F
.56543 .79245 m .5649 .79448 L .56545 .7924 L 0 1 .145 r
F
.56185 .78442 m .5649 .79448 L .56543 .79245 L 0 .744 .39 r
F
.5565 .78665 m .56251 .80106 L .5633 .79814 L 0 .805 .399 r
F
.56185 .78442 m .56348 .79843 L .56369 .79869 L 0 .744 .39 r
F
.56185 .78442 m .56369 .79869 L .56372 .79857 L F
.5649 .79448 m .56369 .79869 L .56376 .79854 L 0 1 .145 r
F
.56185 .78442 m .56375 .79876 L .5649 .79448 L 0 .744 .39 r
F
.5565 .78665 m .56348 .79843 L .56046 .7914 L 0 .805 .399 r
F
.56185 .78442 m .56046 .7914 L .56348 .79843 L 0 .744 .39 r
F
.56286 .79713 m .56519 .79334 L .56538 .79253 L 0 1 .145 r
F
.56196 .79878 m .56277 .79741 L .56286 .79713 L F
.56277 .79741 m .56519 .79334 L .56286 .79713 L F
.56265 .79762 m .5649 .79448 L .56519 .79334 L F
.56196 .79878 m .56255 .79791 L .56265 .79762 L F
.56255 .79791 m .5649 .79448 L .56265 .79762 L F
.56668 .78147 m .56481 .78274 L .56594 .78926 L 0 .675 .379 r
F
.56553 .78875 m .5649 .79083 L .56629 .78665 L 0 0 0 r
F
.559 .80112 m .54725 .80888 L .54803 .8142 L 0 1 .417 r
F
.559 .80112 m .55195 .80328 L .54725 .80888 L F
.55634 .7879 m .55195 .80328 L .559 .80112 L 0 1 .423 r
F
.5565 .78665 m .55712 .79965 L .56108 .80439 L 0 .805 .399 r
F
.5565 .78665 m .56108 .80439 L .56162 .80431 L F
.5565 .78665 m .56162 .80431 L .56164 .80427 L F
.5565 .78665 m .56165 .80431 L .56268 .80146 L F
.55829 .80834 m .56008 .80569 L .56041 .80458 L 0 .922 .142 r
F
.55805 .80899 m .56008 .80569 L .55829 .80834 L F
.56196 .79878 m .5599 .80386 L .56056 .80401 L 0 1 .145 r
F
.56116 .80077 m .5599 .80386 L .56196 .79878 L 0 0 0 r
F
.5574 .81004 m .55965 .80709 L .56008 .80569 L 0 .922 .142 r
F
.55725 .8104 m .55965 .80709 L .5574 .81004 L F
.55672 .81115 m .55965 .80709 L .55674 .81111 L F
.55756 .80964 m .55805 .80899 L .55829 .80834 L F
.55672 .81113 m .5574 .81004 L .55756 .80964 L F
.55674 .81111 m .55725 .8104 L .5574 .81004 L F
.55667 .81123 m .55814 .80934 L .55825 .80904 L F
.54971 .80516 m .55147 .81972 L .55491 .81992 L 0 .9 .424 r
F
.54971 .80516 m .55491 .81992 L .55583 .81561 L F
.54971 .80516 m .55583 .81561 L .55362 .80964 L F
.55695 .80483 m .55362 .80964 L .55583 .81561 L 0 .845 .418 r
F
.56088 .80147 m .55963 .80453 L .56098 .80122 L 0 0 0 r
F
.55719 .81056 m .55721 .81275 L .56109 .80554 L 0 .922 .142 r
F
.5568 .81151 m .55721 .81275 L .55719 .81056 L F
.55668 .81124 m .55668 .81125 L .5567 .81119 L F
.55668 .81125 m .55721 .81275 L .5567 .8112 L F
.55668 .81125 m .5567 .8112 L .5567 .81119 L F
.55338 .81887 m .55701 .81378 L .55721 .81275 L 0 .894 .136 r
F
.55491 .81992 m .55147 .81972 L .55022 .82361 L 0 .901 .434 r
F
.55175 .82145 m .55299 .81972 L .55338 .81887 L 0 .894 .136 r
F
.55115 .82241 m .55161 .82174 L .55175 .82145 L F
.55161 .82174 m .55299 .81972 L .55175 .82145 L F
.55667 .81123 m .55441 .81596 L .55465 .81661 L 0 .922 .142 r
F
.55552 .81383 m .55441 .81596 L .55667 .81123 L 0 0 0 r
F
.55109 .82253 m .55299 .81972 L .55115 .82241 L 0 .894 .136 r
F
.54391 .82982 m .52714 .84223 L .52738 .84434 L 0 1 .465 r
F
.54391 .82982 m .53423 .836 L .52714 .84223 L F
.54258 .82594 m .53423 .836 L .54391 .82982 L 0 1 .426 r
F
.54129 .83285 m .54258 .82594 L .54905 .82472 L 0 1 .453 r
F
.54129 .83285 m .54905 .82472 L .54842 .82917 L F
.54685 .81807 m .54998 .8288 L .5492 .82274 L 0 1 .426 r
F
.54685 .81807 m .54389 .82669 L .54623 .83135 L F
.54685 .81807 m .54325 .82162 L .54389 .82669 L F
.54685 .81807 m .54623 .83135 L .54871 .8325 L F
.54685 .81807 m .54871 .8325 L .54998 .8288 L F
.5462 .81925 m .5503 .8326 L .552 .82899 L 0 .95 .438 r
F
.5462 .81925 m .552 .82899 L .55022 .82361 L F
.55491 .81992 m .55022 .82361 L .552 .82899 L 0 .901 .434 r
F
.54983 .82652 m .55493 .82239 L .55586 .81978 L 0 1 .175 r
F
.54983 .82652 m .55152 .82769 L .55493 .82239 L F
.54871 .8325 m .54623 .83135 L .54486 .83378 L 0 .855 .434 r
F
.54258 .82594 m .52678 .83942 L .53423 .836 L 0 1 .426 r
F
.54258 .82594 m .52654 .8378 L .52678 .83942 L F
.54258 .82594 m .53332 .83202 L .52654 .8378 L F
.54129 .83285 m .53332 .83202 L .54258 .82594 L 0 1 .453 r
F
.53839 .82835 m .5455 .83815 L .54486 .83378 L 0 1 .5 r
F
.54871 .8325 m .54486 .83378 L .5455 .83816 L 0 .855 .434 r
F
.5503 .8326 m .54627 .83203 L .54424 .83532 L 0 .957 .446 r
F
.5462 .81925 m .54627 .83203 L .5503 .8326 L 0 .95 .438 r
F
.54983 .82652 m .54765 .83262 L .55152 .82769 L 0 1 .175 r
F
.54983 .82652 m .55586 .81978 L .5537 .82159 L F
.55418 .81797 m .55419 .81901 L .55701 .81378 L 0 .894 .136 r
F
.55108 .82255 m .55336 .81998 L .55418 .81797 L F
.55101 .8227 m .55336 .81998 L .55108 .82255 L F
.55101 .8227 m .55045 .82521 L .55419 .81901 L F
.5509 .82282 m .55088 .82294 L .55101 .8227 L F
.55088 .82294 m .55045 .82521 L .55101 .8227 L F
.55322 .81897 m .55721 .81275 L .55465 .81661 L F
.55299 .81947 m .55721 .81275 L .55322 .81897 L F
.55114 .82244 m .55296 .81952 L .5512 .82233 L F
.55296 .81952 m .55721 .81275 L .55299 .81947 L F
.55296 .81952 m .55299 .81947 L .5512 .82233 L F
.55742 .81001 m .55926 .80538 L .55932 .80527 L 0 0 0 r
F
.55299 .81972 m .55701 .81378 L .55338 .81887 L 0 .894 .136 r
F
.55668 .81124 m .55465 .81661 L .55721 .81275 L 0 .922 .142 r
F
.55667 .81123 m .55661 .8114 L .55668 .81124 L F
.55661 .8114 m .55465 .81661 L .55668 .81124 L F
.55943 .80504 m .55936 .80514 L .55963 .80453 L 0 0 0 r
F
.5574 .81004 m .55805 .80899 L .55756 .80964 L 0 .922 .142 r
F
.5633 .79814 m .5634 .79952 L .56348 .79843 L 0 .805 .399 r
F
.56268 .80146 m .56165 .80431 L .56371 .7998 L 0 .922 .142 r
F
.5634 .79952 m .56374 .804 L .56351 .79923 L 0 .805 .399 r
F
.5634 .79952 m .56351 .79923 L .56348 .79843 L F
.56268 .80146 m .56371 .7998 L .56351 .79923 L 0 .922 .142 r
F
.56251 .80106 m .56374 .804 L .5633 .79814 L 0 .805 .399 r
F
.56268 .80146 m .56351 .79923 L .56351 .79922 L 0 .922 .142 r
F
.55674 .8111 m .56348 .79913 L .56056 .80401 L F
.55667 .81123 m .55672 .81113 L .55674 .8111 L F
.55672 .81113 m .56348 .79913 L .55674 .8111 L F
.55936 .80521 m .55919 .80559 L .55943 .80504 L 0 0 0 r
F
.55405 .81844 m .55913 .80574 L .55936 .80521 L F
.55913 .80574 m .55919 .80559 L .55936 .80521 L F
.55919 .80559 m .55936 .80514 L .55943 .80504 L F
.55405 .81844 m .5574 .81006 L .55742 .81001 L F
.5574 .81006 m .55926 .80538 L .55742 .81001 L F
.55405 .81844 m .55617 .81275 L .55644 .81211 L F
.5567 .81119 m .5568 .81151 L .55719 .81056 L 0 .922 .142 r
F
.5574 .81006 m .55644 .81211 L .55926 .80538 L 0 0 0 r
F
.55405 .81844 m .55644 .81211 L .5574 .81006 L F
.5512 .82233 m .55299 .81947 L .55322 .81897 L 0 .894 .136 r
F
.5509 .82282 m .55114 .82244 L .5512 .82233 L F
.5496 .82726 m .5508 .82365 L .55346 .818 L 0 0 0 r
F
.55356 .81781 m .55346 .818 L .55364 .81761 L F
.5496 .82726 m .55346 .818 L .55356 .81781 L F
.55371 .81747 m .55364 .81761 L .55377 .81733 L F
.5496 .82726 m .55364 .81761 L .55371 .81747 L F
.55412 .81666 m .55377 .81733 L .55441 .81596 L F
.5496 .82726 m .55377 .81733 L .55412 .81666 L F
.5509 .82282 m .55101 .8227 L .55108 .82255 L 0 .894 .136 r
F
.55336 .81998 m .55419 .81901 L .55418 .81797 L F
.55851 .80735 m .55958 .80467 L .56088 .80147 L 0 0 0 r
F
.55405 .81844 m .55797 .80867 L .55851 .80735 L F
.55797 .80867 m .55958 .80467 L .55851 .80735 L F
.5496 .82726 m .55408 .81676 L .55552 .81383 L F
.55408 .81676 m .55441 .81596 L .55552 .81383 L F
.5496 .82726 m .55552 .81383 L .55617 .81275 L F
.55552 .81383 m .55667 .81123 L .55634 .81222 L F
.55552 .81383 m .55634 .81222 L .55617 .81275 L F
.5509 .82282 m .55109 .82253 L .55115 .82241 L 0 .894 .136 r
F
.55887 .80657 m .56088 .80147 L .56106 .80119 L 0 0 0 r
F
.55405 .81844 m .55837 .8077 L .55887 .80657 L F
.55837 .8077 m .56088 .80147 L .55887 .80657 L F
.56088 .80147 m .56116 .80077 L .56114 .80086 L F
.56088 .80147 m .56114 .80086 L .56106 .80119 L F
.55958 .80467 m .55963 .80453 L .56088 .80147 L F
.55667 .81123 m .55668 .81124 L .5567 .81119 L 0 .922 .142 r
F
.55932 .80527 m .55926 .80538 L .55936 .80514 L 0 0 0 r
F
.55963 .80453 m .55936 .80514 L .5599 .80386 L F
.55667 .81123 m .55671 .81116 L .55672 .81113 L 0 .922 .142 r
F
.55671 .81116 m .5574 .81004 L .55672 .81113 L F
.56098 .80122 m .55972 .80431 L .56116 .80077 L 0 0 0 r
F
.55963 .80453 m .55972 .80431 L .56098 .80122 L F
.55972 .80431 m .5599 .80386 L .56116 .80077 L F
.55667 .81123 m .55672 .81115 L .55674 .81111 L 0 .922 .142 r
F
.56116 .80077 m .56196 .79878 L .56163 .79967 L 0 0 0 r
F
.56116 .80077 m .56163 .79967 L .56106 .80119 L F
.55805 .80957 m .56106 .80119 L .5622 .79812 L F
.56377 .79366 m .56467 .79146 L .56553 .78875 L F
.56304 .79593 m .5622 .79812 L .56469 .79141 L F
.56304 .79593 m .56469 .79141 L .56466 .79149 L F
.56304 .79591 m .56466 .79149 L .56467 .79146 L F
.56304 .79593 m .56466 .79149 L .56304 .79591 L F
.56325 .79534 m .56467 .79146 L .56377 .79366 L F
.56196 .79878 m .56348 .79913 L .56369 .79869 L 0 1 .145 r
F
.56196 .79878 m .56369 .79869 L .5649 .79448 L F
.56196 .79878 m .56374 .7952 L .56386 .79476 L F
.56563 .79139 m .56538 .79253 L .56583 .79098 L F
.56196 .79878 m .56538 .79253 L .56563 .79139 L F
.56538 .79253 m .56538 .79253 L .56563 .79139 L F
.56196 .79878 m .56056 .80401 L .56348 .79913 L F
.56158 .80093 m .56189 .79922 L .56544 .789 L 0 0 0 r
F
.56545 .7924 m .56745 .79073 L .56984 .78439 L 0 1 .145 r
F
.57256 .77929 m .57623 .7927 L .58016 .78578 L 0 1 .407 r
F
.57072 .79247 m .57772 .78853 L .57804 .7846 L 0 1 .28 r
F
.57072 .79247 m .57438 .7955 L .57772 .78853 L F
.57072 .79247 m .57804 .7846 L .57513 .78632 L F
.56984 .78439 m .57077 .78997 L .57498 .78217 L 0 1 .218 r
F
.56984 .78439 m .56745 .79073 L .56786 .79312 L F
.56777 .78279 m .57455 .79446 L .57085 .78649 L 0 .675 .379 r
F
.56668 .78147 m .56769 .78313 L .56777 .78279 L F
.56766 .78346 m .56817 .78239 L .56774 .78306 L 0 1 .146 r
F
.56769 .78313 m .57455 .79446 L .56777 .78279 L 0 .675 .379 r
F
.56122 .75553 m .56892 .77817 L .56973 .77493 L 0 .684 .355 r
F
.56438 .79195 m .56672 .78545 L .56544 .789 L 0 0 0 r
F
.56377 .79366 m .5659 .78772 L .56438 .79195 L F
.5659 .78772 m .56672 .78545 L .56574 .78818 L F
.5653 .78938 m .56668 .78514 L .56703 .78402 L F
.56158 .80093 m .56534 .78927 L .5653 .78938 L F
.56534 .78927 m .56668 .78514 L .5653 .78938 L F
.5659 .78772 m .56574 .78818 L .56549 .78886 L F
.56551 .78881 m .56549 .78886 L .56438 .79195 L F
.5659 .78772 m .56549 .78886 L .56551 .78881 L F
.56949 .77569 m .56976 .77533 L .57012 .77367 L F
.56668 .78147 m .56761 .78348 L .56769 .78313 L 0 .675 .379 r
F
.56122 .75553 m .56532 .77418 L .56877 .77863 L 0 .684 .355 r
F
.56892 .77817 m .56877 .77863 L .56931 .77932 L F
.56122 .75553 m .56877 .77863 L .56892 .77817 L F
.5681 .78072 m .56753 .78251 L .56877 .77863 L 0 0 0 r
F
.56892 .77817 m .56879 .77859 L .56929 .77702 L F
.56892 .77817 m .56931 .77932 L .56963 .77593 L 0 .684 .355 r
F
.56901 .77766 m .56976 .77533 L .56949 .77569 L 0 0 0 r
F
.56917 .77716 m .56917 .7774 L .5693 .77676 L F
.56917 .77717 m .56917 .7774 L .56917 .77716 L F
.56894 .77809 m .56917 .7774 L .56917 .77717 L F
.56917 .7774 m .56929 .77702 L .5693 .77676 L F
.56892 .77817 m .56963 .77593 L .56973 .77493 L 0 .684 .355 r
F
.56892 .77817 m .56877 .77863 L .56879 .77859 L 0 0 0 r
F
.5681 .78072 m .56877 .77863 L .56892 .77817 L F
.55805 .80957 m .5622 .79812 L .56304 .79593 L F
.55805 .80957 m .56304 .79593 L .56304 .79591 L F
.55805 .80957 m .56325 .79534 L .56377 .79366 L F
.55805 .80957 m .56377 .79366 L .56438 .79195 L F
.55805 .80957 m .56544 .789 L .56189 .79922 L F
.56268 .7974 m .56901 .77766 L .56949 .77569 L F
.56206 .79939 m .56259 .79773 L .56268 .7974 L F
.56259 .79773 m .56901 .77766 L .56268 .7974 L F
.56196 .79973 m .56901 .77766 L .56206 .79939 L F
.56525 .78956 m .56778 .7817 L .56516 .7898 L F
.56778 .7817 m .56778 .7817 L .56274 .7973 L F
.56668 .78514 m .56634 .78621 L .56753 .78251 L F
.56973 .77493 m .57007 .77374 L .56919 .7697 L 0 .684 .355 r
F
.56686 .78441 m .56894 .77809 L .56917 .77717 L 0 0 0 r
F
.56668 .78514 m .56753 .78251 L .56703 .78402 L F
.56629 .78665 m .5649 .79083 L .56672 .78545 L F
.5681 .78072 m .5681 .7807 L .56274 .7973 L F
.56734 .78242 m .56908 .77698 L .56925 .77629 L F
.56698 .78368 m .56908 .77698 L .56734 .78242 L F
.5668 .78473 m .56917 .7774 L .56686 .78441 L F
.57115 .76902 m .57162 .76693 L .57145 .76608 L 0 .626 .341 r
F
.56423 .74898 m .56919 .7697 L .56968 .77035 L F
.57012 .77367 m .56976 .77533 L .57088 .77123 L 0 0 0 r
F
.56973 .77493 m .57088 .77123 L .57007 .77374 L F
.57082 .77047 m .57023 .77272 L .57056 .7715 L F
.57115 .76902 m .57119 .76914 L .57162 .76693 L 0 .626 .341 r
F
.57119 .76914 m .57063 .77124 L .57308 .7623 L 0 0 0 r
F
.57088 .77123 m .57075 .77555 L .57429 .76782 L 0 1 .144 r
F
.57119 .76914 m .57321 .77498 L .57169 .76727 L 0 .626 .341 r
F
.57119 .76914 m .57169 .76727 L .57162 .76693 L F
.57119 .76914 m .57056 .7715 L .57063 .77124 L 0 0 0 r
F
.5707 .76774 m .57056 .7715 L .57119 .76914 L 0 .626 .341 r
F
.57082 .77047 m .57056 .7715 L .57119 .76914 L 0 0 0 r
F
.5707 .76774 m .56968 .77035 L .57056 .7715 L 0 .626 .341 r
F
.57088 .77123 m .5709 .77118 L .57091 .77117 L 0 1 .144 r
F
.57119 .76914 m .57056 .7715 L .57321 .77498 L 0 .626 .341 r
F
.56423 .74898 m .56968 .77035 L .5707 .76774 L F
.56188 .79999 m .56634 .78621 L .56668 .78514 L 0 0 0 r
F
.56274 .7973 m .5668 .78473 L .56686 .78441 L F
.57225 .76404 m .57442 .7562 L .57231 .76376 L F
.5715 .7658 m .57172 .76631 L .57231 .76378 L 0 .626 .341 r
F
.57167 .76646 m .57172 .76631 L .57225 .76404 L 0 0 0 r
F
.57172 .76631 m .57442 .7562 L .57225 .76404 L F
.57172 .76631 m .57304 .76936 L .57231 .76378 L 0 .626 .341 r
F
.57311 .772 m .57321 .77435 L .57534 .76732 L 0 1 .146 r
F
.57534 .76732 m .57321 .77435 L .57406 .77658 L 0 1 .231 r
F
.57304 .76936 m .57459 .77295 L .57323 .76748 L 0 .626 .341 r
F
.57272 .76668 m .57798 .75365 L .57284 .76586 L 0 1 .144 r
F
.57304 .76936 m .57323 .76748 L .57231 .76378 L 0 .626 .341 r
F
.57514 .74851 m .57516 .74874 L .57523 .74802 L 0 0 .024 r
F
.57231 .76378 m .57323 .76748 L .57245 .76405 L 0 .626 .341 r
F
.57323 .76748 m .57459 .77295 L .57324 .76733 L F
.57323 .76748 m .57324 .76733 L .57245 .76405 L F
.56973 .77493 m .56931 .77932 L .57095 .77771 L 0 .684 .355 r
F
.56666 .74069 m .57239 .76349 L .5732 .75989 L 0 .568 .326 r
F
.56423 .74898 m .57231 .76378 L .56824 .75423 L 0 .626 .341 r
F
.57231 .76378 m .57245 .76405 L .57232 .76374 L F
.57231 .76378 m .57232 .76374 L .56824 .75423 L F
.57241 .76338 m .57242 .76338 L .57232 .76374 L 0 0 0 r
F
.57079 .76953 m .57198 .76515 L .57227 .76394 L F
.57232 .76375 m .57232 .76374 L .57123 .76801 L F
.57241 .76338 m .57232 .76374 L .57232 .76375 L F
.56666 .74069 m .56824 .75423 L .57232 .76374 L 0 .568 .326 r
F
.57235 .76365 m .57232 .76374 L .57245 .76405 L F
.57232 .76374 m .57232 .76374 L .57233 .76373 L 0 0 0 r
F
.57231 .76378 m .57241 .76338 L .57232 .76375 L F
.56666 .74069 m .57232 .76374 L .57235 .76365 L 0 .568 .326 r
F
.57232 .76374 m .57232 .76375 L .57232 .76374 L 0 0 0 r
F
.57232 .76374 m .57232 .76374 L .57232 .76374 L F
.57228 .76386 m .57273 .76196 L .5732 .75989 L F
.57273 .76196 m .573 .76087 L .5732 .75989 L F
.57229 .76387 m .57228 .7639 L .57232 .76375 L F
.57229 .76387 m .57232 .76375 L .57232 .76374 L F
.57227 .76394 m .57198 .76515 L .57231 .76376 L F
.57231 .76379 m .57231 .76378 L .57231 .76378 L 0 .626 .341 r
F
.57172 .76631 m .57231 .76378 L .57231 .76379 L F
.57232 .76374 m .57233 .76373 L .57235 .76367 L 0 0 0 r
F
.57235 .76361 m .57235 .76365 L .57238 .76346 L 0 .568 .326 r
F
.57183 .76585 m .573 .76087 L .57228 .76386 L 0 0 0 r
F
.56973 .77493 m .57095 .77771 L .57007 .77374 L 0 .684 .355 r
F
.57161 .76688 m .57196 .76865 L .57172 .76631 L 0 .626 .341 r
F
.57172 .76631 m .57196 .76865 L .57214 .76729 L F
.5724 .76352 m .57257 .7642 L .57285 .76228 L 0 .568 .326 r
F
.5724 .76352 m .57285 .76228 L .5732 .75989 L F
.57239 .76349 m .57245 .76405 L .57257 .7642 L F
.57235 .76365 m .57245 .76405 L .57239 .76349 L F
.5732 .75989 m .57257 .7642 L .57321 .76506 L F
.5732 .75989 m .57321 .76506 L .57371 .76139 L F
.57356 .75724 m .57409 .75852 L .57399 .75496 L F
.57409 .75852 m .57432 .75683 L .57399 .75496 L F
.57972 .72259 m .57961 .7226 L .58006 .71916 L 0 0 .101 r
F
.57374 .76337 m .57798 .75365 L .578 .75165 L 0 1 .144 r
F
.57367 .76387 m .57798 .75365 L .57374 .76337 L F
.59091 .7618 m .57711 .77304 L .57833 .77617 L 0 1 .479 r
F
.59091 .7618 m .5825 .76687 L .57711 .77304 L F
.58628 .75315 m .5825 .76687 L .59091 .7618 L 0 1 .474 r
F
.58349 .75461 m .58199 .77282 L .58814 .76803 L 0 1 .4 r
F
.58349 .75461 m .57618 .77241 L .58199 .77282 L F
.58349 .75461 m .58814 .76803 L .59127 .7604 L F
.57534 .76732 m .58394 .75517 L .58311 .75293 L 0 1 .231 r
F
.57534 .76732 m .58153 .76335 L .58394 .75517 L F
.57534 .76732 m .5773 .77252 L .58153 .76335 L F
.57534 .76732 m .58311 .75293 L .57958 .75813 L F
.57476 .76011 m .57646 .76946 L .57756 .76685 L 0 .568 .326 r
F
.57463 .76103 m .57646 .76946 L .57476 .76011 L F
.57442 .7562 m .57308 .7623 L .57492 .75951 L 0 1 .14 r
F
.57401 .75914 m .57541 .76504 L .57409 .75852 L 0 .568 .326 r
F
.57541 .76504 m .57646 .76946 L .57543 .76473 L F
.57541 .76504 m .57543 .76473 L .57409 .75852 L F
.57854 .72807 m .57816 .72915 L .57861 .72767 L 0 0 .081 r
F
.57832 .72939 m .57816 .72915 L .57857 .72797 L F
.57409 .75852 m .57463 .76103 L .57476 .76011 L 0 .568 .326 r
F
.57356 .75724 m .57401 .75914 L .57409 .75852 L F
.57284 .76586 m .57367 .76387 L .57374 .76337 L 0 1 .144 r
F
.57534 .76732 m .57406 .77658 L .5773 .77252 L 0 1 .231 r
F
.57371 .76139 m .57321 .76506 L .57646 .76946 L 0 .568 .326 r
F
.56917 .80541 m .57523 .80478 L .57632 .80015 L 0 1 .321 r
F
.57623 .7927 m .5799 .80624 L .58412 .7991 L 0 1 .402 r
F
.57623 .7927 m .58412 .7991 L .58254 .79378 L F
.57772 .78853 m .57378 .80048 L .57632 .80015 L 0 1 .33 r
F
.57772 .78853 m .57438 .7955 L .57378 .80048 L F
.56769 .78313 m .57568 .801 L .57455 .79446 L 0 .675 .379 r
F
.57409 .75852 m .575 .76071 L .57432 .75683 L 0 .568 .326 r
F
.5732 .75989 m .573 .76087 L .57368 .75784 L 0 0 0 r
F
.5732 .75989 m .57371 .76139 L .57356 .75724 L 0 .568 .326 r
F
.57371 .76139 m .57646 .76946 L .57401 .75914 L F
.57371 .76139 m .57401 .75914 L .57356 .75724 L F
.57673 .73927 m .57706 .7368 L .57672 .73537 L 0 .462 .294 r
F
.57666 .73944 m .57681 .73846 L .57689 .73785 L 0 0 .054 r
F
.57442 .7562 m .57492 .75951 L .5787 .74972 L 0 1 .14 r
F
.575 .76071 m .57516 .75877 L .5744 .75622 L 0 .568 .326 r
F
.57429 .75401 m .57412 .7545 L .57447 .75536 L 0 .512 .31 r
F
.5743 .75405 m .57412 .7545 L .57434 .75384 L 0 0 .024 r
F
.57432 .75683 m .5744 .75622 L .574 .75485 L 0 .568 .326 r
F
.57432 .75683 m .574 .75485 L .57398 .7549 L F
.57393 .75463 m .57412 .75499 L .574 .75421 L F
.57412 .75499 m .57507 .75682 L .57418 .75466 L F
.57412 .75499 m .57418 .75466 L .574 .75421 L F
.57402 .75552 m .57433 .75389 L .57426 .75433 L 0 0 .024 r
F
.57433 .75389 m .57501 .75034 L .57456 .75274 L F
.57433 .75389 m .57456 .75274 L .57426 .75433 L F
.56423 .74898 m .5715 .7658 L .57231 .76378 L 0 .626 .341 r
F
.57067 .77008 m .57198 .76515 L .57079 .76953 L 0 0 0 r
F
.57079 .76953 m .57231 .76378 L .57123 .76801 L F
.57231 .76378 m .57232 .76375 L .57123 .76801 L F
.56583 .79098 m .56618 .7898 L .56594 .78926 L 0 .744 .39 r
F
.56672 .78545 m .56488 .79089 L .56595 .79035 L 0 1 .146 r
F
.56158 .80093 m .56196 .79973 L .56206 .79939 L 0 0 0 r
F
.56432 .79212 m .56698 .78368 L .56734 .78242 L F
.56158 .80093 m .56447 .7917 L .56432 .79212 L F
.56447 .7917 m .56698 .78368 L .56432 .79212 L F
.56158 .80093 m .56264 .79765 L .56274 .7973 L F
.56158 .80093 m .56925 .77629 L .56545 .78888 L F
.56459 .79293 m .56545 .78888 L .56925 .77629 L F
.56459 .79293 m .56967 .77461 L .57058 .77054 L F
.56967 .77461 m .57119 .76914 L .57058 .77054 L F
.57058 .77054 m .57119 .76914 L .57172 .76631 L F
.56459 .79293 m .57056 .77063 L .57067 .77008 L F
.57079 .76953 m .57123 .76801 L .56846 .77885 L F
.56771 .78313 m .56766 .78346 L .56774 .78306 L 0 1 .146 r
F
.56764 .78351 m .56766 .78346 L .56771 .78313 L F
.56761 .78348 m .57568 .801 L .56769 .78313 L 0 .675 .379 r
F
.56917 .77717 m .56917 .77717 L .56917 .77716 L 0 0 0 r
F
.5681 .78072 m .56929 .77702 L .5681 .7807 L F
.56754 .78404 m .57348 .80173 L .56764 .78355 L 0 .675 .379 r
F
.56732 .78515 m .56733 .78514 L .56754 .78404 L 0 1 .146 r
F
.56756 .78408 m .56931 .7967 L .57348 .80173 L 0 .675 .379 r
F
.56755 .78411 m .56931 .7967 L .56756 .78408 L F
.57067 .77008 m .57167 .76646 L .57198 .76515 L 0 0 0 r
F
.57056 .77063 m .57167 .76646 L .57067 .77008 L F
.56754 .78404 m .56755 .78411 L .56756 .78408 L 0 .675 .379 r
F
.56934 .77591 m .56925 .77629 L .57023 .77272 L 0 0 0 r
F
.57025 .7723 m .56846 .77885 L .57123 .76801 L F
.56484 .79205 m .56925 .77629 L .56934 .77591 L F
.5648 .7922 m .56925 .77629 L .56484 .79205 L F
.56908 .77698 m .56953 .77555 L .56925 .77629 L F
.56495 .79163 m .57023 .77272 L .57078 .77064 L F
.56495 .79163 m .57078 .77064 L .57078 .77063 L F
.56484 .79205 m .57023 .77272 L .56495 .79163 L F
.56953 .77555 m .5699 .77428 L .56925 .77629 L F
.56754 .78405 m .56931 .7967 L .56754 .78404 L 0 .675 .379 r
F
.56732 .78515 m .56931 .7967 L .56754 .78402 L F
.56732 .78515 m .56631 .79008 L .56931 .7967 L F
.56711 .78604 m .57123 .76801 L .57171 .76637 L 0 0 0 r
F
.5708 .77021 m .57183 .76585 L .57228 .76386 L F
.56711 .78604 m .57228 .7639 L .57229 .76387 L F
.56706 .78627 m .57079 .7703 L .5708 .77021 L F
.57074 .7705 m .57232 .76374 L .57079 .77032 L F
.57079 .7703 m .57183 .76585 L .5708 .77021 L F
.57078 .77063 m .57078 .77064 L .57082 .77047 L F
.56459 .79293 m .56484 .79205 L .56495 .79163 L F
.57079 .77032 m .57232 .76374 L .57235 .76367 L F
.56706 .78627 m .57074 .7705 L .57079 .77032 L F
.56754 .78402 m .56754 .78405 L .56754 .78404 L 0 .675 .379 r
F
.56711 .78604 m .56846 .77885 L .57025 .7723 L 0 0 0 r
F
.56459 .79293 m .5648 .7922 L .56484 .79205 L F
.57171 .76637 m .57123 .76801 L .57228 .7639 L F
.56666 .74069 m .57235 .76361 L .57238 .76346 L 0 .568 .326 r
F
.56706 .78627 m .57305 .76051 L .5734 .75798 L 0 0 0 r
F
.56833 .7817 m .56977 .77903 L .56997 .77787 L 0 1 .146 r
F
.56817 .78239 m .56977 .77903 L .56833 .7817 L F
.57256 .77929 m .58016 .78578 L .57857 .78043 L 0 1 .407 r
F
.56984 .78439 m .57769 .77492 L .5773 .77252 L 0 1 .218 r
F
.56984 .78439 m .57498 .78217 L .57769 .77492 L F
.56984 .78439 m .5773 .77252 L .57406 .77658 L F
.57095 .77771 m .56931 .77932 L .57085 .78649 L 0 .599 .366 r
F
.56898 .78205 m .57411 .75456 L .5743 .75405 L 0 0 .024 r
F
.57411 .75456 m .57412 .7545 L .5743 .75405 L F
.57398 .7549 m .574 .75485 L .57393 .75463 L 0 .568 .326 r
F
.575 .76071 m .5744 .75622 L .57432 .75683 L F
.57694 .73751 m .5771 .73642 L .57716 .73605 L 0 0 .054 r
F
.57417 .75314 m .57447 .75536 L .57455 .7547 L 0 .512 .31 r
F
.57561 .74597 m .57549 .74694 L .57593 .74421 L 0 0 .024 r
F
.57563 .74507 m .57551 .74788 L .57574 .74479 L 0 .512 .31 r
F
.57608 .74395 m .57589 .74436 L .57611 .74371 L 0 0 .054 r
F
.57516 .74874 m .57549 .74694 L .57523 .74802 L 0 0 .024 r
F
.57516 .74874 m .57508 .74948 L .57549 .74694 L F
.57534 .74744 m .57506 .75018 L .57551 .74788 L 0 .512 .31 r
F
.57523 .74802 m .57549 .74694 L .57561 .74597 L 0 0 .024 r
F
.57534 .74744 m .57551 .74649 L .57567 .7453 L F
.57534 .74744 m .57551 .74788 L .5756 .74578 L 0 .512 .31 r
F
.57534 .74744 m .5756 .74578 L .57565 .7446 L F
.57534 .74744 m .57567 .7453 L .57571 .74504 L 0 0 .024 r
F
.57506 .75018 m .57518 .75056 L .57551 .74788 L 0 .512 .31 r
F
.57518 .75056 m .57901 .7623 L .57553 .74796 L F
.57518 .75056 m .57553 .74796 L .57551 .74788 L F
.57698 .73723 m .57728 .73522 L .57729 .73517 L 0 0 .054 r
F
.57506 .75018 m .57507 .75682 L .57901 .7623 L 0 .512 .31 r
F
.57498 .7506 m .575 .75189 L .57506 .75018 L F
.575 .75189 m .57507 .75682 L .57506 .75142 L F
.575 .75189 m .57506 .75142 L .57506 .75018 L F
.57272 .76864 m .57321 .77498 L .57459 .77295 L 0 .626 .341 r
F
.57214 .76729 m .57253 .77009 L .57272 .76864 L F
.57292 .77483 m .57321 .77435 L .57311 .772 L 0 1 .146 r
F
.57253 .77009 m .57321 .77498 L .57272 .76864 L 0 .626 .341 r
F
.57669 .73909 m .57731 .73498 L .57741 .73419 L 0 0 .054 r
F
.57628 .74275 m .57691 .73841 L .57756 .73435 L F
.57541 .74854 m .57619 .74327 L .57628 .74275 L F
.57619 .74327 m .57691 .73841 L .57628 .74275 L F
.57731 .73498 m .57734 .73482 L .57735 .73473 L F
.57674 .7402 m .57729 .73618 L .57684 .73964 L F
.57729 .73618 m .57756 .73435 L .57817 .73096 L F
.57684 .73964 m .57818 .73089 L .57718 .73596 L F
.57736 .73463 m .57734 .73482 L .57757 .73309 L F
.57731 .73498 m .5773 .73506 L .57734 .73482 L F
.57711 .73643 m .57767 .73268 L .57729 .73518 L F
.57711 .73643 m .57732 .73699 L .57756 .73319 L 0 .462 .294 r
F
.57732 .73699 m .58135 .7479 L .57782 .73422 L F
.57732 .73699 m .57782 .73422 L .57756 .73319 L F
.57531 .74901 m .57691 .73841 L .57541 .74854 L 0 0 .054 r
F
.57594 .73669 m .57611 .74357 L .57684 .73964 L 0 .462 .294 r
F
.57635 .74228 m .57756 .73435 L .57657 .74112 L 0 0 .054 r
F
.57673 .73927 m .57684 .73964 L .57706 .7368 L 0 .462 .294 r
F
.57679 .7386 m .57684 .73964 L .57718 .73596 L 0 0 .054 r
F
.57502 .73894 m .57611 .74357 L .57594 .73669 L 0 .462 .294 r
F
.57196 .76865 m .57321 .77498 L .57214 .76729 L 0 .626 .341 r
F
.57095 .77771 m .57085 .78649 L .57455 .79446 L 0 .599 .366 r
F
.57627 .74209 m .57656 .74145 L .57679 .7386 L 0 0 .054 r
F
.57095 .77771 m .57343 .78196 L .57351 .78094 L 0 .599 .366 r
F
.5847 .78724 m .58012 .80017 L .58266 .80053 L 0 1 .363 r
F
.5847 .78724 m .581 .79448 L .58012 .80017 L F
.57772 .78853 m .57632 .80015 L .581 .79448 L 0 1 .33 r
F
.57769 .77492 m .57513 .78632 L .57804 .7846 L 0 1 .29 r
F
.57769 .77492 m .57498 .78217 L .57513 .78632 L F
.57343 .78196 m .58069 .79889 L .57914 .7917 L 0 .599 .366 r
F
.57095 .77771 m .57337 .78299 L .57343 .78196 L F
.57337 .78299 m .58069 .79889 L .57343 .78196 L F
.57138 .77866 m .57877 .79978 L .58069 .79889 L F
.57095 .77771 m .57135 .77886 L .57138 .77866 L F
.57135 .77886 m .57877 .79978 L .57138 .77866 L F
.57549 .7472 m .57652 .74029 L .57669 .73909 L 0 0 .054 r
F
.57095 .77771 m .57455 .79446 L .57877 .79978 L 0 .599 .366 r
F
.57033 .78205 m .57538 .74798 L .57549 .7472 L 0 0 .054 r
F
.57538 .74798 m .57652 .74029 L .57549 .7472 L F
.57033 .78205 m .57595 .74427 L .57608 .74395 L F
.57622 .74314 m .57627 .74287 L .5757 .74707 L F
.57611 .74357 m .57613 .74363 L .57616 .74342 L 0 .462 .294 r
F
.57553 .74705 m .57611 .7444 L .57627 .74209 L 0 0 .054 r
F
.57551 .74788 m .57983 .75885 L .57601 .74534 L 0 .512 .31 r
F
.57551 .74788 m .57901 .7623 L .57983 .75885 L F
.57033 .78205 m .57541 .74854 L .5757 .74707 L 0 0 .054 r
F
.57033 .78205 m .57531 .74901 L .57541 .74854 L F
.57033 .78205 m .57543 .74884 L .57553 .74705 L F
.57541 .74854 m .57622 .74314 L .5757 .74707 L F
.57543 .74884 m .57611 .7444 L .57553 .74705 L F
.57033 .78205 m .57593 .74432 L .57595 .74427 L F
.57635 .74228 m .57649 .74155 L .57633 .74244 L F
.57649 .74155 m .57657 .74112 L .57633 .74244 L F
.57622 .74314 m .57635 .74228 L .57627 .74287 L F
.57611 .74357 m .57616 .74342 L .57684 .73964 L 0 .462 .294 r
F
.5757 .74707 m .57634 .74271 L .57659 .74125 L 0 0 .054 r
F
.57611 .7444 m .57656 .74145 L .57627 .74209 L F
.57351 .78094 m .57914 .7917 L .57516 .78301 L 0 .599 .366 r
F
.57343 .78196 m .57914 .7917 L .57351 .78094 L F
.57659 .74125 m .57673 .74026 L .57684 .73964 L 0 0 .054 r
F
.57656 .74145 m .57684 .73964 L .57679 .7386 L F
.57706 .7368 m .57723 .7375 L .57711 .73643 L 0 .462 .294 r
F
.57723 .7375 m .57729 .73719 L .57711 .73643 L F
.57637 .74466 m .577 .74736 L .57684 .73964 L F
.57711 .73643 m .57729 .73719 L .57732 .73699 L F
.57684 .73964 m .58083 .75268 L .57723 .7375 L F
.57684 .73964 m .57723 .7375 L .57706 .7368 L F
.57756 .73319 m .57762 .73333 L .57762 .73296 L F
.57762 .73333 m .57788 .73389 L .57766 .73311 L F
.57762 .73333 m .57766 .73311 L .57762 .73296 L F
.57776 .73253 m .57821 .7346 L .57861 .72767 L 0 .421 .28 r
F
.57763 .73348 m .58135 .7479 L .57765 .73338 L 0 .462 .294 r
F
.57439 .75615 m .575 .75822 L .57439 .75607 L 0 .568 .326 r
F
.575 .75822 m .57501 .75816 L .57439 .75607 L F
.57444 .75561 m .57756 .76685 L .57507 .75682 L F
.57439 .75607 m .57756 .76685 L .57444 .75561 L F
.57455 .7547 m .57447 .75536 L .57507 .75682 L 0 .512 .31 r
F
.57601 .74534 m .57645 .74689 L .57651 .74637 L F
.57459 .75485 m .57507 .75682 L .575 .75189 L F
.57114 .78905 m .5739 .75951 L .57762 .73296 L 0 0 .081 r
F
.57765 .73288 m .57762 .73296 L .57771 .7323 L F
.57765 .73288 m .57771 .7323 L .57776 .73253 L F
.57757 .73309 m .57816 .72915 L .57763 .73287 L 0 0 .054 r
F
.57775 .73247 m .57763 .73293 L .57776 .73253 L 0 .421 .28 r
F
.56911 .71267 m .57616 .71872 L .57409 .71299 L 0 1 .387 r
F
.57029 .69856 m .57763 .73292 L .57775 .73247 L 0 .421 .28 r
F
.57763 .73292 m .57763 .73293 L .57775 .73247 L F
.57763 .73293 m .57767 .73309 L .57776 .73253 L F
.57776 .73253 m .57771 .7323 L .57782 .73205 L 0 0 .081 r
F
.57763 .73293 m .57762 .73296 L .57767 .73309 L 0 .421 .28 r
F
.57776 .73253 m .57767 .73309 L .57821 .7346 L F
.57765 .73338 m .57797 .73465 L .57803 .7342 L 0 .462 .294 r
F
.57756 .73319 m .57763 .73348 L .57765 .73338 L F
.57114 .78905 m .57765 .73288 L .57776 .73253 L 0 0 .081 r
F
.57114 .78905 m .57762 .73296 L .57765 .73288 L F
.57029 .69856 m .57353 .72167 L .57762 .73296 L 0 .421 .28 r
F
.57029 .69856 m .57762 .73296 L .57763 .73293 L F
.57775 .7326 m .57776 .73253 L .57831 .72937 L 0 0 .081 r
F
.57776 .73253 m .57816 .72915 L .57829 .72934 L F
.57776 .73253 m .57829 .72934 L .57831 .72937 L F
.57749 .73482 m .57775 .7326 L .57839 .72948 L F
.57775 .7326 m .57831 .72937 L .57839 .72948 L F
.57782 .73205 m .57771 .7323 L .57816 .72915 L F
.56972 .71641 m .57502 .73894 L .57594 .73669 L 0 .462 .294 r
F
.57652 .74029 m .57731 .73498 L .57669 .73909 L 0 0 .054 r
F
.57033 .78205 m .57587 .74445 L .5759 .74438 L F
.57731 .73498 m .57735 .73473 L .57741 .73419 L F
.57573 .74494 m .57551 .74788 L .57575 .74481 L 0 .512 .31 r
F
.57033 .78205 m .57697 .73727 L .57698 .73723 L 0 0 .054 r
F
.57697 .73727 m .57728 .73522 L .57698 .73723 L F
.57587 .74445 m .57589 .74436 L .57608 .74395 L F
.57033 .78205 m .57689 .73785 L .57694 .73751 L F
.57689 .73785 m .5771 .73642 L .57694 .73751 L F
.57589 .74436 m .57589 .74435 L .57611 .74371 L F
.57033 .78205 m .57658 .73998 L .57666 .73944 L F
.57658 .73998 m .57681 .73846 L .57666 .73944 L F
.57842 .72701 m .57775 .73247 L .57861 .72767 L 0 .421 .28 r
F
.57869 .72251 m .57861 .72767 L .57899 .72339 L F
.578 .72554 m .57861 .72767 L .57869 .72251 L F
.56781 .78393 m .57348 .80173 L .57568 .801 L 0 .675 .379 r
F
.56779 .78403 m .57348 .80173 L .56781 .78393 L F
.575 .76071 m .57756 .76685 L .57516 .75877 L 0 .568 .326 r
F
.57723 .7375 m .58083 .75268 L .57729 .73719 L 0 .462 .294 r
F
.57732 .73699 m .58083 .75268 L .58135 .7479 L F
.57729 .73719 m .58083 .75268 L .57732 .73699 L F
.57788 .73389 m .57821 .7346 L .57791 .73375 L F
.57854 .72806 m .57854 .72807 L .57861 .72767 L 0 0 .081 r
F
.57775 .73247 m .57781 .73227 L .57861 .72767 L 0 .421 .28 r
F
.57857 .72797 m .57854 .72806 L .57861 .72767 L 0 0 .081 r
F
.57839 .72948 m .57832 .72939 L .57857 .72797 L F
.57829 .73028 m .58149 .704 L .57883 .72474 L F
.57947 .72499 m .57868 .73121 L .58118 .72359 L 0 1 .122 r
F
.57861 .72767 m .58188 .73912 L .57899 .72339 L 0 .421 .28 r
F
.57856 .72804 m .57876 .72585 L .57952 .71934 L 0 0 .101 r
F
.57899 .72339 m .57926 .72414 L .57931 .72106 L 0 .421 .28 r
F
.57899 .72339 m .5793 .7208 L .57915 .72222 L 0 0 .081 r
F
.5793 .7208 m .57931 .72071 L .57931 .72076 L F
.57899 .72339 m .57931 .72106 L .57932 .72054 L 0 .421 .28 r
F
.57898 .72355 m .57898 .72354 L .57899 .72339 L 0 0 .081 r
F
.57891 .72407 m .57898 .72355 L .57899 .72339 L F
.57883 .72474 m .57889 .72425 L .57891 .72407 L F
.57881 .72495 m .57899 .72339 L .57904 .72324 L F
.57899 .72339 m .57915 .72222 L .57904 .72324 L F
.57856 .72804 m .57952 .71934 L .57965 .71827 L 0 0 .101 r
F
.575 .75822 m .57756 .76685 L .57501 .75816 L 0 .568 .326 r
F
.57861 .72767 m .57821 .7346 L .58188 .73912 L 0 .421 .28 r
F
.57899 .72339 m .57919 .72448 L .57926 .72414 L F
.57651 .74637 m .57983 .75885 L .577 .74736 L 0 .512 .31 r
F
.57645 .74689 m .57983 .75885 L .57651 .74637 L F
.57803 .7342 m .58135 .7479 L .57821 .7346 L 0 .462 .294 r
F
.57797 .73465 m .58135 .7479 L .57803 .7342 L F
.57931 .72071 m .57935 .72043 L .57931 .72076 L 0 0 .081 r
F
.57926 .72414 m .57973 .72151 L .57933 .71972 L 0 .421 .28 r
F
.56917 .80541 m .57124 .81128 L .57523 .80478 L 0 1 .321 r
F
.58064 .81174 m .57259 .82722 L .58337 .8223 L 0 1 .443 r
F
.5799 .80624 m .57595 .82476 L .58357 .81984 L 0 1 .395 r
F
.5799 .80624 m .56935 .82399 L .57595 .82476 L F
.5799 .80624 m .56816 .81806 L .56935 .82399 L F
.5799 .80624 m .57268 .81045 L .56816 .81806 L F
.5799 .80624 m .58357 .81984 L .58809 .81224 L F
.5799 .80624 m .58809 .81224 L .5865 .80701 L F
.58127 .80576 m .57719 .81882 L .5823 .81446 L 0 1 .389 r
F
.57011 .82187 m .57494 .82399 L .57719 .81882 L 0 1 .382 r
F
.57011 .82187 m .57719 .81882 L .57514 .81798 L F
.58127 .80576 m .57514 .81798 L .57719 .81882 L 0 1 .389 r
F
.58127 .80576 m .57689 .81238 L .57514 .81798 L F
.57523 .80478 m .57199 .817 L .57689 .81238 L 0 1 .361 r
F
.57523 .80478 m .56985 .81652 L .57199 .817 L F
.57523 .80478 m .57124 .81128 L .56985 .81652 L F
.57 .80271 m .57536 .81959 L .57815 .81935 L 0 .709 .403 r
F
.57 .80271 m .57773 .8141 L .57436 .80735 L F
.57 .80271 m .57815 .81935 L .57773 .8141 L F
.57459 .77295 m .57321 .77498 L .57516 .78301 L 0 .516 .349 r
F
.57142 .80708 m .57856 .72804 L .57965 .71827 L 0 0 .101 r
F
.57019 .6753 m .57866 .7167 L .57975 .71744 L 0 .396 .268 r
F
.57985 .71689 m .57975 .71744 L .58002 .71762 L F
.58052 .71322 m .57975 .71744 L .58189 .6991 L 0 0 .101 r
F
.57019 .6753 m .57975 .71744 L .57985 .71689 L 0 .396 .268 r
F
.57019 .6753 m .58002 .71762 L .58052 .71322 L F
.58032 .71531 m .57965 .71827 L .57975 .71744 L 0 0 .101 r
F
.58032 .71531 m .57975 .71744 L .58052 .71322 L F
.58052 .71322 m .58002 .71762 L .58212 .71906 L 0 .396 .268 r
F
.57926 .72414 m .58188 .73912 L .58208 .73219 L 0 .421 .28 r
F
.57919 .72448 m .58188 .73912 L .57926 .72414 L F
.57947 .72499 m .57959 .7243 L .5796 .72424 L 0 1 .122 r
F
.57926 .72414 m .58208 .73219 L .57973 .72151 L 0 .421 .28 r
F
.58814 .76803 m .58016 .78578 L .58625 .78614 L 0 1 .402 r
F
.57772 .78853 m .5847 .78724 L .5853 .78227 L 0 1 .33 r
F
.57772 .78853 m .581 .79448 L .5847 .78724 L F
.58814 .76803 m .57857 .78043 L .58016 .78578 L 0 1 .402 r
F
.57772 .78853 m .5853 .78227 L .5824 .78286 L 0 1 .33 r
F
.57459 .77295 m .57516 .78301 L .57914 .7917 L 0 .516 .349 r
F
.58814 .76803 m .58199 .77282 L .57857 .78043 L 0 1 .402 r
F
.57769 .77492 m .57804 .7846 L .5825 .77744 L 0 1 .29 r
F
.57647 .77551 m .58304 .78835 L .5788 .77867 L 0 .516 .349 r
F
.57459 .77295 m .5764 .77624 L .57647 .77551 L F
.5764 .77624 m .58304 .78835 L .57647 .77551 L F
.58303 .69306 m .58256 .69641 L .5848 .65738 L 0 0 .064 r
F
.58192 .70016 m .58297 .68788 L .58192 .70011 L 0 0 .001 r
F
.58188 .70058 m .5826 .69084 L .58266 .68896 L F
.58188 .70058 m .58235 .69352 L .58237 .69337 L F
.58192 .70021 m .58211 .69816 L .58214 .69794 L F
.58188 .70058 m .58192 .70025 L .58192 .70021 L F
.58188 .70058 m .58283 .69068 L .58297 .68788 L F
.58098 .67167 m .58148 .68817 L .58256 .69641 L 0 .238 .224 r
F
.58303 .69306 m .58256 .69641 L .58315 .70091 L F
.58303 .69306 m .58315 .70091 L .58328 .69568 L F
.58303 .69306 m .58371 .70013 L .58341 .6903 L F
.58371 .70013 m .58553 .71911 L .58359 .69271 L F
.58371 .70013 m .58359 .69271 L .58341 .6903 L F
.58052 .71322 m .58083 .71433 L .58108 .70843 L 0 .396 .268 r
F
.58083 .71433 m .58212 .71906 L .5812 .70968 L F
.58083 .71433 m .5812 .70968 L .58108 .70843 L F
.58098 .67167 m .58256 .69641 L .58303 .69306 L 0 .238 .224 r
F
.58296 .69447 m .58251 .6973 L .58256 .69641 L 0 0 .064 r
F
.58296 .69447 m .58256 .69641 L .58303 .69306 L F
.58305 .69292 m .5848 .65738 L .58491 .65562 L F
.58194 .70839 m .58212 .71906 L .58197 .7085 L 0 .396 .268 r
F
.58139 .71163 m .58212 .71906 L .58194 .70839 L F
.58938 .73269 m .5884 .7468 L .59192 .74381 L 0 1 .29 r
F
.58938 .73269 m .58731 .74203 L .5884 .7468 L F
.58419 .72691 m .58435 .73737 L .58812 .73069 L 0 1 .238 r
F
.584 .71455 m .59044 .74399 L .58553 .71911 L 0 .248 .238 r
F
.58303 .69306 m .5848 .65738 L .58305 .69292 L 0 0 .064 r
F
.58311 .69246 m .58315 .69172 L .58341 .6903 L F
.58315 .69172 m .58331 .68868 L .58341 .6903 L F
.58237 .68231 m .58303 .69306 L .58341 .6903 L 0 .238 .224 r
F
.58098 .67167 m .58212 .68363 L .58237 .68231 L F
.58212 .68363 m .58303 .69306 L .58237 .68231 L F
.58321 .6929 m .58341 .6903 L .58345 .68862 L 0 0 .064 r
F
.58197 .7085 m .58292 .71246 L .58293 .71137 L 0 .248 .238 r
F
.58345 .68328 m .58451 .66814 L .58493 .65223 L 0 0 .064 r
F
.5835 .68684 m .58451 .66814 L .58345 .68328 L F
.58318 .68429 m .58335 .68525 L .58332 .68285 L 0 .238 .224 r
F
.58318 .68429 m .58339 .68719 L .58335 .68525 L F
.58098 .67171 m .58308 .68519 L .58318 .68429 L F
.58308 .68519 m .58339 .68719 L .58318 .68429 L F
.58197 .7085 m .58292 .71302 L .58292 .71246 L 0 .248 .238 r
F
.58388 .69387 m .58553 .71911 L .59044 .74399 L 0 .238 .224 r
F
.58341 .6903 m .58379 .69544 L .58388 .69387 L F
.58379 .69544 m .58553 .71911 L .58388 .69387 L F
.58919 .60505 m .58924 .58655 L .58933 .60257 L 0 0 .087 r
F
.58946 .5975 m .59161 .56823 L .58939 .59132 L 0 0 .001 r
F
.58933 .60257 m .59131 .66295 L .59059 .63574 L 0 .091 .152 r
F
.60891 .63887 m .60401 .65126 L .60204 .66321 L 0 1 .348 r
F
.60261 .62967 m .60401 .65126 L .60891 .63887 L 0 1 .336 r
F
.5994 .62314 m .59998 .65144 L .60487 .65004 L 0 1 .335 r
F
.5994 .62314 m .59671 .64458 L .59998 .65144 L F
.5994 .62314 m .59646 .63245 L .59671 .64458 L F
.59614 .64666 m .60019 .63944 L .59777 .63934 L 0 1 .23 r
F
.58982 .675 m .5961 .65346 L .59614 .64666 L F
.5961 .65346 m .60019 .63944 L .59614 .64666 L F
.59503 .49285 m .60544 .51069 L .60334 .49359 L 0 .886 .286 r
F
.59503 .49285 m .60402 .52619 L .60544 .51069 L F
.59503 .49285 m .59992 .53285 L .60402 .52619 L F
.59503 .49285 m .59588 .52619 L .59992 .53285 L F
.59164 .53135 m .59992 .53285 L .59588 .52619 L 0 .96 .296 r
F
.59741 .44617 m .60723 .48501 L .60819 .46631 L 0 .813 .276 r
F
.59741 .44617 m .60334 .49359 L .60723 .48501 L F
.59741 .44617 m .59912 .48625 L .60334 .49359 L F
.59741 .44617 m .59658 .4659 L .59912 .48625 L F
.59503 .49285 m .60334 .49359 L .59912 .48625 L 0 .886 .286 r
F
.59503 .49285 m .59379 .50903 L .59588 .52619 L F
.59164 .53135 m .60156 .54767 L .59992 .53285 L 0 .96 .296 r
F
.59164 .53135 m .59971 .56078 L .60156 .54767 L F
.59164 .53135 m .59545 .56598 L .59971 .56078 L F
.59164 .53135 m .59164 .55976 L .59545 .56598 L F
.59161 .56823 m .60112 .45417 L .59798 .46603 L 0 1 .185 r
F
.59161 .56823 m .60166 .48921 L .60112 .45417 L F
.59662 .57908 m .60504 .58399 L .60119 .57636 L 0 .973 .315 r
F
.59662 .57908 m .60603 .59764 L .60504 .58399 L F
.59161 .56823 m .59907 .53956 L .60166 .48921 L 0 1 .185 r
F
.60261 .62967 m .61062 .62671 L .608 .62288 L 0 1 .336 r
F
.60261 .62967 m .60891 .63887 L .61062 .62671 L F
.5994 .62314 m .60787 .6292 L .60428 .62175 L 0 1 .335 r
F
.5994 .62314 m .60812 .64132 L .60787 .6292 L F
.5994 .62314 m .60487 .65004 L .60812 .64132 L F
.60891 .63887 m .60432 .66671 L .60997 .66044 L 0 1 .348 r
F
.60891 .63887 m .60204 .66321 L .60432 .66671 L F
.5997 .66242 m .60794 .66826 L .60479 .66159 L 0 1 .355 r
F
.60179 .67753 m .61003 .67569 L .60775 .67206 L 0 1 .37 r
F
.60179 .67753 m .60723 .68622 L .61003 .67569 L F
.5997 .66242 m .60731 .67881 L .60794 .66826 L 0 1 .355 r
F
.5997 .66242 m .60333 .68618 L .60731 .67881 L F
.5997 .66242 m .59824 .68702 L .60333 .68618 L F
.59191 .60715 m .60206 .53466 L .59907 .53956 L 0 1 .209 r
F
.60156 .54767 m .61009 .55296 L .60601 .54432 L 0 .893 .304 r
F
.60156 .54767 m .61159 .56852 L .61009 .55296 L F
.60156 .54767 m .60949 .58062 L .61159 .56852 L F
.60156 .54767 m .60504 .58399 L .60949 .58062 L F
.60156 .54767 m .60119 .57636 L .60504 .58399 L F
.60156 .54767 m .59971 .56078 L .60119 .57636 L F
.59662 .57908 m .59437 .59034 L .59535 .60401 L 0 .973 .315 r
F
.59191 .60715 m .60207 .56007 L .60206 .53466 L 0 1 .209 r
F
.59191 .60715 m .59602 .56837 L .59505 .57166 L F
.59602 .56837 m .59907 .53956 L .59596 .56443 L F
.59602 .56837 m .59596 .56443 L .59505 .57166 L F
.58981 .55962 m .58961 .59471 L .5895 .55956 L 0 0 .087 r
F
.58961 .59471 m .58938 .58969 L .5895 .55956 L F
.58929 .58898 m .58961 .59471 L .59017 .50024 L F
.58952 .51592 m .58929 .58898 L .59017 .50024 L F
.59241 .45334 m .59259 .44837 L .59259 .44823 L 0 .674 .037 r
F
.59239 .45446 m .5925 .45581 L .59258 .44936 L F
.5925 .45581 m .59252 .45611 L .59258 .44936 L F
.59228 .4622 m .59252 .45611 L .59239 .45446 L F
.59741 .44617 m .60563 .44604 L .60128 .43768 L 0 .813 .276 r
F
.59741 .44617 m .60819 .46631 L .60563 .44604 L F
.59054 .53515 m .59798 .46603 L .59984 .38886 L 0 1 .128 r
F
.59161 .56823 m .59592 .49913 L .59427 .51734 L 0 1 .185 r
F
.59592 .49913 m .59798 .46603 L .59591 .49463 L F
.59592 .49913 m .59591 .49463 L .59427 .51734 L F
.59161 .56823 m .59505 .57166 L .59907 .53956 L F
.59787 .52758 m .59712 .49314 L .59804 .54437 L 0 .223 .192 r
F
.59191 .60715 m .59898 .59536 L .60207 .56007 L 0 1 .209 r
F
.59278 .63633 m .60124 .61319 L .60171 .59375 L 0 1 .222 r
F
.59132 .64325 m .59276 .63888 L .59278 .63633 L F
.59276 .63888 m .60124 .61319 L .59278 .63633 L F
.59429 .42022 m .59269 .2839 L .5947 .42541 L 0 .267 .202 r
F
.59954 .81775 m .60878 .83686 L .61055 .83798 L 0 .206 .261 r
F
.59527 .79209 m .60016 .81022 L .60427 .82046 L 0 .137 .22 r
F
.60277 .81894 m .60405 .82414 L .60852 .83252 L 0 .025 .167 r
F
.59593 .78604 m .59725 .79562 L .60206 .8112 L 0 .051 .169 r
F
.60091 .8049 m .60688 .83814 L .6009 .80515 L 0 0 .141 r
F
.60073 .80349 m .6013 .8067 L .6004 .80205 L F
.6013 .8067 m .60295 .81601 L .6013 .80696 L F
.6013 .8067 m .6013 .80696 L .6004 .80205 L F
.59474 .7979 m .60277 .81894 L .60016 .81022 L 0 .224 .274 r
F
.59168 .78794 m .58881 .80223 L .59394 .79733 L 0 1 .387 r
F
.59127 .78999 m .59467 .79855 L .59474 .7979 L 0 .224 .274 r
F
.59467 .79855 m .60277 .81894 L .59474 .7979 L F
.59281 .63209 m .59659 .6096 L .59483 .61702 L 0 1 .222 r
F
.59279 .63407 m .5966 .61024 L .59281 .63209 L F
.5966 .61024 m .59898 .59536 L .59659 .6096 L F
.5966 .61024 m .59659 .6096 L .59281 .63209 L F
.59659 .6096 m .59656 .60799 L .59483 .61702 L F
.59054 .53515 m .59427 .51734 L .59798 .46603 L 0 1 .128 r
F
.59054 .53515 m .59106 .54728 L .59427 .51734 L F
.59161 .56823 m .59184 .58406 L .59505 .57166 L 0 1 .185 r
F
.59298 .60537 m .59483 .61702 L .59898 .59536 L 0 1 .209 r
F
.59191 .60715 m .59296 .61068 L .59298 .60537 L F
.59296 .61068 m .59483 .61702 L .59298 .60537 L F
.59659 .6096 m .59898 .59536 L .59656 .60799 L 0 1 .222 r
F
.59429 .42022 m .59392 .41557 L .59269 .2839 L 0 .267 .202 r
F
.60295 .81601 m .60297 .81638 L .6013 .80704 L 0 0 .141 r
F
.6013 .80696 m .6013 .80704 L .6004 .80205 L F
.60295 .81601 m .6013 .80704 L .6013 .80696 L F
.59984 .79928 m .60129 .8073 L .60129 .80766 L F
.60129 .80766 m .60413 .82293 L .60306 .81786 L F
.60129 .8073 m .60413 .82293 L .60129 .80766 L F
.59872 .79164 m .60306 .81786 L .59873 .79109 L F
.5972 .78365 m .59857 .79047 L .59862 .79162 L F
.59422 .7669 m .5987 .7921 L .59814 .78951 L F
.59695 .78263 m .59869 .79265 L .59704 .78156 L F
.59814 .78951 m .59982 .79881 L .59984 .79928 L F
.59869 .79265 m .60306 .81786 L .59872 .79164 L F
.59869 .79265 m .59872 .79164 L .59704 .78156 L F
.5977 .78049 m .60065 .80178 L .60099 .80898 L 0 .009 .137 r
F
.59467 .79855 m .60159 .81832 L .60277 .81894 L 0 .224 .274 r
F
.59127 .78999 m .59458 .79907 L .59467 .79855 L F
.59458 .79907 m .60159 .81832 L .59467 .79855 L F
.59132 .64325 m .59279 .63407 L .59281 .63209 L 0 1 .222 r
F
.59954 .81775 m .60002 .82305 L .60427 .83046 L 0 .206 .261 r
F
.60277 .81894 m .60159 .81832 L .60405 .82414 L 0 .025 .167 r
F
.60099 .80898 m .60366 .82387 L .60356 .83122 L 0 .009 .137 r
F
.60321 .8203 m .60366 .82387 L .60099 .80898 L F
.59915 .79566 m .60079 .80721 L .60096 .81214 L F
.59903 .792 m .60079 .80721 L .59915 .79566 L F
.60079 .80721 m .60149 .81332 L .60096 .81214 L F
.60149 .81332 m .60641 .85594 L .60194 .82 L F
.60149 .81332 m .60194 .82 L .60096 .81214 L F
.60096 .81214 m .60137 .81543 L .60212 .82268 L F
.60185 .8193 m .60194 .82 L .60212 .82268 L F
.60128 .81203 m .60088 .81064 L .60212 .82268 L 0 .066 .149 r
F
.59872 .79164 m .59873 .79109 L .59795 .78626 L 0 0 .141 r
F
.5966 .7709 m .59762 .77859 L .5977 .78049 L 0 .009 .137 r
F
.59359 .74474 m .59608 .76514 L .5936 .74462 L F
.59608 .76514 m .59608 .76501 L .5936 .74462 L F
.5936 .74462 m .59608 .76501 L .59606 .76363 L F
.59323 .74175 m .59359 .74474 L .5936 .74462 L F
.59359 .74474 m .59614 .76902 L .59608 .76514 L F
.59614 .76902 m .59795 .78626 L .59608 .76514 L F
.59323 .74175 m .59624 .76547 L .5966 .7709 L F
.60092 .80457 m .60682 .83331 L .60688 .83814 L 0 0 .141 r
F
.60097 .80268 m .60115 .80558 L .60303 .81365 L F
.60287 .81254 m .60303 .81365 L .60416 .81947 L F
.6021 .80841 m .60303 .81365 L .60287 .81254 L F
.60482 .82273 m .60416 .81947 L .60682 .83331 L F
.6027 .81187 m .60303 .81365 L .60263 .81148 L F
.60263 .81148 m .60303 .81365 L .6021 .80841 L F
.60083 .80175 m .60682 .83331 L .60092 .80457 L F
.60044 .79754 m .60081 .8039 L .60306 .81786 L 0 .009 .137 r
F
.59624 .76547 m .59749 .77527 L .5966 .7709 L F
.59749 .77527 m .60261 .81553 L .59762 .77859 L F
.60261 .81553 m .60261 .81581 L .59762 .77859 L F
.59749 .77527 m .59762 .77859 L .5966 .7709 L F
.59525 .79214 m .60016 .81022 L .59527 .79209 L 0 .137 .22 r
F
.59502 .79204 m .60016 .81022 L .59509 .79156 L F
.59542 .81759 m .59908 .82964 L .60369 .83511 L 0 .316 .339 r
F
.59127 .78999 m .59734 .81026 L .60159 .81832 L 0 .224 .274 r
F
.5998 .81365 m .60316 .85409 L .60007 .81764 L 0 .066 .149 r
F
.59976 .81206 m .60316 .85409 L .5998 .81365 L F
.59416 .77876 m .59966 .80063 L .59908 .79811 L 0 .051 .169 r
F
.59127 .78999 m .60016 .81022 L .5955 .79801 L 0 .224 .274 r
F
.59316 .78546 m .5955 .79801 L .60016 .81022 L 0 .137 .22 r
F
.59884 .79308 m .60316 .85409 L .59934 .80687 L 0 .066 .149 r
F
.60261 .84791 m .59957 .85123 L .60291 .856 L 0 .6 .424 r
F
.60261 .84791 m .59943 .84776 L .59957 .85123 L F
.58723 .83317 m .59201 .84914 L .59684 .83944 L 0 1 .402 r
F
.57049 .86195 m .57325 .86868 L .5793 .86877 L 0 .784 .437 r
F
.59201 .84914 m .57805 .86445 L .5792 .8686 L 0 1 .426 r
F
.57942 .8688 m .5792 .8686 L .5793 .86897 L F
.59201 .84914 m .5792 .8686 L .5795 .86866 L F
.57049 .86195 m .5793 .86877 L .5792 .8686 L 0 .784 .437 r
F
.57325 .86868 m .55845 .87319 L .56632 .87679 L 0 .976 .444 r
F
.57325 .86868 m .56632 .87679 L .57602 .87691 L F
.57056 .86998 m .5793 .86897 L .5792 .8686 L 0 1 .357 r
F
.57638 .86569 m .5792 .8686 L .57805 .86445 L F
.57505 .86484 m .5792 .8686 L .57638 .86569 L 0 .784 .437 r
F
.57049 .86195 m .5792 .8686 L .57505 .86484 L F
.5658 .85905 m .56389 .86895 L .56766 .86736 L 0 1 .481 r
F
.5658 .85905 m .56056 .86771 L .56389 .86895 L F
.55058 .86544 m .5519 .8734 L .56056 .86771 L 0 1 .497 r
F
.57325 .86868 m .55764 .86851 L .55845 .87319 L 0 .976 .444 r
F
.5658 .85905 m .55991 .86445 L .56056 .86771 L 0 1 .481 r
F
.55058 .86544 m .56056 .86771 L .5599 .86445 L 0 1 .497 r
F
.57325 .86868 m .56397 .86657 L .55764 .86851 L 0 .976 .444 r
F
.5658 .85905 m .56766 .86736 L .5699 .86365 L 0 1 .481 r
F
.5658 .85905 m .5699 .86365 L .56912 .8603 L F
.57049 .86195 m .56397 .86657 L .57325 .86868 L 0 .784 .437 r
F
.57056 .86998 m .5792 .8686 L .57638 .86569 L 0 1 .357 r
F
.57638 .86569 m .5792 .8686 L .57808 .86676 L 0 .784 .437 r
F
.59217 .86209 m .57808 .86676 L .5792 .8686 L 0 1 .542 r
F
.5795 .86866 m .5792 .8686 L .5793 .86877 L F
.59217 .86209 m .5792 .8686 L .5795 .86866 L F
.5795 .86866 m .5792 .8686 L .57942 .8688 L 0 1 .426 r
F
.59201 .84914 m .5835 .85595 L .57805 .86445 L F
.58881 .84268 m .56987 .85903 L .57949 .85794 L 0 1 .457 r
F
.58881 .84268 m .56908 .85502 L .56987 .85903 L F
.58881 .84268 m .5772 .84801 L .56908 .85502 L F
.5861 .83262 m .5772 .84801 L .58881 .84268 L 0 1 .453 r
F
.58723 .83317 m .5835 .85595 L .59201 .84914 L 0 1 .402 r
F
.59803 .83993 m .58855 .85108 L .59522 .84844 L 0 1 .484 r
F
.59803 .83993 m .58701 .84986 L .58855 .85108 L F
.59803 .83993 m .59107 .84508 L .58701 .84986 L F
.59349 .83636 m .59107 .84508 L .59803 .83993 L 0 1 .468 r
F
.58893 .83295 m .59349 .83636 L .59697 .83114 L 0 1 .453 r
F
.59365 .83427 m .59943 .84776 L .60261 .84791 L 0 .579 .413 r
F
.59365 .83427 m .60224 .8439 L .59855 .8384 L F
.59365 .83427 m .60261 .84791 L .60224 .8439 L F
.60019 .83459 m .59855 .8384 L .60224 .8439 L 0 .414 .38 r
F
.60316 .85409 m .60319 .85647 L .60007 .81764 L 0 .066 .149 r
F
.60319 .85647 m .6032 .85739 L .60318 .85704 L F
.60319 .85647 m .60318 .85704 L .60007 .81764 L F
.59916 .79547 m .60212 .82268 L .59918 .79417 L 0 .009 .137 r
F
.59704 .78156 m .59872 .79164 L .59795 .78626 L 0 0 .141 r
F
.59679 .77413 m .59903 .792 L .59915 .79566 L 0 .009 .137 r
F
.59323 .74175 m .59358 .74501 L .59359 .74474 L F
.59358 .74501 m .59795 .78626 L .59359 .74474 L F
.59323 .74175 m .59682 .77284 L .59679 .77413 L F
.59682 .77284 m .59903 .792 L .59679 .77413 L F
.59383 .7472 m .59792 .78442 L .5939 .74727 L F
.59792 .78442 m .59793 .78423 L .5939 .74727 L F
.59792 .78442 m .59915 .79566 L .59793 .78423 L F
.59915 .79566 m .60212 .82268 L .59916 .79547 L F
.59915 .79566 m .59916 .79547 L .59793 .78423 L F
.60029 .79956 m .60088 .81064 L .60128 .81203 L 0 .066 .149 r
F
.59762 .77859 m .60321 .8203 L .5977 .78049 L 0 .009 .137 r
F
.59577 .74248 m .5997 .79497 L .59931 .78715 L 0 .066 .149 r
F
.59914 .78506 m .59917 .78534 L .59889 .78303 L F
.5997 .79497 m .60074 .80883 L .59931 .78715 L F
.59931 .78715 m .60074 .80883 L .60029 .79956 L F
.59917 .78534 m .60024 .79892 L .59929 .78786 L F
.60024 .79892 m .60029 .79956 L .60024 .79894 L F
.60024 .79892 m .60024 .79894 L .59929 .78786 L F
.60012 .79505 m .60042 .79741 L .59965 .79229 L 0 .009 .137 r
F
.60042 .79741 m .60111 .80271 L .6004 .79762 L F
.60042 .79741 m .6004 .79762 L .59965 .79229 L F
.60029 .79956 m .60027 .7998 L .59929 .78786 L 0 .066 .149 r
F
.59917 .78782 m .59918 .79417 L .60088 .81064 L F
.60074 .80883 m .60088 .81064 L .6008 .80917 L F
.60074 .80883 m .6008 .80917 L .60029 .79956 L F
.59971 .87044 m .60962 .87226 L .60797 .86846 L 0 1 .466 r
F
.61782 .85942 m .60395 .86782 L .60559 .87023 L 0 1 .523 r
F
.61782 .85942 m .60919 .86319 L .60395 .86782 L F
.62245 .85549 m .60962 .87226 L .6179 .87091 L 0 1 .457 r
F
.62245 .85549 m .60797 .86846 L .60962 .87226 L F
.61782 .85942 m .60559 .87023 L .61359 .8692 L 0 1 .523 r
F
.59596 .86729 m .60559 .87023 L .60395 .86782 L 0 1 .528 r
F
.59217 .86209 m .59596 .86729 L .60149 .86443 L 0 1 .542 r
F
.59217 .86209 m .60149 .86443 L .59985 .86232 L F
.60251 .85955 m .60075 .86685 L .60605 .86997 L 0 .769 .453 r
F
.60251 .85955 m .60605 .86997 L .61027 .86992 L F
.60251 .85955 m .61027 .86992 L .61104 .86679 L F
.60251 .85955 m .61104 .86679 L .60783 .86267 L F
.59932 .78852 m .60568 .86983 L .59957 .80341 L 0 .066 .149 r
F
.60062 .81479 m .60317 .84257 L .60119 .82628 L F
.60119 .82628 m .60317 .84257 L .60323 .85507 L F
.59441 .8476 m .60251 .85954 L .60291 .856 L 0 .726 .441 r
F
.59441 .8476 m .60291 .856 L .59957 .85123 L F
.59981 .79704 m .60283 .85874 L .6027 .85408 L 0 .091 .152 r
F
.60013 .8034 m .60013 .80339 L .60007 .80215 L F
.60067 .81412 m .60013 .80339 L .60013 .8034 L F
.60067 .81412 m .60067 .81413 L .60013 .80339 L F
.60027 .79981 m .60026 .79989 L .59929 .78798 L 0 .066 .149 r
F
.60027 .7998 m .59929 .78798 L .59929 .78786 L F
.60128 .81203 m .60027 .79981 L .60027 .7998 L F
.60027 .79981 m .59929 .78798 L .60027 .7998 L F
.59932 .78852 m .60128 .81295 L .60127 .81349 L F
.59889 .78303 m .59931 .78827 L .59932 .78852 L F
.59931 .78827 m .60128 .81295 L .59932 .78852 L F
.60128 .81203 m .60128 .81232 L .60026 .79989 L F
.60128 .81203 m .60026 .79989 L .60027 .79981 L F
.60029 .79956 m .60128 .81203 L .60027 .7998 L F
.60067 .81412 m .60007 .80215 L .60007 .80214 L 0 .091 .152 r
F
.60007 .80213 m .60067 .81412 L .60007 .80214 L F
.59917 .78534 m .59929 .78786 L .59889 .78303 L 0 .066 .149 r
F
.5939 .74727 m .59916 .79547 L .59678 .77097 L 0 .009 .137 r
F
.59916 .79547 m .59918 .79417 L .59678 .77097 L F
.59577 .74248 m .59692 .77231 L .59918 .79417 L 0 .066 .149 r
F
.59577 .74248 m .59918 .79417 L .59917 .78782 L F
.59626 .74937 m .59914 .78506 L .59889 .78303 L F
.59598 .74548 m .59914 .78506 L .59626 .74937 L F
.59395 .70673 m .59378 .7228 L .59756 .71896 L 0 1 .285 r
F
.59395 .70673 m .59223 .71756 L .59378 .7228 L F
.59381 .7177 m .59692 .77231 L .59577 .74248 L 0 .066 .149 r
F
.59381 .7177 m .59578 .74281 L .59441 .72576 L F
.59381 .7177 m .59648 .75141 L .59578 .74281 L F
.59648 .75141 m .59914 .78506 L .59646 .75141 L F
.59648 .75141 m .59646 .75141 L .59441 .72576 L F
.59637 .76257 m .59884 .79308 L .59934 .80687 L F
.59381 .7177 m .59678 .77097 L .59692 .77231 L F
.58982 .675 m .59142 .68656 L .59551 .67515 L 0 1 .23 r
F
.58982 .675 m .58897 .68651 L .59142 .68656 L F
.59092 .68121 m .59402 .72866 L .59381 .7177 L 0 .066 .149 r
F
.59402 .72866 m .59678 .77097 L .59381 .7177 L F
.59092 .68121 m .59641 .75877 L .59637 .76257 L F
.59641 .75877 m .59884 .79308 L .59637 .76257 L F
.59441 .72576 m .59598 .74548 L .59626 .74937 L F
.59306 .71148 m .59932 .78852 L .59957 .80341 L F
.59092 .68121 m .59285 .70584 L .59306 .71148 L F
.59285 .70584 m .59932 .78852 L .59306 .71148 L F
.59929 .78786 m .59929 .78798 L .59889 .78303 L F
.59889 .78303 m .59929 .78798 L .59931 .78827 L F
.59912 .78487 m .59931 .80174 L .59943 .79112 L 0 .091 .152 r
F
.59619 .6285 m .59777 .63934 L .60124 .61319 L 0 1 .222 r
F
.59276 .63888 m .59617 .63919 L .59619 .6285 L F
.59617 .63919 m .59777 .63934 L .59619 .6285 L F
.59699 .45468 m .59529 .28249 L .59669 .36618 L 0 .267 .202 r
F
.59981 .79859 m .60283 .85874 L .59981 .79704 L 0 .091 .152 r
F
.59957 .80341 m .60062 .81479 L .60119 .82628 L 0 .066 .149 r
F
.59943 .79112 m .60007 .81764 L .60283 .85874 L 0 .091 .152 r
F
.59931 .80174 m .60007 .81764 L .59943 .79112 L F
.59892 .78111 m .6006 .81326 L .60055 .81367 L F
.60003 .80321 m .60157 .83407 L .60003 .80321 L F
.60097 .80855 m .60097 .8086 L .60026 .79992 L 0 .066 .149 r
F
.60026 .79989 m .60097 .80855 L .60026 .79992 L F
.60128 .81232 m .60128 .81235 L .60026 .79992 L F
.60065 .80178 m .60321 .8203 L .60128 .81047 L 0 .009 .137 r
F
.60065 .80178 m .60128 .81047 L .60099 .80898 L F
.60019 .63944 m .59927 .65496 L .60168 .66187 L 0 1 .269 r
F
.59243 .66604 m .59741 .65797 L .59725 .64952 L 0 1 .23 r
F
.59274 .64239 m .59777 .63934 L .59276 .63888 L 0 1 .222 r
F
.59239 .66955 m .59927 .65496 L .59243 .66604 L 0 1 .23 r
F
.59191 .60715 m .59179 .62211 L .59483 .61702 L 0 1 .209 r
F
.58982 .675 m .59408 .65587 L .5936 .65476 L 0 1 .23 r
F
.59132 .64325 m .59274 .64239 L .59276 .63888 L 0 1 .222 r
F
.58982 .675 m .59239 .66955 L .59243 .66604 L 0 1 .23 r
F
.59239 .66955 m .59551 .67515 L .59927 .65496 L F
.58982 .675 m .59231 .67507 L .59239 .66955 L F
.59231 .67507 m .59551 .67515 L .59239 .66955 L F
.59725 .64952 m .59927 .65496 L .60019 .63944 L F
.59741 .65797 m .59927 .65496 L .59725 .64952 L F
.60353 .87959 m .61375 .88137 L .6121 .8778 L 0 1 .48 r
F
.59971 .87044 m .60353 .87959 L .60962 .87226 L 0 1 .466 r
F
.59976 .87352 m .60354 .88038 L .60969 .87662 L 0 1 .513 r
F
.59976 .87352 m .60969 .87662 L .60805 .874 L F
.59596 .86729 m .59976 .87352 L .60559 .87023 L 0 1 .528 r
F
.60354 .88038 m .61378 .8834 L .61215 .88065 L 0 1 .506 r
F
.60632 .87991 m .60138 .88009 L .59946 .883 L 0 .943 .476 r
F
.59946 .87003 m .60138 .88009 L .60632 .87991 L 0 .894 .468 r
F
.59946 .87003 m .60632 .87991 L .60789 .87685 L F
.59946 .87003 m .60789 .87685 L .60504 .87294 L F
.60316 .85409 m .60501 .88026 L .6032 .85739 L 0 .066 .149 r
F
.60261 .81553 m .60321 .8203 L .60261 .81581 L 0 .009 .137 r
F
.6025 .82837 m .6034 .83954 L .6026 .82972 L 0 .066 .149 r
F
.60194 .82 m .60641 .85594 L .60212 .82268 L 0 .009 .137 r
F
.60291 .83442 m .6034 .83954 L .60315 .8375 L 0 .066 .149 r
F
.60127 .81349 m .6026 .82972 L .60291 .83442 L F
.6026 .82972 m .6034 .83954 L .60291 .83442 L F
.60062 .79994 m .60306 .81786 L .60321 .8203 L 0 .009 .137 r
F
.60111 .80271 m .6029 .81663 L .60083 .80114 L F
.6029 .81663 m .6029 .81664 L .60083 .80114 L F
.60083 .80114 m .60306 .81786 L .60062 .79994 L F
.60025 .80007 m .60212 .82268 L .6034 .83954 L 0 .066 .149 r
F
.62245 .85549 m .6179 .87091 L .6273 .86529 L 0 1 .457 r
F
.62262 .86543 m .60805 .874 L .60969 .87662 L 0 1 .518 r
F
.62262 .86543 m .61359 .8692 L .60805 .874 L F
.61027 .86992 m .60504 .87294 L .60789 .87685 L 0 .824 .465 r
F
.61027 .86992 m .60605 .86997 L .60504 .87294 L F
.60323 .85507 m .60568 .86983 L .60501 .88026 L 0 .066 .149 r
F
.60317 .84257 m .60568 .86983 L .60323 .85507 L F
.59436 .42111 m .59738 .57039 L .59539 .43431 L 0 .223 .192 r
F
.61112 .89639 m .60386 .90911 L .61489 .90431 L 0 1 .497 r
F
.61112 .89639 m .59468 .91051 L .60386 .90911 L F
.61112 .89639 m .59346 .90756 L .59468 .91051 L F
.61112 .89639 m .60051 .90151 L .59346 .90756 L F
.60733 .88818 m .60051 .90151 L .61112 .89639 L 0 1 .49 r
F
.58427 .90219 m .59462 .90592 L .5934 .90276 L F
.60733 .88818 m .59163 .9031 L .60051 .90151 L F
.60733 .88818 m .59041 .90009 L .59163 .9031 L F
.60733 .88818 m .59714 .8937 L .59041 .90009 L F
.62 .99314 m .60177 .99932 L .6117 .99976 L 0 1 .54 r
F
.62 .99314 m .60055 .9971 L .60177 .99932 L F
.62 .99314 m .6117 .99976 L .62375 .99813 L F
.62004 .99557 m .60182 1.00294 L .61175 1.00287 L 0 1 .542 r
F
.62004 .99557 m .60061 1.00093 L .60182 1.00294 L F
.62 .99314 m .60836 .99445 L .60055 .9971 L 0 1 .54 r
F
.62004 .99557 m .60841 .99777 L .60061 1.00093 L 0 1 .542 r
F
.61624 .98822 m .59873 .99377 L .60836 .99445 L 0 1 .539 r
F
.61624 .98822 m .59751 .99155 L .59873 .99377 L F
.59708 .69669 m .60527 .70258 L .60245 .69637 L 0 1 .373 r
F
.59708 .69669 m .60383 .71201 L .60527 .70258 L F
.59708 .69669 m .59911 .71837 L .60383 .71201 L F
.60383 .71201 m .59967 .73293 L .60523 .73252 L 0 1 .381 r
F
.59067 .99593 m .60177 .99932 L .60055 .9971 L 0 1 .534 r
F
.61624 .98822 m .60836 .99445 L .62 .99314 L 0 1 .539 r
F
.61628 .99031 m .59878 .99793 L .60841 .99777 L 0 1 .542 r
F
.61628 .99031 m .59757 .99593 L .59878 .99793 L F
.61624 .98822 m .60501 .98917 L .59751 .99155 L 0 1 .539 r
F
.61628 .99031 m .60506 .99266 L .59757 .99593 L 0 1 .542 r
F
.61247 .98342 m .59568 .98822 L .60501 .98917 L 0 1 .538 r
F
.61247 .98342 m .59446 .986 L .59568 .98822 L F
.61247 .98342 m .60501 .98917 L .61624 .98822 L F
.6125 .98496 m .60506 .99266 L .61628 .99031 L 0 1 .541 r
F
.58794 .99007 m .59067 .99593 L .59873 .99377 L 0 1 .531 r
F
.58794 .99007 m .59873 .99377 L .59751 .99155 L F
.6125 .98496 m .59574 .99293 L .60506 .99266 L 0 1 .541 r
F
.6125 .98496 m .59452 .99093 L .59574 .99293 L F
.61247 .98342 m .60165 .98394 L .59446 .986 L 0 1 .538 r
F
.6125 .98496 m .6017 .98751 L .59452 .99093 L 0 1 .541 r
F
.60869 .9788 m .59262 .98269 L .60165 .98394 L 0 1 .534 r
F
.60869 .9788 m .5914 .98049 L .59262 .98269 L F
.60869 .9788 m .60165 .98394 L .61247 .98342 L F
.6087 .97945 m .6017 .98751 L .6125 .98496 L 0 1 .54 r
F
.5852 .98415 m .58794 .99007 L .59568 .98822 L 0 1 .527 r
F
.5852 .98415 m .59568 .98822 L .59446 .986 L F
.6087 .97945 m .59269 .98791 L .6017 .98751 L 0 1 .54 r
F
.60869 .9788 m .59827 .97883 L .5914 .98049 L 0 1 .534 r
F
.6087 .97945 m .59146 .98589 L .59269 .98791 L 0 1 .54 r
F
.6087 .97945 m .59832 .98226 L .59146 .98589 L F
.60739 .97732 m .59827 .97883 L .60869 .9788 L 0 1 .525 r
F
.60671 .97696 m .59827 .97883 L .60739 .97732 L F
.60363 .97531 m .59827 .97883 L .60701 .97689 L F
.58244 .97817 m .5852 .98415 L .59262 .98269 L 0 1 .519 r
F
.58244 .97817 m .59262 .98269 L .5914 .98049 L F
.60353 .97538 m .58955 .97725 L .59827 .97883 L 0 1 .525 r
F
.60347 .97533 m .58955 .97725 L .60353 .97538 L F
.60345 .9753 m .58955 .97725 L .60347 .97533 L F
.60275 .97487 m .58955 .97725 L .60345 .9753 L F
.57968 .97216 m .58244 .97817 L .58955 .97725 L 0 1 .506 r
F
.57968 .97216 m .58955 .97725 L .58832 .97513 L F
.60295 .97483 m .58832 .97513 L .58955 .97725 L 0 1 .525 r
F
.60389 .97497 m .60295 .97483 L .60363 .97531 L 0 1 .537 r
F
.60489 .97367 m .60323 .97466 L .60389 .97497 L F
.60323 .97466 m .60295 .97483 L .60389 .97497 L F
.60294 .9745 m .6027 .97436 L .6028 .97456 L F
.60489 .97367 m .6027 .97436 L .60294 .9745 L F
.60105 .96744 m .59844 .97143 L .60489 .97367 L 0 1 .531 r
F
.59844 .97143 m .59622 .97078 L .5981 .97196 L F
.60105 .96744 m .59639 .97066 L .59844 .97143 L F
.59639 .97066 m .59622 .97078 L .59844 .97143 L F
.6028 .97456 m .58832 .97513 L .60295 .97483 L 0 1 .525 r
F
.6028 .97456 m .59489 .97394 L .58832 .97513 L F
.60489 .97367 m .6028 .97456 L .60295 .97483 L 0 1 .537 r
F
.6049 .97448 m .6027 .97436 L .6028 .97456 L 0 1 .525 r
F
.6027 .97436 m .59489 .97394 L .6028 .97456 L F
.6028 .97456 m .60271 .9746 L .60295 .97483 L 0 1 .537 r
F
.59762 .97248 m .58647 .97208 L .59489 .97394 L 0 1 .503 r
F
.59844 .97143 m .59783 .97237 L .60477 .97365 L 0 1 .531 r
F
.59844 .97143 m .60477 .97365 L .60489 .97367 L F
.59566 .97117 m .58647 .97208 L .59762 .97248 L 0 1 .503 r
F
.59783 .97237 m .6027 .97436 L .60489 .97367 L 0 1 .531 r
F
.59806 .97225 m .59489 .97394 L .60256 .97435 L 0 1 .503 r
F
.59783 .97237 m .58654 .97747 L .59493 .97681 L 0 1 .531 r
F
.5981 .97196 m .59755 .97222 L .59783 .97237 L F
.59783 .97237 m .59566 .97117 L .59762 .97248 L 0 1 .503 r
F
.59755 .97222 m .58654 .97747 L .59783 .97237 L 0 1 .531 r
F
.59622 .97078 m .59566 .97117 L .5981 .97196 L F
.59566 .97117 m .58654 .97747 L .59712 .97242 L F
.59566 .97117 m .59712 .97242 L .5981 .97196 L F
.59566 .97117 m .58524 .97013 L .58647 .97208 L 0 1 .503 r
F
.59639 .97066 m .59553 .97102 L .59566 .97117 L 0 1 .531 r
F
.59481 .97043 m .58524 .97013 L .59566 .97117 L 0 1 .503 r
F
.59553 .97102 m .59547 .97104 L .59566 .97117 L 0 1 .531 r
F
.60105 .96744 m .59538 .97024 L .59639 .97066 L F
.59499 .97044 m .59481 .97043 L .59566 .97117 L 0 1 .503 r
F
.59538 .97024 m .59499 .97044 L .59639 .97066 L 0 1 .531 r
F
.59499 .97044 m .5853 .97522 L .59553 .97102 L F
.59499 .97044 m .59553 .97102 L .59639 .97066 L F
.59499 .97044 m .5915 .96951 L .58524 .97013 L 0 1 .503 r
F
.59464 .97006 m .5915 .96951 L .59499 .97044 L F
.59445 .96985 m .59433 .96984 L .59464 .97006 L F
.59433 .96984 m .5915 .96951 L .59464 .97006 L F
.59225 .96925 m .5937 .96976 L .59433 .96984 L 0 .925 .433 r
F
.59538 .97024 m .59152 .97092 L .5853 .97522 L 0 1 .531 r
F
.60105 .96744 m .59445 .96985 L .59538 .97024 L F
.59445 .96985 m .59152 .97092 L .59538 .97024 L F
.59299 .96937 m .59433 .96984 L .59445 .96985 L 0 .925 .433 r
F
.59719 .96046 m .59246 .96918 L .60105 .96744 L 0 1 .517 r
F
.59299 .96937 m .59445 .96985 L .59303 .96938 L 0 .925 .433 r
F
.59225 .96925 m .59433 .96984 L .59299 .96937 L F
.59243 .96919 m .59225 .96925 L .59284 .96935 L F
.59225 .96925 m .5915 .96951 L .5937 .96976 L F
.59246 .96918 m .59152 .97092 L .59445 .96985 L 0 1 .517 r
F
.59246 .96918 m .59445 .96985 L .60105 .96744 L F
.59303 .96938 m .59445 .96985 L .59348 .96945 L 0 .925 .433 r
F
.59348 .96945 m .59445 .96985 L .60109 .97063 L F
.57691 .96624 m .57968 .97216 L .58647 .97208 L 0 .964 .482 r
F
.57691 .96624 m .58647 .97208 L .58524 .97013 L F
.59229 .96924 m .58339 .9675 L .5915 .96951 L 0 .925 .433 r
F
.59195 .96909 m .58339 .9675 L .59229 .96924 L F
.58843 .96752 m .58339 .9675 L .59246 .96918 L F
.58843 .96752 m .58219 .96891 L .58344 .97155 L 0 1 .517 r
F
.58843 .96752 m .58216 .96594 L .58339 .9675 L 0 .925 .433 r
F
.58946 .9667 m .58661 .96642 L .58843 .96752 L 0 1 .517 r
F
.59719 .96046 m .58726 .96606 L .58946 .9667 L F
.58726 .96606 m .58661 .96642 L .58946 .9667 L F
.59719 .96046 m .58971 .96649 L .59096 .96739 L F
.59308 .96805 m .59096 .96739 L .59273 .96868 L F
.59719 .96046 m .59096 .96739 L .59308 .96805 L F
.57136 .95679 m .57413 .96069 L .58031 .96417 L 0 .368 .366 r
F
.59719 .96046 m .58808 .96416 L .58601 .96583 L 0 1 .517 r
F
.58661 .96642 m .58216 .96594 L .58843 .96752 L 0 .925 .433 r
F
.58706 .96617 m .58601 .96583 L .58585 .96596 L 0 1 .517 r
F
.59719 .96046 m .58601 .96583 L .58706 .96617 L F
.59729 .96756 m .5881 .96596 L .58585 .96596 L 0 .925 .433 r
F
.58661 .96642 m .58585 .96596 L .58216 .96594 L F
.58706 .96617 m .58585 .96596 L .58661 .96642 L 0 1 .517 r
F
.58971 .96649 m .58344 .97155 L .59273 .96868 L F
.59729 .96756 m .58585 .96596 L .58661 .96642 L 0 .925 .433 r
F
.58661 .96642 m .58585 .96596 L .58219 .96891 L 0 1 .517 r
F
.59331 .95231 m .58051 .9642 L .58808 .96416 L 0 1 .49 r
F
.58051 .9642 m .58031 .96417 L .58112 .96436 L 0 .591 .248 r
F
.58051 .9642 m .58031 .96439 L .58112 .96436 L 0 1 .49 r
F
.58051 .9642 m .58112 .96436 L .58808 .96416 L F
.58113 .96427 m .58051 .9642 L .58264 .96471 L 0 .591 .248 r
F
.58051 .9642 m .58112 .96436 L .58264 .96471 L F
.58113 .96427 m .58013 .96406 L .58063 .96421 L F
.59348 .9657 m .58068 .96412 L .58113 .96427 L F
.58068 .96412 m .58013 .96406 L .58113 .96427 L F
.57136 .95679 m .58031 .96417 L .58021 .96411 L 0 .368 .366 r
F
.57691 .96624 m .56705 .96301 L .56029 .9631 L 0 .964 .482 r
F
.57413 .96069 m .56705 .96301 L .57691 .96624 L 0 .708 .439 r
F
.57413 .96069 m .57691 .96624 L .58339 .9675 L F
.57413 .96069 m .58339 .9675 L .58216 .96594 L F
.57143 .96507 m .58021 .96411 L .57735 .9619 L 0 1 .34 r
F
.57735 .9619 m .58021 .96411 L .57908 .96338 L 0 .368 .366 r
F
.57136 .95679 m .58021 .96411 L .57735 .9619 L F
.57143 .96507 m .58031 .96439 L .58021 .96411 L 0 1 .34 r
F
.57735 .9619 m .58021 .96411 L .57905 .96099 L F
.59331 .95231 m .57905 .96099 L .58021 .96411 L 0 1 .49 r
F
.58051 .9642 m .58021 .96411 L .58031 .96417 L 0 .591 .248 r
F
.58051 .9642 m .58021 .96411 L .58031 .96439 L 0 1 .49 r
F
.59331 .95231 m .58021 .96411 L .58051 .9642 L F
.58063 .96421 m .58013 .96406 L .58021 .96411 L 0 .591 .248 r
F
.58063 .96421 m .58021 .96411 L .58051 .9642 L F
.59348 .9657 m .57908 .96338 L .58013 .96406 L F
.59348 .9657 m .58113 .96427 L .5881 .96596 L F
.58113 .96427 m .58264 .96471 L .5881 .96596 L F
.59729 .96756 m .58661 .96642 L .58843 .96752 L 0 .925 .433 r
F
.58661 .96642 m .58632 .96658 L .58843 .96752 L 0 1 .517 r
F
.58632 .96658 m .58219 .96891 L .58843 .96752 L F
.59246 .96918 m .59195 .96909 L .59229 .96924 L 0 .925 .433 r
F
.59273 .96868 m .59188 .96894 L .59246 .96918 L 0 1 .517 r
F
.59729 .96756 m .58843 .96752 L .59246 .96918 L 0 .925 .433 r
F
.59188 .96894 m .59182 .96896 L .59246 .96918 L 0 1 .517 r
F
.59246 .96918 m .58344 .97155 L .59152 .97092 L F
.59182 .96896 m .58344 .97155 L .59246 .96918 L F
.60109 .97063 m .59445 .96985 L .59499 .97044 L 0 1 .503 r
F
.60109 .97063 m .59499 .97044 L .59566 .97117 L F
.60109 .97063 m .59566 .97117 L .59783 .97237 L F
.59566 .97117 m .5853 .97522 L .58654 .97747 L 0 1 .531 r
F
.59547 .97104 m .5853 .97522 L .59566 .97117 L F
.59729 .96756 m .59268 .96911 L .60109 .97063 L 0 .925 .433 r
F
.59268 .96911 m .59243 .96919 L .59317 .96932 L F
.59268 .96911 m .59317 .96932 L .60109 .97063 L F
.59243 .96919 m .59284 .96935 L .60109 .97063 L F
.60172 .97396 m .60256 .97435 L .6027 .97436 L 0 1 .503 r
F
.59783 .97237 m .59493 .97681 L .6027 .97436 L 0 1 .531 r
F
.59806 .97225 m .60172 .97396 L .6027 .97436 L 0 1 .503 r
F
.60489 .97367 m .60368 .97524 L .60701 .97689 L 0 1 .537 r
F
.60368 .97524 m .60363 .97531 L .60701 .97689 L F
.60489 .97367 m .60701 .97689 L .61525 .97553 L F
.60701 .97689 m .60869 .9788 L .61024 .97853 L 0 1 .525 r
F
.60869 .9788 m .61247 .98342 L .61785 .98213 L 0 1 .534 r
F
.61506 .98057 m .61785 .98213 L .61809 .982 L 0 1 .54 r
F
.61506 .98057 m .61809 .982 L .61937 .98133 L F
.61219 .97929 m .61937 .98133 L .61773 .97904 L F
.60869 .9788 m .61506 .98057 L .61219 .97929 L 0 1 .534 r
F
.60869 .9788 m .61785 .98213 L .61506 .98057 L F
.6087 .97945 m .61506 .98057 L .61219 .97929 L 0 1 .54 r
F
.61506 .98057 m .61937 .98133 L .61219 .97929 L F
.61219 .97929 m .61506 .98057 L .61243 .97932 L 0 1 .534 r
F
.61243 .97932 m .61938 .98176 L .61774 .98006 L F
.61506 .98057 m .61938 .98176 L .61243 .97932 L F
.61506 .98057 m .61785 .98213 L .61938 .98176 L F
.61247 .98342 m .61624 .98822 L .62346 .98617 L 0 1 .538 r
F
.61247 .98342 m .62346 .98617 L .62183 .98438 L F
.6087 .97945 m .6125 .98496 L .61785 .98213 L 0 1 .54 r
F
.6087 .97945 m .61785 .98213 L .61506 .98057 L F
.60701 .97689 m .6087 .97945 L .61024 .97853 L 0 1 .537 r
F
.60701 .97689 m .61024 .97853 L .61525 .97553 L F
.60701 .97689 m .61024 .97853 L .61029 .97852 L 0 1 .525 r
F
.6049 .97448 m .60701 .97689 L .61529 .97762 L F
.60701 .97689 m .61029 .97852 L .61529 .97762 L F
.60031 .97298 m .6027 .97436 L .6049 .97448 L 0 1 .503 r
F
.59806 .97225 m .6027 .97436 L .60031 .97298 L F
.60109 .97063 m .59806 .97225 L .6049 .97448 L F
.6049 .97448 m .6028 .97456 L .60295 .97483 L 0 1 .525 r
F
.6028 .97456 m .60251 .97442 L .60271 .9746 L 0 1 .537 r
F
.6027 .97436 m .60251 .97442 L .6028 .97456 L F
.60295 .97483 m .60275 .97487 L .60345 .9753 L 0 1 .525 r
F
.60295 .97483 m .60347 .97533 L .60363 .97531 L F
.60271 .9746 m .59493 .97681 L .58839 .98073 L 0 1 .537 r
F
.60251 .97442 m .59493 .97681 L .60271 .9746 L F
.60295 .97483 m .58839 .98073 L .58962 .98281 L F
.60271 .9746 m .58839 .98073 L .60295 .97483 L F
.60363 .97531 m .60347 .97533 L .60353 .97538 L 0 1 .525 r
F
.6049 .97448 m .60295 .97483 L .60363 .97531 L F
.60295 .97483 m .60285 .97489 L .60363 .97531 L 0 1 .537 r
F
.60363 .97531 m .58962 .98281 L .59832 .98226 L F
.60285 .97489 m .58962 .98281 L .60363 .97531 L F
.60701 .97689 m .60671 .97696 L .60739 .97732 L 0 1 .525 r
F
.6049 .97448 m .60363 .97531 L .60701 .97689 L F
.60701 .97689 m .59832 .98226 L .6087 .97945 L 0 1 .537 r
F
.60363 .97531 m .59832 .98226 L .60701 .97689 L F
.60489 .97367 m .61525 .97553 L .6136 .97312 L F
.6049 .97448 m .61529 .97762 L .61365 .97605 L 0 1 .525 r
F
.60105 .96744 m .60489 .97367 L .61112 .96937 L 0 1 .531 r
F
.60109 .97063 m .6049 .97448 L .61118 .97386 L 0 1 .503 r
F
.60105 .96744 m .61112 .96937 L .60945 .96678 L 0 1 .531 r
F
.60109 .97063 m .61118 .97386 L .60954 .97249 L 0 1 .503 r
F
.59719 .96046 m .60105 .96744 L .60696 .96269 L 0 1 .517 r
F
.59729 .96756 m .60109 .97063 L .60707 .97066 L 0 .925 .433 r
F
.59719 .96046 m .60696 .96269 L .60529 .95983 L 0 1 .517 r
F
.61938 .95304 m .60529 .95983 L .60696 .96269 L 0 1 .519 r
F
.61938 .95304 m .61061 .9557 L .60529 .95983 L F
.59729 .96756 m .60707 .97066 L .60543 .96957 L 0 .925 .433 r
F
.62427 .95999 m .61112 .96937 L .61954 .96923 L 0 1 .528 r
F
.62427 .95999 m .60945 .96678 L .61112 .96937 L F
.61963 .96791 m .60543 .96957 L .60707 .97066 L 0 1 .411 r
F
.61447 .94547 m .60277 .95529 L .61061 .9557 L 0 1 .506 r
F
.61447 .94547 m .60109 .95209 L .60277 .95529 L F
.60812 .64133 m .60479 .66159 L .60794 .66826 L 0 .979 .345 r
F
.60812 .64133 m .60487 .65004 L .60479 .66159 L F
.59758 .67621 m .60779 .66144 L .60581 .65555 L 0 1 .277 r
F
.59758 .67621 m .60631 .67565 L .60779 .66144 L F
.59758 .67621 m .60581 .65555 L .60168 .66187 L F
.61447 .94547 m .6061 .94788 L .60109 .95209 L 0 1 .506 r
F
.61963 .96791 m .6108 .9684 L .60543 .96957 L 0 1 .411 r
F
.6084 .93524 m .59827 .94634 L .6061 .94788 L 0 1 .491 r
F
.6084 .93524 m .5962 .94188 L .59827 .94634 L F
.59758 .67621 m .60221 .69 L .60631 .67565 L 0 1 .277 r
F
.62085 .76398 m .60824 .7823 L .61639 .78019 L 0 1 .448 r
F
.60849 .76813 m .60751 .7864 L .61405 .78095 L 0 1 .405 r
F
.61607 .75456 m .61201 .77065 L .62085 .76398 L 0 1 .448 r
F
.60849 .76813 m .61405 .78095 L .61721 .77302 L 0 1 .405 r
F
.60292 .75488 m .60231 .77356 L .60849 .76813 L 0 1 .399 r
F
.60849 .76813 m .61721 .77302 L .61488 .76789 L 0 1 .405 r
F
.61128 .74543 m .60763 .7614 L .61607 .75456 L 0 1 .447 r
F
.60292 .75488 m .60849 .76813 L .61137 .76007 L 0 1 .399 r
F
.60121 .76805 m .60873 .77018 L .60942 .7634 L 0 1 .378 r
F
.60121 .76805 m .6047 .77835 L .60873 .77018 L F
.60121 .76805 m .59959 .78387 L .6047 .77835 L F
.6148 .96624 m .60295 .96822 L .6108 .9684 L 0 .844 .301 r
F
.62427 .95999 m .61509 .96276 L .60945 .96678 L 0 1 .528 r
F
.6148 .96624 m .6013 .96749 L .60295 .96822 L 0 .844 .301 r
F
.60121 .76805 m .60942 .7634 L .60632 .76254 L 0 1 .378 r
F
.6084 .93524 m .60053 .93712 L .5962 .94188 L 0 1 .491 r
F
.60539 .73472 m .61128 .74543 L .61543 .7367 L 0 1 .439 r
F
.61128 .74543 m .61607 .75456 L .62087 .74662 L 0 1 .447 r
F
.61128 .74543 m .62087 .74662 L .61883 .74287 L F
.60539 .73472 m .61543 .7367 L .61292 .73222 L 0 1 .439 r
F
.6103 .72638 m .60553 .74669 L .61134 .74632 L 0 1 .388 r
F
.6103 .72638 m .60318 .74123 L .60553 .74669 L F
.60115 .74542 m .60976 .74569 L .60958 .73869 L 0 1 .348 r
F
.60292 .75488 m .61137 .76007 L .60904 .75477 L 0 1 .399 r
F
.60115 .74542 m .60646 .75495 L .60976 .74569 L 0 1 .348 r
F
.60115 .74542 m .60958 .73869 L .60605 .7386 L F
.61265 .69509 m .60483 .71812 L .61133 .7135 L 0 1 .396 r
F
.61807 .70409 m .6077 .72305 L .60961 .72636 L 0 1 .408 r
F
.61807 .70409 m .61133 .7135 L .6077 .72305 L F
.60383 .71201 m .61208 .71742 L .60939 .7116 L 0 1 .381 r
F
.61807 .70409 m .60961 .72636 L .61638 .72214 L 0 1 .408 r
F
.60383 .71201 m .6103 .72638 L .61208 .71742 L 0 1 .381 r
F
.60383 .71201 m .60523 .73252 L .6103 .72638 L F
.59864 .72373 m .60792 .72008 L .60702 .71336 L 0 1 .317 r
F
.59864 .72373 m .60533 .73062 L .60792 .72008 L F
.60115 .74542 m .60156 .76178 L .60646 .75495 L 0 1 .348 r
F
.6148 .96624 m .60637 .96664 L .6013 .96749 L 0 .844 .301 r
F
.60731 .67881 m .60245 .69637 L .60527 .70258 L 0 1 .364 r
F
.60731 .67881 m .60333 .68618 L .60245 .69637 L F
.59571 .70318 m .60375 .69524 L .60221 .69 L 0 1 .285 r
F
.59395 .70673 m .59569 .7047 L .59571 .70318 L F
.59569 .7047 m .60375 .69524 L .59571 .70318 L F
.59569 .7047 m .60183 .70715 L .60375 .69524 L F
.59395 .70673 m .59566 .70682 L .59569 .7047 L F
.59566 .70682 m .60183 .70715 L .59569 .7047 L F
.59738 .57039 m .5986 .63061 L .59725 .53205 L 0 .223 .192 r
F
.59864 .72373 m .60702 .71336 L .60323 .71492 L 0 1 .317 r
F
.60376 .92681 m .60053 .93712 L .6084 .93524 L 0 1 .478 r
F
.59572 .70185 m .60221 .69 L .59823 .69493 L 0 1 .285 r
F
.59395 .70673 m .59571 .70318 L .59572 .70185 L F
.59571 .70318 m .60221 .69 L .59572 .70185 L F
.59758 .67621 m .59823 .69493 L .60221 .69 L 0 1 .277 r
F
.59864 .72373 m .60075 .73944 L .60533 .73062 L 0 1 .317 r
F
.60376 .92681 m .6084 .93524 L .61283 .93142 L 0 1 .478 r
F
.60115 .74542 m .59833 .76163 L .60156 .76178 L 0 1 .348 r
F
.59566 .70682 m .59756 .71896 L .60183 .70715 L 0 1 .285 r
F
.59395 .70673 m .5956 .71231 L .59566 .70682 L F
.5956 .71231 m .59756 .71896 L .59566 .70682 L F
.60115 .74542 m .59815 .75462 L .59833 .76163 L 0 1 .348 r
F
.60885 .96519 m .59855 .9667 L .60637 .96664 L 0 .711 .238 r
F
.60885 .96519 m .59652 .96636 L .59855 .9667 L F
.60376 .92681 m .61283 .93142 L .61086 .9282 L 0 1 .478 r
F
.59909 .91795 m .60376 .92681 L .6079 .92324 L 0 1 .472 r
F
.59909 .91795 m .6079 .92324 L .60592 .91986 L F
.60885 .96519 m .60093 .96572 L .59652 .96636 L 0 .711 .238 r
F
.61489 .90431 m .6072 .91657 L .61865 .91203 L 0 1 .502 r
F
.61064 .90719 m .60294 .91467 L .60949 .91651 L 0 1 .488 r
F
.61064 .90719 m .60096 .91114 L .60294 .91467 L F
.61064 .90719 m .60425 .90793 L .60096 .91114 L F
.6043 .96509 m .60092 .96572 L .60885 .96519 L 0 .646 .204 r
F
.60501 .89858 m .59798 .90575 L .60425 .90793 L 0 1 .482 r
F
.60501 .89858 m .59598 .9021 L .59798 .90575 L F
.60501 .89858 m .60425 .90793 L .61064 .90719 L F
.60501 .89858 m .599 .89902 L .59598 .9021 L F
.6043 .96509 m .60885 .96519 L .61336 .96472 L 0 .646 .204 r
F
.59937 .8896 m .599 .89902 L .60501 .89858 L 0 1 .477 r
F
.6043 .96509 m .61336 .96472 L .61142 .96462 L 0 .646 .204 r
F
.59937 .8896 m .60501 .89858 L .60776 .89561 L 0 1 .477 r
F
.59974 .96547 m .6043 .96509 L .60852 .96462 L 0 0 0 r
F
.59937 .8896 m .60776 .89561 L .60539 .89209 L 0 1 .477 r
F
.60632 .87991 m .60184 .88669 L .60758 .88917 L 0 .943 .476 r
F
.60632 .87991 m .59946 .883 L .60184 .88669 L F
.59974 .96547 m .60852 .96462 L .60658 .96472 L 0 0 0 r
F
.6115 .96309 m .60366 .96498 L .61021 .96373 L 0 .724 .211 r
F
.6115 .96309 m .60171 .96523 L .60366 .96498 L F
.6115 .96309 m .60507 .96442 L .60171 .96523 L F
.60597 .96427 m .60507 .96442 L .6115 .96309 L 0 .681 .195 r
F
.59348 .9657 m .5881 .96596 L .59729 .96756 L 0 .591 .248 r
F
.59348 .9657 m .59729 .96756 L .60295 .96822 L F
.59348 .9657 m .60295 .96822 L .6013 .96749 L F
.5888 .96548 m .59348 .9657 L .59855 .9667 L 0 0 0 r
F
.5888 .96548 m .59855 .9667 L .59652 .96636 L F
.58522 .96644 m .5888 .96548 L .59383 .96618 L F
.6043 .96509 m .59228 .96628 L .59383 .96618 L 0 .646 .204 r
F
.6043 .96509 m .59676 .96581 L .59228 .96628 L F
.60597 .96427 m .59878 .96571 L .60507 .96442 L 0 .681 .195 r
F
.6043 .96509 m .59383 .96618 L .60092 .96572 L 0 .646 .204 r
F
.59974 .96547 m .59676 .96581 L .6043 .96509 L 0 0 0 r
F
.60597 .96427 m .59683 .96609 L .59878 .96571 L 0 .681 .195 r
F
.60597 .96427 m .5999 .96548 L .59683 .96609 L F
.61021 1.05593 m .59767 1.05428 L .59975 1.05696 L 0 .81 .443 r
F
.61021 1.05593 m .60214 1.05383 L .59767 1.05428 L F
.59516 .96618 m .59974 .96547 L .60366 .96498 L 0 0 0 r
F
.59516 .96618 m .60366 .96498 L .60171 .96523 L F
.60042 .96582 m .5999 .96548 L .60597 .96427 L F
.60042 .96582 m .60597 .96427 L .60879 .96386 L F
.60554 1.05146 m .60214 1.05383 L .61021 1.05593 L 0 .658 .42 r
F
.60042 .96582 m .60879 .96386 L .60645 .96454 L 0 0 0 r
F
.60554 1.05146 m .61021 1.05593 L .6148 1.05635 L 0 .658 .42 r
F
.60554 1.05146 m .6148 1.05635 L .61281 1.0548 L F
.60084 1.04668 m .60554 1.05146 L .60983 1.05238 L 0 .477 .372 r
F
.61701 .96231 m .60658 .96472 L .60852 .96462 L 0 .763 .228 r
F
.61938 .95304 m .60696 .96269 L .61509 .96276 L 0 1 .519 r
F
.61938 .95304 m .61509 .96276 L .62427 .95999 L F
.61701 .96231 m .61021 .96373 L .60658 .96472 L 0 .763 .228 r
F
.60759 .96547 m .60295 .96567 L .6087 .96409 L 0 0 0 r
F
.60759 .96547 m .60061 .96651 L .60295 .96567 L F
.60759 .96547 m .60259 .96642 L .60061 .96651 L F
.60084 1.04668 m .60983 1.05238 L .60784 1.0507 L 0 .477 .372 r
F
.60082 .96874 m .60259 .96642 L .60759 .96547 L 0 0 0 r
F
.61288 1.05266 m .60484 1.04811 L .61156 1.05221 L 0 .231 .196 r
F
.61288 1.05266 m .60284 1.04633 L .60484 1.04811 L F
.60885 .96519 m .60637 .96664 L .6148 .96624 L 0 .711 .238 r
F
.60082 .96874 m .60759 .96547 L .60923 .96583 L 0 0 0 r
F
.61288 1.05266 m .60628 1.04828 L .60284 1.04633 L 0 .231 .196 r
F
.60082 .96874 m .60923 .96583 L .60642 .96726 L 0 0 0 r
F
.60721 1.04913 m .59983 1.04359 L .60628 1.04828 L 0 .122 .171 r
F
.60721 1.04913 m .59782 1.04171 L .59983 1.04359 L F
.60317 1.04594 m .60097 1.04408 L .59782 1.04171 L F
.60721 1.04913 m .60097 1.04408 L .60317 1.04594 L F
.60151 1.04525 m .59518 1.03917 L .60097 1.04408 L 0 .018 .145 r
F
.59518 1.03917 m .5948 1.03881 L .60097 1.04408 L F
.60721 1.04913 m .60628 1.04828 L .61288 1.05266 L 0 .122 .171 r
F
.60151 1.04525 m .60097 1.04408 L .60721 1.04913 L 0 .018 .145 r
F
.60412 .97221 m .6075 .96783 L .61177 .96716 L 0 0 0 r
F
.60412 .97221 m .60218 .96955 L .6075 .96783 L F
.61963 .96791 m .60707 .97066 L .61522 .97095 L 0 1 .411 r
F
.6148 .96624 m .6108 .9684 L .61963 .96791 L 0 .844 .301 r
F
.60412 .97221 m .61177 .96716 L .61262 .9683 L 0 0 0 r
F
.61854 1.0559 m .60784 1.0507 L .60983 1.05238 L 0 .337 .219 r
F
.61854 1.0559 m .61156 1.05221 L .60784 1.0507 L F
.60151 1.04525 m .60721 1.04913 L .61011 1.05191 L 0 .018 .145 r
F
.60412 .97221 m .61262 .9683 L .60946 .97049 L 0 0 0 r
F
.60151 1.04525 m .61011 1.05191 L .60771 1.05055 L 0 .018 .145 r
F
.61021 1.05593 m .59975 1.05696 L .60774 1.0599 L 0 .81 .443 r
F
.60895 1.05729 m .60411 1.04834 L .61005 1.05402 L 0 .233 0 r
F
.60554 1.05146 m .5949 1.05051 L .60214 1.05383 L 0 .658 .42 r
F
.60554 1.05146 m .59329 1.04818 L .5949 1.05051 L F
.60554 1.05146 m .59785 1.04858 L .59329 1.04818 L F
.60084 1.04668 m .59785 1.04858 L .60554 1.05146 L 0 .477 .372 r
F
.59613 1.04168 m .60084 1.04668 L .60484 1.04811 L 0 .369 .308 r
F
.60895 1.05729 m .60171 1.04676 L .60411 1.04834 L 0 .233 0 r
F
.62914 .96644 m .61525 .97553 L .62398 .97527 L 0 1 .534 r
F
.62914 .96644 m .6136 .97312 L .61525 .97553 L F
.62914 .96644 m .61954 .96923 L .6136 .97312 L F
.62445 .97026 m .60954 .97249 L .61118 .97386 L 0 1 .478 r
F
.6045 .97957 m .60975 .97206 L .61331 .97197 L 0 0 0 r
F
.6045 .97957 m .6046 .974 L .60975 .97206 L F
.60895 1.05729 m .60377 1.05059 L .60171 1.04676 L 0 .233 0 r
F
.62445 .97026 m .61118 .97386 L .61963 .97415 L 0 1 .478 r
F
.6045 .97957 m .61331 .97197 L .61328 .97435 L 0 0 0 r
F
.60198 1.0535 m .60377 1.05059 L .60895 1.05729 L 0 .299 0 r
F
.6045 .97957 m .61328 .97435 L .60966 .97763 L 0 0 0 r
F
.60459 .98965 m .60909 .98079 L .61197 .98173 L 0 .076 .052 r
F
.60238 .99202 m .6044 .98863 L .60459 .98965 L F
.6044 .98863 m .60909 .98079 L .60459 .98965 L F
.60067 .81412 m .60324 .86486 L .60067 .81413 L 0 .091 .152 r
F
.60196 .83947 m .60324 .86486 L .60198 .84014 L F
.60197 .83996 m .60324 .86486 L .60211 .84398 L F
.60197 .83996 m .60211 .84398 L .60157 .83407 L F
.60193 .83888 m .60324 .86486 L .60193 .83893 L F
.60007 .80215 m .60324 .86486 L .60007 .80215 L F
.60229 .84605 m .60324 .86486 L .60229 .84604 L F
.60229 .84605 m .60229 .84604 L .59981 .79705 L F
.59981 .79704 m .60229 .84605 L .59981 .79705 L F
.62445 .97026 m .61522 .97095 L .60954 .97249 L 0 1 .478 r
F
.6084 .93524 m .6061 .94788 L .61447 .94547 L 0 1 .491 r
F
.60885 .96519 m .6148 .96624 L .61924 .96559 L 0 .711 .238 r
F
.60885 .96519 m .61924 .96559 L .61671 .96514 L F
.61701 .96231 m .60852 .96462 L .61533 .96345 L 0 .763 .228 r
F
.60597 .96427 m .6115 .96309 L .6146 .96246 L 0 .681 .195 r
F
.60597 .96427 m .6146 .96246 L .61227 .96297 L F
.6115 .96309 m .61021 .96373 L .61701 .96231 L 0 .724 .211 r
F
.61404 .96281 m .60879 .96386 L .61479 .96218 L 0 0 0 r
F
.61404 .96281 m .60645 .96454 L .60879 .96386 L F
.61404 .96281 m .6087 .96409 L .60645 .96454 L F
.60759 .96547 m .6087 .96409 L .61404 .96281 L F
.60759 .96547 m .61404 .96281 L .61605 .96271 L F
.60759 .96547 m .61605 .96271 L .61336 .96388 L F
.6225 .96197 m .61336 .96472 L .62044 .96365 L 0 .798 .245 r
F
.6225 .96197 m .61142 .96462 L .61336 .96472 L F
.61177 .96716 m .60923 .96583 L .61479 .96388 L 0 0 0 r
F
.61177 .96716 m .60642 .96726 L .60923 .96583 L F
.61177 .96716 m .6075 .96783 L .60642 .96726 L F
.61332 .97197 m .60946 .97049 L .61262 .9683 L F
.61332 .97197 m .60975 .97206 L .60946 .97049 L F
.61197 .98173 m .60966 .97763 L .61328 .97435 L 0 0 .022 r
F
.61197 .98173 m .60909 .98079 L .60966 .97763 L F
.61625 .91544 m .60592 .91986 L .6079 .92324 L 0 1 .493 r
F
.61625 .91544 m .60949 .91651 L .60592 .91986 L F
.60501 .89858 m .61064 .90719 L .61367 .90412 L 0 1 .482 r
F
.60501 .89858 m .61367 .90412 L .61131 .90076 L F
.61287 .88879 m .60539 .89209 L .60776 .89561 L 0 .993 .485 r
F
.61287 .88879 m .60758 .88917 L .60539 .89209 L F
.60501 .88026 m .61058 .97612 L .60901 .9587 L 0 .995 .11 r
F
.62004 .99557 m .61175 1.00287 L .62379 1.00077 L 0 1 .542 r
F
.61628 .99031 m .60841 .99777 L .62004 .99557 L F
.61854 1.0559 m .60983 1.05238 L .61682 1.05589 L 0 .337 .219 r
F
.61288 1.05266 m .61156 1.05221 L .61703 1.05511 L 0 .231 .196 r
F
.61288 1.05266 m .61703 1.05511 L .61854 1.0559 L F
.60946 1.05064 m .61288 1.05266 L .61607 1.05505 L 0 .122 .171 r
F
.60721 1.04913 m .61288 1.05266 L .60946 1.05064 L F
.61288 1.05266 m .61854 1.0559 L .62201 1.05787 L 0 .231 .196 r
F
.61854 1.0559 m .61682 1.05589 L .62416 1.0589 L 0 .337 .219 r
F
.61288 1.05266 m .62201 1.05787 L .61964 1.05677 L 0 .231 .196 r
F
.60721 1.04913 m .61607 1.05505 L .61369 1.05384 L 0 .122 .171 r
F
.61021 1.05593 m .61631 1.06115 L .62082 1.06072 L 0 .81 .443 r
F
.61021 1.05593 m .62082 1.06072 L .61823 1.05889 L F
.62977 1.06167 m .62082 1.06072 L .62889 1.06332 L 0 .506 .252 r
F
.62977 1.06167 m .61823 1.05889 L .62082 1.06072 L F
.62977 1.06167 m .62205 1.05929 L .61823 1.05889 L F
.62416 1.0589 m .6148 1.05635 L .62205 1.05929 L 0 .43 .236 r
F
.62416 1.0589 m .61281 1.0548 L .6148 1.05635 L F
.62416 1.0589 m .61682 1.05589 L .61281 1.0548 L F
.62218 1.06217 m .61369 1.05384 L .61607 1.05505 L 0 .065 0 r
F
.62218 1.06217 m .6163 1.05689 L .61369 1.05384 L F
.60238 .99202 m .61197 .98173 L .6112 .98574 L 0 .076 .052 r
F
.60238 .99202 m .6112 .98574 L .60728 .99016 L F
.61624 .98822 m .62 .99314 L .62753 .99076 L 0 1 .539 r
F
.61624 .98822 m .62753 .99076 L .6259 .98891 L F
.6125 .98496 m .61628 .99031 L .62347 .98689 L 0 1 .541 r
F
.6125 .98496 m .62347 .98689 L .62184 .98469 L F
.60825 .99802 m .6112 .98574 L .61598 .9834 L 0 .105 .069 r
F
.60825 .99802 m .60728 .99016 L .6112 .98574 L F
.60825 .99802 m .61598 .9834 L .61844 .98468 L F
.62 .99314 m .62375 .99813 L .63158 .99548 L 0 1 .54 r
F
.62 .99314 m .63158 .99548 L .62996 .99358 L F
.61628 .99031 m .62004 .99557 L .62756 .9923 L 0 1 .542 r
F
.61628 .99031 m .62756 .9923 L .62593 .99016 L F
.60825 .99802 m .61844 .98468 L .6172 .98993 L 0 .105 .069 r
F
.60825 .99802 m .6172 .98993 L .61305 .99566 L F
.61317 1.00611 m .61132 1.0026 L .61305 .99566 L 0 .124 .084 r
F
.60238 1.0222 m .61132 1.0026 L .61174 1.0034 L 0 .232 .101 r
F
.61153 1.00855 m .61174 1.0034 L .61317 1.00611 L F
.60238 1.0222 m .61174 1.0034 L .61153 1.00855 L F
.60157 .83407 m .6078 .9384 L .6074 .93071 L 0 0 .042 r
F
.61058 .97612 m .61043 .98088 L .60901 .9587 L 0 .995 .11 r
F
.60685 .91991 m .61043 .98088 L .6096 .96477 L 0 0 .042 r
F
.60157 .83407 m .6074 .93071 L .60685 .91991 L F
.6074 .93071 m .61043 .98088 L .60685 .91991 L F
.62147 1.08135 m .60292 1.08282 L .61299 1.08383 L 0 1 .398 r
F
.62147 1.08135 m .60171 1.08172 L .60292 1.08282 L F
.62147 1.08135 m .60965 1.08109 L .60171 1.08172 L F
.6177 1.07868 m .59988 1.08011 L .60965 1.08109 L 0 .99 .383 r
F
.6177 1.07868 m .59867 1.07907 L .59988 1.08011 L F
.6177 1.07868 m .60629 1.07845 L .59867 1.07907 L F
.61391 1.07605 m .59683 1.07753 L .60629 1.07845 L 0 .968 .371 r
F
.61391 1.07605 m .59561 1.07653 L .59683 1.07753 L F
.61391 1.07605 m .60292 1.07589 L .59561 1.07653 L F
.61011 1.07339 m .59377 1.07504 L .60292 1.07589 L 0 .969 .366 r
F
.61011 1.07339 m .59254 1.07407 L .59377 1.07504 L F
.61011 1.07339 m .60292 1.07589 L .61391 1.07605 L F
.61011 1.07339 m .59953 1.07336 L .59254 1.07407 L F
.60628 1.0706 m .59069 1.07259 L .59953 1.07336 L 0 1 .378 r
F
.60628 1.0706 m .58946 1.07159 L .59069 1.07259 L F
.60628 1.0706 m .59953 1.07336 L .61011 1.07339 L F
.60628 1.0706 m .59613 1.07074 L .58946 1.07159 L F
.60243 1.06749 m .59613 1.07074 L .60628 1.0706 L 0 1 .418 r
F
.60243 1.06749 m .60628 1.0706 L .61265 1.06953 L F
.60243 1.06749 m .61265 1.06953 L .61099 1.06823 L F
.59856 1.06375 m .60243 1.06749 L .60848 1.06612 L 0 1 .488 r
F
.59856 1.06375 m .60848 1.06612 L .6068 1.06461 L F
.59465 1.05895 m .59856 1.06375 L .60428 1.06213 L 0 1 .532 r
F
.59465 1.05895 m .60428 1.06213 L .60259 1.06032 L F
.61632 1.06116 m .60259 1.06032 L .60428 1.06213 L 0 .95 .451 r
F
.61632 1.06116 m .60774 1.0599 L .60259 1.06032 L F
.59613 1.04168 m .60484 1.04811 L .60284 1.04633 L 0 .369 .308 r
F
.5914 1.0365 m .59613 1.04168 L .59983 1.04359 L 0 .28 .24 r
F
.59578 1.04086 m .60151 1.04525 L .60411 1.04834 L 0 .074 0 r
F
.59578 1.04086 m .60411 1.04834 L .60171 1.04676 L F
.60084 1.04668 m .59089 1.04457 L .59785 1.04858 L 0 .477 .372 r
F
.60084 1.04668 m .58928 1.0421 L .59089 1.04457 L F
.60084 1.04668 m .59354 1.043 L .58928 1.0421 L F
.59613 1.04168 m .59354 1.043 L .60084 1.04668 L 0 .369 .308 r
F
.60198 1.0535 m .59801 1.04409 L .60377 1.05059 L 0 .299 0 r
F
.61021 1.05593 m .60774 1.0599 L .61631 1.06115 L 0 .81 .443 r
F
.60198 1.0535 m .60895 1.05729 L .61067 1.06135 L 0 .299 0 r
F
.60198 1.0535 m .61067 1.06135 L .60778 1.06004 L F
.62125 1.06482 m .6068 1.06461 L .60848 1.06612 L 0 .986 .433 r
F
.62125 1.06482 m .61227 1.06405 L .6068 1.06461 L F
.61632 1.06116 m .60428 1.06213 L .61227 1.06405 L 0 .95 .451 r
F
.60551 1.0699 m .60341 1.05761 L .60894 1.06519 L 0 .422 .041 r
F
.60551 1.0699 m .6005 1.0557 L .60341 1.05761 L F
.60551 1.0699 m .60139 1.06095 L .6005 1.0557 L F
.59465 1.05895 m .58926 1.06412 L .59856 1.06375 L 0 1 .532 r
F
.59722 1.06355 m .60139 1.06095 L .60252 1.0634 L 0 .476 .042 r
F
.60234 1.06747 m .60252 1.0634 L .60551 1.0699 L F
.59856 1.06375 m .59271 1.06781 L .60243 1.06749 L 0 1 .488 r
F
.59856 1.06375 m .58449 1.06695 L .59271 1.06781 L F
.59856 1.06375 m .58323 1.06549 L .58449 1.06695 L F
.59856 1.06375 m .58926 1.06412 L .58323 1.06549 L F
.59722 1.06355 m .60252 1.0634 L .60234 1.06747 L 0 .476 .042 r
F
.60243 1.06749 m .5876 1.07001 L .59613 1.07074 L 0 1 .418 r
F
.60243 1.06749 m .58636 1.06889 L .5876 1.07001 L F
.60243 1.06749 m .59271 1.06781 L .58636 1.06889 L F
.59722 1.06355 m .60551 1.0699 L .60605 1.07486 L 0 .476 .042 r
F
.59722 1.06355 m .60605 1.07486 L .60262 1.07248 L F
.60608 1.09009 m .60262 1.07248 L .60605 1.07486 L 0 .618 .079 r
F
.60238 1.0222 m .6068 1.00399 L .61132 1.0026 L 0 .232 .101 r
F
.60238 1.0222 m .60262 1.00935 L .6068 1.00399 L F
.60608 1.09009 m .60262 1.07899 L .60262 1.07248 L 0 .618 .079 r
F
.60342 1.15812 m .60505 1.1417 L .61029 1.14778 L 0 .339 .089 r
F
.60238 1.0222 m .61317 1.00611 L .61129 1.01391 L 0 .232 .101 r
F
.60342 1.15812 m .61029 1.14778 L .6121 1.15567 L 0 .339 .089 r
F
.59169 1.08012 m .5944 1.08283 L .60292 1.08282 L 0 .932 .378 r
F
.59169 1.08012 m .60292 1.08282 L .60171 1.08172 L F
.59806 1.08169 m .60262 1.07899 L .60608 1.09009 L 0 .663 .074 r
F
.59682 1.0804 m .59799 1.08012 L .59806 1.08169 L F
.58896 1.07759 m .59169 1.08012 L .59988 1.08011 L 0 .856 .343 r
F
.58896 1.07759 m .59988 1.08011 L .59867 1.07907 L F
.59799 1.08012 m .60262 1.07899 L .59806 1.08169 L 0 .663 .074 r
F
.60412 .97221 m .59935 .97118 L .60218 .96955 L 0 0 0 r
F
.60412 .97221 m .60018 .97232 L .59935 .97118 L F
.59611 .97798 m .60018 .97232 L .60412 .97221 L F
.59611 .97798 m .60412 .97221 L .6046 .974 L F
.59611 .97798 m .6046 .974 L .6013 .97649 L F
.6045 .97957 m .6013 .97649 L .6046 .974 L F
.6045 .97957 m .60124 .97888 L .6013 .97649 L F
.59563 .98749 m .60124 .97888 L .6045 .97957 L 0 .037 .031 r
F
.59563 .98749 m .6045 .97957 L .60421 .98264 L F
.60238 .99202 m .60421 .98264 L .60909 .98079 L 0 .076 .052 r
F
.59563 .98749 m .60421 .98264 L .60057 .98605 L 0 .037 .031 r
F
.60238 .99202 m .60057 .98605 L .60421 .98264 L 0 .076 .052 r
F
.60366 .98898 m .60329 .95679 L .60345 .97242 L 0 1 .196 r
F
.59497 1.04829 m .60198 1.0535 L .60341 1.05761 L 0 .35 0 r
F
.59497 1.04829 m .60341 1.05761 L .6005 1.0557 L F
.60342 1.15812 m .59927 1.13973 L .60505 1.1417 L 0 .339 .089 r
F
.60342 1.15812 m .6121 1.15567 L .60924 1.1601 L F
.59809 1.08255 m .60608 1.09009 L .60582 1.09561 L 0 .663 .074 r
F
.59682 1.0804 m .59806 1.08169 L .59809 1.08255 L F
.59806 1.08169 m .60608 1.09009 L .59809 1.08255 L F
.59812 1.08325 m .60582 1.09561 L .60202 1.09181 L F
.59682 1.0804 m .59809 1.08255 L .59812 1.08325 L F
.59809 1.08255 m .60582 1.09561 L .59812 1.08325 L F
.60407 1.11289 m .60202 1.09181 L .60582 1.09561 L 0 .754 .1 r
F
.60407 1.11289 m .60126 1.09919 L .60202 1.09181 L F
.59886 1.10366 m .60126 1.09919 L .60407 1.11289 L 0 .786 .089 r
F
.59388 1.09485 m .59865 1.09765 L .59886 1.10366 L F
.59865 1.09765 m .60126 1.09919 L .59886 1.10366 L F
.5965 1.16834 m .60342 1.15812 L .60494 1.16671 L 0 .423 .095 r
F
.5965 1.16834 m .60494 1.16671 L .60206 1.1711 L F
.60723 1.19033 m .60206 1.1711 L .60494 1.16671 L 0 .436 .106 r
F
.60198 1.0535 m .59549 1.04211 L .59801 1.04409 L 0 .299 0 r
F
.59989 1.04982 m .60593 1.03808 L .60348 1.04789 L 0 .334 .132 r
F
.60198 1.0535 m .59718 1.04613 L .59549 1.04211 L 0 .299 0 r
F
.59497 1.04829 m .59718 1.04613 L .60198 1.0535 L 0 .35 0 r
F
.5861 1.04421 m .58981 1.05115 L .5949 1.05051 L 0 .824 .456 r
F
.5861 1.04421 m .5949 1.05051 L .59329 1.04818 L F
.58238 1.03714 m .5861 1.04421 L .59089 1.04457 L 0 .643 .431 r
F
.58238 1.03714 m .59089 1.04457 L .58928 1.0421 L F
.58763 1.04069 m .59497 1.04829 L .59601 1.05207 L 0 .387 0 r
F
.58763 1.04069 m .59601 1.05207 L .59295 1.04916 L F
.58981 1.05115 m .59465 1.05895 L .59975 1.05696 L 0 1 .495 r
F
.58981 1.05115 m .59975 1.05696 L .59767 1.05428 L F
.59722 1.06355 m .59295 1.04916 L .59601 1.05207 L 0 .476 .042 r
F
.59458 1.05268 m .59977 1.046 L .59989 1.04982 L 0 .334 .132 r
F
.60151 1.04525 m .59278 1.03681 L .5948 1.03881 L 0 .018 .145 r
F
.60151 1.04525 m .59564 1.03956 L .59278 1.03681 L F
.5914 1.0365 m .59983 1.04359 L .59782 1.04171 L 0 .28 .24 r
F
.59578 1.04086 m .59564 1.03956 L .60151 1.04525 L 0 .074 0 r
F
.59977 1.046 m .60593 1.03808 L .59989 1.04982 L 0 .334 .132 r
F
.60723 1.19033 m .60303 1.18121 L .60206 1.1711 L 0 .436 .106 r
F
.59899 1.10755 m .60407 1.11289 L .60305 1.11767 L 0 .786 .089 r
F
.59388 1.09485 m .59886 1.10366 L .59899 1.10755 L F
.59886 1.10366 m .60407 1.11289 L .59899 1.10755 L F
.59903 1.20319 m .60303 1.18121 L .60723 1.19033 L 0 .531 .111 r
F
.59959 1.13282 m .60305 1.11767 L .60805 1.13588 L 0 .852 .109 r
F
.59903 1.20319 m .60723 1.19033 L .60786 1.20134 L 0 .531 .111 r
F
.59966 1.13295 m .60805 1.13588 L .61055 1.15287 L 0 .852 .109 r
F
.59965 1.13284 m .60805 1.13588 L .59966 1.13295 L F
.59722 1.06355 m .59601 1.05207 L .60139 1.06095 L 0 .476 .042 r
F
.59458 1.05268 m .59989 1.04982 L .5989 1.05404 L 0 .334 .132 r
F
.59989 1.04982 m .60348 1.04789 L .59997 1.05261 L F
.59989 1.04982 m .59997 1.05261 L .5989 1.05404 L F
.59903 1.20319 m .60786 1.20134 L .60448 1.20686 L 0 .531 .111 r
F
.60811 1.23226 m .60448 1.20686 L .60786 1.20134 L 0 .53 .133 r
F
.61391 1.07605 m .60629 1.07845 L .6177 1.07868 L 0 .968 .371 r
F
.60608 1.09009 m .60605 1.07486 L .61145 1.08439 L 0 .618 .079 r
F
.60127 1.10439 m .60581 1.07316 L .60979 1.07846 L 0 .39 .172 r
F
.60036 1.069 m .60348 1.04789 L .60764 1.05058 L 0 .364 .153 r
F
.60593 1.03808 m .61129 1.01391 L .61565 1.01236 L 0 .248 .115 r
F
.60593 1.03808 m .61565 1.01236 L .6171 1.01718 L F
.60593 1.03808 m .6171 1.01718 L .61482 1.02753 L F
.60593 1.03808 m .61482 1.02753 L .61031 1.03652 L F
.61558 1.06003 m .61011 1.05191 L .6163 1.05689 L 0 .156 0 r
F
.61558 1.06003 m .60771 1.05055 L .61011 1.05191 L F
.61558 1.06003 m .61005 1.05402 L .60771 1.05055 L F
.60895 1.05729 m .61005 1.05402 L .61558 1.06003 L 0 .233 0 r
F
.61632 1.06116 m .61227 1.06405 L .62125 1.06482 L 0 .95 .451 r
F
.60895 1.05729 m .61558 1.06003 L .61768 1.06389 L 0 .233 0 r
F
.60895 1.05729 m .61768 1.06389 L .61492 1.06301 L F
.6086 1.06036 m .61482 1.02753 L .61897 1.02582 L 0 .259 .137 r
F
.6086 1.06036 m .61031 1.03652 L .61482 1.02753 L F
.6086 1.06036 m .61897 1.02582 L .62001 1.03254 L F
.6086 1.06036 m .62001 1.03254 L .61737 1.0466 L F
.6086 1.06036 m .61737 1.0466 L .61278 1.05865 L F
.6177 1.07868 m .60965 1.08109 L .62147 1.08135 L 0 .99 .383 r
F
.61011 1.07339 m .61391 1.07605 L .62094 1.07535 L 0 .969 .366 r
F
.61011 1.07339 m .62094 1.07535 L .61929 1.07424 L F
.60628 1.0706 m .61011 1.07339 L .61681 1.07254 L 0 1 .378 r
F
.60628 1.0706 m .61681 1.07254 L .61515 1.07138 L F
.62616 1.06804 m .61265 1.06953 L .62124 1.07068 L 0 .982 .409 r
F
.62616 1.06804 m .61099 1.06823 L .61265 1.06953 L F
.62616 1.06804 m .61676 1.06759 L .61099 1.06823 L F
.62125 1.06482 m .60848 1.06612 L .61676 1.06759 L 0 .986 .433 r
F
.62416 1.0589 m .62205 1.05929 L .62977 1.06167 L 0 .43 .236 r
F
.62218 1.06217 m .61607 1.05505 L .62252 1.05936 L 0 .065 0 r
F
.61342 1.07342 m .61067 1.06135 L .61645 1.06786 L 0 .373 .035 r
F
.61342 1.07342 m .60778 1.06004 L .61067 1.06135 L F
.61342 1.07342 m .60894 1.06519 L .60778 1.06004 L F
.60551 1.0699 m .60894 1.06519 L .61342 1.07342 L 0 .422 .041 r
F
.60551 1.0699 m .61342 1.07342 L .61434 1.07873 L F
.60551 1.0699 m .61434 1.07873 L .61107 1.07754 L F
.62147 1.08135 m .61299 1.08383 L .62523 1.08408 L 0 1 .398 r
F
.61524 1.09476 m .61107 1.07754 L .61434 1.07873 L 0 .54 .078 r
F
.61524 1.09476 m .61145 1.08439 L .61107 1.07754 L F
.60608 1.09009 m .61145 1.08439 L .61524 1.09476 L 0 .618 .079 r
F
.60608 1.09009 m .61524 1.09476 L .61527 1.10134 L F
.61042 1.09286 m .61278 1.05865 L .61737 1.0466 L 0 .266 .156 r
F
.61058 .97612 m .61519 1.05539 L .61043 .98088 L 0 .995 .11 r
F
.60952 .96324 m .61453 1.04496 L .61457 1.04517 L 0 0 .042 r
F
.60157 .83407 m .6072 .92559 L .60714 .92444 L F
.61502 1.17713 m .60924 1.1601 L .6121 1.15567 L 0 .346 .101 r
F
.60608 1.09009 m .61527 1.10134 L .61151 1.09969 L 0 .618 .079 r
F
.61502 1.17713 m .61048 1.16928 L .60924 1.1601 L 0 .346 .101 r
F
.60407 1.11289 m .60582 1.09561 L .61101 1.10839 L 0 .754 .1 r
F
.60723 1.19033 m .61048 1.16928 L .61502 1.17713 L 0 .436 .106 r
F
.60407 1.11289 m .61101 1.10839 L .61413 1.12171 L 0 .754 .1 r
F
.60723 1.19033 m .61502 1.17713 L .61604 1.18727 L 0 .436 .106 r
F
.60407 1.11289 m .61413 1.12171 L .6134 1.1292 L 0 .754 .1 r
F
.60407 1.11289 m .6134 1.1292 L .60928 1.12578 L F
.60045 1.07245 m .60764 1.05058 L .6086 1.06036 L 0 .364 .153 r
F
.60043 1.07179 m .60764 1.05058 L .60045 1.07245 L F
.60811 1.23226 m .60457 1.22009 L .60448 1.20686 L 0 .53 .133 r
F
.59896 1.24611 m .59937 1.21444 L .60457 1.22009 L 0 .626 .137 r
F
.60342 1.15812 m .59678 1.14319 L .59927 1.13973 L 0 .339 .089 r
F
.60342 1.15812 m .59855 1.15107 L .59678 1.14319 L F
.5965 1.16834 m .59855 1.15107 L .60342 1.15812 L 0 .423 .095 r
F
.60458 1.18051 m .60267 1.16013 L .6046 1.15117 L 0 .869 .136 r
F
.59102 1.14099 m .5914 1.12729 L .59696 1.13291 L 0 .325 .074 r
F
.59102 1.14099 m .59696 1.13291 L .59927 1.13973 L F
.59102 1.14099 m .59927 1.13973 L .59678 1.14319 L F
.5965 1.16834 m .59302 1.14834 L .59855 1.15107 L 0 .423 .095 r
F
.59903 1.20319 m .59762 1.17758 L .60303 1.18121 L 0 .531 .111 r
F
.59269 1.13537 m .60458 1.18051 L .60237 1.18135 L 0 .918 .105 r
F
.59269 1.13537 m .60267 1.16013 L .60458 1.18051 L F
.59896 1.24611 m .60457 1.22009 L .60811 1.23226 L 0 .626 .137 r
F
.59896 1.24611 m .60811 1.23226 L .60797 1.24588 L F
.59896 1.24611 m .60797 1.24588 L .60421 1.25184 L F
.60647 1.28486 m .60421 1.25184 L .60797 1.24588 L 0 .617 .157 r
F
.59903 1.20319 m .59459 1.18183 L .59762 1.17758 L 0 .531 .111 r
F
.59622 1.18255 m .60237 1.18135 L .60723 1.21574 L 0 .96 .119 r
F
.60647 1.28486 m .60355 1.26851 L .60421 1.25184 L 0 .617 .157 r
F
.59622 1.18255 m .60621 1.24302 L .60106 1.21703 L 0 .96 .119 r
F
.59622 1.18255 m .60887 1.24243 L .60621 1.24302 L F
.60811 1.23226 m .60786 1.20134 L .61328 1.20503 L 0 .53 .133 r
F
.60811 1.23226 m .61328 1.20503 L .61714 1.21552 L F
.60811 1.23226 m .61714 1.21552 L .61727 1.22881 L F
.60811 1.23226 m .61727 1.22881 L .61357 1.23601 L F
.59622 1.18255 m .60723 1.21574 L .60887 1.24243 L 0 .96 .119 r
F
.61055 1.15287 m .60928 1.12578 L .6134 1.1292 L 0 .782 .122 r
F
.61055 1.15287 m .60805 1.13588 L .60928 1.12578 L F
.59959 1.13282 m .60907 1.15946 L .6046 1.15117 L 0 .852 .109 r
F
.59959 1.13282 m .61055 1.15287 L .60907 1.15946 L F
.59269 1.13537 m .59783 1.13354 L .60267 1.16013 L 0 .918 .105 r
F
.60723 1.19033 m .60494 1.16671 L .61048 1.16928 L 0 .436 .106 r
F
.60458 1.18051 m .6046 1.15117 L .60907 1.15946 L 0 .869 .136 r
F
.60458 1.18051 m .60907 1.15946 L .61406 1.18187 L F
.59943 1.16348 m .61146 1.14311 L .6081 1.16626 L 0 .411 .187 r
F
.59637 1.29567 m .60355 1.26851 L .60647 1.28486 L 0 .714 .155 r
F
.59943 1.16348 m .6081 1.16626 L .60327 1.17436 L 0 .411 .187 r
F
.60723 1.19033 m .61604 1.18727 L .61282 1.19294 L 0 .436 .106 r
F
.61714 1.21552 m .61282 1.19294 L .61604 1.18727 L 0 .43 .124 r
F
.61714 1.21552 m .61328 1.20503 L .61282 1.19294 L F
.60458 1.18051 m .61406 1.18187 L .61625 1.2036 L 0 .869 .136 r
F
.60458 1.18051 m .61433 1.21277 L .60958 1.20312 L F
.60458 1.18051 m .61625 1.2036 L .61433 1.21277 L F
.59905 1.24131 m .60106 1.21703 L .60621 1.24302 L 0 .981 .139 r
F
.59971 1.2394 m .6081 1.16626 L .61182 1.18937 L 0 .433 .198 r
F
.59896 1.24611 m .59594 1.21902 L .59937 1.21444 L 0 .626 .137 r
F
.59905 1.24131 m .598 1.21628 L .60106 1.21703 L 0 .981 .139 r
F
.59971 1.2394 m .60327 1.17436 L .6081 1.16626 L 0 .433 .198 r
F
.59637 1.29567 m .60647 1.28486 L .60557 1.30065 L 0 .714 .155 r
F
.59637 1.29567 m .60557 1.30065 L .60144 1.30527 L F
.60647 1.28486 m .60797 1.24588 L .61317 1.25223 L 0 .617 .157 r
F
.60647 1.28486 m .61317 1.25223 L .61638 1.26672 L F
.60647 1.28486 m .61638 1.26672 L .61576 1.28349 L F
.60647 1.28486 m .61576 1.28349 L .61171 1.29131 L F
.59905 1.24131 m .60621 1.24302 L .61113 1.28967 L 0 .981 .139 r
F
.6024 1.34617 m .60557 1.30065 L .61061 1.31223 L 0 .702 .173 r
F
.6024 1.34617 m .60144 1.30527 L .60557 1.30065 L F
.60887 1.24243 m .60958 1.20312 L .61433 1.21277 L 0 .859 .163 r
F
.60887 1.24243 m .60723 1.21574 L .60958 1.20312 L F
.61638 1.26672 m .61727 1.22881 L .62265 1.23254 L 0 .516 .152 r
F
.61638 1.26672 m .61357 1.23601 L .61727 1.22881 L F
.61638 1.26672 m .61317 1.25223 L .61357 1.23601 L F
.60887 1.24243 m .61433 1.21277 L .6193 1.24144 L 0 .859 .163 r
F
.59971 1.2394 m .61182 1.18937 L .61196 1.22875 L 0 .433 .198 r
F
.59637 1.29567 m .59852 1.25905 L .60355 1.26851 L 0 .714 .155 r
F
.6024 1.34617 m .61061 1.31223 L .61321 1.33241 L 0 .702 .173 r
F
.59905 1.24131 m .60941 1.32545 L .60392 1.28803 L 0 .981 .139 r
F
.61321 1.33241 m .61061 1.31223 L .61171 1.29131 L 0 .598 .173 r
F
.59905 1.24131 m .61252 1.32612 L .60941 1.32545 L 0 .981 .139 r
F
.59905 1.24131 m .61113 1.28967 L .61252 1.32612 L F
.6024 1.34617 m .61321 1.33241 L .61189 1.35206 L 0 .702 .173 r
F
.61638 1.26672 m .62265 1.23254 L .62613 1.24476 L 0 .516 .152 r
F
.61638 1.26672 m .62613 1.24476 L .62578 1.26105 L F
.61638 1.26672 m .62578 1.26105 L .62179 1.27052 L F
.60887 1.24243 m .6193 1.24144 L .62119 1.27028 L 0 .859 .163 r
F
.60887 1.24243 m .61886 1.28325 L .61385 1.27145 L F
.60887 1.24243 m .62119 1.27028 L .61886 1.28325 L F
.59971 1.2394 m .61196 1.22875 L .60838 1.26057 L 0 .433 .198 r
F
.59971 1.2394 m .60838 1.26057 L .60344 1.26313 L F
.6024 1.34617 m .60007 1.32472 L .60144 1.30527 L 0 .702 .173 r
F
.60118 1.31486 m .60392 1.28803 L .60941 1.32545 L 0 .998 .153 r
F
.6024 1.34617 m .61189 1.35206 L .60748 1.35795 L 0 .702 .173 r
F
.60776 1.40993 m .6057 1.38265 L .60748 1.35795 L 0 .683 .187 r
F
.58922 1.17824 m .58665 1.15674 L .59199 1.16031 L 0 .514 .098 r
F
.58922 1.17824 m .58401 1.16001 L .58665 1.15674 L F
.58922 1.17824 m .5851 1.16922 L .58401 1.16001 L F
.58186 1.18641 m .5851 1.16922 L .58922 1.17824 L 0 .601 .1 r
F
.58186 1.18641 m .58922 1.17824 L .59003 1.18767 L F
.58186 1.18641 m .59003 1.18767 L .58697 1.19118 L F
.59074 1.21383 m .59003 1.18767 L .59519 1.1928 L 0 .622 .114 r
F
.59074 1.21383 m .58697 1.19118 L .59003 1.18767 L F
.59074 1.21383 m .59519 1.1928 L .59903 1.20319 L F
.59074 1.21383 m .59903 1.20319 L .59937 1.21444 L F
.59074 1.21383 m .59937 1.21444 L .59594 1.21902 L F
.58968 1.2546 m .59076 1.22459 L .59575 1.23257 L 0 .717 .135 r
F
.58968 1.2546 m .59575 1.23257 L .59896 1.24611 L F
.58968 1.2546 m .59896 1.24611 L .59852 1.25905 L F
.58968 1.2546 m .59852 1.25905 L .5947 1.26268 L F
.59637 1.29567 m .5947 1.26268 L .59852 1.25905 L 0 .714 .155 r
F
.59637 1.29567 m .59377 1.27834 L .5947 1.26268 L F
.58609 1.29495 m .59377 1.27834 L .59637 1.29567 L 0 .805 .145 r
F
.58609 1.29495 m .59637 1.29567 L .59518 1.30845 L F
.59133 1.34376 m .59518 1.30845 L .60007 1.32472 L 0 .803 .163 r
F
.59133 1.34376 m .60007 1.32472 L .6024 1.34617 L F
.59133 1.34376 m .6024 1.34617 L .60078 1.36147 L F
.59133 1.34376 m .60078 1.36147 L .59626 1.36026 L F
.59596 1.40409 m .60078 1.36147 L .6057 1.38265 L 0 .794 .178 r
F
.59596 1.40409 m .59626 1.36026 L .60078 1.36147 L F
.59596 1.40409 m .6057 1.38265 L .60776 1.40993 L F
.60228 1.39946 m .58696 1.15115 L .60212 1.36666 L 0 .566 0 r
F
.5934 1.2427 m .59724 1.28069 L .60212 1.36666 L F
.58696 1.15115 m .59011 1.19094 L .59049 1.20143 L F
.59169 1.08012 m .57187 1.08014 L .58186 1.08174 L 0 .932 .378 r
F
.59169 1.08012 m .57108 1.0791 L .57187 1.08014 L F
.59169 1.08012 m .58186 1.08174 L .5944 1.08283 L F
.59169 1.08012 m .57956 1.07909 L .57108 1.0791 L F
.58896 1.07759 m .57956 1.07909 L .59169 1.08012 L 0 .856 .343 r
F
.58896 1.07759 m .56989 1.07761 L .57956 1.07909 L F
.58896 1.07759 m .56909 1.07668 L .56989 1.07761 L F
.58896 1.07759 m .57726 1.07667 L .56909 1.07668 L F
.58622 1.07524 m .57726 1.07667 L .58896 1.07759 L 0 .771 .3 r
F
.56758 1.07165 m .56556 1.07558 L .56948 1.07611 L 0 1 .509 r
F
.56758 1.07165 m .56948 1.07611 L .57182 1.0752 L F
.58622 1.07524 m .5679 1.07539 L .57726 1.07667 L 0 .771 .3 r
F
.56758 1.07165 m .57182 1.0752 L .57102 1.07345 L 0 1 .509 r
F
.58622 1.07524 m .5671 1.0746 L .5679 1.07539 L 0 .771 .3 r
F
.58622 1.07524 m .57495 1.07453 L .5671 1.0746 L F
.58347 1.07308 m .57495 1.07453 L .58622 1.07524 L 0 .714 .257 r
F
.58347 1.07308 m .58622 1.07524 L .59377 1.07504 L F
.58347 1.07308 m .59377 1.07504 L .59254 1.07407 L F
.58071 1.07107 m .58347 1.07308 L .59069 1.07259 L 0 .708 .241 r
F
.58071 1.07107 m .59069 1.07259 L .58946 1.07159 L F
.57794 1.0691 m .58071 1.07107 L .5876 1.07001 L 0 .694 .212 r
F
.57794 1.0691 m .5876 1.07001 L .58636 1.06889 L F
.59465 1.05895 m .58135 1.06275 L .58926 1.06412 L 0 1 .532 r
F
.59465 1.05895 m .58008 1.06055 L .58135 1.06275 L F
.59465 1.05895 m .58578 1.05892 L .58008 1.06055 L F
.58981 1.05115 m .57795 1.05581 L .58578 1.05892 L 0 1 .495 r
F
.58981 1.05115 m .57638 1.05167 L .57795 1.05581 L F
.58981 1.05115 m .58145 1.04967 L .57638 1.05167 L F
.5861 1.04421 m .57429 1.04571 L .58145 1.04967 L 0 .824 .456 r
F
.5861 1.04421 m .57308 1.04191 L .57429 1.04571 L F
.5861 1.04421 m .58145 1.04967 L .58981 1.05115 L F
.5861 1.04421 m .57813 1.04126 L .57308 1.04191 L F
.58238 1.03714 m .57813 1.04126 L .5861 1.04421 L 0 .643 .431 r
F
.57865 1.03026 m .58238 1.03714 L .58686 1.03836 L 0 .461 .393 r
F
.57865 1.03026 m .58686 1.03836 L .58525 1.03585 L F
.5914 1.0365 m .58282 1.03207 L .58921 1.03726 L 0 .28 .24 r
F
.5914 1.0365 m .5812 1.02955 L .58282 1.03207 L F
.5914 1.0365 m .58487 1.03144 L .5812 1.02955 L F
.58665 1.0311 m .57877 1.02576 L .58487 1.03144 L 0 .189 .201 r
F
.58665 1.0311 m .57714 1.02321 L .57877 1.02576 L F
.58665 1.0311 m .58051 1.0255 L .57714 1.02321 L F
.58188 1.02536 m .58051 1.0255 L .58665 1.0311 L 0 .104 .182 r
F
.58188 1.02536 m .58665 1.0311 L .58974 1.0337 L F
.58188 1.02536 m .58974 1.0337 L .58772 1.03154 L F
.57687 1.01878 m .58188 1.02536 L .5846 1.02804 L 0 .029 .165 r
F
.57687 1.01878 m .5846 1.02804 L .58247 1.02553 L F
.58665 1.0311 m .58487 1.03144 L .5914 1.0365 L 0 .189 .201 r
F
.58665 1.0311 m .5914 1.0365 L .5948 1.03881 L F
.58665 1.0311 m .5948 1.03881 L .59278 1.03681 L F
.58976 1.03551 m .58247 1.02553 L .5846 1.02804 L 0 .151 0 r
F
.58976 1.03551 m .58468 1.02872 L .58247 1.02553 L F
.58188 1.02536 m .5747 1.01935 L .58051 1.0255 L 0 .104 .182 r
F
.58188 1.02536 m .57307 1.01673 L .5747 1.01935 L F
.58188 1.02536 m .57614 1.0193 L .57307 1.01673 L F
.57687 1.01878 m .57614 1.0193 L .58188 1.02536 L 0 .029 .165 r
F
.58372 1.02901 m .57927 1.02147 L .58468 1.02872 L 0 .208 0 r
F
.57184 1.01131 m .57687 1.01878 L .57927 1.02147 L 0 0 .153 r
F
.58372 1.02901 m .57714 1.01857 L .57927 1.02147 L 0 .208 0 r
F
.58372 1.02901 m .57903 1.02179 L .57714 1.01857 L F
.57738 1.02047 m .57903 1.02179 L .58372 1.02901 L 0 .245 0 r
F
.57738 1.02047 m .58372 1.02901 L .58525 1.03195 L F
.57738 1.02047 m .58525 1.03195 L .58259 1.02862 L F
.59613 1.04168 m .58686 1.03836 L .59354 1.043 L 0 .369 .308 r
F
.59613 1.04168 m .58525 1.03585 L .58686 1.03836 L F
.59613 1.04168 m .58921 1.03726 L .58525 1.03585 L F
.58763 1.04069 m .58259 1.02862 L .58525 1.03195 L 0 .387 0 r
F
.58763 1.04069 m .5836 1.03236 L .58259 1.02862 L F
.5749 1.02357 m .57865 1.03026 L .58282 1.03207 L 0 .345 .339 r
F
.5749 1.02357 m .58282 1.03207 L .5812 1.02955 L F
.58023 1.02995 m .5836 1.03236 L .58763 1.04069 L 0 .404 0 r
F
.58023 1.02995 m .58763 1.04069 L .58835 1.04378 L F
.58023 1.02995 m .58835 1.04378 L .58527 1.03952 L F
.58238 1.03714 m .57126 1.03632 L .57813 1.04126 L 0 .643 .431 r
F
.58238 1.03714 m .57005 1.03266 L .57126 1.03632 L F
.58238 1.03714 m .57481 1.03301 L .57005 1.03266 L F
.57865 1.03026 m .57481 1.03301 L .58238 1.03714 L 0 .461 .393 r
F
.58043 1.03752 m .58063 1.03177 L .58548 1.04357 L 0 .495 .014 r
F
.59102 1.14099 m .58568 1.1251 L .5914 1.12729 L 0 .325 .074 r
F
.59102 1.14099 m .58357 1.1278 L .58568 1.1251 L F
.58981 1.05115 m .58578 1.05892 L .59465 1.05895 L 0 1 .495 r
F
.58043 1.03752 m .58548 1.04357 L .58886 1.05325 L 0 .495 .014 r
F
.59102 1.14099 m .58585 1.13461 L .58357 1.1278 L 0 .325 .074 r
F
.58043 1.03752 m .58879 1.05576 L .5853 1.04938 L 0 .495 .014 r
F
.58043 1.03752 m .58886 1.05325 L .58879 1.05576 L F
.58503 1.1489 m .58585 1.13461 L .59102 1.14099 L 0 .389 .079 r
F
.57806 1.03803 m .58005 1.03754 L .58474 1.05277 L 0 .539 .024 r
F
.58503 1.1489 m .59102 1.14099 L .59302 1.14834 L 0 .389 .079 r
F
.58108 1.04625 m .58474 1.05277 L .58748 1.06372 L 0 .539 .024 r
F
.57806 1.03803 m .58102 1.04456 L .58108 1.04625 L F
.58102 1.04456 m .58474 1.05277 L .58108 1.04625 L F
.57793 1.12547 m .58288 1.11919 L .58568 1.1251 L 0 .305 .054 r
F
.57793 1.12547 m .58568 1.1251 L .58357 1.1278 L F
.58503 1.1489 m .58041 1.13179 L .58585 1.13461 L 0 .389 .079 r
F
.58503 1.1489 m .59302 1.14834 L .59051 1.15174 L F
.59067 .99593 m .57116 1.0015 L .58102 1.00268 L 0 1 .534 r
F
.59067 .99593 m .57036 .99897 L .57116 1.0015 L F
.59067 .99593 m .58102 1.00268 L .59339 1.00171 L F
.59072 1.00053 m .5712 1.00634 L .58106 1.00674 L 0 1 .539 r
F
.59067 .99593 m .57872 .99658 L .57036 .99897 L 0 1 .534 r
F
.59072 1.00053 m .57041 1.00448 L .5712 1.00634 L 0 1 .539 r
F
.59072 1.00053 m .57877 1.00199 L .57041 1.00448 L F
.58794 .99007 m .56917 .9951 L .57872 .99658 L 0 1 .531 r
F
.58794 .99007 m .56837 .99249 L .56917 .9951 L F
.58794 .99007 m .57641 .99033 L .56837 .99249 L F
.56696 .99716 m .56885 1.00357 L .57115 1.00151 L 0 1 .532 r
F
.56696 .99716 m .57115 1.00151 L .57036 .99897 L F
.58794 .99007 m .57872 .99658 L .59067 .99593 L 0 1 .531 r
F
.588 .9957 m .56922 1.00176 L .57877 1.00199 L 0 1 .536 r
F
.588 .9957 m .56843 .99999 L .56922 1.00176 L F
.5852 .98415 m .56717 .98849 L .57641 .99033 L 0 1 .527 r
F
.5852 .98415 m .56636 .98577 L .56717 .98849 L F
.588 .9957 m .57648 .99739 L .56843 .99999 L 0 1 .536 r
F
.5852 .98415 m .57408 .98391 L .56636 .98577 L 0 1 .527 r
F
.58527 .99094 m .56724 .9974 L .57648 .99739 L 0 1 .53 r
F
.56506 .99055 m .56322 .9973 L .56696 .99716 L 0 1 .528 r
F
.56506 .99055 m .56696 .99716 L .56916 .9951 L F
.56506 .99055 m .56916 .9951 L .56836 .99249 L F
.58527 .99094 m .56645 .99573 L .56724 .9974 L 0 1 .53 r
F
.58244 .97817 m .56516 .98159 L .57408 .98391 L 0 1 .519 r
F
.58244 .97817 m .56435 .97874 L .56516 .98159 L F
.58244 .97817 m .57408 .98391 L .5852 .98415 L F
.58527 .99094 m .57417 .99296 L .56645 .99573 L 0 1 .53 r
F
.58244 .97817 m .57175 .97727 L .56435 .97874 L 0 1 .519 r
F
.5852 .98415 m .57641 .99033 L .58794 .99007 L 0 1 .527 r
F
.58253 .98626 m .57417 .99296 L .58527 .99094 L 0 1 .518 r
F
.58253 .98626 m .56525 .99333 L .57417 .99296 L F
.57968 .97216 m .56314 .97431 L .57175 .97727 L 0 1 .506 r
F
.57968 .97216 m .56233 .97125 L .56314 .97431 L F
.56506 .99055 m .55992 .99536 L .56322 .9973 L 0 1 .528 r
F
.58253 .98626 m .56445 .9918 L .56525 .99333 L 0 1 .518 r
F
.57968 .97216 m .57175 .97727 L .58244 .97817 L 0 1 .506 r
F
.57968 .97216 m .56941 .97033 L .56233 .97125 L F
.58253 .98626 m .57186 .98877 L .56445 .9918 L 0 1 .518 r
F
.57691 .96624 m .56111 .96645 L .56941 .97033 L 0 .964 .482 r
F
.57691 .96624 m .56029 .9631 L .56111 .96645 L F
.57691 .96624 m .56941 .97033 L .57968 .97216 L F
.57978 .98161 m .57186 .98877 L .58253 .98626 L 0 1 .491 r
F
.56315 .98366 m .56145 .99058 L .56506 .99055 L 0 1 .523 r
F
.56315 .98366 m .56506 .99055 L .56716 .98849 L F
.56315 .98366 m .56716 .98849 L .56636 .98577 L F
.57978 .98161 m .56326 .98965 L .57186 .98877 L 0 1 .491 r
F
.57978 .98161 m .56246 .98832 L .56326 .98965 L F
.57413 .96069 m .55906 .95778 L .56705 .96301 L 0 .708 .439 r
F
.57413 .96069 m .55824 .95402 L .55906 .95778 L F
.57978 .98161 m .56954 .98487 L .56246 .98832 L 0 1 .491 r
F
.57413 .96069 m .56469 .95526 L .55824 .95402 L 0 .708 .439 r
F
.57702 .97689 m .56954 .98487 L .57978 .98161 L 0 1 .429 r
F
.56315 .98366 m .55824 .98848 L .56145 .99058 L 0 1 .523 r
F
.57702 .97689 m .56126 .98654 L .56954 .98487 L 0 1 .429 r
F
.56315 .98366 m .55757 .98563 L .55824 .98848 L 0 1 .523 r
F
.57702 .97689 m .56046 .98551 L .56126 .98654 L 0 1 .429 r
F
.57136 .95679 m .56469 .95526 L .57413 .96069 L 0 .368 .366 r
F
.57702 .97689 m .56721 .98137 L .56046 .98551 L 0 1 .429 r
F
.57424 .9718 m .56721 .98137 L .57702 .97689 L 0 1 .311 r
F
.56315 .98366 m .55967 .98356 L .55757 .98563 L 0 1 .523 r
F
.56123 .97639 m .55967 .98356 L .56315 .98366 L 0 1 .514 r
F
.56123 .97639 m .56315 .98366 L .56515 .98159 L F
.56123 .97639 m .56515 .98159 L .56434 .97874 L F
.57424 .9718 m .55925 .98426 L .56721 .98137 L 0 1 .311 r
F
.56123 .97639 m .55657 .98122 L .55967 .98356 L 0 1 .514 r
F
.57424 .9718 m .55845 .98364 L .55925 .98426 L 0 1 .311 r
F
.57424 .9718 m .56488 .97829 L .55845 .98364 L F
.57143 .96507 m .57424 .9718 L .58031 .96439 L 0 1 .34 r
F
.57143 .96507 m .56488 .97829 L .57424 .9718 L F
.5701 .95847 m .57143 .96506 L .57408 .95985 L 0 1 .365 r
F
.5593 .96855 m .56123 .97639 L .56313 .9743 L 0 1 .499 r
F
.5593 .96855 m .56313 .9743 L .56232 .97125 L F
.57136 .95679 m .55701 .94871 L .56469 .95526 L 0 .368 .366 r
F
.57136 .95679 m .55619 .94539 L .55701 .94871 L F
.57136 .95679 m .56233 .94884 L .55619 .94539 L F
.5701 .95847 m .56252 .9739 L .57143 .96506 L 0 1 .365 r
F
.5701 .95847 m .56233 .94884 L .57136 .95679 L 0 .249 .073 r
F
.566 .95686 m .56233 .94884 L .5701 .95847 L F
.56789 .94755 m .566 .95686 L .5701 .95847 L 0 1 .365 r
F
.566 .95686 m .56252 .9739 L .5701 .95847 L F
.56801 .96127 m .566 .95686 L .5701 .95847 L 0 .249 .073 r
F
.56801 .96127 m .5701 .95847 L .57702 .96315 L F
.5701 .95847 m .57136 .95679 L .57408 .95985 L F
.5701 .95847 m .57408 .95985 L .57702 .96315 L F
.56789 .94755 m .5701 .95847 L .57693 .95423 L 0 1 .365 r
F
.5701 .95847 m .57408 .95985 L .57693 .95423 L F
.56801 .96127 m .57702 .96315 L .57552 .96364 L 0 .249 .073 r
F
.56758 1.07165 m .56212 1.07378 L .56556 1.07558 L 0 1 .509 r
F
.58347 1.07308 m .5659 1.07355 L .57495 1.07453 L 0 .714 .257 r
F
.58347 1.07308 m .56511 1.07294 L .5659 1.07355 L F
.57143 .96507 m .55724 .98238 L .56488 .97829 L 0 1 .34 r
F
.5473 .97571 m .54866 .98349 L .55656 .98122 L 0 1 .506 r
F
.5473 .97571 m .55656 .98122 L .55589 .97818 L F
.56123 .97639 m .55589 .97818 L .55657 .98122 L 0 1 .514 r
F
.56123 .97639 m .55789 .97611 L .55589 .97818 L F
.5593 .96855 m .55789 .97611 L .56123 .97639 L 0 1 .499 r
F
.57143 .96507 m .55643 .98133 L .55724 .98238 L 0 1 .34 r
F
.57143 .96507 m .56252 .9739 L .55643 .98133 L F
.56547 .9683 m .56801 .96133 L .57352 .96481 L 0 .223 .103 r
F
.58347 1.07308 m .57263 1.07274 L .56511 1.07294 L 0 .714 .257 r
F
.56547 .9683 m .57352 .96481 L .57237 .96587 L 0 .223 .103 r
F
.58522 .96644 m .57237 .96587 L .57352 .96481 L 0 0 0 r
F
.58071 1.07107 m .57263 1.07274 L .58347 1.07308 L 0 .708 .241 r
F
.58522 .96644 m .57738 .96657 L .57237 .96587 L 0 0 0 r
F
.58163 .96765 m .57064 .96738 L .57738 .96657 L F
.58163 .96765 m .56948 .96834 L .57064 .96738 L F
.58163 .96765 m .57419 .96846 L .56948 .96834 L F
.57802 .96876 m .56774 .96954 L .57419 .96846 L F
.57515 1.06688 m .57794 1.0691 L .58449 1.06695 L F
.57802 .96876 m .56657 .97017 L .56774 .96954 L F
.57515 1.06688 m .58449 1.06695 L .58323 1.06549 L F
.57802 .96876 m .57098 .96984 L .56657 .97017 L F
.57233 1.06308 m .57515 1.06688 L .58135 1.06275 L 0 .912 .211 r
F
.57439 .96971 m .57098 .96984 L .57802 .96876 L 0 0 0 r
F
.57439 .96971 m .56482 .97094 L .57098 .96984 L F
.57439 .96971 m .56364 .97132 L .56482 .97094 L F
.57233 1.06308 m .58135 1.06275 L .58008 1.06055 L 0 .912 .211 r
F
.57439 .96971 m .56774 .97079 L .56364 .97132 L 0 0 0 r
F
.57073 .97054 m .56774 .97079 L .57439 .96971 L F
.57073 .97054 m .57439 .96971 L .57819 .96917 L F
.57073 .97054 m .57819 .96917 L .57661 .96955 L F
.56705 .97133 m .57073 .97054 L .57423 .97013 L F
.57865 1.03026 m .56824 1.02744 L .57481 1.03301 L 0 .461 .393 r
F
.57865 1.03026 m .56703 1.02414 L .56824 1.02744 L F
.56705 .97133 m .57423 .97013 L .57264 .97052 L 0 0 0 r
F
.57424 .9718 m .58344 .97155 L .58219 .96891 L 0 1 .311 r
F
.58128 .9696 m .57264 .97052 L .57423 .97013 L 0 0 0 r
F
.57865 1.03026 m .57148 1.02534 L .56703 1.02414 L 0 .461 .393 r
F
.58128 .9696 m .57566 .97029 L .57264 .97052 L 0 0 0 r
F
.5749 1.02357 m .57148 1.02534 L .57865 1.03026 L 0 .345 .339 r
F
.5764 .97117 m .5702 .97113 L .57566 .97029 L 0 0 0 r
F
.5764 .97117 m .56853 .97157 L .5702 .97113 L F
.5764 .97117 m .57118 .97159 L .56853 .97157 L F
.57115 1.01693 m .5749 1.02357 L .57877 1.02576 L 0 .281 .285 r
F
.57424 .9718 m .57702 .97689 L .58344 .97155 L 0 1 .311 r
F
.57149 .97294 m .57118 .97159 L .5764 .97117 L 0 0 0 r
F
.57149 .97294 m .5764 .97117 L .57876 .97147 L F
.57115 1.01693 m .57877 1.02576 L .57714 1.02321 L 0 .281 .285 r
F
.57149 .97294 m .57876 .97147 L .57667 .97227 L 0 0 0 r
F
.57694 .97579 m .57347 .97358 L .57853 .97281 L F
.57694 .97579 m .57129 .9745 L .57347 .97358 L F
.57694 .97579 m .57277 .97546 L .57129 .9745 L F
.57074 .97905 m .57277 .97546 L .57694 .97579 L F
.57702 .97689 m .57978 .98161 L .58654 .97747 L 0 1 .429 r
F
.57702 .97689 m .58654 .97747 L .5853 .97522 L F
.57074 .97905 m .57694 .97579 L .57812 .97712 L 0 0 0 r
F
.57184 1.01131 m .57927 1.02147 L .57714 1.01857 L 0 0 .153 r
F
.57074 .97905 m .57812 .97712 L .57552 .97856 L 0 0 0 r
F
.57687 1.01878 m .57057 1.01258 L .57614 1.0193 L 0 .029 .165 r
F
.57687 1.01878 m .56886 1.00968 L .57057 1.01258 L F
.57687 1.01878 m .57155 1.01233 L .56886 1.00968 L F
.57184 1.01131 m .57155 1.01233 L .57687 1.01878 L 0 0 .153 r
F
.57738 1.02047 m .57385 1.01368 L .57903 1.02179 L 0 .245 0 r
F
.56696 .99716 m .56498 1.00378 L .56885 1.00357 L 0 1 .532 r
F
.56701 1.00327 m .56888 1.00787 L .5712 1.00634 L 0 1 .536 r
F
.56701 1.00327 m .5712 1.00634 L .57041 1.00449 L F
.56696 .99716 m .56158 1.00198 L .56498 1.00378 L 0 1 .532 r
F
.56512 .99888 m .56701 1.00327 L .56922 1.00177 L 0 1 .531 r
F
.56658 1.0021 m .57184 1.01131 L .57385 1.01368 L 0 0 .145 r
F
.57738 1.02047 m .57161 1.01006 L .57385 1.01368 L 0 .245 0 r
F
.57738 1.02047 m .57312 1.01296 L .57161 1.01006 L F
.57251 .98576 m .5762 .98034 L .57972 .98128 L 0 .034 0 r
F
.57251 .98576 m .5716 .98072 L .5762 .98034 L F
.57101 1.00941 m .57312 1.01296 L .57738 1.02047 L 0 0 .09 r
F
.57251 .98576 m .57972 .98128 L .58012 .98344 L 0 .034 0 r
F
.57251 .98576 m .58012 .98344 L .57713 .98538 L F
.57101 1.00941 m .57738 1.02047 L .57858 1.02283 L 0 0 .09 r
F
.57101 1.00941 m .57858 1.02283 L .57591 1.01844 L F
.58023 1.02995 m .57591 1.01844 L .57858 1.02283 L 0 .404 0 r
F
.58023 1.02995 m .57661 1.02147 L .57591 1.01844 L F
.57177 .99514 m .57704 .98817 L .57994 .98994 L 0 .181 .042 r
F
.57177 .99514 m .57261 .98814 L .57704 .98817 L F
.57177 .99514 m .57994 .98994 L .57959 .99294 L F
.57278 1.0149 m .57661 1.02147 L .58023 1.02995 L 0 .388 0 r
F
.57177 .99514 m .57959 .99294 L .57621 .99516 L 0 .181 .042 r
F
.57509 1.01985 m .58023 1.02995 L .58063 1.03177 L 0 .388 0 r
F
.57278 1.0149 m .57524 1.01987 L .57509 1.01985 L F
.57524 1.01987 m .58023 1.02995 L .57509 1.01985 L F
.56738 1.01018 m .57115 1.01693 L .5747 1.01935 L 0 .22 .24 r
F
.56738 1.01018 m .5747 1.01935 L .57307 1.01673 L F
.57195 1.01473 m .57286 1.01475 L .57459 1.0198 L 0 .451 0 r
F
.57399 1.01973 m .57459 1.0198 L .57744 1.02813 L F
.57195 1.01473 m .57459 1.0198 L .57399 1.01973 L F
.57278 1.0149 m .58063 1.03177 L .57753 1.02568 L 0 .388 0 r
F
.58527 .99094 m .57648 .99739 L .588 .9957 L 0 1 .53 r
F
.5777 1.00173 m .5754 .99893 L .57621 .99516 L 0 .225 .064 r
F
.58043 1.03752 m .57753 1.02568 L .58063 1.03177 L 0 .495 .014 r
F
.58043 1.03752 m .57744 1.02813 L .57753 1.02568 L F
.56701 1.00327 m .56501 1.00806 L .56888 1.00787 L 0 1 .536 r
F
.56701 1.00327 m .56162 1.00685 L .56501 1.00806 L F
.56701 1.00327 m .56096 1.00504 L .56162 1.00685 L F
.56701 1.00327 m .56327 1.00351 L .56096 1.00504 L F
.56658 1.0021 m .56694 1.00454 L .57184 1.01131 L 0 0 .145 r
F
.56658 1.0021 m .57385 1.01368 L .57161 1.01006 L F
.57101 1.00941 m .56825 1.00397 L .57312 1.01296 L 0 0 .09 r
F
.57101 1.00941 m .56599 .99949 L .56825 1.00397 L F
.57101 1.00941 m .56717 1.0018 L .56599 .99949 L F
.56696 .99716 m .56091 .99936 L .56158 1.00198 L 0 1 .532 r
F
.56696 .99716 m .56322 .9973 L .56091 .99936 L F
.56512 .99888 m .56922 1.00177 L .56843 .99999 L 0 1 .531 r
F
.56324 .99476 m .56512 .99888 L .56724 .9974 L 0 1 .522 r
F
.56324 .99476 m .56724 .9974 L .56644 .99573 L F
.5646 .99489 m .56717 1.0018 L .57101 1.00941 L 0 0 .104 r
F
.5646 .99489 m .57101 1.00941 L .57188 1.01074 L F
.5671 1.00034 m .57188 1.01074 L .56919 1.00488 L F
.5646 .99489 m .56695 1.00002 L .5671 1.00034 L F
.56695 1.00002 m .57188 1.01074 L .5671 1.00034 L F
.56529 .99423 m .56513 .99463 L .56781 1.00189 L 0 0 .079 r
F
.56828 1.00292 m .56781 1.00189 L .56957 1.00665 L F
.56529 .99423 m .56781 1.00189 L .56828 1.00292 L F
.57184 1.01131 m .56629 1.0051 L .57155 1.01233 L 0 0 .153 r
F
.56512 .99888 m .56327 1.00351 L .56701 1.00327 L 0 1 .531 r
F
.57184 1.01131 m .56457 1.00189 L .56629 1.0051 L 0 0 .153 r
F
.57184 1.01131 m .56694 1.00455 L .56457 1.00189 L F
.57278 1.0149 m .56919 1.00488 L .57188 1.01074 L 0 .388 0 r
F
.57278 1.0149 m .56957 1.00665 L .56919 1.00488 L F
.56635 .99717 m .56957 1.00665 L .57278 1.0149 L 0 0 .079 r
F
.56529 .99423 m .56616 .99677 L .56635 .99717 L F
.56616 .99677 m .56957 1.00665 L .56635 .99717 L F
.56506 .99055 m .55925 .99265 L .55992 .99536 L 0 1 .528 r
F
.56506 .99055 m .56145 .99058 L .55925 .99265 L F
.55944 .98788 m .56134 .99104 L .56325 .98965 L 0 1 .447 r
F
.55944 .98788 m .56325 .98965 L .56245 .98832 L F
.55754 .98561 m .55944 .98788 L .56125 .98654 L 0 1 .308 r
F
.55754 .98561 m .56125 .98654 L .56045 .98551 L F
.55564 .98485 m .55754 .98561 L .55925 .98426 L 0 .829 .164 r
F
.55564 .98485 m .55925 .98426 L .55845 .98364 L F
.54866 .98349 m .55002 .99077 L .55824 .98848 L 0 1 .515 r
F
.54866 .98349 m .55824 .98848 L .55757 .98563 L F
.55754 .98561 m .55266 .98811 L .55333 .98872 L 0 1 .308 r
F
.55754 .98561 m .55447 .98678 L .55266 .98811 L F
.55564 .98485 m .55447 .98678 L .55754 .98561 L 0 .829 .164 r
F
.55376 .98801 m .55564 .98485 L .55724 .98239 L 0 0 .05 r
F
.55564 .98485 m .55166 .98798 L .55447 .98678 L 0 .829 .164 r
F
.54866 .98349 m .53839 .99098 L .55002 .99077 L 0 1 .515 r
F
.54469 .98801 m .55332 .98872 L .55266 .98811 L 0 .761 .254 r
F
.54866 .98349 m .52949 .98885 L .53839 .99098 L 0 1 .515 r
F
.54469 .98801 m .53567 .98984 L .54604 .98946 L 0 .761 .254 r
F
.54469 .98801 m .54604 .98946 L .55332 .98872 L F
.54335 .98883 m .54469 .98801 L .55166 .98798 L 0 0 0 r
F
.54335 .98883 m .55166 .98798 L .551 .98842 L F
.55564 .98485 m .551 .98842 L .55166 .98798 L 0 .829 .164 r
F
.55564 .98485 m .55271 .98708 L .551 .98842 L F
.55376 .98801 m .55271 .98708 L .55564 .98485 L 0 0 .05 r
F
.55376 .98801 m .55724 .98239 L .55643 .98134 L F
.55681 .97903 m .55727 .98386 L .56128 .99085 L 0 0 .148 r
F
.54592 .96721 m .5473 .97571 L .55487 .97341 L 0 1 .492 r
F
.5593 .96855 m .55488 .97341 L .55789 .97611 L 0 1 .499 r
F
.54592 .96721 m .55487 .97341 L .55419 .97009 L 0 1 .492 r
F
.5593 .96855 m .5542 .97009 L .55488 .97341 L 0 1 .499 r
F
.54454 .95751 m .54592 .96721 L .55317 .96474 L 0 1 .474 r
F
.54454 .95751 m .55317 .96474 L .55249 .96092 L F
.55125 .96258 m .55376 .98801 L .55503 .97298 L 0 1 .253 r
F
.5563 .97862 m .55381 .97644 L .5539 .97662 L 0 0 .148 r
F
.5563 .97862 m .5539 .97662 L .55727 .98386 L F
.5563 .97862 m .55727 .98386 L .55681 .97903 L F
.55679 .97903 m .5563 .97862 L .55681 .97903 L 0 0 0 r
F
.55598 .97938 m .5563 .97862 L .55679 .97903 L F
.55598 .97938 m .55292 .97643 L .55381 .97644 L F
.5563 .97862 m .55381 .97644 L .55722 .97648 L F
.55598 .97938 m .55381 .97644 L .5563 .97862 L F
.55137 .9977 m .54023 1.00492 L .55271 1.00436 L 0 1 .526 r
F
.55137 .9977 m .5307 1.00326 L .54023 1.00492 L F
.55137 .9977 m .53046 1.00048 L .5307 1.00326 L F
.55137 .9977 m .53931 .99809 L .53046 1.00048 L F
.55002 .99077 m .53931 .99809 L .55137 .9977 L 0 1 .521 r
F
.55002 .99077 m .55137 .9977 L .55991 .99536 L F
.55002 .99077 m .55991 .99536 L .55924 .99265 L F
.55137 .9977 m .55271 1.00436 L .56157 1.00198 L 0 1 .526 r
F
.55137 .9977 m .56157 1.00198 L .56091 .99936 L F
.54873 .99549 m .55007 .99936 L .55831 .99821 L 0 1 .503 r
F
.54873 .99549 m .55831 .99821 L .55764 .99663 L F
.55002 .99077 m .53009 .99622 L .53931 .99809 L 0 1 .521 r
F
.54738 .99211 m .54873 .99549 L .55665 .99439 L 0 1 .465 r
F
.54738 .99211 m .55665 .99439 L .55598 .99299 L F
.55002 .99077 m .52985 .99332 L .53009 .99622 L 0 1 .521 r
F
.55002 .99077 m .53839 .99098 L .52985 .99332 L F
.54604 .98946 m .54738 .99211 L .55499 .99112 L 0 1 .382 r
F
.54604 .98946 m .55499 .99112 L .55432 .99001 L F
.55754 .98561 m .55333 .98872 L .55623 .98862 L 0 1 .308 r
F
.55375 .988 m .55003 .99375 L .55271 .98708 L 0 0 .05 r
F
.55376 .98801 m .55373 .98805 L .55375 .988 L F
.55373 .98805 m .55003 .99375 L .55375 .988 L F
.54873 .99549 m .53842 .99932 L .55007 .99936 L 0 1 .503 r
F
.54873 .99549 m .52951 .99818 L .53842 .99932 L F
.54873 .99549 m .52927 .99671 L .52951 .99818 L F
.54873 .99549 m .5375 .99556 L .52927 .99671 L F
.54738 .99211 m .5375 .99556 L .54873 .99549 L 0 1 .465 r
F
.52119 .9987 m .5307 1.00326 L .53046 1.00048 L 0 1 .526 r
F
.55007 .99936 m .53011 1.00213 L .53933 1.00345 L 0 1 .521 r
F
.55007 .99936 m .52987 1.00051 L .53011 1.00213 L F
.55007 .99936 m .53842 .99932 L .52987 1.00051 L F
.52091 .99146 m .53009 .99622 L .52985 .99332 L 0 1 .522 r
F
.54738 .99211 m .52891 .99467 L .5375 .99556 L 0 1 .465 r
F
.54738 .99211 m .52867 .99342 L .52891 .99467 L F
.54738 .99211 m .53659 .99232 L .52867 .99342 L F
.54604 .98946 m .53659 .99232 L .54738 .99211 L 0 1 .382 r
F
.54604 .98946 m .52831 .99177 L .53659 .99232 L F
.54604 .98946 m .52807 .99083 L .52831 .99177 L F
.54604 .98946 m .53567 .98984 L .52807 .99083 L F
.54205 1.00119 m .54335 .98883 L .55003 .99384 L 0 .016 0 r
F
.55007 .99936 m .53933 1.00345 L .5514 1.00358 L 0 1 .521 r
F
.54205 1.00119 m .55003 .99384 L .54939 1.00066 L 0 .016 0 r
F
.55125 .96258 m .54826 .99771 L .54947 .99783 L 0 1 .253 r
F
.55376 .98801 m .5494 1.00043 L .55003 .99375 L 0 0 .05 r
F
.55369 .9882 m .551 .99798 L .5494 1.00043 L F
.55376 .98801 m .55124 .99709 L .55369 .9882 L F
.55124 .99709 m .551 .99798 L .55369 .9882 L F
.55102 .99427 m .54947 .99783 L .55099 .99799 L 0 1 .253 r
F
.551 .99798 m .55099 .99799 L .551 .99799 L F
.55102 .99427 m .55099 .99799 L .551 .99798 L F
.55125 .96258 m .54947 .99783 L .55102 .99427 L F
.55125 .96258 m .551 .99799 L .55376 .98801 L F
.5593 .96855 m .55609 .968 L .5542 .97009 L 0 1 .499 r
F
.55736 .95983 m .55609 .968 L .5593 .96855 L 0 .997 .471 r
F
.55736 .95983 m .5593 .96855 L .5611 .96645 L F
.55736 .95983 m .5611 .96645 L .56029 .9631 L F
.566 .95686 m .55503 .97286 L .56252 .9739 L 0 1 .365 r
F
.55095 .928 m .55229 .9364 L .56104 .93176 L 0 1 .493 r
F
.55095 .928 m .53995 .93926 L .55229 .9364 L F
.55098 .93376 m .55231 .94002 L .56108 .93652 L 0 1 .534 r
F
.55342 .93557 m .55246 .94752 L .55541 .94962 L 0 .142 .208 r
F
.55342 .93557 m .55541 .94962 L .55701 .94871 L F
.55342 .93557 m .55701 .94871 L .55619 .94538 L F
.566 .95686 m .55486 .94647 L .56233 .94884 L 0 .249 .073 r
F
.5635 .95619 m .55486 .94647 L .566 .95686 L F
.56789 .94755 m .5635 .95619 L .566 .95686 L 0 1 .365 r
F
.5635 .95619 m .55503 .97286 L .566 .95686 L F
.56801 .96127 m .5635 .95619 L .566 .95686 L 0 .249 .073 r
F
.54866 .98349 m .52925 .98578 L .52949 .98885 L 0 1 .515 r
F
.54866 .98349 m .53746 .98349 L .52925 .98578 L F
.5473 .97571 m .53746 .98349 L .54866 .98349 L 0 1 .506 r
F
.55125 .96258 m .54737 .98733 L .54826 .99771 L 0 1 .253 r
F
.55125 .96258 m .54866 .97227 L .54737 .98733 L F
.56026 .9721 m .54893 .97501 L .55524 .97308 L 0 0 0 r
F
.54951 .97384 m .54623 .97904 L .54866 .97228 L 0 1 .276 r
F
.54951 .97384 m .54559 .97836 L .54623 .97904 L F
.54951 .97384 m .547 .97614 L .54559 .97836 L F
.56026 .9721 m .54817 .97528 L .54893 .97501 L 0 0 0 r
F
.56026 .9721 m .55302 .97404 L .54817 .97528 L F
.54592 .96721 m .53652 .97547 L .5473 .97571 L 0 1 .492 r
F
.54771 .97574 m .54951 .97384 L .55083 .97293 L 0 .874 .208 r
F
.54771 .97574 m .547 .97614 L .54951 .97384 L F
.54771 .97574 m .55083 .97293 L .55007 .974 L F
.55763 .97274 m .54701 .97546 L .55302 .97404 L 0 .759 .219 r
F
.55763 .97274 m .54624 .97542 L .54701 .97546 L F
.55763 .97274 m .55079 .97426 L .54624 .97542 L F
.55497 .97301 m .55079 .97426 L .55763 .97274 L 0 .766 .232 r
F
.55497 .97301 m .54508 .97527 L .55079 .97426 L F
.55174 .97531 m .5507 .97838 L .55531 .98498 L 0 .077 .178 r
F
.55174 .97531 m .55067 .97397 L .55524 .97425 L 0 0 0 r
F
.55172 .9753 m .55067 .97397 L .55174 .97531 L F
.55101 .97504 m .55067 .97397 L .55173 .97531 L F
.55736 .95983 m .55318 .96474 L .55609 .968 L 0 .997 .471 r
F
.55736 .95983 m .55249 .96092 L .55318 .96474 L F
.55736 .95983 m .55429 .95882 L .55249 .96092 L F
.55541 .94962 m .55429 .95882 L .55736 .95983 L 0 .67 .41 r
F
.55541 .94962 m .55736 .95983 L .55906 .95777 L F
.55541 .94962 m .55906 .95777 L .55824 .95402 L F
.5635 .95619 m .55398 .96262 L .55503 .97286 L 0 1 .365 r
F
.55541 .94962 m .55146 .95443 L .55429 .95882 L 0 .67 .41 r
F
.55541 .94962 m .55077 .94959 L .55146 .95443 L F
.55541 .94962 m .55246 .94752 L .55077 .94959 L F
.5635 .95619 m .55391 .95127 L .55486 .94647 L 0 .249 .073 r
F
.56029 .95579 m .55391 .95127 L .5635 .95619 L F
.56789 .94755 m .56029 .95579 L .5635 .95619 L 0 1 .365 r
F
.56029 .95579 m .55398 .96262 L .5635 .95619 L F
.56801 .96127 m .56029 .95579 L .5635 .95619 L 0 .249 .073 r
F
.55125 .96258 m .55503 .97298 L .55398 .9629 L 0 1 .253 r
F
.56288 .97078 m .55008 .974 L .55083 .97292 L 0 0 0 r
F
.56288 .97078 m .55524 .97308 L .55008 .974 L F
.55497 .97301 m .5443 .9751 L .54508 .97527 L 0 .766 .232 r
F
.55497 .97301 m .54854 .97413 L .5443 .9751 L F
.54951 .97384 m .55125 .9626 L .55265 .96037 L 0 1 .276 r
F
.54951 .97384 m .54866 .97228 L .55125 .9626 L F
.54951 .97384 m .55265 .96037 L .55193 .96708 L F
.55763 .97274 m .55302 .97404 L .56026 .9721 L 0 .759 .219 r
F
.5523 .97311 m .54854 .97413 L .55497 .97301 L 0 .745 .234 r
F
.5523 .97311 m .54313 .9748 L .54854 .97413 L F
.5523 .97311 m .54235 .97458 L .54313 .9748 L F
.5523 .97311 m .54628 .97386 L .54235 .97458 L F
.55524 .97425 m .54824 .97361 L .54956 .97341 L 0 0 0 r
F
.55524 .97425 m .55067 .97397 L .54824 .97361 L F
.55114 .97368 m .55101 .97504 L .55174 .97531 L 0 .077 .178 r
F
.55101 .97504 m .5507 .97838 L .55174 .97533 L F
.55101 .97504 m .54838 .97406 L .5507 .97838 L F
.5473 .97571 m .52888 .98103 L .53746 .98349 L 0 1 .506 r
F
.5473 .97571 m .52864 .97774 L .52888 .98103 L F
.5473 .97571 m .53652 .97547 L .52864 .97774 L F
.54592 .96721 m .52827 .97259 L .53652 .97547 L 0 1 .492 r
F
.54771 .97574 m .54464 .97788 L .547 .97614 L 0 .874 .208 r
F
.54771 .97574 m .544 .97792 L .54464 .97788 L F
.54771 .97574 m .54532 .977 L .544 .97792 L F
.54589 .9761 m .54771 .97574 L .54893 .97501 L 0 .863 .231 r
F
.54589 .9761 m .54532 .977 L .54771 .97574 L F
.54589 .9761 m .54893 .97501 L .54816 .97528 L F
.54405 .97581 m .54589 .9761 L .54701 .97546 L 0 .846 .243 r
F
.54405 .97581 m .54701 .97546 L .54624 .97543 L F
.5495 .97317 m .54628 .97386 L .5523 .97311 L 0 .703 .23 r
F
.5495 .97317 m .54115 .97424 L .54628 .97386 L F
.5495 .97317 m .54033 .97401 L .54115 .97424 L F
.5495 .97317 m .5439 .97355 L .54033 .97401 L F
.54667 .97329 m .5439 .97355 L .5495 .97317 L 0 .644 .222 r
F
.53979 .97366 m .53827 .9735 L .5391 .97369 L F
.54667 .97329 m .54177 .97341 L .53979 .97366 L F
.53967 .97366 m .53909 .97327 L .53937 .97368 L 0 .22 .265 r
F
.53967 .97366 m .53826 .96986 L .53909 .97327 L F
.54177 .97341 m .54175 .97341 L .53979 .97366 L 0 .644 .222 r
F
.54175 .97341 m .53975 .97365 L .53979 .97366 L F
.54563 .97339 m .53979 .97366 L .5439 .97355 L F
.54667 .97329 m .54476 .97339 L .54563 .97339 L F
.54476 .97339 m .53979 .97366 L .54563 .97339 L F
.54175 .97341 m .53826 .96986 L .53967 .97366 L 0 .22 .265 r
F
.53763 .97403 m .53664 .97238 L .53584 .97328 L 0 .275 .303 r
F
.5384 .97392 m .53653 .97472 L .53846 .97482 L 0 .73 .242 r
F
.5384 .97434 m .53804 .97394 L .53763 .97403 L 0 .275 .303 r
F
.53804 .97394 m .53664 .97238 L .53763 .97403 L F
.53644 .97334 m .53665 .97402 L .53804 .97394 L 0 .669 .233 r
F
.54592 .96721 m .52802 .969 L .52827 .97259 L 0 1 .492 r
F
.54592 .96721 m .53559 .96669 L .52802 .969 L F
.54454 .95751 m .53559 .96669 L .54592 .96721 L 0 1 .474 r
F
.54454 .95751 m .52765 .96329 L .53559 .96669 L F
.53641 .96583 m .53664 .97238 L .53803 .97393 L 0 .255 .292 r
F
.53641 .96583 m .53803 .97393 L .53804 .97393 L F
.53641 .96583 m .53804 .97394 L .53829 .97389 L F
.53829 .97389 m .5384 .97392 L .53873 .97381 L 0 .669 .233 r
F
.53641 .96583 m .53829 .97389 L .53909 .97327 L 0 .255 .292 r
F
.53829 .97389 m .53873 .97381 L .53875 .9738 L 0 .669 .233 r
F
.5384 .97392 m .53846 .97482 L .54035 .97459 L 0 .73 .242 r
F
.53829 .97389 m .5384 .97434 L .53875 .9738 L 0 .255 .292 r
F
.53829 .97389 m .53875 .9738 L .53909 .97327 L F
.53829 .97389 m .53875 .9738 L .53909 .97369 L 0 .669 .233 r
F
.53644 .97334 m .53829 .97389 L .53909 .97369 L F
.53804 .97393 m .53803 .97393 L .53804 .97394 L 0 .255 .292 r
F
.53829 .97389 m .53804 .97394 L .5384 .97392 L 0 .669 .233 r
F
.53829 .97389 m .53804 .97394 L .5384 .97434 L 0 .255 .292 r
F
.53829 .97389 m .53804 .97394 L .53829 .97389 L 0 .669 .233 r
F
.53644 .97334 m .53804 .97394 L .53829 .97389 L F
.53979 .97366 m .53972 .97366 L .5439 .97355 L 0 .644 .222 r
F
.53967 .97366 m .53937 .97368 L .5439 .97355 L F
.54589 .9761 m .54304 .97782 L .54532 .977 L 0 .863 .231 r
F
.54589 .9761 m .5424 .97765 L .54304 .97782 L F
.54589 .9761 m .54362 .97692 L .5424 .97765 L F
.54405 .97581 m .54362 .97692 L .54589 .9761 L 0 .846 .243 r
F
.5422 .97525 m .54405 .97581 L .54508 .97527 L 0 .817 .248 r
F
.5422 .97525 m .54508 .97527 L .5443 .9751 L F
.54175 .97341 m .54151 .97207 L .53826 .96986 L 0 .22 .265 r
F
.54667 .97329 m .54253 .97332 L .54253 .97332 L 0 .644 .222 r
F
.54177 .97341 m .54253 .97332 L .54175 .97341 L F
.54667 .97329 m .54253 .97332 L .54177 .97341 L F
.54503 .97301 m .54263 .97344 L .54511 .97326 L 0 .197 .254 r
F
.5437 .96866 m .54266 .9733 L .54503 .97301 L F
.54266 .9733 m .54263 .97344 L .54503 .97301 L F
.5467 .97844 m .54253 .97332 L .54175 .97341 L 0 .22 .265 r
F
.54253 .97332 m .54151 .97207 L .54175 .97341 L F
.54175 .97341 m .54152 .97332 L .53827 .9735 L 0 .644 .222 r
F
.54253 .97332 m .54152 .97332 L .54175 .97341 L F
.54233 .9734 m .537 .97324 L .54152 .97332 L 0 .565 .208 r
F
.54372 .97352 m .54083 .9734 L .54233 .9734 L F
.54083 .9734 m .537 .97324 L .54233 .9734 L F
.53979 .97366 m .53967 .97366 L .53972 .97366 L 0 .644 .222 r
F
.54405 .97581 m .54143 .9773 L .54362 .97692 L 0 .846 .243 r
F
.54405 .97581 m .54079 .97701 L .54143 .9773 L F
.54405 .97581 m .54191 .97637 L .54079 .97701 L F
.5422 .97525 m .54191 .97637 L .54405 .97581 L 0 .817 .248 r
F
.5422 .97525 m .53982 .97652 L .54191 .97637 L F
.5422 .97525 m .53917 .97616 L .53982 .97652 L F
.5422 .97525 m .54019 .97562 L .53917 .97616 L F
.54035 .97459 m .54019 .97562 L .5422 .97525 L 0 .779 .247 r
F
.54035 .97459 m .5422 .97525 L .54313 .9748 L F
.54035 .97459 m .54313 .9748 L .54235 .97458 L F
.5384 .97392 m .54035 .97459 L .54115 .97424 L 0 .73 .242 r
F
.5384 .97392 m .54115 .97424 L .54033 .97401 L F
.5467 .97844 m .54175 .97341 L .53967 .97366 L 0 .22 .265 r
F
.54175 .97341 m .53827 .9735 L .53975 .97365 L 0 .644 .222 r
F
.5437 .96866 m .54151 .97207 L .54253 .97332 L 0 .197 .254 r
F
.54266 .97332 m .54253 .97332 L .54263 .97344 L F
.54372 .97352 m .54152 .97332 L .54253 .97332 L 0 .565 .208 r
F
.54614 .97348 m .54667 .97329 L .54956 .97341 L F
.54515 .97341 m .54264 .97331 L .54667 .97329 L F
.54511 .97328 m .54263 .97344 L .5467 .97844 L 0 .197 .254 r
F
.54511 .97326 m .54505 .97327 L .54511 .97328 L F
.54505 .97327 m .54263 .97344 L .54511 .97328 L F
.54672 .97358 m .54956 .97341 L .54824 .97361 L 0 .565 .208 r
F
.54515 .97341 m .5467 .97844 L .54612 .97347 L 0 .197 .254 r
F
.54515 .97341 m .54523 .9734 L .54614 .97348 L 0 .565 .208 r
F
.54523 .9734 m .54667 .97329 L .54614 .97348 L F
.54656 .97351 m .5496 .9803 L .54825 .97639 L 0 .197 .254 r
F
.5437 .96866 m .54614 .97348 L .54656 .97351 L F
.54667 .97358 m .54616 .97348 L .54672 .97358 L 0 .565 .208 r
F
.54614 .97348 m .54616 .97348 L .54667 .97358 L F
.54614 .97348 m .5496 .9803 L .54656 .97351 L 0 .197 .254 r
F
.54594 .97344 m .54612 .97347 L .54612 .97344 L F
.54515 .97341 m .54612 .97347 L .54594 .97344 L F
.54372 .97352 m .54614 .97348 L .54667 .97358 L 0 .565 .208 r
F
.54616 .97348 m .54956 .97341 L .54672 .97358 L F
.54372 .97352 m .54515 .97341 L .54614 .97348 L F
.54614 .97348 m .5467 .97844 L .5496 .9803 L 0 .197 .254 r
F
.54612 .97344 m .54612 .97347 L .54614 .97348 L F
.54612 .97347 m .5467 .97844 L .54614 .97348 L F
.5437 .96866 m .54515 .97341 L .54612 .97344 L F
.54515 .97341 m .54253 .97332 L .54264 .97331 L 0 .565 .208 r
F
.54372 .97352 m .54253 .97332 L .54515 .97341 L F
.54266 .9733 m .54253 .97332 L .54253 .97332 L 0 .197 .254 r
F
.54266 .9733 m .54253 .97332 L .54266 .97332 L F
.5437 .96866 m .54253 .97332 L .54266 .9733 L F
.53967 .97366 m .5391 .97369 L .53937 .97368 L 0 .644 .222 r
F
.53901 .98224 m .54623 .97905 L .54559 .97837 L 0 1 .458 r
F
.53901 .98224 m .54031 .98554 L .54623 .97905 L F
.53772 .98082 m .53901 .98224 L .54463 .97788 L 0 1 .492 r
F
.53772 .98082 m .54463 .97788 L .544 .97792 L F
.53642 .97944 m .53772 .98082 L .54304 .97782 L 0 1 .48 r
F
.53642 .97944 m .54304 .97782 L .5424 .97765 L F
.54035 .97459 m .53819 .97562 L .54019 .97562 L 0 .779 .247 r
F
.54035 .97459 m .53754 .97526 L .53819 .97562 L F
.54035 .97459 m .53846 .97482 L .53754 .97526 L F
.5467 .97844 m .53967 .97366 L .54394 .98057 L 0 .22 .265 r
F
.53967 .97366 m .53937 .97368 L .54394 .98057 L F
.55115 .97549 m .54626 .97394 L .54822 .97395 L 0 0 0 r
F
.55101 .97504 m .54832 .97395 L .55067 .97397 L F
.55114 .97368 m .54853 .97404 L .55101 .97504 L 0 .077 .178 r
F
.54853 .97404 m .54838 .97406 L .55101 .97504 L F
.55101 .97504 m .54822 .97395 L .54832 .97395 L 0 0 0 r
F
.55115 .97549 m .54822 .97395 L .55101 .97504 L F
.55101 .97504 m .55174 .97533 L .55174 .97531 L 0 .077 .178 r
F
.55173 .97531 m .55172 .9753 L .55174 .97531 L 0 0 0 r
F
.55115 .97549 m .55101 .97504 L .55173 .97531 L F
.5495 .97317 m .5523 .97311 L .55588 .97265 L 0 .703 .23 r
F
.5495 .97317 m .55588 .97265 L .55463 .97279 L F
.54667 .97329 m .5495 .97317 L .55275 .973 L 0 .644 .222 r
F
.54667 .97329 m .55275 .973 L .55149 .97315 L F
.55524 .97425 m .54956 .97341 L .5543 .97321 L 0 0 0 r
F
.55114 .97368 m .54624 .97007 L .54838 .97406 L 0 .077 .178 r
F
.55199 .97541 m .55524 .97425 L .55735 .97491 L 0 0 0 r
F
.55115 .97549 m .55174 .97531 L .55199 .97541 L F
.55754 .98561 m .55623 .98862 L .55944 .98788 L 0 1 .308 r
F
.5521 .97547 m .55743 .98655 L .55562 .98202 L 0 .077 .178 r
F
.55114 .97368 m .55199 .97541 L .5521 .97547 L F
.55212 .97549 m .55735 .97491 L .55558 .97551 L 0 0 0 r
F
.55115 .97549 m .55199 .97541 L .55212 .97549 L F
.55199 .97541 m .55735 .97491 L .55212 .97549 L F
.55199 .97541 m .55743 .98655 L .55211 .97549 L 0 .077 .178 r
F
.55199 .97541 m .55211 .97549 L .5521 .97547 L F
.55174 .97531 m .55177 .9753 L .55199 .97541 L 0 0 0 r
F
.55177 .9753 m .55524 .97425 L .55199 .97541 L F
.55199 .97541 m .55531 .98498 L .55743 .98655 L 0 .077 .178 r
F
.55114 .97368 m .55174 .97531 L .55199 .97541 L F
.55174 .97531 m .55531 .98498 L .55199 .97541 L F
.55596 .97678 m .5529 .97449 L .55381 .97644 L 0 0 .148 r
F
.55596 .97678 m .55381 .97644 L .5563 .97862 L F
.55596 .97678 m .5563 .97862 L .55681 .97903 L F
.55681 .97903 m .55722 .97648 L .56118 .97717 L 0 0 0 r
F
.56134 .99104 m .56324 .99476 L .56525 .99333 L 0 1 .5 r
F
.56134 .99104 m .56525 .99333 L .56445 .9918 L F
.55704 .97923 m .56118 .97717 L .5625 .97843 L 0 0 0 r
F
.55598 .97938 m .55681 .97903 L .55704 .97923 L F
.55718 .97939 m .5625 .97843 L .56029 .97943 L F
.55598 .97938 m .55704 .97923 L .55718 .97939 L F
.55704 .97923 m .5625 .97843 L .55718 .97939 L F
.55718 .97939 m .56261 .99186 L .56034 .98618 L 0 0 .148 r
F
.55716 .97935 m .55718 .97939 L .55718 .97939 L F
.55718 .97939 m .56261 .99186 L .55718 .97939 L F
.55631 .97861 m .55722 .97648 L .55681 .97903 L 0 0 0 r
F
.55596 .97678 m .55704 .97923 L .55716 .97935 L 0 0 .148 r
F
.55704 .97923 m .56261 .99186 L .55716 .97935 L F
.55681 .97903 m .55684 .97901 L .55704 .97923 L 0 0 0 r
F
.55684 .97901 m .56118 .97717 L .55704 .97923 L F
.55704 .97923 m .56128 .99085 L .56261 .99186 L 0 0 .148 r
F
.55703 .97921 m .55704 .97922 L .55704 .97923 L F
.55704 .97922 m .56128 .99085 L .55704 .97923 L F
.55596 .97678 m .55681 .97903 L .55703 .97921 L F
.55681 .97903 m .56128 .99085 L .55703 .97921 L F
.5563 .97862 m .55631 .97861 L .55681 .97903 L 0 0 0 r
F
.56189 .98547 m .56505 .9842 L .56241 .9855 L 0 .054 0 r
F
.56147 .98476 m .56513 .99463 L .56187 .98543 L 0 0 .125 r
F
.56147 .98476 m .56505 .9842 L .56189 .98547 L 0 .054 0 r
F
.5616 .98496 m .56187 .98543 L .56183 .98532 L 0 0 .125 r
F
.56147 .98476 m .56187 .98543 L .5616 .98496 L F
.56525 .98976 m .56381 .98877 L .56241 .9855 L 0 .125 .015 r
F
.56189 .98547 m .56513 .99463 L .56242 .98684 L 0 0 .125 r
F
.56188 .98545 m .56513 .99463 L .56189 .98547 L F
.56147 .98476 m .5646 .99489 L .56513 .99463 L F
.56146 .98474 m .56146 .98474 L .56147 .98476 L 0 .054 0 r
F
.56092 .984 m .5646 .99489 L .56147 .98476 L 0 0 .125 r
F
.56089 .98401 m .56092 .984 L .56143 .98477 L 0 .054 0 r
F
.56092 .984 m .5645 .98231 L .56147 .98474 L F
.56092 .984 m .56147 .98474 L .56143 .98477 L F
.56092 .984 m .56119 .98747 L .5646 .99489 L 0 0 .125 r
F
.56118 .97717 m .55558 .97551 L .55735 .97491 L 0 0 0 r
F
.56118 .97717 m .55722 .97648 L .55558 .97551 L F
.5618 .98523 m .56147 .98476 L .56183 .98532 L 0 0 .125 r
F
.56096 .98398 m .56115 .9811 L .5645 .98231 L 0 .054 0 r
F
.56093 .98392 m .56115 .9811 L .56096 .98398 L F
.55997 .98277 m .55998 .98275 L .56092 .984 L F
.55998 .98275 m .56115 .9811 L .56092 .984 L F
.56145 .98471 m .56092 .984 L .56147 .98476 L 0 0 .125 r
F
.56092 .984 m .56093 .98392 L .56096 .98398 L 0 .054 0 r
F
.55822 .98527 m .55697 .98087 L .55867 .98096 L F
.55997 .98277 m .55867 .98096 L .56115 .9811 L F
.55997 .98277 m .55867 .98096 L .55874 .98112 L 0 0 .125 r
F
.55997 .98277 m .55874 .98112 L .56119 .98747 L F
.55997 .98277 m .56119 .98747 L .56092 .984 L F
.56089 .98401 m .55997 .98277 L .56092 .984 L 0 .054 0 r
F
.55822 .98527 m .55997 .98277 L .56089 .98401 L F
.55822 .98527 m .55867 .98096 L .55997 .98277 L F
.55995 .9827 m .55865 .98089 L .55867 .98096 L 0 0 .125 r
F
.55995 .9827 m .55867 .98096 L .55997 .98277 L F
.55815 .97582 m .56092 .984 L .56145 .98471 L F
.56147 .98476 m .5645 .98231 L .56505 .9842 L 0 .054 0 r
F
.56146 .98474 m .5645 .98231 L .56147 .98476 L F
.55815 .97582 m .56145 .98471 L .5618 .98523 L 0 0 .125 r
F
.56145 .98471 m .56147 .98476 L .5618 .98523 L F
.55995 .9827 m .55997 .98277 L .56092 .984 L F
.55815 .97582 m .55995 .9827 L .56092 .984 L F
.56143 .98477 m .56146 .98474 L .56147 .98476 L 0 .054 0 r
F
.56529 .99423 m .56242 .98684 L .56513 .99463 L 0 0 .079 r
F
.56529 .99423 m .56309 .98828 L .56242 .98684 L F
.56309 .98828 m .56246 .98675 L .56244 .98642 L 0 .125 .015 r
F
.56309 .98828 m .56249 .98666 L .56246 .98675 L 0 0 .079 r
F
.56309 .98828 m .56246 .98675 L .56242 .98684 L F
.56381 .98877 m .56309 .98828 L .56244 .98642 L 0 .125 .015 r
F
.56309 .98828 m .5625 .98788 L .56246 .98675 L F
.56381 .98877 m .56244 .98642 L .56241 .9855 L F
.55822 .98527 m .56147 .98476 L .56189 .98547 L 0 .054 0 r
F
.56183 .98532 m .56188 .98545 L .56189 .98547 L 0 0 .125 r
F
.55822 .98527 m .56089 .98401 L .56143 .98477 L 0 .054 0 r
F
.55815 .97582 m .55694 .97647 L .55865 .98089 L 0 0 .125 r
F
.55815 .97582 m .55865 .98089 L .55995 .9827 L F
.56525 .98976 m .56241 .9855 L .56505 .9842 L 0 .125 .015 r
F
.56134 .99104 m .55599 .99299 L .55665 .99439 L 0 1 .5 r
F
.56134 .99104 m .558 .99156 L .55599 .99299 L F
.55944 .98788 m .558 .99156 L .56134 .99104 L 0 1 .447 r
F
.56134 .99104 m .55665 .99439 L .55976 .99515 L 0 1 .5 r
F
.55944 .98788 m .55499 .99112 L .558 .99156 L 0 1 .447 r
F
.55944 .98788 m .55433 .99001 L .55499 .99112 L F
.55944 .98788 m .55623 .98862 L .55433 .99001 L F
.55531 .98498 m .5544 .9881 L .55947 .9946 L 0 .09 .18 r
F
.56324 .99476 m .55831 .99821 L .56152 .99917 L 0 1 .522 r
F
.56324 .99476 m .55765 .99662 L .55831 .99821 L F
.56324 .99476 m .55976 .99515 L .55765 .99662 L F
.56134 .99104 m .55976 .99515 L .56324 .99476 L 0 1 .5 r
F
.55531 .98498 m .55947 .9946 L .56193 .99663 L 0 .09 .18 r
F
.55531 .98498 m .56193 .99663 L .56013 .99281 L F
.56128 .99085 m .55743 .98655 L .56212 .99514 L 0 0 .144 r
F
.56128 .99085 m .55562 .98202 L .55743 .98655 L F
.56128 .99085 m .55727 .98386 L .55562 .98202 L F
.5646 .99489 m .56034 .98618 L .56261 .99186 L 0 0 .104 r
F
.5646 .99489 m .56119 .98747 L .56034 .98618 L F
.56418 .99018 m .56309 .98828 L .56529 .99423 L 0 0 .121 r
F
.56356 .98911 m .56308 .98828 L .56309 .98828 L 0 .197 .023 r
F
.56356 .98911 m .56309 .98828 L .56394 .98887 L F
.56356 .98911 m .56309 .98828 L .56356 .98911 L F
.56029 .95579 m .55762 .95546 L .55391 .95127 L 0 .249 .073 r
F
.56789 .94755 m .55949 .95178 L .55762 .95546 L 0 1 .365 r
F
.56029 .95579 m .55762 .95546 L .55398 .96262 L F
.56789 .94755 m .55762 .95546 L .56029 .95579 L F
.56801 .96127 m .55953 .95762 L .55762 .95546 L 0 .249 .073 r
F
.56801 .96127 m .55762 .95546 L .56029 .95579 L F
.56547 .9683 m .55194 .96699 L .55265 .96017 L 0 .223 .103 r
F
.56547 .9683 m .55743 .97049 L .55194 .96699 L F
.56288 .97078 m .55743 .97049 L .56547 .9683 L 0 0 0 r
F
.56288 .97078 m .55083 .97292 L .55743 .97049 L F
.56026 .9721 m .55524 .97308 L .56288 .97078 L F
.55763 .97274 m .56026 .9721 L .56482 .97094 L 0 .759 .219 r
F
.55763 .97274 m .56482 .97094 L .56364 .97132 L F
.55497 .97301 m .55763 .97274 L .56187 .97177 L 0 .766 .232 r
F
.55497 .97301 m .56187 .97177 L .56069 .972 L F
.56705 .97133 m .55891 .97229 L .56448 .97147 L 0 0 0 r
F
.56705 .97133 m .55771 .97244 L .55891 .97229 L F
.56705 .97133 m .5612 .97203 L .55771 .97244 L F
.5523 .97311 m .55497 .97301 L .55891 .97229 L 0 .745 .234 r
F
.5523 .97311 m .55891 .97229 L .55771 .97244 L F
.56319 .97219 m .55588 .97265 L .5612 .97203 L 0 0 0 r
F
.56319 .97219 m .55463 .97279 L .55588 .97265 L F
.56319 .97219 m .55776 .97259 L .55463 .97279 L F
.55931 .97314 m .55776 .97259 L .56319 .97219 L F
.55931 .97314 m .55275 .973 L .55776 .97259 L F
.55931 .97314 m .56319 .97219 L .56601 .97225 L F
.55931 .97314 m .55149 .97315 L .55275 .973 L F
.55931 .97314 m .5543 .97321 L .55149 .97315 L F
.55931 .97314 m .56601 .97225 L .56433 .97273 L F
.55524 .97425 m .5543 .97321 L .55931 .97314 L F
.55524 .97425 m .55931 .97314 L .56175 .9735 L F
.55524 .97425 m .56175 .9735 L .55999 .97405 L F
.56118 .97717 m .55735 .97491 L .56196 .97469 L F
.5645 .98231 m .56029 .97943 L .5625 .97843 L F
.5645 .98231 m .56115 .9811 L .56029 .97943 L F
.55776 .96663 m .56249 .98666 L .56309 .98828 L 0 0 .121 r
F
.56512 .99888 m .55997 1.0024 L .56327 1.00351 L 0 1 .531 r
F
.56512 .99888 m .55931 1.00068 L .55997 1.0024 L F
.56512 .99888 m .56152 .99917 L .55931 1.00068 L F
.56324 .99476 m .56152 .99917 L .56512 .99888 L 0 1 .522 r
F
.56128 .99085 m .56212 .99514 L .56658 1.0021 L 0 0 .144 r
F
.56128 .99085 m .56658 1.0021 L .56825 1.00397 L F
.56128 .99085 m .56825 1.00397 L .56599 .99949 L F
.55794 .99266 m .56394 .98887 L .56444 .99008 L 0 .197 .023 r
F
.55776 .96663 m .56309 .98828 L .56418 .99018 L 0 0 .121 r
F
.56444 .99008 m .56394 .98887 L .56525 .98976 L 0 .197 .023 r
F
.56418 .99018 m .56529 .99423 L .56508 .99177 L 0 0 .121 r
F
.5646 .99489 m .56261 .99186 L .56717 1.0018 L 0 0 .104 r
F
.55794 .99266 m .56418 .99018 L .56505 .99211 L 0 .197 .023 r
F
.56418 .99018 m .56525 .98976 L .56508 .99177 L F
.56418 .99018 m .56508 .99177 L .56505 .99211 L F
.56418 .99018 m .56508 .99177 L .56507 .99171 L 0 0 .121 r
F
.55776 .96663 m .56418 .99018 L .56504 .99136 L F
.56418 .99018 m .56507 .99171 L .56504 .99136 L F
.55794 .99266 m .5625 .98788 L .56308 .98828 L 0 .197 .023 r
F
.55794 .99266 m .56308 .98828 L .56356 .98911 L F
.56341 .98347 m .56504 .99136 L .56523 .99201 L 0 0 .086 r
F
.56717 .99717 m .56922 .99287 L .57177 .99514 L 0 .247 .049 r
F
.56613 .99447 m .56536 .99246 L .56728 .9991 L 0 0 .086 r
F
.56657 .99562 m .56728 .9991 L .56773 1.00005 L F
.56657 .99562 m .56527 .99215 L .56531 .99215 L 0 .247 .049 r
F
.56657 .99562 m .56531 .99215 L .56922 .99287 L F
.57004 1.00541 m .5754 .99893 L .5777 1.00173 L 0 .286 .069 r
F
.56661 .9978 m .57286 1.01475 L .56974 1.00628 L 0 0 .079 r
F
.56529 .99423 m .56647 .99744 L .56661 .9978 L F
.56647 .99744 m .57286 1.01475 L .56661 .9978 L F
.56773 1.00005 m .56728 .9991 L .56791 1.00129 L 0 0 .086 r
F
.56529 .99423 m .57278 1.0149 L .57286 1.01475 L 0 0 .079 r
F
.56838 1.00256 m .56791 1.00129 L .56934 1.00626 L 0 0 .086 r
F
.56773 1.00005 m .56791 1.00129 L .56838 1.00256 L F
.57195 1.01473 m .56934 1.00626 L .56974 1.00628 L 0 .451 0 r
F
.5677 .99918 m .56934 1.00626 L .57195 1.01473 L 0 0 .086 r
F
.56731 .99774 m .56764 .99914 L .5677 .99918 L F
.56764 .99914 m .56934 1.00626 L .5677 .99918 L F
.56983 1.00482 m .5754 .99893 L .57004 1.00541 L 0 .286 .069 r
F
.57115 1.01693 m .56814 1.01812 L .5749 1.02357 L 0 .281 .285 r
F
.57195 1.01473 m .56974 1.00628 L .57286 1.01475 L 0 .451 0 r
F
.56657 .99562 m .56922 .99287 L .56717 .99717 L 0 .247 .049 r
F
.5676 .99836 m .57177 .99514 L .57113 .998 L F
.56719 .99731 m .56726 .99762 L .56731 .99774 L 0 0 .086 r
F
.56726 .99762 m .56934 1.00626 L .56731 .99774 L F
.56657 .99562 m .56934 1.00626 L .56719 .99731 L F
.56611 .99439 m .56728 .9991 L .56657 .99562 L F
.56658 1.0021 m .56193 .99663 L .56694 1.00454 L 0 0 .145 r
F
.56658 1.0021 m .56013 .99281 L .56193 .99663 L F
.56658 1.0021 m .56212 .99514 L .56013 .99281 L F
.56987 1.00478 m .57113 .998 L .5754 .99893 L 0 .286 .069 r
F
.56771 .99877 m .57195 1.01473 L .57125 1.01136 L 0 0 .086 r
F
.56767 .99863 m .56771 .99875 L .56771 .99877 L F
.56771 .99875 m .57195 1.01473 L .56771 .99877 L F
.57028 1.00591 m .5777 1.00173 L .57664 1.00521 L 0 .286 .069 r
F
.56766 .99859 m .57195 1.01473 L .56767 .99863 L 0 0 .086 r
F
.56715 .99718 m .57195 1.01473 L .5676 .99836 L F
.5676 .99836 m .57113 .998 L .568 .99942 L 0 .247 .049 r
F
.56765 .99849 m .56766 .99852 L .56796 .99926 L 0 0 .086 r
F
.56766 .99852 m .57125 1.01136 L .568 .99942 L F
.56766 .99852 m .568 .99942 L .56796 .99926 L F
.56353 .99878 m .5676 .99836 L .56773 .99954 L 0 .247 .049 r
F
.5676 .99836 m .56766 .99859 L .56767 .99863 L 0 0 .086 r
F
.56715 .99718 m .57177 .99514 L .5676 .99836 L 0 .247 .049 r
F
.56446 .98717 m .56757 .99825 L .56454 .98737 L 0 0 .086 r
F
.56757 .99825 m .57125 1.01136 L .56763 .9984 L F
.56757 .99825 m .56763 .9984 L .56454 .98737 L F
.56357 .98403 m .56603 .99278 L .56359 .98409 L F
.56603 .99278 m .57125 1.01136 L .56604 .99279 L F
.56603 .99278 m .56604 .99279 L .56359 .98409 L F
.56947 1.00337 m .568 .99942 L .57113 .998 L 0 .286 .069 r
F
.57009 1.00539 m .5777 1.00173 L .57028 1.00591 L F
.56942 1.00352 m .57113 .998 L .56987 1.00478 L F
.57288 1.01724 m .57744 1.02813 L .58043 1.03752 L 0 .451 0 r
F
.57195 1.01473 m .57275 1.0167 L .57288 1.01724 L F
.57275 1.0167 m .57744 1.02813 L .57288 1.01724 L F
.56862 1.00609 m .568 .99942 L .56827 1.00044 L 0 .286 .069 r
F
.56859 1.00183 m .56772 .99838 L .568 .99942 L 0 .418 0 r
F
.56923 1.00413 m .56808 .99971 L .57125 1.01136 L F
.5695 1.00517 m .56942 1.00352 L .56987 1.00478 L 0 .286 .069 r
F
.57303 1.01791 m .58005 1.03754 L .57654 1.02815 L 0 .451 0 r
F
.57195 1.01473 m .57295 1.01756 L .57303 1.01791 L F
.57295 1.01756 m .58005 1.03754 L .57303 1.01791 L F
.57583 1.02975 m .57806 1.03803 L .57692 1.03394 L 0 .418 0 r
F
.56948 1.00519 m .56923 1.00413 L .56949 1.00518 L 0 .286 .069 r
F
.5749 1.02357 m .56521 1.01938 L .57148 1.02534 L 0 .345 .339 r
F
.5749 1.02357 m .564 1.01634 L .56521 1.01938 L F
.5749 1.02357 m .56814 1.01812 L .564 1.01634 L F
.57507 1.0268 m .57524 1.02725 L .57583 1.02975 L 0 .418 0 r
F
.57288 1.01836 m .57468 1.0251 L .57507 1.0268 L F
.57068 1.00988 m .57281 1.01801 L .57288 1.01836 L F
.57281 1.01801 m .57468 1.0251 L .57288 1.01836 L F
.5735 1.02069 m .57688 1.0338 L .5735 1.02069 L F
.57688 1.0338 m .57692 1.03394 L .57688 1.0338 L F
.57688 1.0338 m .57688 1.0338 L .5735 1.02069 L F
.57287 1.01833 m .57692 1.03394 L .57285 1.01816 L F
.57285 1.01816 m .5735 1.02069 L .57302 1.01881 L F
.5735 1.02069 m .5735 1.02069 L .57302 1.01881 L F
.56968 1.00602 m .5706 1.00954 L .57068 1.00988 L F
.56968 1.00602 m .57068 1.00988 L .56977 1.00634 L F
.57188 1.01452 m .57692 1.03394 L .5719 1.01457 L F
.57385 1.02402 m .57302 1.01881 L .57692 1.03394 L 0 .511 0 r
F
.57195 1.01473 m .57287 1.01722 L .57295 1.01756 L 0 .451 0 r
F
.5706 1.00954 m .57468 1.0251 L .57068 1.00988 L 0 .418 0 r
F
.56959 1.00567 m .56972 1.00616 L .56968 1.00602 L F
.56972 1.00616 m .57524 1.02725 L .56982 1.00658 L F
.56972 1.00616 m .56982 1.00658 L .56968 1.00602 L F
.56992 1.00693 m .57287 1.01833 L .57285 1.01816 L F
.56977 1.00634 m .56991 1.00689 L .56992 1.00693 L F
.56991 1.00689 m .57287 1.01833 L .56992 1.00693 L F
.5645 .98231 m .56698 .97827 L .57074 .97905 L 0 0 0 r
F
.5645 .98231 m .5625 .97843 L .56698 .97827 L F
.5645 .98231 m .57074 .97905 L .5716 .98072 L F
.5645 .98231 m .5716 .98072 L .56899 .98215 L F
.56525 .98976 m .56937 .98431 L .57251 .98576 L 0 .125 .015 r
F
.56525 .98976 m .56505 .9842 L .56937 .98431 L F
.56525 .98976 m .57251 .98576 L .57261 .98814 L F
.56525 .98976 m .57261 .98814 L .56959 .98987 L F
.56956 1.00545 m .57377 1.02101 L .57413 1.02256 L 0 .418 0 r
F
.56949 1.00518 m .56955 1.00542 L .56956 1.00545 L F
.56955 1.00542 m .57377 1.02101 L .56956 1.00545 L F
.57323 1.02201 m .57305 1.01937 L .57385 1.02402 L 0 .511 0 r
F
.56941 1.00489 m .56942 1.0049 L .56949 1.00518 L 0 .418 0 r
F
.56942 1.0049 m .57377 1.02101 L .56949 1.00518 L F
.56959 1.00563 m .56983 1.00482 L .57004 1.00541 L 0 .286 .069 r
F
.56958 1.00563 m .57568 1.02835 L .57806 1.03803 L 0 .418 0 r
F
.56945 1.00522 m .56923 1.00413 L .56948 1.00519 L 0 .286 .069 r
F
.56919 1.00427 m .56923 1.00413 L .56945 1.00522 L F
.56859 1.00183 m .56949 1.00518 L .56958 1.00563 L 0 .418 0 r
F
.56949 1.00518 m .57568 1.02835 L .56958 1.00563 L F
.56958 1.00563 m .56949 1.00518 L .56959 1.00563 L 0 .286 .069 r
F
.56862 1.00609 m .56949 1.00518 L .56958 1.00563 L F
.56949 1.00518 m .56983 1.00482 L .56959 1.00563 L F
.56942 1.00492 m .57125 1.01136 L .57377 1.02101 L 0 .418 0 r
F
.56923 1.00413 m .57125 1.01136 L .56942 1.00492 L F
.56977 1.00634 m .57664 1.00521 L .57291 1.00704 L 0 .286 .069 r
F
.56966 1.00598 m .57664 1.00521 L .56977 1.00634 L F
.57278 1.0149 m .57188 1.01074 L .57661 1.02147 L 0 .388 0 r
F
.57316 1.015 m .57142 1.01123 L .57291 1.00704 L 0 .316 .085 r
F
.57092 1.01148 m .57074 1.01081 L .57089 1.01091 L 0 .375 .08 r
F
.57102 1.01143 m .57089 1.01091 L .57142 1.01123 L F
.56923 1.00413 m .56824 1.00007 L .56947 1.00337 L 0 .286 .069 r
F
.56937 1.00601 m .57009 1.00539 L .57028 1.00591 L F
.56862 1.00609 m .56929 1.00577 L .56937 1.00601 L F
.56929 1.00577 m .57009 1.00539 L .56937 1.00601 L F
.56288 .97078 m .56547 .9683 L .57064 .96738 L 0 0 0 r
F
.56288 .97078 m .57064 .96738 L .56948 .96834 L F
.56026 .9721 m .56288 .97078 L .56774 .96954 L F
.56026 .9721 m .56774 .96954 L .56657 .97017 L F
.57073 .97054 m .56187 .97177 L .56774 .97079 L F
.57073 .97054 m .56069 .972 L .56187 .97177 L F
.57073 .97054 m .56448 .97147 L .56069 .972 L F
.56319 .97219 m .5612 .97203 L .56705 .97133 L F
.56319 .97219 m .56705 .97133 L .5702 .97113 L F
.56319 .97219 m .5702 .97113 L .56853 .97157 L F
.56635 .97498 m .56175 .9735 L .56668 .97302 L F
.56635 .97498 m .55999 .97405 L .56175 .9735 L F
.56635 .97498 m .56196 .97469 L .55999 .97405 L F
.56118 .97717 m .56196 .97469 L .56635 .97498 L F
.56118 .97717 m .56635 .97498 L .568 .97595 L F
.56118 .97717 m .568 .97595 L .56581 .97694 L F
.56287 .9668 m .56716 .99278 L .57066 1.00992 L 0 0 .111 r
F
.57071 1.01007 m .57066 1.00992 L .57086 1.01089 L F
.56287 .9668 m .57066 1.00992 L .57071 1.01007 L F
.57211 1.01504 m .57142 1.01123 L .57316 1.015 L 0 .375 .08 r
F
.57102 1.01143 m .57087 1.01091 L .57144 1.01371 L 0 0 .111 r
F
.57323 1.02201 m .57144 1.01371 L .57302 1.01881 L 0 .511 0 r
F
.57195 1.01521 m .57144 1.01371 L .57323 1.02201 L 0 0 .111 r
F
.57192 1.01505 m .57111 1.0118 L .57195 1.01521 L F
.57188 1.01452 m .5719 1.01457 L .57071 1.00999 L 0 .418 0 r
F
.57192 1.01505 m .57102 1.01143 L .57211 1.01504 L 0 .375 .08 r
F
.57068 1.00988 m .57188 1.01452 L .57071 1.00999 L 0 .418 0 r
F
.57102 1.01143 m .57142 1.01123 L .57211 1.01504 L 0 .375 .08 r
F
.56914 1.00022 m .57111 1.01179 L .57192 1.01505 L 0 0 .111 r
F
.57111 1.01179 m .57111 1.0118 L .57192 1.01505 L F
.57111 1.0118 m .57144 1.01371 L .57195 1.01521 L F
.57115 1.01693 m .56218 1.01187 L .56814 1.01812 L 0 .281 .285 r
F
.57115 1.01693 m .56096 1.00896 L .56218 1.01187 L F
.57115 1.01693 m .5648 1.01112 L .56096 1.00896 L F
.56738 1.01018 m .5648 1.01112 L .57115 1.01693 L 0 .22 .24 r
F
.56343 1.00274 m .56738 1.01018 L .57057 1.01258 L 0 .165 .208 r
F
.56343 1.00274 m .57057 1.01258 L .56886 1.00968 L F
.56325 1.01538 m .57102 1.01143 L .57192 1.01505 L 0 .375 .08 r
F
.57102 1.01143 m .57086 1.01089 L .57087 1.01091 L 0 0 .111 r
F
.5709 1.01101 m .57089 1.01091 L .57102 1.01143 L 0 .375 .08 r
F
.56287 .9668 m .57086 1.01089 L .57102 1.01143 L 0 0 .111 r
F
.57092 1.01148 m .5709 1.01101 L .57102 1.01143 L 0 .375 .08 r
F
.56325 1.01538 m .57192 1.01505 L .57144 1.01788 L F
.57192 1.01505 m .57316 1.015 L .57231 1.01643 L F
.57205 1.01551 m .57208 1.01567 L .57206 1.01555 L 0 0 .111 r
F
.56827 .9956 m .57323 1.02201 L .56849 .99587 L F
.57192 1.01505 m .57231 1.01643 L .57144 1.01788 L 0 .375 .08 r
F
.56849 .99587 m .57205 1.01551 L .57137 1.01078 L 0 0 .111 r
F
.57205 1.01551 m .57206 1.01555 L .57137 1.01078 L F
.57208 1.01567 m .57323 1.02201 L .57233 1.01658 L F
.57208 1.01567 m .57233 1.01658 L .57137 1.01078 L F
.5514 1.00358 m .55273 1.00806 L .56161 1.00685 L 0 1 .53 r
F
.5514 1.00358 m .56161 1.00685 L .56095 1.00504 L F
.56738 1.01018 m .55914 1.0046 L .5648 1.01112 L 0 .22 .24 r
F
.55007 .99936 m .5514 1.00358 L .55996 1.0024 L 0 1 .521 r
F
.55007 .99936 m .55996 1.0024 L .5593 1.00068 L F
.56738 1.01018 m .55792 1.0017 L .55914 1.0046 L 0 .22 .24 r
F
.56738 1.01018 m .56145 1.00408 L .55792 1.0017 L F
.56343 1.00274 m .56144 1.00408 L .56738 1.01018 L 0 .165 .208 r
F
.56325 1.01538 m .56729 1.00867 L .57074 1.01081 L 0 .375 .08 r
F
.56325 1.01538 m .57074 1.01081 L .57092 1.01148 L F
.56059 1.01695 m .56331 1.02523 L .56824 1.02744 L 0 .401 .377 r
F
.56059 1.01695 m .56824 1.02744 L .56703 1.02414 L F
.56652 1.02518 m .57144 1.01788 L .57286 1.01906 L 0 .435 .092 r
F
.57305 1.01937 m .57302 1.01881 L .57385 1.02402 L 0 .511 0 r
F
.57295 1.01756 m .58043 1.03752 L .58005 1.03754 L 0 .451 0 r
F
.57287 1.01722 m .58043 1.03752 L .57295 1.01756 L F
.57413 1.02256 m .57377 1.02101 L .57568 1.02835 L 0 .418 0 r
F
.57357 1.02219 m .57286 1.01906 L .5756 1.02133 L 0 .435 .092 r
F
.57312 1.02023 m .57299 1.01976 L .57355 1.0221 L 0 0 .101 r
F
.56758 1.07165 m .56146 1.07192 L .56212 1.07378 L 0 1 .509 r
F
.58071 1.07107 m .5639 1.07222 L .57263 1.07274 L 0 .708 .241 r
F
.58071 1.07107 m .5631 1.07186 L .5639 1.07222 L F
.56568 1.06706 m .56379 1.071 L .56758 1.07165 L 0 1 .504 r
F
.56568 1.06706 m .56758 1.07165 L .56982 1.07079 L F
.58071 1.07107 m .5703 1.07137 L .5631 1.07186 L 0 .708 .241 r
F
.57794 1.0691 m .5703 1.07137 L .58071 1.07107 L 0 .694 .212 r
F
.57388 1.08254 m .58263 1.09992 L .58285 1.10766 L 0 .67 .126 r
F
.58606 1.13587 m .58606 1.13585 L .58366 1.10805 L 0 0 .114 r
F
.58169 1.0908 m .58226 1.09141 L .58263 1.09992 L 0 .67 .126 r
F
.58188 1.08664 m .58458 1.11242 L .58195 1.08758 L 0 0 .105 r
F
.58458 1.11242 m .58458 1.11242 L .58195 1.08758 L F
.57894 1.0587 m .58043 1.07056 L .58035 1.0701 L 0 0 .097 r
F
.58226 1.09141 m .58294 1.09948 L .58263 1.09992 L 0 .67 .126 r
F
.58235 1.0928 m .58245 1.09386 L .58267 1.09654 L 0 0 .114 r
F
.57959 1.06359 m .58079 1.07329 L .57986 1.06591 L 0 0 .097 r
F
.58079 1.07329 m .58346 1.09474 L .58082 1.07363 L F
.56568 1.06706 m .56982 1.07079 L .56902 1.069 L 0 1 .504 r
F
.55179 1.06894 m .56212 1.07378 L .56145 1.07192 L 0 1 .528 r
F
.56758 1.07165 m .56379 1.071 L .56146 1.07192 L 0 1 .509 r
F
.56568 1.06706 m .56045 1.06907 L .56379 1.071 L 0 1 .504 r
F
.57276 1.06808 m .55989 1.07189 L .56796 1.0705 L 0 0 0 r
F
.57515 1.06688 m .57139 1.06811 L .57276 1.06808 L F
.57139 1.06811 m .55989 1.07189 L .57276 1.06808 L F
.55179 1.06894 m .55314 1.0738 L .56212 1.07378 L 0 1 .528 r
F
.57794 1.0691 m .56109 1.07156 L .5619 1.07158 L 0 .694 .212 r
F
.57794 1.0691 m .56796 1.0705 L .56109 1.07156 L F
.57515 1.06688 m .55908 1.07234 L .55989 1.07189 L 0 0 0 r
F
.57515 1.06688 m .56562 1.07019 L .55908 1.07234 L F
.56751 1.06819 m .55787 1.07272 L .56562 1.07019 L 0 .912 .211 r
F
.56376 1.06228 m .56568 1.06706 L .56782 1.06625 L 0 1 .496 r
F
.56376 1.06228 m .56782 1.06625 L .56701 1.06439 L F
.57233 1.06308 m .56457 1.06825 L .56751 1.06819 L 0 .912 .211 r
F
.56457 1.06825 m .55787 1.07272 L .56751 1.06819 L F
.57233 1.06308 m .56562 1.07019 L .57515 1.06688 L F
.56877 1.04902 m .57233 1.06308 L .57795 1.05581 L 0 .968 .385 r
F
.57295 1.06551 m .57553 1.05684 L .57901 1.05931 L 0 .601 .12 r
F
.58079 1.07329 m .58082 1.07363 L .57888 1.05819 L 0 0 .097 r
F
.58079 1.07329 m .57888 1.05819 L .57888 1.05818 L F
.58079 1.07329 m .57887 1.05809 L .57885 1.0579 L F
.57839 1.0538 m .58245 1.08411 L .57844 1.05434 L F
.56877 1.04902 m .57795 1.05581 L .57638 1.05167 L 0 .968 .385 r
F
.57802 1.05409 m .57792 1.04986 L .57844 1.05434 L 0 .545 .109 r
F
.57719 1.04989 m .57792 1.04986 L .57802 1.05409 L F
.57139 1.05011 m .57802 1.05409 L .57894 1.0587 L F
.57802 1.05409 m .57844 1.05434 L .57894 1.0587 L F
.57833 1.05344 m .57844 1.05434 L .5785 1.05493 L 0 0 .097 r
F
.57844 1.05434 m .57854 1.05519 L .57865 1.05634 L F
.57801 1.05072 m .57819 1.05228 L .57807 1.05136 L F
.57687 1.04148 m .5763 1.03839 L .5771 1.04354 L 0 0 .096 r
F
.57708 1.04294 m .5771 1.04354 L .57942 1.05862 L F
.57728 1.04425 m .57579 1.03541 L .57727 1.04019 L 0 .573 .021 r
F
.57579 1.03541 m .57575 1.03515 L .57727 1.04019 L F
.57728 1.04425 m .57727 1.04019 L .57755 1.04282 L F
.57768 1.0479 m .57886 1.0549 L .5793 1.05896 L 0 0 .096 r
F
.57579 1.03541 m .57573 1.03509 L .57575 1.03515 L 0 .573 .021 r
F
.57571 1.03489 m .57573 1.03509 L .57728 1.04425 L 0 0 .101 r
F
.57404 1.02516 m .57512 1.02844 L .57535 1.03019 L 0 .511 0 r
F
.57459 1.02727 m .58142 1.05361 L .58142 1.05363 L F
.57404 1.02516 m .57459 1.02727 L .57459 1.02727 L F
.57459 1.02727 m .58142 1.05361 L .57459 1.02727 L F
.57666 1.0403 m .57886 1.0549 L .57768 1.0479 L 0 0 .096 r
F
.57535 1.03019 m .57631 1.03248 L .57653 1.03475 L 0 .511 0 r
F
.57512 1.02844 m .57692 1.03394 L .57535 1.03019 L F
.57385 1.02402 m .57692 1.03394 L .57404 1.02516 L F
.57638 1.03818 m .5763 1.03839 L .57687 1.04148 L 0 0 .096 r
F
.5772 1.03939 m .57853 1.04507 L .57775 1.04178 L 0 .511 0 r
F
.57853 1.04507 m .57854 1.04513 L .57775 1.04178 L F
.57727 1.03949 m .58152 1.05783 L .5772 1.03939 L F
.58152 1.05783 m .582 1.05988 L .58152 1.05784 L F
.58152 1.05783 m .58152 1.05784 L .5772 1.03939 L F
.57687 1.04148 m .5771 1.04354 L .57708 1.04294 L 0 0 .096 r
F
.57634 1.03791 m .57942 1.05862 L .57666 1.0403 L F
.58071 1.06863 m .57942 1.05862 L .58187 1.06782 L 0 .61 .042 r
F
.57937 1.05919 m .57951 1.05848 L .57959 1.05943 L 0 .545 .109 r
F
.57808 1.04996 m .57814 1.05044 L .57816 1.05059 L 0 0 .097 r
F
.5789 1.05835 m .58043 1.07056 L .57894 1.0587 L F
.57894 1.0587 m .57896 1.05882 L .57894 1.05871 L F
.57873 1.05664 m .58245 1.08411 L .58346 1.09474 L F
.57844 1.05434 m .57869 1.05617 L .57873 1.05664 L F
.57869 1.05617 m .58245 1.08411 L .57873 1.05664 L F
.57794 1.0691 m .5619 1.07158 L .5703 1.07137 L 0 .694 .212 r
F
.57515 1.06688 m .56796 1.0705 L .57794 1.0691 L 0 0 0 r
F
.57295 1.06551 m .58064 1.07926 L .57701 1.07511 L 0 .601 .12 r
F
.58073 1.07514 m .58413 1.10494 L .58459 1.11242 L 0 0 .105 r
F
.58043 1.07056 m .58346 1.09474 L .58035 1.0701 L 0 0 .097 r
F
.58028 1.06853 m .58035 1.0701 L .58136 1.07873 L 0 0 .105 r
F
.58024 1.06823 m .58025 1.06828 L .58028 1.06853 L F
.58025 1.06828 m .58035 1.0701 L .58028 1.06853 L F
.57822 1.05245 m .58245 1.08411 L .57823 1.05255 L 0 0 .097 r
F
.57489 1.02929 m .57727 1.03949 L .5772 1.03939 L 0 .511 0 r
F
.57485 1.02903 m .57727 1.03949 L .57489 1.02929 L F
.57357 1.02348 m .57465 1.02816 L .57359 1.02359 L F
.57484 1.02897 m .57728 1.0395 L .57485 1.02903 L F
.57728 1.0395 m .582 1.05988 L .57727 1.03949 L F
.57728 1.0395 m .57727 1.03949 L .57485 1.02903 L F
.57632 1.0381 m .57666 1.0403 L .57671 1.04073 L 0 0 .096 r
F
.57484 1.02897 m .58359 1.06502 L .582 1.05988 L 0 .511 0 r
F
.57323 1.02201 m .57474 1.02828 L .57484 1.02897 L F
.57474 1.02828 m .58359 1.06502 L .57484 1.02897 L F
.57866 1.05482 m .57954 1.06176 L .57963 1.06244 L 0 0 .097 r
F
.5793 1.05896 m .57942 1.05862 L .58071 1.06863 L 0 0 .096 r
F
.57995 1.06343 m .58071 1.06863 L .57994 1.06332 L F
.57775 1.04835 m .57994 1.06332 L .57802 1.05011 L F
.57994 1.06332 m .58071 1.06863 L .57986 1.06277 L F
.57886 1.0549 m .57942 1.05862 L .5793 1.05896 L F
.57994 1.06332 m .57986 1.06277 L .57802 1.05011 L F
.57653 1.03475 m .57692 1.03394 L .58142 1.05361 L 0 .511 0 r
F
.57323 1.02201 m .58145 1.05374 L .58359 1.06502 L F
.57728 1.04425 m .57775 1.04178 L .582 1.05988 L 0 .573 .021 r
F
.57705 1.04235 m .57882 1.04096 L .57795 1.043 L 0 .491 .102 r
F
.57701 1.04232 m .57705 1.0423 L .57705 1.04235 L F
.57755 1.04282 m .57727 1.04019 L .57775 1.04178 L 0 .573 .021 r
F
.57705 1.0423 m .57882 1.04096 L .57705 1.04235 L 0 .491 .102 r
F
.58136 1.07873 m .58088 1.07457 L .58477 1.11056 L 0 0 .105 r
F
.58088 1.07457 m .58106 1.07654 L .58477 1.11056 L F
.58161 1.08099 m .58477 1.11056 L .58134 1.08051 L F
.58161 1.08099 m .58134 1.08051 L .58073 1.07514 L F
.58088 1.07457 m .58035 1.0701 L .58106 1.07654 L F
.58046 1.07029 m .58161 1.08099 L .58073 1.07514 L F
.58098 1.07988 m .5812 1.08026 L .581 1.08019 L 0 .601 .12 r
F
.58073 1.07514 m .58459 1.11242 L .58137 1.08173 L 0 0 .105 r
F
.58078 1.07574 m .58137 1.08173 L .58104 1.07857 L F
.58073 1.07514 m .58137 1.08173 L .58078 1.07574 L F
.58362 1.10444 m .58195 1.08758 L .58631 1.135 L 0 0 .114 r
F
.58459 1.11242 m .58459 1.11242 L .58104 1.07857 L 0 0 .105 r
F
.58104 1.07857 m .58104 1.07857 L .58103 1.07849 L F
.58459 1.11242 m .58104 1.07857 L .58104 1.07857 L F
.58101 1.07828 m .58459 1.11242 L .58112 1.07937 L F
.58459 1.11242 m .58548 1.12101 L .58458 1.11242 L F
.58459 1.11242 m .58458 1.11242 L .58112 1.07937 L F
.58305 1.10075 m .58611 1.13642 L .58365 1.10791 L 0 0 .114 r
F
.58611 1.13642 m .58669 1.14318 L .58606 1.13587 L F
.58611 1.13642 m .58606 1.13587 L .58365 1.10791 L F
.5854 1.12859 m .58483 1.1219 L .58697 1.15012 L 0 0 .123 r
F
.58483 1.1219 m .58473 1.12087 L .58697 1.15012 L F
.58462 1.11944 m .58449 1.11814 L .58697 1.15012 L F
.58683 1.14817 m .58684 1.14835 L .58541 1.12902 L F
.58683 1.14817 m .58541 1.12902 L .58541 1.129 L F
.58606 1.13587 m .58366 1.10805 L .58366 1.10805 L 0 0 .114 r
F
.58294 1.09948 m .58297 1.09944 L .58305 1.10075 L 0 .67 .126 r
F
.58303 1.10047 m .58631 1.135 L .58305 1.10075 L 0 0 .114 r
F
.58286 1.09819 m .58631 1.135 L .58296 1.09972 L F
.58249 1.09165 m .58195 1.08758 L .58362 1.10444 L F
.58229 1.08287 m .58245 1.08411 L .58227 1.08283 L 0 0 .097 r
F
.58229 1.08287 m .58227 1.08283 L .57818 1.05216 L F
.57768 1.0479 m .57995 1.06343 L .57773 1.04827 L 0 0 .096 r
F
.57853 1.04507 m .582 1.05988 L .57854 1.04513 L 0 .511 0 r
F
.57728 1.04425 m .58442 1.08004 L .58187 1.06782 L 0 .573 .021 r
F
.58442 1.08004 m .58644 1.09017 L .58436 1.07999 L F
.58442 1.08004 m .58436 1.07999 L .58187 1.06782 L F
.5812 1.08026 m .58099 1.07462 L .58177 1.08128 L 0 .601 .12 r
F
.58131 1.08046 m .58189 1.08149 L .58135 1.08079 L F
.58119 1.0802 m .58188 1.08664 L .58195 1.08758 L 0 0 .105 r
F
.58098 1.07988 m .58098 1.07896 L .5812 1.08026 L 0 .601 .12 r
F
.58098 1.07896 m .58099 1.07799 L .5812 1.08026 L F
.58067 1.07514 m .58111 1.07934 L .58119 1.0802 L 0 0 .105 r
F
.57728 1.04425 m .58847 1.09692 L .58644 1.09017 L 0 .573 .021 r
F
.57728 1.04425 m .5866 1.08352 L .58847 1.09692 L F
.57728 1.04425 m .582 1.05988 L .5866 1.08352 L F
.57807 1.04985 m .57795 1.043 L .58034 1.04687 L 0 .545 .109 r
F
.57807 1.04985 m .58034 1.04687 L .58045 1.04976 L F
.57762 1.04667 m .57863 1.05461 L .57866 1.05482 L 0 0 .097 r
F
.57762 1.04666 m .57863 1.05461 L .57762 1.04667 L F
.57761 1.04652 m .57863 1.05461 L .57761 1.04654 L F
.57751 1.04578 m .57863 1.05461 L .57754 1.04602 L F
.57806 1.03803 m .58664 1.06396 L .58276 1.0533 L 0 .539 .024 r
F
.57806 1.03803 m .58748 1.06372 L .58664 1.06396 L F
.57649 1.03867 m .5801 1.03967 L .57701 1.04232 L 0 .491 .102 r
F
.5801 1.03967 m .58041 1.03975 L .58011 1.03998 L F
.5801 1.03967 m .58011 1.03998 L .57701 1.04232 L F
.58103 1.07504 m .58101 1.07669 L .5817 1.0827 L 0 0 .114 r
F
.58104 1.07531 m .58124 1.07737 L .58122 1.07735 L F
.57807 1.04985 m .58208 1.0497 L .57866 1.05406 L 0 .545 .109 r
F
.57725 1.044 m .57802 1.05011 L .57813 1.05094 L 0 0 .097 r
F
.57632 1.03866 m .57671 1.04073 L .57768 1.0479 L 0 0 .096 r
F
.57359 1.02359 m .57485 1.02903 L .57489 1.02929 L 0 .511 0 r
F
.57722 1.04379 m .57795 1.043 L .57807 1.04985 L 0 .545 .109 r
F
.57567 1.03462 m .57728 1.04425 L .5753 1.03204 L 0 0 .101 r
F
.57622 1.03777 m .57671 1.04073 L .57632 1.03866 L 0 0 .096 r
F
.57418 1.02577 m .57449 1.02478 L .57464 1.02581 L 0 .435 .092 r
F
.57345 1.02224 m .57408 1.02197 L .57418 1.02577 L F
.57408 1.02197 m .5756 1.02133 L .57449 1.02478 L F
.57408 1.02197 m .57449 1.02478 L .57418 1.02577 L F
.57687 1.04102 m .57696 1.0417 L .57697 1.04177 L 0 0 .097 r
F
.57464 1.02581 m .5756 1.02133 L .57624 1.02333 L 0 .435 .092 r
F
.57639 1.02594 m .57624 1.02333 L .5771 1.026 L F
.57464 1.02581 m .57624 1.02333 L .57639 1.02594 L F
.57686 1.04221 m .57802 1.05011 L .57697 1.04267 L 0 0 .096 r
F
.5772 1.04365 m .57697 1.04267 L .57802 1.05011 L 0 0 .097 r
F
.57638 1.03904 m .57768 1.0479 L .57641 1.03926 L 0 0 .096 r
F
.57596 1.03601 m .5763 1.03839 L .57638 1.03818 L F
.57863 1.05461 m .57954 1.06176 L .57866 1.05482 L 0 0 .097 r
F
.57995 1.06343 m .57994 1.06332 L .57776 1.04845 L 0 0 .096 r
F
.57995 1.06343 m .57776 1.04845 L .57776 1.04844 L F
.57995 1.06343 m .57775 1.04835 L .57773 1.04827 L F
.57814 1.05044 m .57843 1.05274 L .57816 1.05059 L 0 0 .097 r
F
.57843 1.05274 m .57963 1.06244 L .57844 1.05281 L F
.57843 1.05274 m .57844 1.05281 L .57816 1.05059 L F
.57849 1.05315 m .57999 1.06505 L .57975 1.06303 L F
.57816 1.05059 m .57847 1.05302 L .57849 1.05315 L F
.57847 1.05302 m .57999 1.06505 L .57849 1.05315 L F
.57847 1.05302 m .57963 1.06244 L .57999 1.06505 L F
.57816 1.05059 m .57844 1.05281 L .57847 1.05302 L F
.57844 1.05281 m .57963 1.06244 L .57847 1.05302 L F
.57975 1.06303 m .57999 1.06505 L .58026 1.06699 L F
.57807 1.04985 m .57808 1.04994 L .57808 1.04996 L F
.57808 1.04994 m .57963 1.06244 L .57808 1.04996 L F
.57805 1.04972 m .57806 1.0498 L .57807 1.04985 L F
.57806 1.0498 m .57963 1.06244 L .57808 1.04994 L F
.57806 1.0498 m .57808 1.04994 L .57807 1.04985 L F
.5775 1.04574 m .57813 1.05094 L .57836 1.05252 L F
.57581 1.03388 m .57516 1.02931 L .57552 1.02972 L 0 .491 .102 r
F
.57588 1.03482 m .57552 1.02972 L .57613 1.03475 L F
.57487 1.02907 m .57508 1.02879 L .575 1.02914 L 0 .435 .092 r
F
.57797 1.04921 m .57963 1.06244 L .578 1.0493 L 0 0 .097 r
F
.57963 1.06244 m .57974 1.06329 L .57985 1.06411 L F
.57963 1.06244 m .57985 1.06411 L .58026 1.06699 L F
.57836 1.05252 m .57813 1.05094 L .57954 1.06176 L F
.57963 1.06244 m .57954 1.06176 L .57974 1.06329 L F
.58026 1.06699 m .57974 1.06329 L .58245 1.08411 L F
.57808 1.04996 m .58229 1.08287 L .57839 1.05373 L F
.58071 1.06863 m .58187 1.06782 L .58644 1.09017 L 0 .61 .042 r
F
.58071 1.06863 m .58755 1.10996 L .58533 1.09745 L F
.58755 1.10996 m .59021 1.12603 L .58756 1.11054 L F
.58755 1.10996 m .58756 1.11054 L .58533 1.09745 L F
.58023 1.02995 m .57858 1.02283 L .5836 1.03236 L 0 .404 0 r
F
.5771 1.026 m .58759 1.02057 L .58571 1.02563 L 0 .359 .099 r
F
.58359 1.06502 m .58276 1.0533 L .58664 1.06396 L 0 .689 .061 r
F
.5771 1.026 m .58571 1.02563 L .58144 1.02785 L 0 .359 .099 r
F
.58976 1.03551 m .5846 1.02804 L .59029 1.0346 L 0 .151 0 r
F
.58372 1.02901 m .58468 1.02872 L .58976 1.03551 L 0 .208 0 r
F
.5914 1.0365 m .58921 1.03726 L .59613 1.04168 L 0 .28 .24 r
F
.58372 1.02901 m .58976 1.03551 L .59169 1.03877 L 0 .208 0 r
F
.58372 1.02901 m .59169 1.03877 L .58915 1.03629 L F
.58763 1.04069 m .58525 1.03195 L .59055 1.04036 L 0 .387 0 r
F
.58041 1.03975 m .58571 1.02563 L .59 1.02841 L 0 .409 .111 r
F
.58041 1.03975 m .58144 1.02785 L .58571 1.02563 L F
.58622 1.07524 m .58896 1.07759 L .59683 1.07753 L 0 .771 .3 r
F
.58622 1.07524 m .59683 1.07753 L .59561 1.07653 L F
.58359 1.06502 m .58664 1.06396 L .5914 1.08175 L 0 .689 .061 r
F
.59578 1.04086 m .58974 1.0337 L .59564 1.03956 L 0 .074 0 r
F
.59578 1.04086 m .58772 1.03154 L .58974 1.0337 L F
.59578 1.04086 m .59029 1.0346 L .58772 1.03154 L F
.58976 1.03551 m .59029 1.0346 L .59578 1.04086 L 0 .151 0 r
F
.58041 1.03975 m .59 1.02841 L .59146 1.03435 L 0 .409 .111 r
F
.58922 1.17824 m .59199 1.16031 L .5965 1.16834 L 0 .514 .098 r
F
.58976 1.03551 m .59578 1.04086 L .59801 1.04409 L 0 .151 0 r
F
.58976 1.03551 m .59801 1.04409 L .59549 1.04211 L F
.59497 1.04829 m .58915 1.03629 L .59169 1.03877 L 0 .35 0 r
F
.59497 1.04829 m .59055 1.04036 L .58915 1.03629 L F
.58886 1.05325 m .58527 1.03952 L .58835 1.04378 L 0 .491 .034 r
F
.58886 1.05325 m .58548 1.04357 L .58527 1.03952 L F
.58041 1.03975 m .59146 1.03435 L .5892 1.04041 L 0 .409 .111 r
F
.58359 1.06502 m .59258 1.09534 L .58836 1.08286 L 0 .689 .061 r
F
.58359 1.06502 m .59388 1.09485 L .59258 1.09534 L F
.58359 1.06502 m .5914 1.08175 L .59388 1.09485 L F
.58922 1.17824 m .5965 1.16834 L .59762 1.17758 L 0 .514 .098 r
F
.58763 1.04069 m .59055 1.04036 L .59497 1.04829 L 0 .387 0 r
F
.58041 1.03975 m .5892 1.04041 L .58472 1.04255 L 0 .409 .111 r
F
.58886 1.05325 m .58835 1.04378 L .59346 1.05406 L 0 .491 .034 r
F
.58748 1.06372 m .5853 1.04938 L .58879 1.05576 L 0 .642 .059 r
F
.58748 1.06372 m .58474 1.05277 L .5853 1.04938 L F
.58306 1.05711 m .5892 1.04041 L .59343 1.04474 L 0 .453 .131 r
F
.58306 1.05711 m .58472 1.04255 L .5892 1.04041 L F
.58359 1.06502 m .58145 1.05374 L .58276 1.0533 L 0 .689 .061 r
F
.58306 1.05711 m .58208 1.0497 L .58472 1.04255 L 0 .453 .131 r
F
.59722 1.06355 m .59346 1.05406 L .59295 1.04916 L 0 .476 .042 r
F
.58886 1.05325 m .59346 1.05406 L .59722 1.06355 L 0 .491 .034 r
F
.58886 1.05325 m .59722 1.06355 L .59745 1.06766 L F
.58886 1.05325 m .59745 1.06766 L .594 1.0636 L F
.58306 1.05711 m .59343 1.04474 L .59458 1.05268 L 0 .453 .131 r
F
.58922 1.17824 m .59762 1.17758 L .59459 1.18183 L 0 .514 .098 r
F
.58748 1.06372 m .58879 1.05576 L .59372 1.06904 L 0 .642 .059 r
F
.58306 1.05711 m .59458 1.05268 L .59196 1.05987 L 0 .453 .131 r
F
.58071 1.06863 m .59269 1.13537 L .59021 1.12603 L 0 .61 .042 r
F
.58071 1.06863 m .59109 1.11913 L .59269 1.13537 L F
.58071 1.06863 m .58644 1.09017 L .59109 1.11913 L F
.58306 1.05711 m .59196 1.05987 L .58729 1.06148 L 0 .453 .131 r
F
.59682 1.0804 m .594 1.0636 L .59745 1.06766 L 0 .663 .074 r
F
.59682 1.0804 m .59372 1.06904 L .594 1.0636 L F
.58748 1.06372 m .59372 1.06904 L .59682 1.0804 L 0 .642 .059 r
F
.58748 1.06372 m .59628 1.08387 L .59243 1.07707 L F
.58748 1.06372 m .59682 1.0804 L .59628 1.08387 L F
.5889 1.07484 m .59196 1.05987 L .59609 1.06679 L 0 .494 .149 r
F
.58502 1.07918 m .58889 1.06842 L .5889 1.07484 L F
.58889 1.06842 m .59196 1.05987 L .5889 1.07484 L F
.58502 1.07918 m .58729 1.06148 L .58887 1.06094 L F
.58889 1.06842 m .58887 1.06094 L .59196 1.05987 L F
.58502 1.07918 m .58887 1.06094 L .58889 1.06842 L F
.58502 1.07918 m .58432 1.06974 L .58729 1.06148 L F
.59388 1.09485 m .59243 1.07707 L .59628 1.08387 L 0 .786 .089 r
F
.59388 1.09485 m .5914 1.08175 L .59243 1.07707 L F
.5889 1.07869 m .59609 1.06679 L .59693 1.07767 L 0 .494 .149 r
F
.58502 1.07918 m .5889 1.07484 L .5889 1.07869 L F
.5889 1.07484 m .59609 1.06679 L .5889 1.07869 L F
.59074 1.21383 m .58726 1.20238 L .58697 1.19118 L 0 .622 .114 r
F
.58346 1.09474 m .58533 1.09745 L .59021 1.12603 L 0 .674 .054 r
F
.58891 1.08214 m .59693 1.07767 L .59397 1.086 L 0 .494 .149 r
F
.58502 1.07918 m .5889 1.07869 L .58891 1.08214 L F
.5889 1.07869 m .59693 1.07767 L .58891 1.08214 L F
.58847 1.09692 m .58836 1.08286 L .59258 1.09534 L 0 .835 .087 r
F
.58847 1.09692 m .5866 1.08352 L .58836 1.08286 L F
.58502 1.07918 m .59247 1.08486 L .58916 1.08616 L 0 .494 .149 r
F
.59247 1.08486 m .59397 1.086 L .59243 1.08605 L F
.59247 1.08486 m .59243 1.08605 L .58916 1.08616 L F
.5965 1.16834 m .59051 1.15174 L .59302 1.14834 L 0 .423 .095 r
F
.5965 1.16834 m .59199 1.1603 L .59051 1.15174 L F
.58346 1.09474 m .59287 1.16579 L .58809 1.13095 L 0 .674 .054 r
F
.59287 1.16579 m .59329 1.16892 L .59286 1.16582 L F
.59287 1.16579 m .59286 1.16582 L .58809 1.13095 L F
.58346 1.09474 m .59622 1.18255 L .59329 1.16892 L F
.58346 1.09474 m .59489 1.16253 L .59622 1.18255 L F
.58346 1.09474 m .59021 1.12603 L .59489 1.16253 L F
.58234 1.22046 m .58726 1.20238 L .59074 1.21383 L 0 .707 .112 r
F
.59388 1.09485 m .59628 1.08387 L .60126 1.09919 L 0 .786 .089 r
F
.59388 1.09485 m .60305 1.11767 L .59888 1.11027 L F
.58847 1.09692 m .59258 1.09534 L .59739 1.11672 L 0 .835 .087 r
F
.58847 1.09692 m .59783 1.13354 L .59329 1.11837 L F
.58847 1.09692 m .59959 1.13282 L .59783 1.13354 L F
.58847 1.09692 m .59739 1.11672 L .59959 1.13282 L F
.58629 1.10719 m .59397 1.086 L .59798 1.09733 L 0 .536 .164 r
F
.58629 1.10719 m .58916 1.08616 L .59397 1.086 L F
.58629 1.10719 m .58587 1.09522 L .58916 1.08616 L F
.58234 1.22046 m .59074 1.21383 L .59076 1.22459 L 0 .707 .112 r
F
.59959 1.13282 m .59739 1.11672 L .59888 1.11027 L 0 .852 .109 r
F
.58629 1.10719 m .59798 1.09733 L .59853 1.1127 L 0 .536 .164 r
F
.58548 1.12101 m .58477 1.11056 L .58809 1.13095 L 0 .68 .055 r
F
.59269 1.13537 m .59329 1.11837 L .59783 1.13354 L 0 .918 .105 r
F
.59269 1.13537 m .59109 1.11913 L .59329 1.11837 L F
.58629 1.10719 m .59524 1.12187 L .59031 1.11863 L 0 .536 .164 r
F
.58629 1.10719 m .59853 1.1127 L .59524 1.12187 L F
.58548 1.12101 m .58809 1.13095 L .59329 1.16892 L 0 .68 .055 r
F
.58904 1.15694 m .59564 1.22029 L .59011 1.16775 L F
.58548 1.12101 m .589 1.15539 L .58904 1.15694 L F
.589 1.15539 m .59564 1.22029 L .58904 1.15694 L F
.59896 1.24611 m .59575 1.23257 L .59594 1.21902 L 0 .626 .137 r
F
.59536 1.21751 m .59905 1.24131 L .59564 1.22029 L 0 .68 .055 r
F
.58548 1.12101 m .59555 1.21028 L .59536 1.21751 L F
.59555 1.21028 m .59905 1.24131 L .59536 1.21751 L F
.59976 1.39659 m .59376 1.27724 L .59801 1.3463 L 0 0 .062 r
F
.58305 1.10075 m .58631 1.135 L .58669 1.14318 L 0 0 .114 r
F
.58683 1.14817 m .58541 1.129 L .5854 1.12889 L 0 0 .123 r
F
.58504 1.12362 m .58462 1.11944 L .58456 1.11634 L 0 .762 .122 r
F
.58462 1.11944 m .58406 1.11379 L .58421 1.11458 L F
.58364 1.10776 m .58606 1.13587 L .58365 1.10791 L 0 0 .114 r
F
.58462 1.11944 m .58421 1.11458 L .58456 1.11634 L 0 .762 .122 r
F
.58361 1.10742 m .58364 1.10776 L .58362 1.10755 L 0 0 .114 r
F
.58364 1.10776 m .58365 1.10791 L .58362 1.10755 L F
.58063 1.07421 m .58432 1.06974 L .58502 1.07918 L 0 .601 .12 r
F
.58063 1.07421 m .58432 1.06974 L .58063 1.07421 L F
.57872 1.05451 m .58306 1.05711 L .57929 1.05856 L 0 .545 .109 r
F
.57631 1.03248 m .57692 1.03394 L .57653 1.03475 L 0 .511 0 r
F
.57524 1.02725 m .57806 1.03803 L .57583 1.02975 L 0 .418 0 r
F
.57806 1.03803 m .57654 1.02815 L .58005 1.03754 L 0 .539 .024 r
F
.57806 1.03803 m .57568 1.02835 L .57654 1.02815 L F
.57613 1.03475 m .57552 1.02972 L .57853 1.03317 L 0 .491 .102 r
F
.57857 1.03406 m .57853 1.03317 L .57917 1.03389 L F
.57613 1.03475 m .57853 1.03317 L .57857 1.03406 L F
.57712 1.0439 m .57693 1.04265 L .57697 1.04267 L 0 .545 .109 r
F
.57485 1.02907 m .57427 1.02578 L .57487 1.02907 L 0 .435 .092 r
F
.57465 1.02816 m .57484 1.02897 L .57466 1.02821 L 0 .511 0 r
F
.57484 1.02897 m .57485 1.02903 L .57466 1.02821 L F
.57418 1.02577 m .57427 1.02578 L .57485 1.02907 L 0 .435 .092 r
F
.57465 1.02805 m .57467 1.0282 L .57485 1.02905 L 0 0 .101 r
F
.57467 1.0282 m .57728 1.04425 L .57485 1.02906 L F
.57467 1.0282 m .57485 1.02906 L .57485 1.02905 L F
.57418 1.02577 m .57567 1.03462 L .57459 1.02779 L F
.57567 1.03462 m .5753 1.03204 L .57465 1.02806 L F
.57456 1.0276 m .57465 1.02806 L .57409 1.02461 L F
.57567 1.03462 m .57465 1.02806 L .57456 1.0276 L F
.57356 1.02217 m .57553 1.03387 L .57403 1.02493 L F
.57357 1.02218 m .57403 1.02493 L .5737 1.0229 L F
.57356 1.02217 m .57403 1.02493 L .57357 1.02218 L F
.57473 1.02901 m .57418 1.02577 L .57485 1.02907 L 0 .435 .092 r
F
.57465 1.02816 m .57466 1.02821 L .57359 1.02359 L 0 .511 0 r
F
.57553 1.03387 m .57558 1.03416 L .5737 1.0229 L 0 0 .101 r
F
.57471 1.029 m .57464 1.02897 L .57573 1.03509 L F
.57356 1.02217 m .57464 1.02897 L .57471 1.029 L F
.57323 1.02201 m .57385 1.02402 L .57404 1.02516 L 0 .511 0 r
F
.57356 1.02217 m .57299 1.01976 L .57464 1.02897 L 0 0 .101 r
F
.56652 1.02518 m .57473 1.02901 L .57069 1.02864 L 0 .435 .092 r
F
.57473 1.02901 m .57485 1.02907 L .57474 1.02905 L F
.57473 1.02901 m .57474 1.02905 L .57069 1.02864 L F
.57415 1.02564 m .57522 1.03204 L .57571 1.03489 L 0 0 .101 r
F
.57405 1.02502 m .57412 1.02543 L .57415 1.02564 L F
.57412 1.02543 m .57522 1.03204 L .57415 1.02564 L F
.5737 1.0229 m .57394 1.02434 L .57405 1.02502 L F
.57394 1.02434 m .57522 1.03204 L .57405 1.02502 L F
.56331 1.02523 m .56602 1.03474 L .57126 1.03632 L 0 .518 .396 r
F
.56331 1.02523 m .57126 1.03632 L .57005 1.03266 L F
.56924 1.03668 m .57069 1.02864 L .57475 1.02911 L 0 .491 .102 r
F
.57477 1.02924 m .57475 1.02911 L .57486 1.02912 L F
.56924 1.03668 m .57475 1.02911 L .57477 1.02924 L F
.56652 1.02518 m .57418 1.02577 L .57473 1.02901 L 0 .435 .092 r
F
.57489 1.02928 m .57486 1.02912 L .575 1.02914 L 0 .491 .102 r
F
.57485 1.02907 m .57728 1.04425 L .57501 1.03 L 0 0 .101 r
F
.57485 1.02906 m .57728 1.04425 L .57485 1.02907 L F
.57427 1.02578 m .57486 1.02582 L .57487 1.02907 L 0 .435 .092 r
F
.57486 1.02582 m .57517 1.02867 L .57487 1.02907 L F
.56612 .97788 m .57485 1.02905 L .57045 1.002 L 0 0 .101 r
F
.57485 1.02905 m .57501 1.03 L .57487 1.02912 L F
.57485 1.02905 m .57487 1.02912 L .57045 1.002 L F
.57541 1.03216 m .57501 1.03 L .5763 1.03839 L 0 0 .096 r
F
.57575 1.03485 m .57498 1.02974 L .57588 1.03482 L 0 .491 .102 r
F
.57521 1.031 m .57501 1.03 L .57541 1.03216 L 0 0 .096 r
F
.57493 1.02942 m .57501 1.03 L .57534 1.03168 L F
.57498 1.02974 m .575 1.02983 L .57588 1.03482 L 0 .491 .102 r
F
.57177 .99514 m .56922 .99287 L .56959 .98987 L 0 .181 .042 r
F
.56881 .98736 m .57045 1.002 L .57501 1.03 L 0 0 .096 r
F
.57489 1.02928 m .57494 1.02954 L .57498 1.02974 L 0 .491 .102 r
F
.57494 1.02954 m .575 1.02983 L .57498 1.02974 L F
.57686 1.04218 m .57775 1.04835 L .57802 1.05011 L 0 0 .096 r
F
.5749 1.02927 m .575 1.02914 L .57588 1.03482 L 0 .491 .102 r
F
.57534 1.03168 m .57521 1.031 L .57541 1.03216 L 0 0 .096 r
F
.57485 1.02907 m .575 1.02914 L .57486 1.02912 L 0 .435 .092 r
F
.57363 1.01974 m .57493 1.02942 L .57534 1.03168 L 0 0 .096 r
F
.57588 1.03482 m .57596 1.03601 L .57638 1.03818 L F
.57363 1.01974 m .57541 1.03215 L .57588 1.03482 L F
.57541 1.03215 m .57596 1.03601 L .57588 1.03482 L F
.57575 1.03485 m .57588 1.03482 L .57632 1.03863 L 0 .491 .102 r
F
.57586 1.03503 m .57605 1.0363 L .57603 1.03664 L 0 0 .096 r
F
.57605 1.0363 m .57671 1.04073 L .57622 1.03774 L F
.57605 1.0363 m .57622 1.03774 L .57603 1.03664 L F
.57588 1.03482 m .57917 1.03389 L .57632 1.03863 L 0 .491 .102 r
F
.58111 1.07934 m .58188 1.08664 L .58119 1.0802 L 0 0 .105 r
F
.5812 1.08026 m .58195 1.08758 L .58128 1.08075 L F
.58143 1.08155 m .58127 1.08069 L .58195 1.08758 L 0 0 .114 r
F
.57388 1.08254 m .58127 1.08069 L .58143 1.08155 L 0 .67 .126 r
F
.58143 1.08155 m .58127 1.08069 L .58189 1.08149 L F
.58142 1.08146 m .58127 1.08069 L .58143 1.08155 L 0 0 .114 r
F
.58185 1.0855 m .58195 1.08758 L .58249 1.09165 L F
.58142 1.08146 m .58195 1.08758 L .58182 1.085 L F
.57388 1.08254 m .58143 1.08155 L .58249 1.09165 L 0 .67 .126 r
F
.58143 1.08155 m .58189 1.08149 L .58249 1.09165 L F
.57632 1.03863 m .57917 1.03389 L .58006 1.0381 L 0 .491 .102 r
F
.57632 1.03863 m .58006 1.0381 L .5801 1.03967 L F
.57468 1.0251 m .57524 1.02725 L .57507 1.0268 L 0 .418 0 r
F
.57486 1.02582 m .5771 1.026 L .57517 1.02867 L 0 .435 .092 r
F
.57722 1.04379 m .57697 1.04267 L .57795 1.043 L 0 .545 .109 r
F
.57711 1.04261 m .57727 1.04391 L .57726 1.04355 L 0 0 .097 r
F
.57727 1.04391 m .57963 1.06244 L .57767 1.04678 L F
.57727 1.04391 m .57767 1.04678 L .57726 1.04355 L F
.57959 1.06359 m .57986 1.06591 L .57882 1.05766 L F
.57878 1.05734 m .57882 1.05766 L .57865 1.05634 L F
.57959 1.06359 m .57882 1.05766 L .57878 1.05734 L F
.57899 1.0611 m .5792 1.06095 L .57961 1.06799 L 0 .601 .12 r
F
.57896 1.05882 m .58035 1.0701 L .5791 1.05953 L 0 0 .097 r
F
.57535 1.02841 m .5771 1.026 L .57537 1.02858 L 0 .435 .092 r
F
.57712 1.04273 m .57722 1.04379 L .5775 1.04574 L 0 0 .097 r
F
.57722 1.04379 m .57813 1.05094 L .5775 1.04574 L F
.57792 1.04986 m .57807 1.04985 L .57844 1.05434 L 0 .545 .109 r
F
.57807 1.04985 m .57808 1.04996 L .57837 1.05357 L 0 0 .097 r
F
.57808 1.04996 m .57839 1.05373 L .57837 1.05357 L F
.57844 1.05434 m .57851 1.05491 L .57854 1.05519 L F
.57851 1.05491 m .57959 1.06359 L .57865 1.05634 L F
.5789 1.05832 m .5789 1.05835 L .57894 1.0587 L F
.57844 1.05434 m .57872 1.05451 L .57894 1.0587 L 0 .545 .109 r
F
.57632 1.03863 m .57768 1.0479 L .57638 1.039 L 0 0 .096 r
F
.57649 1.03978 m .57775 1.04835 L .57686 1.04218 L F
.57773 1.04827 m .57775 1.04835 L .5765 1.03983 L F
.57773 1.04827 m .5765 1.03983 L .5765 1.03981 L F
.57724 1.04394 m .57802 1.05011 L .57725 1.044 L 0 0 .097 r
F
.57696 1.0417 m .57802 1.05011 L .57697 1.04177 L F
.57637 1.03898 m .57629 1.03839 L .57628 1.03835 L 0 0 .096 r
F
.57773 1.04827 m .57639 1.03908 L .57637 1.03898 L F
.57633 1.03811 m .57666 1.0403 L .57632 1.0381 L F
.57637 1.03817 m .57666 1.0403 L .57633 1.03811 L F
.57632 1.03863 m .57649 1.03867 L .57686 1.04221 L 0 .491 .102 r
F
.57639 1.03908 m .57629 1.03839 L .57637 1.03898 L 0 0 .096 r
F
.57801 1.04986 m .57722 1.04379 L .57807 1.04985 L 0 .545 .109 r
F
.57776 1.04844 m .57776 1.04845 L .57775 1.04835 L 0 0 .096 r
F
.57768 1.0479 m .57773 1.04827 L .57637 1.03898 L F
.57381 1.02144 m .57597 1.03612 L .576 1.03645 L F
.57629 1.03841 m .57637 1.03898 L .57341 1.01872 L F
.57768 1.0479 m .57637 1.03898 L .57629 1.03841 L F
.57618 1.04491 m .57712 1.0439 L .57711 1.0495 L 0 .545 .109 r
F
.57712 1.0439 m .57722 1.04379 L .57721 1.04452 L F
.57712 1.0439 m .57721 1.04452 L .57711 1.04989 L F
.57719 1.04989 m .57721 1.04452 L .57801 1.04986 L F
.57711 1.04989 m .57712 1.04953 L .57719 1.04989 L F
.57712 1.04953 m .57721 1.04452 L .57719 1.04989 L F
.57894 1.0587 m .57894 1.05871 L .57891 1.05843 L 0 0 .097 r
F
.57721 1.04452 m .57722 1.04379 L .57801 1.04986 L 0 .545 .109 r
F
.57508 1.02879 m .57535 1.02841 L .57511 1.02898 L 0 .435 .092 r
F
.57535 1.02841 m .57537 1.02858 L .57511 1.02898 L F
.57701 1.04232 m .57695 1.04257 L .57688 1.04229 L 0 .491 .102 r
F
.57686 1.04221 m .57649 1.03867 L .57701 1.04232 L F
.5772 1.04364 m .57697 1.04267 L .5772 1.04365 L 0 0 .097 r
F
.57701 1.04232 m .57707 1.0427 L .57697 1.04267 L 0 .491 .102 r
F
.57701 1.04232 m .57697 1.04267 L .57695 1.04257 L F
.57449 1.02478 m .5756 1.02133 L .57464 1.02581 L 0 .435 .092 r
F
.57701 1.04232 m .57795 1.043 L .57707 1.0427 L 0 .491 .102 r
F
.57316 1.015 m .57664 1.00521 L .58095 1.00647 L 0 .316 .085 r
F
.57316 1.015 m .57291 1.00704 L .57664 1.00521 L F
.57316 1.015 m .58095 1.00647 L .58299 1.01 L F
.57316 1.015 m .58299 1.01 L .58151 1.0142 L F
.57316 1.015 m .58151 1.0142 L .57749 1.01628 L F
.57088 .99359 m .57697 1.04267 L .5772 1.04364 L 0 0 .097 r
F
.57697 1.04267 m .57697 1.04267 L .5772 1.04364 L F
.57695 1.04257 m .57697 1.04267 L .57693 1.04265 L 0 .491 .102 r
F
.57088 .99359 m .5769 1.04122 L .57712 1.04273 L 0 0 .097 r
F
.57761 1.04654 m .57762 1.04666 L .57762 1.04667 L F
.57754 1.04602 m .57761 1.04652 L .57761 1.04654 L F
.57753 1.04705 m .57756 1.04583 L .57807 1.05136 L F
.57697 1.04267 m .57697 1.04267 L .57698 1.0427 L F
.57712 1.0439 m .57697 1.04267 L .57722 1.04379 L 0 .545 .109 r
F
.57697 1.04267 m .57698 1.0427 L .5772 1.04365 L 0 0 .097 r
F
.5769 1.04122 m .57722 1.04379 L .57712 1.04273 L F
.57088 .99359 m .57685 1.04088 L .57687 1.04102 L F
.57685 1.04088 m .57696 1.0417 L .57687 1.04102 L F
.57712 1.04268 m .57751 1.04578 L .57754 1.04602 L F
.57088 .99359 m .57709 1.0425 L .57712 1.04268 L F
.57709 1.0425 m .57751 1.04578 L .57712 1.04268 L F
.57723 1.04381 m .57724 1.04394 L .57725 1.044 L F
.57697 1.04177 m .57722 1.04377 L .57723 1.04381 L F
.57722 1.04377 m .57724 1.04394 L .57723 1.04381 L F
.57088 .99359 m .57711 1.04261 L .57726 1.04355 L F
.57088 .99359 m .5774 1.0446 L .57753 1.04705 L F
.57891 1.05842 m .57891 1.05843 L .57524 1.02704 L F
.57894 1.0587 m .57891 1.05843 L .57891 1.05842 L F
.57688 1.04229 m .57689 1.04232 L .57688 1.04229 L 0 .491 .102 r
F
.57686 1.04221 m .57686 1.04218 L .57686 1.04221 L F
.57686 1.04218 m .57649 1.03867 L .57686 1.04221 L F
.57686 1.04221 m .57701 1.04232 L .57687 1.04229 L F
.57634 1.03791 m .57637 1.03817 L .57342 1.01882 L 0 0 .096 r
F
.57637 1.03817 m .57633 1.03811 L .57342 1.01882 L F
.57363 1.01974 m .57634 1.03791 L .57342 1.01882 L F
.57686 1.04221 m .57697 1.04267 L .57317 1.01565 L F
.57508 1.02879 m .57511 1.02898 L .575 1.02914 L 0 .435 .092 r
F
.57588 1.03482 m .575 1.02914 L .57516 1.02931 L 0 .491 .102 r
F
.57588 1.03482 m .57516 1.02931 L .57581 1.03388 L F
.57088 .99359 m .57317 1.01565 L .57697 1.04267 L 0 0 .097 r
F
.57618 1.04491 m .57693 1.04265 L .57712 1.0439 L 0 .545 .109 r
F
.57139 1.05011 m .57598 1.04393 L .57618 1.04491 L F
.57598 1.04393 m .57693 1.04265 L .57618 1.04491 L F
.57088 .99359 m .5788 1.05756 L .57524 1.02704 L 0 0 .097 r
F
.57865 1.05634 m .5789 1.05832 L .57894 1.0587 L F
.5788 1.05756 m .5789 1.0584 L .57881 1.05762 L F
.57885 1.0579 m .57887 1.05809 L .57865 1.05634 L F
.5788 1.05756 m .57881 1.05762 L .57524 1.02704 L F
.5789 1.0584 m .57894 1.0587 L .57891 1.05842 L F
.57888 1.05818 m .57888 1.05819 L .57887 1.05809 L F
.5789 1.0584 m .57891 1.05842 L .57524 1.02704 L F
.57608 1.04502 m .57618 1.04491 L .57711 1.04989 L 0 .545 .109 r
F
.57618 1.04491 m .57711 1.0495 L .57711 1.04989 L F
.57139 1.05011 m .57608 1.04502 L .57711 1.04989 L F
.5774 1.0446 m .57756 1.04583 L .57753 1.04705 L 0 0 .097 r
F
.578 1.0493 m .57805 1.04972 L .57807 1.04985 L F
.57726 1.04355 m .57797 1.04921 L .578 1.0493 L F
.57772 1.04714 m .57807 1.04985 L .57818 1.05216 L F
.57807 1.04985 m .57837 1.05357 L .57818 1.05216 L F
.57807 1.04985 m .57866 1.05406 L .57844 1.05434 L 0 .545 .109 r
F
.57756 1.04583 m .57772 1.04714 L .57818 1.05216 L 0 0 .097 r
F
.57894 1.0587 m .57915 1.05893 L .57901 1.05931 L 0 .545 .109 r
F
.57844 1.05434 m .57866 1.05406 L .57872 1.05451 L F
.57229 .99375 m .57524 1.02704 L .57905 1.0591 L 0 0 .105 r
F
.57905 1.05911 m .57905 1.0591 L .57905 1.05914 L F
.57229 .99375 m .57905 1.0591 L .57905 1.05911 L F
.57937 1.06082 m .57908 1.05935 L .58035 1.0701 L F
.5792 1.06095 m .57921 1.06 L .57937 1.06082 L 0 .601 .12 r
F
.57921 1.06 m .57921 1.05945 L .57937 1.06082 L F
.5792 1.06095 m .57901 1.05931 L .57921 1.05945 L F
.57937 1.06082 m .57905 1.05914 L .57908 1.05935 L 0 0 .105 r
F
.57872 1.05451 m .57929 1.05856 L .57911 1.05863 L 0 .545 .109 r
F
.5788 1.05606 m .57911 1.05863 L .57894 1.0587 L F
.57872 1.05451 m .57911 1.05863 L .5788 1.05606 L F
.57863 1.0538 m .57937 1.06076 L .57867 1.05407 L 0 0 .105 r
F
.57937 1.06082 m .57921 1.05945 L .58025 1.06018 L 0 .601 .12 r
F
.57937 1.06076 m .57937 1.06082 L .57937 1.06077 L 0 0 .105 r
F
.57937 1.06076 m .57937 1.06077 L .57867 1.05407 L F
.57915 1.05893 m .57918 1.05925 L .57906 1.05929 L 0 .545 .109 r
F
.57905 1.05921 m .57906 1.05929 L .57901 1.05931 L F
.57915 1.05893 m .57906 1.05929 L .57905 1.05921 L F
.57894 1.0587 m .57929 1.05856 L .57937 1.05919 L F
.57229 .99375 m .57905 1.05914 L .57921 1.05999 L 0 0 .105 r
F
.57935 1.06064 m .57921 1.05999 L .57937 1.06082 L F
.57937 1.05919 m .57943 1.0596 L .57901 1.05931 L 0 .545 .109 r
F
.57866 1.05406 m .58208 1.0497 L .57872 1.05451 L F
.57229 .99375 m .57921 1.05999 L .57935 1.06064 L 0 0 .105 r
F
.57936 1.06083 m .57937 1.06082 L .57959 1.06204 L 0 .601 .12 r
F
.57937 1.06082 m .57958 1.06067 L .57959 1.06194 L F
.57937 1.06082 m .57959 1.06194 L .57959 1.06204 L F
.5792 1.06095 m .57936 1.06083 L .57959 1.06429 L F
.57936 1.06083 m .57959 1.06204 L .57959 1.06429 L F
.5792 1.06095 m .57959 1.06429 L .57961 1.06799 L F
.57958 1.06067 m .58025 1.06018 L .57997 1.06353 L F
.57937 1.06082 m .58035 1.0701 L .58017 1.06759 L 0 0 .105 r
F
.57961 1.06799 m .57996 1.06364 L .58024 1.06823 L 0 .601 .12 r
F
.57937 1.06082 m .58017 1.06759 L .58015 1.06738 L 0 0 .105 r
F
.57958 1.06067 m .57997 1.06353 L .57986 1.06495 L 0 .601 .12 r
F
.57959 1.06265 m .57986 1.06495 L .57961 1.06799 L F
.57958 1.06067 m .57986 1.06495 L .57959 1.06265 L F
.58137 1.08085 m .58127 1.08069 L .58142 1.08146 L 0 0 .114 r
F
.58099 1.07799 m .58099 1.07462 L .5812 1.08026 L 0 .601 .12 r
F
.58063 1.07421 m .58073 1.07514 L .58103 1.07849 L 0 0 .105 r
F
.58073 1.07514 m .58104 1.07857 L .58103 1.07849 L F
.58063 1.07421 m .58099 1.07462 L .58098 1.07988 L 0 .601 .12 r
F
.58063 1.07421 m .58046 1.07029 L .58073 1.07514 L 0 0 .105 r
F
.57961 1.06799 m .58024 1.06823 L .57991 1.07125 L 0 .601 .12 r
F
.58017 1.06757 m .58035 1.0701 L .58024 1.06823 L 0 0 .105 r
F
.58024 1.06823 m .58052 1.07254 L .5797 1.07315 L 0 .601 .12 r
F
.57968 1.06508 m .58031 1.06927 L .58063 1.07421 L 0 0 .105 r
F
.58031 1.06927 m .58033 1.0694 L .58063 1.07421 L F
.58033 1.0694 m .58046 1.07029 L .58063 1.07421 L F
.58024 1.06823 m .58046 1.07029 L .5803 1.06922 L F
.58024 1.06823 m .58073 1.07239 L .58052 1.07254 L 0 .601 .12 r
F
.58024 1.06823 m .58025 1.06018 L .58432 1.06974 L F
.57996 1.06364 m .58025 1.06018 L .58024 1.06823 L F
.58003 1.06622 m .57937 1.06082 L .58015 1.06738 L 0 0 .105 r
F
.58015 1.06738 m .58017 1.06757 L .58024 1.06823 L F
.57957 1.06193 m .58024 1.06823 L .57968 1.06508 L F
.58024 1.06823 m .5803 1.06922 L .57968 1.06508 L F
.57882 1.04096 m .57885 1.04181 L .57795 1.043 L 0 .491 .102 r
F
.57937 1.05919 m .58025 1.06018 L .57943 1.0596 L 0 .545 .109 r
F
.57929 1.05856 m .57951 1.05848 L .57937 1.05919 L F
.58142 1.05363 m .58142 1.05361 L .58145 1.05374 L 0 .511 0 r
F
.57872 1.05451 m .58208 1.0497 L .58306 1.05711 L 0 .545 .109 r
F
.58024 1.06823 m .58432 1.06974 L .58073 1.07239 L 0 .601 .12 r
F
.58048 1.07258 m .58432 1.06974 L .58063 1.07421 L F
.5771 1.026 m .5756 1.02133 L .57749 1.01628 L 0 .359 .099 r
F
.57295 .98334 m .58122 1.08002 L .58137 1.08085 L 0 0 .114 r
F
.58131 1.08046 m .58135 1.08079 L .58127 1.08069 L 0 .601 .12 r
F
.58131 1.08046 m .58127 1.08069 L .58125 1.08059 L F
.58122 1.08002 m .58127 1.08069 L .58137 1.08085 L 0 0 .114 r
F
.58142 1.08146 m .58182 1.085 L .5817 1.0827 L F
.58113 1.07843 m .58172 1.08306 L .58187 1.08708 L F
.58023 1.06597 m .58047 1.07042 L .58102 1.07493 L F
.57959 1.05943 m .58306 1.05711 L .58025 1.06018 L 0 .545 .109 r
F
.57951 1.05848 m .58306 1.05711 L .57959 1.05943 L F
.57295 .98334 m .5798 1.06266 L .58023 1.06597 L 0 0 .114 r
F
.5798 1.06266 m .58047 1.07042 L .58023 1.06597 L F
.58102 1.07493 m .58048 1.07051 L .58103 1.07504 L F
.58047 1.07042 m .58048 1.07051 L .58102 1.07493 L F
.58048 1.07051 m .58101 1.07669 L .58103 1.07504 L F
.57295 .98334 m .58105 1.07545 L .58113 1.07843 L F
.58101 1.07669 m .58142 1.08146 L .5817 1.0827 L F
.58105 1.07545 m .58172 1.08306 L .58113 1.07843 L F
.5801 1.03967 m .58006 1.0381 L .58041 1.03975 L 0 .491 .102 r
F
.56924 1.03668 m .57575 1.03485 L .57632 1.03863 L F
.57631 1.0386 m .57632 1.03863 L .57637 1.03898 L 0 0 .096 r
F
.57632 1.03863 m .57638 1.039 L .57637 1.03898 L F
.57381 1.02144 m .57586 1.03503 L .57597 1.03612 L F
.57343 1.01915 m .57501 1.03 L .57363 1.01974 L F
.57342 1.01882 m .57381 1.02144 L .576 1.03645 L F
.576 1.03645 m .57622 1.03777 L .57632 1.03866 L F
.57341 1.01872 m .57649 1.03978 L .57686 1.04218 L F
.5736 1.02005 m .57631 1.0386 L .57341 1.01876 L F
.57631 1.0386 m .57637 1.03898 L .57341 1.01876 L F
.56924 1.03668 m .57489 1.02928 L .57498 1.02974 L 0 .491 .102 r
F
.57553 1.03387 m .57573 1.03509 L .57558 1.03416 L 0 0 .101 r
F
.57522 1.03204 m .57573 1.03509 L .57571 1.03489 L F
.56924 1.03668 m .57498 1.02974 L .57575 1.03485 L 0 .491 .102 r
F
.57586 1.03503 m .57603 1.03664 L .576 1.03645 L 0 0 .096 r
F
.56924 1.03668 m .57486 1.02912 L .57489 1.02928 L 0 .491 .102 r
F
.57485 1.02907 m .57486 1.02912 L .57069 1.02864 L 0 .435 .092 r
F
.57485 1.02905 m .57485 1.02906 L .57485 1.02907 L 0 0 .101 r
F
.57409 1.02461 m .57465 1.02805 L .57485 1.02905 L F
.57489 1.02928 m .5749 1.02927 L .575 1.02983 L 0 .491 .102 r
F
.57967 1.06499 m .57957 1.06193 L .57968 1.06508 L 0 0 .105 r
F
.577 1.0384 m .57863 1.0538 L .57699 1.03781 L F
.57863 1.0538 m .57867 1.05407 L .57699 1.03781 L F
.57915 1.05893 m .57937 1.05919 L .57918 1.05925 L 0 .545 .109 r
F
.57834 1.05045 m .57936 1.06069 L .58003 1.06622 L 0 0 .105 r
F
.57936 1.06069 m .57937 1.06082 L .58003 1.06622 L F
.57699 1.03781 m .57828 1.05023 L .57834 1.05045 L F
.57828 1.05023 m .57937 1.06082 L .57834 1.05045 L F
.57229 .99375 m .577 1.0384 L .57699 1.03781 L F
.57229 .99375 m .57956 1.06185 L .57967 1.06499 L F
.57956 1.06185 m .57957 1.06193 L .57967 1.06499 L F
.58346 1.09474 m .58245 1.08411 L .58533 1.09745 L 0 .674 .054 r
F
.58249 1.09165 m .58189 1.08149 L .58587 1.09522 L 0 .67 .126 r
F
.58183 1.08523 m .58185 1.0855 L .58249 1.09165 L 0 0 .114 r
F
.5817 1.0827 m .58183 1.08523 L .58249 1.09165 L F
.58249 1.09165 m .58631 1.135 L .58295 1.09908 L F
.58226 1.09141 m .58587 1.09522 L .58303 1.09934 L 0 .67 .126 r
F
.58166 1.08214 m .58249 1.09165 L .58244 1.09369 L 0 0 .114 r
F
.58226 1.09141 m .58226 1.09141 L .58294 1.09948 L 0 .67 .126 r
F
.58226 1.09141 m .58303 1.09934 L .58294 1.09948 L F
.58249 1.09165 m .58295 1.09908 L .58244 1.09369 L 0 0 .114 r
F
.58297 1.09944 m .58325 1.09902 L .58305 1.10075 L 0 .67 .126 r
F
.58325 1.09902 m .58587 1.09522 L .58336 1.10012 L F
.58325 1.09902 m .58336 1.10012 L .58305 1.10075 L F
.57882 1.04096 m .58041 1.03975 L .57885 1.04181 L 0 .491 .102 r
F
.58177 1.08128 m .58502 1.07918 L .58189 1.08149 L 0 .601 .12 r
F
.58099 1.07462 m .58502 1.07918 L .58177 1.08128 L F
.58305 1.10075 m .58587 1.09522 L .58629 1.10719 L 0 .67 .126 r
F
.58413 1.10494 m .58477 1.11056 L .58459 1.11242 L 0 0 .105 r
F
.58305 1.10075 m .58629 1.10719 L .58362 1.10755 L 0 .67 .126 r
F
.5771 1.026 m .58151 1.0142 L .58583 1.01604 L 0 .359 .099 r
F
.5771 1.026 m .57749 1.01628 L .58151 1.0142 L F
.5771 1.026 m .58583 1.01604 L .58759 1.02057 L F
.57281 .95567 m .58448 1.11778 L .58494 1.12218 L 0 0 .123 r
F
.58527 1.12709 m .58418 1.1123 L .58418 1.1123 L F
.58683 1.14817 m .58527 1.12714 L .58527 1.12709 L F
.58494 1.12218 m .58462 1.11944 L .58504 1.12362 L F
.58527 1.12714 m .58418 1.1123 L .58527 1.12709 L F
.58548 1.12101 m .598 1.21628 L .59905 1.24131 L 0 .68 .055 r
F
.59903 1.20319 m .59519 1.1928 L .59459 1.18183 L 0 .531 .111 r
F
.58548 1.12101 m .59329 1.16892 L .598 1.21628 L 0 .68 .055 r
F
.58504 1.12362 m .58456 1.11634 L .58671 1.12725 L 0 .762 .122 r
F
.58494 1.12218 m .58448 1.11778 L .58462 1.11944 L 0 0 .123 r
F
.58504 1.12362 m .58462 1.11944 L .5854 1.12859 L F
.58483 1.1219 m .58462 1.11944 L .58473 1.12087 L F
.58669 1.14318 m .58631 1.135 L .59011 1.16775 L 0 .641 .04 r
F
.58677 1.14177 m .58671 1.12725 L .58685 1.14204 L 0 .762 .122 r
F
.58437 1.11661 m .58392 1.11205 L .58697 1.15012 L 0 0 .123 r
F
.58475 1.12299 m .58406 1.11379 L .58504 1.12362 L 0 .762 .122 r
F
.58437 1.12217 m .58412 1.1156 L .58475 1.12299 L F
.58412 1.1156 m .58406 1.11379 L .58475 1.12299 L F
.58539 1.13722 m .58515 1.12784 L .58612 1.13962 L F
.58515 1.12784 m .58504 1.12362 L .58612 1.13962 L F
.58437 1.12217 m .58504 1.12362 L .58539 1.13722 L F
.58422 1.11231 m .58683 1.14817 L .58418 1.1123 L 0 0 .123 r
F
.58418 1.1123 m .58418 1.1123 L .58258 1.09067 L F
.58253 1.08905 m .58422 1.11231 L .58258 1.09067 L F
.58422 1.11231 m .58418 1.1123 L .58258 1.09067 L F
.585 1.12418 m .58697 1.15012 L .58696 1.15115 L F
.58414 1.11229 m .58517 1.12597 L .585 1.12418 L F
.58517 1.12597 m .58697 1.15012 L .585 1.12418 L F
.58258 1.09067 m .58418 1.1123 L .58414 1.11229 L F
.58418 1.1123 m .58697 1.15012 L .58414 1.11229 L F
.5817 1.07844 m .58253 1.08905 L .58258 1.09067 L F
.58169 1.07752 m .58253 1.08905 L .5817 1.07844 L F
.5817 1.07844 m .58612 1.13962 L .58199 1.08066 L F
.58612 1.13962 m .58696 1.15115 L .58627 1.14143 L F
.58606 1.13587 m .58669 1.14318 L .58606 1.13585 L 0 0 .114 r
F
.58612 1.13962 m .58627 1.13651 L .58677 1.14177 L 0 .762 .122 r
F
.58541 1.129 m .58528 1.12723 L .5854 1.12889 L 0 0 .123 r
F
.58541 1.129 m .58541 1.12902 L .58534 1.12799 L F
.58541 1.129 m .58534 1.12799 L .58534 1.12798 L F
.58504 1.12362 m .58555 1.12473 L .58612 1.13962 L 0 .762 .122 r
F
.58555 1.12473 m .58671 1.12725 L .58621 1.13772 L F
.58555 1.12473 m .58621 1.13772 L .58612 1.13962 L F
.58234 1.22046 m .59076 1.22459 L .58729 1.22743 L 0 .707 .112 r
F
.58968 1.2546 m .58729 1.22743 L .59076 1.22459 L 0 .717 .135 r
F
.58627 1.13651 m .58671 1.12725 L .58677 1.14177 L 0 .762 .122 r
F
.58677 1.14177 m .58685 1.14204 L .58679 1.14199 L F
.58609 1.29495 m .58893 1.26539 L .59377 1.27834 L 0 .805 .145 r
F
.58868 1.18174 m .59176 1.23616 L .59161 1.23384 L 0 .566 0 r
F
.58853 1.17895 m .59176 1.23604 L .58868 1.18174 L F
.59176 1.23604 m .59801 1.3463 L .59176 1.23616 L F
.59176 1.23604 m .59176 1.23616 L .58868 1.18174 L F
.58609 1.29495 m .59518 1.30845 L .59096 1.30805 L 0 .805 .145 r
F
.59133 1.34376 m .59096 1.30805 L .59518 1.30845 L 0 .803 .163 r
F
.58567 1.2215 m .58618 1.20654 L .58916 1.21316 L 0 .877 .163 r
F
.59596 1.40409 m .59418 1.37844 L .59626 1.36026 L 0 .794 .178 r
F
.59752 1.39396 m .58929 1.2005 L .59837 1.3952 L 0 0 .062 r
F
.58929 1.2005 m .58929 1.20048 L .59837 1.3952 L F
.58928 1.20025 m .58928 1.20008 L .5893 1.20032 L F
.58929 1.20048 m .5893 1.20032 L .59837 1.3952 L F
.58928 1.20025 m .5893 1.20032 L .58929 1.20048 L F
.59176 1.23616 m .59801 1.3463 L .59176 1.23651 L 0 .566 0 r
F
.59176 1.23616 m .59176 1.23651 L .59161 1.23384 L F
.60219 1.39935 m .58696 1.15115 L .60228 1.39946 L F
.60219 1.39935 m .59801 1.3463 L .58696 1.15115 L F
.58986 1.19492 m .59161 1.23384 L .59801 1.3463 L 0 0 .062 r
F
.58972 1.1939 m .59161 1.23384 L .58986 1.19492 L F
.58877 1.17774 m .59161 1.23384 L .58931 1.18522 L F
.58861 1.13782 m .58976 1.12237 L .58951 1.13564 L 0 .591 .175 r
F
.58685 1.14204 m .58857 1.1304 L .58861 1.13782 L F
.58857 1.1304 m .58976 1.12237 L .58861 1.13782 L F
.58874 1.17718 m .58804 1.16749 L .59161 1.23384 L 0 0 .062 r
F
.58685 1.14204 m .58671 1.12725 L .59031 1.11863 L 0 .591 .175 r
F
.59269 1.13537 m .60237 1.18135 L .59752 1.16204 L 0 .918 .105 r
F
.5878 1.14197 m .59524 1.12187 L .59915 1.14101 L 0 .591 .175 r
F
.58685 1.14204 m .5877 1.14001 L .5878 1.14197 L F
.5877 1.14001 m .59524 1.12187 L .5878 1.14197 L F
.59049 1.20143 m .5931 1.22855 L .5934 1.2427 L 0 .566 0 r
F
.59011 1.19094 m .5931 1.22855 L .59049 1.20143 L F
.5931 1.22855 m .59724 1.28069 L .5934 1.2427 L F
.5901 1.18864 m .59724 1.28069 L .59133 1.205 L 0 .641 .04 r
F
.58669 1.14318 m .59006 1.18706 L .5901 1.18864 L F
.59006 1.18706 m .59724 1.28069 L .5901 1.18864 L F
.5916 1.23444 m .58952 1.19306 L .59077 1.21182 L 0 0 .062 r
F
.59086 1.21964 m .59094 1.21852 L .59125 1.22753 L 0 .877 .163 r
F
.58669 1.14318 m .59888 1.28755 L .59724 1.28069 L 0 .641 .04 r
F
.59888 1.28755 m .60118 1.31486 L .59874 1.29366 L F
.59888 1.28755 m .59874 1.29366 L .59724 1.28069 L F
.58669 1.14318 m .60041 1.28351 L .60118 1.31486 L F
.58669 1.14318 m .59564 1.22029 L .60041 1.28351 L F
.58929 1.16559 m .59011 1.16775 L .59564 1.22029 L F
.58669 1.14318 m .58916 1.16087 L .58929 1.16559 L F
.58916 1.16087 m .59011 1.16775 L .58929 1.16559 L F
.59837 1.3952 m .59406 1.30044 L .59976 1.39659 L 0 0 .062 r
F
.59066 1.14854 m .59915 1.14101 L .59943 1.16348 L 0 .591 .175 r
F
.58685 1.14204 m .59087 1.14171 L .59066 1.14854 L F
.59087 1.14171 m .59915 1.14101 L .59066 1.14854 L F
.59406 1.30044 m .58928 1.19533 L .5916 1.23444 L 0 0 .062 r
F
.59622 1.18255 m .59489 1.16253 L .59752 1.16204 L 0 .96 .119 r
F
.5902 1.15865 m .59582 1.17225 L .59075 1.16135 L 0 .591 .175 r
F
.58685 1.14204 m .59046 1.15421 L .5902 1.15865 L F
.59046 1.15421 m .59582 1.17225 L .5902 1.15865 L F
.58877 1.17774 m .58931 1.18522 L .58906 1.17994 L 0 0 .062 r
F
.58696 1.15115 m .58853 1.17895 L .58868 1.18174 L 0 .566 0 r
F
.58862 1.18608 m .58906 1.17994 L .58911 1.18693 L 0 .686 .18 r
F
.58791 1.18482 m .58845 1.18251 L .58862 1.18608 L F
.58845 1.18251 m .58906 1.17994 L .58862 1.18608 L F
.58928 1.19533 m .58941 1.19096 L .5916 1.23444 L 0 0 .062 r
F
.58668 1.18265 m .58891 1.19239 L .58928 1.20025 L 0 .686 .18 r
F
.58891 1.19239 m .58921 1.19367 L .58928 1.20025 L F
.59752 1.39395 m .5893 1.20057 L .59752 1.39396 L 0 0 .062 r
F
.5893 1.20057 m .5893 1.20057 L .59752 1.39396 L F
.58929 1.2005 m .58928 1.20025 L .58929 1.20048 L F
.58929 1.20034 m .58929 1.20032 L .5893 1.20055 L F
.5893 1.20057 m .5893 1.20055 L .59752 1.39396 L F
.58929 1.20034 m .5893 1.20055 L .5893 1.20057 L F
.58928 1.19999 m .58926 1.19857 L .59837 1.3952 L F
.58891 1.19239 m .58911 1.18693 L .58921 1.19367 L 0 .686 .18 r
F
.58668 1.18265 m .58862 1.18608 L .58891 1.19239 L F
.58862 1.18608 m .58911 1.18693 L .58891 1.19239 L F
.58919 1.19795 m .58862 1.18467 L .58918 1.19666 L 0 0 .062 r
F
.58879 1.18873 m .58879 1.18869 L .58933 1.20125 L F
.58933 1.20133 m .58933 1.20125 L .59752 1.39396 L F
.58879 1.18873 m .58933 1.20125 L .58933 1.20133 L F
.58862 1.18467 m .58867 1.18185 L .58921 1.19367 L F
.58929 1.19922 m .58921 1.19367 L .59837 1.3952 L F
.58862 1.18467 m .58921 1.19367 L .58929 1.19922 L F
.58928 1.19533 m .58921 1.19367 L .58941 1.19096 L F
.58911 1.18693 m .58922 1.18713 L .58921 1.19367 L 0 .686 .18 r
F
.58921 1.19367 m .58875 1.18349 L .58922 1.18877 L 0 0 .062 r
F
.58921 1.19367 m .58922 1.18877 L .58941 1.19096 L F
.58952 1.19306 m .58922 1.18713 L .5895 1.19156 L F
.58952 1.19306 m .5895 1.19156 L .59077 1.21182 L F
.58906 1.17994 m .58972 1.1939 L .58986 1.19492 L F
.5893 1.20057 m .58929 1.20034 L .5893 1.20057 L F
.58928 1.20025 m .58964 1.20265 L .58946 1.20379 L 0 .686 .18 r
F
.5893 1.20057 m .58973 1.20954 L .58929 1.20031 L 0 0 .062 r
F
.59752 1.39395 m .58974 1.20961 L .5893 1.20057 L F
.58974 1.20961 m .58973 1.20954 L .5893 1.20057 L F
.59752 1.39395 m .59065 1.23081 L .58974 1.20962 L F
.59752 1.39395 m .58974 1.20962 L .58974 1.20961 L F
.58911 1.21765 m .59008 1.21657 L .58898 1.22889 L 0 .877 .163 r
F
.59016 1.21647 m .5901 1.21616 L .5902 1.21752 L 0 0 .1 r
F
.58948 1.19121 m .58941 1.18655 L .59077 1.21182 L 0 0 .062 r
F
.58964 1.20265 m .59061 1.20922 L .58971 1.208 L 0 .686 .18 r
F
.59061 1.20922 m .59074 1.21279 L .58971 1.208 L F
.5916 1.23444 m .59077 1.21182 L .59393 1.27059 L 0 0 .062 r
F
.59205 1.21898 m .59205 1.2219 L .59079 1.21443 L 0 .686 .18 r
F
.59074 1.21279 m .59079 1.21443 L .58971 1.208 L F
.59205 1.21898 m .59079 1.21443 L .59074 1.21279 L F
.59754 1.39392 m .5915 1.23449 L .59065 1.23081 L 0 0 .1 r
F
.59406 1.30044 m .5916 1.23444 L .59976 1.39659 L 0 0 .062 r
F
.59218 1.25894 m .5915 1.23449 L .59244 1.26046 L 0 .877 .163 r
F
.59754 1.39392 m .59065 1.23081 L .59752 1.39395 L 0 0 .1 r
F
.58981 1.24534 m .5915 1.23449 L .59218 1.25894 L 0 .877 .163 r
F
.58888 1.22865 m .5915 1.23449 L .58981 1.24534 L F
.59436 1.33048 m .59428 1.32875 L .59426 1.32775 L 0 0 .1 r
F
.59647 1.38985 m .59437 1.33104 L .59436 1.33048 L F
.59437 1.33104 m .59428 1.32875 L .59436 1.33048 L F
.58024 1.25465 m .58204 1.22966 L .58681 1.24027 L 0 .798 .124 r
F
.58024 1.25465 m .58681 1.24027 L .58968 1.2546 L F
.58024 1.25465 m .58968 1.2546 L .58893 1.26539 L F
.58024 1.25465 m .58893 1.26539 L .58504 1.26537 L F
.58609 1.29495 m .58504 1.26537 L .58893 1.26539 L 0 .805 .145 r
F
.58361 1.23839 m .58944 1.27896 L .59441 1.33429 L 0 .994 .102 r
F
.59644 1.36646 m .59263 1.26538 L .59534 1.33585 L 0 0 .1 r
F
.5915 1.23449 m .59143 1.23356 L .59146 1.23432 L F
.59143 1.23356 m .59016 1.21647 L .59146 1.23432 L F
.59146 1.23432 m .59016 1.21647 L .59065 1.23081 L F
.59088 1.23312 m .59086 1.21964 L .5915 1.23449 L 0 .877 .163 r
F
.59016 1.21647 m .59048 1.21611 L .59027 1.21794 L F
.58925 1.18766 m .58906 1.17994 L .58941 1.18655 L 0 0 .062 r
F
.58925 1.18766 m .58941 1.18655 L .58948 1.19121 L F
.58922 1.18713 m .58906 1.17994 L .58925 1.18766 L F
.59011 1.19094 m .59133 1.205 L .59724 1.28069 L 0 .566 0 r
F
.58696 1.15115 m .59012 1.19016 L .59011 1.19094 L F
.59012 1.19016 m .59133 1.205 L .59011 1.19094 L F
.59108 1.21236 m .59196 1.21114 L .59205 1.21898 L 0 .686 .18 r
F
.58964 1.20265 m .59095 1.20745 L .59108 1.21236 L F
.59095 1.20745 m .59196 1.21114 L .59108 1.21236 L F
.58968 1.2546 m .58681 1.24027 L .58729 1.22743 L 0 .717 .135 r
F
.58567 1.2215 m .59234 1.28432 L .59438 1.33273 L 0 .877 .163 r
F
.59234 1.28432 m .59319 1.29233 L .59438 1.33273 L F
.59647 1.38985 m .59527 1.35816 L .59469 1.34167 L 0 0 .1 r
F
.58567 1.2215 m .59218 1.25894 L .59319 1.29233 L 0 .877 .163 r
F
.59133 1.34376 m .58931 1.32312 L .59096 1.30805 L 0 .803 .163 r
F
.59578 1.38797 m .58361 1.23839 L .59444 1.33589 L 0 .994 .102 r
F
.59647 1.38985 m .59469 1.34167 L .59439 1.33172 L 0 0 .1 r
F
.59438 1.33273 m .59527 1.35816 L .59453 1.33624 L F
.59645 1.38937 m .59377 1.3136 L .59612 1.37364 L F
.59377 1.3136 m .59315 1.29608 L .59358 1.30739 L F
.59377 1.3136 m .59358 1.30739 L .59612 1.37364 L F
.59315 1.29608 m .59286 1.28447 L .59612 1.37364 L F
.59647 1.38985 m .59319 1.29757 L .59315 1.29608 L F
.59675 1.39091 m .59319 1.29233 L .59741 1.39222 L F
.59218 1.25894 m .59244 1.26046 L .59319 1.29233 L 0 .877 .163 r
F
.58961 1.20147 m .59093 1.20643 L .58964 1.20265 L 0 .686 .18 r
F
.59093 1.20643 m .59094 1.20694 L .58964 1.20265 L F
.59195 1.21028 m .59196 1.21114 L .59095 1.20745 L F
.59094 1.20694 m .59095 1.20745 L .58964 1.20265 L F
.59195 1.21028 m .59095 1.20745 L .59094 1.20694 L F
.58922 1.18713 m .58974 1.18805 L .58922 1.18915 L F
.58911 1.18693 m .58921 1.1867 L .58922 1.18713 L F
.58875 1.18349 m .5889 1.18082 L .58922 1.18713 L 0 0 .062 r
F
.5892 1.18856 m .58922 1.18713 L .58941 1.19096 L F
.58875 1.18349 m .58922 1.18713 L .5892 1.18856 L F
.58696 1.15115 m .58697 1.15012 L .59013 1.18987 L 0 .566 0 r
F
.59012 1.19016 m .59013 1.18987 L .59133 1.205 L F
.58696 1.15115 m .59013 1.18987 L .59012 1.19016 L F
.58933 1.17963 m .59582 1.17225 L .58923 1.18667 L 0 .686 .18 r
F
.58974 1.18805 m .5917 1.19151 L .58922 1.18915 L F
.58922 1.18915 m .5917 1.19151 L .58921 1.19367 L F
.58906 1.17994 m .58933 1.17963 L .58911 1.18693 L F
.58933 1.17963 m .58923 1.18667 L .58911 1.18693 L F
.5917 1.19151 m .59177 1.19659 L .58921 1.19367 L F
.5919 1.20538 m .59967 1.20556 L .59971 1.2394 L F
.58921 1.19367 m .59177 1.19659 L .5919 1.20538 L F
.59177 1.19659 m .59967 1.20556 L .5919 1.20538 L F
.59033 1.22175 m .59094 1.21852 L .59048 1.22486 L 0 .877 .163 r
F
.58921 1.19367 m .5919 1.20538 L .58928 1.20025 L 0 .686 .18 r
F
.5919 1.20538 m .59971 1.2394 L .59195 1.21028 L F
.5919 1.20538 m .59195 1.21028 L .58928 1.20025 L F
.59313 1.29045 m .59276 1.28023 L .59309 1.28789 L 0 0 .1 r
F
.59048 1.22486 m .59086 1.21964 L .59088 1.23312 L 0 .877 .163 r
F
.58784 1.18381 m .58906 1.17994 L .58791 1.18482 L 0 .686 .18 r
F
.58752 1.18169 m .58906 1.17994 L .58766 1.18438 L F
.59086 1.21964 m .59125 1.22753 L .5915 1.23449 L 0 .877 .163 r
F
.58964 1.20265 m .58971 1.208 L .58964 1.20755 L 0 .686 .18 r
F
.58946 1.20379 m .58964 1.20755 L .58924 1.20516 L F
.58964 1.20265 m .58964 1.20755 L .58946 1.20379 L F
.58919 1.19795 m .58926 1.19857 L .58928 1.19999 L 0 0 .062 r
F
.58948 1.20731 m .59116 1.2166 L .59048 1.21611 L 0 .686 .18 r
F
.58939 1.20607 m .59116 1.2166 L .58948 1.20731 L F
.58848 1.17239 m .58804 1.16749 L .58868 1.1764 L 0 0 .062 r
F
.59622 1.18255 m .59752 1.16204 L .60237 1.18135 L 0 .96 .119 r
F
.58797 1.14581 m .59943 1.16348 L .59582 1.17225 L 0 .591 .175 r
F
.58685 1.14204 m .58788 1.14379 L .58797 1.14581 L F
.58788 1.14379 m .59943 1.16348 L .58797 1.14581 L F
.59319 1.29233 m .59269 1.27091 L .59741 1.39222 L 0 0 .1 r
F
.59263 1.26953 m .59684 1.37708 L .59683 1.37738 L F
.59263 1.26922 m .59684 1.37708 L .59263 1.26953 L F
.59263 1.26922 m .59285 1.27123 L .59293 1.27688 L F
.59116 1.2166 m .5912 1.21857 L .59048 1.21611 L 0 .686 .18 r
F
.59027 1.21794 m .59048 1.21611 L .59049 1.22091 L 0 .877 .163 r
F
.5915 1.23449 m .59101 1.22154 L .59016 1.21647 L 0 0 .1 r
F
.58852 1.17299 m .58868 1.1764 L .58874 1.17718 L 0 0 .062 r
F
.58852 1.17299 m .58788 1.1646 L .59075 1.16135 L 0 .686 .18 r
F
.58602 1.12347 m .58848 1.17239 L .58852 1.17299 L 0 0 .062 r
F
.58848 1.17239 m .58868 1.1764 L .58852 1.17299 L F
.58668 1.18265 m .58684 1.16578 L .58788 1.1646 L 0 .686 .18 r
F
.58794 1.16534 m .58804 1.16749 L .58848 1.17239 L 0 0 .062 r
F
.58744 1.17866 m .58788 1.1646 L .58852 1.17299 L 0 .686 .18 r
F
.58851 1.17394 m .58852 1.17299 L .58865 1.17461 L F
.58852 1.17299 m .58877 1.17774 L .58906 1.17994 L 0 0 .062 r
F
.58851 1.17394 m .58865 1.17461 L .58906 1.17994 L 0 .686 .18 r
F
.58837 1.18073 m .58851 1.17394 L .58906 1.17994 L F
.58602 1.12347 m .58794 1.16534 L .58848 1.17239 L 0 0 .062 r
F
.58816 1.17662 m .58852 1.17299 L .58837 1.18073 L 0 .686 .18 r
F
.58744 1.17866 m .58852 1.17299 L .58768 1.18151 L F
.58928 1.20025 m .58961 1.20147 L .58964 1.20265 L F
.58677 1.14177 m .58679 1.14199 L .58625 1.14151 L 0 .762 .122 r
F
.58677 1.14177 m .58625 1.14151 L .58624 1.14133 L F
.58612 1.13962 m .58677 1.14177 L .58627 1.14136 L F
.58612 1.13962 m .58627 1.14143 L .58626 1.14127 L 0 0 .123 r
F
.58612 1.13962 m .58627 1.14136 L .58624 1.14133 L 0 .762 .122 r
F
.58528 1.12728 m .58528 1.12723 L .58418 1.1123 L 0 0 .123 r
F
.58612 1.13962 m .58626 1.14127 L .58199 1.08066 L F
.58602 1.12347 m .58655 1.13971 L .58804 1.16749 L 0 0 .062 r
F
.58875 1.18349 m .58602 1.12347 L .5889 1.18082 L F
.58852 1.17299 m .59075 1.16135 L .58906 1.17994 L 0 .686 .18 r
F
.58841 1.17072 m .58852 1.17299 L .58906 1.17994 L 0 0 .062 r
F
.58602 1.12347 m .58841 1.17072 L .58906 1.17994 L F
.58881 1.17907 m .58602 1.12347 L .58879 1.17509 L F
.5835 1.0233 m .58471 1.07334 L .58972 1.20604 L 0 0 .1 r
F
.58977 1.20671 m .58972 1.20604 L .59006 1.21521 L F
.58922 1.18713 m .58881 1.17907 L .58906 1.17994 L 0 0 .062 r
F
.58881 1.17907 m .58879 1.17509 L .58906 1.17994 L F
.5835 1.0233 m .58972 1.20604 L .58977 1.20671 L 0 0 .1 r
F
.58668 1.18265 m .58716 1.17536 L .58744 1.17866 L 0 .686 .18 r
F
.58716 1.17536 m .58788 1.1646 L .58744 1.17866 L F
.59197 1.25236 m .59258 1.26454 L .59263 1.26922 L 0 0 .1 r
F
.59189 1.22095 m .59204 1.22312 L .59048 1.21611 L 0 .686 .18 r
F
.59204 1.22312 m .59204 1.22436 L .59048 1.21611 L F
.58906 1.17994 m .58942 1.17594 L .58954 1.17939 L F
.59049 1.22091 m .59091 1.2184 L .59092 1.2186 L 0 .877 .163 r
F
.59049 1.22091 m .59048 1.21611 L .59091 1.2184 L F
.58961 1.18782 m .59582 1.17225 L .59967 1.20556 L 0 .686 .18 r
F
.58922 1.18713 m .58951 1.18648 L .58961 1.18782 L F
.58951 1.18648 m .59582 1.17225 L .58961 1.18782 L F
.58921 1.1867 m .59582 1.17225 L .58922 1.18713 L F
.59101 1.22154 m .5835 1.0233 L .58986 1.20772 L 0 0 .1 r
F
.5891 1.17869 m .59067 1.21751 L .59056 1.21619 L F
.59007 1.2153 m .59006 1.21521 L .5901 1.21616 L F
.58911 1.21765 m .58916 1.21316 L .59006 1.21518 L 0 .877 .163 r
F
.59016 1.21647 m .59006 1.21518 L .59048 1.21611 L F
.59007 1.21527 m .59006 1.21521 L .59007 1.2153 L 0 0 .1 r
F
.59006 1.21518 m .59006 1.21521 L .59007 1.21527 L F
.59007 1.21527 m .5901 1.21616 L .59016 1.21647 L F
.58911 1.21765 m .59006 1.21518 L .59016 1.21647 L 0 .877 .163 r
F
.5835 1.0233 m .59006 1.21518 L .59007 1.21527 L 0 0 .1 r
F
.59101 1.22154 m .58986 1.20772 L .59016 1.21647 L F
.59067 1.21751 m .59198 1.24979 L .59056 1.21619 L F
.59056 1.21619 m .59198 1.24979 L .59197 1.25236 L F
.59198 1.24979 m .59258 1.26454 L .59197 1.25236 L F
.59204 1.22312 m .59219 1.22514 L .59204 1.22436 L 0 .686 .18 r
F
.59258 1.26454 m .59285 1.27123 L .59263 1.26922 L 0 0 .1 r
F
.59263 1.26538 m .59226 1.25535 L .59534 1.33585 L F
.59293 1.27688 m .59285 1.27123 L .59684 1.37708 L F
.5921 1.25109 m .59154 1.23602 L .59179 1.24252 L F
.59226 1.25535 m .59179 1.24252 L .59534 1.33585 L F
.5921 1.25109 m .59179 1.24252 L .59226 1.25535 L F
.59286 1.28447 m .59276 1.28023 L .59612 1.37364 L F
.59426 1.32775 m .59411 1.32375 L .5941 1.32322 L F
.59319 1.29233 m .59383 1.29836 L .59438 1.33273 L 0 .877 .163 r
F
.59172 1.24052 m .59491 1.32467 L .59495 1.32564 L 0 0 .1 r
F
.59172 1.24051 m .59491 1.32467 L .59172 1.24052 L F
.59172 1.24051 m .59172 1.2403 L .59491 1.32467 L F
.59495 1.32564 m .59491 1.32467 L .59534 1.33585 L F
.59376 1.27724 m .59393 1.27059 L .59801 1.3463 L 0 0 .062 r
F
.59644 1.36646 m .59534 1.33585 L .59754 1.39392 L 0 0 .1 r
F
.59383 1.29836 m .59948 1.35151 L .5952 1.33577 L 0 .877 .163 r
F
.59383 1.29836 m .5952 1.33577 L .59438 1.33273 L F
.59376 1.27724 m .5916 1.23444 L .59393 1.27059 L 0 0 .062 r
F
.59244 1.26046 m .59963 1.3018 L .59364 1.29298 L 0 .877 .163 r
F
.59244 1.26046 m .59364 1.29298 L .59319 1.29233 L F
.5914 1.23271 m .59115 1.22551 L .59154 1.23602 L 0 0 .1 r
F
.5914 1.23271 m .59154 1.23602 L .5921 1.25109 L F
.59319 1.29233 m .59963 1.3018 L .59948 1.35151 L 0 .877 .163 r
F
.59195 1.21028 m .59971 1.2394 L .59196 1.21114 L 0 .686 .18 r
F
.59205 1.21898 m .59971 1.2394 L .59576 1.24398 L F
.59196 1.21114 m .59971 1.2394 L .59205 1.21898 L F
.59976 1.39659 m .59801 1.3463 L .60024 1.39757 L 0 0 .062 r
F
.5952 1.33577 m .59948 1.35151 L .59545 1.34243 L 0 .877 .163 r
F
.59244 1.26046 m .59576 1.24398 L .59963 1.3018 L F
.59167 1.23915 m .59172 1.2403 L .59172 1.24049 L 0 0 .1 r
F
.59153 1.23547 m .59172 1.2403 L .59164 1.23859 L F
.59153 1.23547 m .59151 1.23478 L .59172 1.2403 L F
.5915 1.23449 m .59576 1.24398 L .59244 1.26046 L 0 .877 .163 r
F
.59205 1.21898 m .59576 1.24398 L .59205 1.2219 L 0 .686 .18 r
F
.5917 1.19151 m .59967 1.20556 L .59177 1.19659 L F
.59189 1.22095 m .59576 1.24398 L .59219 1.22514 L F
.59827 1.38759 m .59594 1.31805 L .59796 1.38789 L 0 0 .116 r
F
.58961 1.17932 m .59075 1.16135 L .59582 1.17225 L 0 .686 .18 r
F
.58954 1.17939 m .58958 1.17877 L .58961 1.17932 L F
.58958 1.17877 m .59075 1.16135 L .58961 1.17932 L F
.59313 1.23813 m .59219 1.22514 L .59576 1.24398 L 0 .877 .163 r
F
.59827 1.38759 m .59572 1.26117 L .5941 1.21744 L 0 0 .116 r
F
.58942 1.17594 m .59075 1.16135 L .58954 1.17939 L 0 .686 .18 r
F
.58951 1.13564 m .59031 1.11863 L .59524 1.12187 L 0 .591 .175 r
F
.58976 1.12237 m .59031 1.11863 L .58951 1.13564 L F
.58973 .91837 m .58024 .92948 L .59244 .92622 L 0 1 .498 r
F
.58978 .92286 m .58029 .93345 L .59249 .92985 L 0 1 .52 r
F
.58978 .92286 m .59249 .92985 L .60074 .925 L F
.58978 .92286 m .60074 .925 L .59953 .92213 L F
.58973 .91837 m .57051 .92947 L .58024 .92948 L 0 1 .498 r
F
.58973 .91837 m .56971 .92618 L .57051 .92947 L F
.58973 .91837 m .57795 .92142 L .56971 .92618 L F
.58701 .91036 m .57795 .92142 L .58973 .91837 L 0 1 .494 r
F
.58701 .91036 m .58973 .91837 L .59766 .91375 L F
.58707 .91585 m .58978 .92286 L .59771 .9178 L 0 1 .518 r
F
.59072 1.00053 m .58106 1.00674 L .59343 1.00543 L 0 1 .539 r
F
.59067 .99593 m .59339 1.00171 L .60177 .99932 L 0 1 .534 r
F
.59072 1.00053 m .59343 1.00543 L .60182 1.00294 L 0 1 .539 r
F
.59072 1.00053 m .60182 1.00294 L .60061 1.00093 L F
.588 .9957 m .59072 1.00053 L .59878 .99793 L 0 1 .536 r
F
.588 .9957 m .59878 .99793 L .59757 .99593 L F
.58527 .99094 m .588 .9957 L .59574 .99293 L 0 1 .53 r
F
.58527 .99094 m .59574 .99293 L .59452 .99093 L F
.58253 .98626 m .58527 .99094 L .59269 .98791 L 0 1 .518 r
F
.58253 .98626 m .59269 .98791 L .59146 .98589 L F
.59331 .95231 m .58808 .96416 L .59719 .96046 L 0 1 .49 r
F
.59331 .95231 m .58462 .95582 L .57905 .96099 L F
.59348 .9657 m .58471 .96403 L .57908 .96338 L 0 .591 .248 r
F
.5885 .94029 m .58462 .95582 L .59331 .95231 L 0 1 .453 r
F
.5885 .94029 m .59331 .95231 L .59827 .94634 L F
.5885 .94029 m .59827 .94634 L .5962 .94188 L F
.5888 .96548 m .58471 .96403 L .59348 .9657 L 0 0 0 r
F
.58481 .93004 m .5885 .94029 L .59344 .93573 L 0 1 .433 r
F
.58481 .93004 m .59344 .93573 L .59185 .932 L F
.59909 .91795 m .58946 .92627 L .59627 .92818 L 0 1 .472 r
F
.58978 .92286 m .57055 .93419 L .58029 .93345 L 0 1 .52 r
F
.58978 .92286 m .56976 .93157 L .57055 .93419 L F
.58978 .92286 m .578 .92671 L .56976 .93157 L F
.58707 .91585 m .578 .92671 L .58978 .92286 L 0 1 .518 r
F
.59909 .91795 m .58786 .92237 L .58946 .92627 L 0 1 .472 r
F
.58522 .96644 m .59383 .96618 L .59228 .96628 L 0 0 0 r
F
.59974 .96547 m .58995 .96656 L .59676 .96581 L F
.59974 .96547 m .58839 .96684 L .58995 .96656 L F
.59974 .96547 m .59258 .96637 L .58839 .96684 L F
.59516 .96618 m .58605 .96732 L .59258 .96637 L F
.59516 .96618 m .58448 .96768 L .58605 .96732 L F
.59516 .96618 m .58838 .96719 L .58448 .96768 L F
.59056 .96714 m .58838 .96719 L .59516 .96618 L F
.59056 .96714 m .59516 .96618 L .59878 .96571 L F
.59056 .96714 m .59878 .96571 L .59683 .96609 L F
.58593 .96828 m .59056 .96714 L .59388 .96675 L F
.58593 .96828 m .59388 .96675 L .59192 .96724 L F
.59484 .96772 m .58896 .96805 L .59471 .96685 L F
.59484 .96772 m .58699 .96864 L .58896 .96805 L F
.59484 .96772 m .5895 .9685 L .58699 .96864 L F
.58898 .97006 m .5895 .9685 L .59484 .96772 L F
.58898 .97006 m .59484 .96772 L .59701 .96791 L F
.58898 .97006 m .59701 .96791 L .59455 .96894 L F
.5831 .97272 m .58898 .97006 L .59086 .97059 L F
.5831 .97272 m .59086 .97059 L .58839 .97177 L F
.59401 .97248 m .58839 .97177 L .59086 .97059 L F
.59401 .97248 m .58974 .97258 L .58839 .97177 L F
.58689 .97676 m .58973 .97258 L .59401 .97248 L F
.58689 .97676 m .59401 .97248 L .59501 .9738 L F
.58689 .97676 m .59501 .9738 L .59205 .97566 L F
.57978 .98161 m .58253 .98626 L .58962 .98281 L 0 1 .491 r
F
.57978 .98161 m .58962 .98281 L .58839 .98073 L F
.58805 .98402 m .59251 .97746 L .59611 .97798 L 0 0 .005 r
F
.58805 .98402 m .58759 .97854 L .59251 .97746 L F
.58805 .98402 m .59611 .97798 L .59632 .98032 L F
.58805 .98402 m .59632 .98032 L .59299 .98293 L F
.59497 1.04829 m .59169 1.03877 L .59718 1.04613 L 0 .35 0 r
F
.5867 .99516 m .59269 .98601 L .59563 .98749 L 0 .144 .051 r
F
.5867 .99516 m .58798 .9868 L .59269 .98601 L F
.5867 .99516 m .59563 .98749 L .59509 .99107 L F
.5867 .99516 m .59509 .99107 L .59142 .99436 L F
.59273 1.00184 m .5904 .99898 L .59142 .99436 L 0 .182 .071 r
F
.588 .9957 m .57877 1.00199 L .59072 1.00053 L 0 1 .536 r
F
.58299 1.01 m .5904 .99898 L .59273 1.00184 L 0 .259 .082 r
F
.58299 1.01 m .59273 1.00184 L .59149 1.00658 L F
.58299 1.01 m .59149 1.00658 L .58751 1.01005 L F
.58759 1.02057 m .59149 1.00658 L .59597 1.0068 L 0 .286 .097 r
F
.58759 1.02057 m .58751 1.01005 L .59149 1.00658 L F
.58759 1.02057 m .59597 1.0068 L .59797 1.01056 L F
.58759 1.02057 m .59797 1.01056 L .59631 1.01656 L F
.58759 1.02057 m .59631 1.01656 L .59209 1.02079 L F
.59146 1.03435 m .59631 1.01656 L .60072 1.01716 L 0 .306 .11 r
F
.59146 1.03435 m .59209 1.02079 L .59631 1.01656 L F
.60011 1.02472 m .60072 1.01716 L .60238 1.0222 L F
.59146 1.03435 m .60021 1.0181 L .60011 1.02472 L F
.60021 1.0181 m .60072 1.01716 L .60011 1.02472 L F
.59682 1.0804 m .59745 1.06766 L .60262 1.07899 L 0 .663 .074 r
F
.59693 1.07767 m .59981 1.0704 L .59996 1.07318 L 0 .364 .153 r
F
.59693 1.07767 m .6002 1.0628 L .60036 1.069 L F
.60776 1.40993 m .61189 1.35206 L .61689 1.36669 L 0 .683 .187 r
F
.60776 1.40993 m .60748 1.35795 L .61189 1.35206 L F
.60776 1.40993 m .61689 1.36669 L .61919 1.39228 L F
.60118 1.31486 m .60941 1.32545 L .61447 1.39258 L 0 .998 .153 r
F
.60826 1.40269 m .60118 1.31486 L .60884 1.40309 L F
.60826 1.40269 m .60615 1.3819 L .60118 1.31486 L F
.60884 1.40309 m .60118 1.31486 L .61113 1.40421 L F
.61113 1.40421 m .60118 1.31486 L .61447 1.39258 L F
.59948 1.35151 m .60471 1.29809 L .60639 1.33433 L 0 .474 .207 r
F
.60471 1.29809 m .60838 1.26057 L .60639 1.33433 L F
.61321 1.33241 m .61171 1.29131 L .61576 1.28349 L 0 .598 .173 r
F
.61252 1.32612 m .61113 1.28967 L .61385 1.27145 L 0 .832 .184 r
F
.60639 1.33433 m .60838 1.26057 L .61231 1.3196 L 0 .474 .207 r
F
.60118 1.31486 m .60041 1.28351 L .60392 1.28803 L 0 .998 .153 r
F
.59948 1.35151 m .60344 1.26313 L .60838 1.26057 L 0 .474 .207 r
F
.60919 1.38932 m .59948 1.35151 L .61231 1.3196 L F
.60253 1.39969 m .60212 1.36666 L .60615 1.3819 L 0 1 .157 r
F
.60228 1.39946 m .60212 1.36666 L .60253 1.39969 L 0 .566 0 r
F
.60329 1.40008 m .60615 1.3819 L .60826 1.40269 L 0 1 .157 r
F
.60253 1.39969 m .60615 1.3819 L .60329 1.40008 L F
.60333 1.38942 m .59948 1.35151 L .60919 1.38932 L 0 .474 .207 r
F
.60737 1.37996 m .60387 1.15771 L .60634 1.38032 L 0 .288 .209 r
F
.59981 1.0704 m .60036 1.069 L .59996 1.07318 L 0 .364 .153 r
F
.60036 1.069 m .60764 1.05058 L .60043 1.07179 L F
.60036 1.069 m .60043 1.07179 L .59996 1.07318 L F
.60387 1.15771 m .60532 1.311 L .60634 1.38032 L 0 .288 .209 r
F
.58933 .60257 m .59281 .69461 L .59195 .66754 L 0 .091 .152 r
F
.59092 .68121 m .59381 .7177 L .59441 .72576 L 0 .066 .149 r
F
.58945 .60051 m .59431 .72615 L .58959 .59805 L 0 .091 .152 r
F
.58959 .59805 m .58936 .60204 L .58937 .59737 L 0 0 .087 r
F
.58959 .59805 m .58937 .59737 L .58938 .58969 L F
.58919 .60505 m .5892 .59683 L .58921 .59688 L F
.58912 .60632 m .58914 .59665 L .58919 .60505 L F
.58914 .59665 m .58918 .59678 L .58919 .60505 L F
.58912 .60632 m .58908 .59647 L .58914 .59665 L F
.58912 .60632 m .58885 .61117 L .58897 .59052 L F
.58912 .60632 m .58897 .59052 L .58907 .59165 L F
.58746 .59921 m .58854 .5678 L .58757 .59058 L 0 0 .1 r
F
.58854 .5678 m .58893 .55665 L .5885 .56738 L F
.58838 .57247 m .58845 .56498 L .58854 .5678 L F
.58854 .5678 m .5885 .56738 L .58757 .59058 L F
.5847 .65702 m .58493 .65223 L .58469 .65692 L 0 0 .064 r
F
.58098 .67171 m .58335 .68525 L .58098 .67171 L 0 .238 .224 r
F
.5847 .65702 m .58469 .65692 L .5832 .68562 L 0 0 .064 r
F
.58098 .67172 m .58339 .68719 L .58098 .67171 L 0 .238 .224 r
F
.58339 .68719 m .58346 .68762 L .58339 .68719 L F
.58339 .68719 m .58339 .68719 L .58098 .67171 L F
.58255 .68176 m .58341 .6903 L .58346 .68762 L F
.58098 .67167 m .58237 .68231 L .58255 .68176 L F
.58237 .68231 m .58341 .6903 L .58255 .68176 L F
.58292 .71302 m .58311 .71438 L .58313 .71401 L 0 .248 .238 r
F
.58197 .7085 m .58293 .71345 L .58292 .71302 L F
.58293 .71345 m .58311 .71438 L .58292 .71302 L F
.58824 .57535 m .58933 .60257 L .58835 .57218 L 0 .091 .152 r
F
.58936 .60204 m .58933 .60257 L .58938 .58969 L 0 0 .087 r
F
.58914 .59665 m .58911 .59215 L .58915 .59267 L F
.58933 .60257 m .58945 .60051 L .58835 .57218 L 0 .091 .152 r
F
.58929 .64803 m .58915 .64935 L .58933 .60257 L 0 0 .087 r
F
.58933 .60257 m .59431 .72615 L .58945 .60051 L 0 .091 .152 r
F
.58929 .64803 m .58933 .60257 L .58936 .60204 L 0 0 .087 r
F
.58931 .64415 m .58929 .64803 L .5893 .64285 L F
.58931 .64415 m .5893 .64285 L .58936 .60204 L F
.58959 .59805 m .58931 .64415 L .58936 .60204 L F
.58511 .68834 m .58913 .71054 L .58523 .68715 L 0 .238 .224 r
F
.58959 .59807 m .58967 .59831 L .5886 .57529 L 0 .091 .152 r
F
.58967 .59831 m .58969 .5984 L .58954 .59517 L F
.58967 .59831 m .58954 .59517 L .5886 .57529 L F
.58335 .68525 m .5847 .65702 L .58331 .68347 L 0 0 .064 r
F
.58339 .68719 m .58346 .68762 L .58335 .68525 L 0 .238 .224 r
F
.58315 .68944 m .5835 .68684 L .58345 .68328 L 0 0 .064 r
F
.58332 .68285 m .58552 .63335 L .58332 .68285 L F
.58331 .6832 m .58552 .63335 L .58331 .68317 L F
.58331 .68345 m .58493 .65223 L .58331 .68344 L F
.58333 .68318 m .58493 .65223 L .58332 .68288 L F
.58321 .68538 m .58493 .65223 L .58321 .68535 L F
.58551 .63333 m .58552 .63335 L .58553 .63302 L F
.58553 .63302 m .58575 .62865 L .58576 .6277 L F
.58332 .68285 m .58759 .58642 L .58359 .67946 L F
.58346 .68762 m .58433 .67276 L .58425 .67293 L F
.58346 .68765 m .58433 .67276 L .58346 .68762 L F
.58332 .68285 m .5849 .69037 L .58356 .6798 L 0 .238 .224 r
F
.5849 .69037 m .58913 .71054 L .58511 .68834 L F
.5849 .69037 m .58511 .68834 L .58356 .6798 L F
.58915 .64935 m .58914 .6264 L .58925 .62469 L 0 0 .087 r
F
.58509 .67244 m .58482 .68468 L .58523 .68715 L 0 .238 .216 r
F
.58576 .67881 m .58523 .68715 L .58913 .71054 L F
.58509 .67244 m .58523 .68715 L .58576 .67881 L F
.58914 .62567 m .58912 .60632 L .58919 .60505 L 0 0 .087 r
F
.58576 .67881 m .58913 .71054 L .58617 .67247 L 0 .238 .216 r
F
.58914 .6264 m .58908 .62657 L .58914 .62567 L 0 0 .087 r
F
.58638 .66928 m .58913 .71054 L .58938 .71054 L 0 .238 .216 r
F
.58638 .66928 m .58938 .71054 L .58924 .69027 L F
.58617 .67247 m .58913 .71054 L .58638 .66928 L F
.58659 .6512 m .5874 .64308 L .58678 .64333 L 0 0 .001 r
F
.58651 .64027 m .5876 .6504 L .58656 .64044 L 0 .238 .216 r
F
.58637 .62757 m .58712 .60493 L .5866 .62421 L 0 0 .1 r
F
.58606 .63637 m .58721 .60151 L .58724 .60123 L F
.5856 .65001 m .58721 .60151 L .58606 .63637 L F
.5856 .65001 m .58705 .60292 L .58721 .60151 L F
.58552 .65108 m .58705 .60292 L .5856 .65001 L F
.58735 .59784 m .58786 .58263 L .58737 .59752 L F
.58705 .60292 m .58759 .58642 L .58724 .60123 L F
.58554 .65136 m .58753 .5939 L .58755 .59134 L F
.58798 .57864 m .58687 .6128 L .58685 .61347 L F
.58838 .56639 m .58799 .57861 L .58798 .57864 L F
.58799 .57861 m .58687 .6128 L .58798 .57864 L F
.58838 .5664 m .58768 .58809 L .58838 .56639 L F
.58768 .58809 m .58687 .6128 L .58768 .58811 L F
.58768 .58809 m .58768 .58811 L .58838 .56639 L F
.58686 .54098 m .58835 .57218 L .58686 .54089 L 0 .091 .152 r
F
.5885 .56738 m .58893 .55665 L .58838 .56629 L 0 0 .1 r
F
.58852 .562 m .58854 .56826 L .58853 .56264 L 0 0 .087 r
F
.58961 .59471 m .58959 .59805 L .58938 .58969 L F
.59132 .64325 m .5936 .65476 L .59777 .63934 L 0 1 .222 r
F
.58978 .59868 m .59261 .65461 L .59261 .65453 L 0 .091 .152 r
F
.58929 .58898 m .58959 .59805 L .58961 .59471 L 0 0 .087 r
F
.58926 .60071 m .58925 .6041 L .58933 .60257 L 0 .091 .152 r
F
.58763 .56024 m .58925 .6041 L .58926 .60071 L F
.58761 .56095 m .58925 .6041 L .58763 .56024 L F
.58799 .5786 m .588 .57828 L .58687 .6128 L 0 0 .1 r
F
.58795 .57921 m .58798 .57864 L .58769 .58753 L F
.58793 .6096 m .58862 .59927 L .58793 .60967 L 0 0 .001 r
F
.58793 .60967 m .58862 .59927 L .58789 .61032 L F
.58808 .60877 m .58862 .59927 L .58809 .60812 L 0 0 .064 r
F
.58811 .60785 m .58862 .59927 L .58809 .6021 L F
.58761 .56095 m .58885 .61117 L .58925 .6041 L 0 .091 .152 r
F
.58679 .53942 m .58751 .56446 L .58761 .56095 L F
.58751 .56446 m .58885 .61117 L .58761 .56095 L F
.58905 .66387 m .59092 .68121 L .58905 .66373 L 0 .238 .216 r
F
.58719 .66542 m .58861 .65514 L .58716 .66534 L 0 .902 .101 r
F
.5876 .6504 m .58905 .66387 L .58761 .65026 L 0 .238 .216 r
F
.58905 .66387 m .58905 .66373 L .58761 .65026 L F
.5858 .65291 m .58601 .65404 L .58651 .64027 L F
.58908 .62753 m .58886 .63067 L .58908 .62728 L 0 0 .087 r
F
.58701 .65957 m .59092 .68121 L .5876 .6504 L 0 .238 .216 r
F
.58701 .65957 m .5892 .68445 L .5891 .67116 L F
.58694 .66724 m .58719 .66542 L .58692 .66727 L 0 .902 .101 r
F
.58682 .66239 m .5892 .68445 L .58701 .65957 L 0 .238 .216 r
F
.58532 .66154 m .58638 .66928 L .5858 .65291 L F
.58679 .53942 m .58867 .60739 L .58885 .61117 L 0 .091 .152 r
F
.58864 .60562 m .58861 .60185 L .58861 .60216 L 0 0 .087 r
F
.58638 .66928 m .58924 .69027 L .58682 .66239 L 0 .238 .216 r
F
.58924 .69027 m .5892 .68445 L .58682 .66239 L F
.589 .66736 m .58886 .63104 L .58908 .62769 L 0 0 .087 r
F
.5849 .69037 m .58948 .71924 L .58913 .71054 L 0 .238 .224 r
F
.58891 .71118 m .58889 .668 L .589 .66736 L 0 0 .087 r
F
.58889 .668 m .58886 .63104 L .589 .66736 L F
.58483 .67314 m .58484 .67304 L .58475 .67575 L 0 0 .1 r
F
.58474 .68961 m .58478 .69102 L .5849 .69037 L 0 .238 .224 r
F
.58393 .68573 m .58473 .69069 L .58474 .68961 L F
.58473 .69069 m .58478 .69102 L .58474 .68961 L F
.58392 .68582 m .58473 .69069 L .58393 .68573 L F
.58473 .69069 m .58478 .69102 L .58473 .69069 L F
.58473 .69069 m .58473 .69069 L .58393 .68573 L F
.58499 .66908 m .58499 .66905 L .58492 .671 L 0 0 .1 r
F
.58349 .75461 m .59127 .7604 L .5893 .75502 L 0 1 .4 r
F
.59337 .76761 m .58965 .782 L .59255 .78225 L 0 1 .358 r
F
.59337 .76761 m .59 .77572 L .58965 .782 L F
.58554 .76962 m .59337 .76761 L .59348 .76219 L 0 1 .331 r
F
.58554 .76962 m .59 .77572 L .59337 .76761 L F
.58554 .76962 m .59348 .76219 L .59024 .76309 L F
.59254 .74823 m .59024 .76309 L .59348 .76219 L 0 1 .326 r
F
.59254 .74823 m .58984 .7571 L .59024 .76309 L F
.58394 .75517 m .59254 .74823 L .59192 .74381 L 0 1 .293 r
F
.58394 .75517 m .58984 .7571 L .59254 .74823 L F
.58394 .75517 m .59192 .74381 L .5884 .7468 L F
.58436 .72086 m .59071 .76158 L .59431 .77239 L 0 .248 .238 r
F
.58311 .71438 m .58436 .72252 L .58436 .72086 L F
.58309 .71476 m .58436 .72252 L .58311 .71438 L F
.58307 .71518 m .58435 .72295 L .58309 .71486 L F
.58435 .72295 m .58436 .72252 L .58309 .71476 L F
.58309 .71486 m .58309 .71476 L .58261 .71179 L F
.58435 .72295 m .58309 .71476 L .58309 .71486 L F
.58313 .71401 m .58436 .72041 L .58435 .71982 L F
.58311 .71438 m .58436 .72086 L .58313 .71401 L F
.58436 .72086 m .58436 .72041 L .58313 .71401 L F
.58483 .67314 m .58475 .67575 L .58474 .67583 L 0 0 .1 r
F
.58448 .68487 m .58466 .68372 L .58424 .68117 L 0 .238 .224 r
F
.58484 .67007 m .58495 .6681 L .58461 .67948 L 0 0 .1 r
F
.58362 .68678 m .58428 .69054 L .58382 .68521 L 0 .238 .224 r
F
.58428 .69054 m .59323 .74175 L .58445 .68904 L F
.58487 .67266 m .58487 .6726 L .58478 .6754 L 0 0 .1 r
F
.58428 .69054 m .58445 .68904 L .58392 .68582 L 0 .238 .224 r
F
.58315 .71345 m .58435 .71921 L .58435 .71844 L 0 .248 .238 r
F
.58432 .684 m .58448 .68487 L .58436 .68305 L 0 .238 .224 r
F
.58315 .71357 m .58435 .71934 L .58315 .71345 L 0 .248 .238 r
F
.58435 .71934 m .59422 .7669 L .58435 .71921 L F
.58435 .71934 m .58435 .71921 L .58315 .71345 L F
.58428 .69054 m .58392 .68582 L .58389 .68611 L 0 .238 .224 r
F
.58292 .71302 m .58313 .71401 L .58292 .71246 L 0 .248 .238 r
F
.58313 .71401 m .58435 .71982 L .58315 .71357 L F
.58435 .71982 m .58435 .71934 L .58315 .71357 L F
.58293 .71137 m .58409 .71738 L .584 .71455 L F
.58292 .71246 m .58409 .71738 L .58293 .71137 L F
.58328 .69568 m .58315 .70091 L .58553 .71911 L 0 .238 .224 r
F
.58409 .68987 m .5847 .69394 L .58409 .6898 L F
.5847 .69394 m .5847 .69383 L .58377 .68763 L F
.58348 .68778 m .58365 .68885 L .58362 .68678 L F
.58409 .69165 m .58469 .69555 L .58423 .69082 L F
.58469 .69555 m .59376 .75376 L .5847 .69394 L F
.58469 .69555 m .5847 .69394 L .58423 .69082 L F
.58492 .67122 m .58492 .67118 L .5848 .67448 L 0 0 .1 r
F
.58504 .66706 m .58505 .66705 L .58501 .66804 L F
.58256 .71208 m .5843 .72773 L .58435 .72295 L 0 .248 .238 r
F
.58419 .72691 m .58266 .73576 L .58435 .73737 L 0 1 .238 r
F
.58249 .71294 m .58585 .74177 L .58256 .71208 L 0 .248 .238 r
F
.58465 .67841 m .58436 .6875 L .58417 .69295 L 0 0 .1 r
F
.58341 .6903 m .58331 .68868 L .58372 .68487 L 0 0 .064 r
F
.58332 .6901 m .58343 .68903 L .58344 .68788 L F
.58197 .7085 m .58212 .71906 L .58278 .7231 L 0 .248 .238 r
F
.58197 .7085 m .58278 .7231 L .58285 .71897 L F
.58197 .7085 m .58362 .72822 L .58357 .72216 L F
.58197 .7085 m .58249 .71294 L .58256 .71208 L F
.58197 .7085 m .58256 .71208 L .58261 .71179 L F
.58155 .72291 m .58311 .69246 L .58341 .6903 L 0 0 .064 r
F
.58155 .72291 m .58331 .69128 L .58331 .69105 L F
.58155 .72291 m .58331 .69105 L .58332 .6901 L F
.58331 .69128 m .58343 .68903 L .58332 .6901 L F
.58285 .71897 m .58278 .7231 L .58362 .72822 L 0 .248 .238 r
F
.58357 .72216 m .58362 .72822 L .58585 .74177 L F
.58321 .68528 m .58331 .6832 L .58331 .68317 L 0 0 .064 r
F
.58155 .72291 m .58251 .6973 L .58275 .69579 L F
.58155 .72291 m .58275 .69577 L .58296 .69447 L F
.58155 .72291 m .58321 .68531 L .58321 .68528 L F
.58321 .68531 m .58331 .6832 L .58321 .68528 L F
.58501 .66804 m .58501 .66804 L .58312 .72383 L 0 0 .1 r
F
.58504 .66706 m .58501 .66804 L .58501 .66804 L F
.58394 .75517 m .58539 .76547 L .58984 .7571 L 0 1 .293 r
F
.58435 .72295 m .58585 .74177 L .59071 .76158 L 0 .248 .238 r
F
.5843 .72773 m .58585 .74177 L .58435 .72295 L F
.58908 .62769 m .58886 .6309 L .58908 .62753 L 0 0 .087 r
F
.58886 .63104 m .58886 .6309 L .58908 .62769 L F
.58886 .6309 m .58886 .63067 L .58908 .62753 L F
.58891 .71118 m .58907 .6501 L .5891 .64981 L F
.58891 .71118 m .5891 .64981 L .58915 .64935 L F
.58862 .5779 m .58899 .58557 L .58862 .57788 L 0 .091 .152 r
F
.58914 .62666 m .58908 .62728 L .58914 .6264 L 0 0 .087 r
F
.58891 .71118 m .58908 .62753 L .58914 .62666 L F
.58908 .62753 m .58908 .62728 L .58914 .62666 L F
.58908 .62728 m .58908 .62657 L .58914 .6264 L F
.58908 .62657 m .58912 .60632 L .58914 .62567 L F
.58907 .6501 m .58914 .6264 L .58915 .64935 L F
.58914 .6264 m .58919 .60505 L .58925 .62469 L F
.58862 .57781 m .58959 .59807 L .5886 .57529 L 0 .091 .152 r
F
.58899 .58557 m .58959 .59805 L .58899 .58555 L F
.58908 .62728 m .58885 .61117 L .58912 .60632 L 0 0 .087 r
F
.58723 .64438 m .58851 .63424 L .58847 .63174 L 0 .742 .063 r
F
.58718 .64537 m .58735 .64295 L .58901 .62621 L 0 0 .001 r
F
.5874 .64308 m .58901 .62621 L .58716 .63884 L F
.58847 .63174 m .58896 .62833 L .58901 .62621 L 0 .742 .063 r
F
.58886 .63067 m .58885 .61117 L .58908 .62728 L 0 0 .087 r
F
.58835 .57218 m .58945 .60051 L .58959 .59805 L 0 .091 .152 r
F
.58899 .58557 m .58769 .5582 L .58769 .5582 L F
.58793 .562 m .58862 .57781 L .5886 .57529 L F
.5886 .57529 m .58839 .57119 L .58839 .57119 L F
.5891 .67116 m .59201 .71058 L .59092 .68121 L 0 .238 .216 r
F
.5892 .68445 m .59201 .71058 L .5891 .67116 L F
.58929 .64803 m .58891 .71118 L .58915 .64935 L 0 0 .087 r
F
.58959 .59805 m .58959 .59807 L .58899 .58555 L 0 .091 .152 r
F
.58929 .58898 m .58977 .59865 L .58978 .59868 L F
.5886 .57529 m .5893 .58926 L .58929 .58898 L F
.5893 .58926 m .58977 .59865 L .58929 .58898 L F
.58855 .56925 m .58855 .56978 L .58853 .56264 L 0 0 .087 r
F
.58854 .56826 m .58855 .56925 L .58853 .56264 L F
.59293 .66089 m .59293 .66089 L .5886 .57529 L 0 .091 .152 r
F
.58978 .59868 m .59127 .62832 L .59562 .71431 L F
.59293 .66089 m .5886 .57529 L .5886 .57529 L F
.5886 .57529 m .588 .56335 L .588 .56335 L F
.59293 .66089 m .5886 .57529 L .5886 .57529 L F
.5886 .57529 m .588 .56335 L .5886 .57529 L F
.58929 .58887 m .5886 .57529 L .5886 .57529 L F
.58841 .57121 m .58858 .57475 L .58842 .57093 L F
.58979 .59875 m .58982 .59952 L .58859 .57527 L F
.58859 .57527 m .58859 .57527 L .58791 .56185 L F
.5886 .57529 m .58939 .59194 L .5893 .58926 L F
.58979 .59875 m .58859 .57527 L .58859 .57527 L F
.58862 .57787 m .58862 .57781 L .58769 .5582 L F
.58792 .56299 m .58862 .57781 L .58793 .562 L F
.58856 .57517 m .58861 .60143 L .58864 .60523 L 0 0 .087 r
F
.5885 .57329 m .5886 .57529 L .58854 .57421 L 0 .091 .152 r
F
.5886 .57529 m .58839 .57119 L .5886 .57529 L F
.5886 .57529 m .5886 .57529 L .58839 .57119 L F
.5886 .57529 m .58859 .57527 L .58854 .57421 L F
.58858 .57519 m .58858 .57475 L .58841 .57121 L F
.5886 .57529 m .58839 .57119 L .58839 .57119 L F
.59305 .66324 m .5886 .57529 L .5886 .57529 L F
.5886 .57529 m .58839 .57119 L .5886 .57529 L F
.58686 .54079 m .58856 .57363 L .58686 .54051 L F
.58861 .57437 m .58885 .57899 L .58885 .57032 L 0 0 .087 r
F
.5886 .57458 m .58885 .57899 L .58861 .57437 L F
.5886 .57458 m .58885 .58061 L .58885 .57899 L F
.58839 .57118 m .58978 .59868 L .58839 .57119 L 0 .091 .152 r
F
.58885 .57926 m .58885 .58061 L .58898 .58177 L 0 0 .087 r
F
.58916 .58482 m .58924 .54656 L .58921 .58581 L F
.58916 .58482 m .58903 .58175 L .58924 .54656 L F
.58885 .57926 m .58898 .58177 L .58931 .58465 L F
.58885 .57032 m .58885 .57926 L .58931 .58465 L F
.58929 .58887 m .5886 .57529 L .58929 .58887 L 0 .091 .152 r
F
.5886 .57529 m .58979 .59875 L .58859 .57527 L F
.58908 .58489 m .58907 .58477 L .589 .58337 L F
.58885 .58061 m .58929 .58898 L .58931 .58465 L 0 0 .087 r
F
.58903 .58388 m .589 .58337 L .58791 .56185 L 0 .091 .152 r
F
.58979 .59874 m .58979 .59875 L .58839 .57119 L F
.58853 .56185 m .58916 .54315 L .58862 .5594 L 0 0 .1 r
F
.58852 .55798 m .58856 .57363 L .58885 .57032 L 0 0 .087 r
F
.58858 .57475 m .5888 .57924 L .58857 .57406 L 0 .091 .152 r
F
.58856 .57363 m .58857 .5752 L .5886 .57458 L 0 0 .087 r
F
.58856 .57363 m .5886 .57458 L .58885 .57032 L F
.58856 .57363 m .58911 .58568 L .58919 .58575 L 0 .091 .152 r
F
.58842 .57093 m .58868 .57654 L .58856 .57363 L F
.58868 .57654 m .58911 .58568 L .58856 .57363 L F
.58856 .57363 m .59568 .71089 L .58856 .57332 L F
.58856 .57363 m .58856 .57332 L .58686 .54051 L F
.58855 .57267 m .58855 .57516 L .58855 .57286 L 0 0 .087 r
F
.58855 .57516 m .58861 .60143 L .58856 .57517 L F
.58855 .57516 m .58856 .57517 L .58855 .57286 L F
.58855 .57286 m .58856 .57517 L .58856 .57517 L F
.58856 .57517 m .58861 .60143 L .58856 .57517 L F
.5888 .57924 m .58868 .57654 L .58857 .57406 L 0 .091 .152 r
F
.58794 .56229 m .58909 .58517 L .58911 .58567 L F
.58859 .57525 m .58907 .58483 L .58859 .57521 L F
.58907 .58483 m .58906 .58473 L .58839 .5714 L F
.58858 .57519 m .58911 .58568 L .58858 .57475 L F
.58857 .5752 m .58885 .58061 L .5886 .57458 L 0 0 .087 r
F
.5888 .57924 m .58911 .58568 L .58868 .57654 L 0 .091 .152 r
F
.58858 .57475 m .58857 .57406 L .58842 .57093 L F
.58853 .56185 m .58838 .5664 L .58838 .56639 L 0 0 .1 r
F
.58853 .56185 m .58838 .5667 L .58838 .5664 L F
.58838 .56629 m .58853 .56185 L .58838 .56639 L F
.58686 .54051 m .58856 .57332 L .58851 .5646 L 0 .091 .152 r
F
.58854 .56826 m .58855 .57267 L .58855 .57286 L 0 0 .087 r
F
.58856 .57518 m .58856 .57337 L .58856 .57319 L F
.58857 .57999 m .58856 .57518 L .58856 .57518 L F
.58856 .57518 m .58856 .57337 L .58856 .57518 L F
.58877 .56962 m .5891 .56328 L .58873 .56898 L 0 0 .064 r
F
.58852 .55798 m .58885 .57032 L .58872 .28844 L 0 0 .087 r
F
.58872 .28844 m .58885 .57032 L .59022 .28957 L F
.58885 .57032 m .58931 .58465 L .59022 .28957 L F
.58837 .50223 m .58851 .5646 L .58854 .56826 L F
.58851 .5646 m .59568 .71089 L .58971 .58226 L 0 .091 .152 r
F
.58855 .57228 m .58855 .56978 L .58855 .56925 L 0 0 .087 r
F
.58856 .57247 m .58855 .56978 L .58855 .57228 L F
.58856 .57337 m .58855 .56978 L .58856 .57319 L F
.58854 .56826 m .58855 .57286 L .58855 .56925 L F
.58855 .57286 m .58856 .57319 L .58855 .56925 L F
.58856 .57332 m .59568 .71089 L .58851 .5646 L 0 .091 .152 r
F
.58856 .57319 m .58856 .57247 L .58855 .57228 L 0 0 .087 r
F
.58839 .57142 m .58859 .57525 L .58839 .5714 L 0 .091 .152 r
F
.58859 .57525 m .58859 .57521 L .58839 .5714 L F
.58939 .59194 m .58969 .5984 L .5893 .58926 L F
.58977 .59865 m .59538 .71798 L .5956 .71469 L F
.5893 .58926 m .58974 .59854 L .58977 .59865 L F
.58974 .59854 m .59054 .61543 L .58977 .59865 L F
.59054 .61543 m .59931 .80174 L .59059 .61603 L F
.59054 .61543 m .59059 .61603 L .58977 .59865 L F
.60731 1.04692 m .60704 1.03701 L .60733 1.04717 L 0 0 .042 r
F
.60251 .85955 m .59789 .86263 L .60075 .86685 L 0 .769 .453 r
F
.60251 .85955 m .59864 .8595 L .59789 .86263 L F
.59441 .8476 m .59864 .8595 L .60251 .85954 L 0 .726 .441 r
F
.5985 1.00957 m .60138 .99663 L .60601 .99542 L 0 .211 .087 r
F
.59797 1.01056 m .59845 1.0086 L .5985 1.00957 L F
.59845 1.0086 m .60138 .99663 L .5985 1.00957 L F
.59964 .68212 m .59918 .63383 L .59916 .63283 L 0 .223 .192 r
F
.5996 .68049 m .59964 .68212 L .59916 .63283 L F
.5974 .75065 m .59857 .78189 L .59912 .78487 L 0 .091 .152 r
F
.59857 .78189 m .59918 .79015 L .59912 .78487 L F
.59929 .78798 m .60026 .79989 L .59931 .78827 L 0 .066 .149 r
F
.60026 .79989 m .60026 .79992 L .59931 .78827 L F
.59931 .78827 m .59947 .79022 L .59947 .79036 L F
.59864 .72373 m .59631 .73392 L .59722 .74066 L 0 1 .317 r
F
.59562 .71431 m .59981 .79859 L .59981 .79721 L 0 .091 .152 r
F
.599 .78195 m .59981 .79785 L .59897 .78166 L F
.59981 .79785 m .60004 .80241 L .59897 .78166 L F
.59897 .78166 m .60004 .80241 L .59892 .78111 L F
.59839 .77054 m .60003 .80321 L .5984 .77045 L F
.60003 .80321 m .60157 .83407 L .60003 .80308 L F
.5996 .68049 m .59916 .63283 L .59811 .57735 L 0 .223 .192 r
F
.5986 .63061 m .5996 .68049 L .59811 .57735 L F
.59982 .7973 m .60196 .83947 L .5999 .79954 L 0 .091 .152 r
F
.60196 .83947 m .60198 .84014 L .5999 .79963 L F
.5999 .79954 m .5999 .79963 L .59968 .79527 L F
.60196 .83947 m .5999 .79963 L .5999 .79954 L F
.6006 .81326 m .60197 .83996 L .60055 .81367 L F
.60111 .80271 m .60083 .80114 L .59965 .79229 L 0 .009 .137 r
F
.59965 .79229 m .60083 .80114 L .60062 .79994 L F
.60007 .80212 m .60193 .83888 L .60007 .80213 L 0 .091 .152 r
F
.60193 .83888 m .60193 .83893 L .60007 .80213 L F
.60004 .80241 m .6006 .81326 L .60004 .8025 L F
.60006 .80359 m .60157 .83407 L .60024 .80611 L F
.60026 .79992 m .60212 .82268 L .60025 .80007 L 0 .066 .149 r
F
.59852 1.0099 m .60601 .99542 L .60825 .99802 L 0 .211 .087 r
F
.59797 1.01056 m .5985 1.00957 L .59852 1.0099 L F
.5985 1.00957 m .60601 .99542 L .59852 1.0099 L F
.60125 1.10399 m .60581 1.07316 L .60127 1.10439 L 0 .39 .172 r
F
.60101 1.09922 m .60581 1.07316 L .60113 1.10481 L F
.59959 1.13282 m .59888 1.11027 L .60305 1.11767 L 0 .852 .109 r
F
.59853 1.1127 m .60111 1.08041 L .60581 1.07316 L 0 .39 .172 r
F
.60142 1.10788 m .60979 1.07846 L .61042 1.09286 L F
.59853 1.1127 m .60127 1.10439 L .60142 1.10788 L F
.60127 1.10439 m .60979 1.07846 L .60142 1.10788 L F
.59853 1.01015 m .60825 .99802 L .6068 1.00399 L 0 .211 .087 r
F
.59797 1.01056 m .59852 1.0099 L .59853 1.01015 L F
.59852 1.0099 m .60825 .99802 L .59853 1.01015 L F
.60158 1.11172 m .61042 1.09286 L .60731 1.10988 L 0 .39 .172 r
F
.59853 1.1127 m .60142 1.10788 L .60158 1.11172 L F
.60142 1.10788 m .61042 1.09286 L .60158 1.11172 L F
.61321 1.33241 m .61576 1.28349 L .62092 1.29076 L 0 .598 .173 r
F
.61321 1.33241 m .62092 1.29076 L .62377 1.30836 L F
.61321 1.33241 m .62377 1.30836 L .62272 1.32942 L F
.61252 1.32612 m .61385 1.27145 L .61886 1.28325 L 0 .832 .184 r
F
.61252 1.32612 m .61886 1.28325 L .62384 1.32177 L F
.61321 1.33241 m .62272 1.32942 L .61842 1.33983 L 0 .598 .173 r
F
.61919 1.39228 m .62272 1.32942 L .62778 1.33789 L 0 .57 .186 r
F
.61919 1.39228 m .61842 1.33983 L .62272 1.32942 L F
.61919 1.39228 m .62778 1.33789 L .63027 1.35972 L F
.61919 1.39228 m .61689 1.36669 L .61842 1.33983 L F
.61252 1.32612 m .62384 1.32177 L .62548 1.36181 L 0 .832 .184 r
F
.61252 1.32612 m .62276 1.38064 L .6175 1.36526 L F
.61252 1.32612 m .62548 1.36181 L .62276 1.38064 L F
.61259 1.38923 m .61231 1.3196 L .61528 1.22499 L 0 .273 .195 r
F
.60919 1.38932 m .61231 1.3196 L .61259 1.38923 L 0 .474 .207 r
F
.61263 1.37876 m .61066 1.19438 L .60971 1.15379 L 0 1 .196 r
F
.60054 1.07584 m .6086 1.06036 L .60581 1.07316 L 0 .364 .153 r
F
.60011 1.07606 m .60052 1.07529 L .60054 1.07584 L F
.60052 1.07529 m .6086 1.06036 L .60054 1.07584 L F
.59693 1.07767 m .59996 1.07318 L .60011 1.07606 L F
.59996 1.07318 m .60045 1.07245 L .60011 1.07606 L F
.60045 1.07245 m .6086 1.06036 L .60052 1.07529 L F
.60045 1.07245 m .60052 1.07529 L .60011 1.07606 L F
.60634 1.38032 m .60408 1.22649 L .60482 1.32239 L 0 0 .073 r
F
.59853 1.1127 m .60101 1.09922 L .60113 1.10481 L 0 .39 .172 r
F
.59959 1.13282 m .59965 1.13284 L .59966 1.13295 L 0 .852 .109 r
F
.59854 1.01041 m .6068 1.00399 L .60262 1.00935 L 0 .211 .087 r
F
.59797 1.01056 m .59853 1.01015 L .59854 1.01041 L F
.59853 1.01015 m .6068 1.00399 L .59854 1.01041 L F
.60634 1.38032 m .60482 1.32239 L .60527 1.38057 L 0 0 .073 r
F
.60608 1.37926 m .60426 1.18272 L .60619 1.37909 L 0 .267 .202 r
F
.6018 1.1171 m .60731 1.10988 L .60254 1.11811 L 0 .39 .172 r
F
.59853 1.1127 m .60158 1.11172 L .6018 1.1171 L F
.60158 1.11172 m .60731 1.10988 L .6018 1.1171 L F
.59943 1.16348 m .60731 1.10988 L .61113 1.12052 L 0 .411 .187 r
F
.59943 1.16348 m .61113 1.12052 L .61146 1.14311 L F
.61026 1.15624 m .60731 1.04692 L .61025 1.15556 L 0 0 .042 r
F
.62408 1.12405 m .62079 1.10275 L .62438 1.10298 L 0 .591 .101 r
F
.61502 1.17713 m .6121 1.15567 L .61787 1.15729 L 0 .346 .101 r
F
.62408 1.12405 m .62066 1.11175 L .62079 1.10275 L 0 .591 .101 r
F
.61502 1.17713 m .61787 1.15729 L .62275 1.16387 L 0 .346 .101 r
F
.61502 1.17713 m .62275 1.16387 L .62403 1.17308 L F
.61413 1.12171 m .62065 1.11175 L .62408 1.12405 L 0 .682 .103 r
F
.61502 1.17713 m .62403 1.17308 L .62084 1.17876 L 0 .346 .101 r
F
.61413 1.12171 m .62408 1.12405 L .62361 1.13285 L 0 .682 .103 r
F
.61413 1.12171 m .62361 1.13285 L .61954 1.13223 L F
.62134 1.1604 m .61954 1.13223 L .62361 1.13285 L 0 .692 .128 r
F
.62134 1.1604 m .61856 1.14399 L .61954 1.13223 L F
.61055 1.15287 m .6134 1.1292 L .61856 1.14399 L 0 .782 .122 r
F
.61055 1.15287 m .61856 1.14399 L .62134 1.1604 L F
.61055 1.15287 m .62134 1.1604 L .62013 1.17066 L F
.61055 1.15287 m .62013 1.17066 L .61573 1.16782 L F
.61714 1.21552 m .61604 1.18727 L .62155 1.1896 L 0 .43 .124 r
F
.61625 1.2036 m .61573 1.16782 L .62013 1.17066 L 0 .773 .154 r
F
.61613 1.18398 m .61962 1.11519 L .62288 1.11145 L 0 .271 .185 r
F
.61625 1.2036 m .61406 1.18187 L .61573 1.16782 L 0 .773 .154 r
F
.61196 1.22875 m .61612 1.16705 L .61613 1.18398 L 0 .271 .185 r
F
.61612 1.16705 m .61962 1.11519 L .61613 1.18398 L F
.61196 1.22875 m .61511 1.14083 L .61962 1.11519 L F
.61603 1.19234 m .62288 1.11145 L .62275 1.13209 L F
.61196 1.22875 m .61613 1.18398 L .61603 1.19234 L F
.61613 1.18398 m .62288 1.11145 L .61603 1.19234 L F
.61196 1.22875 m .61182 1.18937 L .61511 1.14083 L F
.62571 1.19841 m .62403 1.17308 L .62975 1.17418 L 0 .336 .112 r
F
.62571 1.19841 m .62084 1.17876 L .62403 1.17308 L F
.62571 1.19841 m .62155 1.1896 L .62084 1.17876 L F
.61714 1.21552 m .62155 1.1896 L .62571 1.19841 L 0 .43 .124 r
F
.61625 1.2036 m .62013 1.17066 L .62524 1.18824 L 0 .773 .154 r
F
.61599 1.2031 m .62275 1.13209 L .61951 1.1806 L 0 .271 .185 r
F
.61196 1.22875 m .61603 1.19234 L .61599 1.2031 L F
.61603 1.19234 m .62275 1.13209 L .61599 1.2031 L F
.61714 1.21552 m .62571 1.19841 L .62622 1.21053 L 0 .43 .124 r
F
.61714 1.21552 m .62622 1.21053 L .6227 1.21789 L F
.62571 1.19841 m .62975 1.17418 L .63421 1.18134 L 0 .336 .112 r
F
.62571 1.19841 m .63421 1.18134 L .63496 1.19221 L F
.62571 1.19841 m .63496 1.19221 L .63147 1.19953 L F
.61625 1.2036 m .62524 1.18824 L .62767 1.209 L 0 .773 .154 r
F
.62613 1.24476 m .62622 1.21053 L .63164 1.21247 L 0 .41 .141 r
F
.62613 1.24476 m .6227 1.21789 L .62622 1.21053 L F
.61625 1.2036 m .62767 1.209 L .62602 1.22329 L 0 .773 .154 r
F
.62613 1.24476 m .62265 1.23254 L .6227 1.21789 L 0 .41 .141 r
F
.61625 1.2036 m .62602 1.22329 L .62138 1.22142 L 0 .773 .154 r
F
.62119 1.27028 m .6193 1.24144 L .62138 1.22142 L 0 .742 .178 r
F
.61327 1.3888 m .61808 1.28281 L .61896 1.29405 L 0 .273 .195 r
F
.61808 1.28281 m .6191 1.26012 L .61896 1.29405 L F
.60825 .99802 m .60601 .99542 L .60728 .99016 L 0 .105 .069 r
F
.60238 1.0222 m .61129 1.01391 L .60692 1.02081 L 0 .232 .101 r
F
.60593 1.03808 m .60692 1.02081 L .61129 1.01391 L 0 .248 .115 r
F
.60593 1.03808 m .60461 1.03116 L .60692 1.02081 L F
.6086 1.06036 m .60764 1.05058 L .61031 1.03652 L 0 .259 .137 r
F
.6177 1.07868 m .62147 1.08135 L .62914 1.08073 L 0 .99 .383 r
F
.6177 1.07868 m .62914 1.08073 L .6275 1.07966 L F
.61391 1.07605 m .6177 1.07868 L .62505 1.07805 L 0 .968 .371 r
F
.61391 1.07605 m .62505 1.07805 L .6234 1.07698 L F
.63589 1.07358 m .62094 1.07535 L .63011 1.07615 L 0 .972 .383 r
F
.63589 1.07358 m .61929 1.07424 L .62094 1.07535 L F
.63589 1.07358 m .62569 1.07349 L .61929 1.07424 L F
.63104 1.07092 m .61681 1.07254 L .62569 1.07349 L 0 .972 .391 r
F
.63104 1.07092 m .61515 1.07138 L .61681 1.07254 L F
.63104 1.07092 m .62124 1.07068 L .61515 1.07138 L F
.62616 1.06804 m .62124 1.07068 L .63104 1.07092 L 0 .982 .409 r
F
.62125 1.06482 m .61676 1.06759 L .62616 1.06804 L 0 .986 .433 r
F
.62127 1.07526 m .61768 1.06389 L .62359 1.06944 L 0 .319 .024 r
F
.62127 1.07526 m .61492 1.06301 L .61768 1.06389 L F
.62127 1.07526 m .61645 1.06786 L .61492 1.06301 L F
.63104 1.07092 m .62569 1.07349 L .63589 1.07358 L 0 .972 .391 r
F
.62127 1.07526 m .62359 1.06944 L .62874 1.07598 L 0 .319 .024 r
F
.61342 1.07342 m .61645 1.06786 L .62127 1.07526 L 0 .373 .035 r
F
.64554 1.07862 m .62914 1.08073 L .63891 1.08136 L 0 1 .391 r
F
.64554 1.07862 m .6275 1.07966 L .62914 1.08073 L F
.64554 1.07862 m .63452 1.07875 L .6275 1.07966 L F
.64073 1.07612 m .62505 1.07805 L .63452 1.07875 L 0 .987 .384 r
F
.64073 1.07612 m .6234 1.07698 L .62505 1.07805 L F
.64073 1.07612 m .63011 1.07615 L .6234 1.07698 L F
.62127 1.07526 m .62874 1.07598 L .63031 1.08088 L 0 .319 .024 r
F
.62127 1.07526 m .63031 1.08088 L .62722 1.08085 L F
.61342 1.07342 m .62127 1.07526 L .62247 1.08046 L 0 .373 .035 r
F
.61342 1.07342 m .62247 1.08046 L .61923 1.07998 L F
.62147 1.08135 m .62523 1.08408 L .63321 1.08345 L 0 1 .398 r
F
.62147 1.08135 m .63321 1.08345 L .63158 1.08236 L F
.62397 1.09606 m .61923 1.07998 L .62247 1.08046 L 0 .448 .073 r
F
.62397 1.09606 m .61986 1.08665 L .61923 1.07998 L F
.61524 1.09476 m .61434 1.07873 L .61986 1.08665 L 0 .54 .078 r
F
.61524 1.09476 m .61986 1.08665 L .62397 1.09606 L F
.61524 1.09476 m .62397 1.09606 L .62438 1.10298 L F
.61524 1.09476 m .62438 1.10298 L .62079 1.10275 L F
.6181 1.10044 m .61895 1.07406 L .62256 1.07177 L 0 .27 .172 r
F
.61413 1.12171 m .61527 1.10134 L .62065 1.11175 L 0 .682 .103 r
F
.61413 1.12171 m .61151 1.09969 L .61527 1.10134 L F
.61413 1.12171 m .61101 1.10839 L .61151 1.09969 L F
.61146 1.14311 m .61847 1.07848 L .6181 1.10044 L 0 .27 .172 r
F
.61847 1.07848 m .61895 1.07406 L .6181 1.10044 L F
.61146 1.14311 m .61435 1.09097 L .6185 1.07573 L F
.61847 1.07848 m .6185 1.07573 L .61895 1.07406 L F
.61146 1.14311 m .6185 1.07573 L .61847 1.07848 L F
.62397 1.09606 m .62247 1.08046 L .6282 1.08704 L 0 .448 .073 r
F
.61781 1.1109 m .62256 1.07177 L .6228 1.08563 L 0 .27 .172 r
F
.61146 1.14311 m .6181 1.10044 L .61781 1.1109 L F
.6181 1.10044 m .62256 1.07177 L .61781 1.1109 L F
.61146 1.14311 m .61113 1.12052 L .61435 1.09097 L F
.61758 1.12215 m .6228 1.08563 L .61962 1.11519 L F
.61146 1.14311 m .61781 1.1109 L .61758 1.12215 L F
.61781 1.1109 m .6228 1.08563 L .61758 1.12215 L F
.61146 1.14311 m .61962 1.11519 L .61511 1.14083 L F
.61911 1.25971 m .6223 1.16995 L .62183 1.19994 L 0 .273 .195 r
F
.61321 1.38895 m .61917 1.24539 L .61911 1.25971 L F
.61917 1.24539 m .6223 1.16995 L .61911 1.25971 L F
.61306 1.38907 m .6223 1.16995 L .61321 1.38895 L F
.61306 1.38907 m .61951 1.1806 L .6223 1.16995 L F
.61196 1.22875 m .61951 1.1806 L .61528 1.22499 L 0 .271 .185 r
F
.61284 1.38914 m .61951 1.1806 L .61306 1.38907 L 0 .273 .195 r
F
.61284 1.38914 m .61528 1.22499 L .61951 1.1806 L F
.61321 1.38895 m .61911 1.25971 L .61327 1.3888 L F
.61911 1.25971 m .62183 1.19994 L .6191 1.26012 L F
.61911 1.25971 m .6191 1.26012 L .61327 1.3888 L F
.61919 1.39228 m .63027 1.35972 L .6288 1.3868 L 0 .57 .186 r
F
.61919 1.39228 m .6288 1.3868 L .62431 1.40097 L F
.60776 1.40993 m .61919 1.39228 L .61746 1.4173 L 0 .683 .187 r
F
.61657 1.40617 m .6175 1.36526 L .62276 1.38064 L 0 .795 .2 r
F
.61478 1.40585 m .6175 1.36526 L .61657 1.40617 L F
.61478 1.40585 m .61447 1.39258 L .6175 1.36526 L F
.6157 1.38681 m .61896 1.29405 L .61861 1.38577 L 0 .276 .202 r
F
.61866 1.36618 m .61866 1.36612 L .61866 1.36617 L 0 0 .042 r
F
.61664 1.37905 m .61866 1.36612 L .61866 1.36618 L F
.61259 1.38923 m .61528 1.22499 L .61284 1.38914 L 0 .273 .195 r
F
.61347 1.38855 m .61896 1.29405 L .6157 1.38681 L F
.61327 1.3888 m .61896 1.29405 L .61347 1.38855 L F
.61664 1.37905 m .61387 1.21687 L .61866 1.36612 L 0 0 .042 r
F
.61635 1.38093 m .61866 1.36617 L .6186 1.38189 L F
.61861 1.38577 m .61961 1.30218 L .61959 1.38393 L 0 .276 .202 r
F
.61961 1.30218 m .62003 1.30754 L .61959 1.38393 L F
.62377 1.30836 m .62092 1.29076 L .62179 1.27052 L 0 .489 .167 r
F
.6191 1.26012 m .62183 1.19994 L .61896 1.29405 L 0 .273 .195 r
F
.61635 1.38093 m .60157 .83407 L .61387 1.21687 L 0 0 .042 r
F
.60714 .92444 m .6096 .96477 L .60952 .96324 L F
.6072 .92559 m .6096 .96477 L .60714 .92444 L F
.6074 .93071 m .60901 .9587 L .61043 .98088 L F
.6078 .9384 m .60901 .9587 L .6074 .93071 L F
.6027 .85408 m .60283 .85874 L .60324 .86486 L 0 .091 .152 r
F
.60705 .95433 m .60952 .96324 L .61055 1.03109 L 0 0 .042 r
F
.60157 .83407 m .60324 .86486 L .60841 .94897 L F
.60829 .94662 m .60841 .94897 L .60901 .9587 L F
.60157 .83407 m .60841 .94897 L .60829 .94662 L F
.60157 .83407 m .60714 .92444 L .60705 .95433 L F
.61961 1.30218 m .62021 1.2513 L .62003 1.30754 L 0 .276 .202 r
F
.62021 1.2513 m .62023 1.25524 L .62003 1.30754 L F
.62028 1.2645 m .62017 1.24215 L .62052 1.25553 L 0 0 .042 r
F
.62028 1.2645 m .62052 1.25553 L .62153 1.29343 L F
.61861 1.38577 m .61896 1.29405 L .62026 1.23831 L 0 .276 .202 r
F
.62026 1.24701 m .62026 1.23831 L .62048 1.22853 L F
.61861 1.38577 m .62026 1.23831 L .62026 1.24701 L F
.62026 1.24701 m .62028 1.2645 L .62017 1.27124 L F
.61959 1.38393 m .62028 1.2645 L .6194 1.31964 L F
.61916 1.23885 m .61975 1.23291 L .62028 1.2645 L 0 0 .042 r
F
.60157 .83407 m .61055 1.03109 L .61077 1.0458 L F
.60714 .92444 m .60952 .96324 L .60705 .95433 L F
.61632 1.06116 m .62125 1.06482 L .62643 1.06441 L 0 .95 .451 r
F
.61632 1.06116 m .62643 1.06441 L .62434 1.06309 L F
.61854 1.0559 m .62416 1.0589 L .62792 1.06043 L 0 .337 .219 r
F
.61854 1.0559 m .62792 1.06043 L .62556 1.05943 L F
.61558 1.06003 m .6163 1.05689 L .62218 1.06217 L 0 .156 0 r
F
.62125 1.06482 m .63166 1.06748 L .62957 1.06629 L 0 .986 .433 r
F
.61558 1.06003 m .62218 1.06217 L .62455 1.06567 L 0 .156 0 r
F
.62125 1.06482 m .62616 1.06804 L .63166 1.06748 L 0 .986 .433 r
F
.61558 1.06003 m .62455 1.06567 L .62181 1.06503 L 0 .156 0 r
F
.61042 1.09286 m .61737 1.0466 L .62127 1.04472 L 0 .266 .156 r
F
.63708 1.06496 m .62434 1.06309 L .62643 1.06441 L 0 .588 .285 r
F
.63708 1.06496 m .62889 1.06332 L .62434 1.06309 L F
.62875 1.06392 m .61964 1.05677 L .62201 1.05787 L 0 0 0 r
F
.62875 1.06392 m .62252 1.05936 L .61964 1.05677 L F
.61042 1.09286 m .62127 1.04472 L .6219 1.05425 L 0 .266 .156 r
F
.61042 1.09286 m .60979 1.07846 L .61278 1.05865 L F
.61042 1.09286 m .6219 1.05425 L .61895 1.07406 L F
.61042 1.09286 m .61895 1.07406 L .61435 1.09097 L F
.61866 1.36617 m .60157 .83407 L .61916 1.23885 L 0 0 .042 r
F
.61635 1.38093 m .61387 1.21687 L .61664 1.37905 L F
.59535 .43375 m .59374 .28438 L .59539 .43431 L 0 .267 .202 r
F
.59374 .28438 m .59373 .28334 L .59374 .28441 L F
.59374 .28438 m .59374 .28441 L .59539 .43431 L F
.60413 .82293 m .60688 .83814 L .60401 .82287 L 0 0 .141 r
F
.60354 .82936 m .60427 .83046 L .60352 .82915 L 0 .316 .339 r
F
.60366 .82387 m .60671 .84783 L .60356 .83122 L 0 .009 .137 r
F
.60321 .8203 m .60306 .81786 L .60671 .84783 L F
.60295 .81601 m .60688 .83814 L .60297 .81638 L 0 0 .141 r
F
.60412 .81882 m .60508 .82187 L .60397 .81794 L 0 .137 .22 r
F
.60315 .8375 m .6034 .83954 L .60568 .86983 L 0 .066 .149 r
F
.59539 .43431 m .59373 .28334 L .59694 .45406 L 0 .267 .202 r
F
.596 .44207 m .59335 .28211 L .59251 .28268 L 0 .223 .192 r
F
.61327 .59518 m .61062 .62671 L .61592 .61943 L 0 1 .328 r
F
.61327 .59518 m .608 .62288 L .61062 .62671 L F
.61327 .59518 m .60914 .60935 L .608 .62288 L F
.60603 .59764 m .60787 .6292 L .61267 .62749 L 0 .927 .325 r
F
.60603 .59764 m .60428 .62175 L .60787 .6292 L F
.60603 .59764 m .6035 .60822 L .60428 .62175 L F
.60019 .63944 m .60828 .61342 L .60405 .62164 L 0 1 .269 r
F
.60019 .63944 m .61068 .62029 L .60828 .61342 L F
.60019 .63944 m .60966 .63771 L .61068 .62029 L F
.62563 .7736 m .61232 .79192 L .62076 .78989 L 0 1 .448 r
F
.61405 .78095 m .60604 .79917 L .61269 .79878 L 0 1 .41 r
F
.61141 .79661 m .60419 .81022 L .6065 .81174 L 0 1 .437 r
F
.60891 .63887 m .61717 .63667 L .61455 .63262 L 0 1 .348 r
F
.60891 .63887 m .61521 .64859 L .61717 .63667 L F
.60891 .63887 m .60997 .66044 L .61521 .64859 L F
.61521 .64859 m .62372 .64701 L .6211 .64284 L 0 1 .361 r
F
.60812 .64133 m .6166 .64751 L .61315 .64024 L 0 .979 .345 r
F
.61521 .64859 m .62151 .65861 L .62372 .64701 L 0 1 .361 r
F
.61521 .64859 m .61593 .66992 L .62151 .65861 L F
.61521 .64859 m .61003 .67569 L .61593 .66992 L F
.61521 .64859 m .60775 .67206 L .61003 .67569 L F
.61521 .64859 m .60997 .66044 L .60775 .67206 L F
.60812 .64133 m .61652 .65906 L .6166 .64751 L 0 .979 .345 r
F
.60812 .64133 m .61297 .66718 L .61652 .65906 L F
.60812 .64133 m .60794 .66826 L .61297 .66718 L F
.60019 .63944 m .60581 .65555 L .60966 .63771 L 0 1 .269 r
F
.61141 .79661 m .6063 .80374 L .60419 .81022 L 0 1 .437 r
F
.60019 .63944 m .60168 .66187 L .60581 .65555 L 0 1 .269 r
F
.60873 .77018 m .60376 .78542 L .60653 .78666 L 0 1 .395 r
F
.60873 .77018 m .6047 .77835 L .60376 .78542 L F
.60375 .69524 m .60183 .70715 L .60323 .71492 L 0 1 .307 r
F
.61486 .90228 m .61861 .90966 L .62599 .90475 L 0 1 .503 r
F
.61486 .90228 m .62599 .90475 L .62437 .90187 L F
.61112 .89639 m .61489 .90431 L .62194 .89826 L 0 1 .497 r
F
.61112 .89639 m .62194 .89826 L .62031 .895 L F
.61287 .88879 m .60776 .89561 L .61376 .89778 L 0 .993 .485 r
F
.60632 .87991 m .60758 .88917 L .61287 .88879 L 0 .943 .476 r
F
.60632 .87991 m .61287 .88879 L .6148 .88589 L F
.60632 .87991 m .6148 .88589 L .61208 .8824 L F
.60501 .88026 m .60568 .86983 L .61018 .89376 L 0 .995 .11 r
F
.61317 1.00611 m .6172 .98993 L .62182 .98696 L 0 .124 .084 r
F
.61317 1.00611 m .61305 .99566 L .6172 .98993 L F
.61317 1.00611 m .62182 .98696 L .62385 .98872 L F
.62004 .99557 m .62379 1.00077 L .63162 .99761 L 0 1 .542 r
F
.62004 .99557 m .63162 .99761 L .63 .9955 L F
.61317 1.00611 m .62385 .98872 L .62214 .99564 L 0 .124 .084 r
F
.61317 1.00611 m .62214 .99564 L .61782 1.00312 L F
.61058 .97612 m .61987 1.0807 L .61519 1.05539 L 0 .995 .11 r
F
.6084 .93524 m .61447 .94547 L .61882 .94071 L 0 1 .491 r
F
.6084 .93524 m .61882 .94071 L .61625 .93678 L F
.61865 .91203 m .61053 .92391 L .62239 .91958 L 0 1 .506 r
F
.61625 .91544 m .6079 .92324 L .61471 .92472 L 0 1 .493 r
F
.60501 .88026 m .61046 .95375 L .61058 .97612 L 0 .995 .11 r
F
.63398 .97251 m .61773 .97904 L .61937 .98133 L 0 1 .538 r
F
.63398 .97251 m .62398 .97527 L .61773 .97904 L F
.62914 .96644 m .62398 .97527 L .63398 .97251 L 0 1 .534 r
F
.62926 .97317 m .61529 .97762 L .62402 .97781 L 0 1 .512 r
F
.62926 .97317 m .61365 .97605 L .61529 .97762 L F
.62926 .97317 m .61963 .97415 L .61365 .97605 L F
.61197 .98173 m .61835 .97185 L .62149 .97179 L 0 0 .022 r
F
.61197 .98173 m .61328 .97435 L .61835 .97185 L F
.62445 .97026 m .61963 .97415 L .62926 .97317 L 0 1 .478 r
F
.61197 .98173 m .62149 .97179 L .62095 .97495 L 0 0 .022 r
F
.61197 .98173 m .62095 .97495 L .61705 .97922 L F
.61046 .95375 m .61987 1.0807 L .61058 .97612 L 0 .995 .11 r
F
.61447 .94547 m .61061 .9557 L .61938 .95304 L 0 1 .506 r
F
.6225 .96197 m .61533 .96345 L .61142 .96462 L 0 .798 .245 r
F
.6115 .96309 m .61701 .96231 L .62039 .9615 L 0 .724 .211 r
F
.6115 .96309 m .62039 .9615 L .61807 .96183 L F
.61177 .96716 m .61479 .96388 L .61939 .9627 L 0 0 0 r
F
.61177 .96716 m .61939 .9627 L .6205 .96327 L F
.62427 .95999 m .61954 .96923 L .62914 .96644 L 0 1 .528 r
F
.62427 .95999 m .62914 .96644 L .63479 .96242 L F
.62797 .96211 m .61671 .96514 L .61924 .96559 L 0 .916 .28 r
F
.62797 .96211 m .62044 .96365 L .61671 .96514 L F
.61177 .96716 m .6205 .96327 L .61735 .96521 L 0 0 0 r
F
.6171 1.01718 m .62214 .99564 L .62656 .99181 L 0 .134 .095 r
F
.6171 1.01718 m .61782 1.00312 L .62214 .99564 L F
.6171 1.01718 m .62656 .99181 L .62814 .99417 L F
.6171 1.01718 m .61565 1.01236 L .61782 1.00312 L F
.6171 1.01718 m .62814 .99417 L .626 1.00338 L F
.6171 1.01718 m .626 1.00338 L .62154 1.01333 L F
.62001 1.03254 m .61897 1.02582 L .62154 1.01333 L 0 .135 .104 r
F
.61046 .95375 m .61975 1.01638 L .61987 1.0807 L 0 .995 .11 r
F
.60501 .88026 m .61023 .92846 L .61046 .95375 L F
.62047 .96062 m .61227 .96297 L .6146 .96246 L 0 .742 .205 r
F
.62047 .96062 m .61479 .96218 L .61227 .96297 L F
.61701 .96231 m .61533 .96345 L .6225 .96197 L 0 .763 .228 r
F
.61939 .9627 m .61336 .96388 L .61605 .96271 L 0 0 0 r
F
.61939 .9627 m .61479 .96388 L .61336 .96388 L F
.6148 .96624 m .61963 .96791 L .62473 .96707 L 0 .844 .301 r
F
.6148 .96624 m .62473 .96707 L .62268 .96642 L F
.62797 .96211 m .61924 .96559 L .62712 .96469 L 0 .916 .28 r
F
.61332 .97197 m .61788 .96606 L .62174 .96526 L 0 0 0 r
F
.61332 .97197 m .61262 .9683 L .61788 .96606 L F
.61963 .96791 m .61522 .97095 L .62445 .97026 L 0 1 .411 r
F
.61963 .96791 m .62445 .97026 L .62985 .96909 L F
.61963 .96791 m .62985 .96909 L .62781 .96821 L F
.61332 .97197 m .62174 .96526 L .62205 .96683 L 0 0 0 r
F
.61332 .97197 m .62205 .96683 L .61859 .96972 L F
.61844 .98468 m .61598 .9834 L .61705 .97922 L 0 0 .039 r
F
.61023 .92846 m .61975 1.01638 L .61046 .95375 L 0 .995 .11 r
F
.63398 .97251 m .61937 .98133 L .6284 .98101 L 0 1 .538 r
F
.63398 .97251 m .6284 .98101 L .6388 .9783 L F
.63406 .97651 m .61774 .98006 L .61938 .98176 L 0 1 .528 r
F
.63406 .97651 m .62402 .97781 L .61774 .98006 L F
.61447 .94547 m .61938 .95304 L .62441 .94883 L 0 1 .506 r
F
.61447 .94547 m .62441 .94883 L .62232 .94587 L F
.62047 .96062 m .6146 .96246 L .62085 .96073 L 0 .742 .205 r
F
.61404 .96281 m .61479 .96218 L .62047 .96062 L 0 0 0 r
F
.61404 .96281 m .62047 .96062 L .62274 .96016 L F
.61404 .96281 m .62274 .96016 L .62006 .96112 L F
.61701 .96231 m .6225 .96197 L .62616 .96098 L 0 .763 .228 r
F
.61701 .96231 m .62616 .96098 L .62385 .96113 L F
.61939 .9627 m .61605 .96271 L .62174 .96064 L 0 0 0 r
F
.61844 .98468 m .61705 .97922 L .62095 .97495 L 0 0 .039 r
F
.61023 .92846 m .61557 .93656 L .61975 1.01638 L 0 .995 .11 r
F
.61064 .90719 m .60949 .91651 L .61625 .91544 L 0 1 .488 r
F
.60501 .88026 m .6102 .90791 L .61023 .92846 L 0 .995 .11 r
F
.62184 .9233 m .61283 .93142 L .61992 .93252 L 0 1 .5 r
F
.62184 .9233 m .61086 .9282 L .61283 .93142 L F
.62184 .9233 m .61471 .92472 L .61086 .9282 L F
.6102 .90791 m .61557 .93656 L .61023 .92846 L 0 .995 .11 r
F
.60501 .88026 m .61018 .89376 L .61063 .89732 L F
.61861 .90966 m .62235 .917 L .63004 .91194 L 0 1 .504 r
F
.61865 .91203 m .62239 .91958 L .63008 .91402 L 0 1 .506 r
F
.61861 .90966 m .63004 .91194 L .62842 .90906 L 0 1 .504 r
F
.61865 .91203 m .63008 .91402 L .62846 .91094 L 0 1 .506 r
F
.61489 .90431 m .61865 .91203 L .62602 .90625 L 0 1 .502 r
F
.61064 .90719 m .61625 .91544 L .61956 .91223 L 0 1 .488 r
F
.61064 .90719 m .61956 .91223 L .6172 .90903 L F
.6102 .90791 m .61063 .89732 L .61557 .93656 L 0 .995 .11 r
F
.60501 .88026 m .61063 .89732 L .6102 .90791 L F
.61654 1.38074 m .59699 .45468 L .596 .44207 L 0 .223 .192 r
F
.61026 1.15624 m .61544 1.3473 L .61544 1.34731 L 0 0 .042 r
F
.61026 1.15624 m .61025 1.15556 L .61453 1.31364 L F
.61026 1.15624 m .61453 1.31364 L .61453 1.31372 L F
.61631 1.38085 m .61026 1.15624 L .61635 1.38093 L F
.60659 1.02023 m .60157 .83407 L .60657 1.01907 L F
.60659 1.02023 m .60657 1.01907 L .60706 1.03719 L F
.60704 1.03701 m .60659 1.02023 L .60706 1.03719 L F
.60704 1.03701 m .60706 1.03719 L .60733 1.04717 L F
.60731 1.04692 m .60733 1.04717 L .61635 1.38093 L F
.60413 .82293 m .60401 .82287 L .60306 .81786 L 0 0 .141 r
F
.61631 1.38085 m .6072 1.05581 L .60682 1.04086 L 0 0 .042 r
F
.60731 1.04692 m .60682 1.04086 L .60157 .83407 L F
.61631 1.38085 m .60682 1.04086 L .60731 1.04692 L F
.60614 1.28942 m .60611 1.29975 L .60737 1.37996 L 0 .288 .209 r
F
.59943 1.16348 m .60254 1.11811 L .60731 1.10988 L 0 .411 .187 r
F
.60325 1.07852 m .60611 1.29975 L .60614 1.28942 L 0 .288 .209 r
F
.60325 1.07852 m .60424 1.18146 L .60611 1.29975 L F
.59331 .95231 m .59719 .96046 L .60277 .95529 L 0 1 .49 r
F
.59331 .95231 m .60277 .95529 L .60109 .95209 L F
.60376 .92681 m .59344 .93573 L .60053 .93712 L 0 1 .478 r
F
.60376 .92681 m .59185 .932 L .59344 .93573 L F
.60376 .92681 m .59627 .92818 L .59185 .932 L F
.59909 .91795 m .59627 .92818 L .60376 .92681 L 0 1 .472 r
F
.58701 .91036 m .59766 .91375 L .59644 .91062 L 0 1 .494 r
F
.59442 .90879 m .59909 .91795 L .60294 .91467 L 0 1 .47 r
F
.59442 .90879 m .60294 .91467 L .60096 .91114 L F
.59372 .88023 m .59937 .8896 L .60184 .88669 L 0 .975 .472 r
F
.59372 .88023 m .60184 .88669 L .59946 .883 L F
.59484 .96772 m .60042 .96582 L .60295 .96567 L 0 0 0 r
F
.59484 .96772 m .60295 .96567 L .60061 .96651 L F
.60082 .96874 m .59701 .96791 L .60259 .96642 L F
.60098 .82375 m .60099 .82429 L .60274 1.01096 L 0 .267 .202 r
F
.6002 1.0628 m .60348 1.04789 L .60036 1.069 L 0 .364 .153 r
F
.59964 1.04183 m .60032 1.02983 L .60461 1.03116 L 0 .334 .132 r
F
.59458 1.05268 m .5994 1.0335 L .59964 1.04183 L F
.5994 1.0335 m .60032 1.02983 L .59964 1.04183 L F
.60274 1.01094 m .60274 1.01096 L .60274 1.01103 L 0 .267 .202 r
F
.60098 .82375 m .60274 1.01096 L .60274 1.01094 L F
.59977 1.046 m .60461 1.03116 L .60593 1.03808 L 0 .334 .132 r
F
.59964 1.04183 m .60461 1.03116 L .59977 1.046 L F
.59693 1.07767 m .5989 1.05404 L .60348 1.04789 L 0 .364 .153 r
F
.59693 1.07767 m .60581 1.07316 L .60111 1.08041 L F
.60274 1.01096 m .6028 1.04502 L .60383 1.10616 L 0 .288 .209 r
F
.60274 1.01135 m .60298 1.0361 L .60297 1.0362 L 0 .267 .202 r
F
.60055 .81367 m .60197 .83996 L .60157 .83407 L 0 .091 .152 r
F
.60056 .81372 m .60157 .83407 L .60057 .81375 L F
.60094 .81924 m .60274 1.01094 L .60274 1.01085 L 0 .267 .202 r
F
.60274 1.01085 m .60274 1.01103 L .60274 1.01135 L F
.60274 1.01094 m .60274 1.01103 L .60274 1.01085 L F
.60238 1.0222 m .60072 1.01716 L .60262 1.00935 L 0 .232 .101 r
F
.60275 1.02027 m .60235 1.00014 L .60264 1.00827 L 0 .267 .202 r
F
.6028 1.04502 m .6039 1.14949 L .6031 1.06762 L 0 .288 .209 r
F
.6039 1.14949 m .60424 1.18146 L .6031 1.06762 L F
.6031 1.06762 m .60424 1.18146 L .60325 1.07852 L F
.6028 1.04502 m .60387 1.15771 L .60424 1.18146 L F
.60845 1.37959 m .6028 1.04502 L .60737 1.37996 L F
.60608 1.37926 m .6028 1.04502 L .60275 1.02027 L 0 .267 .202 r
F
.6028 1.04502 m .60235 1.00014 L .60275 1.02027 L F
.60397 1.15179 m .60292 1.0386 L .60396 1.14138 L F
.60292 1.0386 m .60218 .95874 L .60295 1.0374 L F
.60292 1.0386 m .60295 1.0374 L .60396 1.14138 L F
.59712 .49314 m .5989 .60091 L .59873 .58332 L 0 .223 .192 r
F
.59712 .49314 m .59716 .50563 L .5989 .60091 L F
.5956 .71466 m .59981 .79859 L .59562 .71431 L 0 .091 .152 r
F
.60056 .81372 m .59821 .76647 L .59821 .76648 L F
.60056 .81372 m .60057 .81375 L .5995 .79238 L F
.60056 .81372 m .5995 .79238 L .5995 .79236 L F
.59999 .80226 m .60056 .81372 L .59999 .8023 L F
.59946 .87003 m .59582 .87718 L .60138 .88009 L 0 .894 .468 r
F
.59401 .97248 m .60082 .96874 L .60218 .96955 L 0 0 0 r
F
.59401 .97248 m .60218 .96955 L .59935 .97118 L F
.60238 .99202 m .59978 .99007 L .60057 .98605 L 0 .076 .052 r
F
.59787 .99661 m .59978 .99007 L .60238 .99202 L 0 .182 .071 r
F
.59273 1.00184 m .59768 .99358 L .59787 .99661 L F
.59768 .99358 m .59978 .99007 L .59787 .99661 L F
.59799 .99867 m .60238 .99202 L .60138 .99663 L F
.59273 1.00184 m .59787 .99661 L .59799 .99867 L F
.59787 .99661 m .60238 .99202 L .59799 .99867 L F
.60254 1.00525 m .60196 .94477 L .60264 1.00827 L 0 .267 .202 r
F
.60235 1.00014 m .60196 .94477 L .60254 1.00525 L F
.60235 1.00014 m .60031 .79267 L .60196 .94477 L F
.60031 .79267 m .60046 .79494 L .60264 1.00827 L F
.60211 .96446 m .60072 .82328 L .60205 .96027 L F
.596 .44207 m .59539 .43431 L .6072 1.05581 L 0 .223 .192 r
F
.60031 .79267 m .59995 .75566 L .60046 .79494 L 0 .267 .202 r
F
.60128 .81295 m .6025 .82837 L .60127 .81349 L 0 .066 .149 r
F
.6025 .82837 m .6026 .82972 L .60127 .81349 L F
.59157 .28334 m .59313 .37744 L .59392 .41557 L 0 .223 .192 r
F
.59864 .72373 m .59722 .74066 L .60075 .73944 L 0 1 .317 r
F
.59436 .42111 m .59392 .41557 L .6072 1.05581 L 0 .223 .192 r
F
.59157 .28334 m .59392 .41557 L .59436 .42111 L F
.60387 1.15771 m .60221 1.05305 L .60532 1.311 L 0 .288 .209 r
F
.58969 .5984 m .59931 .80174 L .58974 .59854 L 0 .091 .152 r
F
.59408 .65587 m .59711 .64229 L .59393 .65358 L 0 1 .23 r
F
.59711 .64229 m .5971 .64181 L .5936 .65476 L F
.59259 .44298 m .5946 .57038 L .59346 .42013 L 0 .005 .124 r
F
.5895 .52401 m .5946 .57038 L .59259 .44298 L F
.59408 .65587 m .59393 .65358 L .5936 .65476 L 0 1 .23 r
F
.5895 .52401 m .59566 .71014 L .5946 .57038 L 0 .005 .124 r
F
.59943 1.16348 m .59915 1.14101 L .60254 1.11811 L 0 .411 .187 r
F
.60221 1.05305 m .60165 1.06091 L .60532 1.311 L 0 .288 .209 r
F
.59971 1.2394 m .59967 1.20556 L .60327 1.17436 L 0 .433 .198 r
F
.60408 1.22649 m .60165 1.06091 L .60482 1.32239 L 0 0 .073 r
F
.60554 1.37947 m .60185 1.03736 L .60581 1.37936 L 0 .267 .202 r
F
.60003 .80321 m .60003 .80308 L .5984 .77045 L 0 .091 .152 r
F
.59711 .64229 m .59777 .63934 L .5971 .64181 L 0 1 .23 r
F
.59425 .6879 m .59981 .79859 L .59426 .68789 L 0 .091 .152 r
F
.59866 .77596 m .60003 .80321 L .59866 .77596 L F
.60003 .80321 m .60003 .80321 L .59866 .77596 L F
.60004 .80241 m .60004 .8025 L .59892 .78111 L F
.59261 .65453 m .59981 .79721 L .59965 .79387 L F
.59965 .79387 m .59981 .79721 L .59981 .79704 L F
.60007 .80214 m .60007 .80215 L .59812 .76362 L F
.59812 .76369 m .60007 .80213 L .59812 .76362 L F
.60007 .80213 m .60007 .80214 L .59812 .76362 L F
.59934 .80687 m .59976 .81206 L .5998 .81365 L 0 .066 .149 r
F
.59731 .74775 m .59974 .79572 L .59706 .74416 L 0 .091 .152 r
F
.59974 .79572 m .59968 .79527 L .59706 .74416 L F
.59718 .74568 m .60006 .80359 L .59719 .74552 L F
.59974 .79573 m .59974 .79572 L .59442 .69056 L F
.59974 .79573 m .59442 .69056 L .59442 .6905 L F
.59127 .62832 m .5956 .71466 L .59562 .71433 L F
.59441 .69049 m .59105 .62409 L .59105 .62406 L F
.59974 .79573 m .59442 .6905 L .59441 .69049 L F
.59442 .6905 m .59105 .62409 L .59441 .69049 L F
.58977 .59865 m .59425 .6879 L .58978 .59868 L F
.59425 .6879 m .59426 .68789 L .58978 .59868 L F
.5956 .71469 m .59568 .71653 L .59912 .78487 L F
.59538 .71798 m .59931 .80174 L .5956 .71469 L F
.59101 .62358 m .59731 .74775 L .59706 .74416 L F
.58996 .60269 m .595 .70305 L .58997 .60275 L F
.59568 .71653 m .59712 .75039 L .5974 .75065 L F
.59712 .75039 m .59931 .80174 L .5974 .75065 L F
.595 .70305 m .59582 .71943 L .595 .70308 L F
.59582 .71943 m .59582 .71941 L .595 .70308 L F
.595 .70305 m .595 .70308 L .58997 .60275 L F
.59582 .71943 m .59866 .77596 L .59582 .71941 L F
.59442 .6905 m .59442 .69056 L .59105 .62409 L F
.59105 .62406 m .59105 .62409 L .58991 .60145 L F
.59458 1.05268 m .59964 1.04183 L .59977 1.046 L 0 .334 .132 r
F
.58929 .59049 m .58891 .71118 L .58959 .59805 L 0 0 .087 r
F
.58899 .58557 m .58899 .58555 L .58862 .57781 L 0 .091 .152 r
F
.58899 .58557 m .58862 .57781 L .58862 .57787 L F
.58885 .58061 m .58891 .71118 L .58928 .59198 L 0 0 .087 r
F
.58435 .71982 m .59422 .7669 L .58435 .71934 L 0 .248 .238 r
F
.58435 .71844 m .59422 .7669 L .59044 .74399 L F
.58435 .71921 m .59422 .7669 L .58435 .71844 L F
.58436 .72086 m .59431 .77239 L .58436 .72041 L F
.58435 .72295 m .59071 .76158 L .58436 .72252 L F
.58436 .72252 m .59071 .76158 L .58436 .72086 L F
.58478 .69102 m .58948 .71924 L .5849 .69037 L 0 .238 .224 r
F
.58948 .71924 m .5894 .7126 L .58913 .71054 L F
.58924 .69027 m .59201 .71058 L .5892 .68445 L 0 .238 .216 r
F
.59146 1.03435 m .59 1.02841 L .59209 1.02079 L 0 .306 .11 r
F
.59146 1.03435 m .60238 1.0222 L .60032 1.02983 L F
.59146 1.03435 m .60032 1.02983 L .59589 1.03496 L F
.59302 1.09511 m .59 .92249 L .5931 1.10406 L 0 0 .073 r
F
.59 .92249 m .58997 .92221 L .5931 1.10406 L F
.58435 .71982 m .59431 .77239 L .59422 .7669 L 0 .248 .238 r
F
.58436 .72041 m .59431 .77239 L .58435 .71982 L F
.58409 .71738 m .59044 .74399 L .584 .71455 L F
.5847 .69394 m .59376 .75376 L .5847 .69383 L 0 .238 .224 r
F
.58464 .69969 m .59044 .74399 L .58467 .6974 L F
.58469 .69555 m .59044 .74399 L .59376 .75376 L F
.58467 .6974 m .59044 .74399 L .58469 .69555 L F
.58471 .69301 m .59376 .75376 L .59323 .74175 L F
.5847 .69356 m .59376 .75376 L .58471 .69301 L F
.58707 .91585 m .59771 .9178 L .5965 .91489 L 0 1 .518 r
F
.58427 .90219 m .58701 .91036 L .59462 .90592 L 0 1 .49 r
F
.58701 .91036 m .56852 .92116 L .57795 .92142 L 0 1 .494 r
F
.58701 .91036 m .56772 .91777 L .56852 .92116 L F
.58701 .91036 m .57564 .91314 L .56772 .91777 L F
.58427 .90219 m .57564 .91314 L .58701 .91036 L 0 1 .49 r
F
.58435 .90881 m .58707 .91585 L .59468 .91051 L 0 1 .514 r
F
.58435 .90881 m .59468 .91051 L .59346 .90756 L F
.58153 .89386 m .58427 .90219 L .59157 .89801 L 0 1 .484 r
F
.58427 .90219 m .56653 .91257 L .57564 .91314 L 0 1 .49 r
F
.58427 .90219 m .56572 .90904 L .56653 .91257 L F
.58427 .90219 m .57333 .90459 L .56572 .90904 L F
.58153 .89386 m .57333 .90459 L .58427 .90219 L 0 1 .484 r
F
.58161 .90173 m .58435 .90881 L .59163 .9031 L 0 1 .508 r
F
.58161 .90173 m .59163 .9031 L .59041 .90009 L F
.59217 .86209 m .58696 .86899 L .59596 .86729 L 0 1 .542 r
F
.59217 .86209 m .58359 .8639 L .57808 .86676 L F
.58752 .85751 m .58359 .8639 L .59217 .86209 L 0 1 .436 r
F
.58752 .85751 m .59217 .86209 L .5971 .85912 L F
.58752 .85751 m .5971 .85912 L .59508 .85698 L F
.58396 .85499 m .58752 .85751 L .59241 .85435 L 0 1 .273 r
F
.58396 .85499 m .59241 .85435 L .59087 .853 L F
.58723 .83317 m .57595 .8558 L .5835 .85595 L 0 1 .402 r
F
.59349 .83636 m .58468 .84807 L .59107 .84508 L 0 1 .468 r
F
.59349 .83636 m .58313 .8469 L .58468 .84807 L F
.59349 .83636 m .5869 .84188 L .58313 .8469 L F
.58893 .83295 m .5869 .84188 L .59349 .83636 L 0 1 .453 r
F
.58893 .83295 m .59697 .83114 L .59503 .8297 L F
.58337 .8223 m .5749 .83778 L .5861 .83262 L 0 1 .448 r
F
.5861 .83262 m .56789 .84891 L .5772 .84801 L 0 1 .453 r
F
.5861 .83262 m .56709 .84477 L .56789 .84891 L F
.5861 .83262 m .5749 .83778 L .56709 .84477 L F
.58337 .8223 m .5659 .83844 L .5749 .83778 L 0 1 .448 r
F
.58337 .8223 m .5651 .83413 L .5659 .83844 L F
.58337 .8223 m .57259 .82722 L .5651 .83413 L F
.58357 .81984 m .57923 .83908 L .58723 .83316 L 0 1 .391 r
F
.58435 .82972 m .58893 .83295 L .59212 .82761 L 0 1 .439 r
F
.58435 .82972 m .59212 .82761 L .59018 .82626 L F
.59283 .81067 m .58725 .82433 L .59284 .8204 L 0 1 .429 r
F
.59283 .81067 m .5853 .82311 L .58725 .82433 L F
.59283 .81067 m .58769 .81725 L .5853 .82311 L F
.58706 .80782 m .59283 .81067 L .59486 .80487 L 0 1 .41 r
F
.58706 .80782 m .58769 .81725 L .59283 .81067 L F
.58706 .80782 m .59486 .80487 L .59244 .80371 L F
.59168 .78794 m .58638 .80141 L .58881 .80223 L 0 1 .387 r
F
.59168 .78794 m .58761 .79529 L .58638 .80141 L F
.5847 .78724 m .59167 .78794 L .59255 .78225 L 0 1 .363 r
F
.5847 .78724 m .58761 .79529 L .59167 .78794 L F
.59909 .91795 m .59199 .91881 L .58786 .92237 L 0 1 .472 r
F
.5847 .78724 m .59255 .78225 L .58965 .782 L 0 1 .363 r
F
.56634 .92437 m .56823 .93263 L .5705 .92947 L 0 1 .495 r
F
.56634 .92437 m .5705 .92947 L .56971 .92618 L F
.58707 .91585 m .56858 .92767 L .578 .92671 L 0 1 .518 r
F
.58707 .91585 m .56779 .92509 L .56858 .92767 L F
.58707 .91585 m .57571 .92003 L .56779 .92509 L F
.58435 .90881 m .57571 .92003 L .58707 .91585 L 0 1 .514 r
F
.59442 .90879 m .58547 .91647 L .59199 .91881 L 0 1 .47 r
F
.59442 .90879 m .58387 .91249 L .58547 .91647 L F
.59442 .90879 m .5877 .9092 L .58387 .91249 L F
.58554 .76962 m .5853 .78227 L .59 .77572 L 0 1 .331 r
F
.58973 .89941 m .5877 .9092 L .59442 .90879 L 0 1 .469 r
F
.58973 .89941 m .59442 .90879 L .59798 .90575 L F
.58973 .89941 m .59798 .90575 L .59598 .9021 L F
.57878 .88539 m .58153 .89386 L .58851 .89009 L 0 1 .477 r
F
.58153 .89386 m .56452 .90362 L .57333 .90459 L 0 1 .484 r
F
.58153 .89386 m .56372 .89992 L .56452 .90362 L F
.58153 .89386 m .571 .89573 L .56372 .89992 L F
.57887 .89459 m .58161 .90173 L .58857 .89549 L 0 1 .494 r
F
.57887 .89459 m .58857 .89549 L .58735 .89238 L F
.58503 .88982 m .58973 .89941 L .59299 .89653 L 0 1 .468 r
F
.58503 .88982 m .59299 .89653 L .591 .89277 L F
.59372 .88023 m .588 .88703 L .59373 .8898 L 0 .975 .472 r
F
.59372 .88023 m .586 .88315 L .588 .88703 L F
.59372 .88023 m .58845 .88024 L .586 .88315 L F
.58779 .86997 m .58844 .88024 L .59372 .88023 L 0 .938 .465 r
F
.58779 .86997 m .59372 .88023 L .59582 .87718 L F
.58779 .86997 m .59582 .87718 L .59333 .87312 L F
.59258 .85941 m .58959 .86683 L .59489 .87005 L 0 .849 .458 r
F
.59258 .85941 m .5871 .86252 L .58959 .86683 L F
.59258 .85941 m .58838 .85934 L .5871 .86252 L F
.5804 .85259 m .58396 .85499 L .58855 .85108 L 0 1 .321 r
F
.5804 .85259 m .58855 .85108 L .58701 .84986 L F
.5854 .84742 m .58838 .85934 L .59258 .85941 L 0 .813 .447 r
F
.5854 .84742 m .59258 .85941 L .5935 .85587 L F
.5854 .84742 m .5935 .85587 L .59051 .85108 L F
.58723 .83317 m .57439 .84878 L .57595 .8558 L 0 1 .402 r
F
.58723 .83317 m .57923 .83908 L .57439 .84878 L F
.58893 .83295 m .5808 .84513 L .5869 .84188 L 0 1 .453 r
F
.58893 .83295 m .57924 .84396 L .5808 .84513 L F
.58893 .83295 m .58272 .83874 L .57924 .84396 L F
.58435 .82972 m .58272 .83874 L .58893 .83295 L 0 1 .439 r
F
.58629 .83427 m .58602 .84354 L .5909 .84753 L 0 .699 .428 r
F
.58629 .83427 m .5909 .84753 L .59441 .8476 L F
.58629 .83427 m .59441 .8476 L .59454 .84363 L F
.58629 .83427 m .59454 .84363 L .59118 .83827 L F
.58357 .81984 m .57233 .83899 L .57923 .83908 L 0 1 .391 r
F
.57976 .82673 m .58435 .82972 L .58725 .82433 L 0 1 .423 r
F
.57976 .82673 m .58725 .82433 L .5853 .82311 L F
.58357 .81984 m .57114 .83296 L .57233 .83899 L 0 1 .391 r
F
.58357 .81984 m .57595 .82476 L .57114 .83296 L F
.58706 .80782 m .5823 .82137 L .58769 .81725 L 0 1 .41 r
F
.58467 .81866 m .58614 .82972 L .5908 .83425 L 0 .587 .403 r
F
.58467 .81866 m .5908 .83425 L .59365 .83427 L F
.58467 .81866 m .59302 .82952 L .58933 .82319 L F
.58467 .81866 m .59365 .83427 L .59302 .82952 L F
.58706 .80782 m .58026 .82027 L .5823 .82137 L 0 1 .41 r
F
.58706 .80782 m .5823 .81446 L .58026 .82027 L F
.58127 .80576 m .58706 .80782 L .58881 .80223 L 0 1 .389 r
F
.58127 .80576 m .5823 .81446 L .58706 .80782 L F
.58127 .80576 m .58881 .80223 L .58638 .80141 L F
.57523 .80478 m .58127 .80576 L .58266 .80053 L 0 1 .361 r
F
.57523 .80478 m .58266 .80053 L .58012 .80017 L F
.58069 .79889 m .59044 .818 L .58911 .81192 L 0 .517 .376 r
F
.58069 .79889 m .58822 .81825 L .59044 .818 L F
.59044 .818 m .58933 .82319 L .59302 .82952 L 0 .45 .38 r
F
.59044 .818 m .58822 .81825 L .58933 .82319 L F
.58419 .73756 m .59071 .76158 L .58585 .74177 L 0 .268 .259 r
F
.58208 .73219 m .58418 .73935 L .58419 .73756 L F
.58418 .73935 m .59071 .76158 L .58419 .73756 L F
.58457 .6817 m .58494 .67055 L .58465 .68097 L 0 0 .1 r
F
.58453 .68273 m .58473 .67875 L .58461 .68041 L F
.58417 .69295 m .58436 .6875 L .58292 .73133 L F
.58469 .67795 m .5847 .67791 L .58292 .73133 L F
.58467 .67818 m .58469 .67795 L .58292 .73133 L F
.58422 .69198 m .58453 .68293 L .58453 .68273 L F
.58474 .67583 m .58475 .67575 L .58292 .73133 L F
.5829 .73092 m .58378 .7051 L .58292 .73133 L F
.58289 .73071 m .58378 .7051 L .5829 .73092 L F
.58289 .73071 m .58465 .67841 L .58378 .7051 L F
.57769 .77492 m .58554 .76962 L .58539 .76547 L 0 1 .29 r
F
.57769 .77492 m .5825 .77744 L .58554 .76962 L F
.57769 .77492 m .58539 .76547 L .58215 .76777 L F
.58394 .75517 m .58153 .76335 L .58215 .76777 L 0 1 .293 r
F
.5847 .78724 m .58266 .80053 L .58761 .79529 L 0 1 .363 r
F
.57459 .77295 m .5847 .79573 L .58304 .78835 L 0 .516 .349 r
F
.5847 .79573 m .58499 .7964 L .58468 .79513 L F
.5847 .79573 m .58468 .79513 L .58304 .78835 L F
.58327 .72006 m .58453 .68293 L .58422 .69198 L 0 0 .1 r
F
.57459 .77295 m .58336 .79744 L .58471 .79658 L 0 .516 .349 r
F
.5847 .79573 m .58471 .79658 L .58499 .7964 L F
.57459 .77295 m .58471 .79658 L .5847 .79573 L F
.58448 .68487 m .58511 .68834 L .58466 .68372 L 0 .238 .224 r
F
.58292 .73133 m .58457 .6817 L .58465 .68097 L 0 0 .1 r
F
.58311 .72484 m .58451 .68497 L .58453 .68293 L F
.58554 .76962 m .5824 .78286 L .5853 .78227 L 0 1 .331 r
F
.58554 .76962 m .5825 .77744 L .5824 .78286 L F
.57756 .76685 m .58618 .78425 L .58173 .77318 L 0 .43 .329 r
F
.57756 .76685 m .58854 .79349 L .58618 .78425 L F
.57756 .76685 m .58721 .79471 L .58854 .79349 L F
.57756 .76685 m .58304 .78835 L .58721 .79471 L F
.57756 .76685 m .5788 .77867 L .58304 .78835 L F
.58208 .73219 m .59416 .77876 L .59071 .76158 L 0 .268 .259 r
F
.58208 .73219 m .59387 .78175 L .59416 .77876 L F
.58208 .73219 m .59006 .77204 L .59387 .78175 L F
.58208 .73219 m .5853 .75617 L .59006 .77204 L F
.58208 .73219 m .58188 .73912 L .5853 .75617 L F
.57983 .75885 m .57901 .7623 L .58173 .77318 L 0 .348 .306 r
F
.58394 .75517 m .58215 .76777 L .58539 .76547 L 0 1 .293 r
F
.57983 .75885 m .58854 .77906 L .58391 .76601 L 0 .348 .306 r
F
.57983 .75885 m .59127 .78999 L .58854 .77906 L F
.58427 .77093 m .59028 .79147 L .59127 .78999 L F
.57983 .75885 m .58432 .77285 L .58427 .77093 L F
.58432 .77285 m .59028 .79147 L .58427 .77093 L F
.58315 .72352 m .58327 .72012 L .58327 .72006 L 0 0 .1 r
F
.57983 .75885 m .58618 .78425 L .59028 .79147 L 0 .348 .306 r
F
.57983 .75885 m .58173 .77318 L .58618 .78425 L F
.58135 .7479 m .58083 .75268 L .58391 .76601 L 0 .296 .282 r
F
.58135 .7479 m .59006 .77204 L .5853 .75617 L F
.58135 .7479 m .59316 .78546 L .59006 .77204 L F
.58135 .7479 m .59251 .78741 L .59316 .78546 L F
.58135 .7479 m .58854 .77906 L .59251 .78741 L F
.58135 .7479 m .58391 .76601 L .58854 .77906 L F
.58094 .78902 m .58289 .73071 L .5829 .73092 L 0 0 .1 r
F
.58094 .78902 m .58315 .72358 L .58315 .72352 L F
.58315 .72358 m .58327 .72012 L .58315 .72352 L F
.58094 .78902 m .58312 .72545 L .58311 .72484 L F
.58312 .72545 m .58451 .68497 L .58311 .72484 L F
.58327 .72012 m .58453 .68293 L .58327 .72006 L F
.58451 .68497 m .58473 .67875 L .58453 .68273 L F
.59283 .81067 m .59284 .8204 L .59834 .81393 L 0 1 .429 r
F
.58499 .7964 m .58911 .81192 L .59353 .81771 L 0 .395 .352 r
F
.58499 .7964 m .59365 .81092 L .5894 .80217 L F
.58499 .7964 m .59542 .81759 L .59365 .81092 L F
.58499 .7964 m .59353 .81771 L .59542 .81759 L F
.58854 .79349 m .5894 .80217 L .59365 .81092 L 0 .298 .319 r
F
.58854 .79349 m .59734 .81026 L .59287 .80014 L F
.58854 .79349 m .59954 .81775 L .59734 .81026 L F
.58854 .79349 m .598 .8176 L .59954 .81775 L F
.58854 .79349 m .59365 .81092 L .598 .8176 L F
.59035 .92633 m .58892 .6348 L .58897 .63424 L 0 0 .08 r
F
.59401 .97248 m .59086 .97059 L .59618 .9693 L 0 0 0 r
F
.59273 1.00184 m .59142 .99436 L .59509 .99107 L 0 .182 .071 r
F
.59827 1.38759 m .5941 1.21744 L .59464 1.27903 L 0 0 .116 r
F
.59858 1.38671 m .59572 1.26117 L .59827 1.38759 L 0 0 .073 r
F
.59809 1.386 m .59572 1.26117 L .59839 1.38613 L F
.5987 1.38639 m .59572 1.26117 L .59858 1.38671 L F
.59839 1.38613 m .59572 1.26117 L .5987 1.38639 L F
.59728 1.33885 m .59035 .92639 L .59 .92249 L F
.59056 .96714 m .58213 .96823 L .58838 .96719 L 0 0 0 r
F
.59056 .96714 m .58056 .96861 L .58213 .96823 L F
.59056 .96714 m .58416 .96814 L .58056 .96861 L F
.58593 .96828 m .58416 .96814 L .59056 .96714 L F
.59088 1.03791 m .59033 .92617 L .59035 .92633 L 0 0 .08 r
F
.59033 .92617 m .58892 .6348 L .59035 .92633 L F
.60113 1.10481 m .60125 1.10399 L .60127 1.10439 L 0 .39 .172 r
F
.59706 .74416 m .599 .78195 L .59892 .78111 L 0 .091 .152 r
F
.59866 .77596 m .59866 .77596 L .595 .70309 L F
.595 .70308 m .595 .70309 L .58997 .60275 L F
.59866 .77596 m .595 .70309 L .595 .70308 L F
.59127 .62832 m .59562 .71433 L .59562 .71431 L F
.59812 .76369 m .59812 .76362 L .5905 .61304 L F
.59812 .76369 m .5905 .61304 L .5905 .61305 L F
.59106 .62427 m .59731 .74775 L .59101 .62358 L F
.59096 .62213 m .59812 .76369 L .59095 .62191 L F
.59261 .65461 m .59981 .79721 L .59261 .65453 L F
.59981 .79704 m .59293 .66089 L .59293 .66089 L F
.59821 .76648 m .5951 .70383 L .5951 .70388 L F
.59305 .66324 m .59981 .79704 L .59305 .66323 L F
.59821 .76647 m .5951 .70383 L .59821 .76648 L F
.59513 .70568 m .59839 .77054 L .59511 .70452 L F
.59839 .77054 m .5984 .77045 L .59511 .70452 L F
.5995 .79236 m .5995 .79238 L .59519 .70567 L F
.59519 .70567 m .59519 .70567 L .5951 .70383 L F
.5995 .79236 m .59519 .70567 L .59519 .70567 L F
.59664 .73507 m .59999 .80226 L .59664 .73484 L F
.59999 .80226 m .59999 .8023 L .59664 .73484 L F
.59693 .74025 m .59974 .79573 L .59693 .74019 L F
.59974 .79573 m .59974 .79573 L .59693 .74019 L F
.59272 .65372 m .59576 .71588 L .59566 .71046 L F
.59237 .65007 m .59693 .74025 L .59232 .64914 L F
.59693 .74025 m .59693 .74019 L .59232 .64914 L F
.59239 .65024 m .59813 .76377 L .59237 .65005 L F
.59813 .76377 m .59812 .76369 L .59237 .65005 L F
.59981 .79704 m .59981 .79705 L .59293 .66089 L F
.59232 .64704 m .59895 .78108 L .59272 .65372 L F
.59813 .76377 m .60007 .80212 L .59812 .76369 L F
.60007 .80212 m .60007 .80213 L .59812 .76369 L F
.59566 .71046 m .59895 .78108 L .59568 .71089 L F
.59576 .71588 m .59895 .78108 L .59566 .71046 L F
.59422 .7669 m .59722 .78273 L .5972 .78365 L 0 0 .141 r
F
.59422 .7669 m .59695 .78263 L .59704 .78156 L F
.59566 .71014 m .59568 .71089 L .5955 .68668 L 0 .005 .124 r
F
.59566 .71014 m .5955 .68668 L .59346 .42013 L F
.59551 .78429 m .59588 .78668 L .59593 .78604 L 0 .051 .169 r
F
.59588 .78668 m .59725 .79562 L .59593 .78604 L F
.59544 .78577 m .59725 .79562 L .59551 .78429 L F
.5951 .70383 m .59718 .74568 L .59509 .70308 L 0 .091 .152 r
F
.59718 .74568 m .59719 .74552 L .59509 .70308 L F
.58943 .54506 m .59568 .71089 L .5895 .52401 L 0 .005 .124 r
F
.59132 .6267 m .59232 .64704 L .59272 .65372 L 0 .091 .152 r
F
.59947 .79022 m .60026 .79992 L .59947 .79036 L 0 .066 .149 r
F
.59947 .79036 m .60026 .79992 L .60025 .80007 L F
.60263 1.04733 m .59694 .45406 L .60278 1.04521 L 0 .267 .202 r
F
.6028 1.04502 m .60221 1.05305 L .60337 1.12633 L 0 .288 .209 r
F
.6028 1.04502 m .60337 1.12633 L .60387 1.15771 L F
.59694 .45406 m .59699 .45468 L .60608 1.37926 L 0 .267 .202 r
F
.5986 .63061 m .59811 .57735 L .59725 .53205 L 0 .223 .192 r
F
.59738 .57039 m .59725 .53205 L .59539 .43431 L F
.59974 .79572 m .59982 .7973 L .59968 .79527 L 0 .091 .152 r
F
.59982 .7973 m .5999 .79954 L .59968 .79527 L F
.60007 .80215 m .60007 .80215 L .59974 .79572 L F
.60007 .80215 m .59974 .79572 L .59974 .79573 L F
.59974 .79573 m .60007 .80215 L .59974 .79573 L F
.59895 .78108 m .60006 .80359 L .599 .78104 L F
.60006 .80359 m .60024 .80611 L .59568 .71089 L F
.59798 .77399 m .60007 .81764 L .59803 .77465 L F
.58959 .59805 m .60007 .81764 L .58959 .59807 L F
.58959 .59805 m .59431 .72615 L .60007 .81764 L F
.59712 .49314 m .596 .44207 L .59716 .50563 L 0 .223 .192 r
F
.59258 .85941 m .59946 .87003 L .60075 .86685 L 0 .849 .458 r
F
.59258 .85941 m .60075 .86685 L .59789 .86263 L F
.59092 .68121 m .60007 .81764 L .59431 .72615 L 0 .066 .149 r
F
.60019 .83459 m .59767 .83441 L .59855 .8384 L 0 .414 .38 r
F
.59044 .818 m .59767 .83441 L .60019 .83459 L 0 .45 .38 r
F
.59044 .818 m .60019 .83459 L .59908 .82964 L F
.59954 .81775 m .598 .8176 L .60002 .82305 L 0 .206 .261 r
F
.60581 1.37936 m .59539 .43431 L .59694 .45406 L 0 .267 .202 r
F
.6028 1.04502 m .6009 .93281 L .60221 1.05305 L 0 .288 .209 r
F
.59094 .29428 m .59446 .47891 L .59384 .6499 L 0 0 .08 r
F
.59293 .66089 m .58929 .58887 L .58929 .58887 L 0 .091 .152 r
F
.58948 .71924 m .59323 .74175 L .5894 .7126 L 0 .238 .224 r
F
.59323 .74175 m .59383 .7472 L .5939 .74727 L 0 .009 .137 r
F
.59316 .78546 m .59502 .79204 L .59509 .79156 L 0 .137 .22 r
F
.59059 .63574 m .59131 .66295 L .59281 .69461 L 0 .091 .152 r
F
.59195 .66754 m .59281 .69461 L .59431 .72615 L F
.58998 .60293 m .59106 .62427 L .59102 .62365 L F
.58998 .60293 m .59102 .62365 L .59101 .62358 L F
.58911 .58567 m .58998 .60293 L .59101 .62358 L F
.5905 .61305 m .5905 .61304 L .5891 .58551 L F
.59096 .62213 m .59095 .62191 L .5891 .58551 L F
.58989 .60096 m .59237 .65007 L .58991 .60145 L F
.59237 .65007 m .59232 .64914 L .58991 .60145 L F
.59239 .65024 m .59237 .65005 L .58984 .59992 L F
.59239 .65024 m .58984 .59992 L .58982 .59952 L F
.58979 .59875 m .59239 .65024 L .58982 .59952 L F
.59305 .66324 m .59305 .66323 L .58979 .59875 L F
.59305 .66324 m .58979 .59875 L .58979 .59874 L F
.58978 .59868 m .59305 .66324 L .58979 .59873 L F
.58997 .60275 m .59513 .70568 L .59015 .60501 L F
.59513 .70568 m .59511 .70452 L .59015 .60501 L F
.59147 .63067 m .5951 .70383 L .59132 .6267 L F
.5951 .70383 m .59509 .70308 L .59132 .6267 L F
.5951 .70388 m .5951 .70383 L .59026 .60632 L F
.59323 .74175 m .59606 .76363 L .59624 .76547 L 0 .009 .137 r
F
.59015 .60501 m .59664 .73507 L .59026 .60632 L 0 .091 .152 r
F
.59664 .73507 m .59664 .73484 L .59026 .60632 L F
.59316 .78546 m .59781 .80012 L .59789 .7999 L 0 .137 .22 r
F
.59316 .78546 m .59789 .7999 L .59795 .79931 L F
.59316 .78546 m .59787 .79908 L .59725 .79562 L F
.58959 .59807 m .59798 .77399 L .58969 .5984 L 0 .091 .152 r
F
.59798 .77399 m .59803 .77465 L .58969 .5984 L F
.58906 .53533 m .58971 .58226 L .59568 .71089 L 0 .005 .124 r
F
.58838 .50594 m .58839 .50741 L .58838 .5037 L 0 0 .087 r
F
.58852 .52848 m .58848 .53009 L .58823 .46658 L 0 0 .08 r
F
.58862 .52484 m .58852 .52848 L .58838 .49884 L F
.5888 .54376 m .58852 .52848 L .58862 .52484 L F
.58862 .5495 m .58971 .58226 L .58906 .53533 L 0 .005 .124 r
F
.58907 .58483 m .58996 .60269 L .58906 .58473 L 0 .091 .152 r
F
.58885 .58061 m .58928 .59198 L .58927 .58855 L 0 0 .087 r
F
.58982 .59952 m .58984 .59992 L .58907 .58477 L 0 .091 .152 r
F
.58969 .5984 m .58974 .59854 L .5893 .58926 L F
.58982 .59952 m .58907 .58477 L .58908 .58489 L F
.58927 .58855 m .58928 .59198 L .58929 .58898 L 0 0 .087 r
F
.58982 .59952 m .589 .58337 L .58903 .58388 L 0 .091 .152 r
F
.58919 .58711 m .59096 .62213 L .5891 .58551 L F
.58978 .59868 m .58979 .59873 L .58839 .57119 L F
.5891 .58551 m .58989 .60096 L .58911 .58567 L F
.58989 .60096 m .58991 .60145 L .58911 .58567 L F
.58909 .58517 m .58919 .58711 L .5891 .58551 L F
.58911 .58568 m .58997 .60275 L .58919 .58575 L F
.58996 .60269 m .58997 .60275 L .58858 .57519 L F
.58859 .5752 m .58858 .57519 L .58839 .5714 L F
.58996 .60269 m .58858 .57519 L .58859 .5752 L F
.58854 .56826 m .58851 .5646 L .58852 .57103 L 0 0 .087 r
F
.58854 .57191 m .58852 .57103 L .58854 .57511 L F
.58854 .56826 m .58852 .57103 L .58854 .57191 L F
.58852 .562 m .58853 .56264 L .5885 .54954 L F
.58846 .5422 m .58844 .54181 L .58851 .5646 L F
.57801 .36973 m .58105 .39309 L .58519 .38059 L 0 1 .251 r
F
.57766 .41514 m .58519 .38059 L .58105 .39309 L 0 1 .26 r
F
.57766 .41514 m .58803 .38811 L .58519 .38059 L F
.57766 .41514 m .58768 .41071 L .58803 .38811 L F
.57766 .41514 m .58432 .43284 L .58768 .41071 L F
.57766 .41514 m .58017 .43966 L .58432 .43284 L F
.57656 .45595 m .58432 .43284 L .58017 .43966 L 0 1 .268 r
F
.57656 .45595 m .58688 .44157 L .58432 .43284 L F
.57656 .45595 m .58615 .46008 L .58688 .44157 L F
.57656 .45595 m .58255 .47645 L .58615 .46008 L F
.5827 .373 m .58353 .41744 L .58856 .55148 L 0 .005 .124 r
F
.58857 .55093 m .58856 .55148 L .58848 .53009 L 0 0 .08 r
F
.58862 .5495 m .58856 .55148 L .58971 .58226 L 0 .005 .124 r
F
.59464 1.27903 m .5941 1.21744 L .58905 1.08205 L 0 0 .116 r
F
.59464 1.27903 m .58905 1.08205 L .5887 1.10147 L F
.59733 1.3398 m .59037 .92659 L .59728 1.33885 L 0 0 .073 r
F
.58924 .69027 m .58938 .71054 L .59201 .71058 L 0 .238 .216 r
F
.58835 .57218 m .58862 .5779 L .58835 .57216 L 0 .091 .152 r
F
.58862 .5779 m .58862 .57788 L .58835 .57216 L F
.58886 .63104 m .58881 .61827 L .58885 .61117 L 0 0 .087 r
F
.58891 .71118 m .58882 .63166 L .58886 .63104 L F
.58882 .63166 m .58881 .61827 L .58886 .63104 L F
.58552 .65217 m .58753 .5939 L .58554 .65136 L 0 0 .1 r
F
.5836 .67931 m .58759 .58642 L .58409 .6688 L 0 0 .064 r
F
.58359 .67946 m .58759 .58642 L .5836 .67931 L F
.58507 .66875 m .58603 .63778 L .58508 .6686 L 0 0 .1 r
F
.58479 .65775 m .58512 .64895 L .58493 .65223 L 0 0 .064 r
F
.58451 .66814 m .58512 .64895 L .58479 .65775 L F
.58514 .66371 m .58541 .65581 L .58515 .66363 L 0 0 .1 r
F
.5839 .62964 m .5809 .6492 L .58382 .65535 L 0 1 .337 r
F
.58365 .68885 m .58409 .69165 L .58376 .68772 L 0 .238 .224 r
F
.58409 .69165 m .58423 .69082 L .58376 .68772 L F
.58389 .68611 m .58392 .68582 L .58382 .68521 L F
.58382 .68521 m .58392 .68582 L .58393 .68573 L F
.5836 .67931 m .58432 .684 L .58424 .68117 L F
.58358 .67958 m .58432 .684 L .5836 .67931 L F
.58343 .67909 m .58432 .684 L .58347 .67894 L F
.58432 .684 m .58436 .68305 L .58424 .68117 L F
.58376 .68772 m .58409 .68987 L .58377 .68763 L F
.58409 .68987 m .58409 .6898 L .58377 .68763 L F
.58497 .66132 m .58501 .65991 L .58466 .6658 L 0 0 .064 r
F
.58416 .67733 m .58496 .66327 L .58451 .66814 L F
.58496 .66327 m .58466 .6658 L .58451 .66814 L F
.58484 .67014 m .58409 .6688 L .58759 .58642 L 0 0 .1 r
F
.58425 .67293 m .58433 .67276 L .58451 .66814 L 0 0 .064 r
F
.58397 .67613 m .58409 .6688 L .58484 .67014 L 0 0 .1 r
F
.58388 .67672 m .58423 .68112 L .58484 .67014 L 0 .238 .216 r
F
.58365 .68885 m .58376 .68772 L .58362 .68678 L 0 .238 .224 r
F
.58313 .71401 m .58315 .71357 L .58292 .71246 L 0 .248 .238 r
F
.58292 .71246 m .58315 .71357 L .58315 .71345 L F
.58362 .68926 m .58363 .68914 L .58362 .68921 L 0 .238 .224 r
F
.5835 .69092 m .58362 .68926 L .58346 .68762 L F
.58365 .68885 m .584 .69181 L .58403 .69126 L F
.58346 .68762 m .58364 .68905 L .58365 .68885 L F
.5835 .68369 m .58362 .68678 L .58382 .68521 L F
.58377 .68763 m .58409 .68977 L .5841 .68954 L F
.58362 .68678 m .58376 .68772 L .58377 .68763 L F
.58388 .67672 m .58382 .6772 L .58424 .68117 L 0 .238 .216 r
F
.58292 .71337 m .58388 .67672 L .58328 .7178 L 0 0 .1 r
F
.58388 .67672 m .58409 .6688 L .58397 .67613 L F
.58388 .67672 m .58397 .67613 L .58328 .7178 L F
.57603 .61546 m .58368 .61896 L .58043 .61324 L 0 1 .328 r
F
.57603 .61546 m .5839 .62964 L .58368 .61896 L F
.57603 .61546 m .58094 .63818 L .5839 .62964 L F
.57603 .61546 m .57653 .64041 L .58094 .63818 L F
.5839 .62964 m .58094 .63818 L .5809 .6492 L 0 1 .337 r
F
.57627 .65019 m .58382 .65535 L .5809 .6492 L 0 1 .348 r
F
.57627 .65019 m .58329 .66539 L .58382 .65535 L F
.57627 .65019 m .57967 .67263 L .58329 .66539 L F
.57904 .6155 m .57993 .64049 L .58382 .6772 L 0 .238 .216 r
F
.57904 .6155 m .58382 .6772 L .58388 .67672 L F
.58387 .67728 m .58393 .67385 L .58397 .67363 L 0 0 .1 r
F
.58383 .67743 m .58393 .67385 L .58387 .67728 L F
.58383 .67743 m .5838 .67755 L .58393 .67385 L F
.58397 .67363 m .58393 .67385 L .58409 .6688 L F
.57904 .6155 m .58388 .67672 L .58484 .67014 L 0 .238 .216 r
F
.58423 .68112 m .58424 .68117 L .58484 .67014 L F
.58328 .7178 m .58397 .67613 L .58484 .67014 L 0 0 .1 r
F
.58256 .71208 m .58307 .71518 L .58261 .71179 L 0 .248 .238 r
F
.58307 .71518 m .58309 .71486 L .58261 .71179 L F
.58261 .71179 m .58309 .71476 L .58311 .71438 L F
.58094 .78902 m .58292 .71337 L .58328 .7178 L 0 0 .1 r
F
.5887 .57779 m .58887 .61223 L .58885 .58061 L 0 0 .087 r
F
.58857 .5752 m .58887 .61223 L .5887 .57779 L F
.58865 .60728 m .58867 .60739 L .58865 .60657 L 0 .27 .221 r
F
.58865 .60728 m .58865 .60657 L .58679 .53942 L F
.58547 .65453 m .58753 .5939 L .58552 .65224 L 0 0 .1 r
F
.5857 .64693 m .58755 .59134 L .58589 .64185 L F
.58515 .64927 m .58532 .66154 L .58554 .65143 L 0 .238 .216 r
F
.58475 .65409 m .58532 .66154 L .58515 .64927 L F
.58545 .65539 m .58746 .59921 L .58753 .5939 L 0 0 .1 r
F
.58478 .67544 m .58478 .6754 L .5847 .67791 L F
.58478 .67544 m .5847 .67791 L .58469 .67795 L F
.58487 .67266 m .58478 .6754 L .58478 .67544 L F
.58372 .64982 m .58532 .66154 L .58383 .64202 L 0 .238 .216 r
F
.58461 .68041 m .5854 .65793 L .58545 .65539 L 0 0 .1 r
F
.5854 .65793 m .58746 .59921 L .58545 .65539 L F
.58505 .66947 m .58507 .66875 L .58508 .6686 L F
.58473 .67875 m .58532 .66158 L .58461 .68041 L F
.58532 .66158 m .58746 .59921 L .5854 .65795 L F
.58532 .66158 m .5854 .65795 L .58461 .68041 L F
.58465 .67841 m .58514 .66371 L .58466 .67825 L F
.58372 .64982 m .58512 .66518 L .58526 .66108 L 0 .238 .216 r
F
.58519 .66167 m .58552 .65217 L .58554 .65136 L 0 0 .1 r
F
.58547 .65333 m .58554 .65143 L .58548 .65362 L F
.58554 .65143 m .58755 .59134 L .5857 .64693 L F
.58554 .65143 m .58562 .65187 L .58558 .65032 L 0 .238 .216 r
F
.58554 .65143 m .5857 .64693 L .58548 .65362 L 0 0 .1 r
F
.58559 .65119 m .58749 .59503 L .58557 .65164 L F
.58601 .63863 m .5858 .65291 L .58651 .64027 L 0 .238 .216 r
F
.5869 .61259 m .58557 .65165 L .58557 .65164 L 0 0 .1 r
F
.58582 .64392 m .5858 .65291 L .58601 .63863 L 0 .238 .216 r
F
.58601 .63863 m .58755 .59134 L .5864 .62719 L 0 0 .1 r
F
.58554 .65255 m .58589 .64185 L .58601 .63863 L F
.58589 .64185 m .58755 .59134 L .58601 .63863 L F
.58556 .65015 m .58558 .65032 L .58583 .638 L 0 .238 .216 r
F
.58558 .65032 m .5858 .65291 L .58582 .64392 L F
.58558 .65032 m .58582 .64392 L .58583 .638 L F
.58583 .638 m .58582 .64392 L .58601 .63863 L F
.58398 .63188 m .58556 .65015 L .58583 .638 L F
.58562 .65187 m .5858 .65291 L .58564 .65104 L F
.58562 .65187 m .58564 .65104 L .58558 .65032 L F
.58631 .7755 m .58881 .61827 L .58891 .71118 L 0 0 .116 r
F
.58544 .7472 m .58881 .61827 L .58631 .7755 L F
.57602 .87691 m .57878 .88539 L .58544 .8823 L 0 1 .464 r
F
.57878 .88539 m .571 .89573 L .58153 .89386 L 0 1 .477 r
F
.57878 .88539 m .56251 .8942 L .571 .89573 L F
.57612 .88726 m .5855 .88754 L .58427 .88422 L 0 1 .462 r
F
.57878 .88539 m .5617 .89027 L .56251 .8942 L 0 1 .477 r
F
.57878 .88539 m .56867 .88649 L .5617 .89027 L F
.57602 .87691 m .56049 .88413 L .56867 .88649 L 0 1 .464 r
F
.57602 .87691 m .56867 .88649 L .57878 .88539 L F
.57335 .87947 m .57612 .88726 L .58241 .87891 L 0 1 .393 r
F
.57335 .87947 m .58241 .87891 L .58117 .87517 L F
.58752 .85751 m .57603 .86444 L .58359 .8639 L 0 1 .436 r
F
.58752 .85751 m .57453 .86334 L .57603 .86444 L F
.58752 .85751 m .57945 .86038 L .57453 .86334 L F
.58396 .85499 m .57945 .86038 L .58752 .85751 L 0 1 .273 r
F
.5658 .85905 m .56215 .86074 L .55991 .86445 L 0 1 .481 r
F
.57049 .86195 m .55641 .86178 L .56397 .86657 L 0 .784 .437 r
F
.56392 .85078 m .56215 .86074 L .5658 .85905 L 0 1 .477 r
F
.56392 .85078 m .55892 .85959 L .56215 .86074 L F
.57049 .86195 m .5556 .85748 L .55641 .86178 L 0 .784 .437 r
F
.57049 .86195 m .56162 .85755 L .5556 .85748 L F
.56924 .86216 m .56162 .85755 L .57049 .86195 L 0 .061 .034 r
F
.56705 .84923 m .56924 .86216 L .57595 .8558 L 0 1 .347 r
F
.56924 .86216 m .57056 .86998 L .57302 .86351 L F
.57602 .87691 m .55967 .87988 L .56049 .88413 L 0 1 .464 r
F
.57602 .87691 m .56632 .87679 L .55967 .87988 L F
.56924 .86216 m .56181 .8819 L .57056 .86998 L 0 1 .347 r
F
.5652 .86076 m .56514 .86071 L .56924 .86216 L 0 .061 .034 r
F
.56514 .86071 m .56162 .85755 L .56924 .86216 L F
.56392 .85078 m .5658 .85905 L .56794 .85527 L 0 1 .477 r
F
.56392 .85078 m .56794 .85527 L .56715 .85193 L F
.56705 .84923 m .5652 .86076 L .56924 .86216 L 0 1 .347 r
F
.5652 .86076 m .56181 .8819 L .56924 .86216 L F
.56716 .86252 m .5652 .86076 L .56924 .86216 L 0 .061 .034 r
F
.56716 .86252 m .56924 .86216 L .57603 .86444 L F
.56924 .86216 m .57049 .86195 L .57316 .86315 L F
.56924 .86216 m .57302 .86351 L .57316 .86315 L 0 1 .347 r
F
.56924 .86216 m .57316 .86315 L .57603 .86444 L 0 .061 .034 r
F
.56924 .86216 m .57316 .86315 L .57595 .8558 L 0 1 .347 r
F
.58396 .85499 m .57255 .86236 L .57945 .86038 L 0 1 .273 r
F
.58396 .85499 m .57141 .86215 L .57255 .86236 L F
.58396 .85499 m .5763 .85899 L .57141 .86215 L F
.5804 .85259 m .5763 .85899 L .58396 .85499 L 0 1 .321 r
F
.57681 .85003 m .5804 .85259 L .58468 .84807 L 0 1 .386 r
F
.57681 .85003 m .58468 .84807 L .58313 .8469 L F
.58435 .82972 m .5769 .8422 L .58272 .83874 L 0 1 .439 r
F
.58435 .82972 m .57533 .84103 L .5769 .8422 L F
.58435 .82972 m .57852 .83568 L .57533 .84103 L F
.57976 .82673 m .57852 .83568 L .58435 .82972 L 0 1 .423 r
F
.57612 .88726 m .57887 .89459 L .5855 .88754 L 0 1 .462 r
F
.58032 .88 m .57909 .88966 L .58503 .88982 L 0 .991 .466 r
F
.58032 .88 m .58503 .88982 L .588 .88703 L F
.58032 .88 m .588 .88703 L .586 .88315 L F
.57056 .86998 m .57335 .87947 L .5793 .86897 L 0 1 .357 r
F
.57539 .86943 m .58032 .88 L .58292 .87709 L 0 .967 .463 r
F
.57539 .86943 m .58292 .87709 L .58083 .87289 L F
.58779 .86997 m .58083 .87289 L .58292 .87709 L 0 .938 .465 r
F
.58779 .86997 m .58291 .86983 L .58083 .87289 L F
.58185 .85913 m .57768 .86644 L .58291 .86983 L 0 .904 .458 r
F
.58185 .85913 m .58291 .86983 L .58779 .86997 L F
.58185 .85913 m .58779 .86997 L .58959 .86683 L F
.58185 .85913 m .58959 .86683 L .5871 .86252 L F
.5804 .85259 m .56969 .86172 L .5763 .85899 L 0 1 .321 r
F
.5804 .85259 m .56854 .86137 L .56969 .86172 L F
.56705 .84923 m .57595 .8558 L .57439 .84878 L 0 1 .347 r
F
.5804 .85259 m .57313 .85746 L .56854 .86137 L 0 1 .321 r
F
.57681 .85003 m .57313 .85746 L .5804 .85259 L 0 1 .386 r
F
.57321 .84726 m .57681 .85003 L .5808 .84513 L 0 1 .411 r
F
.57565 .84709 m .58185 .85913 L .58327 .85567 L 0 .876 .45 r
F
.57565 .84709 m .58327 .85567 L .58067 .85086 L F
.5854 .84742 m .58067 .85086 L .58327 .85567 L 0 .813 .447 r
F
.5854 .84742 m .58158 .84732 L .58067 .85086 L F
.57976 .82673 m .57298 .8393 L .57852 .83568 L 0 1 .423 r
F
.57819 .8343 m .58158 .84732 L .5854 .84742 L 0 .787 .436 r
F
.57819 .8343 m .5854 .84742 L .58602 .84354 L F
.57819 .8343 m .58602 .84354 L .58302 .83827 L F
.56434 .82992 m .57233 .83899 L .57114 .83296 L 0 .829 .324 r
F
.56434 .82992 m .56705 .84917 L .57233 .83899 L F
.57976 .82673 m .57141 .83817 L .57298 .8393 L 0 1 .423 r
F
.57976 .82673 m .57431 .83278 L .57141 .83817 L F
.57494 .82399 m .57975 .82672 L .5823 .82137 L 0 1 .405 r
F
.57494 .82399 m .57431 .83278 L .57975 .82672 L F
.57494 .82399 m .5823 .82137 L .58026 .82027 L F
.57815 .81935 m .57852 .82995 L .58313 .8343 L 0 .693 .416 r
F
.57815 .81935 m .58313 .8343 L .58629 .83427 L F
.57815 .81935 m .58614 .82972 L .58278 .82369 L F
.57815 .81935 m .58629 .83427 L .58614 .82972 L F
.58467 .81866 m .58278 .82369 L .58614 .82972 L 0 .587 .403 r
F
.58467 .81866 m .58215 .81895 L .58278 .82369 L F
.57523 .80478 m .57689 .81238 L .58127 .80576 L 0 1 .361 r
F
.57568 .801 m .58379 .81304 L .58009 .80584 L 0 .621 .392 r
F
.57568 .801 m .58467 .81866 L .58379 .81304 L F
.57568 .801 m .58215 .81895 L .58467 .81866 L F
.58069 .79889 m .58009 .80584 L .58379 .81304 L 0 .517 .376 r
F
.58069 .79889 m .58379 .81304 L .58822 .81825 L F
.58069 .79889 m .58911 .81192 L .58513 .80409 L F
.58499 .7964 m .58336 .79744 L .58513 .80409 L 0 .395 .352 r
F
.58143 .88277 m .58532 .74334 L .58181 .88605 L 0 0 .116 r
F
.58629 .83427 m .58302 .83827 L .58602 .84354 L 0 .699 .428 r
F
.58629 .83427 m .58313 .8343 L .58302 .83827 L F
.58532 .74334 m .58544 .7472 L .58179 .88699 L 0 0 .116 r
F
.58499 .7964 m .58513 .80409 L .58911 .81192 L 0 .395 .352 r
F
.58179 .88699 m .58544 .7472 L .58631 .7755 L 0 0 .116 r
F
.57321 .84726 m .5808 .84513 L .57924 .84396 L 0 1 .411 r
F
.57887 .89459 m .57111 .90694 L .58161 .90173 L 0 1 .494 r
F
.56255 .90693 m .56089 .91664 L .56445 .91583 L 0 1 .485 r
F
.56255 .90693 m .56445 .91583 L .56652 .91257 L F
.56255 .90693 m .56652 .91257 L .56572 .90904 L F
.57887 .89459 m .56263 .90916 L .57111 .90694 L 0 1 .494 r
F
.58503 .88982 m .57745 .89654 L .5834 .89948 L 0 1 .468 r
F
.56255 .90693 m .55772 .91453 L .56089 .91664 L 0 1 .485 r
F
.56255 .90693 m .55705 .91091 L .55772 .91453 L F
.56255 .90693 m .55912 .90765 L .55705 .91091 L F
.56064 .89757 m .55912 .90765 L .56255 .90693 L 0 1 .478 r
F
.56064 .89757 m .56255 .90693 L .56452 .90362 L F
.57887 .89459 m .56183 .9069 L .56263 .90916 L 0 1 .494 r
F
.57887 .89459 m .56879 .90066 L .56183 .9069 L F
.57612 .88726 m .56879 .90066 L .57887 .89459 L 0 1 .462 r
F
.58503 .88982 m .57584 .89254 L .57745 .89654 L 0 1 .468 r
F
.58503 .88982 m .57909 .88966 L .57584 .89254 L F
.58965 .88442 m .58915 .85463 L .58909 .86622 L 0 0 .073 r
F
.58638 .66928 m .58682 .66239 L .5858 .65291 L 0 .238 .216 r
F
.58601 .65404 m .58701 .65957 L .58655 .64063 L F
.58701 .65957 m .5876 .6504 L .58655 .64063 L F
.58601 .65404 m .58655 .64063 L .58651 .64027 L F
.5876 .6504 m .58761 .65026 L .58656 .64044 L F
.58722 .62713 m .5864 .62719 L .58772 .6223 L 0 0 .116 r
F
.5862 .63691 m .58656 .64044 L .58772 .6223 L 0 .27 .221 r
F
.58631 .63643 m .5864 .62719 L .58856 .62704 L 0 0 .116 r
F
.5869 .61259 m .5869 .61258 L .58557 .65165 L 0 0 .1 r
F
.5862 .63691 m .58608 .63786 L .5864 .62719 L 0 0 .116 r
F
.58618 .63697 m .58603 .63762 L .58608 .63786 L 0 .27 .221 r
F
.58619 .637 m .58608 .63786 L .58651 .64019 L F
.58618 .63697 m .58608 .63786 L .58619 .637 L F
.58915 .85463 m .58827 .80255 L .58869 .84125 L 0 0 .073 r
F
.58511 .68834 m .58523 .68715 L .58466 .68372 L 0 .238 .224 r
F
.58576 .67881 m .58617 .67247 L .58532 .66154 L 0 .238 .216 r
F
.58532 .66154 m .58617 .67247 L .58638 .66928 L F
.58206 .59149 m .58043 .61324 L .58368 .61896 L 0 1 .317 r
F
.57904 .6155 m .5823 .62632 L .58187 .61546 L 0 .238 .216 r
F
.58596 .63846 m .58651 .64027 L .58607 .63791 L F
.58651 .64027 m .58651 .64019 L .58603 .63762 L F
.58602 .63765 m .58603 .63762 L .58241 .61835 L F
.58602 .63765 m .58241 .61835 L .58241 .61836 L F
.58651 .64027 m .58603 .63762 L .58602 .63765 L F
.5858 .65291 m .58682 .66239 L .58701 .65957 L F
.58457 .72147 m .5862 .6372 L .58532 .74334 L 0 0 .116 r
F
.5862 .6372 m .58621 .63719 L .58532 .74334 L F
.5862 .63691 m .58651 .64019 L .58652 .64005 L 0 .27 .221 r
F
.58618 .63697 m .58651 .64019 L .5862 .63691 L F
.58621 .63686 m .58631 .63643 L .58532 .74334 L 0 0 .116 r
F
.58616 .63655 m .58618 .63697 L .5862 .63691 L 0 .27 .221 r
F
.58601 .63869 m .5864 .62719 L .58608 .63786 L 0 0 .1 r
F
.57762 .32183 m .57786 .34118 L .58109 .3392 L 0 1 .237 r
F
.57801 .36973 m .57796 .38842 L .58105 .39309 L 0 1 .251 r
F
.56785 .43807 m .57801 .36973 L .57504 .37815 L 0 1 .204 r
F
.56785 .43807 m .57796 .38842 L .57801 .36973 L F
.56785 .43807 m .57486 .418 L .57796 .38842 L F
.56737 .46211 m .57766 .41514 L .57486 .418 L 0 1 .235 r
F
.56737 .46211 m .57731 .43205 L .57766 .41514 L F
.56737 .46211 m .57486 .418 L .57074 .4388 L F
.56785 .43807 m .57074 .4388 L .57486 .418 L 0 1 .204 r
F
.56737 .46211 m .57397 .45526 L .57731 .43205 L 0 1 .235 r
F
.56632 .48745 m .57397 .45526 L .56986 .46931 L 0 1 .252 r
F
.56737 .46211 m .56986 .46931 L .57397 .45526 L 0 1 .235 r
F
.57269 .46024 m .5811 .3241 L .57705 .30915 L 0 .6 .249 r
F
.57766 .41514 m .57731 .43205 L .58017 .43966 L 0 1 .26 r
F
.57269 .46024 m .58353 .41744 L .5811 .3241 L 0 .6 .249 r
F
.57656 .45595 m .57847 .4797 L .58255 .47645 L 0 1 .268 r
F
.57656 .45595 m .5759 .47089 L .57847 .4797 L F
.56632 .48745 m .57656 .45595 L .57397 .45526 L 0 1 .252 r
F
.56632 .48745 m .5759 .47089 L .57656 .45595 L F
.5747 .49195 m .58255 .47645 L .57847 .4797 L 0 1 .275 r
F
.5747 .49195 m .58479 .48557 L .58255 .47645 L F
.56632 .48745 m .57238 .48901 L .5759 .47089 L 0 1 .252 r
F
.5747 .49195 m .58371 .50101 L .58479 .48557 L 0 1 .275 r
F
.5747 .49195 m .57993 .51332 L .58371 .50101 L F
.5747 .49195 m .57599 .51424 L .57993 .51332 L F
.5747 .49195 m .57375 .50506 L .57599 .51424 L F
.56468 .51235 m .5747 .49195 L .57238 .48901 L 0 1 .263 r
F
.56468 .51235 m .57375 .50506 L .5747 .49195 L F
.57211 .52354 m .57993 .51332 L .57599 .51424 L 0 1 .283 r
F
.57211 .52354 m .58182 .52243 L .57993 .51332 L F
.56468 .51235 m .5701 .5192 L .57375 .50506 L 0 1 .263 r
F
.57211 .52354 m .5804 .53553 L .58182 .52243 L 0 1 .283 r
F
.57269 .46024 m .58237 .49699 L .58353 .41744 L 0 .6 .249 r
F
.57211 .52354 m .57652 .54487 L .5804 .53553 L 0 1 .283 r
F
.57788 .47994 m .57832 .50718 L .58237 .49699 L 0 .6 .249 r
F
.57269 .46024 m .5775 .50036 L .57788 .47994 L F
.5775 .50036 m .57832 .50718 L .57788 .47994 L F
.57269 .46024 m .57416 .49134 L .57832 .50718 L F
.56468 .51235 m .57238 .48901 L .56834 .49821 L 0 1 .263 r
F
.56632 .48745 m .56834 .49821 L .57238 .48901 L 0 1 .252 r
F
.56632 .48745 m .56573 .49755 L .56834 .49821 L F
.56714 .50449 m .57416 .49134 L .57269 .46024 L 0 .865 .263 r
F
.56246 .53592 m .57211 .52354 L .5701 .5192 L 0 1 .272 r
F
.56246 .53592 m .5701 .5192 L .56619 .52491 L F
.56468 .51235 m .56619 .52491 L .5701 .5192 L 0 1 .263 r
F
.56468 .51235 m .56386 .52197 L .56619 .52491 L F
.56333 .53481 m .56578 .52498 L .56714 .50449 L 0 .865 .263 r
F
.56578 .52498 m .57416 .49134 L .56714 .50449 L F
.56785 .43807 m .57504 .37815 L .571 .40826 L 0 1 .204 r
F
.57269 .46024 m .57705 .30915 L .57396 .38161 L 0 .6 .249 r
F
.57211 .52354 m .57277 .54421 L .57652 .54487 L 0 1 .283 r
F
.57211 .52354 m .57088 .53506 L .57277 .54421 L F
.56246 .53592 m .57088 .53506 L .57211 .52354 L 0 1 .272 r
F
.56578 .52498 m .57228 .52802 L .57416 .49134 L 0 .865 .263 r
F
.56333 .53481 m .56517 .53342 L .56578 .52498 L F
.56517 .53342 m .57228 .52802 L .56578 .52498 L F
.57336 .52632 m .57705 .30921 L .57396 .38164 L 0 .09 .148 r
F
.57386 .40749 m .57341 .40977 L .57388 .40266 L 0 .032 .122 r
F
.57386 .40749 m .57388 .40266 L .57507 .38467 L F
.57456 .40394 m .57386 .40749 L .57507 .38467 L F
.56883 .5513 m .57652 .54487 L .57277 .54421 L 0 1 .291 r
F
.56883 .5513 m .57802 .55379 L .57652 .54487 L F
.56883 .5513 m .57628 .56503 L .57802 .55379 L F
.56883 .5513 m .57235 .57216 L .57628 .56503 L F
.56883 .5513 m .56884 .57039 L .57235 .57216 L F
.56737 .46211 m .56702 .47226 L .56986 .46931 L 0 1 .235 r
F
.56333 .53481 m .56714 .50449 L .5689 .46308 L 0 .865 .263 r
F
.56714 .50449 m .57269 .46024 L .57001 .46225 L F
.56714 .50449 m .57001 .46225 L .5689 .46308 L F
.56246 .53592 m .56716 .54609 L .57088 .53506 L 0 1 .272 r
F
.55968 .55782 m .56883 .5513 L .56716 .54609 L 0 1 .28 r
F
.55968 .55782 m .56733 .56144 L .56883 .5513 L F
.55968 .55782 m .56716 .54609 L .56343 .54925 L F
.56246 .53592 m .56343 .54925 L .56716 .54609 L 0 1 .272 r
F
.55968 .55782 m .56359 .57002 L .56733 .56144 L 0 1 .28 r
F
.56591 .5708 m .57228 .52802 L .56827 .54567 L 0 .599 .265 r
F
.56883 .5513 m .56733 .56144 L .56884 .57039 L 0 1 .291 r
F
.56591 .5708 m .5762 .53925 L .57228 .52802 L 0 .599 .265 r
F
.56517 .53342 m .56827 .54567 L .57228 .52802 L 0 .865 .263 r
F
.56333 .53481 m .56475 .53793 L .56517 .53342 L F
.56475 .53793 m .56827 .54567 L .56517 .53342 L F
.56333 .53481 m .56442 .54859 L .56827 .54567 L F
.56358 .56504 m .56483 .5601 L .5689 .4631 L 0 .273 .213 r
F
.56483 .5601 m .57336 .52632 L .56969 .47436 L F
.56483 .5601 m .56969 .47436 L .5689 .4631 L F
.57346 .58079 m .58115 .58085 L .57762 .57664 L 0 1 .309 r
F
.57346 .58079 m .58206 .59149 L .58115 .58085 L F
.5649 .57576 m .57235 .57216 L .56884 .57039 L 0 1 .3 r
F
.5649 .57576 m .57346 .58079 L .57235 .57216 L F
.57346 .58079 m .57974 .60146 L .58206 .59149 L 0 1 .309 r
F
.57346 .58079 m .57557 .60563 L .57974 .60146 L F
.57346 .58079 m .57233 .6012 L .57557 .60563 L F
.57346 .58079 m .57143 .59054 L .57233 .6012 L F
.5649 .57576 m .57143 .59054 L .57346 .58079 L 0 1 .3 r
F
.5649 .57576 m .56749 .59594 L .57143 .59054 L F
.56819 .60425 m .57557 .60563 L .57233 .6012 L 0 1 .319 r
F
.56819 .60425 m .57603 .61546 L .57557 .60563 L F
.57603 .61546 m .57362 .63484 L .57653 .64041 L 0 1 .328 r
F
.57603 .61546 m .5734 .62414 L .57362 .63484 L F
.56819 .60425 m .5734 .62414 L .57603 .61546 L 0 1 .319 r
F
.56819 .60425 m .56926 .62721 L .5734 .62414 L F
.56927 .63635 m .57653 .64041 L .57362 .63484 L 0 1 .339 r
F
.56927 .63635 m .57627 .65019 L .57653 .64041 L F
.56927 .63635 m .57302 .65767 L .57627 .65019 L F
.57802 .55379 m .57628 .56503 L .57762 .57664 L 0 1 .299 r
F
.56591 .5708 m .57744 .57206 L .5762 .53925 L 0 .599 .265 r
F
.55638 .57793 m .5649 .57576 L .56359 .57002 L 0 1 .288 r
F
.55638 .57793 m .56316 .58472 L .5649 .57576 L F
.55638 .57793 m .56359 .57002 L .5601 .57131 L F
.55968 .55782 m .5601 .57131 L .56359 .57002 L 0 1 .28 r
F
.55638 .57793 m .55945 .59135 L .56316 .58472 L 0 1 .288 r
F
.55259 .59628 m .56038 .59739 L .55945 .59135 L 0 1 .295 r
F
.55259 .59628 m .55841 .60532 L .56038 .59739 L F
.55259 .59628 m .55945 .59135 L .55623 .59123 L F
.55638 .57793 m .55623 .59123 L .55945 .59135 L 0 1 .288 r
F
.55259 .59628 m .55477 .61038 L .55841 .60532 L 0 1 .295 r
F
.55553 .60129 m .56591 .5708 L .56219 .56979 L 0 .84 .285 r
F
.56591 .5708 m .5751 .59738 L .57744 .57206 L 0 .599 .265 r
F
.56591 .5708 m .57074 .59806 L .5751 .59738 L F
.56591 .5708 m .5668 .58665 L .57074 .59806 L F
.5649 .57576 m .56427 .59337 L .56749 .59594 L 0 1 .3 r
F
.5649 .57576 m .56316 .58472 L .56427 .59337 L F
.55553 .60129 m .5668 .58665 L .56591 .5708 L 0 .84 .285 r
F
.56038 .59739 m .56749 .59594 L .56427 .59337 L 0 1 .309 r
F
.56038 .59739 m .56819 .60425 L .56749 .59594 L F
.56038 .59739 m .56589 .61276 L .56819 .60425 L F
.56038 .59739 m .562 .6168 L .56589 .61276 L F
.56038 .59739 m .55911 .61364 L .562 .6168 L F
.56038 .59739 m .55841 .60532 L .55911 .61364 L F
.55553 .60129 m .56425 .60366 L .5668 .58665 L 0 .84 .285 r
F
.56819 .60425 m .56635 .62261 L .56926 .62721 L 0 1 .319 r
F
.56796 .60981 m .5751 .59738 L .57074 .59806 L 0 .445 .259 r
F
.56796 .60981 m .57904 .6155 L .5751 .59738 L F
.56796 .60981 m .57993 .64049 L .57904 .6155 L F
.56796 .60981 m .57714 .65236 L .57993 .64049 L F
.57627 .65019 m .57503 .67363 L .57967 .67263 L 0 1 .348 r
F
.57627 .65019 m .57248 .66772 L .57503 .67363 L F
.57627 .65019 m .57302 .65767 L .57248 .66772 L F
.56796 .60981 m .57255 .64309 L .57714 .65236 L 0 .445 .259 r
F
.56358 .56504 m .5758 .64942 L .57336 .52632 L 0 .273 .213 r
F
.57035 .56383 m .57107 .49072 L .57184 .46181 L 0 .032 .122 r
F
.57229 .45697 m .57184 .46181 L .57298 .41854 L F
.57035 .56383 m .57184 .46181 L .57229 .45697 L F
.57333 .41341 m .57298 .41854 L .57396 .38162 L F
.57035 .56383 m .57298 .41854 L .57333 .41341 L F
.57035 .56383 m .57313 .42364 L .57456 .40394 L F
.57313 .42364 m .57341 .40977 L .57456 .40394 L F
.57507 .38467 m .57396 .38162 L .57705 .30918 L F
.57341 .40977 m .57396 .38162 L .57507 .38467 L F
.5762 .53925 m .58237 .49699 L .57832 .50718 L 0 .27 .221 r
F
.57336 .52632 m .5786 .51131 L .57705 .30921 L 0 .09 .148 r
F
.58182 .52243 m .58216 .54829 L .58594 .55218 L 0 1 .29 r
F
.58182 .52243 m .5804 .53553 L .58216 .54829 L F
.5762 .53925 m .58679 .53942 L .58237 .49699 L 0 .27 .221 r
F
.5786 .51131 m .58316 .49824 L .57906 .37119 L 0 .09 .148 r
F
.5786 .51131 m .57906 .37119 L .57705 .30921 L F
.57802 .55379 m .57762 .57664 L .58115 .58085 L 0 1 .299 r
F
.58206 .59149 m .57974 .60146 L .58043 .61324 L 0 1 .317 r
F
.57673 .54449 m .58615 .63668 L .58616 .63655 L 0 .27 .221 r
F
.57673 .5445 m .58615 .63668 L .57673 .54449 L F
.58621 .63686 m .5864 .62719 L .58631 .63643 L 0 0 .116 r
F
.58185 .85913 m .57558 .86206 L .57768 .86644 L 0 .904 .458 r
F
.58185 .85913 m .57736 .85892 L .57558 .86206 L F
.57681 .85003 m .56681 .86059 L .57313 .85746 L 0 1 .386 r
F
.57681 .85003 m .56565 .85991 L .56681 .86059 L F
.57681 .85003 m .56994 .85538 L .56565 .85991 L F
.57321 .84726 m .56994 .85538 L .57681 .85003 L 0 1 .411 r
F
.57565 .84709 m .57736 .85892 L .58185 .85913 L 0 .876 .45 r
F
.57459 .77295 m .57914 .7917 L .58336 .79744 L 0 .516 .349 r
F
.58117 .88114 m .5845 .71945 L .58143 .88277 L 0 0 .116 r
F
.5845 .71945 m .5864 .62719 L .58457 .72147 L F
.5845 .71945 m .58457 .72147 L .58143 .88277 L F
.58891 .8603 m .58854 .83684 L .58881 .85487 L 0 0 .073 r
F
.58685 .61347 m .58687 .6128 L .5864 .62719 L 0 0 .1 r
F
.58749 .59503 m .5869 .61258 L .5869 .61259 L F
.58724 .62349 m .58808 .60877 L .58726 .62236 L 0 0 .064 r
F
.58755 .59134 m .58753 .5939 L .58757 .59058 L 0 0 .1 r
F
.58755 .59134 m .58769 .58753 L .5864 .62719 L F
.57802 .55379 m .58115 .58085 L .5853 .57532 L 0 1 .299 r
F
.58239 .57307 m .5862 .63691 L .58867 .60739 L 0 .27 .221 r
F
.57802 .55379 m .58594 .55218 L .58216 .54829 L 0 1 .299 r
F
.57802 .55379 m .58729 .56376 L .58594 .55218 L F
.57802 .55379 m .5853 .57532 L .58729 .56376 L F
.5762 .53925 m .5825 .60082 L .58239 .57307 L 0 .27 .221 r
F
.5825 .60082 m .5862 .63691 L .58239 .57307 L F
.58559 .65119 m .58557 .65164 L .58547 .65454 L 0 0 .1 r
F
.58559 .65119 m .58547 .65454 L .58546 .6549 L F
.58545 .65535 m .58559 .65119 L .58546 .65524 L F
.58557 .65164 m .58557 .65165 L .58547 .65452 L F
.58557 .65164 m .58547 .65452 L .58547 .65452 L F
.58554 .65143 m .58532 .66154 L .5858 .65291 L 0 .238 .216 r
F
.5845 .71945 m .58608 .63786 L .58619 .63723 L 0 0 .116 r
F
.58117 .88114 m .58445 .71832 L .5845 .71945 L F
.58115 .88113 m .58445 .71832 L .58117 .88114 L F
.58908 1.1811 m .58908 1.17809 L .59196 1.25808 L 0 0 .1 r
F
.59198 1.25938 m .59196 1.25808 L .59276 1.28023 L F
.58908 1.1811 m .59196 1.25808 L .59198 1.25938 L F
.59276 1.28023 m .5891 1.17869 L .59273 1.27818 L F
.59276 1.28023 m .59273 1.27818 L .59309 1.28789 L F
.59079 1.22496 m .5891 1.17869 L .59102 1.22808 L F
.59079 1.22496 m .59102 1.22808 L .59269 1.27091 L F
.59309 1.28789 m .59079 1.22496 L .59269 1.27091 L F
.58825 1.14918 m .58823 1.14816 L .59005 1.19626 L F
.59005 1.1963 m .59005 1.19626 L .59023 1.20099 L F
.58825 1.14918 m .59005 1.19626 L .59005 1.1963 L F
.58908 1.1811 m .59276 1.28023 L .59286 1.28447 L F
.59315 1.29608 m .58908 1.1811 L .59286 1.28447 L F
.5891 1.17869 m .59263 1.26922 L .59263 1.26953 L F
.59079 1.21657 m .59004 1.19683 L .59073 1.21444 L F
.59004 1.19683 m .58825 1.14918 L .59005 1.19657 L F
.59004 1.19683 m .59005 1.19657 L .59073 1.21444 L F
.59263 1.26538 m .5914 1.23271 L .59226 1.25535 L F
.5941 1.32322 m .59356 1.30859 L .59351 1.30653 L F
.59027 1.20234 m .59153 1.23547 L .59164 1.23859 L F
.59027 1.20234 m .59023 1.20099 L .59151 1.23478 L F
.59027 1.20234 m .59151 1.23478 L .59153 1.23547 L F
.59061 1.20922 m .59205 1.21898 L .59074 1.21279 L 0 .686 .18 r
F
.5891 1.17869 m .58923 1.17515 L .59198 1.24828 L 0 0 .1 r
F
.5891 1.17869 m .59198 1.24828 L .59198 1.24979 L F
.59106 1.22392 m .59079 1.21657 L .59101 1.22201 L F
.59079 1.21657 m .59073 1.21444 L .59101 1.22201 L F
.5914 1.23271 m .59106 1.22392 L .59115 1.22551 L F
.59106 1.22392 m .59101 1.22201 L .59115 1.22551 L F
.5915 1.23449 m .59094 1.21852 L .59219 1.22514 L 0 .877 .163 r
F
.59092 1.2186 m .59091 1.2184 L .59094 1.21852 L F
.59027 1.20234 m .59163 1.23824 L .59163 1.23837 L 0 0 .1 r
F
.58825 1.14918 m .59023 1.20099 L .59027 1.20234 L F
.5891 1.17869 m .5835 1.0233 L .58923 1.17515 L F
.58825 1.14918 m .5835 1.0233 L .58823 1.14816 L F
.56445 .91583 m .56634 .92437 L .56851 .92116 L 0 1 .49 r
F
.56445 .91583 m .56851 .92116 L .56772 .91777 L F
.58435 .90881 m .5666 .92128 L .57571 .92003 L 0 1 .514 r
F
.58435 .90881 m .56581 .91876 L .5666 .92128 L F
.58435 .90881 m .57341 .91342 L .56581 .91876 L F
.58161 .90173 m .57341 .91342 L .58435 .90881 L 0 1 .508 r
F
.58161 .90173 m .56462 .91507 L .57341 .91342 L F
.58161 .90173 m .56382 .91266 L .56462 .91507 L F
.58161 .90173 m .57111 .90694 L .56382 .91266 L F
.5885 .94029 m .57693 .95423 L .58462 .95582 L 0 1 .453 r
F
.5885 .94029 m .57537 .94861 L .57693 .95423 L F
.5885 .94029 m .58032 .94263 L .57537 .94861 L F
.58481 .93004 m .57329 .94067 L .58032 .94263 L 0 1 .433 r
F
.58481 .93004 m .57209 .93572 L .57329 .94067 L F
.5888 .96548 m .57702 .96315 L .58471 .96403 L 0 0 0 r
F
.58481 .93004 m .58032 .94263 L .5885 .94029 L 0 1 .433 r
F
.58481 .93004 m .57702 .93116 L .57209 .93572 L F
.5888 .96548 m .57552 .96364 L .57702 .96315 L 0 0 0 r
F
.58112 .91959 m .57702 .93116 L .58481 .93004 L 0 1 .437 r
F
.58112 .91959 m .58481 .93004 L .58946 .92627 L F
.5888 .96548 m .58055 .96464 L .57552 .96364 L 0 0 0 r
F
.58112 .91959 m .58946 .92627 L .58786 .92237 L 0 1 .437 r
F
.57741 .90925 m .58112 .91959 L .58547 .91647 L 0 1 .448 r
F
.57741 .90925 m .58547 .91647 L .58387 .91249 L F
.58522 .96644 m .58055 .96464 L .5888 .96548 L 0 0 0 r
F
.58522 .96644 m .57352 .96481 L .58055 .96464 L F
.58973 .89941 m .58146 .90652 L .5877 .9092 L 0 1 .469 r
F
.58973 .89941 m .57986 .90253 L .58146 .90652 L F
.58973 .89941 m .5834 .89948 L .57986 .90253 L F
.58163 .96765 m .57738 .96657 L .58522 .96644 L 0 0 0 r
F
.58163 .96765 m .58522 .96644 L .58995 .96656 L F
.58163 .96765 m .58995 .96656 L .58839 .96684 L F
.57802 .96876 m .58163 .96765 L .58605 .96732 L F
.57802 .96876 m .58605 .96732 L .58448 .96768 L F
.58593 .96828 m .57819 .96917 L .58416 .96814 L F
.58593 .96828 m .57661 .96955 L .57819 .96917 L F
.58593 .96828 m .57992 .96917 L .57661 .96955 L F
.58128 .9696 m .57992 .96917 L .58593 .96828 L F
.58128 .9696 m .58593 .96828 L .58896 .96805 L F
.58128 .9696 m .58896 .96805 L .58699 .96864 L F
.5764 .97117 m .58128 .9696 L .58395 .96962 L F
.5764 .97117 m .58395 .96962 L .58188 .97033 L F
.58898 .97006 m .58188 .97033 L .58395 .96962 L F
.58898 .97006 m .58403 .97052 L .58188 .97033 L F
.5831 .97272 m .58403 .97052 L .58898 .97006 L F
.5831 .97272 m .57876 .97147 L .58403 .97052 L F
.57694 .97579 m .5831 .97272 L .5846 .97367 L F
.57694 .97579 m .5846 .97367 L .58201 .97503 L F
.58689 .97676 m .58201 .97503 L .5846 .97367 L F
.58689 .97676 m .58299 .97635 L .58201 .97503 L F
.57972 .98128 m .58299 .97635 L .58689 .97676 L F
.57972 .98128 m .58689 .97676 L .58759 .97854 L F
.57972 .98128 m .58759 .97854 L .58461 .98051 L F
.57994 .98994 m .5848 .98285 L .58805 .98402 L 0 .095 .028 r
F
.57994 .98994 m .58012 .98344 L .5848 .98285 L F
.57994 .98994 m .58805 .98402 L .58798 .9868 L F
.57994 .98994 m .58798 .9868 L .58463 .98935 L F
.5867 .99516 m .58407 .99294 L .58463 .98935 L 0 .144 .051 r
F
.5777 1.00173 m .58407 .99294 L .5867 .99516 L 0 .225 .064 r
F
.5777 1.00173 m .57959 .99294 L .58407 .99294 L F
.5777 1.00173 m .5867 .99516 L .5859 .99893 L F
.5777 1.00173 m .5859 .99893 L .5822 1.00173 L F
.58299 1.01 m .5859 .99893 L .5904 .99898 L 0 .259 .082 r
F
.58299 1.01 m .5822 1.00173 L .5859 .99893 L F
.58122 .88664 m .58786 1.14044 L .59392 1.31839 L 0 0 .116 r
F
.5812 .88652 m .58786 1.14044 L .58122 .88664 L F
.58092 .88224 m .58786 1.14044 L .5811 .88281 L F
.58898 .97006 m .58395 .96962 L .5895 .9685 L 0 0 0 r
F
.58805 .98402 m .58461 .98051 L .58759 .97854 L 0 0 .005 r
F
.58805 .98402 m .5848 .98285 L .58461 .98051 L F
.5867 .99516 m .58463 .98935 L .58798 .9868 L 0 .144 .051 r
F
.58759 1.02057 m .58583 1.01604 L .58751 1.01005 L 0 .286 .097 r
F
.5887 1.10147 m .58146 .88517 L .58864 1.10462 L 0 0 .116 r
F
.58146 .88517 m .58144 .88468 L .58146 .88516 L F
.58146 .88517 m .58146 .88516 L .58864 1.10462 L F
.58854 .79349 m .58721 .79471 L .5894 .80217 L 0 .298 .319 r
F
.58648 .78084 m .58891 .71118 L .58713 .80094 L 0 0 .116 r
F
.58909 .86622 m .58895 .85733 L .58891 .8603 L 0 0 .073 r
F
.58641 .77883 m .58891 .71118 L .58648 .78084 L 0 0 .116 r
F
.5854 .84742 m .58327 .85567 L .58838 .85934 L 0 .813 .447 r
F
.58182 .88615 m .58631 .7755 L .58231 .88987 L 0 0 .116 r
F
.58631 .7755 m .58891 .71118 L .58641 .77883 L F
.58631 .7755 m .58641 .77883 L .58231 .88987 L F
.5862 .63691 m .58772 .6223 L .58867 .60739 L 0 .27 .221 r
F
.58856 .62704 m .58722 .62713 L .58881 .61827 L 0 0 .116 r
F
.58722 .62713 m .58772 .6223 L .58881 .61827 L F
.58532 .74334 m .58881 .61827 L .58544 .7472 L F
.58857 .5752 m .58891 .71118 L .58887 .61223 L 0 0 .087 r
F
.58794 .56229 m .58909 .58517 L .58794 .56229 L 0 .091 .152 r
F
.59036 .92595 m .58848 .53009 L .59037 .92659 L 0 0 .08 r
F
.59037 .92659 m .58848 .53009 L .58852 .52848 L F
.59067 .99419 m .59035 .92633 L .59068 .99343 L F
.59035 .92633 m .58848 .53009 L .59036 .9265 L F
.59037 .92659 m .59035 .92639 L .59728 1.33885 L 0 0 .073 r
F
.59035 .92633 m .59036 .9265 L .59068 .99343 L 0 0 .08 r
F
.59592 1.23727 m .5906 .92909 L .59556 1.23474 L 0 0 .073 r
F
.5909 1.05051 m .59013 .96375 L .58997 .92221 L 0 0 .08 r
F
.59028 .92559 m .58997 .92221 L .58898 .66271 L F
.5909 1.05051 m .58997 .92221 L .59028 .92559 L F
.59088 1.04291 m .59065 .99401 L .59088 1.03791 L F
.59065 .99401 m .58892 .6348 L .59065 .99071 L F
.59065 .99401 m .59065 .99071 L .59088 1.03791 L F
.59516 .96618 m .59258 .96637 L .59974 .96547 L 0 0 0 r
F
.60042 .96582 m .59192 .96724 L .59388 .96675 L F
.60042 .96582 m .59471 .96685 L .59192 .96724 L F
.59611 .97798 m .59205 .97566 L .59501 .9738 L F
.59611 .97798 m .59251 .97746 L .59205 .97566 L F
.59563 .98749 m .59299 .98293 L .59632 .98032 L 0 .037 .031 r
F
.59563 .98749 m .59269 .98601 L .59299 .98293 L F
.59273 1.00184 m .59509 .99107 L .59978 .99007 L 0 .182 .071 r
F
.59273 1.00184 m .60138 .99663 L .59744 1.00083 L F
.59458 1.05268 m .59343 1.04474 L .59589 1.03496 L 0 .334 .132 r
F
.59273 .95439 m .59195 .94513 L .59843 1.38248 L 0 0 .073 r
F
.59026 .60632 m .59147 .63067 L .59132 .6267 L 0 .091 .152 r
F
.59442 .90879 m .59199 .91881 L .59909 .91795 L 0 1 .47 r
F
.59937 .8896 m .591 .89277 L .59299 .89653 L 0 1 .477 r
F
.59937 .8896 m .59373 .8898 L .591 .89277 L F
.59441 .8476 m .59051 .85108 L .5935 .85587 L 0 .726 .441 r
F
.59441 .8476 m .5909 .84753 L .59051 .85108 L F
.59365 .83427 m .59118 .83827 L .59454 .84363 L 0 .579 .413 r
F
.59365 .83427 m .5908 .83425 L .59118 .83827 L F
.59092 .68121 m .59201 .71058 L .59678 .77097 L 0 .066 .149 r
F
.59044 .818 m .59302 .82952 L .59767 .83441 L 0 .45 .38 r
F
.59044 .818 m .59908 .82964 L .5951 .82288 L F
.59127 .78999 m .59028 .79147 L .59287 .80014 L 0 .224 .274 r
F
.59127 .78999 m .59287 .80014 L .59734 .81026 L F
.59094 .29428 m .59273 .95439 L .5915 .93982 L 0 0 .08 r
F
.59195 .94513 m .5906 .92909 L .59843 1.38248 L 0 0 .073 r
F
.58906 .53533 m .58943 .54506 L .5895 .52401 L 0 .005 .124 r
F
.58919 .58575 m .59015 .60501 L .59026 .60632 L 0 .091 .152 r
F
.58997 .60275 m .59015 .60501 L .58919 .58575 L F
.59025 .65962 m .59027 .66062 L .59083 .65646 L 0 .902 .101 r
F
.59094 .28493 m .5915 .93982 L .58809 .28596 L 0 0 .08 r
F
.58929 .58898 m .58929 .59049 L .58959 .59805 L 0 0 .087 r
F
.5915 .93982 m .5906 .92909 L .58809 .28596 L 0 0 .08 r
F
.59054 .85023 m .5906 .92909 L .59195 .94513 L 0 0 .073 r
F
.59055 .92855 m .59037 .92659 L .59556 1.23474 L F
.5906 .92909 m .59055 .92855 L .59556 1.23474 L F
.5915 1.23449 m .59219 1.22514 L .59313 1.23813 L 0 .877 .163 r
F
.59594 1.31805 m .5887 1.10147 L .59549 1.31285 L 0 0 .116 r
F
.5887 1.10147 m .58864 1.10462 L .59549 1.31285 L F
.59116 1.2166 m .59189 1.22095 L .5912 1.21857 L 0 .686 .18 r
F
.59093 1.20643 m .59195 1.21028 L .59094 1.20694 L F
.58779 .86997 m .58292 .87709 L .58844 .88024 L 0 .938 .465 r
F
.58231 .88987 m .58641 .77883 L .58261 .89153 L 0 0 .116 r
F
.58179 .88699 m .58182 .88615 L .58231 .88987 L F
.59072 1.00072 m .59067 .99419 L .59068 .99343 L 0 0 .08 r
F
.58916 1.07678 m .59572 1.26117 L .58956 1.05734 L 0 0 .116 r
F
.58179 .88699 m .58187 .88924 L .58258 .89194 L F
.59067 1.00308 m .58898 .66271 L .58899 .66264 L 0 0 .08 r
F
.58905 1.08205 m .59572 1.26117 L .58916 1.07678 L 0 0 .116 r
F
.5962 1.36846 m .59482 1.341 L .59527 1.35816 L F
.59645 1.38937 m .59612 1.37364 L .59675 1.39091 L 0 0 .1 r
F
.59522 1.34883 m .59507 1.34158 L .59719 1.38808 L 0 .994 .102 r
F
.59683 1.37738 m .59684 1.37708 L .59741 1.39222 L 0 0 .1 r
F
.59741 1.39222 m .59644 1.36646 L .59754 1.39392 L F
.59796 1.38789 m .5962 1.36846 L .59723 1.38868 L 0 0 .116 r
F
.5962 1.36846 m .59527 1.35816 L .59719 1.38808 L F
.5962 1.36846 m .59719 1.38808 L .59723 1.38868 L F
.59556 1.37309 m .59517 1.34785 L .596 1.38808 L 0 .994 .102 r
F
.59517 1.34785 m .59507 1.34158 L .59522 1.34883 L F
.59517 1.34785 m .59522 1.34883 L .596 1.38808 L F
.596 1.38808 m .59522 1.34883 L .59722 1.38869 L F
.59522 1.34883 m .59719 1.38808 L .59722 1.38869 L F
.59467 1.33799 m .59449 1.33508 L .59527 1.35816 L 0 0 .116 r
F
.59556 1.37309 m .59444 1.33589 L .59467 1.33799 L 0 .994 .102 r
F
.59517 1.34785 m .59467 1.33799 L .59507 1.34158 L F
.59482 1.341 m .59467 1.33799 L .59527 1.35816 L 0 0 .116 r
F
.59556 1.37309 m .59467 1.33799 L .59517 1.34785 L 0 .994 .102 r
F
.59438 1.33273 m .5952 1.33577 L .59507 1.34158 L 0 .877 .163 r
F
.59467 1.33799 m .59449 1.33508 L .59507 1.34158 L 0 .994 .102 r
F
.59439 1.33172 m .59469 1.34167 L .59415 1.32618 L 0 0 .1 r
F
.59438 1.33273 m .59453 1.33624 L .59449 1.33508 L F
.59438 1.33273 m .59507 1.34158 L .59449 1.33508 L 0 .877 .163 r
F
.59439 1.33172 m .59415 1.32618 L .59392 1.31846 L 0 0 .1 r
F
.59438 1.33273 m .59449 1.33508 L .59305 1.29295 L F
.59438 1.33273 m .59449 1.33508 L .59445 1.33464 L 0 .877 .163 r
F
.59441 1.33403 m .59445 1.33464 L .59441 1.33429 L F
.59438 1.33273 m .59445 1.33464 L .59441 1.33403 L F
.58864 1.10462 m .59467 1.33799 L .59475 1.3396 L 0 0 .116 r
F
.59481 1.34055 m .59475 1.3396 L .59482 1.341 L F
.58864 1.10462 m .59475 1.3396 L .59481 1.34055 L F
.59198 1.24979 m .59198 1.24828 L .59285 1.27123 L 0 0 .1 r
F
.58864 1.10462 m .58824 1.12181 L .59467 1.33799 L 0 0 .116 r
F
.5952 1.33577 m .59545 1.34243 L .59507 1.34158 L 0 .877 .163 r
F
.59796 1.38789 m .58864 1.10462 L .59482 1.341 L 0 0 .116 r
F
.59796 1.38789 m .59482 1.341 L .5962 1.36846 L F
.58251 .89289 m .58179 .88699 L .58258 .89194 L F
.58864 1.10462 m .58141 .8849 L .58824 1.12181 L F
.58141 .8849 m .58113 .88289 L .58824 1.12181 L F
.58689 .97676 m .5846 .97367 L .58973 .97258 L 0 0 0 r
F
.58187 .88924 m .58905 1.08205 L .58258 .89194 L 0 0 .116 r
F
.58144 .88468 m .58139 .88434 L .58864 1.10462 L F
.57819 .8343 m .57676 .84336 L .58158 .84732 L 0 .787 .436 r
F
.57568 .801 m .57773 .8141 L .58215 .81895 L 0 .621 .392 r
F
.58099 .88245 m .5832 .73246 L .58396 .70758 L 0 0 .116 r
F
.58099 .88245 m .5832 .73246 L .58099 .88245 L F
.57371 .89907 m .57741 .90925 L .58146 .90652 L 0 1 .456 r
F
.57371 .89907 m .58146 .90652 L .57986 .90253 L F
.5831 .97272 m .57667 .97227 L .57876 .97147 L 0 0 0 r
F
.5831 .97272 m .57853 .97281 L .57667 .97227 L F
.57694 .97579 m .57853 .97281 L .5831 .97272 L F
.58092 .88224 m .58109 .91199 L .58786 1.14044 L 0 0 .116 r
F
.58046 .88082 m .58109 .91199 L .58092 .88224 L F
.58139 .88434 m .58143 .88277 L .58179 .88699 L F
.58143 .88277 m .58181 .88605 L .58179 .88699 L F
.5887 1.10147 m .58905 1.08205 L .58161 .88224 L F
.59319 1.29233 m .59313 1.29045 L .59309 1.28789 L 0 0 .1 r
F
.59411 1.32375 m .59356 1.30859 L .5941 1.32322 L F
.59164 1.23859 m .59167 1.23915 L .59172 1.24051 L F
.59167 1.23915 m .59172 1.24049 L .59172 1.24051 L F
.59163 1.23837 m .59172 1.24051 L .59172 1.24052 L F
.59163 1.23824 m .59172 1.24051 L .59163 1.23837 L F
.58113 .88289 m .59392 1.31839 L .59428 1.32486 L 0 0 .116 r
F
.58092 .88224 m .58054 .86062 L .5832 .73246 L F
.58089 .88214 m .58054 .86062 L .58092 .88224 L F
.58089 .88322 m .58054 .86062 L .5809 .8832 L F
.57973 .89127 m .58109 .91199 L .58046 .88082 L 0 .146 .172 r
F
.58044 .88482 m .58046 .88082 L .58089 .88382 L 0 0 .116 r
F
.58046 .88082 m .58054 .86062 L .58078 .87623 L F
.58046 .88082 m .58078 .87623 L .58089 .88382 L F
.57142 .80708 m .57965 .71827 L .58032 .71531 L 0 0 .101 r
F
.57788 .73389 m .57791 .73375 L .57762 .73296 L 0 .462 .294 r
F
.57114 .78905 m .57749 .73482 L .57839 .72948 L 0 0 .081 r
F
.57114 .78905 m .57782 .73414 L .57804 .73137 L F
.57142 .80708 m .57932 .72562 L .57972 .72259 L 0 0 .101 r
F
.57033 .78205 m .57657 .74011 L .57658 .73998 L 0 0 .054 r
F
.57434 .75384 m .57412 .7545 L .57501 .75034 L 0 0 .024 r
F
.57429 .754 m .57412 .7545 L .57429 .75401 L 0 .512 .31 r
F
.57417 .75314 m .57412 .7545 L .57429 .754 L F
.56898 .78205 m .57426 .75433 L .57446 .75331 L 0 0 .024 r
F
.56898 .78205 m .57402 .75552 L .57426 .75433 L F
.56898 .78205 m .57446 .75331 L .57498 .75007 L F
.57402 .75483 m .57501 .75034 L .57412 .7545 L 0 0 0 r
F
.56898 .78205 m .57498 .75007 L .575 .74989 L 0 0 .024 r
F
.57241 .76338 m .57245 .76325 L .57242 .76338 L 0 0 0 r
F
.56459 .79293 m .57067 .77008 L .57079 .76953 L F
.56729 .78311 m .57079 .76953 L .56846 .77885 L F
.56673 .78483 m .57079 .76953 L .56729 .78311 L F
.56666 .74069 m .57356 .75724 L .57393 .75463 L 0 .568 .326 r
F
.56719 .78568 m .57356 .75724 L .57398 .75499 L 0 0 0 r
F
.56706 .78627 m .56716 .78583 L .56719 .78568 L F
.56716 .78583 m .57356 .75724 L .56719 .78568 L F
.57356 .75724 m .57399 .75496 L .57393 .75463 L 0 .568 .326 r
F
.57398 .75499 m .57393 .75526 L .57402 .7548 L 0 0 0 r
F
.57397 .75503 m .57402 .75483 L .57396 .75508 L F
.57397 .75503 m .57396 .75508 L .57222 .76336 L F
.57179 .76491 m .57397 .75503 L .57222 .76336 L F
.57235 .76367 m .57233 .76373 L .57235 .76365 L F
.57235 .76365 m .57245 .76325 L .57252 .76289 L F
.57239 .76349 m .5724 .76352 L .5732 .75989 L 0 .568 .326 r
F
.57235 .76365 m .57233 .76373 L .57245 .76325 L 0 0 0 r
F
.57238 .76346 m .57235 .76365 L .57239 .76349 L 0 .568 .326 r
F
.57186 .76573 m .57232 .7638 L .57247 .76314 L 0 0 0 r
F
.56706 .78627 m .57177 .76614 L .57186 .76573 L F
.57177 .76614 m .57232 .7638 L .57186 .76573 L F
.57247 .76314 m .57235 .76365 L .57252 .76289 L F
.57232 .7638 m .57235 .76365 L .57247 .76314 L F
.57352 .75754 m .57352 .75754 L .57356 .75724 L F
.57345 .75773 m .57352 .75754 L .57356 .75724 L F
.5734 .75795 m .57343 .75787 L .57345 .75773 L F
.5734 .75798 m .5734 .75797 L .5734 .75795 L F
.56898 .78205 m .57087 .76976 L .57411 .75457 L 0 0 .024 r
F
.56898 .78205 m .56967 .77829 L .57016 .7756 L F
.57405 .75473 m .57411 .75457 L .57087 .76976 L 0 0 0 r
F
.56967 .77829 m .57507 .74919 L .57016 .7756 L 0 0 .024 r
F
.57402 .75483 m .57405 .75473 L .57087 .76976 L 0 0 0 r
F
.57016 .7756 m .57507 .74919 L .57514 .74851 L 0 0 .024 r
F
.57405 .75473 m .57412 .7545 L .57411 .75457 L 0 0 0 r
F
.57411 .75456 m .57411 .75457 L .57412 .7545 L 0 0 .024 r
F
.56898 .78205 m .57411 .75457 L .57411 .75456 L F
.56898 .78205 m .57508 .74948 L .57516 .74874 L F
.57393 .75463 m .574 .75485 L .57402 .7548 L 0 .568 .326 r
F
.56898 .78205 m .57534 .74744 L .57571 .74504 L 0 0 .024 r
F
.57016 .7756 m .57488 .74961 L .57425 .75337 L F
.57016 .7756 m .57425 .75337 L .57269 .76269 L F
.56926 .78056 m .57016 .7756 L .57269 .76269 L F
.57488 .74961 m .57571 .74504 L .57512 .74846 L F
.57488 .74961 m .57512 .74846 L .57269 .76269 L F
.56706 .78627 m .57179 .76491 L .57087 .76976 L 0 0 0 r
F
.57179 .76491 m .57222 .76336 L .57087 .76976 L F
.56923 .78063 m .57571 .74504 L .56926 .78056 L 0 0 .024 r
F
.57033 .78205 m .57694 .73747 L .57695 .73741 L 0 0 .054 r
F
.56666 .74069 m .57393 .75463 L .57065 .74607 L 0 .568 .326 r
F
.57393 .75463 m .574 .75421 L .57065 .74607 L F
.575 .74989 m .57498 .75007 L .57508 .74948 L 0 0 .024 r
F
.57507 .74919 m .57516 .74874 L .57514 .74851 L F
.57033 .78205 m .57269 .76269 L .57585 .74451 L 0 0 .054 r
F
.57033 .78205 m .57585 .74451 L .57587 .74445 L F
.57571 .74504 m .57567 .7453 L .57575 .74481 L 0 0 .024 r
F
.57571 .74504 m .57581 .74476 L .57269 .76269 L F
.56851 .7301 m .57447 .7484 L .57507 .74677 L 0 .512 .31 r
F
.57658 .73998 m .57674 .73891 L .57681 .73846 L 0 0 .054 r
F
.57657 .74011 m .57674 .73891 L .57658 .73998 L F
.57689 .73785 m .57681 .73846 L .5771 .73642 L F
.57716 .73605 m .5771 .73642 L .57728 .73522 L F
.57694 .73747 m .57729 .73517 L .57695 .73741 L F
.57741 .73419 m .57736 .73458 L .57756 .73319 L F
.57674 .73891 m .57706 .73679 L .57727 .73528 L F
.57033 .78205 m .57751 .73349 L .5739 .75951 L F
.56851 .7301 m .574 .75421 L .57417 .75314 L 0 .512 .31 r
F
.57114 .78905 m .57684 .74135 L .57696 .74082 L 0 0 .081 r
F
.56404 .69808 m .57093 .70426 L .56877 .69836 L 0 1 .38 r
F
.56404 .69808 m .56911 .71267 L .57093 .70426 L F
.56491 .71697 m .55723 .739 L .56256 .73319 L 0 1 .335 r
F
.56911 .71267 m .56236 .72612 L .56402 .73165 L 0 1 .387 r
F
.56491 .71697 m .55607 .73668 L .55723 .739 L 0 1 .335 r
F
.56911 .71267 m .56454 .71798 L .56236 .72612 L 0 1 .387 r
F
.56491 .71697 m .55936 .72723 L .55607 .73668 L 0 1 .335 r
F
.56404 .69808 m .56454 .71798 L .56911 .71267 L 0 1 .38 r
F
.56959 .84439 m .57321 .84726 L .5769 .8422 L 0 1 .414 r
F
.56959 .84439 m .5769 .8422 L .57533 .84103 L F
.56064 .89757 m .56452 .90362 L .56371 .89992 L 0 1 .478 r
F
.57612 .88726 m .56063 .90371 L .56879 .90066 L 0 1 .462 r
F
.56064 .89757 m .55605 .90531 L .55912 .90765 L 0 1 .478 r
F
.57612 .88726 m .55984 .90171 L .56063 .90371 L 0 1 .462 r
F
.57612 .88726 m .56648 .89465 L .55984 .90171 L F
.57335 .87947 m .56648 .89465 L .57612 .88726 L 0 1 .393 r
F
.58032 .88 m .57343 .88651 L .57909 .88966 L 0 .991 .466 r
F
.56064 .89757 m .55538 .90147 L .55605 .90531 L 0 1 .478 r
F
.56064 .89757 m .55734 .89815 L .55538 .90147 L F
.55872 .88758 m .55734 .89815 L .56064 .89757 L 0 1 .467 r
F
.55872 .88758 m .56064 .89757 L .5625 .8942 L F
.55872 .88758 m .5625 .8942 L .5617 .89027 L F
.57335 .87947 m .55864 .89897 L .56648 .89465 L 0 1 .393 r
F
.58032 .88 m .57182 .88247 L .57343 .88651 L 0 .991 .466 r
F
.58032 .88 m .57477 .87968 L .57182 .88247 L F
.57539 .86943 m .57477 .87968 L .58032 .88 L 0 .967 .463 r
F
.55898 .68392 m .56554 .68965 L .56339 .68393 L 0 1 .371 r
F
.55898 .68392 m .56404 .69808 L .56554 .68965 L F
.55391 .67059 m .55898 .68392 L .56016 .67562 L 0 1 .362 r
F
.55873 .67977 m .57014 .70624 L .57029 .69856 L 0 .601 .296 r
F
.55873 .67977 m .56657 .70563 L .57014 .70624 L F
.56404 .69808 m .55981 .7177 L .56454 .71798 L 0 1 .38 r
F
.56404 .69808 m .55807 .71202 L .55981 .7177 L F
.56404 .69808 m .55989 .7036 L .55807 .71202 L F
.55898 .68392 m .55989 .7036 L .56404 .69808 L 0 1 .371 r
F
.55898 .68392 m .55547 .7036 L .55989 .7036 L F
.55827 .6948 m .56972 .71641 L .56657 .70563 L 0 .619 .304 r
F
.55827 .6948 m .56931 .72229 L .56972 .71641 L F
.55827 .6948 m .56561 .71992 L .56931 .72229 L F
.56205 .8426 m .56392 .85078 L .56597 .84694 L 0 1 .473 r
F
.56205 .8426 m .56041 .85258 L .56392 .85078 L F
.56205 .8426 m .56597 .84694 L .56518 .84362 L F
.56434 .82992 m .5588 .85672 L .56705 .84917 L 0 .829 .324 r
F
.56596 .84157 m .56959 .84439 L .57298 .8393 L 0 1 .406 r
F
.56596 .84157 m .57298 .8393 L .57141 .83817 L F
.57494 .82399 m .56899 .83651 L .57431 .83278 L 0 1 .405 r
F
.57494 .82399 m .56734 .83543 L .56899 .83651 L F
.56943 .83414 m .57565 .84709 L .57676 .84336 L 0 .855 .44 r
F
.56943 .83414 m .57676 .84336 L .57415 .83816 L F
.57819 .8343 m .57415 .83816 L .57676 .84336 L 0 .787 .436 r
F
.57819 .8343 m .57476 .83427 L .57415 .83816 L F
.57494 .82399 m .56989 .83007 L .56734 .83543 L 0 1 .405 r
F
.57011 .82187 m .56989 .83007 L .57494 .82399 L 0 1 .382 r
F
.57097 .81988 m .57476 .83427 L .57819 .8343 L 0 .777 .424 r
F
.57097 .81988 m .57819 .8343 L .57852 .82995 L F
.57097 .81988 m .57852 .82995 L .57551 .82414 L F
.56972 .71641 m .56931 .72229 L .57243 .73554 L 0 .462 .294 r
F
.56917 .80541 m .56663 .81622 L .57124 .81128 L 0 1 .321 r
F
.57 .80271 m .571 .81495 L .57536 .81959 L 0 .709 .403 r
F
.57815 .81935 m .57551 .82414 L .57852 .82995 L 0 .693 .416 r
F
.57815 .81935 m .57536 .81959 L .57551 .82414 L F
.56851 .7301 m .56784 .73464 L .57065 .74607 L 0 .512 .31 r
F
.58108 .70843 m .58139 .71163 L .58129 .70659 L 0 .396 .268 r
F
.57142 .80708 m .58129 .70659 L .57879 .73486 L 0 0 .101 r
F
.58129 .70659 m .58188 .70058 L .58142 .70578 L F
.58129 .70659 m .58197 .7085 L .58142 .70578 L 0 .396 .268 r
F
.58129 .70659 m .58142 .70578 L .57879 .73486 L 0 0 .101 r
F
.58172 .70056 m .58186 .69968 L .58187 .6994 L 0 .742 .063 r
F
.58052 .71322 m .58189 .6991 L .58112 .70803 L 0 0 .101 r
F
.58075 .70505 m .58129 .70659 L .58092 .70335 L 0 .396 .268 r
F
.58129 .70659 m .58142 .70578 L .58092 .70335 L F
.57568 .801 m .57436 .80735 L .57773 .8141 L 0 .621 .392 r
F
.57568 .801 m .57348 .80173 L .57436 .80735 L F
.57804 .73137 m .57829 .73028 L .57856 .7275 L 0 0 .081 r
F
.57782 .73414 m .57829 .73028 L .57804 .73137 L F
.57114 .78905 m .57876 .72585 L .57453 .7634 L F
.57142 .80708 m .57453 .7634 L .57876 .72585 L 0 0 .101 r
F
.56959 .84439 m .56673 .85284 L .57321 .84726 L 0 1 .414 r
F
.56943 .83414 m .57157 .84687 L .57565 .84709 L 0 .855 .44 r
F
.57097 .81988 m .57023 .83002 L .57476 .83427 L 0 .777 .424 r
F
.57756 .76685 m .57646 .76946 L .5788 .77867 L 0 .43 .329 r
F
.57122 .84132 m .58174 .71076 L .58155 .72291 L 0 .009 .114 r
F
.57122 .84132 m .57879 .73486 L .58174 .71076 L F
.57033 .78205 m .56986 .78147 L .57269 .76269 L 0 0 .054 r
F
.57122 .84132 m .58155 .72291 L .57836 .76795 L 0 .009 .114 r
F
.57142 .80708 m .57879 .73486 L .57463 .77963 L 0 0 .101 r
F
.57122 .84132 m .57463 .77963 L .57879 .73486 L 0 .009 .114 r
F
.57114 .78905 m .57088 .7853 L .5739 .75951 L 0 0 .081 r
F
.57142 .80708 m .57137 .79838 L .57453 .7634 L 0 0 .101 r
F
.57335 .87947 m .55784 .89733 L .55864 .89897 L 0 1 .393 r
F
.57335 .87947 m .56415 .88897 L .55784 .89733 L F
.57056 .86998 m .56415 .88897 L .57335 .87947 L 0 1 .357 r
F
.56716 .86252 m .57603 .86444 L .57453 .86334 L 0 .061 .034 r
F
.57565 .84709 m .57235 .85515 L .57736 .85892 L 0 .876 .45 r
F
.55679 .87665 m .55556 .88793 L .55872 .88758 L 0 1 .449 r
F
.55679 .87665 m .55267 .8847 L .55556 .88793 L F
.55679 .87665 m .55872 .88758 L .56048 .88413 L F
.55679 .87665 m .55199 .88004 L .55267 .8847 L F
.55679 .87665 m .56048 .88413 L .55967 .87988 L F
.55679 .87665 m .55376 .87658 L .55199 .88004 L F
.55484 .86418 m .55376 .87658 L .55679 .87665 L 0 .88 .411 r
F
.55484 .86418 m .55679 .87665 L .55845 .87319 L F
.55484 .86418 m .55845 .87319 L .55763 .86851 L F
.5652 .86076 m .55444 .88237 L .56181 .8819 L 0 1 .347 r
F
.5652 .86076 m .55427 .85672 L .56162 .85755 L 0 .061 .034 r
F
.56275 .86053 m .55427 .85672 L .5652 .86076 L F
.56705 .84923 m .56275 .86053 L .5652 .86076 L 0 1 .347 r
F
.56275 .86053 m .55444 .88237 L .5652 .86076 L F
.56716 .86252 m .56275 .86053 L .5652 .86076 L 0 .061 .034 r
F
.57321 .84726 m .56391 .85869 L .56994 .85538 L 0 1 .411 r
F
.55058 .86544 m .53969 .87774 L .5519 .8734 L 0 1 .497 r
F
.55484 .86418 m .55097 .87226 L .55376 .87658 L 0 .88 .411 r
F
.56275 .86053 m .55339 .87106 L .55444 .88237 L 0 1 .347 r
F
.56275 .86053 m .55332 .86003 L .55427 .85672 L 0 .061 .034 r
F
.55959 .86116 m .55332 .86003 L .56275 .86053 L F
.56705 .84923 m .55959 .86116 L .56275 .86053 L 0 1 .347 r
F
.55959 .86116 m .55339 .87106 L .56275 .86053 L F
.56716 .86252 m .55959 .86116 L .56275 .86053 L 0 .061 .034 r
F
.57321 .84726 m .56274 .85774 L .56391 .85869 L 0 1 .411 r
F
.57565 .84709 m .57016 .85033 L .57235 .85515 L 0 .876 .45 r
F
.57321 .84726 m .56673 .85284 L .56274 .85774 L 0 1 .411 r
F
.57565 .84709 m .57157 .84687 L .57016 .85033 L 0 .876 .45 r
F
.58069 .79889 m .57877 .79978 L .58009 .80584 L 0 .517 .376 r
F
.57463 .8545 m .58121 .75633 L .58094 .78902 L 0 .076 .128 r
F
.57392 .85272 m .58121 .75633 L .57463 .8545 L F
.56999 .88897 m .56712 .89844 L .57371 .89907 L 0 1 .461 r
F
.56999 .88897 m .57371 .89907 L .57745 .89654 L F
.56999 .88897 m .57745 .89654 L .57584 .89254 L F
.55872 .88758 m .55437 .89547 L .55734 .89815 L 0 1 .467 r
F
.57056 .86998 m .55664 .89453 L .56415 .88897 L 0 1 .357 r
F
.56627 .87884 m .56999 .88897 L .57343 .88651 L 0 .999 .463 r
F
.56627 .87884 m .57343 .88651 L .57182 .88247 L F
.57539 .86943 m .56935 .87622 L .57477 .87968 L 0 .967 .463 r
F
.55872 .88758 m .55369 .89131 L .55437 .89547 L 0 1 .467 r
F
.57056 .86998 m .55583 .89243 L .55664 .89453 L 0 1 .357 r
F
.55872 .88758 m .55556 .88793 L .55369 .89131 L 0 1 .467 r
F
.57056 .86998 m .56181 .8819 L .55583 .89243 L 0 1 .357 r
F
.57539 .86943 m .56766 .87193 L .56935 .87622 L 0 .967 .463 r
F
.57539 .86943 m .57025 .86901 L .56766 .87193 L F
.56464 .86636 m .56716 .86258 L .57255 .86236 L 0 .101 .086 r
F
.56464 .86636 m .57255 .86236 L .57141 .86215 L F
.57045 .85843 m .57025 .86901 L .57539 .86943 L 0 .945 .458 r
F
.57045 .85843 m .57539 .86943 L .57768 .86644 L F
.57045 .85843 m .57768 .86644 L .57558 .86206 L F
.56041 .80458 m .56268 .80146 L .56348 .79913 L 0 .922 .142 r
F
.56008 .80569 m .56268 .80146 L .56041 .80458 L F
.56164 .80427 m .56162 .80431 L .56165 .80431 L 0 .805 .399 r
F
.56008 .80569 m .56165 .80431 L .5626 .80159 L 0 .922 .142 r
F
.55965 .80709 m .56165 .80431 L .56008 .80569 L F
.55825 .80904 m .56109 .80554 L .56165 .80431 L F
.56165 .80431 m .56161 .80441 L .56157 .80466 L 0 1 .198 r
F
.56165 .80431 m .56157 .80466 L .56104 .80804 L F
.56374 .804 m .56165 .80431 L .56105 .80932 L 0 .783 .412 r
F
.56161 .80441 m .56107 .80637 L .56104 .80804 L 0 1 .198 r
F
.56165 .80431 m .56107 .80673 L .56105 .80932 L 0 .783 .412 r
F
.56161 .80441 m .56109 .80554 L .56107 .80637 L 0 1 .198 r
F
.55959 .86116 m .55696 .86167 L .55332 .86003 L 0 .061 .034 r
F
.56705 .84923 m .5588 .85685 L .55696 .86167 L 0 1 .347 r
F
.55959 .86116 m .55696 .86167 L .55339 .87106 L F
.56705 .84923 m .55696 .86167 L .55959 .86116 L F
.56716 .86252 m .55884 .86252 L .55696 .86167 L 0 .061 .034 r
F
.56716 .86252 m .55696 .86167 L .55959 .86116 L F
.56464 .86636 m .55884 .86265 L .56716 .86258 L 0 .101 .086 r
F
.55484 .86418 m .55028 .86656 L .55097 .87226 L 0 .88 .411 r
F
.56464 .86636 m .55207 .86685 L .55884 .86265 L 0 .101 .086 r
F
.56206 .8657 m .56464 .86636 L .56969 .86172 L 0 1 .211 r
F
.56206 .8657 m .56969 .86172 L .56854 .86137 L F
.56959 .84439 m .56099 .85622 L .56673 .85284 L 0 1 .414 r
F
.56959 .84439 m .55982 .85513 L .56099 .85622 L F
.56959 .84439 m .5635 .85006 L .55982 .85513 L F
.56596 .84157 m .5635 .85006 L .56959 .84439 L 0 1 .406 r
F
.56596 .84157 m .55805 .85347 L .5635 .85006 L F
.56596 .84157 m .55688 .85234 L .55805 .85347 L F
.56596 .84157 m .56026 .84724 L .55688 .85234 L F
.56215 .83883 m .56596 .84157 L .56899 .83651 L 0 1 .39 r
F
.56215 .83883 m .56026 .84724 L .56596 .84157 L F
.56215 .83883 m .56899 .83651 L .56734 .83543 L F
.57011 .82187 m .56487 .83396 L .56989 .83007 L 0 1 .382 r
F
.55832 .83654 m .56215 .83883 L .56487 .83396 L 0 1 .366 r
F
.55832 .83654 m .56487 .83396 L .56321 .83307 L F
.57011 .82187 m .56321 .83307 L .56487 .83396 L 0 1 .382 r
F
.57011 .82187 m .56546 .82789 L .56321 .83307 L F
.56507 .82057 m .56068 .83195 L .56546 .82789 L 0 1 .349 r
F
.56 .82059 m .56083 .82646 L .56507 .82057 L 0 1 .303 r
F
.57045 .85843 m .56513 .86539 L .57025 .86901 L 0 .945 .458 r
F
.55946 .86386 m .56206 .8657 L .56681 .86059 L 0 1 .345 r
F
.55946 .86386 m .56681 .86059 L .56565 .85991 L F
.57045 .85843 m .56344 .86097 L .56513 .86539 L 0 .945 .458 r
F
.57045 .85843 m .56571 .85799 L .56344 .86097 L F
.56528 .8464 m .56571 .85799 L .57045 .85843 L 0 .925 .451 r
F
.56528 .8464 m .57045 .85843 L .57235 .85515 L F
.56528 .8464 m .57235 .85515 L .57016 .85033 L F
.5601 .83362 m .56528 .8464 L .56686 .84286 L 0 .91 .444 r
F
.5601 .83362 m .56686 .84286 L .56466 .83773 L F
.56943 .83414 m .56466 .83773 L .56686 .84286 L 0 .855 .44 r
F
.56943 .83414 m .56576 .83399 L .56466 .83773 L F
.5632 .82011 m .56135 .82974 L .56576 .83399 L 0 .844 .43 r
F
.5632 .82011 m .55915 .82422 L .56135 .82974 L F
.5632 .82011 m .55994 .82009 L .55915 .82422 L F
.56507 .82057 m .56546 .82789 L .57011 .82187 L 0 1 .349 r
F
.5632 .82011 m .56576 .83399 L .56943 .83414 L 0 .844 .43 r
F
.5632 .82011 m .56943 .83414 L .57023 .83002 L F
.5632 .82011 m .57023 .83002 L .56761 .82436 L F
.5631 .8082 m .56557 .81167 L .56917 .80541 L 0 1 .262 r
F
.56374 .804 m .56105 .80932 L .56368 .81549 L 0 .783 .412 r
F
.55405 .81844 m .56106 .80119 L .5578 .80951 L 0 0 0 r
F
.55805 .80957 m .5578 .80951 L .56106 .80119 L F
.56158 .80093 m .56023 .80435 L .56189 .79922 L F
.55814 .80934 m .56109 .80554 L .55825 .80904 L 0 .922 .142 r
F
.55218 .83515 m .56158 .80093 L .55973 .80907 L 0 0 .057 r
F
.55218 .83515 m .56023 .80435 L .56158 .80093 L F
.56268 .80146 m .56165 .80431 L .56374 .804 L 0 .805 .399 r
F
.5626 .80159 m .56165 .80431 L .56268 .80146 L 0 .922 .142 r
F
.56386 .79476 m .56563 .79139 L .56574 .7908 L 0 1 .145 r
F
.56374 .7952 m .56563 .79139 L .56386 .79476 L F
.55463 .83323 m .56345 .79604 L .56459 .79293 L 0 0 .07 r
F
.55463 .83323 m .55973 .80907 L .56345 .79604 L F
.55463 .83323 m .56459 .79293 L .56243 .80319 L F
.56538 .79253 m .56519 .79334 L .56543 .79245 L 0 1 .145 r
F
.56543 .79245 m .5649 .79448 L .56545 .7925 L 0 .744 .39 r
F
.5649 .79448 m .56756 .80328 L .56545 .7925 L F
.5649 .79448 m .56375 .79876 L .56756 .80328 L F
.56583 .79098 m .56585 .79095 L .56596 .79061 L 0 1 .145 r
F
.56583 .79098 m .56621 .78986 L .56618 .7898 L 0 .744 .39 r
F
.56583 .79098 m .56596 .79061 L .56617 .78992 L 0 1 .145 r
F
.56583 .79098 m .56931 .7967 L .56621 .78986 L 0 .744 .39 r
F
.56585 .79095 m .56621 .78986 L .56617 .78992 L 0 1 .145 r
F
.56574 .7908 m .56583 .79098 L .56595 .79035 L F
.56563 .79139 m .56583 .79098 L .56574 .7908 L F
.56583 .79098 m .56617 .78992 L .56595 .79035 L F
.56542 .79246 m .56543 .79245 L .56555 .79201 L F
.56583 .79098 m .57 .80271 L .56931 .7967 L 0 .744 .39 r
F
.56583 .79098 m .56542 .79246 L .56585 .79095 L 0 1 .145 r
F
.56543 .79245 m .57 .80271 L .56583 .79098 L 0 .744 .39 r
F
.56538 .79253 m .56542 .79246 L .56583 .79098 L 0 1 .145 r
F
.56672 .78545 m .56595 .79035 L .56621 .78986 L 0 1 .146 r
F
.56635 .78922 m .56618 .7898 L .56621 .78986 L 0 .675 .379 r
F
.56634 .78928 m .56621 .78986 L .56631 .79008 L F
.56635 .78922 m .56621 .78986 L .56634 .78928 L F
.5601 .83362 m .55623 .83328 L .55466 .83682 L 0 .91 .444 r
F
.55666 .83344 m .56614 .78875 L .56706 .78627 L 0 0 .084 r
F
.56372 .79857 m .56369 .79869 L .56375 .79876 L 0 .744 .39 r
F
.55666 .83344 m .56243 .80319 L .56614 .78875 L 0 0 .084 r
F
.56634 .78947 m .56631 .79008 L .5666 .78867 L 0 .675 .379 r
F
.56634 .78947 m .5666 .78867 L .56732 .78515 L F
.55666 .83344 m .56706 .78627 L .56462 .79911 L 0 0 .084 r
F
.55832 .83654 m .55687 .84445 L .56215 .83883 L 0 1 .366 r
F
.5601 .83362 m .55466 .83682 L .55643 .84187 L 0 .91 .444 r
F
.56507 .82057 m .57011 .82187 L .57199 .817 L 0 1 .349 r
F
.56507 .82057 m .57199 .817 L .56985 .81652 L F
.56917 .80541 m .56448 .8163 L .56663 .81622 L 0 1 .321 r
F
.56917 .80541 m .56557 .81167 L .56448 .8163 L F
.56374 .804 m .56368 .81549 L .56793 .82001 L 0 .783 .412 r
F
.56374 .804 m .56793 .82001 L .57097 .81988 L F
.56374 .804 m .571 .81495 L .56799 .80853 L F
.56374 .804 m .57097 .81988 L .571 .81495 L F
.55824 .83665 m .56828 .7834 L .56898 .78205 L 0 0 .096 r
F
.55824 .83665 m .56462 .79911 L .56828 .7834 L F
.55824 .83665 m .56898 .78205 L .56628 .79798 L F
.56215 .83883 m .55507 .85065 L .56026 .84724 L 0 1 .39 r
F
.56215 .83883 m .55383 .84952 L .55507 .85065 L F
.56215 .83883 m .55687 .84445 L .55383 .84952 L F
.5601 .83362 m .55643 .84187 L .56098 .84598 L 0 .91 .444 r
F
.5601 .83362 m .56098 .84598 L .56528 .8464 L F
.55938 .84398 m .56986 .78147 L .57033 .78205 L 0 .021 .106 r
F
.55938 .84398 m .56628 .79798 L .56986 .78147 L F
.55463 .83323 m .56243 .80319 L .55838 .82007 L 0 0 .07 r
F
.55666 .83344 m .55838 .82007 L .56243 .80319 L 0 0 .084 r
F
.55938 .84398 m .57033 .78205 L .56741 .80158 L 0 .021 .106 r
F
.55666 .83344 m .56462 .79911 L .56041 .81883 L 0 0 .084 r
F
.55824 .83665 m .56041 .81883 L .56462 .79911 L 0 0 .096 r
F
.55422 .85848 m .55685 .86134 L .56099 .85622 L 0 1 .396 r
F
.55422 .85848 m .56099 .85622 L .55982 .85513 L F
.55061 .85592 m .55427 .85661 L .55332 .85977 L 0 .676 .064 r
F
.55158 .85553 m .55422 .85848 L .55805 .85347 L 0 1 .391 r
F
.55158 .85553 m .55805 .85347 L .55688 .85234 L F
.55439 .84516 m .55847 .85709 L .56084 .85406 L 0 .967 .453 r
F
.55439 .84516 m .56084 .85406 L .55908 .84926 L F
.56528 .8464 m .55908 .84926 L .56084 .85406 L 0 .925 .451 r
F
.56528 .8464 m .56098 .84598 L .55908 .84926 L F
.57 .80271 m .56756 .80328 L .56799 .80853 L 0 .709 .403 r
F
.56017 .85603 m .57088 .7853 L .57114 .78905 L 0 .065 .114 r
F
.56006 .85673 m .56016 .85603 L .56017 .85603 L F
.56016 .85603 m .57088 .7853 L .56017 .85603 L F
.56634 .92437 m .56441 .93356 L .56823 .93263 L 0 1 .495 r
F
.56639 .93034 m .56827 .93683 L .57054 .93419 L 0 1 .524 r
F
.56639 .93034 m .57054 .93419 L .56975 .93157 L F
.55058 .86544 m .53036 .87873 L .53969 .87774 L 0 1 .497 r
F
.55058 .86544 m .53012 .87571 L .53036 .87873 L F
.55058 .86544 m .53879 .87001 L .53012 .87571 L F
.54925 .85757 m .53879 .87001 L .55058 .86544 L 0 1 .496 r
F
.54925 .85757 m .52976 .87123 L .53879 .87001 L F
.54276 .8642 m .55096 .87226 L .55028 .86656 L 0 1 .425 r
F
.5507 .8708 m .55444 .88249 L .55339 .87133 L 0 1 .247 r
F
.56464 .86636 m .55136 .8724 L .55207 .86685 L 0 .101 .086 r
F
.56464 .86636 m .55675 .87219 L .55136 .8724 L F
.56206 .8657 m .55675 .87219 L .56464 .86636 L 0 1 .211 r
F
.55685 .86134 m .55946 .86386 L .56391 .85869 L 0 1 .388 r
F
.55685 .86134 m .56391 .85869 L .56274 .85774 L F
.56789 .94755 m .57693 .95423 L .57537 .94861 L 0 1 .365 r
F
.56639 .93034 m .56444 .93774 L .56827 .93683 L 0 1 .524 r
F
.56634 .92437 m .56105 .93175 L .56441 .93356 L 0 1 .495 r
F
.56639 .93034 m .56108 .93652 L .56444 .93774 L 0 1 .524 r
F
.56639 .93034 m .56043 .93397 L .56108 .93652 L F
.56639 .93034 m .5627 .93132 L .56043 .93397 L F
.56516 .93067 m .56789 .94749 L .57329 .94067 L 0 .741 .33 r
F
.56516 .93067 m .57329 .94067 L .57209 .93572 L F
.56634 .92437 m .56039 .92841 L .56105 .93175 L 0 1 .495 r
F
.56634 .92437 m .56265 .92525 L .56039 .92841 L F
.56445 .91583 m .56265 .92525 L .56634 .92437 L 0 1 .49 r
F
.56445 .91583 m .55939 .92331 L .56265 .92525 L F
.56445 .91583 m .55872 .91985 L .55939 .92331 L F
.56452 .92396 m .5627 .93132 L .56639 .93034 L 0 1 .524 r
F
.55095 .928 m .56104 .93176 L .56038 .92842 L 0 1 .493 r
F
.56452 .92396 m .55944 .93019 L .5627 .93132 L 0 1 .524 r
F
.56452 .92396 m .56639 .93034 L .56857 .92767 L F
.56452 .92396 m .55878 .9277 L .55944 .93019 L F
.56452 .92396 m .56857 .92767 L .56778 .9251 L F
.56452 .92396 m .56096 .92503 L .55878 .9277 L F
.56263 .91777 m .56096 .92503 L .56452 .92396 L 0 1 .522 r
F
.5496 .91927 m .55095 .928 L .55938 .92331 L 0 1 .488 r
F
.5496 .91927 m .55938 .92331 L .55872 .91985 L F
.56263 .91777 m .55779 .92404 L .56096 .92503 L 0 1 .522 r
F
.56263 .91777 m .56452 .92396 L .56659 .92128 L F
.56247 .91836 m .56516 .93067 L .57029 .92838 L 0 .903 .421 r
F
.56247 .91836 m .57029 .92838 L .56909 .92354 L F
.58112 .91959 m .56909 .92354 L .57029 .92838 L 0 1 .437 r
F
.58112 .91959 m .57372 .91977 L .56909 .92354 L F
.57741 .90925 m .56729 .91653 L .57372 .91977 L 0 1 .448 r
F
.57741 .90925 m .56609 .91202 L .56729 .91653 L F
.57741 .90925 m .57042 .90889 L .56609 .91202 L F
.57371 .89907 m .56429 .90543 L .57042 .90889 L 0 1 .456 r
F
.57371 .89907 m .56309 .90117 L .56429 .90543 L F
.57371 .89907 m .56712 .89844 L .56309 .90117 L F
.56999 .88897 m .56128 .89487 L .56712 .89844 L 0 1 .461 r
F
.56999 .88897 m .56008 .89074 L .56128 .89487 L F
.56999 .88897 m .56381 .88821 L .56008 .89074 L F
.56627 .87884 m .55828 .88459 L .56381 .88821 L 0 .999 .463 r
F
.56627 .87884 m .55707 .88051 L .55828 .88459 L F
.56627 .87884 m .56381 .88821 L .56999 .88897 L F
.56627 .87884 m .5605 .87804 L .55707 .88051 L F
.56238 .86811 m .5605 .87804 L .56627 .87884 L 0 .989 .461 r
F
.56238 .86811 m .56627 .87884 L .56935 .87622 L F
.56238 .86811 m .56935 .87622 L .56766 .87193 L F
.54553 .88991 m .54689 .90042 L .55436 .89547 L 0 1 .459 r
F
.54553 .88991 m .55436 .89547 L .55369 .89132 L F
.54415 .87818 m .54553 .88991 L .55267 .8847 L 0 1 .444 r
F
.54415 .87818 m .55267 .8847 L .55199 .88004 L F
.54276 .8642 m .54415 .87818 L .55096 .87226 L 0 1 .425 r
F
.5507 .8708 m .55319 .89889 L .55444 .88249 L 0 1 .247 r
F
.54689 .90042 m .54825 .91012 L .55604 .90531 L 0 1 .471 r
F
.54689 .90042 m .55604 .90531 L .55537 .90147 L F
.54825 .91012 m .5496 .91927 L .55772 .91453 L 0 1 .48 r
F
.54825 .91012 m .53812 .92197 L .5496 .91927 L F
.54825 .91012 m .52932 .92119 L .53812 .92197 L F
.54825 .91012 m .55772 .91453 L .55705 .91091 L F
.54825 .91012 m .52907 .91745 L .52932 .92119 L F
.54825 .91012 m .53719 .91271 L .52907 .91745 L F
.54689 .90042 m .53719 .91271 L .54825 .91012 L 0 1 .471 r
F
.5443 .90792 m .54564 .91163 L .55282 .90809 L 0 1 .457 r
F
.5443 .90792 m .55282 .90809 L .55215 .90654 L F
.55507 .89846 m .55116 .90495 L .55393 .90382 L 0 1 .228 r
F
.54296 .90634 m .5443 .90792 L .55082 .9051 L 0 1 .323 r
F
.55086 .905 m .55082 .9051 L .55116 .90495 L F
.54296 .90634 m .55082 .9051 L .55086 .905 L F
.55319 .89888 m .55216 .90148 L .55218 .9016 L 0 0 .023 r
F
.55507 .89846 m .5505 .90438 L .55116 .90495 L 0 1 .228 r
F
.54296 .90634 m .55116 .90495 L .5505 .90439 L 0 1 .323 r
F
.55507 .89846 m .55218 .9016 L .5505 .90438 L 0 1 .228 r
F
.55216 .90148 m .54954 .90805 L .55151 .90322 L 0 0 .023 r
F
.55216 .90148 m .55151 .90322 L .55218 .9016 L F
.55319 .89888 m .55218 .9016 L .55507 .89846 L F
.54564 .91163 m .54698 .91642 L .55447 .91275 L 0 1 .511 r
F
.54564 .91163 m .55447 .91275 L .55381 .91075 L F
.55316 .89896 m .54891 .91353 L .54954 .90805 L 0 0 .023 r
F
.55319 .89888 m .55311 .89918 L .55316 .89896 L F
.55311 .89918 m .54891 .91353 L .55316 .89896 L F
.54564 .91163 m .53632 .91933 L .54698 .91642 L 0 1 .511 r
F
.52054 .91692 m .52932 .92119 L .52907 .91745 L 0 1 .485 r
F
.54564 .91163 m .52814 .92022 L .53632 .91933 L 0 1 .511 r
F
.54564 .91163 m .5279 .9185 L .52814 .92022 L F
.54564 .91163 m .5354 .91481 L .5279 .9185 L F
.5443 .90792 m .5354 .91481 L .54564 .91163 L 0 1 .457 r
F
.54689 .90042 m .52871 .91166 L .53719 .91271 L 0 1 .471 r
F
.5443 .90792 m .52754 .9162 L .5354 .91481 L 0 1 .457 r
F
.5443 .90792 m .5273 .91487 L .52754 .9162 L F
.5443 .90792 m .53449 .91132 L .5273 .91487 L F
.54296 .90634 m .53449 .91132 L .5443 .90792 L 0 1 .323 r
F
.54167 .9159 m .54296 .90634 L .54953 .90815 L 0 .46 .218 r
F
.54167 .9159 m .54953 .90815 L .5489 .91375 L F
.55319 .89888 m .55047 .9096 L .54891 .91353 L 0 0 .023 r
F
.5507 .8708 m .54777 .90911 L .55047 .90961 L 0 1 .247 r
F
.55047 .9096 m .55047 .90961 L .55047 .90961 L F
.5507 .8708 m .55047 .90961 L .55047 .9096 L F
.5507 .8708 m .55047 .90961 L .55319 .89889 L F
.56206 .8657 m .55026 .87653 L .55675 .87219 L 0 1 .211 r
F
.5507 .8708 m .54689 .89771 L .54777 .90911 L 0 1 .247 r
F
.5507 .8708 m .54815 .88128 L .54689 .89771 L F
.54897 .87909 m .5507 .87082 L .55207 .86705 L 0 1 .323 r
F
.54897 .87909 m .55207 .86705 L .55136 .87249 L F
.56206 .8657 m .54951 .87647 L .55026 .87653 L 0 1 .211 r
F
.56206 .8657 m .55457 .87183 L .54951 .87647 L F
.55946 .86386 m .55457 .87183 L .56206 .8657 L 0 1 .345 r
F
.55847 .85709 m .56238 .86811 L .56513 .86539 L 0 .978 .458 r
F
.55847 .85709 m .56513 .86539 L .56344 .86097 L F
.56528 .8464 m .56084 .85406 L .56571 .85799 L 0 .925 .451 r
F
.57097 .81988 m .56761 .82436 L .57023 .83002 L 0 .777 .424 r
F
.57097 .81988 m .56793 .82001 L .56761 .82436 L F
.57 .80271 m .56799 .80853 L .571 .81495 L 0 .709 .403 r
F
.58112 .91959 m .57029 .92838 L .57702 .93116 L 0 1 .437 r
F
.57741 .90925 m .57372 .91977 L .58112 .91959 L 0 1 .448 r
F
.57371 .89907 m .57042 .90889 L .57741 .90925 L 0 1 .456 r
F
.57802 .96876 m .57419 .96846 L .58163 .96765 L 0 0 0 r
F
.57439 .96971 m .57802 .96876 L .58213 .96823 L F
.57439 .96971 m .58213 .96823 L .58056 .96861 L F
.58128 .9696 m .57423 .97013 L .57992 .96917 L F
.5764 .97117 m .57566 .97029 L .58128 .9696 L F
.57972 .98128 m .57812 .97712 L .58299 .97635 L F
.58299 1.01 m .58095 1.00647 L .5822 1.00173 L 0 .259 .082 r
F
.57533 .88555 m .5835 1.0233 L .57849 .92539 L 0 .074 .146 r
F
.57499 .88446 m .5835 1.0233 L .57533 .88555 L F
.57385 .86986 m .5835 1.0233 L .57413 .87051 L F
.57328 .8685 m .57332 .86903 L .57385 .86986 L F
.57332 .86903 m .5835 1.0233 L .57385 .86986 L F
.57972 .98128 m .57552 .97856 L .57812 .97712 L 0 0 0 r
F
.57972 .98128 m .5762 .98034 L .57552 .97856 L F
.57994 .98994 m .57713 .98538 L .58012 .98344 L 0 .095 .028 r
F
.57994 .98994 m .57704 .98817 L .57713 .98538 L F
.5777 1.00173 m .57621 .99516 L .57959 .99294 L 0 .225 .064 r
F
.58041 1.03975 m .57917 1.03389 L .58144 1.02785 L 0 .409 .111 r
F
.57296 .87791 m .57556 .95047 L .58125 1.04139 L 0 .074 .146 r
F
.5811 .88281 m .59392 1.31839 L .58113 .88289 L 0 0 .116 r
F
.58143 .88451 m .58161 .88224 L .58138 .88276 L F
.5887 1.10147 m .58172 .8856 L .58143 .88451 L F
.58172 .8856 m .58161 .88224 L .58143 .88451 L F
.58139 .88434 m .58117 .88114 L .58143 .88277 L F
.57973 .89127 m .57849 .92539 L .58109 .91199 L 0 .146 .172 r
F
.5797 .86917 m .5779 .84537 L .58054 .86062 L 0 .16 .157 r
F
.57244 .8677 m .57281 .87738 L .57296 .87791 L 0 .074 .146 r
F
.57281 .87738 m .57556 .95047 L .57296 .87791 L F
.57242 .86766 m .57556 .95047 L .57244 .8677 L F
.57411 .87025 m .57328 .8685 L .57413 .87051 L F
.57328 .8685 m .57329 .86845 L .57411 .87025 L 0 .076 .128 r
F
.57329 .86845 m .57652 .83484 L .57411 .87025 L F
.57351 .86611 m .57392 .85272 L .57463 .8545 L F
.57291 .86609 m .57392 .85272 L .57351 .86611 L F
.5724 .8665 m .57425 .81643 L .57836 .76795 L F
.57239 .8665 m .57425 .81643 L .5724 .8665 L F
.57197 .8662 m .57425 .81643 L .57239 .86663 L F
.5722 .86644 m .57556 .95047 L .57238 .86663 L 0 .074 .146 r
F
.56782 .86592 m .56837 .8709 L .56888 .86595 L 0 .179 .191 r
F
.56837 .8709 m .57179 .90237 L .5692 .86995 L F
.56837 .8709 m .5692 .86995 L .56888 .86595 L F
.56837 .8709 m .57231 .92704 L .57179 .90237 L F
.56481 .8481 m .57137 .79838 L .57142 .80708 L 0 .103 .125 r
F
.5648 .8481 m .57137 .79838 L .56481 .8481 L F
.56451 .84837 m .57137 .79838 L .56476 .84842 L F
.56304 .85905 m .57137 .79838 L .56305 .85903 L F
.56267 .85947 m .57137 .79838 L .56295 .85969 L F
.56006 .85673 m .56741 .80158 L .57088 .7853 L 0 .065 .114 r
F
.55824 .83665 m .56628 .79798 L .56195 .82073 L 0 0 .096 r
F
.55938 .84398 m .56195 .82073 L .56628 .79798 L 0 .021 .106 r
F
.56006 .85673 m .57114 .78905 L .56802 .81248 L 0 .065 .114 r
F
.55938 .84398 m .56741 .80158 L .56301 .82721 L 0 .021 .106 r
F
.56006 .85673 m .56301 .82721 L .56741 .80158 L 0 .065 .114 r
F
.56263 .85942 m .56802 .81248 L .56267 .85947 L 0 .103 .125 r
F
.56445 .91583 m .56089 .91664 L .55872 .91985 L 0 1 .49 r
F
.56263 .91777 m .56659 .92128 L .5658 .91876 L 0 1 .522 r
F
.56263 .91777 m .55713 .92165 L .55779 .92404 L F
.56263 .91777 m .5592 .91896 L .55713 .92165 L F
.56075 .91186 m .56263 .91777 L .56461 .91507 L 0 1 .516 r
F
.56075 .91186 m .5592 .91896 L .56263 .91777 L F
.56075 .91186 m .56461 .91507 L .56382 .91266 L F
.55885 .90642 m .56075 .91186 L .56262 .90916 L 0 1 .5 r
F
.55978 .90719 m .56247 .91836 L .56729 .91653 L 0 .953 .447 r
F
.55978 .90719 m .56729 .91653 L .56609 .91202 L F
.56234 .8593 m .564 .8918 L .56916 .94141 L 0 .158 .185 r
F
.55938 .84398 m .55898 .84051 L .56195 .82073 L 0 .021 .106 r
F
.56006 .85673 m .56802 .81248 L .56358 .84016 L 0 .065 .114 r
F
.56234 .8593 m .56358 .84016 L .56802 .81248 L 0 .103 .125 r
F
.56184 .85919 m .56186 .85944 L .56234 .8593 L 0 .158 .185 r
F
.56186 .85944 m .56186 .85952 L .56234 .8593 L F
.56186 .85952 m .564 .8918 L .56234 .8593 L F
.5728 .86726 m .58121 .75633 L .57282 .8673 L 0 .076 .128 r
F
.57328 .8685 m .57291 .86609 L .57351 .86611 L F
.57411 .87025 m .57484 .87137 L .57484 .87142 L F
.57411 .87025 m .57487 .8719 L .57484 .87142 L 0 .074 .146 r
F
.57411 .87025 m .57849 .92539 L .57487 .8719 L F
.57413 .87051 m .57499 .88446 L .57533 .88555 L F
.5739 .85267 m .57836 .76795 L .58121 .75633 L 0 .076 .128 r
F
.5728 .86726 m .57364 .85221 L .5739 .85267 L F
.57364 .85221 m .57836 .76795 L .5739 .85267 L F
.57652 .83484 m .58094 .78902 L .57771 .84293 L F
.58132 .87291 m .58396 .70758 L .58445 .71832 L 0 0 .116 r
F
.58111 .87531 m .58396 .70758 L .58132 .87291 L F
.58092 .88224 m .5832 .73246 L .58099 .88245 L F
.58143 .88277 m .58457 .72147 L .58532 .74334 L F
.57029 .69856 m .578 .72554 L .57869 .72251 L 0 .421 .28 r
F
.57852 .72735 m .57856 .7275 L .57883 .72474 L 0 0 .081 r
F
.57804 .73137 m .57856 .7275 L .57852 .72735 L F
.57696 .74082 m .57881 .72495 L .57876 .72585 L F
.57684 .74135 m .57881 .72495 L .57696 .74082 L F
.57029 .69856 m .57899 .72339 L .57866 .7167 L 0 .421 .28 r
F
.57019 .6753 m .58011 .71169 L .58075 .70505 L 0 .396 .268 r
F
.56927 .63635 m .56866 .65919 L .57302 .65767 L 0 1 .339 r
F
.56941 .64563 m .57714 .65236 L .57255 .64309 L 0 .395 .26 r
F
.56941 .64563 m .58098 .67167 L .57714 .65236 L F
.56941 .64563 m .58148 .68817 L .58098 .67167 L F
.56793 .66819 m .57503 .67363 L .57248 .66772 L 0 1 .359 r
F
.56941 .64563 m .57832 .69072 L .58148 .68817 L 0 .395 .26 r
F
.56941 .64563 m .57361 .67761 L .57832 .69072 L F
.57019 .6753 m .57832 .69072 L .57361 .67761 L 0 .396 .268 r
F
.57019 .6753 m .57393 .70302 L .57866 .7167 L F
.57029 .69856 m .57866 .7167 L .57393 .70302 L 0 .421 .28 r
F
.57336 .52632 m .58222 .86146 L .58247 .86774 L 0 .09 .148 r
F
.58256 .8679 m .58247 .86774 L .58275 .87494 L F
.57336 .52632 m .58247 .86774 L .58256 .8679 L F
.57279 .86735 m .5728 .86725 L .5728 .86726 L 0 .076 .128 r
F
.5728 .86725 m .57836 .76795 L .5728 .86726 L F
.57326 .86819 m .58471 1.07334 L .5835 1.0233 L 0 .074 .146 r
F
.57239 .86663 m .57836 .76795 L .57279 .86735 L 0 .076 .128 r
F
.57197 .8662 m .57127 .86549 L .57425 .81643 L F
.57195 .86576 m .57121 .86431 L .57556 .95047 L 0 .074 .146 r
F
.57279 .86737 m .57239 .86663 L .57279 .86735 L 0 .076 .128 r
F
.57239 .86663 m .57239 .8665 L .5724 .8665 L F
.57163 .85168 m .57244 .8677 L .57189 .8518 L 0 .074 .146 r
F
.58258 .89194 m .58638 .83872 L .58368 .89613 L 0 0 .116 r
F
.58258 .89194 m .58368 .89613 L .58362 .89739 L F
.58264 .89329 m .58855 1.02391 L .58388 .9041 L F
.58641 .77883 m .58648 .78084 L .58261 .89153 L F
.58261 .89153 m .58648 .78084 L .58638 .83872 L F
.58503 .88982 m .5834 .89948 L .58973 .89941 L 0 1 .468 r
F
.58264 .89329 m .58388 .9041 L .58222 .86146 L 0 0 .116 r
F
.58291 .89669 m .58362 .89739 L .58336 .90301 L F
.58258 .89194 m .58362 .89739 L .58291 .89669 L F
.58483 .90221 m .58362 .89739 L .58638 .83872 L 0 .145 .158 r
F
.58472 .89849 m .58362 .89739 L .58483 .90221 L 0 .09 .148 r
F
.58411 .87836 m .58362 .89739 L .58472 .89849 L F
.58411 .87836 m .58275 .87494 L .58362 .89739 L F
.58483 .90221 m .58362 .89739 L .58855 1.02391 L F
.58905 1.08205 m .58916 1.07678 L .58258 .89194 L 0 0 .116 r
F
.58258 .89194 m .58916 1.07678 L .58855 1.02391 L F
.58452 .91523 m .58301 .91037 L .58362 .89739 L 0 .145 .158 r
F
.58452 .91523 m .58362 .89739 L .58483 .90221 L F
.5845 .9159 m .58301 .91037 L .58452 .91523 L F
.57296 .87791 m .58125 1.04139 L .57322 .87876 L 0 .074 .146 r
F
.57279 .86737 m .58125 1.04139 L .58471 1.07334 L F
.57189 .8518 m .57264 .86701 L .57279 .86737 L F
.57264 .86701 m .58125 1.04139 L .57279 .86737 L F
.5728 .86726 m .57282 .8673 L .57281 .86741 L 0 .076 .128 r
F
.57244 .8677 m .57296 .87791 L .57269 .86809 L 0 .074 .146 r
F
.57296 .87791 m .57322 .87876 L .57269 .86809 L F
.57279 .86737 m .58471 1.07334 L .57328 .86849 L F
.57323 .8684 m .57323 .86839 L .57328 .8685 L 0 .076 .128 r
F
.57281 .86746 m .57291 .86609 L .57327 .86864 L F
.57279 .86737 m .57328 .86849 L .57326 .86819 L 0 .074 .146 r
F
.57327 .86864 m .57323 .8684 L .57328 .8685 L 0 .076 .128 r
F
.57197 .8662 m .57556 .95047 L .5722 .86644 L 0 .074 .146 r
F
.57279 .86737 m .57281 .86741 L .57158 .88362 L 0 .076 .128 r
F
.5728 .86726 m .57281 .86741 L .57279 .86737 L F
.58063 1.07421 m .58063 1.07421 L .58063 1.07421 L 0 .601 .12 r
F
.57295 .98334 m .58103 1.07504 L .58104 1.07531 L 0 0 .114 r
F
.57295 1.06551 m .58063 1.07421 L .58098 1.07988 L 0 .601 .12 r
F
.57728 1.04188 m .57815 1.05029 L .577 1.03954 L 0 0 .105 r
F
.57815 1.05029 m .57998 1.06791 L .57807 1.04968 L F
.57815 1.05029 m .57807 1.04968 L .577 1.03954 L F
.57799 1.04915 m .57998 1.06791 L .57985 1.06718 L F
.577 1.03954 m .57807 1.04968 L .57799 1.04915 L F
.57807 1.04968 m .57998 1.06791 L .57799 1.04915 L F
.57229 .99375 m .57728 1.04188 L .577 1.03954 L F
.57818 1.05216 m .57822 1.05245 L .57819 1.05228 L 0 0 .097 r
F
.57822 1.05245 m .57823 1.05255 L .57819 1.05228 L F
.57756 1.04583 m .57819 1.05228 L .57801 1.05072 L F
.57807 1.05136 m .57839 1.0538 L .57844 1.05434 L F
.57896 1.05882 m .5791 1.05953 L .57524 1.02704 L F
.5797 1.07315 m .58048 1.07258 L .58063 1.07421 L 0 .601 .12 r
F
.57985 1.06718 m .58056 1.07398 L .58067 1.07514 L 0 0 .105 r
F
.57229 .99375 m .58064 1.07486 L .5766 1.0333 L F
.57998 1.06791 m .58063 1.07421 L .57985 1.06718 L F
.58063 1.07421 m .58103 1.07849 L .57985 1.06718 L F
.58056 1.07398 m .58071 1.07542 L .58067 1.07514 L F
.58064 1.07486 m .5807 1.07517 L .5766 1.0333 L F
.5812 1.08026 m .58128 1.08075 L .58127 1.08069 L F
.5812 1.08026 m .58131 1.08046 L .58121 1.08037 L 0 .601 .12 r
F
.5812 1.08026 m .58127 1.08069 L .5766 1.0333 L 0 0 .105 r
F
.58122 1.08038 m .58123 1.08063 L .58121 1.08037 L 0 .601 .12 r
F
.58131 1.08046 m .58126 1.08059 L .58122 1.08038 L F
.58126 1.08059 m .58123 1.08063 L .58122 1.08038 L F
.57388 1.08254 m .57701 1.07511 L .58123 1.08063 L 0 .67 .126 r
F
.57388 1.08254 m .58123 1.08063 L .58124 1.08069 L F
.58045 1.04976 m .58034 1.04687 L .58208 1.0497 L 0 .545 .109 r
F
.57417 1.10002 m .58382 1.11346 L .58437 1.12217 L 0 .762 .122 r
F
.57793 1.12547 m .57707 1.11401 L .58288 1.11919 L 0 .305 .054 r
F
.57417 1.10002 m .58437 1.12217 L .58539 1.13722 L 0 .762 .122 r
F
.57417 1.10002 m .58612 1.13962 L .58311 1.13875 L F
.57417 1.10002 m .58285 1.10766 L .58406 1.11379 L F
.57295 .98334 m .5766 1.0333 L .58127 1.08069 L 0 0 .114 r
F
.58064 1.07926 m .5807 1.07993 L .57701 1.07511 L 0 .601 .12 r
F
.58051 1.06209 m .58169 1.07752 L .5817 1.07844 L 0 0 .123 r
F
.57281 .95567 m .58055 1.06193 L .58051 1.06209 L F
.58055 1.06193 m .58169 1.07752 L .58051 1.06209 L F
.57904 1.05422 m .58111 1.07824 L .58115 1.07887 L 0 0 .114 r
F
.57924 1.0565 m .58111 1.07824 L .57904 1.05422 L F
.58296 1.09972 m .58303 1.10047 L .58305 1.10075 L F
.58244 1.09369 m .58286 1.09819 L .58296 1.09972 L F
.58245 1.09386 m .58305 1.10075 L .58267 1.09654 L F
.58305 1.10075 m .58362 1.10755 L .58344 1.10758 L 0 .67 .126 r
F
.58305 1.10075 m .58365 1.10791 L .58267 1.09654 L 0 0 .114 r
F
.58366 1.10805 m .58366 1.10805 L .58274 1.09734 L F
.58263 1.09992 m .58294 1.09948 L .58305 1.10075 L 0 .67 .126 r
F
.5827 1.09694 m .58361 1.10742 L .58274 1.09734 L 0 0 .114 r
F
.58361 1.10742 m .58362 1.10755 L .58274 1.09734 L F
.57281 .95567 m .58274 1.09734 L .58354 1.1068 L 0 0 .123 r
F
.57281 .95567 m .58354 1.1068 L .58394 1.11026 L F
.57388 1.08254 m .58169 1.0908 L .58263 1.09992 L 0 .67 .126 r
F
.57281 .95567 m .5817 1.07844 L .58199 1.08066 L 0 0 .123 r
F
.57179 .90237 m .58125 1.04139 L .57556 .95047 L 0 .02 .129 r
F
.57179 .90237 m .58602 1.12347 L .58125 1.04139 L F
.58459 1.11242 m .58548 1.12101 L .58459 1.11242 L 0 0 .105 r
F
.58459 1.11242 m .58477 1.11056 L .58548 1.12101 L F
.58458 1.11242 m .58548 1.12101 L .58458 1.11242 L F
.57179 .90237 m .58655 1.13971 L .58602 1.12347 L 0 .02 .129 r
F
.57179 .90237 m .58257 1.08864 L .58655 1.13971 L F
.57179 .90237 m .57688 1.00615 L .58257 1.08864 L F
.57281 .95567 m .58257 1.08864 L .57688 1.00615 L 0 0 .123 r
F
.58103 1.07504 m .58124 1.07737 L .58104 1.07531 L 0 0 .114 r
F
.58122 1.07735 m .58166 1.08214 L .58172 1.08306 L F
.58124 1.07737 m .58166 1.08214 L .58122 1.07735 L F
.58187 1.08708 m .58172 1.08306 L .58244 1.09369 L F
.57281 .95567 m .57718 1.02926 L .58274 1.09734 L 0 0 .123 r
F
.57295 .98334 m .57906 1.05439 L .57904 1.05422 L 0 0 .114 r
F
.57906 1.05439 m .57924 1.0565 L .57908 1.05467 L F
.57906 1.05439 m .57908 1.05467 L .57904 1.05422 L F
.58115 1.07887 m .58194 1.08791 L .58235 1.0928 L F
.58111 1.07824 m .58194 1.08791 L .58115 1.07887 L F
.58194 1.08791 m .58245 1.09386 L .58235 1.0928 L F
.58267 1.09654 m .5827 1.09694 L .58274 1.09734 L F
.57295 .98334 m .58274 1.09734 L .57718 1.02926 L F
.57388 1.08254 m .58285 1.10766 L .57785 1.0963 L 0 .67 .126 r
F
.57417 1.10002 m .57785 1.0963 L .58285 1.10766 L 0 .762 .122 r
F
.57793 1.12547 m .57145 1.11169 L .57707 1.11401 L 0 .305 .054 r
F
.57417 1.10002 m .58311 1.13875 L .578 1.11958 L 0 .762 .122 r
F
.57943 1.12447 m .583 .91097 L .5845 .9159 L 0 .145 .158 r
F
.583 .91097 m .58301 .91037 L .5845 .9159 L F
.57244 .8677 m .57269 .86809 L .57189 .8518 L 0 .074 .146 r
F
.57411 .87025 m .57484 .87142 L .57483 .87146 L 0 .076 .128 r
F
.57411 .87032 m .57483 .87146 L .57349 .88455 L F
.57411 .87025 m .57483 .87146 L .57411 .87032 L F
.57238 .86637 m .57242 .86766 L .57244 .8677 L 0 .074 .146 r
F
.57058 .89657 m .57239 .86666 L .57255 .86694 L 0 .076 .128 r
F
.57279 .86741 m .57255 .86694 L .57279 .86737 L F
.57058 .89657 m .57255 .86694 L .57279 .86741 L F
.57134 .85153 m .57073 .8549 L .57121 .86431 L 0 .074 .146 r
F
.57134 .85153 m .57121 .86431 L .57195 .86576 L F
.56548 .84845 m .57142 .80708 L .56814 .83421 L 0 .103 .125 r
F
.56546 .84844 m .57142 .80708 L .56548 .84845 L F
.56538 .84893 m .57142 .80708 L .56539 .84894 L F
.56504 .84898 m .57142 .80708 L .56535 .84911 L F
.56306 .85896 m .56467 .84902 L .56356 .85873 L F
.56467 .84902 m .57142 .80708 L .56501 .84915 L F
.56467 .84902 m .56501 .84915 L .56356 .85873 L F
.57279 .86741 m .5728 .86726 L .57279 .86741 L 0 .076 .128 r
F
.57323 .86839 m .57291 .86609 L .57328 .8685 L F
.57218 .85191 m .57279 .86737 L .57326 .86819 L 0 .074 .146 r
F
.57122 .84132 m .57136 .82546 L .57463 .77963 L 0 .009 .114 r
F
.57122 .84132 m .57836 .76795 L .57425 .81643 L F
.56943 .83414 m .56686 .84286 L .57157 .84687 L 0 .855 .44 r
F
.56744 .86238 m .57136 .82546 L .57122 .84132 L 0 .141 .14 r
F
.56267 .85947 m .57297 .96906 L .56289 .85973 L 0 .158 .185 r
F
.56744 .86238 m .56719 .87225 L .56837 .8709 L 0 .179 .191 r
F
.56617 .86129 m .57136 .82546 L .56744 .86238 L 0 .141 .14 r
F
.56699 .85823 m .56704 .86204 L .56744 .86238 L 0 .179 .191 r
F
.56704 .86208 m .56719 .87225 L .56744 .86238 L F
.56617 .86129 m .56617 .86129 L .56744 .86238 L 0 .141 .14 r
F
.56617 .86129 m .56814 .83421 L .57136 .82546 L F
.56744 .86238 m .56867 .86332 L .56867 .86333 L F
.56782 .86592 m .56888 .86595 L .56867 .86333 L 0 .179 .191 r
F
.56782 .86592 m .56867 .86333 L .56855 .86324 L F
.56782 .86592 m .56864 .86293 L .56777 .86236 L F
.56744 .86238 m .56782 .86592 L .56778 .86267 L F
.56744 .86238 m .56867 .86333 L .56779 .87091 L 0 .141 .14 r
F
.56744 .86238 m .57122 .84132 L .56867 .86332 L F
.56855 .86324 m .56867 .86333 L .56864 .86293 L 0 .179 .191 r
F
.56777 .86236 m .56864 .86293 L .56761 .85004 L F
.56506 .86055 m .56878 .90738 L .56617 .86141 L F
.56506 .86055 m .56617 .86141 L .56617 .86129 L F
.56617 .86129 m .56878 .90738 L .57231 .92704 L F
.56617 .86129 m .56719 .87225 L .56704 .86187 L F
.56719 .87225 m .57231 .92704 L .56837 .8709 L F
.56295 .85969 m .57297 .96906 L .57281 .95567 L 0 .158 .185 r
F
.56288 .85964 m .57297 .96906 L .56295 .85969 L F
.55696 .90175 m .55885 .90642 L .56063 .90371 L 0 1 .445 r
F
.55696 .90175 m .56063 .90371 L .55983 .90171 L F
.55885 .90642 m .56262 .90916 L .56183 .90691 L 0 1 .5 r
F
.55507 .89846 m .55696 .90175 L .55863 .89898 L 0 1 .228 r
F
.55507 .89846 m .55863 .89898 L .55784 .89734 L F
.5571 .89668 m .55978 .90719 L .56429 .90543 L 0 .982 .458 r
F
.5571 .89668 m .56429 .90543 L .56309 .90117 L F
.56356 .85873 m .56504 .84898 L .56535 .84911 L 0 .103 .125 r
F
.56184 .85919 m .56189 .85869 L .56234 .8593 L F
.56189 .85869 m .56358 .84016 L .56234 .8593 L F
.56343 .86078 m .57281 .95567 L .56878 .90738 L 0 .158 .185 r
F
.56333 .85993 m .56306 .85896 L .56356 .85873 L 0 .103 .125 r
F
.56333 .85993 m .563 .8602 L .56343 .86078 L 0 .158 .185 r
F
.56295 .85969 m .563 .8602 L .56333 .85993 L F
.563 .8602 m .57281 .95567 L .56343 .86078 L F
.56238 .86811 m .55522 .87423 L .5605 .87804 L 0 .989 .461 r
F
.54897 .87909 m .54815 .88129 L .5507 .87082 L 0 1 .323 r
F
.55946 .86386 m .54838 .87579 L .55457 .87183 L 0 1 .345 r
F
.56238 .86811 m .55396 .86994 L .55522 .87423 L 0 .989 .461 r
F
.56238 .86811 m .55703 .86732 L .55396 .86994 L F
.55946 .86386 m .54762 .87494 L .54838 .87579 L 0 1 .345 r
F
.55946 .86386 m .55237 .86983 L .54762 .87494 L F
.55685 .86134 m .55237 .86983 L .55946 .86386 L 0 1 .388 r
F
.55847 .85709 m .55703 .86732 L .56238 .86811 L 0 .978 .458 r
F
.56586 .86338 m .56506 .86056 L .56617 .86129 L 0 .141 .14 r
F
.56234 .8593 m .56802 .81248 L .56265 .85921 L 0 .103 .125 r
F
.56267 .85947 m .56916 .94141 L .57297 .96906 L 0 .158 .185 r
F
.56243 .85694 m .56263 .85945 L .56267 .85947 L F
.56263 .85945 m .56916 .94141 L .56267 .85947 L F
.56234 .8593 m .56265 .85921 L .56262 .85945 L 0 .103 .125 r
F
.5601 .8623 m .56916 .94141 L .564 .8918 L 0 .142 .182 r
F
.56635 .97498 m .57149 .97294 L .57347 .97358 L 0 0 0 r
F
.56635 .97498 m .57347 .97358 L .57129 .9745 L F
.57074 .97905 m .568 .97595 L .57277 .97546 L F
.5601 .8623 m .57295 .98334 L .56916 .94141 L 0 .142 .182 r
F
.57149 .97294 m .56601 .97225 L .57118 .97159 L 0 0 0 r
F
.57149 .97294 m .56433 .97273 L .56601 .97225 L F
.57149 .97294 m .56668 .97302 L .56433 .97273 L F
.56635 .97498 m .56668 .97302 L .57149 .97294 L F
.57251 .98576 m .56899 .98215 L .5716 .98072 L 0 .034 0 r
F
.57251 .98576 m .56937 .98431 L .56899 .98215 L F
.5601 .8623 m .57278 .98896 L .57295 .98334 L 0 .142 .182 r
F
.56516 .93067 m .55949 .95164 L .56789 .94749 L 0 .741 .33 r
F
.56705 .97133 m .56448 .97147 L .57073 .97054 L 0 0 0 r
F
.5601 .8623 m .56878 .95854 L .57278 .98896 L 0 .142 .182 r
F
.5601 .8623 m .56369 .91293 L .56878 .95854 L F
.5601 .8623 m .56 .87192 L .56369 .91293 L F
.56028 .87624 m .56025 .86757 L .56098 .86154 L 0 .103 .125 r
F
.56184 .85919 m .56128 .85906 L .564 .8918 L 0 .158 .185 r
F
.56179 .85978 m .56123 .85945 L .56128 .85906 L 0 .103 .125 r
F
.56184 .85919 m .56128 .85906 L .56358 .84016 L F
.56179 .85978 m .56128 .85906 L .56184 .85919 L F
.56006 .85673 m .55984 .85093 L .56301 .82721 L 0 .065 .114 r
F
.55994 .83041 m .56007 .8445 L .56128 .85906 L 0 .158 .185 r
F
.55994 .83041 m .56128 .85906 L .56184 .85919 L F
.56267 .85947 m .56802 .81248 L .57137 .79838 L 0 .103 .125 r
F
.56305 .85903 m .56451 .84837 L .56476 .84842 L F
.56343 .86078 m .56878 .90738 L .56406 .86116 L 0 .158 .185 r
F
.56234 .8593 m .56916 .94141 L .56263 .85945 L F
.56243 .85693 m .56249 .8578 L .56243 .85694 L F
.56249 .8578 m .56916 .94141 L .5625 .8578 L F
.56249 .8578 m .5625 .8578 L .56243 .85694 L F
.56343 .86078 m .56406 .86116 L .56396 .86015 L F
.56333 .85993 m .56814 .83421 L .56396 .86015 L 0 .103 .125 r
F
.56349 .85963 m .56396 .86015 L .56364 .85708 L 0 .158 .185 r
F
.56343 .86078 m .56396 .86015 L .56349 .85963 L F
.55319 .89888 m .55507 .89846 L .55663 .89454 L 0 0 .023 r
F
.55319 .89888 m .55663 .89454 L .55583 .89244 L F
.5544 .8865 m .5571 .89668 L .56128 .89487 L 0 1 .463 r
F
.5544 .8865 m .56128 .89487 L .56008 .89074 L F
.55967 .88362 m .56878 .95854 L .56369 .91293 L 0 .128 .18 r
F
.55098 .93376 m .53997 .94213 L .55231 .94002 L 0 1 .534 r
F
.55098 .93376 m .56108 .93652 L .56042 .93397 L F
.55095 .928 m .53052 .93885 L .53995 .93926 L 0 1 .493 r
F
.55098 .93376 m .53053 .94193 L .53997 .94213 L 0 1 .534 r
F
.55095 .928 m .53028 .93544 L .53052 .93885 L 0 1 .493 r
F
.55098 .93376 m .53029 .93953 L .53053 .94193 L 0 1 .534 r
F
.55095 .928 m .53904 .93078 L .53028 .93544 L 0 1 .493 r
F
.5496 .91927 m .53904 .93078 L .55095 .928 L 0 1 .488 r
F
.55098 .93376 m .53906 .93603 L .53029 .93953 L 0 1 .534 r
F
.54965 .92767 m .55098 .93376 L .55943 .93019 L F
.54965 .92767 m .53906 .93603 L .55098 .93376 L F
.52111 .93497 m .53052 .93885 L .53028 .93544 L 0 1 .496 r
F
.54965 .92767 m .52994 .936 L .53906 .93603 L 0 1 .534 r
F
.54965 .92767 m .5297 .9337 L .52994 .936 L F
.5496 .91927 m .52992 .93021 L .53904 .93078 L 0 1 .488 r
F
.54965 .92767 m .53815 .93012 L .5297 .9337 L 0 1 .534 r
F
.54832 .92185 m .53815 .93012 L .54965 .92767 L 0 1 .533 r
F
.5534 .93558 m .54898 .92678 L .54971 .93773 L 0 .142 .208 r
F
.55342 .93557 m .55335 .93541 L .5534 .93558 L F
.55335 .93541 m .54898 .92678 L .5534 .93558 L F
.54965 .92767 m .55943 .93019 L .55877 .9277 L 0 1 .534 r
F
.54832 .92185 m .54965 .92767 L .55778 .92404 L 0 1 .533 r
F
.52083 .92616 m .52111 .93497 L .52992 .93021 L 0 1 .491 r
F
.52083 .92616 m .52992 .93021 L .52968 .92666 L F
.5496 .91927 m .52968 .92666 L .52992 .93021 L 0 1 .488 r
F
.54832 .92185 m .52934 .93033 L .53815 .93012 L 0 1 .533 r
F
.54832 .92185 m .5291 .92815 L .52934 .93033 L F
.54832 .92185 m .53723 .92451 L .5291 .92815 L F
.5496 .91927 m .53812 .92197 L .52968 .92666 L 0 1 .488 r
F
.54698 .91642 m .53723 .92451 L .54832 .92185 L 0 1 .528 r
F
.5417 .92238 m .5497 .93763 L .54897 .92656 L 0 1 .421 r
F
.55342 .93557 m .55057 .92585 L .54898 .92678 L 0 .142 .208 r
F
.55342 .93565 m .54971 .93773 L .55246 .94752 L F
.55342 .93557 m .5534 .93558 L .55342 .93565 L F
.5534 .93558 m .54971 .93773 L .55342 .93565 L F
.55116 .94726 m .54784 .92211 L .54903 .92374 L 0 .769 .079 r
F
.55063 .92807 m .54903 .92374 L .55057 .92583 L F
.55116 .94726 m .54903 .92374 L .55063 .92807 L F
.55057 .92584 m .55057 .92583 L .55057 .92583 L F
.55116 .94726 m .55057 .92583 L .55057 .92584 L F
.55116 .94726 m .55057 .92583 L .55342 .93556 L F
.55116 .94726 m .55342 .93556 L .55486 .94635 L F
.56516 .93067 m .55175 .93573 L .55257 .9466 L 0 .741 .33 r
F
.56516 .93067 m .55714 .92891 L .55175 .93573 L F
.56247 .91836 m .55714 .92891 L .56516 .93067 L 0 .903 .421 r
F
.55116 .94726 m .55486 .94635 L .5539 .951 L 0 .769 .079 r
F
.56516 .93067 m .55257 .9466 L .55949 .95164 L 0 .741 .33 r
F
.57074 .97905 m .56581 .97694 L .568 .97595 L 0 0 0 r
F
.57074 .97905 m .56698 .97827 L .56581 .97694 L F
.57177 .99514 m .56959 .98987 L .57261 .98814 L 0 .181 .042 r
F
.55967 .88362 m .57229 .99375 L .56878 .95854 L 0 .128 .18 r
F
.55967 .88362 m .57181 .99453 L .57229 .99375 L F
.56547 .9683 m .55953 .95775 L .56801 .96133 L 0 .223 .103 r
F
.55967 .88362 m .5677 .96448 L .57181 .99453 L 0 .128 .18 r
F
.54832 .92185 m .55778 .92404 L .55712 .92165 L 0 1 .533 r
F
.56247 .91836 m .55054 .92373 L .55714 .92891 L 0 .903 .421 r
F
.56075 .91186 m .55614 .91817 L .5592 .91896 L 0 1 .516 r
F
.54698 .91642 m .54832 .92185 L .55613 .91817 L 0 1 .528 r
F
.56247 .91836 m .54975 .91859 L .55054 .92373 L 0 .903 .421 r
F
.56075 .91186 m .55547 .91592 L .55614 .91817 L 0 1 .516 r
F
.54698 .91642 m .55613 .91817 L .55547 .91593 L 0 1 .528 r
F
.56247 .91836 m .55486 .91628 L .54975 .91859 L 0 .903 .421 r
F
.56075 .91186 m .55745 .91322 L .55547 .91592 L 0 1 .516 r
F
.55885 .90642 m .55745 .91322 L .56075 .91186 L 0 1 .5 r
F
.55885 .90642 m .55448 .91274 L .55745 .91322 L F
.55978 .90719 m .55486 .91628 L .56247 .91836 L 0 .953 .447 r
F
.55967 .88362 m .56276 .92406 L .5677 .96448 L 0 .128 .18 r
F
.55967 .88362 m .55934 .88959 L .56276 .92406 L F
.56005 .90347 m .56368 .86186 L .56396 .86015 L 0 .141 .14 r
F
.56396 .86016 m .56396 .86015 L .56396 .86011 L F
.56506 .86055 m .56396 .86011 L .56814 .83421 L F
.56506 .86055 m .56396 .86015 L .56878 .90738 L 0 .179 .191 r
F
.56494 .86164 m .56401 .86018 L .56506 .86055 L 0 .141 .14 r
F
.56401 .86018 m .56396 .86011 L .56506 .86055 L F
.56506 .86055 m .56814 .83421 L .56617 .86129 L F
.56567 .86077 m .56506 .86055 L .56568 .86097 L 0 .179 .191 r
F
.55918 .78652 m .56506 .86055 L .56567 .86077 L F
.56506 .86055 m .5639 .85965 L .56396 .86015 L F
.56396 .86016 m .56396 .86015 L .56396 .86016 L 0 .141 .14 r
F
.56005 .90347 m .56396 .86015 L .56396 .86016 L F
.56005 .90347 m .56396 .86011 L .56494 .86164 L F
.56028 .87624 m .56333 .85993 L .56368 .86186 L 0 .103 .125 r
F
.56333 .85993 m .56343 .86078 L .56347 .85998 L 0 .158 .185 r
F
.56333 .85993 m .56396 .86015 L .56368 .86186 L 0 .103 .125 r
F
.55994 .83041 m .56333 .85993 L .56364 .85708 L 0 .158 .185 r
F
.56333 .85993 m .56347 .85998 L .56364 .85708 L F
.56163 .86146 m .56098 .86154 L .56123 .85945 L 0 .103 .125 r
F
.56163 .86146 m .56123 .85945 L .56179 .85978 L F
.56028 .87624 m .56098 .86154 L .56163 .86146 L F
.56613 .86091 m .56568 .86097 L .56617 .86129 L 0 .179 .191 r
F
.56476 .84842 m .5648 .8481 L .56481 .8481 L 0 .103 .125 r
F
.55918 .78652 m .56568 .86097 L .56613 .86091 L 0 .179 .191 r
F
.56206 .85596 m .56234 .8593 L .5624 .85663 L 0 .158 .185 r
F
.56234 .8593 m .56263 .85945 L .5624 .85663 L F
.56242 .8612 m .56262 .85945 L .56267 .85947 L 0 .103 .125 r
F
.56262 .85945 m .56263 .85942 L .56267 .85947 L F
.56234 .8593 m .56262 .85945 L .56242 .86119 L F
.56005 .90347 m .56494 .86164 L .56586 .86338 L 0 .141 .14 r
F
.56494 .86164 m .56506 .86056 L .56586 .86338 L F
.5624 .85663 m .56243 .85693 L .56243 .85694 L 0 .158 .185 r
F
.55994 .83041 m .56206 .85596 L .5624 .85663 L F
.56005 .90347 m .56688 .86548 L .56779 .87091 L 0 .141 .14 r
F
.56688 .86548 m .56744 .86239 L .56762 .86695 L F
.56688 .86548 m .56762 .86695 L .56779 .87091 L F
.56028 .87624 m .56295 .85969 L .56333 .85993 L 0 .103 .125 r
F
.56295 .85969 m .56306 .85896 L .56333 .85993 L F
.56295 .85969 m .56304 .85905 L .56305 .85903 L F
.55994 .83041 m .56295 .85969 L .56333 .85993 L 0 .158 .185 r
F
.55918 .78652 m .56364 .85708 L .5639 .85965 L 0 .179 .191 r
F
.55918 .78652 m .5639 .85965 L .56506 .86055 L F
.56744 .86239 m .56744 .86238 L .56744 .8624 L 0 .141 .14 r
F
.56744 .86239 m .56744 .8624 L .56779 .87091 L F
.56744 .86238 m .56744 .86238 L .56744 .86238 L F
.56744 .86238 m .56744 .86238 L .56779 .87091 L F
.56506 .86056 m .56506 .86055 L .56617 .86129 L F
.56594 .85891 m .56617 .86129 L .56699 .85823 L 0 .179 .191 r
F
.56617 .86129 m .56704 .86187 L .56699 .85823 L F
.56704 .86204 m .56704 .86208 L .56744 .86238 L F
.56005 .90347 m .56617 .86129 L .56744 .86238 L 0 .141 .14 r
F
.56699 .85823 m .56744 .86238 L .56771 .85776 L 0 .179 .191 r
F
.56744 .86238 m .56778 .86267 L .56771 .85776 L F
.56985 .8165 m .57189 .8518 L .57218 .85191 L 0 .074 .146 r
F
.57189 .8518 m .57279 .86737 L .57218 .85191 L F
.56985 .8165 m .57065 .85117 L .57134 .85153 L F
.57065 .85117 m .57073 .8549 L .57134 .85153 L F
.56539 .84894 m .56546 .84844 L .56548 .84845 L 0 .103 .125 r
F
.56535 .84911 m .56538 .84893 L .56539 .84894 L F
.56985 .8165 m .57163 .85168 L .57189 .8518 L 0 .074 .146 r
F
.57239 .86666 m .57239 .86663 L .57279 .86737 L 0 .076 .128 r
F
.57411 .87025 m .57765 .84394 L .57484 .87137 L F
.57411 .87025 m .57484 .87142 L .57481 .87102 L 0 .074 .146 r
F
.57411 .87025 m .57652 .83484 L .57765 .84394 L 0 .076 .128 r
F
.57409 .86968 m .57481 .87102 L .5734 .85026 L 0 .074 .146 r
F
.57411 .87025 m .57481 .87102 L .57409 .86968 L F
.57406 .86963 m .57328 .8685 L .57411 .87025 L F
.57267 .85211 m .57327 .86821 L .57406 .86963 L F
.57327 .86821 m .57328 .8685 L .57406 .86963 L F
.56985 .8165 m .57218 .85191 L .57267 .85211 L F
.57218 .85191 m .57328 .8685 L .57267 .85211 L F
.56028 .87624 m .56184 .85919 L .56234 .8593 L 0 .103 .125 r
F
.55994 .83041 m .56184 .85919 L .56234 .8593 L 0 .158 .185 r
F
.56208 .86141 m .56234 .8593 L .56242 .86119 L 0 .103 .125 r
F
.56208 .86142 m .56208 .86141 L .56242 .8612 L F
.56208 .86141 m .56242 .86119 L .56242 .8612 L F
.55918 .78652 m .56699 .85823 L .56761 .85004 L 0 .179 .191 r
F
.56699 .85823 m .56771 .85776 L .56761 .85004 L F
.56217 .85413 m .56267 .85947 L .56236 .85395 L 0 .158 .185 r
F
.56267 .85947 m .56289 .85973 L .56236 .85395 L F
.56028 .87624 m .56208 .86142 L .56242 .8612 L 0 .103 .125 r
F
.55918 .78652 m .56594 .85891 L .56699 .85823 L 0 .179 .191 r
F
.57194 .8668 m .57127 .86549 L .57197 .8662 L 0 .076 .128 r
F
.57058 .89657 m .57122 .86763 L .57194 .8668 L F
.57122 .86763 m .57127 .86549 L .57194 .8668 L F
.57058 .89657 m .57089 .87175 L .57113 .86773 L F
.57122 .86763 m .57113 .86773 L .57127 .86549 L F
.57058 .89657 m .57113 .86773 L .57122 .86763 L F
.57193 .86523 m .57197 .8662 L .57218 .86587 L 0 .074 .146 r
F
.57197 .8662 m .5722 .86644 L .57218 .86587 L F
.57127 .84985 m .57193 .86523 L .57154 .84992 L F
.57193 .86523 m .57218 .86587 L .57154 .84992 L F
.57155 .8837 m .57279 .86741 L .57158 .88362 L 0 .076 .128 r
F
.57279 .86741 m .57279 .86741 L .57158 .88362 L F
.57251 .85007 m .57393 .86792 L .5734 .85026 L 0 .074 .146 r
F
.57393 .86792 m .57411 .87025 L .57403 .86802 L F
.57393 .86792 m .57403 .86802 L .5734 .85026 L F
.57058 .89657 m .57197 .8662 L .57239 .86663 L 0 .076 .128 r
F
.57219 .86618 m .5722 .86644 L .57238 .86662 L 0 .074 .146 r
F
.5722 .86644 m .57238 .86663 L .57238 .86662 L F
.57218 .86587 m .57219 .86618 L .57238 .86637 L F
.57219 .86618 m .57238 .86662 L .57238 .86637 L F
.57408 .87049 m .57328 .8685 L .57411 .87025 L 0 .076 .128 r
F
.57058 .89657 m .57327 .86864 L .57408 .87049 L F
.57327 .86864 m .57328 .8685 L .57408 .87049 L F
.57652 .83484 m .57771 .84293 L .57765 .84394 L F
.57884 .8779 m .57838 .90682 L .57973 .89127 L 0 .146 .172 r
F
.5782 .8768 m .57838 .90682 L .57884 .8779 L F
.57838 .90682 m .57849 .92539 L .57973 .89127 L F
.57179 .90237 m .57231 .92704 L .57688 1.00615 L 0 .02 .129 r
F
.56946 .97338 m .57349 .88455 L .57484 .87142 L 0 .16 .157 r
F
.57583 .87275 m .57484 .87142 L .57765 .84394 L F
.57583 .87275 m .57484 .87142 L .57849 .92539 L 0 .146 .172 r
F
.56946 .97338 m .57484 .87142 L .57583 .87275 L 0 .16 .157 r
F
.57583 .87275 m .57447 .86599 L .57484 .87142 L 0 .146 .172 r
F
.57557 .86762 m .57382 .85634 L .57447 .86599 L F
.57557 .86762 m .57447 .86599 L .57583 .87275 L F
.57583 .87275 m .57765 .84394 L .57884 .8779 L 0 .16 .157 r
F
.57085 .76767 m .57145 .76608 L .57131 .76537 L 0 .626 .341 r
F
.57079 .76798 m .57145 .76608 L .57085 .76767 L F
.56423 .74898 m .57079 .76798 L .57131 .76537 L F
.56898 .78205 m .56828 .7834 L .57087 .76976 L 0 0 .024 r
F
.56704 .69903 m .57584 .87303 L .57814 .8673 L 0 .146 .172 r
F
.57584 .87303 m .57849 .92539 L .5782 .87586 L F
.57665 .87102 m .5782 .87586 L .57814 .8673 L F
.57584 .87303 m .5782 .87586 L .57665 .87102 L F
.57884 .8779 m .57765 .84394 L .5779 .84537 L 0 .16 .157 r
F
.57884 .8779 m .5779 .84537 L .5797 .86917 L F
.57814 .8673 m .57884 .8779 L .5795 .86224 L 0 .146 .172 r
F
.57884 .8779 m .57973 .89127 L .57963 .87932 L F
.57884 .8779 m .58054 .86062 L .58046 .88082 L 0 .16 .157 r
F
.57884 .8779 m .57963 .87932 L .5795 .86224 L 0 .146 .172 r
F
.57973 .89127 m .58046 .88082 L .57913 .81554 L F
.57884 .8779 m .58046 .88082 L .58045 .88293 L 0 .16 .157 r
F
.57819 .88451 m .57884 .8779 L .58038 .89861 L F
.57884 .8779 m .58045 .88293 L .58038 .89861 L F
.57819 .88451 m .57583 .87275 L .57884 .8779 L F
.56946 .97338 m .57583 .87275 L .57819 .88451 L F
.57281 .95567 m .57297 .96906 L .57718 1.02926 L 0 0 .123 r
F
.56946 .97338 m .57819 .88451 L .58028 .92423 L 0 .16 .157 r
F
.57819 .88451 m .58038 .89861 L .58028 .92423 L F
.57464 .84922 m .5734 .85026 L .57382 .85634 L 0 .146 .172 r
F
.57464 .84922 m .57382 .85634 L .57557 .86762 L F
.58035 .86093 m .58041 .87852 L .58092 .88224 L 0 0 .116 r
F
.57913 .81554 m .58 .85859 L .58035 .86093 L F
.58 .85859 m .58041 .87852 L .58035 .86093 L F
.58041 .87852 m .58046 .88082 L .58062 .88133 L F
.58041 .87852 m .58062 .88133 L .58092 .88224 L F
.57814 .8673 m .5782 .8768 L .57884 .8779 L 0 .146 .172 r
F
.58028 .92423 m .58111 .87531 L .58132 .87291 L 0 0 .116 r
F
.5811 .88281 m .5812 .88652 L .58122 .88664 L F
.58028 .92423 m .58112 .88332 L .58139 .88434 L F
.58141 .8849 m .58139 .88434 L .58113 .88289 L F
.58113 .88289 m .58117 .88114 L .58139 .88434 L F
.58139 .88434 m .58134 .88283 L .58113 .88289 L F
.58112 .88332 m .58113 .88289 L .58139 .88434 L F
.57943 1.12447 m .58281 .91469 L .58291 .91247 L 0 .145 .158 r
F
.58297 .91268 m .58291 .91247 L .58301 .91037 L F
.57943 1.12447 m .58291 .91247 L .58297 .91268 L F
.57058 .89657 m .57408 .87049 L .57349 .88455 L 0 .076 .128 r
F
.57408 .87049 m .57411 .87025 L .5741 .87053 L F
.57408 .87049 m .5741 .87053 L .57349 .88455 L F
.57071 .89516 m .57281 .86746 L .57327 .86864 L F
.57154 .84992 m .57218 .86587 L .57238 .86637 L 0 .074 .146 r
F
.56985 .8165 m .57127 .84985 L .57154 .84992 L F
.56985 .8165 m .57251 .85007 L .57312 .84611 L F
.57251 .85007 m .5734 .85026 L .57312 .84611 L F
.55731 .70747 m .56851 .7301 L .56561 .71992 L 0 .65 .314 r
F
.55731 .70747 m .56784 .73464 L .56851 .7301 L F
.56704 .69903 m .57312 .84611 L .5734 .85026 L 0 .146 .172 r
F
.56704 .69903 m .5734 .85026 L .57464 .84922 L F
.56028 .87624 m .56267 .85947 L .56295 .85969 L 0 .103 .125 r
F
.56236 .85395 m .56288 .85964 L .56295 .85969 L 0 .158 .185 r
F
.55994 .83041 m .56217 .85413 L .56236 .85395 L F
.57067 .89531 m .57155 .8837 L .57071 .89516 L 0 .076 .128 r
F
.57155 .8837 m .57158 .88362 L .57071 .89516 L F
.58094 .78902 m .58372 .70656 L .5832 .73246 L 0 0 .1 r
F
.58341 .6903 m .58345 .68973 L .58345 .68879 L 0 0 .064 r
F
.58341 .6903 m .58345 .68879 L .58345 .68862 L F
.58341 .6903 m .5835 .69092 L .58346 .68762 L 0 .238 .224 r
F
.58347 .68593 m .58362 .68678 L .5835 .68369 L F
.58347 .68593 m .58348 .68778 L .58362 .68678 L F
.58094 .78902 m .58383 .67743 L .58387 .67728 L 0 0 .1 r
F
.5832 .6941 m .58341 .6903 L .58321 .6929 L 0 0 .064 r
F
.58094 .78902 m .58121 .75633 L .58379 .67795 L 0 0 .1 r
F
.58094 .78902 m .58379 .67795 L .58379 .67794 L F
.58094 .78902 m .5838 .67755 L .58383 .67743 L F
.58094 .78902 m .58357 .7087 L .58366 .70791 L F
.57932 .72562 m .57961 .7226 L .57972 .72259 L 0 0 .101 r
F
.57881 .72495 m .57904 .72324 L .57876 .72585 L 0 0 .081 r
F
.57931 .72076 m .57959 .71879 L .57876 .72585 L F
.5793 .7208 m .57931 .72076 L .57876 .72585 L F
.57914 .72184 m .57932 .72054 L .57933 .71972 L 0 .421 .28 r
F
.57899 .72339 m .57932 .72054 L .57914 .72184 L F
.57899 .72339 m .57933 .71972 L .57866 .7167 L F
.58075 .70505 m .58092 .70335 L .57832 .69072 L 0 .396 .268 r
F
.58094 .78902 m .58323 .72104 L .58312 .72383 L 0 0 .1 r
F
.58094 .78902 m .58312 .72383 L .58296 .729 L F
.57336 .52632 m .58275 .87494 L .58411 .87836 L 0 .09 .148 r
F
.57058 .89657 m .57067 .89531 L .57071 .89516 L 0 .076 .128 r
F
.56704 .69903 m .57814 .8673 L .57913 .81554 L 0 .146 .172 r
F
.57814 .8673 m .5795 .86224 L .57913 .81554 L F
.58028 .92423 m .58115 .88113 L .58117 .88114 L 0 0 .116 r
F
.57913 .81554 m .5811 .88281 L .58113 .88289 L F
.5809 .8832 m .58089 .88214 L .58092 .88224 L F
.58089 .88382 m .58089 .88322 L .5809 .8832 L F
.58258 .89194 m .58179 .88699 L .58261 .89153 L F
.58211 .88156 m .58179 .88699 L .58258 .89194 L F
.57913 .81554 m .58161 .88224 L .58211 .88156 L F
.58161 .88224 m .58179 .88699 L .58211 .88156 L F
.58138 .88276 m .58161 .88224 L .57913 .81554 L F
.58028 .92423 m .58044 .88482 L .58089 .88382 L F
.58091 .88295 m .58092 .88224 L .58098 .88293 L F
.58092 .88224 m .58099 .88245 L .58098 .88293 L F
.58089 .88382 m .58091 .88295 L .58097 .88366 L F
.58091 .88295 m .58098 .88293 L .58097 .88366 L F
.58134 .88283 m .57913 .81554 L .58113 .88289 L F
.58028 .92423 m .58177 .8875 L .58251 .89289 L F
.58177 .8875 m .58179 .88699 L .58251 .89289 L F
.59073 1.01454 m .59066 1.00328 L .59067 1.00308 L 0 0 .08 r
F
.59175 1.22243 m .59072 1.01471 L .59073 1.01454 L F
.59072 1.01471 m .59066 1.00328 L .59073 1.01454 L F
.59066 1.00328 m .58898 .66271 L .59067 1.00308 L F
.58258 .89194 m .58264 .89329 L .58263 .89231 L 0 0 .116 r
F
.58234 .89526 m .58258 .89194 L .58336 .90301 L F
.59175 1.22243 m .5907 1.00139 L .59072 1.00072 L 0 0 .08 r
F
.5907 1.00139 m .59067 .99419 L .59072 1.00072 L F
.58916 1.07678 m .58956 1.05734 L .58855 1.02391 L 0 0 .116 r
F
.5915 .93982 m .59175 1.22243 L .5906 .92909 L 0 0 .08 r
F
.5915 .93982 m .59273 .95439 L .59152 .96221 L F
.59458 1.05268 m .59589 1.03496 L .60032 1.02983 L 0 .334 .132 r
F
.59948 1.35151 m .59963 1.3018 L .60344 1.26313 L 0 .474 .207 r
F
.60191 1.38933 m .59948 1.35151 L .60333 1.38942 L F
.60168 1.3814 m .59273 .95439 L .59843 1.38248 L 0 0 .073 r
F
.59273 .95439 m .59054 .85023 L .59195 .94513 L F
.58445 .71832 m .58608 .63786 L .5845 .71945 L 0 0 .116 r
F
.58606 .63809 m .58608 .63786 L .58607 .63793 L 0 0 .1 r
F
.58601 .63869 m .58608 .63786 L .58606 .63809 L F
.58619 .63723 m .58608 .63786 L .5862 .63691 L 0 0 .116 r
F
.5823 .62632 m .58596 .63846 L .58241 .61836 L 0 .238 .216 r
F
.58596 .63846 m .58607 .63791 L .58241 .61836 L F
.58445 .71832 m .58396 .70758 L .58608 .63786 L 0 0 .116 r
F
.59175 1.22243 m .58894 .65118 L .589 .65066 L 0 0 .08 r
F
.58958 .66754 m .5906 .92909 L .58922 .66981 L F
.5906 .92909 m .59053 .9283 L .58889 .60682 L F
.59082 .98583 m .59068 .99343 L .58889 .60682 L F
.59054 .85023 m .58927 .78969 L .5906 .92909 L 0 0 .073 r
F
.58652 .64005 m .58651 .64019 L .58656 .64044 L 0 .27 .221 r
F
.58651 .64027 m .58656 .64044 L .58651 .64019 L 0 .238 .216 r
F
.58718 .64537 m .5874 .64308 L .58718 .64529 L 0 0 .001 r
F
.58678 .64333 m .5874 .64308 L .58716 .63884 L F
.58532 .74334 m .58631 .63643 L .58856 .62704 L 0 0 .116 r
F
.57673 .5446 m .58187 .61546 L .58603 .63762 L 0 .27 .221 r
F
.5762 .53925 m .57669 .54593 L .57673 .5446 L F
.57669 .54593 m .58187 .61546 L .57673 .5446 L F
.57989 .3717 m .58006 .42596 L .57987 .40706 L 0 0 .075 r
F
.57673 .5445 m .58603 .63762 L .58618 .63697 L 0 .27 .221 r
F
.5762 .53925 m .57673 .5446 L .57673 .5445 L F
.57673 .5446 m .58603 .63762 L .57673 .5445 L F
.58011 .35992 m .58024 .41963 L .57989 .3717 L 0 0 .075 r
F
.58749 .59503 m .58753 .5939 L .58749 .59503 L 0 0 .1 r
F
.58729 .56376 m .5853 .57532 L .58646 .58845 L 0 1 .307 r
F
.5762 .53925 m .58865 .60728 L .58679 .53942 L 0 .27 .221 r
F
.57904 .6155 m .58383 .64202 L .58398 .63188 L 0 .238 .216 r
F
.58648 .78084 m .58713 .80094 L .58638 .83872 L 0 0 .116 r
F
.5762 .53925 m .57673 .5445 L .57673 .54449 L 0 .27 .221 r
F
.58241 .61836 m .58241 .61835 L .58187 .61546 L 0 .238 .216 r
F
.5823 .62632 m .58241 .61836 L .58187 .61546 L F
.58492 .67122 m .5848 .67448 L .5848 .67451 L 0 0 .1 r
F
.58406 .69648 m .58447 .68443 L .58406 .69633 L F
.58447 .68443 m .58492 .67122 L .58447 .68425 L F
.58512 .66517 m .58487 .6726 L .58487 .67266 L F
.58499 .66908 m .58492 .671 L .58492 .67118 L F
.58512 .66508 m .58487 .6726 L .58512 .66517 L F
.58492 .67122 m .58499 .66908 L .58492 .67118 L F
.58559 .65119 m .58536 .65789 L .58536 .65797 L F
.58545 .65535 m .58546 .65524 L .58499 .66905 L F
.58545 .65535 m .58499 .66905 L .58499 .66905 L F
.58512 .66514 m .58512 .66514 L .58511 .66537 L F
.58511 .66539 m .58511 .66537 L .58487 .6726 L F
.58499 .66908 m .58545 .65535 L .58499 .66905 L F
.58372 .70656 m .58601 .63869 L .58395 .70754 L F
.58372 .70656 m .58395 .70754 L .5832 .73246 L F
.58601 .63869 m .58607 .63793 L .58396 .70758 L F
.58395 .70754 m .58396 .70758 L .5832 .73246 L F
.58601 .63869 m .58396 .70758 L .58395 .70754 L F
.58984 .88499 m .587 .72059 L .58949 .87413 L 0 0 .073 r
F
.58548 .65362 m .5857 .64693 L .58554 .65255 L 0 0 .1 r
F
.5857 .64693 m .58589 .64185 L .58554 .65255 L F
.587 .72059 m .58316 .49824 L .5869 .72015 L 0 0 .073 r
F
.587 .72059 m .5869 .72015 L .58949 .87413 L F
.58383 .64202 m .58475 .65409 L .58515 .64927 L 0 .238 .216 r
F
.58523 .66173 m .58547 .65453 L .58519 .66167 L 0 0 .1 r
F
.58547 .65453 m .58552 .65224 L .58519 .66167 L F
.58554 .65143 m .58558 .65032 L .58556 .65015 L 0 .238 .216 r
F
.58465 .67841 m .58466 .67825 L .58436 .6875 L 0 0 .1 r
F
.5848 .67451 m .5848 .67448 L .58312 .72383 L F
.58447 .68422 m .58447 .68412 L .58429 .68953 L F
.58429 .68961 m .58429 .68953 L .58312 .72383 L F
.58447 .68422 m .58429 .68953 L .58429 .68961 L F
.58481 .67431 m .58481 .67406 L .58312 .72383 L F
.58441 .68623 m .58451 .68251 L .58455 .68206 L F
.58429 .68977 m .58429 .68963 L .58312 .72383 L F
.58447 .68443 m .58429 .68963 L .58429 .68977 L F
.58323 .72104 m .58406 .69648 L .58312 .72383 L F
.58406 .69648 m .58406 .69633 L .58312 .72383 L F
.58481 .67434 m .58406 .69617 L .58406 .69618 L F
.58296 .729 m .58432 .68816 L .58441 .68623 L F
.58447 .68443 m .58447 .68425 L .58429 .68963 L F
.58429 .68938 m .58481 .67406 L .58429 .68886 L F
.58432 .68816 m .58451 .68251 L .58441 .68623 L F
.58429 .68886 m .58481 .67406 L .58481 .67312 L F
.58366 .70791 m .58451 .6801 L .58461 .67948 L F
.58312 .72383 m .58429 .68938 L .58429 .68886 L F
.58451 .68251 m .58454 .68152 L .58454 .68169 L F
.58451 .68251 m .58454 .68169 L .58455 .68206 L F
.58481 .67312 m .58483 .6728 L .5845 .68263 L F
.58449 .68288 m .5845 .68263 L .58296 .729 L F
.58451 .6801 m .58484 .67007 L .58461 .67948 L F
.58481 .67312 m .5845 .68263 L .58449 .68288 L F
.58312 .72383 m .58447 .68321 L .58296 .729 L F
.58447 .68321 m .58481 .67312 L .58449 .68288 L F
.58447 .68321 m .58449 .68288 L .58296 .729 L F
.58492 .67118 m .58492 .671 L .58447 .68412 L F
.58492 .67118 m .58447 .68412 L .58447 .68422 L F
.58332 .68285 m .58359 .67946 L .58354 .68064 L 0 0 .064 r
F
.58332 .68285 m .58356 .6798 L .58343 .67909 L 0 .238 .224 r
F
.58333 .67951 m .58343 .67909 L .58333 .67854 L F
.58332 .68285 m .58343 .67909 L .58333 .67951 L F
.58271 .70202 m .58286 .70001 L .58286 .69938 L 0 0 .064 r
F
.58155 .72291 m .58272 .70248 L .58271 .70202 L F
.58272 .70248 m .58286 .70001 L .58271 .70202 L F
.58379 .67794 m .58379 .67795 L .5838 .67755 L 0 0 .1 r
F
.58314 .68961 m .58335 .68525 L .5832 .68562 L 0 0 .064 r
F
.58335 .68525 m .58331 .68347 L .5832 .68562 L F
.58481 .67434 m .58481 .67431 L .58406 .69617 L 0 0 .1 r
F
.58406 .69618 m .58406 .69617 L .58312 .72383 L F
.58431 .68825 m .58432 .68816 L .58409 .69515 L F
.58408 .6952 m .58409 .69515 L .58296 .729 L F
.58431 .68825 m .58409 .69515 L .58408 .6952 L F
.5832 .68554 m .58331 .68345 L .58321 .68552 L 0 0 .064 r
F
.58331 .68345 m .58331 .68344 L .58321 .68552 L F
.58321 .68535 m .58333 .68318 L .58332 .68288 L F
.58321 .68552 m .58321 .68538 L .58321 .68535 L F
.5832 .68562 m .5832 .68554 L .58321 .68552 L F
.58155 .72291 m .58314 .68961 L .5832 .68562 L F
.58155 .72291 m .58328 .6837 L .58338 .6825 L F
.5835 .68149 m .58338 .6825 L .58354 .68064 L F
.58332 .68285 m .58347 .68593 L .5835 .68369 L 0 .238 .224 r
F
.58335 .68525 m .58347 .68593 L .58332 .68285 L F
.58155 .72291 m .58338 .6825 L .5835 .68149 L 0 0 .064 r
F
.58347 .67894 m .58358 .67958 L .5836 .67931 L 0 .238 .224 r
F
.58354 .68064 m .58359 .67946 L .5836 .67931 L 0 0 .064 r
F
.58333 .67854 m .58343 .67909 L .58347 .67894 L 0 .238 .224 r
F
.58483 .6728 m .58483 .67264 L .58432 .68816 L 0 0 .1 r
F
.58483 .6728 m .58432 .68816 L .58431 .68825 L F
.58286 .69938 m .5832 .6941 L .58321 .6929 L 0 0 .064 r
F
.58286 .70001 m .5832 .6941 L .58286 .69938 L F
.58155 .72291 m .58303 .69306 L .58305 .69292 L F
.58155 .72291 m .58315 .69079 L .58321 .69059 L F
.58155 .72291 m .58323 .69182 L .58315 .68944 L F
.58323 .69182 m .5835 .68684 L .58315 .68944 L F
.58331 .68317 m .58332 .68285 L .58332 .68285 L F
.58328 .6837 m .58332 .68285 L .5835 .68101 L F
.58328 .6837 m .5835 .68101 L .58354 .68064 L F
.58357 .7087 m .58451 .6801 L .58366 .70791 L 0 0 .1 r
F
.58129 .70659 m .58189 .6991 L .58188 .70058 L 0 0 .101 r
F
.5811 .70825 m .58189 .6991 L .58129 .70659 L F
.58155 .72291 m .58174 .71076 L .58251 .6973 L 0 0 .064 r
F
.58098 .67167 m .58332 .68285 L .58333 .67854 L 0 .238 .224 r
F
.58367 .65336 m .58512 .66518 L .58372 .64982 L 0 .238 .216 r
F
.58514 .66371 m .58484 .67304 L .58483 .67314 L 0 0 .1 r
F
.57904 .6155 m .58484 .67014 L .58512 .66518 L 0 .238 .216 r
F
.58481 .67312 m .58523 .66173 L .58519 .66167 L 0 0 .1 r
F
.58098 .67167 m .58098 .67172 L .58098 .67171 L 0 .238 .224 r
F
.58098 .67167 m .58098 .67171 L .58098 .67171 L F
.58188 .70058 m .58192 .70016 L .58192 .70011 L 0 0 .001 r
F
.57904 .6155 m .58372 .64982 L .58383 .64202 L 0 .238 .216 r
F
.57904 .6155 m .58367 .65336 L .58372 .64982 L F
.58172 .70056 m .58191 .69868 L .58192 .69852 L 0 .742 .063 r
F
.58172 .70056 m .58189 .69904 L .58191 .69868 L F
.5762 .53925 m .57744 .57206 L .58187 .61546 L 0 .27 .221 r
F
.57336 .52632 m .58232 .71682 L .58316 .49824 L 0 .09 .148 r
F
.58507 .66546 m .58508 .66522 L .58483 .67264 L 0 0 .1 r
F
.58507 .66546 m .58483 .67264 L .58483 .6728 L F
.58499 .66905 m .58499 .66905 L .58481 .67431 L F
.58499 .66905 m .58481 .67431 L .58481 .67434 L F
.58504 .66742 m .58481 .67406 L .58481 .67431 L F
.58536 .65797 m .58536 .65789 L .58504 .66706 L F
.58536 .65797 m .58504 .66706 L .58504 .66742 L F
.58383 .64202 m .58554 .65143 L .58398 .63188 L 0 .238 .216 r
F
.58554 .65143 m .58556 .65015 L .58398 .63188 L F
.58546 .6549 m .58547 .65454 L .58536 .65789 L 0 0 .1 r
F
.58335 .68525 m .58346 .68762 L .58347 .68593 L 0 .238 .224 r
F
.58519 .66167 m .5852 .66158 L .58508 .66522 L 0 0 .1 r
F
.58519 .66167 m .58508 .66522 L .58507 .66546 L F
.58547 .65452 m .58547 .65452 L .58529 .65982 L F
.58529 .65982 m .58529 .65982 L .58505 .66705 L F
.58529 .65982 m .58505 .66705 L .58504 .66706 L F
.58344 .68788 m .58346 .68765 L .58346 .68762 L 0 0 .064 r
F
.58346 .68762 m .58348 .68778 L .58347 .68593 L 0 .238 .224 r
F
.58557 .65164 m .58529 .65982 L .58529 .65982 L 0 0 .1 r
F
.58544 .65443 m .58547 .65333 L .58548 .65362 L F
.58481 .67406 m .58523 .66173 L .58481 .67312 L F
.58481 .67312 m .58519 .66167 L .58483 .6728 L F
.5853 .65965 m .58544 .65443 L .58554 .65255 L F
.58455 .68206 m .58522 .66126 L .5853 .65965 L F
.58522 .66126 m .58544 .65443 L .5853 .65965 L F
.58519 .66167 m .58544 .65443 L .5852 .66158 L F
.58454 .68152 m .58544 .65443 L .58455 .68206 L F
.58232 .71682 m .58881 .85487 L .58521 .62721 L 0 .09 .148 r
F
.58232 .71682 m .58521 .62721 L .58316 .49824 L F
.58024 .41963 m .58065 .62185 L .58006 .42596 L 0 0 .075 r
F
.58024 .41963 m .58006 .42596 L .57989 .3717 L F
.58006 .42596 m .58065 .62185 L .57995 .4297 L F
.58006 .42596 m .57995 .4297 L .57987 .40706 L F
.58927 .78969 m .58316 .49824 L .5885 .80761 L 0 0 .073 r
F
.58927 .78969 m .5885 .80761 L .5906 .92909 L F
.58984 .88499 m .58949 .87413 L .59037 .92659 L F
.58984 .88499 m .59037 .92659 L .59055 .92855 L F
.5906 .92909 m .58984 .88499 L .59055 .92855 L F
.58895 .85733 m .58316 .49824 L .58878 .85211 L F
.58895 .85733 m .58878 .85211 L .58891 .8603 L F
.58244 .8889 m .58258 .89194 L .5826 .88983 L 0 0 .116 r
F
.58258 .89194 m .58263 .89231 L .5826 .88983 L F
.58364 .52846 m .58364 .52848 L .58876 .85158 L 0 0 .073 r
F
.58876 .85158 m .58876 .85158 L .58881 .85487 L F
.58364 .52846 m .58876 .85158 L .58876 .85158 L F
.58028 .92423 m .58234 .89526 L .58281 .91469 L 0 0 .116 r
F
.58234 .89526 m .58336 .90301 L .58281 .91469 L F
.57913 .81554 m .58092 .88224 L .5811 .88281 L F
.58097 .88366 m .58099 .88245 L .58099 .88245 L F
.58028 .92423 m .58089 .88382 L .58097 .88366 L F
.58144 .88468 m .58138 .88276 L .58139 .88434 L F
.58138 .88276 m .57913 .81554 L .58134 .88283 L F
.58138 .88276 m .58134 .88283 L .58139 .88434 L F
.57913 .81554 m .58211 .88156 L .58222 .86146 L F
.58211 .88156 m .58244 .8889 L .58238 .88168 L F
.58211 .88156 m .58238 .88168 L .58222 .86146 L F
.58854 .83684 m .58784 .79303 L .58852 .83639 L 0 0 .073 r
F
.58784 .79303 m .58364 .52846 L .58783 .79278 L F
.58784 .79303 m .58783 .79278 L .58852 .83639 L F
.58854 .83684 m .58852 .83639 L .58881 .85487 L F
.57995 .28134 m .58011 .35992 L .57989 .3717 L 0 0 .075 r
F
.58023 .28042 m .58039 .41404 L .57995 .28134 L F
.58039 .41404 m .58065 .62185 L .58024 .41963 L F
.58039 .41404 m .58024 .41963 L .57995 .28134 L F
.58615 .63668 m .58618 .63697 L .58616 .63655 L 0 .27 .221 r
F
.58364 .52846 m .58316 .49824 L .58364 .52848 L 0 0 .073 r
F
.5862 .6372 m .58621 .63686 L .58621 .63719 L 0 0 .116 r
F
.58827 .80255 m .58366 .52754 L .58795 .79542 L 0 0 .073 r
F
.58366 .52754 m .58316 .49824 L .58365 .52821 L F
.58366 .52754 m .58365 .52821 L .58795 .79542 L F
.58827 .80255 m .58795 .79542 L .58869 .84125 L F
.58915 .85463 m .58869 .84125 L .58909 .86622 L F
.58244 .8889 m .5826 .88983 L .58222 .86146 L 0 0 .116 r
F
.59035 .92639 m .58965 .88442 L .59 .92249 L 0 0 .073 r
F
.58965 .88442 m .58909 .86622 L .59 .92249 L F
.59 .92249 m .58909 .86622 L .58891 .8603 L F
.58028 .92423 m .58139 .88434 L .58179 .88699 L 0 0 .116 r
F
.58782 .77478 m .5869 .72015 L .58781 .77463 L 0 0 .073 r
F
.5869 .72015 m .58316 .49824 L .58689 .72011 L F
.5869 .72015 m .58689 .72011 L .58781 .77463 L F
.59036 .9265 m .59036 .92595 L .59037 .92659 L 0 0 .08 r
F
.59037 .92659 m .58782 .77478 L .59035 .92639 L 0 0 .073 r
F
.58782 .77478 m .58781 .77463 L .59035 .92639 L F
.59068 .99343 m .59036 .9265 L .59037 .92659 L 0 0 .08 r
F
.58849 .54904 m .5885 .54954 L .58839 .50741 L 0 0 .087 r
F
.5811 .3241 m .58856 .55148 L .58862 .5495 L 0 .005 .124 r
F
.58872 .54627 m .58852 .52848 L .5888 .54376 L 0 0 .08 r
F
.58931 .59939 m .58889 .60682 L .58852 .52848 L F
.58886 .48309 m .58906 .53533 L .58838 .49884 L F
.58906 .53533 m .58931 .59939 L .58909 .57498 L F
.58906 .53533 m .58909 .57498 L .58838 .49884 L F
.59094 .29428 m .59384 .6499 L .59221 .58474 L F
.59316 .78546 m .59251 .78741 L .5955 .79801 L 0 .137 .22 r
F
.59094 .29428 m .59323 .81724 L .59232 .80356 L 0 0 .08 r
F
.59094 .28493 m .59446 .47891 L .59094 .29428 L F
.58895 .35891 m .58906 .53533 L .59313 .37744 L 0 .005 .124 r
F
.58809 .28596 m .58886 .48309 L .58823 .46658 L 0 0 .08 r
F
.58886 .48309 m .58838 .49884 L .58823 .46658 L F
.58837 .50223 m .58838 .50594 L .58838 .5037 L 0 0 .087 r
F
.58837 .50223 m .58832 .49872 L .58844 .54181 L F
.58837 .50223 m .58844 .54181 L .58846 .5422 L F
.58787 .31692 m .58823 .46658 L .58788 .31743 L F
.58781 .2919 m .58823 .46658 L .58781 .29201 L F
.58781 .29201 m .58787 .31692 L .58788 .31743 L F
.5878 .28685 m .58781 .2919 L .58781 .29201 L F
.58809 .28596 m .58823 .46658 L .5878 .28685 L 0 0 .08 r
F
.5811 .3241 m .58906 .53533 L .58895 .35891 L 0 .005 .124 r
F
.5866 .48892 m .58862 .5495 L .58906 .53533 L F
.5811 .3241 m .5866 .48892 L .58906 .53533 L F
.58861 .55916 m .58859 .55913 L .58856 .55148 L 0 0 .08 r
F
.58861 .55916 m .58856 .55148 L .58857 .55093 L F
.58931 .59939 m .58872 .54627 L .5888 .54376 L F
.58857 .57999 m .58858 .58046 L .58857 .5752 L 0 0 .087 r
F
.58856 .57518 m .58857 .5752 L .58855 .56978 L F
.58857 .57999 m .58857 .5752 L .58856 .57518 L F
.58769 .5582 m .58769 .5582 L .58686 .54089 L 0 .091 .152 r
F
.58874 .5862 m .58869 .58736 L .58859 .55913 L 0 0 .08 r
F
.58874 .5862 m .58859 .55913 L .58861 .55916 L F
.58897 .63424 m .58869 .58736 L .58874 .5862 L F
.58892 .6348 m .58869 .58736 L .58897 .63424 L F
.58899 .66264 m .58898 .66271 L .58894 .65118 L F
.589 .65066 m .58894 .65118 L .58869 .58736 L F
.58864 .60591 m .58861 .60216 L .58877 .66065 L 0 0 .087 r
F
.58878 .66148 m .58877 .66065 L .58891 .71118 L F
.58864 .60591 m .58877 .66065 L .58878 .66148 L F
.58864 .60562 m .58861 .60216 L .58864 .60591 L F
.58679 .53942 m .58761 .56095 L .58763 .56024 L 0 .091 .152 r
F
.58855 .57286 m .58856 .57517 L .58856 .57319 L 0 0 .087 r
F
.58856 .57517 m .58857 .57999 L .58856 .57518 L F
.58856 .57517 m .58856 .57518 L .58856 .57319 L F
.58855 .57516 m .58854 .57511 L .58861 .60143 L F
.58854 .56826 m .58854 .57511 L .58855 .57516 L F
.5885 .57329 m .58854 .57421 L .58791 .56185 L 0 .091 .152 r
F
.58793 .56199 m .5885 .57329 L .58791 .56185 L F
.58839 .5714 m .58858 .57519 L .58841 .57121 L F
.58835 .57218 m .58835 .57216 L .58686 .54089 L F
.58839 .57119 m .58839 .57119 L .588 .56335 L F
.58839 .57119 m .58839 .57119 L .58793 .56199 L F
.58839 .57119 m .58793 .56199 L .58793 .56199 L F
.58771 .55776 m .58839 .57118 L .58771 .55773 L F
.58839 .57118 m .58839 .57119 L .58771 .55773 L F
.58794 .56224 m .58839 .5714 L .58793 .56149 L F
.58839 .5714 m .58841 .57121 L .58793 .56149 L F
.58864 .60523 m .58861 .60143 L .58861 .60185 L 0 0 .087 r
F
.58864 .60523 m .58861 .60185 L .58864 .60562 L F
.58931 .59939 m .58958 .66754 L .58889 .60682 L 0 0 .08 r
F
.58958 .66754 m .58922 .66981 L .58889 .60682 L F
.58793 .56199 m .58793 .56199 L .58771 .55773 L 0 .091 .152 r
F
.588 .56335 m .588 .56335 L .58771 .55773 L F
.58906 .53533 m .59346 .42013 L .59313 .37744 L 0 .005 .124 r
F
.58793 .56149 m .58841 .57121 L .58842 .57093 L 0 .091 .152 r
F
.58679 .53942 m .58824 .57535 L .58835 .57218 L F
.58807 .56494 m .58839 .57142 L .58807 .56489 L F
.58839 .57142 m .58839 .5714 L .58807 .56489 L F
.58857 .57999 m .58864 .60591 L .58858 .58046 L 0 0 .087 r
F
.58864 .60591 m .58891 .71118 L .58865 .60744 L F
.58864 .60591 m .58865 .60744 L .58858 .58046 L F
.58791 .56185 m .58794 .56229 L .58794 .56229 L 0 .091 .152 r
F
.58686 .54086 m .58793 .56199 L .58791 .56185 L F
.58722 .5481 m .58807 .56494 L .58722 .54804 L F
.58807 .56494 m .58807 .56489 L .58722 .54804 L F
.58771 .55776 m .58771 .55773 L .58724 .54828 L F
.58686 .54086 m .58722 .5481 L .58686 .54079 L F
.58724 .54832 m .58724 .54828 L .58686 .54086 L F
.58722 .5481 m .58722 .54804 L .58686 .54079 L F
.58686 .54079 m .58794 .56224 L .58793 .56149 L F
.58679 .53942 m .58686 .54098 L .58686 .54089 L F
.58679 .53942 m .58686 .54089 L .58686 .54086 L F
.58679 .53942 m .58686 .54086 L .58686 .54079 L F
.58679 .53942 m .58686 .54079 L .58686 .54051 L F
.58479 .48557 m .58371 .50101 L .58588 .5152 L 0 .984 .281 r
F
.59041 .77393 m .58981 .43738 L .58316 .49824 L 0 0 .073 r
F
.59041 .77393 m .58316 .49824 L .59054 .85023 L F
.58145 .28454 m .59313 .37744 L .59157 .28334 L 0 .005 .124 r
F
.58145 .28454 m .5811 .3241 L .59313 .37744 L F
.58213 .28379 m .59216 .41586 L .5896 .2814 L 0 0 .073 r
F
.59323 .74175 m .59376 .75376 L .59795 .78626 L 0 .009 .137 r
F
.59226 .59554 m .59384 .6499 L .59323 .81724 L 0 0 .08 r
F
.59221 .58474 m .59268 .60344 L .59226 .59554 L F
.59268 .60344 m .59384 .6499 L .59226 .59554 L F
.59895 .78108 m .599 .78104 L .59568 .71089 L 0 .091 .152 r
F
.59758 .67621 m .59624 .68901 L .59823 .69493 L 0 1 .277 r
F
.59365 .83427 m .59454 .84363 L .59943 .84776 L 0 .579 .413 r
F
.59542 .81759 m .5951 .82288 L .59908 .82964 L 0 .316 .339 r
F
.60082 .96874 m .59455 .96894 L .59701 .96791 L 0 0 0 r
F
.60082 .96874 m .59618 .9693 L .59455 .96894 L F
.59401 .97248 m .59618 .9693 L .60082 .96874 L F
.59563 .98749 m .59632 .98032 L .60124 .97888 L 0 .037 .031 r
F
.59797 1.01056 m .59744 1.00083 L .60138 .99663 L 0 .211 .087 r
F
.60178 1.05903 m .59392 .41557 L .59429 .42022 L 0 .267 .202 r
F
.59946 .87003 m .59333 .87312 L .59582 .87718 L 0 .894 .468 r
F
.59946 .87003 m .59489 .87005 L .59333 .87312 L F
.59258 .85941 m .59489 .87005 L .59946 .87003 L 0 .849 .458 r
F
.60169 1.06025 m .59392 .41557 L .60178 1.05903 L 0 .267 .202 r
F
.60185 1.03736 m .60133 .98919 L .60193 1.02857 L F
.60133 .98919 m .59535 .43375 L .60161 .99984 L F
.60133 .98919 m .60161 .99984 L .60193 1.02857 L F
.59535 .43375 m .59539 .43431 L .60581 1.37936 L F
.59857 .78189 m .59931 .80174 L .59918 .79015 L 0 .091 .152 r
F
.60554 1.37947 m .59448 .47469 L .59392 .41557 L 0 .267 .202 r
F
.60554 1.37947 m .59491 .47341 L .59705 .59114 L F
.59787 .79908 m .59795 .79931 L .59786 .79885 L 0 .137 .22 r
F
.59787 .79908 m .59786 .79885 L .59725 .79562 L F
.59795 .79931 m .59799 .79803 L .59725 .79562 L F
.59542 .81759 m .59678 .81956 L .59679 .81922 L 0 .316 .339 r
F
.59937 .8896 m .59299 .89653 L .599 .89902 L 0 1 .477 r
F
.59372 .88023 m .59373 .8898 L .59937 .8896 L 0 .975 .472 r
F
.59441 .8476 m .5935 .85587 L .59864 .8595 L 0 .726 .441 r
F
.60042 .96582 m .59388 .96675 L .5999 .96548 L 0 0 0 r
F
.59484 .96772 m .59471 .96685 L .60042 .96582 L F
.59416 .77876 m .59387 .78175 L .59725 .79562 L 0 .051 .169 r
F
.59422 .7669 m .59431 .77239 L .59808 .79237 L 0 0 .141 r
F
.59611 .97798 m .59501 .9738 L .60018 .97232 L 0 0 0 r
F
.59797 1.01056 m .59597 1.0068 L .59744 1.00083 L 0 .211 .087 r
F
.59686 1.00381 m .59448 .47469 L .60165 1.06091 L 0 0 .08 r
F
.59232 .80356 m .59323 .81724 L .59273 .95439 L F
.59996 1.07318 m .60043 1.07179 L .60045 1.07245 L 0 .364 .153 r
F
.59416 .77876 m .59544 .78577 L .59551 .78429 L 0 .051 .169 r
F
.59509 .79156 m .59525 .79214 L .59527 .79209 L 0 .137 .22 r
F
.59542 .81759 m .59353 .81771 L .5951 .82288 L 0 .316 .339 r
F
.59686 1.00381 m .59273 .95439 L .59448 .47469 L 0 0 .08 r
F
.59626 .99656 m .58981 .43738 L .59041 .77393 L 0 0 .073 r
F
.59693 1.07767 m .59609 1.06679 L .5989 1.05404 L 0 .364 .153 r
F
.59853 1.1127 m .59798 1.09733 L .60111 1.08041 L 0 .39 .172 r
F
.60482 1.32239 m .60007 1.04204 L .59626 .99656 L 0 0 .073 r
F
.60007 1.04204 m .58981 .43738 L .59626 .99656 L F
.59792 1.38589 m .59572 1.26117 L .59809 1.386 L F
.59735 1.3429 m .59302 1.09511 L .59711 1.33786 L F
.59302 1.09511 m .5931 1.10406 L .59711 1.33786 L F
.59748 1.34988 m .59735 1.3429 L .59723 1.34463 L F
.59735 1.3429 m .59711 1.33786 L .59723 1.34463 L F
.59594 1.31805 m .59549 1.31285 L .59796 1.38789 L 0 0 .116 r
F
.59806 1.38348 m .59748 1.34988 L .59791 1.38391 L 0 0 .073 r
F
.59748 1.34988 m .59723 1.34463 L .59791 1.38391 L F
.59806 1.38348 m .59733 1.3398 L .59728 1.33885 L F
.59843 1.38248 m .59806 1.36095 L .59806 1.38348 L F
.59806 1.36095 m .59592 1.23727 L .59761 1.35234 L F
.59806 1.36095 m .59761 1.35234 L .59806 1.38348 L F
.59592 1.23727 m .59556 1.23474 L .59806 1.38348 L F
.59788 1.3857 m .59572 1.26117 L .59792 1.38589 L F
.59856 1.38076 m .59175 1.22243 L .59273 .95439 L 0 0 .08 r
F
.60527 1.38057 m .59041 .77393 L .60168 1.3814 L 0 0 .073 r
F
.60482 1.32239 m .59041 .77393 L .60527 1.38057 L F
.59041 .77393 m .59054 .85023 L .60168 1.3814 L F
.59856 1.38076 m .59273 .95439 L .59686 1.00381 L 0 0 .08 r
F
.59856 1.38076 m .59686 1.00381 L .60554 1.37947 L F
.60482 1.32239 m .60107 1.05407 L .60007 1.04204 L 0 0 .073 r
F
.60165 1.06091 m .59216 .41586 L .60146 1.08184 L F
.60165 1.06091 m .60146 1.08184 L .60482 1.32239 L F
.59686 1.00381 m .60165 1.06091 L .60554 1.37947 L 0 0 .08 r
F
.60007 1.04204 m .5991 .91299 L .598 .92016 L 0 0 .073 r
F
.60107 1.05407 m .5991 .91299 L .60007 1.04204 L F
.60221 .98115 m .59216 .41586 L .6009 .93281 L 0 .288 .209 r
F
.6009 .93281 m .59216 .41586 L .60014 .92133 L F
.598 .92016 m .59216 .41586 L .58981 .43738 L 0 0 .073 r
F
.5991 .91299 m .59216 .41586 L .598 .92016 L F
.60185 1.03736 m .60193 1.02857 L .60581 1.37936 L 0 .267 .202 r
F
.60221 1.05305 m .59216 .41586 L .60165 1.06091 L 0 .288 .209 r
F
.59771 .69413 m .59216 .41586 L .59709 .68738 L F
.59995 .75566 m .60017 .76566 L .60046 .79494 L 0 .267 .202 r
F
.60067 .8154 m .60017 .76566 L .60088 .81835 L F
.60017 .76566 m .59699 .45468 L .60047 .7797 L F
.60017 .76566 m .60047 .7797 L .60088 .81835 L F
.61263 1.37876 m .61154 1.23154 L .61066 1.19438 L 0 1 .196 r
F
.61654 1.38074 m .59948 .60107 L .6072 1.05581 L 0 .223 .192 r
F
.60744 .97502 m .60315 .76858 L .60455 .83256 L F
.60315 .76858 m .60114 .67249 L .60455 .83256 L F
.60455 .83256 m .60114 .67249 L .59898 .55896 L F
.60741 .9758 m .60114 .67249 L .60744 .97502 L F
.61055 1.12871 m .60903 1.05484 L .61055 1.12781 L F
.60903 1.05484 m .60114 .67249 L .60919 1.06193 L F
.60903 1.05484 m .60919 1.06193 L .61055 1.12781 L F
.59995 .75566 m .59699 .45468 L .60017 .76566 L 0 .267 .202 r
F
.59694 .45406 m .59529 .28249 L .59699 .45468 L F
.59694 .45406 m .59373 .28334 L .59529 .28249 L F
.59699 .45468 m .59335 .28211 L .596 .44207 L 0 .223 .192 r
F
.60114 .67249 m .59825 .53159 L .59898 .55896 L F
.59964 .68212 m .6072 1.05581 L .59918 .63383 L F
.59863 .57229 m .59873 .58332 L .60031 .67145 L F
.59787 .52758 m .59873 .58332 L .59863 .57229 L F
.59787 .52758 m .59804 .54437 L .59873 .58332 L F
.59948 .60107 m .59787 .52758 L .60031 .67145 L F
.59824 .53084 m .59825 .53159 L .59872 .58221 L 0 .267 .202 r
F
.59871 .58121 m .59872 .58221 L .60065 .78819 L F
.59824 .53084 m .59872 .58221 L .59871 .58121 L F
.59824 .53084 m .60065 .78819 L .60065 .78814 L F
.59825 .53159 m .59773 .50001 L .59844 .53364 L 0 .223 .192 r
F
.59825 .53159 m .59844 .53364 L .59898 .55896 L F
.59669 .36618 m .59671 .36875 L .59672 .36876 L 0 .267 .202 r
F
.59847 .53391 m .59773 .50001 L .59754 .48803 L 0 .223 .192 r
F
.59898 .55896 m .59844 .53364 L .59847 .53391 L F
.59844 .53364 m .59773 .50001 L .59847 .53391 L F
.60088 .81835 m .59901 .64315 L .59935 .65279 L 0 .267 .202 r
F
.59901 .64315 m .59699 .45468 L .59935 .65279 L F
.59898 .55896 m .59851 .53433 L .60209 .69644 L 0 .223 .192 r
F
.59851 .53433 m .5975 .48132 L .59872 .53653 L F
.59851 .53433 m .59872 .53653 L .60209 .69644 L F
.5975 .48132 m .59699 .45468 L .59757 .48243 L F
.5975 .48132 m .59757 .48243 L .59872 .53653 L F
.59898 .55896 m .59754 .48803 L .59699 .45468 L F
.59819 .52816 m .59699 .45468 L .59669 .36618 L 0 .267 .202 r
F
.59935 .65279 m .59699 .45468 L .59819 .52816 L F
.59754 .48803 m .59717 .4703 L .59699 .45468 L 0 .223 .192 r
F
.59898 .55896 m .60209 .69644 L .60206 .69583 L F
.59898 .55896 m .60234 .70796 L .6021 .70251 L F
.59898 .55896 m .60647 .90384 L .60626 .89974 L F
.60568 .8885 m .59898 .55896 L .60626 .89974 L F
.59669 .36618 m .5959 .28111 L .59669 .3648 L 0 .267 .202 r
F
.6029 .81663 m .60306 .81786 L .6029 .81664 L 0 .009 .137 r
F
.59948 .60107 m .60031 .67145 L .6072 1.05581 L 0 .223 .192 r
F
.59669 .3648 m .5959 .28111 L .59569 .28048 L 0 .267 .202 r
F
.59869 .33723 m .60776 .38846 L .60957 .32061 L 0 .854 .242 r
F
.59824 .53084 m .60092 .81648 L .59824 .53084 L 0 .267 .202 r
F
.59822 .5293 m .60092 .81648 L .60094 .81924 L F
.59672 .36876 m .59823 .52984 L .59822 .5293 L F
.59823 .52984 m .60092 .81648 L .59822 .5293 L F
.59873 .58332 m .5989 .60091 L .6072 1.05581 L 0 .223 .192 r
F
.6057 .97472 m .59954 .6356 L .60799 1.02516 L F
.60335 1.01748 m .60321 1.02426 L .60655 1.20793 L 0 .288 .209 r
F
.60335 1.01748 m .60655 1.20793 L .60652 1.20564 L F
.60619 1.18109 m .60666 1.21416 L .60631 1.18796 L F
.60335 1.01748 m .60652 1.20564 L .60619 1.18109 L F
.60652 1.20564 m .60666 1.21416 L .60619 1.18109 L F
.60218 .95874 m .60088 .81793 L .60199 .93151 L 0 .267 .202 r
F
.60088 .81793 m .60097 .82292 L .60199 .93151 L F
.59863 .57544 m .5987 .58067 L .60199 .93151 L F
.60264 1.00827 m .60067 .8154 L .60088 .81835 L F
.60222 .9725 m .60043 .77027 L .59989 .73434 L F
.60065 .78814 m .60065 .78819 L .60092 .81648 L F
.60094 .81924 m .60092 .81648 L .60099 .82429 L F
.60094 .81924 m .60099 .82429 L .60098 .82375 L F
.60088 .81793 m .59863 .57544 L .60097 .82292 L F
.60218 .95874 m .60199 .93151 L .60396 1.14138 L F
.60274 1.01096 m .60065 .78819 L .60222 .9725 L F
.60059 .781 m .5994 .65418 L .60043 .77027 L F
.59579 .47498 m .59499 .42921 L .59535 .43375 L F
.59705 .59114 m .59499 .42921 L .59579 .47498 L F
.59705 .59114 m .5947 .42541 L .59499 .42921 L F
.59436 .42111 m .59539 .43431 L .59251 .28268 L 0 .223 .192 r
F
.59157 .28334 m .59436 .42111 L .59251 .28268 L F
.59872 .64237 m .59201 .28027 L .5924 .28081 L F
.59872 .64237 m .59201 .28027 L .59872 .64237 L F
.59429 .42022 m .5947 .42541 L .59705 .59114 L 0 .267 .202 r
F
.59873 .65081 m .59201 .28027 L .59873 .64303 L 0 .223 .192 r
F
.59989 .73434 m .59873 .6152 L .5998 .72831 L 0 .267 .202 r
F
.59873 .6152 m .59873 .61529 L .5998 .72831 L F
.5987 .61209 m .59871 .61529 L .59873 .61662 L F
.59873 .61529 m .59873 .61662 L .5998 .72831 L F
.5987 .61209 m .59873 .61662 L .59873 .61529 L F
.59863 .57544 m .59815 .52379 L .5987 .58067 L F
.59815 .52379 m .59669 .36618 L .59822 .5293 L F
.59815 .52379 m .59822 .5293 L .5987 .58067 L F
.59928 .61511 m .59825 .53159 L .61093 1.14863 L 0 .223 .192 r
F
.59928 .61511 m .61093 1.14863 L .61026 1.12694 L F
.60808 1.02726 m .60816 1.02883 L .61026 1.12694 L F
.59954 .6356 m .61026 1.12694 L .61005 1.12012 L F
.61544 1.34731 m .61621 1.37582 L .61621 1.37583 L 0 0 .042 r
F
.61544 1.3473 m .61621 1.37582 L .61544 1.34731 L F
.61453 1.31372 m .61453 1.31364 L .61621 1.37582 L F
.61621 1.37583 m .61621 1.37582 L .61635 1.38093 L F
.61654 1.38074 m .6072 1.05581 L .61631 1.38085 L 0 .223 .192 r
F
.61066 1.19438 m .61023 1.12609 L .60978 1.11154 L 0 1 .196 r
F
.61263 1.37876 m .60871 1.07674 L .60912 1.34962 L F
.60871 1.07674 m .60526 .96512 L .60912 1.34962 L F
.6057 .97472 m .60799 1.02516 L .61005 1.12012 L 0 .223 .192 r
F
.61154 1.23154 m .61093 1.14863 L .61066 1.19438 L 0 1 .196 r
F
.61093 1.14863 m .61023 1.12609 L .61066 1.19438 L F
.6057 .97472 m .61005 1.12012 L .60625 .99714 L 0 .223 .192 r
F
.59954 .6356 m .59928 .61511 L .60816 1.02883 L F
.59954 .6356 m .60816 1.02883 L .60808 1.02726 L F
.61055 1.12781 m .60741 .9758 L .60744 .97502 L F
.60568 .8885 m .61274 1.20773 L .61275 1.20893 L F
.61093 1.14863 m .60114 .67249 L .61123 1.16143 L F
.61635 1.38029 m .61093 1.14863 L .61154 1.23154 L 0 1 .196 r
F
.61589 1.3801 m .61154 1.23154 L .61263 1.37876 L F
.61635 1.38029 m .61154 1.23154 L .61589 1.3801 L F
.60389 .93492 m .60336 .89258 L .60304 .90288 L F
.60339 .924 m .60304 .90288 L .60279 .91082 L F
.60389 .93492 m .60304 .90288 L .60339 .924 L F
.59873 .61662 m .59873 .61761 L .5998 .72831 L 0 .267 .202 r
F
.59851 .5792 m .59809 .55592 L .59825 .53159 L 0 .223 .192 r
F
.59809 .55592 m .59311 .28131 L .59743 .49166 L F
.59809 .55592 m .59743 .49166 L .59825 .53159 L F
.59989 .73434 m .5994 .65418 L .599 .6429 L 0 .267 .202 r
F
.59954 .69411 m .59957 .69657 L .59979 .71872 L F
.60043 .77027 m .5994 .65418 L .59989 .73434 L F
.59979 .71882 m .59979 .71872 L .59991 .73074 L F
.59954 .69411 m .59979 .71872 L .59979 .71882 L F
.59977 .71966 m .59926 .66758 L .59976 .71659 L F
.60128 .81232 m .60212 .82268 L .60128 .81235 L 0 .066 .149 r
F
.60128 .81203 m .60212 .82268 L .60128 .81232 L F
.60242 .85382 m .59958 .69761 L .59942 .68236 L 0 .223 .192 r
F
.59903 .6437 m .59895 .63639 L .599 .6429 L 0 .267 .202 r
F
.5994 .65418 m .59895 .63639 L .59903 .6437 L F
.59926 .66758 m .59954 .69355 L .59976 .71599 L F
.59926 .66758 m .59976 .71599 L .59976 .71613 L F
.59976 .71659 m .59979 .71885 L .59979 .71942 L F
.59926 .66758 m .59976 .71613 L .59976 .71659 L F
.59976 .71613 m .59979 .71885 L .59976 .71659 L F
.60242 .85382 m .59942 .68236 L .60045 .70938 L 0 .223 .192 r
F
.59942 .68236 m .59919 .66057 L .60045 .70938 L F
.60201 .84106 m .59978 .71607 L .60201 .83366 L F
.59979 .71663 m .60201 .84091 L .602 .84067 L F
.5994 .65418 m .59872 .58221 L .59895 .63639 L 0 .267 .202 r
F
.59872 .58221 m .59873 .60245 L .59895 .63639 L F
.596 .44207 m .59251 .28268 L .59539 .43431 L 0 .223 .192 r
F
.59809 .55592 m .5924 .28081 L .59311 .28131 L F
.59851 .5792 m .59815 .56127 L .59809 .55592 L F
.59815 .56127 m .5924 .28081 L .59809 .55592 L F
.59825 .53159 m .59861 .59576 L .599 .6429 L 0 .267 .202 r
F
.59872 .58221 m .59825 .53159 L .59873 .60245 L F
.59873 .6152 m .5987 .61209 L .59873 .61529 L F
.59873 .61761 m .5924 .28081 L .59815 .56127 L 0 .223 .192 r
F
.59873 .61761 m .59815 .56127 L .59851 .5792 L F
.59876 .61913 m .59873 .61761 L .59871 .61427 L F
.5987 .61209 m .59806 .52955 L .59787 .52762 L 0 .267 .202 r
F
.599 .6429 m .59861 .59576 L .5987 .61209 L F
.59861 .59576 m .59806 .52955 L .5987 .61209 L F
.59876 .61913 m .59871 .61427 L .59851 .5792 L 0 .223 .192 r
F
.6085 1.12942 m .59876 .61913 L .59851 .5792 L F
.61287 1.36982 m .60817 1.11976 L .6085 1.12942 L F
.60817 1.11976 m .59876 .61913 L .6085 1.12942 L F
.61284 1.36879 m .60826 1.12507 L .61287 1.36982 L F
.60065 .78819 m .60048 .77646 L .60222 .9725 L 0 .267 .202 r
F
.60128 .86735 m .60375 .99739 L .60375 .99694 L 0 .288 .209 r
F
.60129 .87388 m .59978 .71607 L .60128 .86882 L 0 .267 .202 r
F
.60128 .86736 m .60375 .99739 L .60128 .86735 L 0 .288 .209 r
F
.60816 1.11956 m .59876 .61913 L .60817 1.11976 L 0 .223 .192 r
F
.59825 .53159 m .59806 .52955 L .59861 .59576 L 0 .267 .202 r
F
.59919 .66057 m .59873 .61761 L .60045 .70938 L 0 .223 .192 r
F
.60065 .78819 m .60059 .781 L .60048 .77646 L 0 .267 .202 r
F
.60059 .781 m .60043 .77027 L .60048 .77646 L F
.60128 .86718 m .60375 .99694 L .60362 .98586 L 0 .288 .209 r
F
.60119 .86249 m .60128 .86735 L .60128 .86718 L F
.60128 .86735 m .60375 .99694 L .60128 .86718 L F
.59989 .73434 m .60072 .82328 L .60211 .96446 L 0 .267 .202 r
F
.60222 .9725 m .60044 .7909 L .60214 .9666 L F
.60175 .92554 m .60321 1.02426 L .60335 1.01748 L 0 .288 .209 r
F
.60163 .91391 m .6016 .91099 L .60215 .96825 L 0 .267 .202 r
F
.60044 .7909 m .60043 .79066 L .6016 .91099 L F
.60044 .7909 m .6016 .91099 L .60163 .91391 L F
.60189 .94187 m .60072 .82328 L .60144 .89087 L F
.60274 1.01096 m .60221 .98115 L .6028 1.04502 L 0 .288 .209 r
F
.60213 .9704 m .60221 .98115 L .60274 1.01096 L F
.60207 .96241 m .60274 1.01096 L .60213 .96584 L F
.60161 .93573 m .60213 .9704 L .60207 .96241 L F
.60213 .9704 m .60274 1.01096 L .60207 .96241 L F
.60205 .96027 m .60161 .93573 L .60207 .96241 L F
.60205 .96027 m .60207 .96241 L .60213 .96584 L F
.60199 .95324 m .60072 .82328 L .60189 .94187 L 0 .267 .202 r
F
.60163 .91391 m .60215 .96825 L .60217 .97007 L F
.60194 .94817 m .60205 .96027 L .60321 1.02426 L 0 .288 .209 r
F
.60215 .96825 m .60205 .96027 L .60611 1.37892 L 0 .267 .202 r
F
.60211 .96446 m .60205 .96027 L .60215 .96825 L F
.60217 .97007 m .60215 .96825 L .60611 1.37892 L F
.60205 .96027 m .60213 .96584 L .60307 1.02016 L 0 .288 .209 r
F
.60426 1.18272 m .60397 1.15179 L .6043 1.18513 L 0 .267 .202 r
F
.60426 1.18272 m .6043 1.18513 L .60619 1.37909 L F
.60619 1.37909 m .60222 .9725 L .60611 1.37892 L F
.60464 1.22577 m .60454 1.21528 L .60465 1.22589 L F
.60222 .9725 m .60214 .9666 L .60611 1.37892 L F
.60462 1.22477 m .60454 1.21528 L .60464 1.22577 L F
.60462 1.22477 m .60205 .96019 L .60454 1.21528 L F
.60205 .96019 m .60072 .82328 L .60203 .95712 L F
.60205 .96027 m .60307 1.02016 L .6031 1.02113 L 0 .288 .209 r
F
.60321 1.02426 m .60205 .96027 L .6031 1.02113 L F
.60205 .96019 m .60203 .95712 L .60465 1.22589 L 0 .267 .202 r
F
.60179 .939 m .60205 .96027 L .60194 .94817 L 0 .288 .209 r
F
.60323 1.0814 m .60205 .96027 L .60323 1.08141 L 0 .267 .202 r
F
.60205 .96027 m .60072 .82328 L .60205 .96009 L F
.60205 .96027 m .60205 .96009 L .60323 1.08141 L F
.60199 .95324 m .60189 .94187 L .60199 .9516 L F
.60202 .95682 m .60199 .9516 L .60334 1.08903 L F
.60199 .95324 m .60199 .9516 L .60202 .95682 L F
.60331 1.08853 m .60208 .96305 L .60331 1.08855 L F
.60208 .96305 m .60203 .95712 L .60331 1.08855 L F
.60331 1.08855 m .60203 .95712 L .60334 1.08903 L F
.60203 .95712 m .60199 .95324 L .60202 .95682 L F
.60203 .95712 m .60202 .95682 L .60334 1.08903 L F
.60179 .939 m .60194 .94817 L .60135 .90309 L 0 .288 .209 r
F
.60194 .94817 m .60321 1.02426 L .60181 .93274 L F
.60194 .94817 m .60181 .93274 L .60135 .90309 L F
.60135 .90309 m .60181 .93274 L .60175 .92554 L F
.60181 .93274 m .60321 1.02426 L .60175 .92554 L F
.60128 .86882 m .59992 .72537 L .60122 .83704 L 0 .267 .202 r
F
.60175 .83464 m .60116 .80162 L .60352 .97787 L 0 .288 .209 r
F
.59979 .71662 m .60201 .84091 L .59979 .71663 L 0 .223 .192 r
F
.59978 .71607 m .59972 .71035 L .60201 .83366 L F
.59896 .64193 m .59896 .63937 L .59978 .72109 L 0 .267 .202 r
F
.59978 .72123 m .59978 .72109 L .59982 .72493 L F
.59896 .64193 m .59978 .72109 L .59978 .72123 L F
.59978 .71607 m .59975 .71353 L .59988 .72091 L F
.59873 .65744 m .59873 .65177 L .59922 .67853 L 0 .223 .192 r
F
.59978 .72239 m .59982 .72493 L .59982 .72638 L 0 .267 .202 r
F
.59896 .64193 m .59978 .72123 L .59978 .72239 L F
.59978 .72123 m .59982 .72493 L .59978 .72239 L F
.60044 .74911 m .60103 .7788 L .6025 .85975 L 0 .223 .192 r
F
.59896 .63937 m .59926 .66758 L .59977 .71966 L 0 .267 .202 r
F
.59896 .63937 m .59977 .71966 L .59977 .71981 L F
.59978 .72109 m .59981 .72333 L .59982 .72493 L F
.59896 .63937 m .59977 .71981 L .59978 .72109 L F
.59977 .71981 m .59981 .72333 L .59978 .72109 L F
.59954 .69355 m .59954 .69359 L .59979 .71885 L F
.59979 .71885 m .59979 .71885 L .59991 .73074 L F
.59954 .69355 m .59979 .71885 L .59979 .71885 L F
.59979 .72343 m .60034 .77703 L .60033 .77714 L F
.59896 .64193 m .59978 .72239 L .59979 .72343 L F
.59978 .72239 m .60034 .77703 L .59979 .72343 L F
.6025 .85975 m .59961 .70022 L .60242 .85382 L 0 .223 .192 r
F
.5999 .73872 m .59896 .64193 L .59993 .73782 L 0 .267 .202 r
F
.59961 .70022 m .5996 .69937 L .60242 .85382 L 0 .223 .192 r
F
.59972 .71035 m .60103 .7788 L .60044 .74911 L F
.59959 .7036 m .59971 .70992 L .59972 .71035 L F
.59971 .70992 m .60103 .7788 L .59972 .71035 L F
.59991 .73074 m .59957 .69657 L .59968 .7072 L 0 .267 .202 r
F
.59954 .69359 m .59954 .69411 L .59991 .73074 L F
.59959 .7036 m .59922 .67853 L .59961 .70022 L 0 .223 .192 r
F
.59971 .70992 m .59961 .70022 L .60103 .7788 L F
.59991 .73074 m .59968 .7072 L .59991 .73054 L 0 .267 .202 r
F
.5996 .69937 m .59958 .69761 L .60242 .85382 L 0 .223 .192 r
F
.59968 .7072 m .5993 .66696 L .5997 .7085 L 0 .267 .202 r
F
.59968 .7072 m .5997 .7085 L .59991 .73054 L F
.59873 .65177 m .59873 .65081 L .59958 .69761 L 0 .223 .192 r
F
.59873 .65177 m .59958 .69761 L .5996 .69937 L F
.59959 .7036 m .59961 .70022 L .59971 .70992 L F
.59974 .71263 m .6004 .78111 L .6004 .78111 L 0 .267 .202 r
F
.59919 .65508 m .59974 .71264 L .59974 .71263 L F
.59974 .71264 m .6004 .78111 L .59974 .71263 L F
.59717 .4703 m .59311 .28131 L .59335 .28211 L 0 .223 .192 r
F
.59754 .48803 m .5972 .47231 L .59717 .4703 L F
.5972 .47231 m .59311 .28131 L .59717 .4703 L F
.5987 .61209 m .59787 .52762 L .59871 .61529 L 0 .267 .202 r
F
.59896 .64024 m .59792 .53332 L .59896 .63896 L F
.59787 .52762 m .59785 .52742 L .59873 .61761 L F
.59787 .52762 m .59873 .61761 L .59873 .61662 L F
.59875 .61991 m .59789 .53071 L .59896 .64024 L F
.59773 .50001 m .59727 .478 L .59754 .48803 L 0 .223 .192 r
F
.59727 .478 m .5972 .47245 L .59754 .48803 L F
.59417 .33154 m .59411 .3281 L .5972 .47231 L F
.5972 .47245 m .5972 .47231 L .59754 .48803 L F
.59417 .33154 m .5972 .47231 L .5972 .47245 L F
.59745 .48434 m .59565 .29975 L .59743 .48411 L 0 .267 .202 r
F
.59565 .29975 m .59565 .29975 L .59743 .48411 L F
.59565 .29975 m .59565 .30053 L .59743 .48411 L F
.59564 .29957 m .59565 .30053 L .59565 .29975 L F
.59717 .4703 m .59335 .28211 L .59699 .45468 L 0 .223 .192 r
F
.59374 .28438 m .59372 .28334 L .59373 .28334 L 0 .267 .202 r
F
.59576 .31381 m .59311 .27946 L .59525 .27984 L 0 .727 .225 r
F
.59825 .53159 m .59743 .49166 L .59773 .50001 L 0 .223 .192 r
F
.59743 .49166 m .59311 .28131 L .59727 .478 L F
.59743 .49166 m .59727 .478 L .59773 .50001 L F
.59727 .478 m .59417 .33154 L .5972 .47245 L F
.59669 .36618 m .59669 .3648 L .59825 .53159 L 0 .267 .202 r
F
.59669 .36618 m .59825 .53159 L .59824 .53084 L F
.59745 .48434 m .59669 .3648 L .59545 .27977 L F
.59787 .52762 m .59757 .48601 L .59745 .48434 L F
.59757 .48601 m .59669 .3648 L .59745 .48434 L F
.59851 .5792 m .59825 .53159 L .59928 .61511 L 0 .223 .192 r
F
.59875 .61991 m .59786 .5277 L .59789 .53071 L 0 .267 .202 r
F
.59789 .53071 m .59792 .53332 L .59896 .64024 L F
.59417 .33154 m .59311 .28131 L .59411 .3281 L 0 .223 .192 r
F
.59792 .53332 m .59795 .53544 L .59896 .63896 L 0 .267 .202 r
F
.59671 .36875 m .59824 .53084 L .59672 .36876 L F
.59824 .53084 m .59824 .53084 L .59672 .36876 L F
.59806 .52955 m .59707 .41107 L .59787 .52762 L F
.59707 .41107 m .59669 .3648 L .59702 .41105 L F
.59707 .41107 m .59702 .41105 L .59787 .52762 L F
.59786 .52411 m .59771 .50854 L .59771 .50852 L F
.59792 .53033 m .59786 .52406 L .59786 .52411 L F
.59815 .55264 m .59792 .53029 L .59792 .53033 L F
.60826 1.12507 m .60816 1.11956 L .60827 1.12528 L 0 .223 .192 r
F
.60816 1.11956 m .60817 1.11976 L .60827 1.12528 L F
.60826 1.12507 m .60827 1.12528 L .61287 1.36982 L F
.60589 .9857 m .6057 .97472 L .60625 .99714 L F
.60626 .89974 m .6141 1.26537 L .61411 1.26623 L F
.60626 .89974 m .61157 1.14536 L .61144 1.14126 L F
.60626 .89974 m .60647 .90384 L .61157 1.14536 L F
.60568 .8885 m .60626 .89974 L .61385 1.25504 L F
.60568 .8885 m .61385 1.25504 L .61382 1.25642 L F
.60626 .89974 m .61478 1.29737 L .61477 1.29793 L F
.6021 .70251 m .60234 .70796 L .60647 .90384 L F
.60867 1.03546 m .60568 .8885 L .60882 1.03083 L F
.60871 1.07674 m .60778 1.0053 L .60526 .96512 L 0 1 .196 r
F
.6103 .72638 m .60523 .73252 L .60318 .74123 L 0 1 .388 r
F
.62274 .5573 m .61856 .58794 L .62149 .59243 L 0 1 .32 r
F
.62274 .5573 m .6191 .57287 L .61856 .58794 L F
.61159 .56852 m .62035 .57617 L .61624 .56661 L 0 .839 .313 r
F
.62274 .5573 m .62149 .59243 L .62664 .58475 L 0 1 .32 r
F
.61159 .56852 m .62169 .59149 L .62035 .57617 L 0 .839 .313 r
F
.61327 .59518 m .62149 .59243 L .61856 .58794 L 0 1 .328 r
F
.61327 .59518 m .62036 .60592 L .62149 .59243 L F
.61159 .56852 m .61935 .60233 L .62169 .59149 L 0 .839 .313 r
F
.61327 .59518 m .61592 .61943 L .62036 .60592 L 0 1 .328 r
F
.61159 .56852 m .61469 .60424 L .61935 .60233 L 0 .839 .313 r
F
.61159 .56852 m .61082 .59594 L .61469 .60424 L F
.61159 .56852 m .60949 .58062 L .61082 .59594 L F
.60171 .59375 m .61181 .59056 L .61231 .56839 L 0 1 .261 r
F
.60603 .59764 m .61469 .60424 L .61082 .59594 L 0 .927 .325 r
F
.60603 .59764 m .61548 .61777 L .61469 .60424 L F
.60603 .59764 m .61267 .62749 L .61548 .61777 L F
.60171 .59375 m .60828 .61342 L .61181 .59056 L 0 1 .261 r
F
.60171 .59375 m .60405 .62164 L .60828 .61342 L F
.60171 .59375 m .60124 .61319 L .60405 .62164 L F
.60723 .68622 m .61573 .68489 L .61345 .68119 L 0 1 .384 r
F
.60723 .68622 m .61265 .69509 L .61573 .68489 L F
.60723 .68622 m .60627 .705 L .61265 .69509 L F
.61265 .69509 m .62142 .69423 L .61915 .69048 L 0 1 .396 r
F
.61265 .69509 m .61807 .70409 L .62142 .69423 L F
.62151 .65861 m .61573 .68489 L .62188 .67957 L 0 1 .372 r
F
.62151 .65861 m .61345 .68119 L .61573 .68489 L F
.60731 .67881 m .61493 .69502 L .6158 .68483 L 0 1 .364 r
F
.61265 .69509 m .61133 .7135 L .61807 .70409 L 0 1 .396 r
F
.60731 .67881 m .61061 .702 L .61493 .69502 L 0 1 .364 r
F
.60731 .67881 m .60527 .70258 L .61061 .702 L F
.60375 .69524 m .6122 .68302 L .6082 .68491 L 0 1 .307 r
F
.60375 .69524 m .6136 .69077 L .6122 .68302 L F
.61493 .69502 m .61061 .702 L .60939 .7116 L 0 1 .373 r
F
.60375 .69524 m .61146 .703 L .6136 .69077 L 0 1 .307 r
F
.60375 .69524 m .60702 .71336 L .61146 .703 L F
.60375 .69524 m .60323 .71492 L .60702 .71336 L F
.60778 1.0053 m .60242 .59228 L .60439 .85093 L 0 1 .196 r
F
.60778 1.0053 m .60439 .85093 L .60526 .96512 L F
.60199 .31205 m .59825 .30526 L .60156 .28043 L 0 .727 .225 r
F
.59825 .30526 m .59794 .2976 L .60156 .28043 L F
.59686 .30272 m .5968 .29663 L .59776 .29336 L F
.59794 .2976 m .59776 .29336 L .60156 .28043 L F
.59686 .30272 m .59776 .29336 L .59794 .2976 L F
.60992 .34193 m .61348 .40664 L .61808 .42315 L 0 .53 .258 r
F
.60992 .34193 m .60999 .37178 L .61348 .40664 L F
.60971 .41164 m .61808 .42315 L .61348 .40664 L 0 .629 .27 r
F
.60971 .41164 m .62109 .45 L .61808 .42315 L F
.60971 .41164 m .62049 .46927 L .62109 .45 L F
.60971 .41164 m .61668 .47431 L .62049 .46927 L F
.60971 .41164 m .61223 .46173 L .61668 .47431 L F
.61127 .40311 m .61852 .38125 L .61407 .37574 L 0 .741 .254 r
F
.62164 .39525 m .62158 .41826 L .62505 .4496 L 0 .389 .258 r
F
.61127 .40311 m .62237 .41293 L .61852 .38125 L 0 .741 .254 r
F
.60112 .45417 m .61127 .40311 L .60776 .38846 L 0 .942 .247 r
F
.62109 .45 m .62974 .46837 L .62505 .4496 L 0 .523 .275 r
F
.61127 .40311 m .62305 .44998 L .62237 .41293 L 0 .741 .254 r
F
.62109 .45 m .63271 .49359 L .62974 .46837 L 0 .523 .275 r
F
.62109 .45 m .63193 .50838 L .63271 .49359 L F
.62109 .45 m .62794 .50873 L .63193 .50838 L F
.62109 .45 m .62341 .49445 L .62794 .50873 L F
.62109 .45 m .62049 .46927 L .62341 .49445 L F
.61127 .40311 m .62025 .47792 L .62305 .44998 L 0 .741 .254 r
F
.60819 .46631 m .61668 .47431 L .61223 .46173 L 0 .721 .282 r
F
.60819 .46631 m .61919 .49597 L .61668 .47431 L F
.61127 .40311 m .61584 .4778 L .62025 .47792 L 0 .741 .254 r
F
.61127 .40311 m .61198 .44554 L .61584 .4778 L F
.60971 .41164 m .60925 .43484 L .61223 .46173 L 0 .629 .27 r
F
.60112 .45417 m .61198 .44554 L .61127 .40311 L 0 .942 .247 r
F
.60819 .46631 m .61806 .51228 L .61919 .49597 L 0 .721 .282 r
F
.60819 .46631 m .614 .51689 L .61806 .51228 L F
.60819 .46631 m .60971 .50671 L .614 .51689 L F
.60819 .46631 m .60723 .48501 L .60971 .50671 L F
.60112 .45417 m .6094 .48906 L .61198 .44554 L 0 .942 .247 r
F
.61181 .45123 m .60807 .28012 L .61079 .27923 L 0 .61 .226 r
F
.61489 .90431 m .62602 .90625 L .62439 .90309 L 0 1 .502 r
F
.6273 .86529 m .61375 .88137 L .62233 .87998 L 0 1 .468 r
F
.6273 .86529 m .6121 .8778 L .61375 .88137 L F
.63212 .87455 m .61621 .8866 L .61785 .89 L 0 1 .477 r
F
.63212 .87455 m .62233 .87998 L .61621 .8866 L F
.6273 .86529 m .62233 .87998 L .63212 .87455 L 0 1 .468 r
F
.62741 .8718 m .61378 .8834 L .62237 .88245 L 0 1 .513 r
F
.62741 .8718 m .61215 .88065 L .61378 .8834 L F
.6273 .86529 m .6179 .87091 L .6121 .8778 L 0 1 .468 r
F
.62741 .8718 m .61798 .87567 L .61215 .88065 L 0 1 .513 r
F
.62262 .86543 m .60969 .87662 L .61798 .87567 L 0 1 .518 r
F
.61782 .85942 m .61359 .8692 L .62262 .86543 L 0 1 .523 r
F
.6304 .7833 m .61639 .80165 L .62512 .79962 L 0 1 .449 r
F
.6304 .7833 m .61476 .79775 L .61639 .80165 L F
.6304 .7833 m .62076 .78989 L .61476 .79775 L F
.6196 .79328 m .61094 .81122 L .61787 .81062 L 0 1 .417 r
F
.6196 .79328 m .60898 .80647 L .61094 .81122 L F
.6196 .79328 m .61269 .79878 L .60898 .80647 L F
.61301 .85389 m .61782 .85942 L .62277 .8549 L 0 1 .527 r
F
.62151 .65861 m .61593 .66992 L .61345 .68119 L 0 1 .372 r
F
.60731 .67881 m .6158 .68483 L .61266 .67822 L 0 1 .364 r
F
.61607 .75456 m .62085 .76398 L .62596 .75612 L 0 1 .448 r
F
.61607 .75456 m .62596 .75612 L .62392 .7523 L F
.61676 .74036 m .61137 .76007 L .61745 .75968 L 0 1 .395 r
F
.61676 .74036 m .60904 .75477 L .61137 .76007 L F
.61676 .74036 m .61134 .74632 L .60904 .75477 L F
.61493 .69502 m .60939 .7116 L .61208 .71742 L 0 1 .373 r
F
.62349 .7132 m .61292 .73222 L .61543 .7367 L 0 1 .416 r
F
.62349 .7132 m .61638 .72214 L .61292 .73222 L F
.6103 .72638 m .61134 .74632 L .61676 .74036 L 0 1 .388 r
F
.62349 .7132 m .61543 .7367 L .62299 .73373 L 0 1 .416 r
F
.6103 .72638 m .61881 .73165 L .61612 .72601 L 0 1 .388 r
F
.6103 .72638 m .61676 .74036 L .61881 .73165 L F
.61479 .82584 m .61329 .83597 L .62024 .83037 L 0 1 .487 r
F
.61351 .81862 m .62449 .82102 L .62288 .81717 L 0 1 .455 r
F
.63516 .79301 m .62045 .81137 L .62948 .80931 L 0 1 .451 r
F
.63516 .79301 m .61882 .80749 L .62045 .81137 L F
.62514 .80507 m .61434 .8192 L .6169 .82507 L 0 1 .426 r
F
.60932 .82158 m .61479 .82584 L .61801 .82012 L 0 1 .474 r
F
.62514 .80507 m .61787 .81062 L .61434 .8192 L 0 1 .426 r
F
.60932 .82158 m .61801 .82012 L .61571 .81835 L 0 1 .474 r
F
.63516 .79301 m .62512 .79962 L .61882 .80749 L 0 1 .451 r
F
.6196 .79328 m .61787 .81062 L .62514 .80507 L 0 1 .417 r
F
.61778 .80068 m .61226 .81578 L .61833 .81193 L 0 1 .45 r
F
.61778 .80068 m .60996 .81412 L .61226 .81578 L F
.61778 .80068 m .61232 .80765 L .60996 .81412 L F
.61405 .78095 m .61269 .79878 L .6196 .79328 L 0 1 .41 r
F
.61141 .79661 m .61232 .80765 L .61778 .80068 L 0 1 .437 r
F
.61141 .79661 m .6065 .81174 L .61232 .80765 L F
.61141 .79661 m .61778 .80068 L .61988 .7942 L F
.61141 .79661 m .61988 .7942 L .61723 .79252 L F
.60779 .66144 m .61621 .64707 L .61204 .64921 L 0 1 .295 r
F
.61166 .65485 m .6181 .65628 L .61621 .64707 L F
.60779 .66144 m .61168 .6595 L .61166 .65485 L F
.61168 .6595 m .6181 .65628 L .61166 .65485 L F
.61625 .91544 m .61471 .92472 L .62184 .9233 L 0 1 .493 r
F
.6194 .89716 m .61367 .90412 L .61992 .90597 L 0 1 .492 r
F
.6194 .89716 m .61131 .90076 L .61367 .90412 L F
.6194 .89716 m .61376 .89778 L .61131 .90076 L F
.61287 .88879 m .61376 .89778 L .6194 .89716 L 0 .993 .485 r
F
.6261 .89413 m .62031 .89469 L .62193 .89756 L 0 1 .508 r
F
.6261 .89413 m .62193 .89756 L .62982 .89494 L F
.6261 .89413 m .62982 .89494 L .63232 .8941 L F
.63232 .8941 m .62193 .89756 L .63111 .89644 L F
.6261 .89413 m .62031 .895 L .62194 .89826 L 0 1 .485 r
F
.63693 .88338 m .62267 .89335 L .6261 .89413 L F
.63693 .88338 m .6261 .89413 L .63232 .8941 L F
.63693 .88338 m .63236 .89401 L .64172 .89186 L F
.6391 .89355 m .63111 .89644 L .62437 .90187 L 0 1 .507 r
F
.63896 .89353 m .63111 .89644 L .6391 .89355 L F
.6398 .89362 m .6391 .89355 L .63974 .89367 L 0 1 .491 r
F
.64172 .89186 m .63914 .89353 L .6398 .89362 L F
.63914 .89353 m .6391 .89355 L .6398 .89362 L F
.64172 .89186 m .63842 .89343 L .6391 .89355 L F
.63236 .89401 m .63842 .89343 L .64172 .89186 L 0 1 .485 r
F
.63974 .89367 m .62437 .90187 L .62599 .90475 L 0 1 .507 r
F
.64648 .89898 m .63004 .91194 L .6398 .91058 L F
.64648 .89898 m .62842 .90906 L .63004 .91194 L F
.64648 .89898 m .6398 .91058 L .65121 .90589 L F
.64648 .89898 m .63546 .90351 L .62842 .90906 L F
.64253 .89324 m .63546 .90351 L .64648 .89898 L F
.64172 .89186 m .64091 .89357 L .64253 .89324 L 0 1 .491 r
F
.64173 .89207 m .64091 .89357 L .64253 .89324 L 0 1 .507 r
F
.64091 .89357 m .63546 .90351 L .64253 .89324 L F
.64253 .89324 m .64091 .89357 L .64254 .89325 L 0 1 .491 r
F
.64254 .89325 m .63549 .90495 L .6465 .90004 L F
.64091 .89357 m .63549 .90495 L .64254 .89325 L F
.64091 .89357 m .62599 .90475 L .63546 .90351 L 0 1 .507 r
F
.63974 .89367 m .63952 .89385 L .64091 .89357 L F
.64091 .89357 m .63974 .89367 L .6409 .89358 L 0 1 .491 r
F
.64172 .89186 m .63974 .89367 L .64091 .89357 L F
.64173 .89207 m .63974 .89367 L .64091 .89357 L 0 1 .507 r
F
.63952 .89385 m .62599 .90475 L .64091 .89357 L F
.64173 .89207 m .63876 .89375 L .63974 .89367 L F
.63876 .89375 m .62437 .90187 L .63974 .89367 L F
.6409 .89358 m .62602 .90625 L .63549 .90495 L 0 1 .491 r
F
.63974 .89367 m .62602 .90625 L .6409 .89358 L F
.63697 .8852 m .63306 .8927 L .64173 .89207 L 0 1 .508 r
F
.63236 .89401 m .63232 .8941 L .63842 .89343 L 0 1 .485 r
F
.63232 .8941 m .63111 .89644 L .63842 .89343 L 0 1 .508 r
F
.63842 .89343 m .63111 .89644 L .63896 .89353 L 0 1 .507 r
F
.63232 .8941 m .63112 .89692 L .63842 .89343 L 0 1 .485 r
F
.63306 .8927 m .63232 .8941 L .63842 .89343 L 0 1 .508 r
F
.63306 .8927 m .63842 .89343 L .64173 .89207 L F
.6391 .89355 m .63112 .89692 L .62439 .90309 L 0 1 .491 r
F
.63842 .89343 m .63112 .89692 L .6391 .89355 L F
.63842 .89343 m .63896 .89353 L .63951 .89333 L 0 1 .507 r
F
.63951 .89333 m .63896 .89353 L .6391 .89355 L F
.63974 .89367 m .62439 .90309 L .62602 .90625 L 0 1 .491 r
F
.6391 .89355 m .62439 .90309 L .63974 .89367 L F
.64173 .89207 m .63842 .89343 L .63951 .89333 L 0 1 .507 r
F
.63697 .8852 m .62267 .89335 L .6261 .89413 L 0 1 .508 r
F
.62267 .89335 m .62132 .89412 L .6261 .89413 L F
.62267 .89335 m .62262 .89338 L .6261 .89413 L 0 1 .485 r
F
.62132 .89412 m .62031 .89469 L .6261 .89413 L 0 1 .508 r
F
.62262 .89338 m .62031 .895 L .6261 .89413 L 0 1 .485 r
F
.63232 .8941 m .6261 .89413 L .6323 .89416 L F
.63697 .8852 m .6261 .89413 L .63232 .8941 L 0 1 .508 r
F
.6323 .89416 m .62194 .89826 L .63112 .89692 L 0 1 .485 r
F
.6261 .89413 m .62194 .89826 L .6323 .89416 L F
.63693 .88338 m .62673 .88862 L .6221 .89322 L F
.63693 .88338 m .6221 .89322 L .62267 .89335 L F
.63697 .8852 m .62674 .8894 L .6221 .89322 L 0 1 .508 r
F
.62267 .89335 m .6221 .89322 L .62031 .89469 L F
.63697 .8852 m .6221 .89322 L .62267 .89335 L F
.62267 .89335 m .6221 .89322 L .62031 .895 L 0 1 .485 r
F
.61287 .88879 m .6194 .89716 L .6216 .89424 L 0 .993 .485 r
F
.61287 .88879 m .6216 .89424 L .61889 .89096 L F
.61801 .87939 m .61208 .8824 L .6148 .88589 L 0 .886 .476 r
F
.61801 .87939 m .61345 .87961 L .61208 .8824 L F
.61027 .86992 m .61345 .87961 L .618 .87939 L 0 .824 .465 r
F
.62262 .86543 m .61798 .87567 L .62741 .8718 L 0 1 .518 r
F
.61027 .86992 m .618 .87939 L .61903 .87642 L 0 .824 .465 r
F
.61027 .86992 m .61903 .87642 L .61584 .87268 L F
.61155 .85985 m .61104 .86679 L .6163 .86992 L 0 .648 .436 r
F
.61155 .85985 m .6163 .86992 L .62011 .86997 L F
.61155 .85985 m .62011 .86997 L .62035 .86699 L F
.61155 .85985 m .62035 .86699 L .61683 .86298 L F
.63212 .87455 m .61785 .89 L .62673 .88862 L 0 1 .477 r
F
.63212 .87455 m .62673 .88862 L .63693 .88338 L F
.6322 .87842 m .61623 .88759 L .61786 .89042 L 0 1 .51 r
F
.6322 .87842 m .62237 .88245 L .61623 .88759 L F
.61801 .87939 m .6148 .88589 L .6205 .88818 L 0 .886 .476 r
F
.61155 .85985 m .60783 .86267 L .61104 .86679 L 0 .648 .436 r
F
.61155 .85985 m .60805 .8597 L .60783 .86267 L F
.60991 .84872 m .60776 .85161 L .61143 .85639 L 0 .419 .381 r
F
.60991 .84872 m .6071 .84833 L .60776 .85161 L F
.60688 .83814 m .61586 .88469 L .61074 .86009 L 0 .677 .061 r
F
.6322 .87842 m .61786 .89042 L .62674 .8894 L 0 1 .51 r
F
.62539 .88776 m .61889 .89096 L .6216 .89424 L 0 .948 .487 r
F
.62539 .88776 m .6205 .88818 L .61889 .89096 L F
.60688 .83814 m .61955 .89354 L .61586 .88469 L 0 .677 .061 r
F
.61801 .87939 m .6205 .88818 L .62539 .88776 L 0 .886 .476 r
F
.62741 .8718 m .62237 .88245 L .6322 .87842 L 0 1 .513 r
F
.61801 .87939 m .62539 .88776 L .62677 .88497 L 0 .886 .476 r
F
.61801 .87939 m .62677 .88497 L .62372 .88169 L F
.62011 .86997 m .61584 .87268 L .61903 .87642 L 0 .714 .45 r
F
.62011 .86997 m .6163 .86992 L .61584 .87268 L F
.60991 .84872 m .61143 .85639 L .61651 .86028 L 0 .419 .381 r
F
.62245 .85549 m .6273 .86529 L .6328 .8581 L 0 1 .457 r
F
.61782 .85942 m .62262 .86543 L .62787 .86079 L 0 1 .523 r
F
.61782 .85942 m .62787 .86079 L .62583 .85839 L F
.60991 .84872 m .61651 .86028 L .61961 .8607 L 0 .419 .381 r
F
.60991 .84872 m .61896 .85741 L .615 .85262 L F
.60991 .84872 m .61961 .8607 L .61896 .85741 L F
.60688 .83814 m .61933 .88065 L .61955 .89354 L 0 .677 .061 r
F
.60688 .83814 m .61543 .85857 L .61933 .88065 L F
.60641 .85594 m .61074 .86009 L .61586 .88469 L 0 .896 .098 r
F
.61027 .86992 m .60789 .87685 L .61345 .87961 L 0 .824 .465 r
F
.60641 .85594 m .61557 .93656 L .61018 .89376 L 0 .896 .098 r
F
.62741 .93077 m .61625 .93678 L .61882 .94071 L 0 1 .509 r
F
.62741 .93077 m .61992 .93252 L .61625 .93678 L F
.60641 .85594 m .61968 .94914 L .61557 .93656 L 0 .896 .098 r
F
.62741 .93077 m .61882 .94071 L .62672 .94207 L 0 1 .509 r
F
.61625 .91544 m .62184 .9233 L .62543 .91996 L 0 1 .493 r
F
.61625 .91544 m .62543 .91996 L .62308 .91691 L F
.60641 .85594 m .6197 .92282 L .61968 .94914 L 0 .896 .098 r
F
.62591 .90508 m .6172 .90903 L .61956 .91223 L 0 1 .499 r
F
.62591 .90508 m .61992 .90597 L .6172 .90903 L F
.60641 .85594 m .61586 .88469 L .6197 .92282 L 0 .896 .098 r
F
.61398 .86051 m .61424 .90108 L .61942 1.10296 L 0 .537 .227 r
F
.62151 .65861 m .63028 .65753 L .62766 .6533 L 0 1 .372 r
F
.62151 .65861 m .6278 .66878 L .63028 .65753 L F
.62151 .65861 m .62188 .67957 L .6278 .66878 L F
.61652 .65906 m .62523 .66551 L .62178 .65834 L 0 .958 .355 r
F
.6278 .66878 m .61915 .69048 L .62142 .69423 L 0 1 .383 r
F
.6278 .66878 m .62188 .67957 L .61915 .69048 L F
.61652 .65906 m .62493 .67656 L .62523 .66551 L 0 .958 .355 r
F
.61652 .65906 m .62107 .68411 L .62493 .67656 L F
.61652 .65906 m .6158 .68483 L .62107 .68411 L F
.61652 .65906 m .61266 .67822 L .6158 .68483 L F
.61652 .65906 m .61297 .66718 L .61266 .67822 L F
.61168 .6595 m .61645 .67074 L .6181 .65628 L 0 1 .295 r
F
.60779 .66144 m .61171 .66565 L .61168 .6595 L F
.61171 .66565 m .61645 .67074 L .61168 .6595 L F
.61145 .4636 m .60807 .28012 L .61181 .45123 L 0 .61 .226 r
F
.60544 .51069 m .614 .51689 L .60971 .50671 L 0 .809 .293 r
F
.60544 .51069 m .616 .53499 L .614 .51689 L F
.60544 .51069 m .61438 .54896 L .616 .53499 L F
.60544 .51069 m .61009 .55296 L .61438 .54896 L F
.60544 .51069 m .60601 .54432 L .61009 .55296 L F
.60544 .51069 m .60402 .52619 L .60601 .54432 L F
.60206 .53466 m .61257 .4998 L .6094 .48906 L 0 1 .254 r
F
.60206 .53466 m .61264 .52945 L .61257 .4998 L F
.61002 .5127 m .60899 .38966 L .61145 .4636 L 0 .61 .226 r
F
.60899 .38966 m .60807 .28012 L .61145 .4636 L F
.61197 .47941 m .61145 .4636 L .61181 .45123 L F
.60171 .59375 m .61231 .56839 L .60951 .56002 L 0 1 .261 r
F
.60503 .79303 m .61141 .79661 L .61326 .79016 L 0 1 .423 r
F
.60503 .79303 m .61326 .79016 L .61061 .78869 L F
.62563 .7736 m .62076 .78989 L .6304 .7833 L 0 1 .448 r
F
.61405 .78095 m .6196 .79328 L .62304 .78546 L 0 1 .41 r
F
.61405 .78095 m .62304 .78546 L .62071 .78054 L F
.61624 .77348 m .61061 .78869 L .61326 .79016 L F
.60779 .66144 m .6122 .68302 L .61645 .67074 L 0 1 .295 r
F
.61624 .77348 m .61188 .78154 L .61061 .78869 L 0 1 .41 r
F
.62321 .75386 m .61488 .76789 L .61721 .77302 L 0 1 .402 r
F
.62321 .75386 m .61745 .75968 L .61488 .76789 L F
.60873 .77018 m .61624 .77348 L .61718 .76642 L 0 1 .395 r
F
.60873 .77018 m .61188 .78154 L .61624 .77348 L F
.60779 .66144 m .6082 .68491 L .6122 .68302 L 0 1 .295 r
F
.60873 .77018 m .61718 .76642 L .61408 .76507 L 0 1 .395 r
F
.61676 .74036 m .61745 .75968 L .62321 .75386 L F
.63058 .72529 m .62087 .74662 L .62837 .74334 L 0 1 .426 r
F
.63058 .72529 m .61883 .74287 L .62087 .74662 L F
.63058 .72529 m .62299 .73373 L .61883 .74287 L F
.61676 .74036 m .62552 .7454 L .62284 .73996 L 0 1 .395 r
F
.61676 .74036 m .62321 .75386 L .62552 .7454 L F
.60976 .74569 m .61804 .74802 L .61818 .74044 L 0 1 .366 r
F
.60976 .74569 m .61444 .75718 L .61804 .74802 L F
.60976 .74569 m .61818 .74044 L .61479 .73948 L F
.61807 .70409 m .61638 .72214 L .62348 .7132 L 0 1 .408 r
F
.61493 .69502 m .61208 .71742 L .61758 .7168 L 0 1 .373 r
F
.61807 .70409 m .62348 .7132 L .62711 .70366 L 0 1 .408 r
F
.62222 .71015 m .61758 .7168 L .61612 .72601 L 0 1 .382 r
F
.60792 .72008 m .61722 .72034 L .61651 .71238 L 0 1 .336 r
F
.60792 .72008 m .61437 .73086 L .61722 .72034 L F
.60976 .74569 m .60942 .7634 L .61444 .75718 L 0 1 .366 r
F
.60792 .72008 m .61651 .71238 L .61271 .71227 L 0 1 .336 r
F
.60792 .72008 m .60958 .73869 L .61437 .73086 L F
.61623 .85049 m .61382 .84965 L .615 .85262 L 0 .286 .275 r
F
.61055 .83798 m .61063 .84055 L .61486 .84659 L 0 .112 .186 r
F
.60645 .82766 m .60929 .83215 L .6141 .84448 L 0 .462 0 r
F
.61055 .83798 m .60878 .83686 L .61063 .84055 L 0 .112 .186 r
F
.60645 .82766 m .61543 .85857 L .61048 .84204 L 0 .462 0 r
F
.61961 .8607 m .61683 .86298 L .62035 .86699 L 0 .462 .387 r
F
.61961 .8607 m .61651 .86028 L .61683 .86298 L F
.60645 .82766 m .61873 .86583 L .61543 .85857 L 0 .462 0 r
F
.61623 .85049 m .615 .85262 L .61896 .85741 L 0 .286 .275 r
F
.60645 .82766 m .61816 .85891 L .61873 .86583 L 0 .462 0 r
F
.60645 .82766 m .6141 .84448 L .61816 .85891 L F
.60688 .83814 m .61048 .84204 L .61543 .85857 L 0 .677 .061 r
F
.60785 .58745 m .61942 1.10296 L .60824 .57411 L 0 .537 .227 r
F
.61077 1.0458 m .61923 1.22159 L .61916 1.23885 L 0 0 .042 r
F
.61055 1.03109 m .61923 1.22159 L .61077 1.0458 L F
.61055 1.03109 m .61519 1.05539 L .62017 1.24215 L F
.59869 .33723 m .60375 .41106 L .60776 .38846 L 0 .854 .242 r
F
.60112 .45417 m .60776 .38846 L .60375 .41106 L 0 .942 .247 r
F
.60587 .46296 m .60156 .28043 L .60366 .28033 L 0 .61 .226 r
F
.62085 .76398 m .61639 .78019 L .62563 .7736 L 0 1 .448 r
F
.60112 .45417 m .60522 .50426 L .6094 .48906 L 0 .942 .247 r
F
.60206 .53466 m .6094 .48906 L .60522 .50426 L 0 1 .254 r
F
.62036 .60592 m .61455 .63262 L .61717 .63667 L 0 1 .34 r
F
.62036 .60592 m .61592 .61943 L .61455 .63262 L F
.61548 .61777 m .61315 .64024 L .6166 .64751 L 0 .892 .335 r
F
.61548 .61777 m .61267 .62749 L .61315 .64024 L F
.6399 .80266 m .62449 .82102 L .63382 .8189 L 0 1 .454 r
F
.6399 .80266 m .62288 .81717 L .62449 .82102 L F
.6399 .80266 m .62948 .80931 L .62288 .81717 L F
.62514 .80507 m .6169 .82507 L .62463 .82528 L 0 1 .426 r
F
.60206 .53466 m .60951 .56002 L .61264 .52945 L 0 1 .254 r
F
.61231 .56839 m .61181 .59056 L .61466 .60562 L 0 .994 .274 r
F
.63239 .8197 m .62038 .83283 L .62246 .8373 L 0 1 .436 r
F
.63239 .8197 m .62463 .82529 L .62038 .83283 L F
.62024 .83037 m .61837 .84056 L .62568 .83517 L 0 1 .497 r
F
.61479 .82584 m .62024 .83037 L .62374 .82475 L 0 1 .487 r
F
.61479 .82584 m .62374 .82475 L .62145 .82287 L F
.61068 .62029 m .61896 .60344 L .61466 .60562 L 0 1 .285 r
F
.62036 .60592 m .62271 .63005 L .62747 .6172 L 0 1 .34 r
F
.62036 .60592 m .61717 .63667 L .62271 .63005 L F
.62036 .60592 m .62883 .60404 L .62589 .59933 L F
.62036 .60592 m .62747 .6172 L .62883 .60404 L F
.62169 .59149 m .62038 .61657 L .62411 .62469 L 0 .796 .324 r
F
.62169 .59149 m .61935 .60234 L .62038 .61657 L F
.61548 .61777 m .62411 .62469 L .62038 .61657 L 0 .892 .335 r
F
.62747 .6172 m .6211 .64284 L .62372 .64701 L 0 1 .351 r
F
.62747 .6172 m .62271 .63005 L .6211 .64284 L F
.61548 .61777 m .6246 .63744 L .62411 .62469 L 0 .892 .335 r
F
.61548 .61777 m .62151 .64632 L .6246 .63744 L F
.61548 .61777 m .6166 .64751 L .62151 .64632 L F
.61068 .62029 m .62133 .61486 L .61896 .60344 L 0 1 .285 r
F
.62413 .80514 m .61801 .82012 L .62433 .8165 L 0 1 .461 r
F
.61068 .62029 m .62019 .63233 L .62133 .61486 L 0 1 .285 r
F
.62413 .80514 m .61571 .81835 L .61801 .82012 L 0 1 .461 r
F
.62413 .80514 m .61833 .81193 L .61571 .81835 L F
.61068 .62029 m .61621 .64707 L .62019 .63233 L 0 1 .285 r
F
.61068 .62029 m .61204 .64921 L .61621 .64707 L F
.6304 .7833 m .62512 .79962 L .63516 .79301 L 0 1 .449 r
F
.6196 .79328 m .62514 .80507 L .62886 .79738 L 0 1 .417 r
F
.6196 .79328 m .62886 .79738 L .62653 .79268 L F
.62563 .7736 m .6304 .7833 L .63611 .77545 L 0 1 .448 r
F
.62563 .7736 m .63611 .77545 L .63408 .77156 L F
.62085 .76398 m .62563 .7736 L .63104 .76575 L F
.62965 .76683 m .62071 .78054 L .62304 .78546 L 0 1 .41 r
F
.62342 .77744 m .61723 .79252 L .61988 .7942 L 0 1 .423 r
F
.62342 .77744 m .61875 .78534 L .61723 .79252 L F
.62965 .76683 m .62354 .77256 L .62071 .78054 L 0 1 .41 r
F
.62085 .76398 m .63104 .76575 L .629 .76188 L 0 1 .448 r
F
.62321 .75386 m .61721 .77302 L .62354 .77256 L 0 1 .402 r
F
.62321 .75386 m .62354 .77256 L .62965 .76683 L F
.61624 .77348 m .62342 .77744 L .6247 .77029 L 0 1 .41 r
F
.61624 .77348 m .61875 .78534 L .62342 .77744 L F
.61624 .77348 m .61326 .79016 L .61875 .78534 L F
.61624 .77348 m .6247 .77029 L .62173 .76866 L F
.62493 .67656 m .62107 .68412 L .62043 .6944 L 0 .945 .365 r
F
.6136 .69077 m .62225 .6821 L .61823 .68182 L 0 1 .323 r
F
.6278 .66878 m .62142 .69423 L .62783 .68931 L 0 1 .383 r
F
.62493 .67656 m .62043 .6944 L .62344 .70055 L 0 .945 .365 r
F
.6136 .69077 m .6235 .69135 L .62225 .6821 L 0 1 .323 r
F
.61807 .70409 m .62711 .70366 L .62484 .69988 L 0 1 .408 r
F
.61493 .69502 m .62344 .70055 L .62043 .6944 L 0 1 .373 r
F
.61493 .69502 m .62222 .71015 L .62344 .70055 L F
.6136 .69077 m .62114 .70341 L .6235 .69135 L 0 1 .323 r
F
.61493 .69502 m .61758 .7168 L .62222 .71015 L 0 1 .373 r
F
.6136 .69077 m .61651 .71238 L .62114 .70341 L 0 1 .323 r
F
.61804 .74802 m .61408 .76507 L .61718 .76642 L 0 1 .381 r
F
.6136 .69077 m .61271 .71227 L .61651 .71238 L 0 1 .323 r
F
.61804 .74802 m .61444 .75718 L .61408 .76507 L 0 1 .381 r
F
.62222 .71015 m .61612 .72601 L .61881 .73165 L 0 1 .382 r
F
.61723 .72034 m .61479 .73948 L .61818 .74044 L 0 1 .352 r
F
.61723 .72034 m .61437 .73086 L .61479 .73948 L F
.62591 .90508 m .61956 .91223 L .62607 .91376 L 0 1 .499 r
F
.6194 .89716 m .61992 .90597 L .62591 .90508 L 0 1 .492 r
F
.6194 .89716 m .62591 .90508 L .62838 .9021 L F
.6194 .89716 m .62838 .9021 L .62567 .89901 L F
.62011 .86997 m .61903 .87642 L .62452 .87913 L 0 .714 .45 r
F
.61623 .85049 m .61896 .85741 L .62393 .86168 L 0 .286 .275 r
F
.61623 .85049 m .62393 .86168 L .6266 .86257 L F
.61623 .85049 m .62543 .8596 L .62121 .85476 L F
.61623 .85049 m .6266 .86257 L .62543 .8596 L F
.61427 .84254 m .61521 .8437 L .61967 .85022 L 0 .17 0 r
F
.62245 .85549 m .6328 .8581 L .63074 .85413 L 0 1 .457 r
F
.62152 .85391 m .62543 .8596 L .63025 .86447 L 0 .075 .172 r
F
.61427 .84254 m .61967 .85022 L .6216 .85322 L 0 .17 0 r
F
.64412 .84147 m .6328 .8581 L .64103 .85698 L 0 1 .454 r
F
.64412 .84147 m .63074 .85413 L .6328 .8581 L F
.6386 .8477 m .62787 .86079 L .63581 .85881 L 0 1 .508 r
F
.6386 .8477 m .62583 .85839 L .62787 .86079 L F
.64412 .84147 m .63558 .84701 L .63074 .85413 L 0 1 .454 r
F
.6386 .8477 m .63042 .85278 L .62583 .85839 L 0 1 .508 r
F
.6236 .85601 m .63078 .86367 L .62634 .85877 L 0 .075 .172 r
F
.62152 .85391 m .62389 .85641 L .6236 .85601 L F
.62389 .85641 m .63078 .86367 L .6236 .85601 L F
.61949 .85026 m .6216 .85322 L .62186 .85361 L 0 .17 0 r
F
.6273 .86529 m .63794 .86765 L .63589 .86389 L 0 1 .468 r
F
.6273 .86529 m .63212 .87455 L .63794 .86765 L F
.64995 .85151 m .64103 .85698 L .63589 .86389 L 0 1 .463 r
F
.64412 .84147 m .64103 .85698 L .64995 .85151 L 0 1 .454 r
F
.64437 .85375 m .63093 .86448 L .63297 .867 L 0 1 .508 r
F
.64437 .85375 m .63581 .85881 L .63093 .86448 L F
.62152 .85391 m .63245 .86611 L .63078 .86367 L 0 .075 .172 r
F
.6203 .85147 m .62186 .85361 L .62418 .8572 L 0 .17 0 r
F
.61949 .85026 m .62186 .85361 L .6203 .85147 L F
.61427 .84254 m .6216 .85322 L .61949 .85026 L F
.62262 .86543 m .63297 .867 L .63093 .86448 L 0 1 .518 r
F
.62442 .85715 m .63025 .86447 L .63245 .86611 L 0 .075 .172 r
F
.62152 .85391 m .62589 .85919 L .62442 .85715 L F
.62589 .85919 m .63025 .86447 L .62442 .85715 L F
.61427 .84254 m .62341 .85671 L .61878 .84952 L 0 .17 0 r
F
.61427 .84254 m .62573 .86 L .62341 .85671 L F
.61427 .84254 m .62418 .8572 L .62573 .86 L F
.62152 .85391 m .61953 .85232 L .62121 .85476 L 0 .075 .172 r
F
.617 .85086 m .61878 .84952 L .62341 .85671 L 0 .404 .009 r
F
.62262 .86543 m .62741 .8718 L .63297 .867 L 0 1 .518 r
F
.6266 .86257 m .62479 .86394 L .62859 .86784 L 0 .318 .267 r
F
.6266 .86257 m .62393 .86168 L .62479 .86394 L F
.62152 .85391 m .62121 .85476 L .62543 .8596 L 0 .075 .172 r
F
.617 .85086 m .62341 .85671 L .62773 .86567 L 0 .404 .009 r
F
.61961 .8607 m .62551 .87023 L .62889 .87053 L 0 .462 .387 r
F
.61961 .8607 m .62889 .87053 L .62859 .86784 L F
.61961 .8607 m .62859 .86784 L .62479 .86394 L F
.617 .85086 m .62608 .86794 L .6213 .85982 L 0 .404 .009 r
F
.617 .85086 m .62884 .87044 L .62608 .86794 L F
.617 .85086 m .62773 .86567 L .62884 .87044 L F
.61961 .8607 m .62035 .86699 L .62551 .87023 L 0 .462 .387 r
F
.61873 .86583 m .6213 .85982 L .62608 .86794 L 0 .626 .082 r
F
.61873 .86583 m .61816 .85891 L .6213 .85982 L F
.63693 .88338 m .64172 .89186 L .64816 .88547 L 0 1 .485 r
F
.64648 .89898 m .65121 .90589 L .65827 .90034 L 0 1 .507 r
F
.64648 .89898 m .65827 .90034 L .65626 .89762 L F
.65 .89313 m .64648 .89898 L .65324 .89354 L F
.64633 .89266 m .64638 .89488 L .65 .89313 L F
.64638 .89488 m .64648 .89898 L .65 .89313 L F
.66733 .87896 m .65121 .89055 L .65215 .89209 L 0 1 .484 r
F
.66549 .88417 m .65324 .89354 L .66259 .89151 L 0 1 .506 r
F
.66573 .88357 m .65865 .88814 L .66549 .88417 L F
.65865 .88814 m .65324 .89354 L .66549 .88417 L F
.67305 .88607 m .66259 .89151 L .65626 .89762 L F
.66896 .88134 m .66259 .89151 L .67305 .88607 L F
.66884 .88117 m .66573 .88357 L .66896 .88134 L 0 1 .484 r
F
.66733 .87896 m .66579 .88339 L .66884 .88117 L F
.66579 .88339 m .66573 .88357 L .66884 .88117 L F
.66579 .88339 m .65865 .88814 L .66573 .88357 L F
.66733 .87896 m .65865 .88814 L .66579 .88339 L F
.65865 .88814 m .65215 .89209 L .65223 .89205 L F
.65592 .88997 m .65235 .89235 L .65274 .89288 L 0 1 .506 r
F
.66733 .87896 m .65272 .8916 L .65865 .88814 L 0 1 .484 r
F
.65272 .8916 m .65215 .89209 L .65865 .88814 L F
.65643 .88949 m .65235 .89235 L .65592 .88997 L 0 1 .506 r
F
.66735 .87948 m .65382 .89108 L .65643 .88949 L F
.65382 .89108 m .65235 .89235 L .65643 .88949 L F
.65382 .89108 m .65216 .89209 L .65235 .89235 L F
.65703 .88976 m .65274 .89288 L .65324 .89354 L F
.66735 .87948 m .65274 .89288 L .65703 .88976 L F
.65727 .8896 m .65223 .89205 L .65324 .89387 L 0 1 .484 r
F
.65223 .89205 m .65215 .89209 L .65216 .89209 L F
.64172 .89186 m .64253 .89324 L .64633 .89266 L 0 1 .491 r
F
.64253 .89324 m .64253 .89324 L .64633 .89266 L F
.64172 .89186 m .64633 .89266 L .65121 .89055 L F
.64633 .89266 m .65 .89313 L .65046 .89226 L 0 1 .507 r
F
.65 .89313 m .65324 .89354 L .65216 .89209 L F
.64633 .89266 m .65216 .89209 L .65121 .89055 L 0 1 .491 r
F
.65 .89313 m .65216 .89209 L .65122 .89083 L 0 1 .507 r
F
.64633 .89266 m .65324 .89387 L .65216 .89209 L 0 1 .491 r
F
.64633 .89266 m .65046 .89226 L .65059 .89201 L 0 1 .507 r
F
.64173 .89207 m .64633 .89266 L .65122 .89083 L F
.64633 .89266 m .65059 .89201 L .65122 .89083 L F
.65224 .89205 m .65216 .89209 L .65324 .89387 L 0 1 .484 r
F
.65223 .89205 m .65216 .89209 L .65224 .89205 L F
.65865 .88814 m .65223 .89205 L .65727 .8896 L F
.66735 .87948 m .65122 .89083 L .65216 .89209 L 0 1 .506 r
F
.66735 .87948 m .65216 .89209 L .65382 .89108 L F
.66735 .87948 m .66573 .88357 L .66896 .88134 L F
.66573 .88357 m .66259 .89151 L .66896 .88134 L F
.67305 .88607 m .65827 .90034 L .6679 .89822 L F
.67305 .88607 m .65626 .89762 L .65827 .90034 L F
.67305 .88607 m .6679 .89822 L .67875 .89267 L F
.66896 .88134 m .66261 .89252 L .67309 .8874 L 0 1 .484 r
F
.66573 .88357 m .66261 .89252 L .66896 .88134 L F
.66573 .88357 m .65324 .89387 L .66261 .89252 L F
.65865 .88814 m .65324 .89387 L .66573 .88357 L F
.66735 .87948 m .65865 .88814 L .66573 .88357 L 0 1 .506 r
F
.64633 .89266 m .6465 .90004 L .65324 .89387 L 0 1 .491 r
F
.64253 .89324 m .64648 .89898 L .64633 .89266 L 0 1 .507 r
F
.64253 .89324 m .6465 .90004 L .64633 .89266 L 0 1 .491 r
F
.64173 .89207 m .64253 .89324 L .64633 .89266 L 0 1 .507 r
F
.63697 .8852 m .64173 .89207 L .64819 .88677 L 0 1 .508 r
F
.6322 .87842 m .62674 .8894 L .63697 .8852 L 0 1 .51 r
F
.63693 .88338 m .64816 .88547 L .64612 .88203 L 0 1 .485 r
F
.63697 .8852 m .64819 .88677 L .64617 .88408 L 0 1 .508 r
F
.63212 .87455 m .63693 .88338 L .64306 .87675 L 0 1 .477 r
F
.6322 .87842 m .63697 .8852 L .64313 .88006 L 0 1 .51 r
F
.62865 .879 m .6368 .88681 L .63762 .88425 L 0 .79 .464 r
F
.62865 .879 m .63762 .88425 L .63427 .88119 L F
.62011 .86997 m .62865 .879 L .62912 .87623 L 0 .714 .45 r
F
.62011 .86997 m .62912 .87623 L .62562 .87267 L F
.63212 .87455 m .64306 .87675 L .64101 .87317 L 0 1 .477 r
F
.62741 .8718 m .6322 .87842 L .63805 .87345 L 0 1 .513 r
F
.62741 .8718 m .63805 .87345 L .63602 .87084 L F
.62889 .87053 m .62562 .87267 L .62912 .87623 L 0 .535 .401 r
F
.62889 .87053 m .62551 .87023 L .62562 .87267 L F
.61873 .86583 m .62608 .86794 L .63018 .88008 L 0 .626 .082 r
F
.62865 .879 m .62372 .88169 L .62677 .88497 L 0 .79 .464 r
F
.62865 .879 m .62452 .87913 L .62372 .88169 L F
.62011 .86997 m .62452 .87913 L .62865 .879 L 0 .714 .45 r
F
.61873 .86583 m .6277 .88728 L .62282 .87798 L 0 .626 .082 r
F
.62865 .879 m .62677 .88497 L .63237 .88717 L 0 .79 .464 r
F
.61873 .86583 m .63086 .88817 L .6277 .88728 L 0 .626 .082 r
F
.62865 .879 m .63237 .88717 L .6368 .88681 L 0 .79 .464 r
F
.61873 .86583 m .63018 .88008 L .63086 .88817 L 0 .626 .082 r
F
.62539 .88776 m .6216 .89424 L .62754 .8962 L 0 .948 .487 r
F
.62539 .88776 m .62754 .8962 L .63275 .89553 L F
.62539 .88776 m .63275 .89553 L .63438 .89275 L F
.62539 .88776 m .63438 .89275 L .63134 .88971 L F
.61955 .89354 m .62282 .87798 L .6277 .88728 L 0 .718 .13 r
F
.61955 .89354 m .61933 .88065 L .62282 .87798 L F
.63275 .89553 m .62838 .9021 L .63456 .90372 L 0 1 .496 r
F
.63275 .89553 m .62567 .89901 L .62838 .9021 L F
.63275 .89553 m .62754 .8962 L .62567 .89901 L F
.61955 .89354 m .6277 .88728 L .63158 .9047 L 0 .718 .13 r
F
.6465 .90004 m .63008 .91402 L .63984 .91276 L 0 1 .496 r
F
.6324 .91259 m .62543 .91996 L .63219 .92115 L 0 1 .506 r
F
.6465 .90004 m .62846 .91094 L .63008 .91402 L 0 1 .496 r
F
.6324 .91259 m .62308 .91691 L .62543 .91996 L 0 1 .506 r
F
.6324 .91259 m .62607 .91376 L .62308 .91691 L F
.61955 .89354 m .62836 .92143 L .62341 .91104 L 0 .718 .13 r
F
.6465 .90004 m .63549 .90495 L .62846 .91094 L 0 1 .496 r
F
.62591 .90508 m .62607 .91376 L .6324 .91259 L 0 1 .499 r
F
.61955 .89354 m .63186 .91869 L .62836 .92143 L 0 .718 .13 r
F
.62591 .90508 m .6324 .91259 L .63514 .90952 L 0 1 .499 r
F
.62591 .90508 m .63514 .90952 L .63244 .9066 L F
.61955 .89354 m .63158 .9047 L .63186 .91869 L 0 .718 .13 r
F
.62184 .9233 m .61992 .93252 L .62741 .93077 L 0 1 .5 r
F
.62184 .9233 m .62741 .93077 L .63128 .9273 L F
.62184 .9233 m .63128 .9273 L .62894 .92441 L F
.61968 .94914 m .6197 .92282 L .62341 .91104 L 0 .679 .182 r
F
.60824 .4914 m .62103 .92583 L .61002 .5127 L 0 .537 .227 r
F
.60206 .53466 m .60526 .57098 L .60951 .56002 L 0 1 .254 r
F
.60171 .59375 m .60951 .56002 L .60526 .57098 L 0 1 .261 r
F
.60533 .47553 m .60785 .58745 L .60699 .51545 L 0 .537 .227 r
F
.60785 .58745 m .60824 .57411 L .60699 .51545 L F
.60873 .77018 m .60653 .78666 L .61188 .78154 L 0 1 .395 r
F
.60785 .58745 m .61424 .90108 L .61398 .86051 L 0 .537 .227 r
F
.60785 .58745 m .60704 .62078 L .61424 .90108 L F
.60533 .47553 m .60699 .61687 L .60785 .58745 L F
.60699 .61687 m .60704 .62078 L .60785 .58745 L F
.60996 .51089 m .60366 .28033 L .60807 .28012 L 0 .61 .226 r
F
.616 .53499 m .61624 .56661 L .62035 .57617 L 0 .744 .302 r
F
.616 .53499 m .61438 .54896 L .61624 .56661 L F
.61257 .4998 m .62025 .47792 L .61584 .4778 L 0 .869 .264 r
F
.61919 .49597 m .62794 .50873 L .62341 .49445 L 0 .639 .289 r
F
.63093 .51566 m .62788 .54966 L .6311 .55501 L 0 1 .312 r
F
.63093 .51566 m .62781 .53277 L .62788 .54966 L F
.61919 .49597 m .63036 .52956 L .62794 .50873 L 0 .639 .289 r
F
.61919 .49597 m .62904 .54301 L .63036 .52956 L F
.61919 .49597 m .62479 .54452 L .62904 .54301 L F
.61919 .49597 m .62046 .53309 L .62479 .54452 L F
.61919 .49597 m .61806 .51228 L .62046 .53309 L F
.61257 .4998 m .62358 .49876 L .62025 .47792 L 0 .869 .264 r
F
.61257 .4998 m .6236 .52659 L .62358 .49876 L F
.616 .53499 m .62479 .54452 L .62046 .53309 L 0 .744 .302 r
F
.62274 .5573 m .6311 .55501 L .62788 .54966 L 0 1 .32 r
F
.62274 .5573 m .63058 .57004 L .6311 .55501 L F
.616 .53499 m .62667 .56218 L .62479 .54452 L 0 .744 .302 r
F
.62274 .5573 m .62664 .58475 L .63058 .57004 L 0 1 .32 r
F
.616 .53499 m .62483 .57427 L .62667 .56218 L 0 .744 .302 r
F
.61257 .4998 m .62034 .54886 L .6236 .52659 L 0 .869 .264 r
F
.616 .53499 m .62035 .57617 L .62483 .57427 L 0 .744 .302 r
F
.61257 .4998 m .61597 .55056 L .62034 .54886 L 0 .869 .264 r
F
.61257 .4998 m .61264 .52945 L .61597 .55056 L F
.61231 .56839 m .62034 .54886 L .61597 .55056 L 0 .994 .274 r
F
.61231 .56839 m .62319 .56379 L .62034 .54886 L F
.61231 .56839 m .62261 .58547 L .62319 .56379 L F
.61231 .56839 m .61896 .60344 L .62261 .58547 L F
.61231 .56839 m .61466 .60562 L .61896 .60344 L F
.61669 .59677 m .61252 .47615 L .61666 .56626 L 0 .61 .226 r
F
.6167 .62202 m .61561 .584 L .61669 .59677 L F
.61561 .584 m .61252 .47615 L .61669 .59677 L F
.6304 .7833 m .63516 .79301 L .64117 .78515 L 0 1 .449 r
F
.6304 .7833 m .64117 .78515 L .63914 .78127 L F
.6421 .74519 m .629 .76188 L .63104 .76575 L 0 1 .435 r
F
.6421 .74519 m .63374 .75307 L .629 .76188 L F
.63634 .73522 m .62596 .75612 L .63374 .75307 L 0 1 .431 r
F
.63634 .73522 m .62392 .7523 L .62596 .75612 L F
.63634 .73522 m .62837 .74334 L .62392 .7523 L F
.63058 .72529 m .62837 .74334 L .63634 .73522 L 0 1 .426 r
F
.62349 .7132 m .62299 .73373 L .63058 .72529 L 0 1 .416 r
F
.63608 .77924 m .62653 .79268 L .62886 .79738 L 0 1 .417 r
F
.63608 .77924 m .62963 .78491 L .62653 .79268 L F
.62965 .76683 m .62304 .78546 L .62963 .78491 L 0 1 .41 r
F
.62965 .76683 m .62963 .78491 L .63608 .77924 L F
.64785 .75515 m .63611 .77545 L .64446 .77266 L 0 1 .439 r
F
.64785 .75515 m .63408 .77156 L .63611 .77545 L F
.64785 .75515 m .63911 .76286 L .63408 .77156 L F
.62965 .76683 m .63608 .77924 L .63892 .77125 L 0 1 .41 r
F
.62965 .76683 m .63892 .77125 L .63625 .76627 L F
.62321 .75386 m .62965 .76683 L .63223 .75861 L 0 1 .402 r
F
.62321 .75386 m .63223 .75861 L .62955 .7534 L F
.62951 .72476 m .62284 .73996 L .62552 .7454 L 0 1 .39 r
F
.62951 .72476 m .62454 .73112 L .62284 .73996 L F
.62951 .72476 m .62552 .7454 L .6315 .7449 L F
.62349 .7132 m .63058 .72529 L .63403 .71522 L 0 1 .416 r
F
.62349 .7132 m .63403 .71522 L .63105 .71024 L F
.62222 .71015 m .62454 .73112 L .62951 .72476 L 0 1 .382 r
F
.63516 .79301 m .62948 .80931 L .6399 .80266 L 0 1 .451 r
F
.63516 .79301 m .6399 .80266 L .64621 .79479 L F
.63516 .79301 m .64621 .79479 L .6442 .79094 L F
.63608 .77924 m .62886 .79738 L .6357 .7967 L 0 1 .417 r
F
.63608 .77924 m .6357 .7967 L .6425 .79109 L F
.63059 .78195 m .63245 .79439 L .63776 .78685 L 0 1 .435 r
F
.63059 .78195 m .62649 .79867 L .63245 .79439 L F
.65358 .76506 m .64117 .78515 L .6498 .78241 L 0 1 .442 r
F
.65358 .76506 m .63914 .78127 L .64117 .78515 L F
.65358 .76506 m .64446 .77266 L .63914 .78127 L F
.63608 .77924 m .6425 .79109 L .64561 .78331 L 0 1 .417 r
F
.63608 .77924 m .64561 .78331 L .64294 .77856 L F
.63059 .78195 m .63776 .78685 L .63952 .77969 L 0 1 .435 r
F
.63059 .78195 m .62385 .79684 L .62649 .79867 L F
.63059 .78195 m .63952 .77969 L .63656 .77767 L F
.63059 .78195 m .62561 .78967 L .62385 .79684 L F
.62342 .77744 m .62561 .78967 L .63059 .78195 L 0 1 .423 r
F
.62342 .77744 m .63059 .78195 L .63211 .77476 L F
.62342 .77744 m .63211 .77476 L .62915 .77291 L F
.6421 .74519 m .63104 .76575 L .63911 .76286 L 0 1 .435 r
F
.63634 .73522 m .63374 .75307 L .6421 .74519 L 0 1 .431 r
F
.63679 .73878 m .63223 .75861 L .63845 .75809 L 0 1 .399 r
F
.63423 .75621 m .62915 .77291 L .63211 .77476 L 0 1 .408 r
F
.63423 .75621 m .63006 .76495 L .62915 .77291 L F
.63679 .73878 m .62955 .7534 L .63223 .75861 L 0 1 .399 r
F
.63679 .73878 m .6315 .7449 L .62955 .7534 L F
.62631 .75175 m .63423 .75621 L .63493 .74826 L 0 1 .395 r
F
.62631 .75175 m .63006 .76495 L .63423 .75621 L F
.62631 .75175 m .6247 .77029 L .63006 .76495 L F
.62631 .75175 m .63493 .74826 L .63167 .74641 L F
.63058 .72529 m .63634 .73522 L .6405 .72608 L 0 1 .426 r
F
.63058 .72529 m .6405 .72608 L .63808 .72201 L F
.62222 .71015 m .62951 .72476 L .63097 .71554 L 0 1 .382 r
F
.62951 .72476 m .6315 .7449 L .63679 .73878 L 0 1 .39 r
F
.62951 .72476 m .6385 .72993 L .63549 .72425 L F
.63634 .73522 m .6421 .74519 L .64655 .73623 L 0 1 .431 r
F
.63634 .73522 m .64655 .73623 L .64414 .73217 L F
.62951 .72476 m .63679 .73878 L .6385 .72993 L 0 1 .39 r
F
.62618 .72313 m .63514 .72755 L .63492 .71867 L 0 1 .366 r
F
.62618 .72313 m .63176 .73753 L .63514 .72755 L F
.62618 .72313 m .63492 .71867 L .63126 .71681 L F
.62618 .72313 m .62668 .74386 L .63176 .73753 L F
.63247 .7794 m .63614 .78494 L .64038 .78472 L 0 1 .491 r
F
.62711 .7211 m .62957 .785 L .63127 .78127 L 0 .459 .231 r
F
.63409 .67901 m .62484 .69988 L .62711 .70366 L 0 1 .392 r
F
.63409 .67901 m .62783 .68931 L .62484 .69988 L F
.62358 .49876 m .63159 .49324 L .627 .48453 L 0 .767 .273 r
F
.63093 .51566 m .63935 .51426 L .63587 .50774 L 0 1 .312 r
F
.63093 .51566 m .63944 .53109 L .63935 .51426 L F
.63093 .51566 m .63606 .54704 L .63944 .53109 L F
.63944 .53109 m .63594 .56318 L .63917 .56872 L 0 1 .322 r
F
.63944 .53109 m .63606 .54704 L .63594 .56318 L F
.63271 .4936 m .63463 .52975 L .63901 .54348 L 0 .415 .28 r
F
.63271 .4936 m .63193 .50838 L .63463 .52975 L F
.62358 .49876 m .63498 .51711 L .63159 .49324 L 0 .767 .273 r
F
.63093 .51566 m .6311 .55501 L .63606 .54704 L 0 1 .312 r
F
.63036 .52957 m .63901 .54348 L .63463 .52975 L 0 .564 .298 r
F
.63944 .53109 m .63917 .56872 L .64433 .56173 L 0 1 .322 r
F
.63036 .52957 m .64119 .56195 L .63901 .54348 L 0 .564 .298 r
F
.62358 .49876 m .63489 .54031 L .63498 .51711 L 0 .767 .273 r
F
.63058 .57004 m .63917 .56872 L .63594 .56318 L 0 1 .331 r
F
.63058 .57004 m .63843 .58327 L .63917 .56872 L F
.63036 .52957 m .63967 .57279 L .64119 .56195 L 0 .564 .298 r
F
.63036 .52957 m .63539 .57257 L .63967 .57279 L F
.63036 .52957 m .63119 .56144 L .63539 .57257 L F
.63036 .52957 m .62904 .54302 L .63119 .56144 L F
.62358 .49876 m .63146 .55472 L .63489 .54031 L 0 .767 .273 r
F
.62358 .49876 m .62698 .55065 L .63146 .55472 L F
.62358 .49876 m .6236 .52659 L .62698 .55065 L F
.63058 .57004 m .62883 .60404 L .6342 .59715 L 0 1 .331 r
F
.63058 .57004 m .62589 .59933 L .62883 .60404 L F
.63058 .57004 m .62664 .58475 L .62589 .59933 L F
.62169 .59149 m .6304 .59971 L .62643 .59036 L 0 .796 .324 r
F
.62747 .6172 m .63618 .61598 L .63324 .61117 L 0 1 .351 r
F
.62169 .59149 m .63145 .61394 L .6304 .59971 L 0 .796 .324 r
F
.62747 .6172 m .63458 .62873 L .63618 .61598 L 0 1 .351 r
F
.62747 .6172 m .6295 .64096 L .63458 .62873 L F
.62747 .6172 m .62372 .64701 L .6295 .64096 L F
.62169 .59149 m .62886 .62357 L .63145 .61394 L 0 .796 .324 r
F
.62169 .59149 m .62411 .62469 L .62886 .62357 L F
.6246 .63744 m .62178 .65834 L .62523 .66551 L 0 .867 .345 r
F
.6246 .63744 m .62151 .64632 L .62178 .65834 L F
.62319 .56379 m .63146 .55472 L .62698 .55065 L 0 .906 .285 r
F
.62668 .56218 m .63539 .57257 L .63119 .56144 L 0 .688 .312 r
F
.63058 .57004 m .6342 .59715 L .63843 .58327 L 0 1 .331 r
F
.63843 .58327 m .6342 .59715 L .63324 .61117 L 0 1 .341 r
F
.62668 .56218 m .637 .58867 L .63539 .57257 L 0 .688 .312 r
F
.62668 .56218 m .63494 .59899 L .637 .58867 L F
.62668 .56218 m .6304 .59971 L .63494 .59899 L F
.62668 .56218 m .62643 .59036 L .6304 .59971 L F
.62668 .56218 m .62483 .57428 L .62643 .59036 L F
.62319 .56379 m .6343 .57232 L .63146 .55472 L 0 .906 .285 r
F
.62319 .56379 m .6336 .59177 L .6343 .57232 L F
.62319 .56379 m .62981 .60502 L .6336 .59177 L F
.62319 .56379 m .62545 .60318 L .62981 .60502 L F
.62319 .56379 m .62261 .58547 L .62545 .60318 L F
.62133 .61486 m .62981 .60502 L .62545 .60318 L 0 1 .297 r
F
.63458 .62873 m .64352 .628 L .64058 .62319 L 0 1 .361 r
F
.63458 .62873 m .64169 .64033 L .64352 .628 L F
.63458 .62873 m .63629 .65196 L .64169 .64033 L F
.63458 .62873 m .63028 .65753 L .63629 .65196 L F
.63458 .62873 m .62766 .6533 L .63028 .65753 L F
.63458 .62873 m .6295 .64096 L .62766 .6533 L F
.63145 .61394 m .63345 .64472 L .63839 .64433 L 0 .763 .334 r
F
.63145 .61394 m .62971 .63676 L .63345 .64472 L F
.63145 .61394 m .62886 .62357 L .62971 .63676 L F
.62133 .61486 m .63212 .61866 L .62981 .60502 L 0 1 .297 r
F
.62133 .61486 m .63084 .63505 L .63212 .61866 L F
.6246 .63744 m .63345 .64472 L .62971 .63676 L 0 .867 .345 r
F
.6246 .63744 m .63373 .65676 L .63345 .64472 L F
.6246 .63744 m .63036 .66483 L .63373 .65676 L F
.62133 .61486 m .62671 .6468 L .63084 .63505 L 0 1 .297 r
F
.6246 .63744 m .62523 .66551 L .63036 .66483 L 0 .867 .345 r
F
.62133 .61486 m .6225 .64604 L .62671 .6468 L 0 1 .297 r
F
.62133 .61486 m .62019 .63233 L .6225 .64604 L F
.6181 .65628 m .62671 .6468 L .6225 .64604 L 0 1 .31 r
F
.6181 .65628 m .62849 .65784 L .62671 .6468 L F
.6181 .65628 m .62665 .67182 L .62849 .65784 L F
.6181 .65628 m .62225 .6821 L .62665 .67182 L F
.62255 .67132 m .61837 .40533 L .62421 .49575 L 0 .586 .223 r
F
.61929 .62853 m .61837 .40533 L .62255 .67132 L F
.63409 .67901 m .62711 .70366 L .63377 .69909 L 0 1 .392 r
F
.62493 .67656 m .62344 .70055 L .62882 .69986 L 0 .945 .365 r
F
.62222 .71015 m .63097 .71554 L .62796 .70961 L 0 1 .382 r
F
.6278 .66878 m .62783 .68931 L .63409 .67901 L 0 1 .383 r
F
.62493 .67656 m .63363 .68251 L .63031 .67587 L 0 .945 .365 r
F
.62493 .67656 m .63299 .69279 L .63363 .68251 L F
.62493 .67656 m .62882 .69986 L .63299 .69279 L F
.6278 .66878 m .63682 .66811 L .63421 .66387 L 0 1 .383 r
F
.6278 .66878 m .63409 .67901 L .63682 .66811 L F
.62849 .65784 m .62665 .67182 L .62819 .68352 L 0 1 .324 r
F
.6235 .69135 m .63207 .68513 L .62819 .68352 L 0 1 .337 r
F
.64038 .68923 m .63105 .71024 L .63403 .71522 L 0 1 .401 r
F
.64038 .68923 m .63377 .69909 L .63105 .71024 L F
.63299 .69279 m .62796 .70961 L .63097 .71554 L 0 .939 .374 r
F
.63299 .69279 m .62882 .69986 L .62796 .70961 L F
.64038 .68923 m .63403 .71522 L .64156 .71193 L 0 1 .401 r
F
.63409 .67901 m .63377 .69909 L .64038 .68923 L 0 1 .392 r
F
.63299 .69279 m .63097 .71554 L .63658 .71501 L 0 .939 .374 r
F
.6235 .69135 m .63304 .69505 L .63207 .68513 L 0 1 .337 r
F
.6235 .69135 m .63045 .70668 L .63304 .69505 L F
.6235 .69135 m .62577 .71453 L .63045 .70668 L F
.62605 .70564 m .62487 .57097 L .62833 .62738 L 0 .586 .223 r
F
.62487 .57097 m .6283 .62632 L .62833 .62738 L F
.62583 .70578 m .62572 .70585 L .62711 .7211 L 0 .459 .231 r
F
.62222 .71015 m .61881 .73165 L .62454 .73112 L 0 1 .382 r
F
.6235 .69135 m .62211 .71335 L .62577 .71453 L 0 1 .337 r
F
.62618 .72313 m .62328 .74232 L .62668 .74386 L 0 1 .366 r
F
.62618 .72313 m .62306 .73343 L .62328 .74232 L F
.61723 .72034 m .62618 .72313 L .62577 .71453 L 0 1 .352 r
F
.61723 .72034 m .62306 .73343 L .62618 .72313 L F
.61723 .72034 m .62577 .71453 L .62211 .71335 L F
.62255 .67132 m .62973 .78929 L .62789 .74126 L 0 .459 .231 r
F
.62255 .67132 m .62789 .74126 L .62711 .7211 L F
.62255 .67132 m .62283 .6422 L .62605 .70564 L 0 .586 .223 r
F
.62283 .6422 m .62421 .49575 L .62605 .70564 L F
.6181 .65628 m .61823 .68182 L .62225 .6821 L 0 1 .31 r
F
.6181 .65628 m .61645 .67074 L .61823 .68182 L F
.61604 .61115 m .61002 .5127 L .6162 .63413 L 0 .537 .227 r
F
.61658 .62586 m .6162 .63413 L .61868 .68279 L F
.61604 .61115 m .6162 .63413 L .61658 .62586 L F
.61778 .80068 m .61833 .81193 L .62413 .80514 L 0 1 .45 r
F
.61778 .80068 m .62413 .80514 L .62649 .79867 L F
.61778 .80068 m .62649 .79867 L .62385 .79684 L F
.61804 .74802 m .62631 .75175 L .62668 .74386 L 0 1 .381 r
F
.61804 .74802 m .62242 .76071 L .62631 .75175 L F
.61804 .74802 m .61718 .76642 L .62242 .76071 L F
.61804 .74802 m .62668 .74386 L .62328 .74232 L F
.61723 .72034 m .61818 .74044 L .62306 .73343 L 0 1 .352 r
F
.61002 .5127 m .61868 .83761 L .61964 .78167 L 0 .537 .227 r
F
.61868 .83761 m .62103 .92583 L .61998 .81681 L F
.61868 .83761 m .61998 .81681 L .61964 .78167 L F
.62605 .70564 m .62628 .71112 L .62711 .7211 L 0 .459 .231 r
F
.62674 .73908 m .62605 .70564 L .62901 .77616 L F
.62024 .83037 m .62568 .83517 L .62946 .82964 L 0 1 .497 r
F
.62024 .83037 m .62946 .82964 L .62717 .82766 L F
.62514 .80507 m .62463 .82528 L .63238 .81969 L 0 1 .426 r
F
.62514 .80507 m .63238 .81969 L .63592 .81112 L F
.63047 .80989 m .62145 .82287 L .62374 .82475 L 0 1 .471 r
F
.63047 .80989 m .62433 .8165 L .62145 .82287 L F
.62342 .77744 m .61988 .7942 L .62561 .78967 L 0 1 .423 r
F
.62631 .75175 m .62173 .76866 L .6247 .77029 L 0 1 .395 r
F
.62631 .75175 m .62242 .76071 L .62173 .76866 L F
.61674 .62252 m .61667 .5751 L .61719 .61269 L 0 .61 .226 r
F
.61667 .5751 m .61666 .56626 L .61678 .57685 L F
.61667 .5751 m .61678 .57685 L .61719 .61269 L F
.62617 .72996 m .62595 .72649 L .62641 .72296 L 0 .586 .223 r
F
.62469 .70647 m .62542 .79488 L .62973 .78929 L 0 .459 .231 r
F
.6194 .6549 m .61666 .56626 L .61837 .40533 L 0 .586 .223 r
F
.61002 .5127 m .61964 .78167 L .61868 .68279 L 0 .537 .227 r
F
.61674 .62252 m .61868 .68279 L .61758 .64799 L F
.61758 .64799 m .61868 .68279 L .61813 .66432 L F
.61758 .64799 m .61813 .66432 L .61755 .64529 L F
.61674 .62252 m .61719 .61269 L .61755 .64529 L 0 .61 .226 r
F
.61758 .64799 m .61755 .64529 L .61726 .63723 L 0 .537 .227 r
F
.6124 .55162 m .61181 .45123 L .6167 .62202 L 0 .61 .226 r
F
.60589 .46322 m .60366 .28033 L .60997 .51204 L F
.6388 .9783 m .6284 .98101 L .62366 .98366 L 0 1 .54 r
F
.62424 .98378 m .62183 .98438 L .62772 .98451 L 0 1 .536 r
F
.62424 .98378 m .62366 .98366 L .62184 .98469 L 0 1 .54 r
F
.6388 .9783 m .62366 .98366 L .62424 .98378 L F
.62772 .98451 m .62183 .98438 L .62346 .98617 L 0 1 .536 r
F
.64053 .98493 m .63278 .98605 L .6259 .98891 L 0 1 .539 r
F
.63959 .98482 m .63278 .98605 L .64053 .98493 L F
.63382 .98504 m .62346 .98617 L .63278 .98605 L 0 1 .536 r
F
.63296 .98497 m .62346 .98617 L .63382 .98504 L F
.62772 .98451 m .62346 .98617 L .63404 .98483 L F
.62772 .98451 m .62184 .98469 L .62347 .98689 L 0 1 .54 r
F
.6388 .9783 m .62424 .98378 L .62772 .98451 L F
.6388 .9783 m .6293 .98362 L .63448 .98423 L F
.6388 .9783 m .63404 .98483 L .6436 .98387 L F
.63404 .98483 m .63278 .98605 L .64024 .9847 L 0 1 .536 r
F
.63404 .98483 m .63279 .98654 L .64024 .9847 L 0 1 .54 r
F
.63404 .98483 m .64024 .9847 L .6436 .98387 L F
.64836 .9882 m .62996 .99358 L .63158 .99548 L 0 1 .541 r
F
.64836 .9882 m .63714 .99046 L .62996 .99358 L F
.64271 .98498 m .62753 .99076 L .63714 .99046 L 0 1 .539 r
F
.64264 .98497 m .62753 .99076 L .64271 .98498 L F
.64158 .98494 m .62753 .99076 L .64276 .98493 L F
.64158 .98494 m .6259 .98891 L .62753 .99076 L F
.64198 .98473 m .64093 .98482 L .64158 .98494 L 0 1 .541 r
F
.6436 .98387 m .64123 .98472 L .64198 .98473 L F
.64123 .98472 m .64093 .98482 L .64198 .98473 L F
.64836 .9882 m .63158 .99548 L .64149 .995 L F
.64836 .9882 m .64149 .995 L .6531 .99246 L F
.64441 .98479 m .63714 .99046 L .64836 .9882 L 0 1 .539 r
F
.64441 .98479 m .63717 .99194 L .64838 .98929 L 0 1 .541 r
F
.6436 .98387 m .64276 .98493 L .64441 .98479 L F
.64276 .98493 m .63714 .99046 L .64441 .98479 L 0 1 .539 r
F
.64276 .98493 m .63717 .99194 L .64441 .98479 L 0 1 .541 r
F
.64361 .98409 m .64276 .98493 L .64441 .98479 L 0 1 .539 r
F
.64093 .98482 m .6259 .98891 L .64158 .98494 L F
.64081 .98485 m .63959 .98482 L .64053 .98493 L F
.64093 .98482 m .63279 .98654 L .62593 .99016 L 0 1 .541 r
F
.6436 .98387 m .64024 .9847 L .64093 .98482 L F
.64093 .98482 m .63993 .98476 L .64081 .98485 L 0 1 .539 r
F
.64024 .9847 m .63993 .98476 L .64093 .98482 L F
.63993 .98476 m .63959 .98482 L .64081 .98485 L F
.64024 .9847 m .63279 .98654 L .64093 .98482 L 0 1 .541 r
F
.64361 .98409 m .64024 .9847 L .64093 .98482 L 0 1 .539 r
F
.63884 .98017 m .63426 .98462 L .64361 .98409 L 0 1 .536 r
F
.63426 .98462 m .63404 .98483 L .63638 .98465 L F
.63426 .98462 m .63638 .98465 L .64361 .98409 L F
.64361 .98409 m .64093 .98482 L .64158 .98494 L 0 1 .539 r
F
.64093 .98482 m .6407 .9849 L .64158 .98494 L 0 1 .541 r
F
.64158 .98494 m .62593 .99016 L .62756 .9923 L F
.6407 .9849 m .62593 .99016 L .64158 .98494 L F
.64276 .98493 m .64264 .98497 L .64271 .98498 L 0 1 .539 r
F
.6436 .98387 m .64158 .98494 L .64276 .98493 L 0 1 .541 r
F
.64361 .98409 m .64158 .98494 L .64276 .98493 L 0 1 .539 r
F
.64276 .98493 m .64158 .98494 L .64266 .98505 L 0 1 .541 r
F
.64266 .98505 m .62756 .9923 L .63717 .99194 L F
.64158 .98494 m .62756 .9923 L .64266 .98505 L F
.63404 .98483 m .64024 .9847 L .64361 .98409 L 0 1 .536 r
F
.63884 .98017 m .62841 .98181 L .62366 .98366 L F
.62424 .98378 m .62366 .98366 L .62183 .98438 L F
.63884 .98017 m .62366 .98366 L .62424 .98378 L F
.62424 .98378 m .62333 .98413 L .62772 .98451 L 0 1 .54 r
F
.62333 .98413 m .62184 .98469 L .62772 .98451 L F
.63404 .98483 m .63296 .98497 L .63382 .98504 L 0 1 .536 r
F
.63448 .98423 m .63234 .98474 L .63404 .98483 L 0 1 .54 r
F
.6293 .98362 m .62347 .98689 L .63448 .98423 L F
.63884 .98017 m .62772 .98451 L .63404 .98483 L 0 1 .536 r
F
.63404 .98483 m .62347 .98689 L .63279 .98654 L 0 1 .54 r
F
.63234 .98474 m .62347 .98689 L .63404 .98483 L F
.63884 .98017 m .62424 .98378 L .62772 .98451 L 0 1 .536 r
F
.63406 .97651 m .61938 .98176 L .62841 .98181 L 0 1 .528 r
F
.61068 .62029 m .60966 .63771 L .61204 .64921 L 0 1 .285 r
F
.61938 .95304 m .62427 .95999 L .62961 .95585 L 0 1 .519 r
F
.61938 .95304 m .62961 .95585 L .62753 .9531 L F
.6136 .69077 m .61146 .703 L .61271 .71227 L 0 1 .323 r
F
.6225 .96197 m .62044 .96365 L .62797 .96211 L 0 .798 .245 r
F
.62427 .95999 m .63479 .96242 L .63272 .95985 L 0 1 .528 r
F
.62687 .95892 m .62039 .9615 L .62689 .95973 L 0 .801 .226 r
F
.62687 .95892 m .61807 .96183 L .62039 .9615 L F
.62687 .95892 m .62085 .96073 L .61807 .96183 L F
.62047 .96062 m .62085 .96073 L .62687 .95892 L 0 .742 .205 r
F
.62047 .96062 m .62687 .95892 L .62941 .95813 L F
.62047 .96062 m .62941 .95813 L .62674 .95888 L F
.62666 .95903 m .62006 .96112 L .62274 .96016 L 0 0 0 r
F
.62666 .95903 m .62174 .96064 L .62006 .96112 L F
.61939 .9627 m .62174 .96064 L .62666 .95903 L F
.61939 .9627 m .62666 .95903 L .62811 .95902 L F
.61939 .9627 m .62811 .95902 L .62511 .96062 L F
.6225 .96197 m .62797 .96211 L .63191 .96093 L 0 .798 .245 r
F
.6225 .96197 m .63191 .96093 L .62961 .96089 L F
.62174 .96526 m .6205 .96327 L .62597 .96074 L 0 0 0 r
F
.62174 .96526 m .61735 .96521 L .6205 .96327 L F
.62174 .96526 m .61788 .96606 L .61735 .96521 L F
.617 .85086 m .61603 .84702 L .61878 .84952 L 0 .404 .009 r
F
.6215 .97179 m .61859 .96972 L .62205 .96683 L 0 0 0 r
F
.6215 .97179 m .61835 .97185 L .61859 .96972 L F
.62914 .96644 m .63398 .97251 L .63995 .96862 L 0 1 .534 r
F
.62445 .97026 m .62926 .97317 L .63497 .97163 L 0 1 .478 r
F
.61844 .98468 m .62588 .97175 L .62857 .97174 L 0 0 .039 r
F
.61844 .98468 m .62095 .97495 L .62588 .97175 L F
.62926 .97317 m .62402 .97781 L .63406 .97651 L 0 1 .512 r
F
.61844 .98468 m .62857 .97174 L .62752 .9759 L 0 0 .039 r
F
.61844 .98468 m .62752 .9759 L .6234 .98147 L F
.61968 .94914 m .62341 .91104 L .62836 .92143 L 0 .679 .182 r
F
.63469 .93996 m .62441 .94883 L .63223 .94928 L 0 1 .517 r
F
.63469 .93996 m .62232 .94587 L .62441 .94883 L F
.63469 .93996 m .62672 .94207 L .62232 .94587 L F
.62741 .93077 m .62672 .94207 L .63469 .93996 L 0 1 .509 r
F
.62741 .93077 m .63469 .93996 L .63838 .9357 L F
.62741 .93077 m .63838 .9357 L .63533 .93214 L F
.61968 .94914 m .62836 .92143 L .63205 .94789 L 0 .679 .182 r
F
.62001 1.03254 m .63015 .99826 L .63125 1.00134 L 0 .135 .104 r
F
.62001 1.03254 m .626 1.00338 L .63015 .99826 L F
.62001 1.03254 m .62154 1.01333 L .626 1.00338 L F
.62001 1.03254 m .63125 1.00134 L .62871 1.0138 L F
.62914 .96644 m .63995 .96862 L .63789 .96618 L 0 1 .534 r
F
.62445 .97026 m .63497 .97163 L .63292 .97055 L 0 1 .478 r
F
.64059 .94693 m .62961 .95585 L .63772 .95602 L 0 1 .524 r
F
.64059 .94693 m .62753 .9531 L .62961 .95585 L F
.64059 .94693 m .63223 .94928 L .62753 .9531 L F
.65232 .95971 m .63789 .96618 L .63995 .96862 L 0 1 .534 r
F
.65232 .95971 m .64318 .96237 L .63789 .96618 L F
.64094 .96438 m .62985 .96909 L .63796 .96824 L 0 1 .429 r
F
.64094 .96438 m .62781 .96821 L .62985 .96909 L F
.64094 .96438 m .63255 .96619 L .62781 .96821 L F
.63513 .96303 m .62473 .96707 L .63255 .96619 L 0 1 .364 r
F
.63513 .96303 m .62268 .96642 L .62473 .96707 L F
.63513 .96303 m .62713 .96469 L .62268 .96642 L F
.62797 .96211 m .62712 .96469 L .63513 .96303 L 0 .916 .28 r
F
.64647 .9535 m .63479 .96242 L .64318 .96237 L 0 1 .529 r
F
.64647 .9535 m .63272 .95985 L .63479 .96242 L F
.62797 .96211 m .63513 .96303 L .63889 .96154 L 0 .916 .28 r
F
.62797 .96211 m .63889 .96154 L .63589 .96121 L F
.63962 .957 m .63191 .96093 L .63891 .95916 L 0 .978 .27 r
F
.64647 .9535 m .63772 .95602 L .63272 .95985 L 0 1 .529 r
F
.63962 .957 m .62961 .96089 L .63191 .96093 L 0 .978 .27 r
F
.63962 .957 m .63291 .95921 L .62961 .96089 L F
.63326 .95772 m .62616 .96098 L .63291 .95921 L 0 .845 .244 r
F
.63326 .95772 m .62385 .96113 L .62616 .96098 L F
.63326 .95772 m .62689 .95973 L .62385 .96113 L F
.62687 .95892 m .62689 .95973 L .63326 .95772 L 0 .801 .226 r
F
.62687 .95892 m .63326 .95772 L .63605 .95661 L F
.62687 .95892 m .63605 .95661 L .6334 .95716 L F
.6339 .95596 m .62941 .95813 L .63556 .95582 L 0 .801 .21 r
F
.6339 .95596 m .62674 .95888 L .62941 .95813 L F
.6339 .95596 m .62866 .95795 L .62674 .95888 L F
.62666 .95903 m .62866 .95795 L .6339 .95596 L 0 0 0 r
F
.62666 .95903 m .62274 .96016 L .62866 .95795 L F
.62666 .95903 m .6339 .95596 L .63559 .95547 L F
.62666 .95903 m .63559 .95547 L .6326 .95681 L F
.63013 .9593 m .62811 .95902 L .63368 .95634 L F
.63013 .9593 m .62511 .96062 L .62811 .95902 L F
.64059 .94693 m .63772 .95602 L .64647 .9535 L 0 1 .524 r
F
.64111 .95348 m .6334 .95716 L .63605 .95661 L 0 .865 .234 r
F
.64111 .95348 m .63556 .95582 L .6334 .95716 L F
.6339 .95596 m .63556 .95582 L .64111 .95348 L 0 .801 .21 r
F
.6339 .95596 m .64111 .95348 L .64305 .95254 L F
.63013 .9593 m .63368 .95634 L .63813 .95435 L 0 0 0 r
F
.63013 .9593 m .62597 .96074 L .62511 .96062 L F
.63013 .9593 m .63813 .95435 L .63901 .95447 L F
.62174 .96526 m .62597 .96074 L .63013 .95931 L F
.63013 .9593 m .63901 .95447 L .63572 .95661 L F
.62174 .96526 m .63013 .95931 L .63067 .96015 L F
.63326 .95772 m .63291 .95921 L .63962 .957 L 0 .845 .244 r
F
.63326 .95772 m .63962 .957 L .64268 .9556 L F
.63326 .95772 m .64268 .9556 L .64003 .95594 L F
.64111 .95348 m .63605 .95661 L .64243 .95422 L 0 .865 .234 r
F
.6306 .96301 m .636 .95692 L .63966 .95517 L 0 0 0 r
F
.6306 .96301 m .63067 .96015 L .636 .95692 L F
.62174 .96526 m .63067 .96015 L .62723 .96273 L F
.6306 .96301 m .62723 .96273 L .63067 .96015 L F
.6306 .96301 m .63966 .95517 L .63965 .95639 L F
.6306 .96301 m .62719 .96395 L .62723 .96273 L F
.6306 .96301 m .63965 .95639 L .63594 .95976 L F
.6215 .97179 m .62719 .96395 L .6306 .96301 L F
.6215 .97179 m .6306 .96301 L .63038 .96512 L F
.63513 .96303 m .63255 .96619 L .64094 .96438 L 0 1 .364 r
F
.63513 .96303 m .64094 .96438 L .64542 .96265 L F
.64647 .9535 m .64318 .96237 L .65232 .95971 L 0 1 .529 r
F
.63513 .96303 m .64542 .96265 L .64298 .96215 L 0 1 .364 r
F
.64596 .95677 m .63589 .96121 L .63889 .96154 L 0 1 .338 r
F
.62857 .97174 m .63534 .96145 L .63825 .96032 L 0 0 0 r
F
.62857 .97174 m .63038 .96512 L .63534 .96145 L F
.6215 .97179 m .63038 .96512 L .62666 .9689 L F
.62857 .97174 m .62666 .9689 L .63038 .96512 L F
.62857 .97174 m .63825 .96032 L .6375 .96315 L F
.62857 .97174 m .6375 .96315 L .63356 .96805 L F
.63398 .97251 m .6388 .9783 L .64508 .97452 L 0 1 .538 r
F
.63398 .97251 m .64508 .97452 L .64303 .97219 L F
.62926 .97317 m .63406 .97651 L .64007 .9746 L 0 1 .512 r
F
.62926 .97317 m .64007 .9746 L .63803 .97336 L F
.62385 .98872 m .63225 .97179 L .63446 .97185 L 0 0 .053 r
F
.62385 .98872 m .62752 .9759 L .63225 .97179 L F
.62804 .96529 m .63205 .94789 L .63202 .97298 L 0 .679 .182 r
F
.61968 .94914 m .62923 .94818 L .62804 .96529 L F
.62923 .94818 m .63205 .94789 L .62804 .96529 L F
.61923 1.22159 m .61975 1.23291 L .61916 1.23885 L 0 0 .042 r
F
.62416 1.0589 m .62977 1.06167 L .63381 1.06277 L 0 .43 .236 r
F
.62416 1.0589 m .63381 1.06277 L .63145 1.06186 L F
.62875 1.06392 m .62201 1.05787 L .62871 1.06155 L 0 0 0 r
F
.62218 1.06217 m .62252 1.05936 L .62875 1.06392 L 0 .065 0 r
F
.643 1.06738 m .62957 1.06629 L .63166 1.06748 L 0 .65 .3 r
F
.643 1.06738 m .63442 1.06625 L .62957 1.06629 L F
.63708 1.06496 m .62643 1.06441 L .63442 1.06625 L 0 .588 .285 r
F
.62218 1.06217 m .62875 1.06392 L .63139 1.06699 L 0 .065 0 r
F
.62218 1.06217 m .63139 1.06699 L .62866 1.06651 L F
.62874 1.07598 m .62181 1.06503 L .62455 1.06567 L 0 .256 .009 r
F
.62874 1.07598 m .62359 1.06944 L .62181 1.06503 L F
.63406 .97651 m .62841 .98181 L .63884 .98017 L 0 1 .528 r
F
.6388 .9783 m .6436 .98387 L .65019 .98018 L 0 1 .54 r
F
.6388 .9783 m .65019 .98018 L .64815 .97794 L F
.63406 .97651 m .63884 .98017 L .64515 .97792 L 0 1 .528 r
F
.63406 .97651 m .64515 .97792 L .64312 .97655 L F
.65815 .96563 m .64303 .97219 L .64508 .97452 L 0 1 .536 r
F
.65815 .96563 m .64862 .96838 L .64303 .97219 L F
.65251 .9685 m .63803 .97336 L .64007 .9746 L 0 1 .503 r
F
.65251 .9685 m .64335 .97075 L .63803 .97336 L F
.62814 .99417 m .6374 .97193 L .63909 .97199 L 0 0 .062 r
F
.62814 .99417 m .63291 .97732 L .6374 .97193 L F
.62814 .99417 m .62861 .98458 L .63291 .97732 L F
.62814 .99417 m .63909 .97199 L .63707 .97918 L F
.62814 .99417 m .62656 .99181 L .62861 .98458 L F
.62814 .99417 m .63707 .97918 L .63265 .98875 L F
.6219 1.05425 m .63253 1.00645 L .63314 1.01019 L 0 .124 .111 r
F
.6219 1.05425 m .62871 1.0138 L .63253 1.00645 L F
.62001 1.03254 m .62871 1.0138 L .6242 1.02738 L 0 .135 .104 r
F
.6219 1.05425 m .6242 1.02738 L .62871 1.0138 L 0 .124 .111 r
F
.6219 1.05425 m .63314 1.01019 L .63025 1.02746 L F
.62977 1.06167 m .62889 1.06332 L .63708 1.06496 L 0 .506 .252 r
F
.63529 1.06539 m .62556 1.05943 L .62792 1.06043 L 0 0 0 r
F
.63529 1.06539 m .62871 1.06155 L .62556 1.05943 L F
.62616 1.06804 m .63104 1.07092 L .63685 1.07028 L 0 .982 .409 r
F
.62616 1.06804 m .63685 1.07028 L .63478 1.06919 L F
.62874 1.07598 m .62455 1.06567 L .6307 1.0704 L 0 .256 .009 r
F
.6228 1.08563 m .63025 1.02746 L .63366 1.01574 L 0 .096 .115 r
F
.6219 1.05425 m .63025 1.02746 L .62576 1.04683 L 0 .124 .111 r
F
.6228 1.08563 m .62576 1.04683 L .63025 1.02746 L 0 .096 .115 r
F
.6228 1.08563 m .62256 1.07177 L .62576 1.04683 L F
.61987 1.0807 m .62828 .98507 L .63088 1.01472 L 0 .576 .21 r
F
.62953 1.03649 m .63088 1.01472 L .63126 1.01911 L F
.62977 1.06167 m .63708 1.06496 L .64094 1.06537 L 0 .506 .252 r
F
.62977 1.06167 m .64094 1.06537 L .63787 1.06428 L F
.63529 1.06539 m .62792 1.06043 L .63487 1.06353 L 0 0 0 r
F
.62875 1.06392 m .62871 1.06155 L .63529 1.06539 L F
.643 1.06738 m .63166 1.06748 L .63993 1.0689 L 0 .65 .3 r
F
.63708 1.06496 m .63442 1.06625 L .643 1.06738 L 0 .588 .285 r
F
.62875 1.06392 m .63529 1.06539 L .6382 1.068 L 0 0 0 r
F
.62875 1.06392 m .6382 1.068 L .63548 1.06763 L F
.63589 1.07358 m .63011 1.07615 L .64073 1.07612 L 0 .972 .383 r
F
.63104 1.07092 m .63589 1.07358 L .64202 1.07288 L 0 .972 .391 r
F
.63104 1.07092 m .64202 1.07288 L .63996 1.07186 L F
.63618 1.07608 m .62866 1.06651 L .63139 1.06699 L 0 .183 0 r
F
.63618 1.07608 m .6307 1.0704 L .62866 1.06651 L F
.63263 1.09537 m .62722 1.08085 L .63031 1.08088 L 0 .352 .064 r
F
.63263 1.09537 m .62821 1.08704 L .62722 1.08085 L F
.62397 1.09606 m .6282 1.08704 L .63263 1.09537 L 0 .448 .073 r
F
.62397 1.09606 m .63263 1.09537 L .63329 1.1021 L F
.62397 1.09606 m .63329 1.1021 L .62974 1.1027 L F
.62408 1.12405 m .62438 1.10298 L .62983 1.11135 L 0 .591 .101 r
F
.62408 1.12405 m .62983 1.11135 L .63354 1.12233 L F
.62408 1.12405 m .63354 1.12233 L .63343 1.13142 L F
.62408 1.12405 m .63343 1.13142 L .62957 1.1325 L F
.62134 1.1604 m .62361 1.13285 L .62893 1.14442 L 0 .692 .128 r
F
.62134 1.1604 m .62893 1.14442 L .63197 1.15932 L F
.63154 1.03179 m .63366 1.01574 L .63373 1.01833 L 0 .096 .115 r
F
.6228 1.08563 m .63179 1.02779 L .63154 1.03179 L F
.63179 1.02779 m .63366 1.01574 L .63154 1.03179 L F
.6228 1.13154 m .63059 1.04417 L .6322 1.03189 L 0 .038 .114 r
F
.6228 1.13152 m .63059 1.04417 L .6228 1.13154 L F
.62275 1.13209 m .6322 1.03189 L .63128 1.04462 L F
.6228 1.13147 m .62507 1.10823 L .62528 1.10497 L F
.6228 1.13155 m .62507 1.10823 L .6228 1.13147 L F
.62507 1.10823 m .63128 1.04462 L .62528 1.10497 L F
.62528 1.10497 m .63128 1.04462 L .63071 1.04673 L F
.62281 1.13143 m .63041 1.04988 L .62976 1.05831 L F
.62281 1.13143 m .62976 1.05831 L .62955 1.06078 L F
.6228 1.13147 m .63041 1.04988 L .62281 1.13143 L F
.62134 1.1604 m .63197 1.15932 L .63102 1.17122 L 0 .692 .128 r
F
.62275 1.13209 m .62625 1.07374 L .63059 1.04417 L 0 .038 .114 r
F
.62134 1.1604 m .63102 1.17122 L .62669 1.17211 L 0 .692 .128 r
F
.62275 1.13209 m .62963 1.05992 L .62566 1.10979 L 0 .038 .114 r
F
.62183 1.19994 m .6223 1.16995 L .62566 1.10979 L 0 0 .098 r
F
.62183 1.19994 m .62667 1.08256 L .62505 1.10864 L F
.62387 1.14194 m .62476 1.1168 L .62405 1.14365 L F
.62476 1.1168 m .62494 1.11549 L .62405 1.14365 L F
.6228 1.08563 m .63373 1.01833 L .6334 1.02156 L 0 .096 .115 r
F
.61987 1.0807 m .63088 1.01472 L .62953 1.03649 L 0 .576 .21 r
F
.64838 .98929 m .63 .9955 L .63162 .99761 L 0 1 .541 r
F
.64838 .98929 m .63717 .99194 L .63 .9955 L F
.6228 1.08563 m .6334 1.02156 L .63059 1.04417 L 0 .096 .115 r
F
.6334 1.02156 m .63375 1.01941 L .63323 1.02352 L F
.6334 1.02156 m .63323 1.02352 L .63059 1.04417 L F
.6228 1.08563 m .63059 1.04417 L .62625 1.07374 L F
.62183 1.19994 m .62566 1.10979 L .62963 1.05992 L 0 0 .098 r
F
.6275 1.09007 m .63109 1.02238 L .6305 1.03203 L F
.62765 1.08839 m .63126 1.01911 L .6275 1.09007 L F
.62955 1.06078 m .62976 1.05831 L .62963 1.05992 L 0 .038 .114 r
F
.63128 1.04462 m .6322 1.03189 L .63344 1.02241 L F
.6277 1.09396 m .62963 1.05992 L .62974 1.0572 L 0 0 .098 r
F
.62784 1.09205 m .62963 1.05992 L .6277 1.09396 L F
.63071 1.04673 m .63344 1.02241 L .63294 1.02275 L 0 .038 .114 r
F
.63128 1.04462 m .63344 1.02241 L .63071 1.04673 L F
.63041 1.04988 m .63294 1.02275 L .63015 1.05406 L F
.63041 1.04988 m .63015 1.05406 L .62963 1.05992 L F
.62879 1.06644 m .62974 1.0572 L .63006 1.04911 L 0 0 .098 r
F
.62961 1.05079 m .63006 1.04911 L .63126 1.01911 L F
.62879 1.06644 m .63006 1.04911 L .62961 1.05079 L F
.62183 1.19994 m .62974 1.0572 L .62879 1.06644 L F
.62183 1.19994 m .6305 1.03203 L .62667 1.08256 L F
.63708 1.06496 m .643 1.06738 L .6476 1.06762 L 0 .588 .285 r
F
.63708 1.06496 m .6476 1.06762 L .64511 1.0668 L F
.6418 1.06668 m .63145 1.06186 L .63381 1.06277 L 0 0 0 r
F
.6418 1.06668 m .63487 1.06353 L .63145 1.06186 L F
.63589 1.07358 m .64073 1.07612 L .64717 1.07537 L 0 .972 .383 r
F
.63589 1.07358 m .64717 1.07537 L .64511 1.07439 L F
.6489 1.06961 m .63478 1.06919 L .63685 1.07028 L 0 .719 .311 r
F
.6489 1.06961 m .63993 1.0689 L .63478 1.06919 L F
.63618 1.07608 m .63139 1.06699 L .63777 1.07096 L 0 .183 0 r
F
.62874 1.07598 m .6307 1.0704 L .63618 1.07608 L 0 .256 .009 r
F
.62791 1.07456 m .63185 1.02585 L .63166 1.07169 L 0 .576 .21 r
F
.62275 1.13209 m .62288 1.11145 L .62625 1.07374 L 0 .038 .114 r
F
.61987 1.0807 m .62924 1.03779 L .62697 1.07528 L 0 .576 .21 r
F
.62924 1.03779 m .62953 1.03649 L .62801 1.0595 L F
.62924 1.03779 m .62801 1.0595 L .62697 1.07528 L F
.62505 1.10864 m .62552 1.09835 L .62527 1.10239 L 0 0 .098 r
F
.62183 1.19994 m .62765 1.08839 L .6275 1.09007 L F
.62183 1.19994 m .62784 1.09205 L .6277 1.09396 L F
.62585 1.07613 m .62697 1.07528 L .62527 1.10239 L 0 .576 .21 r
F
.6253 1.10453 m .62543 1.10034 L .62505 1.10864 L 0 0 .098 r
F
.62667 1.08256 m .62543 1.10034 L .6253 1.10453 L F
.62667 1.08256 m .63026 .99535 L .62543 1.10034 L F
.64073 1.07612 m .63452 1.07875 L .64554 1.07862 L 0 .987 .384 r
F
.62874 1.07598 m .63618 1.07608 L .638 1.08052 L 0 .256 .009 r
F
.62874 1.07598 m .638 1.08052 L .63493 1.08074 L F
.65033 1.08111 m .63158 1.08236 L .63321 1.08345 L 0 1 .401 r
F
.65033 1.08111 m .63891 1.08136 L .63158 1.08236 L F
.63263 1.09537 m .63031 1.08088 L .63614 1.08633 L 0 .352 .064 r
F
.62527 1.10239 m .63166 1.07169 L .62805 1.11357 L 0 .576 .21 r
F
.62953 1.03649 m .6305 1.03203 L .62697 1.07528 L F
.62953 1.03649 m .63126 1.01911 L .63098 1.02393 L F
.63109 1.02238 m .63126 1.01911 L .6305 1.03203 L 0 0 .098 r
F
.62953 1.03649 m .63138 1.02045 L .6305 1.03203 L 0 .576 .21 r
F
.64838 .98929 m .63162 .99761 L .64153 .99723 L 0 1 .541 r
F
.63125 1.00134 m .63015 .99826 L .63265 .98875 L 0 0 .066 r
F
.62667 1.08256 m .63158 1.01114 L .63026 .99535 L 0 0 .098 r
F
.6305 1.03203 m .63158 1.01114 L .62667 1.08256 L F
.62697 1.07528 m .63166 1.07169 L .62527 1.10239 L 0 .576 .21 r
F
.62527 1.10239 m .6257 1.0945 L .62537 1.09945 L 0 0 .098 r
F
.62552 1.09835 m .6257 1.0945 L .62527 1.10239 L F
.62537 1.09945 m .63026 .99535 L .62699 1.05349 L F
.6257 1.0945 m .63026 .99535 L .62537 1.09945 L F
.61987 1.0807 m .62527 1.10239 L .62343 1.12289 L 0 .576 .21 r
F
.62527 1.10239 m .62559 1.10368 L .62482 1.12009 L F
.62494 1.11524 m .62482 1.12009 L .62405 1.14365 L 0 0 .098 r
F
.62527 1.10239 m .62482 1.12009 L .62343 1.12289 L 0 .576 .21 r
F
.62183 1.19994 m .62387 1.14194 L .62387 1.14911 L 0 0 .098 r
F
.62767 1.209 m .62669 1.17211 L .63102 1.17122 L 0 .671 .157 r
F
.62767 1.209 m .62524 1.18824 L .62669 1.17211 L F
.62377 1.30836 m .62578 1.26105 L .63105 1.26474 L 0 .489 .167 r
F
.62377 1.30836 m .62179 1.27052 L .62578 1.26105 L F
.62377 1.30836 m .63105 1.26474 L .63413 1.27917 L F
.62613 1.24476 m .63164 1.21247 L .63538 1.22243 L 0 .41 .141 r
F
.62613 1.24476 m .63538 1.22243 L .63538 1.23712 L F
.62613 1.24476 m .63538 1.23712 L .6316 1.24673 L F
.62119 1.27028 m .62602 1.22329 L .63105 1.24481 L 0 .742 .178 r
F
.62119 1.27028 m .62138 1.22142 L .62602 1.22329 L F
.62377 1.30836 m .63413 1.27917 L .63331 1.2995 L 0 .489 .167 r
F
.63414 1.27916 m .63106 1.26473 L .6316 1.24673 L 0 .375 .155 r
F
.62119 1.27028 m .63105 1.24481 L .63313 1.27188 L 0 .742 .178 r
F
.62377 1.30836 m .63331 1.2995 L .6291 1.31213 L 0 .489 .167 r
F
.61916 1.2364 m .62048 1.22853 L .62288 1.17238 L 0 .896 .089 r
F
.62346 1.15678 m .62288 1.17238 L .62387 1.14911 L F
.62328 1.1617 m .62343 1.12289 L .62346 1.15678 L 0 .442 .218 r
F
.62119 1.27028 m .63313 1.27188 L .63108 1.29229 L 0 .742 .178 r
F
.62119 1.27028 m .63108 1.29229 L .62625 1.29219 L F
.61657 1.40617 m .62276 1.38064 L .61989 1.40677 L 0 .795 .2 r
F
.6224 1.38306 m .62153 1.29343 L .62343 1.12289 L 0 .442 .218 r
F
.61916 1.2364 m .62288 1.17238 L .62346 1.15678 L 0 .896 .089 r
F
.62434 1.41931 m .62431 1.40097 L .6288 1.3868 L 0 .535 .196 r
F
.62333 1.41933 m .62431 1.40097 L .62434 1.41931 L F
.61989 1.40677 m .62276 1.38064 L .62525 1.40773 L 0 .795 .2 r
F
.6224 1.38306 m .62328 1.1617 L .62365 1.38285 L 0 .442 .218 r
F
.62328 1.1617 m .62346 1.15678 L .62365 1.38285 L F
.62548 1.36181 m .62384 1.32177 L .62625 1.29219 L 0 .696 .195 r
F
.62365 1.38285 m .62346 1.15678 L .62805 1.11357 L 0 .442 .218 r
F
.62387 1.14194 m .62405 1.14365 L .62387 1.14911 L 0 0 .098 r
F
.62346 1.15678 m .62343 1.12289 L .62482 1.12009 L 0 .442 .218 r
F
.62346 1.15678 m .62387 1.14911 L .62482 1.12009 L 0 .896 .089 r
F
.62346 1.15678 m .62482 1.12009 L .62805 1.11357 L 0 .442 .218 r
F
.62072 1.20747 m .62346 1.15678 L .62482 1.12009 L 0 .896 .089 r
F
.61916 1.2364 m .62072 1.20747 L .62498 1.11514 L F
.62072 1.20747 m .62482 1.12009 L .62498 1.11514 L F
.62559 1.10368 m .62805 1.11357 L .62482 1.12009 L 0 .576 .21 r
F
.62508 1.11093 m .62499 1.11486 L .62482 1.12009 L 0 0 .098 r
F
.62508 1.11093 m .62482 1.12009 L .62494 1.11524 L F
.62597 1.08239 m .62613 1.08001 L .62499 1.11486 L F
.62597 1.08239 m .62499 1.11486 L .62508 1.11093 L F
.61987 1.0807 m .62378 1.07772 L .62322 1.09414 L 0 .576 .21 r
F
.61921 1.21162 m .62011 1.07904 L .61942 1.10296 L 0 .896 .089 r
F
.61916 1.2364 m .61933 1.20806 L .61921 1.21162 L F
.61933 1.20806 m .62011 1.07904 L .61921 1.21162 L F
.62322 1.09414 m .62585 1.07613 L .62527 1.10239 L 0 .576 .21 r
F
.62378 1.07772 m .62585 1.07613 L .62322 1.09414 L F
.6237 1.13043 m .62457 1.1201 L .62699 1.05349 L 0 .896 .089 r
F
.62476 1.1168 m .62597 1.08239 L .62494 1.11549 L 0 0 .098 r
F
.62457 1.1201 m .62498 1.11514 L .62516 1.10957 L 0 .896 .089 r
F
.62597 1.08239 m .62699 1.05349 L .62613 1.08001 L 0 0 .098 r
F
.62457 1.1201 m .62516 1.10957 L .62699 1.05349 L 0 .896 .089 r
F
.62697 1.07528 m .6305 1.03203 L .62791 1.07456 L 0 .576 .21 r
F
.6305 1.03203 m .63185 1.02585 L .62791 1.07456 L F
.61916 1.2364 m .62498 1.11514 L .6237 1.13043 L 0 .896 .089 r
F
.62275 1.13209 m .6228 1.13155 L .6228 1.13147 L 0 .038 .114 r
F
.62275 1.13209 m .6228 1.13147 L .62281 1.13143 L F
.62275 1.13209 m .6228 1.13152 L .6228 1.13154 L F
.6334 1.02156 m .63373 1.01833 L .63375 1.01941 L 0 .096 .115 r
F
.63098 1.02393 m .63126 1.01911 L .63138 1.02045 L 0 .576 .21 r
F
.6305 1.03203 m .63126 1.01911 L .63158 1.01114 L 0 0 .098 r
F
.6305 1.03203 m .63138 1.02045 L .63185 1.02585 L 0 .576 .21 r
F
.6215 .97179 m .62205 .96683 L .62719 .96395 L 0 0 0 r
F
.62385 .98872 m .6234 .98147 L .62752 .9759 L 0 0 .053 r
F
.62385 .98872 m .63446 .97185 L .63291 .97732 L F
.62385 .98872 m .63291 .97732 L .62861 .98458 L F
.61968 .94914 m .62828 .98507 L .62335 .97591 L 0 .679 .182 r
F
.62857 .97174 m .62588 .97174 L .62666 .9689 L 0 0 0 r
F
.61968 .94914 m .63202 .97298 L .62828 .98507 L 0 .679 .182 r
F
.62385 .98872 m .62182 .98696 L .6234 .98147 L 0 0 .053 r
F
.6219 1.05425 m .62127 1.04472 L .6242 1.02738 L 0 .124 .111 r
F
.61987 1.0807 m .62335 .97591 L .62828 .98507 L 0 .576 .21 r
F
.61987 1.0807 m .61975 1.01638 L .62335 .97591 L F
.62011 1.07904 m .62103 .92583 L .61957 1.08673 L 0 .896 .089 r
F
.62011 1.07904 m .61957 1.08673 L .61942 1.10296 L F
.60824 .4914 m .61942 1.10296 L .62103 .92583 L 0 .537 .227 r
F
.60587 .46296 m .60366 .28033 L .60589 .46322 L 0 .61 .226 r
F
.602 .27935 m .60589 .46322 L .60824 .4914 L 0 .537 .227 r
F
.60589 .46322 m .61942 1.10296 L .60824 .4914 L F
.60533 .47553 m .60699 .51545 L .60589 .46322 L F
.60533 .47553 m .60589 .46322 L .60493 .45173 L F
.6096 .96477 m .61453 1.04496 L .60952 .96324 L 0 0 .042 r
F
.6096 .96477 m .61043 .98088 L .61453 1.04496 L F
.61457 1.04517 m .61453 1.04496 L .61519 1.05539 L F
.60952 .96324 m .61519 1.05539 L .61055 1.03109 L F
.60503 .79303 m .6063 .80374 L .61141 .79661 L 0 1 .423 r
F
.60976 .74569 m .60632 .76254 L .60942 .7634 L 0 1 .366 r
F
.60976 .74569 m .60646 .75495 L .60632 .76254 L F
.60792 .72008 m .60605 .7386 L .60958 .73869 L 0 1 .336 r
F
.60688 .83814 m .60682 .83331 L .61048 .84204 L 0 .677 .061 r
F
.60641 .85594 m .60671 .84783 L .61074 .86009 L 0 .896 .098 r
F
.61195 .96566 m .60587 .46296 L .61204 .96762 L 0 .61 .226 r
F
.60587 .46296 m .60589 .46322 L .61289 1.03638 L F
.60587 .46296 m .61289 1.03638 L .61288 1.03646 L F
.61861 1.38023 m .61883 1.32095 L .6186 1.38191 L 0 .276 .202 r
F
.61883 1.32095 m .61883 1.32281 L .6186 1.38191 L F
.61866 1.36617 m .61916 1.23885 L .62028 1.2645 L 0 0 .042 r
F
.61959 1.38393 m .6194 1.31964 L .6186 1.38224 L 0 .276 .202 r
F
.6194 1.31964 m .61916 1.2364 L .61866 1.36617 L F
.6194 1.31964 m .61866 1.36617 L .6186 1.38224 L F
.61917 1.38213 m .61866 1.36617 L .62032 1.32414 L 0 0 .042 r
F
.61866 1.36617 m .62028 1.2645 L .62032 1.32414 L F
.61862 1.37554 m .61866 1.36617 L .61861 1.38023 L 0 .276 .202 r
F
.61866 1.36617 m .61896 1.28801 L .61861 1.38023 L F
.61896 1.28801 m .61916 1.2364 L .61896 1.28805 L F
.61896 1.28801 m .61896 1.28805 L .61861 1.38023 L F
.6186 1.38068 m .61885 1.31675 L .6186 1.38189 L F
.61885 1.31675 m .61885 1.31688 L .6186 1.38189 L F
.6186 1.38189 m .61885 1.31688 L .6186 1.38114 L F
.61885 1.31688 m .61883 1.32108 L .6186 1.38114 L F
.6186 1.38191 m .6186 1.38068 L .6186 1.38189 L F
.6186 1.38224 m .61862 1.37554 L .6186 1.38191 L F
.6186 1.38189 m .61866 1.36617 L .61917 1.38213 L 0 0 .042 r
F
.619 1.37722 m .61648 1.23696 L .61771 1.37723 L 0 .646 .228 r
F
.61648 1.23696 m .61629 1.27025 L .61771 1.37723 L F
.61409 1.10357 m .61406 1.11924 L .61771 1.37723 L F
.61883 1.32095 m .61896 1.28805 L .61883 1.32281 L 0 .276 .202 r
F
.61896 1.28805 m .61916 1.2364 L .61896 1.28807 L F
.61896 1.28805 m .61896 1.28807 L .61883 1.32281 L F
.62033 1.33862 m .62032 1.32414 L .62153 1.29343 L 0 0 .042 r
F
.61917 1.38213 m .62032 1.32414 L .62033 1.33862 L F
.61975 1.23291 m .62017 1.24215 L .62019 1.24651 L F
.61975 1.23291 m .62019 1.24651 L .62028 1.2645 L F
.61934 1.29841 m .62048 1.22853 L .61916 1.2364 L 0 .276 .202 r
F
.6194 1.31964 m .61989 1.27847 L .61934 1.29841 L F
.61989 1.27847 m .62048 1.22853 L .61934 1.29841 L F
.62032 1.32414 m .62028 1.2645 L .62153 1.29343 L 0 0 .042 r
F
.62021 1.2513 m .62026 1.24701 L .62023 1.25524 L 0 .276 .202 r
F
.62026 1.24701 m .62048 1.22853 L .62028 1.2645 L F
.62028 1.2645 m .62048 1.22853 L .6194 1.31964 L F
.61917 1.38213 m .62153 1.29343 L .6224 1.38306 L 0 0 .042 r
F
.62205 1.3772 m .61951 1.26028 L .619 1.37722 L 0 .646 .228 r
F
.61885 1.31675 m .61896 1.28807 L .61885 1.31688 L 0 .276 .202 r
F
.61896 1.28807 m .61916 1.2364 L .61896 1.28807 L F
.61896 1.28807 m .61896 1.28807 L .61885 1.31688 L F
.61885 1.31688 m .61896 1.28807 L .61883 1.32108 L F
.61896 1.28807 m .61916 1.2364 L .61896 1.28821 L F
.61896 1.28807 m .61896 1.28821 L .61883 1.32108 L F
.61951 1.26028 m .61828 1.32311 L .619 1.37722 L 0 .646 .228 r
F
.61951 1.26028 m .61427 1.01867 L .61828 1.32311 L F
.61648 1.23696 m .61409 1.10357 L .61629 1.27025 L F
.61129 1.16392 m .61055 1.12871 L .61055 1.12781 L 0 .223 .192 r
F
.61179 1.18877 m .61123 1.16143 L .61129 1.16392 L F
.61123 1.16143 m .61055 1.12871 L .61129 1.16392 L F
.61423 1.27496 m .61429 1.27768 L .61429 1.27786 L F
.61423 1.27496 m .61429 1.27786 L .61433 1.28046 L F
.61275 1.20893 m .61423 1.27496 L .61433 1.28046 L F
.61274 1.20773 m .61429 1.27768 L .61275 1.20893 L F
.61429 1.27768 m .61583 1.34767 L .61433 1.28046 L F
.61411 1.26623 m .6144 1.27926 L .61439 1.2794 L F
.6141 1.26537 m .6144 1.27926 L .61411 1.26623 L F
.61144 1.14126 m .61157 1.14536 L .6144 1.27926 L F
.61439 1.2794 m .6144 1.27926 L .61478 1.29737 L F
.61382 1.25642 m .61385 1.25504 L .61583 1.34767 L F
.616 1.37943 m .60867 1.03546 L .61654 1.38074 L F
.61566 1.3786 m .61157 1.17759 L .616 1.37943 L F
.61157 1.17759 m .60867 1.03546 L .616 1.37943 L F
.60867 1.03546 m .60882 1.03083 L .61654 1.38074 L F
.60779 .66144 m .60631 .67565 L .6082 .68491 L 0 1 .295 r
F
.60792 .72008 m .60533 .73062 L .60605 .7386 L 0 1 .336 r
F
.60645 .82766 m .60601 .82496 L .60929 .83215 L 0 .462 0 r
F
.61093 1.14863 m .60704 .62078 L .61015 1.11321 L 0 1 .196 r
F
.61093 1.14863 m .61015 1.11321 L .61023 1.12609 L F
.61695 1.38053 m .60704 .62078 L .61093 1.14863 L F
.61289 1.03638 m .61227 1.0443 L .61399 1.14993 L 0 .646 .228 r
F
.61406 1.11924 m .61399 1.14993 L .61771 1.37723 L F
.61289 1.03638 m .61399 1.14993 L .61406 1.11924 L F
.61196 .54449 m .61002 .5127 L .61145 .4636 L 0 .61 .226 r
F
.6145 .90742 m .61145 .4636 L .61197 .47941 L F
.61427 1.01867 m .61409 1.10357 L .619 1.37722 L 0 .646 .228 r
F
.63281 .8419 m .62277 .8549 L .63042 .85278 L 0 1 .508 r
F
.62573 .86 m .62418 .8572 L .62634 .85877 L 0 .21 0 r
F
.61916 1.2364 m .62427 .85341 L .62103 .92583 L 0 .896 .089 r
F
.61916 1.2364 m .62711 .92718 L .62427 .85341 L F
.62111 1.16031 m .62699 1.05349 L .62711 .92718 L F
.61916 1.2364 m .62124 1.18781 L .62111 1.16031 L F
.62124 1.18781 m .62699 1.05349 L .62111 1.16031 L F
.61604 .61115 m .61868 .68279 L .61674 .62252 L 0 .537 .227 r
F
.61674 .66825 m .61666 .56626 L .61679 .66809 L 0 .61 .226 r
F
.61755 .64529 m .61666 .56626 L .6194 .6549 L 0 .586 .223 r
F
.6235 .69135 m .62114 .70341 L .62211 .71335 L 0 1 .337 r
F
.6194 .6549 m .61868 .68279 L .62542 .79488 L 0 .459 .231 r
F
.6142 .53405 m .61755 .64529 L .6194 .6549 L F
.61755 .64529 m .61868 .68279 L .6194 .6549 L F
.6194 .6549 m .62301 .73888 L .62255 .67132 L F
.62088 .8491 m .6194 .6549 L .62255 .67132 L 0 .586 .223 r
F
.62017 .84049 m .6194 .6549 L .62088 .8491 L F
.62017 .84049 m .61755 .64529 L .61962 .70709 L F
.61969 .83466 m .61755 .64529 L .62017 .84049 L F
.62301 .73888 m .62542 .79488 L .62469 .70647 L 0 .459 .231 r
F
.62536 .77388 m .62641 .72296 L .62674 .73908 L 0 .586 .223 r
F
.62481 .77406 m .62641 .72296 L .62536 .77388 L F
.6222 .84642 m .62405 .79208 L .62283 .83794 L F
.62711 .7211 m .63127 .78127 L .63061 .77979 L 0 .459 .231 r
F
.62711 .7211 m .63061 .77979 L .62901 .77616 L F
.62605 .70564 m .62833 .62738 L .62785 .70455 L 0 .586 .223 r
F
.64861 .70256 m .63808 .72201 L .6405 .72608 L 0 1 .411 r
F
.64861 .70256 m .64156 .71193 L .63808 .72201 L F
.63409 .67901 m .64038 .68923 L .64337 .67867 L 0 1 .392 r
F
.64038 .68923 m .64156 .71193 L .64861 .70256 L 0 1 .401 r
F
.63299 .69279 m .64191 .6986 L .63859 .69225 L 0 .939 .374 r
F
.63299 .69279 m .64104 .70835 L .64191 .6986 L F
.63299 .69279 m .63658 .71501 L .64104 .70835 L F
.64104 .70835 m .63549 .72425 L .6385 .72993 L 0 .939 .384 r
F
.64104 .70835 m .63658 .71501 L .63549 .72425 L F
.64879 .65186 m .64075 .67445 L .64337 .67867 L 0 1 .38 r
F
.63409 .67901 m .64337 .67867 L .64075 .67445 L 0 1 .392 r
F
.64249 .67455 m .63884 .68194 L .63859 .69225 L 0 .842 .366 r
F
.64038 .68923 m .64861 .70256 L .65133 .69143 L 0 1 .401 r
F
.64038 .68923 m .65133 .69143 L .6479 .68595 L F
.64249 .67455 m .63859 .69225 L .64191 .6986 L 0 .842 .366 r
F
.64169 .64033 m .63682 .66811 L .64308 .66296 L 0 1 .371 r
F
.64879 .65186 m .64308 .66296 L .64075 .67445 L 0 1 .38 r
F
.64169 .64033 m .63421 .66387 L .63682 .66811 L 0 1 .371 r
F
.64169 .64033 m .63629 .65196 L .63421 .66387 L F
.63373 .65676 m .64249 .67455 L .64253 .66351 L 0 .85 .356 r
F
.63373 .65676 m .63884 .68194 L .64249 .67455 L F
.63373 .65676 m .63363 .68251 L .63884 .68194 L F
.63854 .66326 m .6379 .68813 L .6418 .69053 L 0 1 .338 r
F
.63854 .66326 m .63651 .67644 L .6379 .68813 L F
.63304 .69505 m .6418 .69053 L .6379 .68813 L 0 1 .352 r
F
.64249 .67455 m .64191 .6986 L .64733 .69826 L 0 .842 .366 r
F
.63304 .69505 m .64261 .70064 L .6418 .69053 L 0 1 .352 r
F
.63304 .69505 m .63979 .71174 L .64261 .70064 L F
.64861 .70256 m .6405 .72608 L .64789 .72235 L 0 1 .411 r
F
.64104 .70835 m .6385 .72993 L .64433 .72947 L 0 .939 .384 r
F
.65531 .7133 m .64789 .72235 L .64414 .73217 L 0 1 .418 r
F
.64861 .70256 m .64789 .72235 L .65531 .7133 L 0 1 .411 r
F
.64104 .70835 m .64433 .72947 L .64909 .72317 L 0 .939 .384 r
F
.63514 .72755 m .64372 .73276 L .64382 .72389 L 0 1 .38 r
F
.63679 .73878 m .64602 .74366 L .64302 .73824 L 0 1 .399 r
F
.6421 .74519 m .63911 .76286 L .64785 .75515 L 0 1 .435 r
F
.6421 .74519 m .64785 .75515 L .65259 .74633 L F
.6421 .74519 m .65259 .74633 L .65018 .7423 L F
.63679 .73878 m .64406 .75216 L .64602 .74366 L 0 1 .399 r
F
.63514 .72755 m .64009 .74241 L .64372 .73276 L 0 1 .38 r
F
.63514 .72755 m .64382 .72389 L .6403 .72171 L F
.63304 .69505 m .63492 .71867 L .63979 .71174 L 0 1 .352 r
F
.63304 .69505 m .63126 .71681 L .63492 .71867 L F
.63304 .69505 m .63045 .70668 L .63126 .71681 L F
.62784 .71132 m .63968 .68204 L .63841 .73286 L 0 .625 .212 r
F
.62779 .71123 m .62783 .71112 L .62784 .71132 L F
.62783 .71112 m .63968 .68204 L .62784 .71132 L F
.62605 .70564 m .62773 .70463 L .62781 .71212 L 0 .586 .223 r
F
.62773 .70463 m .62782 .70457 L .62781 .70973 L F
.62773 .70463 m .62781 .70973 L .62781 .71212 L F
.62782 .70457 m .62785 .70455 L .62783 .70838 L F
.63679 .73878 m .63845 .75809 L .64406 .75216 L 0 1 .399 r
F
.64785 .75515 m .64446 .77266 L .65358 .76506 L 0 1 .439 r
F
.64406 .75216 m .63892 .77125 L .64538 .77067 L 0 1 .407 r
F
.64406 .75216 m .63625 .76627 L .63892 .77125 L F
.64406 .75216 m .63845 .75809 L .63625 .76627 L F
.63423 .75621 m .63768 .76977 L .64215 .76125 L 0 1 .408 r
F
.63423 .75621 m .63211 .77476 L .63768 .76977 L F
.63423 .75621 m .64215 .76125 L .64306 .7533 L F
.63423 .75621 m .64306 .7533 L .63981 .75122 L F
.63514 .72755 m .63493 .74826 L .64009 .74241 L 0 1 .38 r
F
.63514 .72755 m .63167 .74641 L .63493 .74826 L F
.63514 .72755 m .63176 .73753 L .63167 .74641 L F
.62902 .77708 m .63435 .7723 L .63033 .77314 L 0 1 .491 r
F
.64215 .76125 m .63656 .77767 L .63952 .77969 L 0 1 .42 r
F
.64215 .76125 m .63768 .76977 L .63656 .77767 L F
.62902 .77708 m .63928 .77553 L .63449 .7723 L 0 1 .491 r
F
.6344 .7723 m .63449 .7723 L .63449 .7723 L 0 .625 .212 r
F
.6344 .7723 m .63449 .7723 L .6344 .7723 L F
.62784 .71169 m .63449 .7723 L .6344 .7723 L F
.63435 .7723 m .63449 .7723 L .63441 .77224 L 0 1 .491 r
F
.62902 .77708 m .63449 .7723 L .63435 .7723 L F
.6344 .7723 m .63449 .7723 L .63445 .77273 L 0 .625 .212 r
F
.63033 .77314 m .63372 .773 L .63037 .77422 L F
.65232 .95971 m .63995 .96862 L .64862 .96838 L 0 1 .534 r
F
.64673 .96622 m .63292 .97055 L .63497 .97163 L 0 1 .475 r
F
.64673 .96622 m .63796 .96824 L .63292 .97055 L F
.63469 .93996 m .63223 .94928 L .64059 .94693 L 0 1 .517 r
F
.63888 .9197 m .63128 .9273 L .63829 .92817 L 0 1 .512 r
F
.63888 .9197 m .62894 .92441 L .63128 .9273 L F
.63888 .9197 m .63219 .92115 L .62894 .92441 L F
.63813 .95435 m .6326 .95681 L .63559 .95547 L 0 0 0 r
F
.63813 .95435 m .63368 .95634 L .6326 .95681 L F
.63447 .97184 m .63225 .97178 L .63356 .96805 L 0 0 .001 r
F
.6324 .91259 m .63219 .92115 L .63888 .9197 L 0 1 .506 r
F
.6324 .91259 m .63888 .9197 L .64188 .91654 L F
.6324 .91259 m .64188 .91654 L .63919 .91378 L F
.6465 .90004 m .63984 .91276 L .65125 .90798 L 0 1 .496 r
F
.64009 .90279 m .63514 .90952 L .64155 .91081 L 0 1 .504 r
F
.64009 .90279 m .63244 .9066 L .63514 .90952 L F
.64009 .90279 m .63456 .90372 L .63244 .9066 L F
.6368 .88681 m .63134 .88971 L .63438 .89275 L 0 .868 .477 r
F
.6368 .88681 m .63237 .88717 L .63134 .88971 L F
.6322 .87842 m .64313 .88006 L .6411 .87739 L 0 1 .51 r
F
.63815 .87907 m .63762 .88425 L .64306 .88643 L 0 .63 .421 r
F
.63815 .87907 m .63427 .88119 L .63762 .88425 L F
.63815 .87907 m .63449 .87897 L .63427 .88119 L F
.62889 .87053 m .62912 .87623 L .63449 .87897 L 0 .535 .401 r
F
.62889 .87053 m .63449 .87897 L .63815 .87906 L F
.63086 .88817 m .63322 .87751 L .63796 .88215 L 0 .523 .094 r
F
.63086 .88817 m .63018 .88008 L .63322 .87751 L F
.6368 .88681 m .63438 .89275 L .6402 .89457 L 0 .868 .477 r
F
.6368 .88681 m .6402 .89457 L .64492 .89396 L F
.6368 .88681 m .64492 .89396 L .64597 .89142 L F
.6368 .88681 m .64597 .89142 L .64263 .88863 L F
.63086 .88817 m .63796 .88215 L .64207 .89095 L 0 .523 .094 r
F
.64492 .89396 m .63894 .89715 L .64198 .89998 L 0 .945 .489 r
F
.64492 .89396 m .6402 .89457 L .63894 .89715 L F
.63086 .88817 m .64207 .89095 L .64281 .89806 L 0 .523 .094 r
F
.63275 .89553 m .64009 .90279 L .64198 .89998 L 0 1 .496 r
F
.63275 .89553 m .64198 .89998 L .63894 .89715 L F
.63086 .88817 m .63977 .90068 L .63497 .89701 L 0 .523 .094 r
F
.63086 .88817 m .64281 .89806 L .63977 .90068 L F
.63275 .89553 m .63456 .90372 L .64009 .90279 L 0 1 .496 r
F
.63186 .91869 m .63497 .89701 L .63977 .90068 L 0 .549 .139 r
F
.63186 .91869 m .63158 .9047 L .63497 .89701 L F
.64741 .90961 m .63919 .91378 L .64188 .91654 L 0 1 .512 r
F
.64741 .90961 m .64155 .91081 L .63919 .91378 L F
.64009 .90279 m .64155 .91081 L .64741 .90961 L 0 1 .504 r
F
.64009 .90279 m .64741 .90961 L .64955 .90673 L F
.64009 .90279 m .64955 .90673 L .64652 .90408 L F
.63186 .91869 m .63977 .90068 L .64357 .91152 L 0 .549 .139 r
F
.63888 .9197 m .63829 .92817 L .64533 .92645 L 0 1 .512 r
F
.63888 .9197 m .64533 .92645 L .6486 .92319 L F
.63888 .9197 m .6486 .92319 L .64591 .92057 L F
.64741 .90961 m .64188 .91654 L .64853 .91751 L F
.63186 .91869 m .64357 .91152 L .64383 .92238 L 0 .549 .139 r
F
.64533 .92645 m .63533 .93214 L .63838 .9357 L 0 1 .519 r
F
.64533 .92645 m .6383 .92817 L .63533 .93214 L F
.63186 .91869 m .64044 .93017 L .63566 .92964 L 0 .549 .139 r
F
.63186 .91869 m .64383 .92238 L .64044 .93017 L F
.63469 .93996 m .64059 .94693 L .64501 .94313 L 0 1 .517 r
F
.63469 .93996 m .64501 .94313 L .64253 .94041 L F
.63202 .97298 m .63205 .94789 L .63566 .92964 L 0 .483 .178 r
F
.62427 .85341 m .63223 .95347 L .63612 .91378 L 0 .814 .24 r
F
.62427 .85341 m .62711 .92718 L .63223 .95347 L F
.6246 .89409 m .63077 .96879 L .62982 .90761 L 0 .644 .229 r
F
.65033 1.08111 m .63321 1.08345 L .64327 1.084 L 0 1 .401 r
F
.6418 1.06668 m .63381 1.06277 L .641 1.06533 L 0 0 0 r
F
.64086 1.09358 m .63493 1.08074 L .638 1.08052 L 0 .298 .053 r
F
.64086 1.09358 m .63614 1.08633 L .63493 1.08074 L F
.63263 1.09537 m .63614 1.08633 L .64086 1.09358 L 0 .352 .064 r
F
.63263 1.09537 m .64086 1.09358 L .64188 1.09983 L F
.63263 1.09537 m .64188 1.09983 L .6385 1.10087 L F
.6339 .95596 m .64305 .95254 L .64007 .95364 L 0 .801 .21 r
F
.64533 .92645 m .63838 .9357 L .64628 .93683 L 0 1 .519 r
F
.63202 .97298 m .63566 .92964 L .64044 .93017 L 0 .483 .178 r
F
.64059 .94693 m .64647 .9535 L .65119 .94967 L 0 1 .524 r
F
.64059 .94693 m .65119 .94967 L .64872 .9471 L F
.65376 .93478 m .64253 .94041 L .64501 .94313 L 0 1 .525 r
F
.65376 .93478 m .64628 .93683 L .64253 .94041 L F
.64596 .95677 m .63891 .95916 L .63589 .96121 L 0 1 .338 r
F
.63813 .95435 m .63559 .95547 L .64137 .95261 L 0 0 0 r
F
.6461 .95013 m .64137 .95261 L .64007 .95364 L 0 .862 .215 r
F
.63813 .95435 m .64137 .95261 L .6461 .95013 L 0 0 0 r
F
.63813 .95435 m .6461 .95013 L .6472 .94965 L F
.63813 .95435 m .6472 .94965 L .64393 .95148 L F
.64111 .95348 m .64243 .95422 L .6483 .95157 L 0 .865 .234 r
F
.64111 .95348 m .6483 .95157 L .65048 .95022 L F
.64111 .95348 m .65048 .95022 L .64751 .95108 L F
.6461 .95013 m .64007 .95364 L .64305 .95254 L 0 .862 .215 r
F
.63967 .95517 m .63901 .95447 L .6444 .95105 L 0 0 0 r
F
.63967 .95517 m .63572 .95661 L .63901 .95447 L F
.63967 .95517 m .636 .95692 L .63572 .95661 L F
.63825 .96032 m .63594 .95976 L .63965 .95639 L F
.63825 .96032 m .63534 .96145 L .63594 .95976 L F
.63447 .97184 m .63356 .96805 L .6375 .96315 L 0 0 .001 r
F
.63202 .97298 m .64044 .93017 L .64387 .94208 L 0 .483 .178 r
F
.64596 .95677 m .63889 .96154 L .64676 .9598 L 0 1 .338 r
F
.63962 .957 m .63891 .95916 L .64596 .95677 L 0 .978 .27 r
F
.64647 .9535 m .65232 .95971 L .65734 .95588 L 0 1 .529 r
F
.63962 .957 m .64596 .95677 L .64928 .95508 L 0 .978 .27 r
F
.63962 .957 m .64928 .95508 L .64664 .95523 L F
.64647 .9535 m .65734 .95588 L .65488 .95344 L 0 1 .529 r
F
.6483 .95157 m .64268 .9556 L .64929 .95315 L 0 1 .253 r
F
.6483 .95157 m .64003 .95594 L .64268 .9556 L F
.6483 .95157 m .64243 .95422 L .64003 .95594 L F
.6461 .95013 m .64305 .95254 L .64903 .94954 L 0 .862 .215 r
F
.6606 .94117 m .64872 .9471 L .65119 .94967 L 0 1 .529 r
F
.6461 .95013 m .64903 .94954 L .65405 .94663 L 0 .862 .215 r
F
.6461 .95013 m .65405 .94663 L .65537 .94559 L F
.6461 .95013 m .65537 .94559 L .65211 .94712 L F
.64831 .94862 m .64393 .95148 L .6472 .94965 L 0 .826 .183 r
F
.64831 .94862 m .6444 .95105 L .64393 .95148 L F
.63967 .95517 m .6444 .95105 L .64831 .94862 L 0 0 0 r
F
.63967 .95517 m .64831 .94862 L .64861 .94892 L F
.63967 .95517 m .64861 .94892 L .64508 .95174 L F
.63825 .96032 m .64476 .95228 L .64789 .95015 L F
.63825 .96032 m .63965 .95639 L .64476 .95228 L F
.63825 .96032 m .64789 .95015 L .64731 .95183 L F
.63825 .96032 m .64731 .95183 L .64339 .95619 L F
.6446 .95705 m .64339 .95619 L .64731 .95183 L F
.6446 .95705 m .64222 .95843 L .64339 .95619 L F
.63447 .97184 m .64222 .95843 L .6446 .95705 L 0 0 .001 r
F
.63447 .97184 m .6375 .96315 L .64222 .95843 L F
.65376 .93478 m .64501 .94313 L .65275 .94345 L 0 1 .525 r
F
.64533 .92645 m .64628 .93683 L .65376 .93478 L 0 1 .519 r
F
.64533 .92645 m .65376 .93478 L .65676 .93081 L F
.64961 .93443 m .64783 .94778 L .65204 .93019 L 0 1 .199 r
F
.64784 .93941 m .64783 .94778 L .64961 .93443 L F
.64511 .94623 m .64742 .92836 L .64961 .93443 L 0 .29 .138 r
F
.64511 .94623 m .64387 .94208 L .64742 .92836 L F
.64376 .94977 m .64412 .95427 L .64511 .94623 L 0 1 .199 r
F
.63202 .97298 m .64387 .94208 L .64377 .94886 L 0 .483 .178 r
F
.64346 .95038 m .64377 .94886 L .64376 .94978 L F
.63202 .97298 m .64377 .94886 L .64346 .95038 L F
.63202 .97298 m .64376 .94978 L .64345 .9507 L F
.64836 .9882 m .6531 .99246 L .66032 .98934 L 0 1 .541 r
F
.64836 .9882 m .66032 .98934 L .6583 .98772 L F
.65072 .98486 m .64836 .9882 L .65528 .98534 L 0 1 .539 r
F
.64827 .98459 m .64829 .98521 L .65072 .98486 L F
.64829 .98521 m .64836 .9882 L .65072 .98486 L F
.66973 .97679 m .65325 .9835 L .65406 .98437 L F
.66803 .97965 m .65528 .98534 L .66478 .98405 L 0 1 .536 r
F
.67546 .98076 m .6583 .98772 L .66032 .98934 L 0 1 .539 r
F
.67546 .98076 m .66478 .98405 L .6583 .98772 L F
.67136 .9783 m .66478 .98405 L .67546 .98076 L 0 1 .536 r
F
.67695 .97634 m .68169 .97732 L .67929 .97602 L F
.67684 .97638 m .68169 .97732 L .67695 .97634 L F
.67392 .97733 m .68169 .97732 L .67678 .97637 L F
.67394 .97733 m .67546 .98076 L .68169 .97732 L F
.66973 .97679 m .67136 .9783 L .67394 .97733 L 0 1 .539 r
F
.67392 .97733 m .67392 .97733 L .67394 .97733 L 0 1 .536 r
F
.67392 .97733 m .67546 .98076 L .67394 .97733 L F
.67136 .9783 m .67546 .98076 L .67392 .97733 L F
.67546 .98076 m .66032 .98934 L .6701 .9879 L 0 1 .539 r
F
.67546 .98076 m .6701 .9879 L .68116 .98437 L F
.67546 .98076 m .68116 .98437 L .68767 .98068 L F
.67546 .98076 m .68767 .98068 L .68528 .97932 L F
.67394 .97733 m .67549 .98212 L .68171 .97831 L F
.67136 .9783 m .67549 .98212 L .67394 .97733 L F
.67695 .97634 m .68171 .97831 L .67929 .9762 L F
.66973 .97679 m .67394 .97733 L .67695 .97634 L F
.67394 .97733 m .68171 .97831 L .67695 .97634 L F
.67678 .97637 m .67684 .97638 L .67695 .97634 L 0 1 .536 r
F
.66973 .97679 m .6683 .9792 L .67127 .97821 L 0 1 .539 r
F
.66975 .97733 m .67392 .97733 L .67678 .97637 L 0 1 .536 r
F
.67127 .97821 m .66811 .97953 L .67136 .9783 L 0 1 .539 r
F
.6683 .9792 m .66811 .97953 L .67127 .97821 L F
.66811 .97953 m .66806 .97961 L .67136 .9783 L F
.66975 .97733 m .67136 .9783 L .67392 .97733 L 0 1 .536 r
F
.66975 .97733 m .66806 .97961 L .67136 .9783 L F
.66806 .97961 m .66478 .98405 L .67136 .9783 L F
.67136 .9783 m .66481 .98509 L .67549 .98212 L 0 1 .539 r
F
.66806 .97961 m .66481 .98509 L .67136 .9783 L F
.66806 .97961 m .65528 .98568 L .66481 .98509 L F
.66973 .97679 m .66083 .98227 L .66806 .97961 L F
.66806 .97961 m .66083 .98227 L .66803 .97965 L 0 1 .536 r
F
.66083 .98227 m .65528 .98534 L .66803 .97965 L F
.66083 .98227 m .65528 .98568 L .66806 .97961 L 0 1 .539 r
F
.66975 .97733 m .66083 .98227 L .66806 .97961 L 0 1 .536 r
F
.65505 .98422 m .65406 .98437 L .6542 .98451 L 0 1 .539 r
F
.66083 .98227 m .6542 .98451 L .65528 .98534 L 0 1 .536 r
F
.66973 .97679 m .65406 .98437 L .65846 .98373 L 0 1 .539 r
F
.6436 .98387 m .64827 .98459 L .65325 .9835 L 0 1 .541 r
F
.64827 .98459 m .65528 .98534 L .6542 .98451 L 0 1 .539 r
F
.64827 .98459 m .65528 .98568 L .6542 .98451 L 0 1 .541 r
F
.64827 .98459 m .6542 .98451 L .65325 .9835 L F
.6436 .98387 m .64441 .98479 L .64827 .98459 L F
.64361 .98409 m .64827 .98459 L .65326 .98379 L 0 1 .539 r
F
.64827 .98459 m .6542 .98451 L .65326 .98379 L F
.66975 .97733 m .65326 .98379 L .6542 .98451 L 0 1 .536 r
F
.66975 .97733 m .6542 .98451 L .66083 .98227 L F
.65572 .98413 m .65505 .98422 L .65431 .98464 L 0 1 .539 r
F
.65505 .98422 m .6542 .98451 L .65431 .98464 L F
.65846 .98373 m .65572 .98413 L .65528 .98568 L F
.65572 .98413 m .65431 .98464 L .65528 .98568 L F
.64827 .98459 m .64838 .98929 L .65528 .98568 L 0 1 .541 r
F
.64441 .98479 m .64836 .9882 L .64827 .98459 L 0 1 .539 r
F
.64441 .98479 m .64838 .98929 L .64827 .98459 L 0 1 .541 r
F
.64361 .98409 m .64441 .98479 L .64827 .98459 L 0 1 .539 r
F
.63884 .98017 m .64361 .98409 L .65022 .98152 L 0 1 .536 r
F
.63884 .98017 m .65022 .98152 L .64819 .98005 L F
.65815 .96563 m .64508 .97452 L .65404 .97414 L F
.65251 .9685 m .64007 .9746 L .64873 .97365 L 0 1 .503 r
F
.64673 .96622 m .63497 .97163 L .64335 .97075 L 0 1 .475 r
F
.64094 .96438 m .63796 .96824 L .64673 .96622 L 0 1 .429 r
F
.65232 .95971 m .64862 .96838 L .65815 .96563 L 0 1 .534 r
F
.64094 .96438 m .64673 .96622 L .6515 .9642 L 0 1 .429 r
F
.64094 .96438 m .6515 .9642 L .64907 .96352 L F
.63447 .97184 m .6446 .95705 L .64332 .96075 L 0 0 .001 r
F
.65426 .95715 m .64298 .96215 L .64542 .96265 L 0 1 .404 r
F
.65426 .95715 m .64676 .9598 L .64298 .96215 L F
.64596 .95677 m .64676 .9598 L .65426 .95715 L 0 1 .338 r
F
.66741 .94724 m .65488 .95344 L .65734 .95588 L 0 1 .532 r
F
.64596 .95677 m .65426 .95715 L .65731 .9551 L 0 1 .338 r
F
.64596 .95677 m .65731 .9551 L .65385 .95502 L F
.65547 .95021 m .64664 .95523 L .64928 .95508 L 0 1 .314 r
F
.65547 .95021 m .64929 .95315 L .64664 .95523 L F
.6483 .95157 m .64929 .95315 L .65547 .95021 L 0 1 .253 r
F
.6391 .97198 m .64775 .95463 L .64957 .95281 L 0 0 0 r
F
.6391 .97198 m .64332 .96075 L .64775 .95463 L F
.63447 .97184 m .64332 .96075 L .63922 .96711 L 0 0 .001 r
F
.6391 .97198 m .63922 .96711 L .64332 .96075 L 0 0 0 r
F
.6391 .97198 m .64957 .95281 L .64777 .9576 L F
.6391 .97198 m .64777 .9576 L .64355 .96583 L F
.6424 .97174 m .64124 .9719 L .64355 .96583 L F
.63125 1.00134 m .64124 .97191 L .64239 .97174 L 0 0 .066 r
F
.63125 1.00134 m .63707 .97918 L .64124 .97191 L F
.63125 1.00134 m .64239 .97174 L .63992 .98119 L F
.64673 .96622 m .64335 .97075 L .65251 .9685 L 0 1 .475 r
F
.64284 .97513 m .6437 .97089 L .64429 .96992 L 0 0 .06 r
F
.64048 .98686 m .64141 .98227 L .64222 .97846 L 0 0 .03 r
F
.63375 1.01941 m .64141 .98227 L .64048 .98686 L F
.63314 1.01019 m .64284 .97513 L .64141 .98227 L 0 0 .06 r
F
.64284 .97513 m .64429 .96992 L .64141 .98227 L F
.63375 1.01941 m .64222 .97846 L .64167 .98135 L 0 0 .03 r
F
.63423 1.00626 m .64352 .97158 L .64284 .97513 L 0 0 .06 r
F
.63409 1.00667 m .64352 .97158 L .63423 1.00626 L F
.64352 .97158 m .6437 .97089 L .64284 .97513 L F
.65232 .95971 m .65815 .96563 L .66347 .96181 L 0 1 .534 r
F
.65232 .95971 m .66347 .96181 L .66102 .95947 L F
.65426 .95715 m .64542 .96265 L .65313 .96087 L 0 1 .404 r
F
.66741 .94724 m .65919 .94973 L .65488 .95344 L 0 1 .532 r
F
.65547 .95021 m .64928 .95508 L .65612 .95257 L 0 1 .314 r
F
.6424 .97174 m .65077 .95287 L .64649 .96357 L 0 0 0 r
F
.64429 .96991 m .6437 .97089 L .64649 .96357 L F
.64167 .98135 m .64222 .97846 L .64471 .96675 L 0 0 .03 r
F
.6606 .94117 m .65119 .94967 L .65919 .94973 L 0 1 .529 r
F
.6483 .95157 m .65547 .95021 L .6579 .94848 L 0 1 .253 r
F
.6483 .95157 m .6579 .94848 L .65494 .94911 L F
.65405 .94663 m .65048 .95022 L .65668 .94711 L 0 .969 .239 r
F
.65405 .94663 m .64751 .95108 L .65048 .95022 L F
.65405 .94663 m .64903 .94954 L .64751 .95108 L F
.6606 .94117 m .65275 .94345 L .64872 .9471 L 0 1 .529 r
F
.65376 .93478 m .65275 .94345 L .6606 .94117 L 0 1 .525 r
F
.65376 .93478 m .6606 .94117 L .66437 .93758 L F
.65376 .93478 m .66437 .93758 L .66153 .9351 L F
.65694 .943 m .65211 .94712 L .65537 .94559 L 0 .924 .219 r
F
.65694 .943 m .65277 .94602 L .65211 .94712 L F
.64831 .94862 m .65277 .94602 L .65694 .943 L 0 .826 .183 r
F
.64831 .94862 m .65694 .943 L .65743 .94255 L F
.64831 .94862 m .65743 .94255 L .65391 .94498 L F
.6571 .94166 m .65391 .94498 L .65743 .94255 L 0 .901 .19 r
F
.6571 .94166 m .65376 .9446 L .65391 .94498 L F
.64831 .94862 m .6472 .94965 L .65277 .94602 L 0 .826 .183 r
F
.6479 .95015 m .65376 .9446 L .6571 .94166 L 0 0 0 r
F
.6479 .95015 m .6571 .94166 L .65681 .94217 L F
.6479 .95015 m .65681 .94217 L .65306 .94582 L F
.6571 .94166 m .65743 .94255 L .66273 .93799 L 0 .901 .19 r
F
.6715 .92963 m .66153 .9351 L .66437 .93758 L 0 1 .528 r
F
.6571 .94166 m .66273 .93799 L .66628 .93433 L 0 .901 .19 r
F
.6571 .94166 m .66628 .93433 L .66615 .93394 L F
.6571 .94166 m .66615 .93394 L .66242 .93708 L F
.65471 .94397 m .65681 .94217 L .66165 .93674 L 0 .838 .148 r
F
.65471 .94397 m .65306 .94582 L .65681 .94217 L F
.6715 .92963 m .66457 .93169 L .66153 .9351 L 0 1 .528 r
F
.65471 .94397 m .66165 .93674 L .66437 .93312 L 0 .838 .148 r
F
.65471 .94397 m .66437 .93312 L .66348 .93388 L F
.65471 .94397 m .66348 .93388 L .65957 .93851 L F
.64957 .95281 m .65357 .94619 L .65808 .93949 L 0 0 0 r
F
.64957 .95281 m .65808 .93949 L .66002 .93614 L F
.64957 .95281 m .64947 .95179 L .65357 .94619 L F
.64957 .95281 m .66002 .93614 L .65832 .93895 L F
.64957 .95281 m .65832 .93895 L .6541 .94608 L F
.65306 .94685 m .65184 .94947 L .6541 .94608 L 0 .853 .12 r
F
.6424 .97174 m .65184 .94947 L .65306 .94685 L 0 0 0 r
F
.6424 .97174 m .64777 .9576 L .65184 .94947 L F
.6424 .97174 m .64355 .96583 L .64777 .9576 L F
.6424 .97174 m .65306 .94685 L .65077 .95287 L F
.63314 1.01019 m .63992 .98119 L .6437 .97089 L 0 0 .06 r
F
.63314 1.01019 m .64141 .98227 L .63695 .9998 L F
.63375 1.01941 m .63695 .9998 L .64141 .98227 L 0 0 .03 r
F
.63375 1.01941 m .64471 .96675 L .64468 .96349 L F
.63375 1.01941 m .64468 .96349 L .64143 .97926 L F
.63375 1.01941 m .63878 .9931 L .63709 1.00371 L F
.63878 .9931 m .64143 .97926 L .63917 .99197 L F
.63878 .9931 m .63917 .99197 L .63709 1.00371 L F
.63314 1.01019 m .63409 1.00667 L .63423 1.00626 L 0 0 .06 r
F
.63125 1.00134 m .63992 .98119 L .63545 .99401 L 0 0 .066 r
F
.63314 1.01019 m .63545 .99401 L .63992 .98119 L 0 0 .06 r
F
.63375 1.01941 m .63366 1.01574 L .63695 .9998 L 0 0 .03 r
F
.63294 1.02275 m .64412 .95428 L .64376 .94978 L 0 .761 .07 r
F
.6396 .96291 m .64353 .95081 L .64133 .96062 L 0 .483 .178 r
F
.64345 .9507 m .64376 .94978 L .64375 .95011 L F
.63294 1.02275 m .64376 .94978 L .64133 .96062 L 0 .761 .07 r
F
.63202 .97298 m .64375 .95011 L .6396 .96291 L 0 .483 .178 r
F
.64133 .96062 m .64376 .94978 L .6434 .94527 L 0 .761 .07 r
F
.63294 1.02275 m .64143 .97926 L .64412 .95428 L F
.64133 .96062 m .64375 .95011 L .64365 .95753 L 0 .483 .178 r
F
.64353 .95081 m .64375 .95011 L .64133 .96062 L F
.6391 .97198 m .6374 .97193 L .63922 .96711 L 0 0 0 r
F
.63294 1.02275 m .64133 .96062 L .63843 .97541 L 0 .761 .07 r
F
.63843 .97541 m .64365 .95753 L .64005 .97602 L 0 .483 .178 r
F
.63294 1.02275 m .63843 .97541 L .63568 .99743 L 0 .761 .07 r
F
.63202 .97298 m .64038 .96187 L .63843 .97541 L 0 .483 .178 r
F
.63125 1.00134 m .63265 .98875 L .63707 .97918 L 0 0 .066 r
F
.63202 .97298 m .63843 .97541 L .63545 .98512 L 0 .483 .178 r
F
.63843 .97541 m .63773 .9806 L .63568 .99743 L 0 .761 .07 r
F
.63843 .97541 m .64005 .97602 L .63773 .9806 L 0 .483 .178 r
F
.63843 .97541 m .63773 .9806 L .63545 .98512 L F
.63843 .97541 m .63799 .97853 L .63773 .9806 L 0 .761 .07 r
F
.63843 .97541 m .6398 .96363 L .63799 .97853 L F
.64038 .96187 m .64133 .96062 L .63843 .97541 L 0 .483 .178 r
F
.64133 .96062 m .64365 .95753 L .63843 .97541 L F
.63843 .97541 m .64133 .96062 L .63866 .97344 L 0 .761 .07 r
F
.63866 .97344 m .6434 .94527 L .6398 .96363 L F
.64133 .96062 m .6434 .94527 L .63866 .97344 L F
.64365 .95753 m .64376 .94977 L .64511 .94623 L 0 .29 .138 r
F
.64376 .94977 m .64387 .94208 L .64511 .94623 L F
.6479 .95015 m .64508 .95174 L .64861 .94892 L 0 0 0 r
F
.6479 .95015 m .64476 .95227 L .64508 .95174 L F
.64511 .94623 m .64412 .95427 L .64783 .94778 L 0 1 .199 r
F
.6434 .94526 m .64376 .94977 L .64511 .94623 L F
.64497 .94615 m .64511 .94623 L .64785 .9375 L F
.64511 .94623 m .64783 .94778 L .64784 .93906 L F
.64511 .94623 m .64784 .93906 L .64785 .9375 L F
.64533 .92645 m .65676 .93081 L .65325 .92758 L 0 1 .519 r
F
.64961 .93443 m .64742 .92836 L .65193 .92541 L 0 .29 .138 r
F
.64785 .9375 m .64784 .93941 L .64961 .93443 L 0 1 .199 r
F
.64365 .95753 m .64511 .94623 L .64961 .93443 L 0 .29 .138 r
F
.66198 .92212 m .65325 .92758 L .65676 .93081 L 0 1 .523 r
F
.66198 .92212 m .65548 .92385 L .65325 .92758 L F
.65471 .91604 m .6486 .92319 L .65548 .92385 L 0 1 .518 r
F
.6479 .95015 m .64861 .94892 L .65376 .9446 L 0 0 0 r
F
.65471 .94397 m .65216 .9466 L .65306 .94582 L 0 .838 .148 r
F
.6446 .95705 m .65216 .9466 L .65471 .94397 L 0 0 0 r
F
.6446 .95705 m .64731 .95183 L .65216 .9466 L F
.6446 .95705 m .65471 .94397 L .65357 .94619 L F
.6446 .95705 m .65357 .94619 L .64947 .95179 L F
.64468 .96348 m .65535 .92929 L .65525 .92231 L 0 1 .123 r
F
.64468 .96348 m .65525 .92231 L .65204 .93019 L F
.64468 .96348 m .65204 .93019 L .64783 .94778 L F
.64365 .95753 m .64961 .93443 L .65503 .92906 L 0 .29 .138 r
F
.64961 .93443 m .65193 .92541 L .65251 .92609 L F
.65471 .91604 m .64591 .92057 L .6486 .92319 L 0 1 .518 r
F
.65471 .91604 m .65548 .92385 L .66198 .92212 L F
.64383 .92238 m .65515 .91775 L .65193 .92541 L 0 .367 .112 r
F
.64383 .92238 m .65193 .92541 L .64742 .92836 L F
.64785 .9375 m .64961 .93443 L .65302 .92155 L 0 1 .199 r
F
.64961 .93443 m .65204 .93019 L .65251 .92609 L F
.64961 .93443 m .65251 .92609 L .65302 .92155 L F
.64961 .93443 m .65251 .92609 L .65255 .92613 L 0 .29 .138 r
F
.64961 .93443 m .65255 .92613 L .65503 .92906 L F
.6434 .94526 m .64497 .94615 L .64785 .9375 L 0 1 .199 r
F
.65471 .91604 m .64853 .91751 L .64591 .92057 L 0 1 .518 r
F
.64741 .90961 m .64853 .91751 L .65471 .91604 L 0 1 .512 r
F
.64741 .90961 m .65471 .91604 L .65709 .91307 L F
.64741 .90961 m .65709 .91307 L .65408 .91058 L F
.6465 .90004 m .65125 .90798 L .65831 .90199 L 0 1 .496 r
F
.66111 .90667 m .65408 .91058 L .65709 .91307 L 0 1 .509 r
F
.66111 .90667 m .65579 .90784 L .65408 .91058 L F
.6465 .90004 m .65831 .90199 L .65628 .89877 L 0 1 .496 r
F
.65303 .90055 m .64955 .90673 L .65579 .90784 L 0 1 .5 r
F
.64383 .92238 m .65135 .9046 L .65493 .9105 L 0 .367 .112 r
F
.65471 .91604 m .66198 .92212 L .66462 .91905 L 0 1 .518 r
F
.65471 .91604 m .66462 .91905 L .66161 .9167 L F
.64383 .92238 m .65493 .9105 L .65515 .91775 L 0 .367 .112 r
F
.6434 .94526 m .64785 .9375 L .65456 .90806 L 0 1 .199 r
F
.64785 .9375 m .65302 .92155 L .65456 .90806 L F
.63026 .99535 m .64017 .90052 L .63612 .91378 L 0 1 .196 r
F
.63026 .99535 m .6417 .9222 L .64017 .90052 L F
.63026 .99535 m .6398 .96363 L .6417 .9222 L F
.63026 .99535 m .63612 .91378 L .63223 .95347 L F
.63314 1.01019 m .63253 1.00645 L .63545 .99401 L 0 0 .06 r
F
.63492 .99714 m .63545 .98512 L .63773 .9806 L 0 .35 .193 r
F
.63294 1.02275 m .63709 1.00371 L .64143 .97926 L 0 .761 .07 r
F
.63294 1.02275 m .63344 1.02241 L .63709 1.00371 L F
.63166 1.07169 m .63185 1.02585 L .63381 1.00369 L 0 .35 .193 r
F
.63492 .99714 m .63381 1.00369 L .63545 .98512 L F
.63492 .99714 m .63381 1.00369 L .63568 .99743 L 0 1 .196 r
F
.63166 1.07169 m .63381 1.00369 L .63492 .99714 L 0 .35 .193 r
F
.63026 .99535 m .63158 1.01114 L .63381 1.00369 L 0 1 .196 r
F
.63026 .99535 m .63381 1.00369 L .63492 .99714 L F
.63026 .99535 m .63492 .99714 L .6398 .96363 L F
.63492 .99714 m .63568 .99743 L .63773 .9806 L F
.63492 .99714 m .63773 .9806 L .6398 .96363 L F
.63166 1.07169 m .63492 .99714 L .64005 .97602 L 0 .35 .193 r
F
.63492 .99714 m .63773 .9806 L .64005 .97602 L F
.62363 .88232 m .63175 1.01449 L .6246 .89409 L 0 .644 .229 r
F
.63175 1.01449 m .63425 .93771 L .62964 .89581 L 0 1 .192 r
F
.63354 1.12233 m .63329 1.1021 L .63893 1.10876 L 0 .492 .096 r
F
.63166 1.07169 m .64005 .97602 L .64205 .98015 L 0 .35 .193 r
F
.64127 .99505 m .64205 .98015 L .64292 .98193 L F
.63166 1.07169 m .64205 .98015 L .64127 .99505 L F
.63529 1.06539 m .63487 1.06353 L .6418 1.06668 L 0 0 0 r
F
.643 1.06738 m .63993 1.0689 L .6489 1.06961 L 0 .65 .3 r
F
.63529 1.06539 m .6418 1.06668 L .64498 1.06883 L 0 0 0 r
F
.63529 1.06539 m .64498 1.06883 L .64227 1.06852 L F
.65476 1.07171 m .63996 1.07186 L .64202 1.07288 L 0 .781 .321 r
F
.65476 1.07171 m .64541 1.07136 L .63996 1.07186 L F
.6489 1.06961 m .63685 1.07028 L .64541 1.07136 L 0 .719 .311 r
F
.64357 1.0758 m .63548 1.06763 L .6382 1.068 L 0 .097 0 r
F
.64357 1.0758 m .63777 1.07096 L .63548 1.06763 L F
.63354 1.12233 m .63893 1.10876 L .64291 1.11829 L 0 .492 .096 r
F
.63354 1.12233 m .64291 1.11829 L .64304 1.12701 L F
.63354 1.12233 m .64304 1.12701 L .63921 1.12906 L F
.63197 1.15931 m .63343 1.13142 L .63877 1.1403 L 0 .593 .124 r
F
.64838 .98929 m .64153 .99723 L .65315 .99461 L 0 1 .541 r
F
.64003 1.01368 m .64292 .98193 L .64215 .99902 L 0 .35 .193 r
F
.63166 1.07169 m .64127 .99505 L .64003 1.01368 L F
.64127 .99505 m .64292 .98193 L .64003 1.01368 L F
.63618 1.07608 m .63777 1.07096 L .64357 1.0758 L 0 .183 0 r
F
.64554 1.07862 m .63891 1.08136 L .65033 1.08111 L 0 1 .391 r
F
.64073 1.07612 m .64554 1.07862 L .65229 1.07779 L 0 .987 .384 r
F
.64073 1.07612 m .65229 1.07779 L .65024 1.07683 L F
.63618 1.07608 m .64357 1.0758 L .64565 1.07972 L 0 .183 0 r
F
.63618 1.07608 m .64565 1.07972 L .64259 1.08008 L F
.63354 1.12233 m .62974 1.1027 L .63329 1.1021 L 0 .492 .096 r
F
.63354 1.12233 m .62983 1.11135 L .62974 1.1027 L F
.63197 1.15931 m .62957 1.1325 L .63343 1.13142 L 0 .593 .124 r
F
.63197 1.15931 m .63877 1.1403 L .64204 1.15331 L F
.63538 1.22243 m .63147 1.19953 L .63496 1.19221 L 0 .312 .127 r
F
.63197 1.15931 m .64204 1.15331 L .64144 1.16535 L 0 .593 .124 r
F
.63538 1.22243 m .63164 1.21247 L .63147 1.19953 L 0 .312 .127 r
F
.63197 1.15931 m .64144 1.16535 L .63734 1.16832 L 0 .593 .124 r
F
.62767 1.209 m .63102 1.17122 L .63622 1.18425 L 0 .671 .157 r
F
.63538 1.22243 m .63496 1.19221 L .64054 1.19255 L 0 .312 .127 r
F
.63538 1.22243 m .64054 1.19255 L .64454 1.20034 L F
.62767 1.209 m .63622 1.18425 L .63885 1.20264 L 0 .671 .157 r
F
.63538 1.22243 m .64454 1.20034 L .64475 1.2133 L 0 .312 .127 r
F
.62767 1.209 m .63885 1.20264 L .63744 1.21898 L 0 .671 .157 r
F
.62767 1.209 m .63744 1.21898 L .63291 1.22224 L F
.6308 1.2213 m .63456 1.07791 L .63858 1.04005 L 0 .176 .162 r
F
.63321 1.14869 m .63619 1.07156 L .6353 1.08553 L F
.63166 1.07169 m .64003 1.01368 L .63858 1.04005 L 0 .35 .193 r
F
.64003 1.01368 m .64215 .99902 L .63858 1.04005 L F
.63407 1.13219 m .63521 1.10126 L .63321 1.14869 L 0 .176 .162 r
F
.63166 1.07169 m .63858 1.04005 L .63456 1.07791 L 0 .35 .193 r
F
.63521 1.10126 m .63858 1.00969 L .63464 1.11165 L 0 .176 .162 r
F
.63521 1.10126 m .63464 1.11165 L .63321 1.14869 L F
.63619 1.07156 m .63858 1.00969 L .63539 1.08359 L F
.63619 1.07156 m .63539 1.08359 L .6353 1.08553 L F
.6308 1.2213 m .63407 1.13219 L .63321 1.14869 L F
.63175 1.01449 m .6353 1.08553 L .63425 .93771 L 0 1 .192 r
F
.62177 .85219 m .62363 .88232 L .62186 .85109 L 0 .644 .229 r
F
.62363 .88232 m .6246 .89409 L .62194 .84997 L F
.62177 .85219 m .62376 .78408 L .62202 .84888 L 0 .586 .223 r
F
.62376 .78408 m .62529 .73158 L .62383 .78392 L F
.62376 .78408 m .62383 .78392 L .62202 .84888 L F
.62411 .78363 m .62529 .73158 L .62595 .72649 L F
.62202 .84888 m .62382 .78428 L .62411 .78363 L F
.62382 .78428 m .62529 .73158 L .62411 .78363 L F
.63826 .83089 m .63558 .84701 L .64412 .84147 L 0 1 .445 r
F
.63281 .8419 m .63042 .85278 L .6386 .8477 L 0 1 .508 r
F
.62889 .87053 m .63815 .87906 L .63806 .87663 L 0 .535 .401 r
F
.62889 .87053 m .63806 .87663 L .63427 .87328 L F
.6266 .86257 m .62859 .86784 L .63361 .87132 L 0 .318 .267 r
F
.6266 .86257 m .63361 .87132 L .63652 .87206 L F
.6266 .86257 m .63567 .86981 L .63163 .86606 L F
.6266 .86257 m .63652 .87206 L .63567 .86981 L F
.63245 .86611 m .63025 .86447 L .63163 .86606 L 0 .11 .171 r
F
.62573 .86 m .62634 .85877 L .63078 .86367 L 0 .21 0 r
F
.64995 .85151 m .63794 .86765 L .64645 .86644 L 0 1 .463 r
F
.64995 .85151 m .63589 .86389 L .63794 .86765 L F
.64437 .85375 m .63297 .867 L .64119 .86508 L 0 1 .508 r
F
.63245 .86611 m .63163 .86606 L .63567 .86981 L 0 .11 .171 r
F
.65577 .86107 m .64101 .87317 L .64306 .87675 L 0 1 .471 r
F
.65577 .86107 m .64645 .86644 L .64101 .87317 L F
.64995 .85151 m .64645 .86644 L .65577 .86107 L 0 1 .463 r
F
.65014 .86001 m .63805 .87345 L .64656 .87155 L 0 1 .507 r
F
.65014 .86001 m .63602 .87084 L .63805 .87345 L F
.65014 .86001 m .64119 .86508 L .63602 .87084 L F
.63245 .86611 m .63567 .86981 L .6405 .87369 L 0 .11 .171 r
F
.63245 .86611 m .6405 .87369 L .64291 .87511 L F
.62573 .86 m .63078 .86367 L .6328 .86618 L 0 .21 0 r
F
.63245 .86611 m .64291 .87511 L .64154 .87352 L 0 .11 .171 r
F
.62614 .8604 m .6328 .86618 L .6354 .86943 L 0 .21 0 r
F
.62573 .86 m .6328 .86618 L .62614 .8604 L F
.63582 .8688 m .64154 .87352 L .63729 .86999 L 0 .11 .171 r
F
.63245 .86611 m .63673 .86959 L .63582 .8688 L F
.63673 .86959 m .64154 .87352 L .63582 .8688 L F
.62573 .86 m .6354 .86943 L .63712 .87222 L 0 .21 0 r
F
.62573 .86 m .63496 .87065 L .63035 .86577 L F
.62573 .86 m .63712 .87222 L .63496 .87065 L F
.62884 .87044 m .63035 .86577 L .63496 .87065 L 0 .375 .039 r
F
.62884 .87044 m .62773 .86567 L .63035 .86577 L F
.65577 .86107 m .64306 .87675 L .65186 .87549 L 0 1 .471 r
F
.65577 .86107 m .65186 .87549 L .66156 .8702 L F
.65589 .86641 m .6411 .87739 L .64313 .88006 L 0 1 .506 r
F
.65589 .86641 m .64656 .87155 L .6411 .87739 L F
.63652 .87206 m .63806 .87663 L .64326 .8795 L 0 .373 .28 r
F
.63652 .87206 m .63427 .87328 L .63806 .87663 L F
.63652 .87206 m .63361 .87132 L .63427 .87328 L F
.62884 .87044 m .63496 .87065 L .63935 .8777 L 0 .375 .039 r
F
.63815 .87907 m .64306 .88643 L .64699 .88627 L 0 .63 .421 r
F
.66156 .8702 m .64816 .88547 L .65724 .88416 L 0 1 .478 r
F
.66156 .8702 m .64612 .88203 L .64816 .88547 L F
.66156 .8702 m .65724 .88416 L .66733 .87896 L F
.66162 .87292 m .64617 .88408 L .64819 .88677 L 0 1 .506 r
F
.66162 .87292 m .65192 .87814 L .64617 .88408 L F
.63815 .87907 m .64699 .88627 L .64723 .88404 L 0 .63 .421 r
F
.63815 .87907 m .64723 .88404 L .64361 .88124 L F
.62884 .87044 m .63935 .8777 L .64058 .88222 L 0 .375 .039 r
F
.62884 .87044 m .63796 .88215 L .63322 .87751 L F
.62884 .87044 m .64058 .88222 L .63796 .88215 L F
.6399 .80266 m .63382 .8189 L .64464 .81221 L 0 1 .454 r
F
.63826 .83089 m .63012 .83647 L .62557 .8438 L 0 1 .445 r
F
.63239 .8197 m .63012 .83647 L .63826 .83089 L 0 1 .436 r
F
.64464 .81221 m .63815 .82836 L .64937 .82164 L 0 1 .456 r
F
.63239 .8197 m .63826 .83089 L .64252 .82334 L 0 1 .436 r
F
.63239 .8197 m .64252 .82334 L .64006 .81886 L F
.6386 .8477 m .63581 .85881 L .64437 .85375 L 0 1 .508 r
F
.63281 .8419 m .6386 .8477 L .64291 .84213 L F
.63281 .8419 m .64291 .84213 L .64048 .83978 L F
.62568 .83517 m .62502 .84708 L .63281 .8419 L 0 1 .503 r
F
.62568 .83517 m .63281 .8419 L .63641 .83595 L F
.62568 .83517 m .63641 .83595 L .63342 .8332 L F
.63826 .83089 m .64412 .84147 L .64868 .83413 L 0 1 .445 r
F
.63826 .83089 m .64868 .83413 L .64622 .82988 L F
.64464 .81221 m .64937 .82164 L .65628 .81378 L 0 1 .456 r
F
.64464 .81221 m .65628 .81378 L .65427 .81002 L F
.6509 .80579 m .64006 .81886 L .64252 .82334 L 0 1 .436 r
F
.64311 .82013 m .63342 .8332 L .63641 .83595 L 0 1 .485 r
F
.64311 .82013 m .63629 .82642 L .63342 .8332 L F
.63679 .8149 m .62946 .82964 L .63628 .82642 L 0 1 .479 r
F
.63679 .8149 m .62717 .82766 L .62946 .82964 L F
.63679 .8149 m .63031 .82134 L .62717 .82766 L F
.63047 .80989 m .63031 .82134 L .63679 .8149 L 0 1 .471 r
F
.62427 .85341 m .63718 .8543 L .63476 .81461 L 0 .814 .24 r
F
.66156 .8702 m .65186 .87549 L .64612 .88203 L 0 1 .478 r
F
.65589 .86641 m .64313 .88006 L .65192 .87814 L 0 1 .506 r
F
.63652 .87206 m .64326 .8795 L .64641 .87998 L 0 .373 .28 r
F
.63652 .87206 m .64641 .87998 L .64575 .87802 L F
.63652 .87206 m .64575 .87802 L .64173 .87494 L F
.63713 .87222 m .6354 .86943 L .63729 .86999 L 0 .154 0 r
F
.62427 .85341 m .63612 .91378 L .63718 .8543 L 0 .814 .24 r
F
.62964 .89581 m .63425 .93771 L .6303 .84523 L 0 1 .192 r
F
.63435 .7723 m .6344 .77276 L .63033 .77314 L 0 .625 .212 r
F
.62902 .77708 m .63198 .78035 L .63247 .7794 L 0 1 .491 r
F
.63198 .78035 m .63614 .78494 L .63247 .7794 L F
.62957 .785 m .62973 .78929 L .63113 .78199 L 0 .459 .231 r
F
.62957 .785 m .63113 .78199 L .63127 .78127 L F
.62514 .80507 m .63592 .81112 L .63288 .80528 L 0 1 .426 r
F
.6425 .79109 m .63288 .80528 L .63592 .81112 L F
.6425 .79109 m .6357 .7967 L .63288 .80528 L F
.6399 .80266 m .64464 .81221 L .65125 .80434 L 0 1 .454 r
F
.6399 .80266 m .65125 .80434 L .64924 .80054 L F
.6425 .79109 m .63592 .81112 L .64364 .81134 L 0 1 .426 r
F
.63047 .80989 m .63679 .8149 L .63968 .80853 L 0 1 .471 r
F
.63047 .80989 m .63968 .80853 L .63705 .80648 L F
.62413 .80514 m .63047 .80989 L .63309 .80347 L 0 1 .461 r
F
.63776 .78685 m .63309 .80347 L .63929 .79941 L 0 1 .446 r
F
.62413 .80514 m .63309 .80347 L .63046 .80151 L 0 1 .461 r
F
.63776 .78685 m .63046 .80151 L .63309 .80347 L 0 1 .446 r
F
.63776 .78685 m .63245 .79439 L .63046 .80151 L F
.63047 .80989 m .62374 .82475 L .63031 .82134 L 0 1 .471 r
F
.62413 .80514 m .62433 .8165 L .63047 .80989 L 0 1 .461 r
F
.62427 .85341 m .63476 .81461 L .62973 .78929 L 0 .814 .24 r
F
.62902 .77708 m .63128 .78167 L .63614 .78494 L 0 1 .491 r
F
.62902 .77708 m .64038 .78472 L .64173 .78069 L F
.65132 .7649 m .64294 .77856 L .64561 .78331 L 0 1 .416 r
F
.65132 .7649 m .64538 .77067 L .64294 .77856 L F
.64215 .76125 m .63952 .77969 L .6453 .77498 L 0 1 .42 r
F
.62902 .77708 m .64173 .78069 L .63928 .77553 L 0 1 .491 r
F
.63039 .77654 m .6344 .77276 L .63037 .77422 L 0 .689 .233 r
F
.63438 .77378 m .6344 .77276 L .63039 .77654 L F
.63441 .77267 m .63445 .77273 L .63444 .77275 L 0 .625 .212 r
F
.63028 .84428 m .63452 .77367 L .63438 .77378 L 0 .722 .24 r
F
.63441 .77405 m .63441 .77375 L .63438 .77378 L 0 .689 .233 r
F
.63441 .77375 m .63444 .77265 L .63438 .77378 L F
.6509 .80579 m .64364 .81134 L .64006 .81886 L 0 1 .436 r
F
.63679 .8149 m .63628 .82642 L .64311 .82012 L 0 1 .479 r
F
.63679 .8149 m .64311 .82012 L .64626 .8138 L F
.63679 .8149 m .64626 .8138 L .64363 .81167 L F
.65931 .77488 m .6442 .79094 L .64621 .79479 L 0 1 .446 r
F
.6425 .79109 m .64364 .81134 L .6509 .80579 L 0 1 .426 r
F
.66502 .78459 m .65125 .80434 L .66045 .80161 L 0 1 .449 r
F
.66502 .78459 m .64924 .80054 L .65125 .80434 L F
.66502 .78459 m .65513 .79207 L .64924 .80054 L F
.65931 .77488 m .64621 .79479 L .65513 .79207 L 0 1 .446 r
F
.6425 .79109 m .6509 .80579 L .65373 .7972 L 0 1 .426 r
F
.6425 .79109 m .65373 .7972 L .65023 .7913 L F
.64491 .79205 m .63705 .80648 L .63968 .80853 L 0 1 .455 r
F
.64491 .79205 m .63929 .79941 L .63705 .80648 L F
.63776 .78685 m .63929 .79941 L .64491 .79205 L 0 1 .446 r
F
.65931 .77488 m .6498 .78241 L .6442 .79094 L F
.63776 .78685 m .64491 .79205 L .64691 .78492 L F
.63776 .78685 m .64691 .78492 L .64396 .7828 L F
.63476 .81461 m .64038 .78472 L .63614 .78494 L 0 .854 .256 r
F
.64491 .79205 m .63968 .80853 L .64611 .80467 L 0 1 .455 r
F
.63476 .81461 m .64523 .80099 L .64038 .78472 L 0 .854 .256 r
F
.6509 .80579 m .64252 .82334 L .65009 .82257 L 0 1 .436 r
F
.65772 .81707 m .64622 .82988 L .64868 .83413 L 0 1 .445 r
F
.65772 .81707 m .65009 .82257 L .64622 .82988 L F
.6509 .80579 m .65009 .82257 L .65772 .81707 L 0 1 .436 r
F
.64311 .82013 m .65138 .82726 L .65426 .82047 L 0 1 .485 r
F
.64311 .82013 m .65426 .82047 L .65081 .81758 L F
.67072 .79415 m .65628 .81378 L .66576 .81102 L 0 1 .452 r
F
.67072 .79415 m .65427 .81002 L .65628 .81378 L F
.67072 .79415 m .66045 .80161 L .65427 .81002 L F
.6509 .80579 m .65772 .81707 L .66132 .80955 L 0 1 .436 r
F
.6509 .80579 m .66132 .80955 L .65848 .80502 L F
.65205 .79745 m .64626 .8138 L .65292 .8101 L 0 1 .463 r
F
.65205 .79745 m .64363 .81167 L .64626 .8138 L F
.65205 .79745 m .64611 .80467 L .64363 .81167 L F
.63875 .80942 m .64729 .82272 L .64523 .80099 L 0 .854 .256 r
F
.65531 .7133 m .64655 .73623 L .6542 .73269 L 0 1 .418 r
F
.65531 .7133 m .64414 .73217 L .64655 .73623 L F
.64861 .70256 m .65531 .7133 L .65879 .70323 L 0 1 .411 r
F
.64406 .75216 m .64538 .77067 L .65132 .7649 L 0 1 .407 r
F
.64785 .75515 m .65358 .76506 L .65862 .75635 L 0 1 .439 r
F
.64785 .75515 m .65862 .75635 L .65621 .75235 L F
.64406 .75216 m .65353 .75671 L .65053 .75157 L 0 1 .407 r
F
.64406 .75216 m .65132 .7649 L .65353 .75671 L F
.66199 .72392 m .65018 .7423 L .65259 .74633 L 0 1 .424 r
F
.66199 .72392 m .6542 .73269 L .65018 .7423 L F
.64909 .72317 m .64602 .74366 L .65207 .74321 L 0 .945 .394 r
F
.66199 .72392 m .65259 .74633 L .66051 .74294 L 0 1 .424 r
F
.65531 .7133 m .6542 .73269 L .66199 .72392 L 0 1 .418 r
F
.64909 .72317 m .65207 .74321 L .65714 .7372 L 0 .945 .394 r
F
.64909 .72317 m .65846 .72842 L .65515 .72271 L F
.64909 .72317 m .65714 .7372 L .65846 .72842 L F
.65531 .7133 m .66199 .72392 L .66575 .71409 L 0 1 .418 r
F
.65531 .7133 m .66575 .71409 L .66297 .70977 L F
.64861 .70256 m .65879 .70323 L .656 .69883 L 0 1 .411 r
F
.65124 .69145 m .65019 .71392 L .65581 .7137 L 0 .841 .377 r
F
.65358 .76506 m .6498 .78241 L .65931 .77488 L 0 1 .442 r
F
.65132 .7649 m .64561 .78331 L .6523 .78265 L 0 1 .416 r
F
.65006 .76668 m .64396 .7828 L .64691 .78492 L 0 1 .431 r
F
.65006 .76668 m .6453 .77498 L .64396 .7828 L F
.64215 .76125 m .6453 .77498 L .65006 .76668 L 0 1 .42 r
F
.64215 .76125 m .65006 .76668 L .65119 .75878 L F
.64215 .76125 m .65119 .75878 L .64794 .75655 L F
.64909 .72317 m .64302 .73824 L .64602 .74366 L 0 .945 .394 r
F
.64909 .72317 m .64433 .72947 L .64302 .73824 L F
.64372 .73276 m .64842 .74788 L .65231 .73856 L 0 1 .393 r
F
.64372 .73276 m .64306 .7533 L .64842 .74788 L F
.64372 .73276 m .65231 .73856 L .6526 .72976 L F
.64372 .73276 m .6526 .72976 L .64908 .72734 L F
.65178 .70702 m .64908 .72734 L .6526 .72976 L 0 1 .379 r
F
.65124 .69145 m .64687 .70788 L .65019 .71392 L 0 .841 .377 r
F
.65124 .69145 m .64733 .69826 L .64687 .70788 L F
.64261 .70064 m .65178 .70702 L .65126 .69706 L 0 1 .366 r
F
.64104 .70835 m .65019 .71392 L .64687 .70788 L 0 .939 .384 r
F
.64104 .70835 m .64909 .72317 L .65019 .71392 L F
.65178 .70702 m .64873 .71759 L .64908 .72734 L 0 1 .379 r
F
.64261 .70064 m .64873 .71759 L .65178 .70702 L 0 1 .366 r
F
.63843 .58327 m .64725 .58265 L .64401 .57707 L 0 1 .341 r
F
.63843 .58327 m .64629 .59665 L .64725 .58265 L F
.63843 .58327 m .64177 .60975 L .64629 .59665 L F
.63843 .58327 m .63618 .61598 L .64177 .60975 L F
.64629 .59665 m .64352 .628 L .64934 .62232 L 0 1 .351 r
F
.64629 .59665 m .64058 .62319 L .64352 .628 L F
.64629 .59665 m .64177 .60975 L .64058 .62319 L F
.6559 .66325 m .65133 .69143 L .65875 .68797 L 0 1 .389 r
F
.64169 .64033 m .65087 .63996 L .64793 .63519 L 0 1 .371 r
F
.6559 .66325 m .6479 .68595 L .65133 .69143 L 0 1 .389 r
F
.64169 .64033 m .64879 .65186 L .65087 .63996 L 0 1 .371 r
F
.6559 .66325 m .64986 .67387 L .6479 .68595 L 0 1 .389 r
F
.64879 .65186 m .64986 .67387 L .65589 .66325 L 0 1 .38 r
F
.64879 .65186 m .64337 .67867 L .64986 .67387 L F
.64169 .64033 m .64308 .66296 L .64879 .65186 L 0 1 .371 r
F
.63843 .58327 m .63324 .61117 L .63618 .61598 L 0 1 .341 r
F
.637 .58867 m .64591 .5996 L .64169 .58892 L 0 .643 .322 r
F
.637 .58867 m .64736 .61418 L .64591 .5996 L F
.637 .58867 m .64508 .62291 L .64736 .61418 L F
.637 .58867 m .64037 .62263 L .64508 .62291 L F
.64123 .63584 m .65006 .64391 L .64623 .63565 L 0 .74 .346 r
F
.64879 .65186 m .65822 .65176 L .65528 .64707 L 0 1 .38 r
F
.64879 .65186 m .65589 .66325 L .65822 .65176 L F
.64123 .63584 m .65062 .65578 L .65006 .64391 L 0 .74 .346 r
F
.64123 .63584 m .64753 .66334 L .65062 .65578 L F
.64123 .63584 m .64253 .66351 L .64753 .66334 L F
.64736 .61418 m .64508 .62292 L .64623 .63565 L 0 .607 .333 r
F
.65415 .60993 m .64793 .63519 L .65087 .63996 L 0 1 .361 r
F
.65415 .60993 m .64934 .62232 L .64793 .63519 L F
.64736 .61418 m .64623 .63565 L .65006 .64391 L 0 .607 .333 r
F
.64304 .42017 m .65055 .4626 L .65271 .44443 L 0 .789 .296 r
F
.64304 .42017 m .64613 .47016 L .65055 .4626 L F
.65271 .44443 m .65172 .48234 L .65545 .49045 L 0 .761 .306 r
F
.65271 .44443 m .65055 .4626 L .65172 .48234 L F
.64684 .4891 m .65545 .49045 L .65172 .48234 L 0 .89 .314 r
F
.64684 .4891 m .65599 .50828 L .65545 .49045 L F
.64684 .4891 m .65297 .52397 L .65599 .50828 L F
.64797 .54687 m .65682 .54726 L .65332 .54068 L 0 .997 .332 r
F
.64797 .54687 m .65652 .56258 L .65682 .54726 L F
.64797 .54687 m .65261 .57644 L .65652 .56258 L F
.64797 .54687 m .64725 .58265 L .65261 .57644 L F
.64629 .59665 m .65533 .59651 L .6521 .59098 L 0 1 .351 r
F
.64629 .59665 m .65415 .60993 L .65533 .59651 L F
.64629 .59665 m .64934 .62232 L .65415 .60993 L F
.64386 .45319 m .65156 .48367 L .64678 .45963 L 0 .163 .214 r
F
.64386 .45319 m .65573 .50772 L .65156 .48367 L F
.65599 .50828 m .65682 .54726 L .6619 .5414 L 0 .875 .324 r
F
.65599 .50828 m .65332 .54068 L .65682 .54726 L F
.65599 .50828 m .65297 .52397 L .65332 .54068 L F
.64386 .45319 m .65647 .51557 L .65573 .50772 L 0 .163 .214 r
F
.64386 .45319 m .65351 .50894 L .65647 .51557 L F
.64386 .45319 m .64884 .49235 L .65351 .50894 L F
.64386 .45319 m .64472 .46848 L .64884 .49235 L F
.64541 .50913 m .65399 .53696 L .64925 .51675 L 0 .192 .232 r
F
.64541 .50913 m .65715 .55651 L .65399 .53696 L F
.64541 .50913 m .65658 .56224 L .65715 .55651 L F
.64541 .50913 m .65271 .55448 L .65658 .56224 L F
.63944 .53109 m .64807 .53077 L .64458 .52412 L 0 1 .322 r
F
.63944 .53109 m .64797 .54687 L .64807 .53077 L F
.64541 .50913 m .64812 .53847 L .65271 .55448 L 0 .192 .232 r
F
.63259 .38511 m .64472 .46848 L .64386 .45319 L 0 .283 .24 r
F
.63182 .38044 m .63219 .38295 L .63259 .38511 L F
.63219 .38295 m .64472 .46848 L .63259 .38511 L F
.63182 .38044 m .64373 .45241 L .63951 .41655 L F
.64373 .45241 m .64386 .45319 L .63951 .41655 L F
.62854 .32316 m .63463 .38332 L .63951 .41655 L 0 0 .118 r
F
.63182 .38044 m .63951 .41655 L .63463 .38332 L 0 .283 .24 r
F
.63169 .35001 m .63951 .41655 L .64239 .44115 L 0 0 .118 r
F
.62854 .32316 m .63951 .41655 L .63169 .35001 L F
.64128 .44037 m .64239 .44115 L .6458 .45552 L 0 .587 .029 r
F
.64618 .45753 m .6458 .45552 L .64678 .45963 L F
.64128 .44037 m .6458 .45552 L .64618 .45753 L F
.64128 .44037 m .64888 .49192 L .64404 .46201 L F
.64645 .49372 m .65351 .50894 L .64884 .49235 L 0 .415 .28 r
F
.64691 .49656 m .6572 .53141 L .65351 .50894 L F
.6477 .50081 m .65745 .54471 L .6572 .53141 L F
.64555 .49022 m .65014 .51344 L .6477 .50081 L 0 0 .128 r
F
.64555 .49022 m .65399 .53696 L .65614 .54544 L F
.65014 .51344 m .65614 .54544 L .65745 .54471 L 0 .415 .28 r
F
.65014 .51344 m .65614 .54544 L .6576 .55122 L 0 0 .128 r
F
.64555 .49022 m .65614 .54544 L .65014 .51344 L F
.64555 .49022 m .64925 .51675 L .65399 .53696 L F
.64564 .49418 m .65422 .5465 L .65614 .54544 L 0 .415 .28 r
F
.64564 .49418 m .65614 .54544 L .65014 .51344 L F
.64564 .49418 m .65014 .51344 L .6477 .50081 L F
.65014 .51344 m .65745 .54471 L .6477 .50081 L F
.65014 .51344 m .65129 .51927 L .6477 .50081 L 0 0 .128 r
F
.6477 .50081 m .6576 .55122 L .65765 .5499 L F
.65129 .51927 m .6576 .55122 L .6477 .50081 L F
.64555 .49022 m .6477 .50081 L .64691 .49656 L F
.64685 .49645 m .6477 .50081 L .64691 .49656 L 0 .415 .28 r
F
.64564 .49418 m .6477 .50081 L .64685 .49645 L F
.6477 .50081 m .6572 .53141 L .64691 .49656 L F
.6477 .50081 m .64841 .50429 L .64691 .49656 L 0 0 .128 r
F
.64691 .49656 m .65765 .5499 L .654 .52968 L F
.64841 .50429 m .65765 .5499 L .64691 .49656 L F
.64555 .49022 m .64691 .49656 L .64645 .49372 L F
.64637 .49377 m .64691 .49656 L .64645 .49372 L 0 .415 .28 r
F
.64564 .49418 m .64691 .49656 L .64637 .49377 L F
.64691 .49656 m .65351 .50894 L .64645 .49372 L F
.64645 .49372 m .654 .52968 L .64912 .50424 L 0 0 .128 r
F
.64691 .49656 m .654 .52968 L .64645 .49372 L F
.64128 .44037 m .65334 .51074 L .64888 .49192 L 0 .587 .029 r
F
.64128 .44037 m .65439 .50564 L .65334 .51074 L F
.64128 .44037 m .65156 .48367 L .65439 .50564 L F
.64128 .44037 m .64678 .45963 L .65156 .48367 L F
.64398 .5347 m .65271 .55448 L .64812 .53847 L 0 .319 .282 r
F
.63944 .53109 m .64433 .56173 L .64797 .54687 L 0 1 .322 r
F
.64797 .54687 m .64401 .57707 L .64725 .58265 L 0 .997 .332 r
F
.64797 .54687 m .64433 .56173 L .64401 .57707 L F
.65652 .56258 m .6521 .59098 L .65533 .59651 L 0 .988 .342 r
F
.65652 .56258 m .65261 .57644 L .6521 .59098 L F
.64398 .5347 m .65531 .5724 L .65271 .55448 L 0 .319 .282 r
F
.64398 .5347 m .65419 .58022 L .65531 .5724 L F
.64398 .5347 m .65002 .57637 L .65419 .58022 L F
.64398 .5347 m .64561 .56347 L .65002 .57637 L F
.64119 .56195 m .65002 .57637 L .64561 .56347 L 0 .497 .306 r
F
.64119 .56195 m .65206 .59255 L .65002 .57637 L F
.64119 .56195 m .65035 .60117 L .65206 .59255 L F
.64119 .56195 m .64591 .5996 L .65035 .60117 L F
.64564 .49418 m .64968 .53561 L .65422 .5465 L 0 .415 .28 r
F
.64564 .49418 m .64601 .51318 L .64968 .53561 L F
.64465 .48848 m .64513 .48666 L .64912 .50424 L 0 .583 .023 r
F
.64465 .48848 m .64912 .50424 L .654 .52968 L F
.63772 .46998 m .63935 .51426 L .64406 .50625 L 0 .912 .305 r
F
.63772 .46998 m .63587 .50774 L .63935 .51426 L F
.63772 .46998 m .63517 .48874 L .63587 .50774 L F
.6337 .45506 m .64541 .50913 L .64214 .48406 L 0 .274 .252 r
F
.6337 .45506 m .645 .51907 L .64541 .50913 L F
.64541 .50913 m .645 .51907 L .64812 .53847 L 0 .192 .232 r
F
.63412 .45203 m .64601 .51318 L .64564 .49418 L 0 .51 .269 r
F
.64465 .48848 m .65296 .54313 L .64798 .51256 L 0 .583 .023 r
F
.64613 .54135 m .65422 .5465 L .64968 .53561 L 0 .645 .299 r
F
.65652 .56258 m .66558 .56341 L .66208 .557 L 0 .988 .342 r
F
.65652 .56258 m .66508 .57795 L .66558 .56341 L F
.65652 .56258 m .6609 .59092 L .66508 .57795 L F
.65652 .56258 m .65533 .59651 L .6609 .59092 L F
.65715 .55651 m .65658 .56225 L .65944 .57664 L 0 .093 .191 r
F
.64613 .54135 m .65737 .56577 L .65422 .5465 L 0 .645 .299 r
F
.64465 .48848 m .65702 .56104 L .65296 .54313 L 0 .583 .023 r
F
.66508 .57795 m .66342 .61011 L .66919 .60501 L 0 .983 .352 r
F
.66508 .57795 m .66019 .6047 L .66342 .61011 L F
.66508 .57795 m .6609 .59092 L .66019 .6047 L F
.6612 .56826 m .66523 .57088 L .66008 .56257 L 0 .613 .317 r
F
.66508 .57795 m .67435 .57903 L .67084 .57285 L 0 .983 .352 r
F
.66508 .57795 m .67364 .59281 L .67435 .57903 L F
.66508 .57795 m .66919 .60501 L .67364 .59281 L F
.6612 .56826 m .66815 .58694 L .66523 .57088 L 0 .613 .317 r
F
.6631 .57703 m .66815 .58694 L .6612 .56826 L F
.65715 .55651 m .66384 .59015 L .66767 .59811 L 0 .093 .191 r
F
.65715 .55651 m .65944 .57664 L .66384 .59015 L F
.65737 .56578 m .66769 .59908 L .66769 .59899 L 0 .613 .317 r
F
.65715 .55651 m .66767 .59811 L .66774 .59779 L 0 .093 .191 r
F
.6631 .57703 m .66774 .59779 L .66815 .58694 L 0 .613 .317 r
F
.67364 .59281 m .66828 .6181 L .67151 .62335 L 0 .982 .362 r
F
.67364 .59281 m .66919 .60501 L .66828 .6181 L F
.67364 .59281 m .67151 .62335 L .67748 .61864 L F
.66617 .6045 m .67356 .61848 L .67042 .6091 L 0 .239 .276 r
F
.66202 .62297 m .67151 .62335 L .66828 .6181 L 0 1 .37 r
F
.66617 .6045 m .66489 .61006 L .66709 .62179 L 0 .239 .276 r
F
.66202 .62297 m .66988 .63569 L .67151 .62335 L 0 1 .37 r
F
.66617 .6045 m .66709 .62179 L .67132 .6319 L 0 .239 .276 r
F
.66988 .63569 m .68136 .63889 L .67712 .63226 L 0 1 .379 r
F
.67385 .61868 m .67614 .62681 L .67476 .61881 L 0 .797 .347 r
F
.66815 .58694 m .66946 .6012 L .67476 .61881 L 0 .603 .337 r
F
.66979 .60484 m .67042 .6091 L .67323 .61662 L 0 0 .154 r
F
.67356 .61848 m .67323 .61662 L .67042 .6091 L 0 .239 .276 r
F
.67262 .61454 m .67052 .61274 L .67306 .61637 L 0 .603 .337 r
F
.66946 .6012 m .66979 .60484 L .67262 .61454 L F
.66979 .60484 m .66767 .59811 L .67042 .6091 L 0 0 .154 r
F
.66831 .58865 m .66774 .59779 L .66979 .60484 L 0 .603 .337 r
F
.66836 .59516 m .66774 .59779 L .66979 .60484 L 0 0 .154 r
F
.66774 .59779 m .66767 .59811 L .66979 .60484 L F
.66979 .60484 m .66774 .59779 L .67034 .61085 L 0 .603 .337 r
F
.66979 .60484 m .67052 .61274 L .67262 .61454 L F
.66946 .6012 m .67306 .61637 L .67476 .61881 L F
.66963 .60371 m .66979 .60484 L .67339 .61706 L 0 0 .154 r
F
.66979 .60484 m .67323 .61662 L .67339 .61706 L F
.67365 .61865 m .67476 .61881 L .67323 .61662 L 0 .797 .347 r
F
.66836 .59516 m .66963 .60371 L .67481 .62086 L 0 0 .154 r
F
.66963 .60371 m .67339 .61706 L .67481 .62086 L F
.67365 .61865 m .677 .63177 L .67614 .62681 L 0 .797 .347 r
F
.67365 .61865 m .67614 .62681 L .67385 .61868 L F
.67356 .61848 m .67409 .62065 L .67365 .61865 L 0 .239 .276 r
F
.66617 .6045 m .67635 .63089 L .67356 .61848 L F
.67635 .63089 m .677 .63177 L .67365 .61865 L 0 .797 .347 r
F
.67635 .63089 m .67673 .63189 L .67525 .62563 L 0 .239 .276 r
F
.67635 .63089 m .67525 .62563 L .67356 .61848 L F
.66988 .63569 m .6802 .65181 L .68136 .63889 L 0 1 .379 r
F
.66617 .6045 m .67558 .63657 L .67685 .63312 L 0 .239 .276 r
F
.67635 .63089 m .67685 .63312 L .677 .63177 L 0 .797 .347 r
F
.67635 .63089 m .67685 .63312 L .67703 .63265 L 0 .239 .276 r
F
.66617 .6045 m .67685 .63312 L .67635 .63089 L F
.67635 .63089 m .67684 .63324 L .67685 .63312 L 0 .797 .347 r
F
.66617 .6045 m .67132 .6319 L .67558 .63657 L 0 .239 .276 r
F
.67709 .63394 m .67558 .63657 L .67766 .64623 L 0 .211 .267 r
F
.66988 .63569 m .6744 .66239 L .6802 .65181 L 0 1 .379 r
F
.6802 .65181 m .67553 .67865 L .68247 .67459 L 0 1 .39 r
F
.6802 .65181 m .6724 .67389 L .67553 .67865 L F
.6802 .65181 m .6744 .66239 L .6724 .67389 L F
.6802 .65181 m .68247 .67459 L .68858 .66442 L F
.6802 .65181 m .69059 .65292 L .68714 .64775 L F
.6802 .65181 m .68858 .66442 L .69059 .65292 L F
.67294 .64367 m .68189 .65522 L .67766 .64623 L 0 .368 .332 r
F
.67294 .64367 m .68337 .6654 L .68189 .65522 L F
.67294 .64367 m .6811 .66994 L .68337 .6654 L F
.67709 .63394 m .67575 .64296 L .67789 .65464 L 0 .807 .365 r
F
.677 .63177 m .67685 .63312 L .67709 .63394 L F
.67705 .63382 m .67558 .63657 L .67709 .63394 L 0 .211 .267 r
F
.67685 .63312 m .67558 .63657 L .67708 .63378 L F
.67685 .63312 m .67575 .64296 L .67709 .63394 L 0 .807 .365 r
F
.67708 .63378 m .67705 .63382 L .67709 .63394 L 0 .211 .267 r
F
.67703 .63265 m .67685 .63312 L .67708 .63378 L F
.66651 .61765 m .67684 .63324 L .67676 .63286 L 0 .797 .347 r
F
.67583 .63019 m .67676 .63286 L .67635 .63089 L F
.66651 .61765 m .67676 .63286 L .67583 .63019 L F
.66651 .61765 m .67575 .64296 L .67684 .63324 L F
.67673 .63189 m .67703 .63265 L .67356 .61848 L 0 .239 .276 r
F
.66651 .61765 m .67635 .63089 L .67365 .61865 L 0 .797 .347 r
F
.67365 .61865 m .67703 .63265 L .67481 .62086 L 0 .239 .276 r
F
.67409 .62065 m .67703 .63265 L .67365 .61865 L F
.66651 .61765 m .67365 .61865 L .67052 .61274 L 0 .797 .347 r
F
.67356 .61848 m .67365 .61865 L .67323 .61662 L 0 .239 .276 r
F
.67365 .61865 m .67323 .61662 L .67052 .61274 L 0 .797 .347 r
F
.67365 .61865 m .67481 .62086 L .67323 .61662 L 0 .239 .276 r
F
.66815 .58694 m .66813 .58761 L .66831 .58865 L 0 .603 .337 r
F
.66813 .58761 m .66774 .59779 L .66831 .58865 L F
.67034 .61085 m .66769 .59908 L .67052 .61274 L F
.66774 .59779 m .66769 .59908 L .67034 .61085 L F
.66468 .58247 m .66774 .59779 L .66836 .59516 L 0 .093 .191 r
F
.6631 .57703 m .66774 .59779 L .66468 .58247 L F
.65715 .55651 m .66774 .59779 L .6631 .57703 L F
.6631 .57703 m .66769 .59899 L .66774 .59779 L 0 .613 .317 r
F
.65737 .56578 m .66769 .59899 L .6631 .57703 L F
.66138 .56877 m .66836 .59516 L .66548 .58066 L 0 .093 .191 r
F
.6612 .56826 m .66152 .56947 L .66138 .56877 L F
.66152 .56947 m .66836 .59516 L .66138 .56877 L F
.65715 .55651 m .6631 .57703 L .6612 .56826 L F
.6631 .57703 m .66836 .59516 L .6612 .56826 L F
.66241 .57568 m .6631 .57703 L .6612 .56826 L 0 .613 .317 r
F
.65737 .56578 m .66241 .57568 L .6612 .56826 L F
.66037 .56317 m .66548 .58066 L .66095 .56437 L 0 .093 .191 r
F
.66008 .56257 m .6605 .56398 L .66037 .56317 L F
.6605 .56398 m .66548 .58066 L .66037 .56317 L F
.65715 .55651 m .6612 .56826 L .66008 .56257 L F
.6612 .56826 m .66548 .58066 L .66008 .56257 L F
.66008 .56257 m .66523 .57088 L .66088 .56163 L 0 .613 .317 r
F
.65737 .56578 m .6612 .56826 L .66008 .56257 L F
.64465 .48848 m .6574 .55409 L .65702 .56104 L 0 .583 .023 r
F
.64465 .48848 m .654 .52968 L .6574 .55409 L F
.65415 .60993 m .65691 .63473 L .66202 .62297 L 0 1 .361 r
F
.65415 .60993 m .65087 .63996 L .65691 .63473 L F
.64736 .61418 m .65614 .62431 L .6521 .61477 L 0 .607 .333 r
F
.66202 .62297 m .65691 .63473 L .65528 .64707 L 0 1 .37 r
F
.64736 .61418 m .65731 .63707 L .65614 .62431 L 0 .607 .333 r
F
.64736 .61418 m .65481 .64452 L .65731 .63707 L F
.64736 .61418 m .65006 .64391 L .65481 .64452 L F
.63203 .39062 m .64465 .48848 L .64041 .45767 L 0 0 .083 r
F
.6337 .45506 m .64126 .51326 L .645 .51907 L 0 .274 .252 r
F
.6337 .45506 m .6367 .49566 L .64126 .51326 L F
.63412 .45203 m .64291 .51914 L .64601 .51318 L 0 .51 .269 r
F
.63271 .4936 m .64126 .51326 L .6367 .49566 L 0 .415 .28 r
F
.63271 .4936 m .64398 .5347 L .64126 .51326 L F
.63412 .45203 m .63841 .50807 L .64291 .51914 L 0 .51 .269 r
F
.63271 .4936 m .64303 .54562 L .64398 .5347 L 0 .415 .28 r
F
.63271 .4936 m .63901 .54348 L .64303 .54562 L F
.63498 .51712 m .64291 .51914 L .63841 .50807 L 0 .696 .284 r
F
.64398 .5347 m .64303 .54562 L .64561 .56347 L 0 .319 .282 r
F
.63498 .51712 m .64613 .54135 L .64291 .51914 L 0 .696 .284 r
F
.63018 .40433 m .64308 .52275 L .63861 .49928 L 0 .974 .102 r
F
.63018 .40433 m .64377 .50388 L .64308 .52275 L F
.63018 .40433 m .64041 .45767 L .64377 .50388 L F
.63887 .50195 m .64404 .46201 L .64888 .49192 L 0 .838 .18 r
F
.65532 .57241 m .65419 .58023 L .65651 .59451 L 0 .274 .281 r
F
.65532 .57241 m .66384 .59015 L .65944 .57664 L F
.65532 .57241 m .66617 .6045 L .66384 .59015 L F
.65532 .57241 m .66489 .61006 L .66617 .6045 L F
.65415 .60993 m .66342 .61011 L .66019 .6047 L 0 1 .361 r
F
.65532 .57241 m .66074 .60577 L .66489 .61006 L 0 .274 .281 r
F
.65532 .57241 m .65651 .59451 L .66074 .60577 L F
.64613 .54135 m .65702 .58056 L .65737 .56577 L 0 .645 .299 r
F
.64613 .54135 m .65345 .58631 L .65702 .58056 L F
.64613 .54135 m .64905 .5792 L .65345 .58631 L F
.64613 .54135 m .64591 .55991 L .64905 .5792 L F
.64512 .58649 m .65345 .58631 L .64905 .5792 L 0 .816 .312 r
F
.65206 .59255 m .65036 .60117 L .6521 .61477 L 0 .44 .315 r
F
.65206 .59255 m .66074 .60577 L .65651 .59451 L F
.65415 .60993 m .66202 .62297 L .66342 .61011 L 0 1 .361 r
F
.65206 .59255 m .6625 .61941 L .66074 .60577 L 0 .44 .315 r
F
.65206 .59255 m .6606 .62631 L .6625 .61941 L F
.65206 .59255 m .65614 .62431 L .6606 .62631 L F
.65206 .59255 m .6521 .61477 L .65614 .62431 L F
.64512 .58649 m .65603 .60251 L .65345 .58631 L 0 .816 .312 r
F
.64512 .58649 m .65505 .61699 L .65603 .60251 L F
.64512 .58649 m .65112 .62431 L .65505 .61699 L F
.64119 .56195 m .64169 .58892 L .64591 .5996 L 0 .497 .306 r
F
.64512 .58649 m .64686 .61957 L .65112 .62431 L 0 .816 .312 r
F
.64308 .52275 m .64798 .51256 L .65296 .54313 L 0 .961 .122 r
F
.64308 .52275 m .64377 .50388 L .64798 .51256 L F
.63887 .50195 m .64888 .49192 L .65169 .53568 L 0 .838 .18 r
F
.64258 .62721 m .65112 .62431 L .64686 .61957 L 0 .964 .325 r
F
.64258 .62721 m .65311 .63797 L .65112 .62431 L F
.64258 .62721 m .6515 .65146 L .65311 .63797 L F
.64258 .62721 m .64722 .65913 L .6515 .65146 L F
.64258 .62721 m .64313 .65585 L .64722 .65913 L F
.63498 .51712 m .64591 .55991 L .64613 .54135 L 0 .696 .284 r
F
.64308 .52275 m .65119 .59242 L .64624 .56063 L 0 .961 .122 r
F
.64308 .52275 m .65548 .6013 L .65119 .59242 L F
.64308 .52275 m .6562 .58121 L .65548 .6013 L F
.64308 .52275 m .65296 .54313 L .6562 .58121 L F
.63498 .51712 m .64247 .56904 L .64591 .55991 L 0 .696 .284 r
F
.64119 .56195 m .63967 .57279 L .64169 .58892 L 0 .497 .306 r
F
.6343 .57232 m .64512 .58649 L .64247 .56904 L 0 .851 .297 r
F
.6343 .57232 m .64429 .60334 L .64512 .58649 L F
.637 .58867 m .63638 .61354 L .64037 .62263 L 0 .643 .322 r
F
.637 .58867 m .63494 .59899 L .63638 .61354 L F
.6343 .57232 m .64049 .61313 L .64429 .60334 L 0 .851 .297 r
F
.64512 .58649 m .64429 .60334 L .64686 .61957 L 0 .816 .312 r
F
.64121 .61181 m .64624 .56063 L .65119 .59242 L 0 .819 .187 r
F
.63498 .51712 m .6381 .5626 L .64247 .56904 L 0 .696 .284 r
F
.6343 .57232 m .64247 .56904 L .6381 .5626 L 0 .851 .297 r
F
.64121 .61181 m .64199 .56879 L .64624 .56063 L 0 .819 .187 r
F
.63887 .50195 m .65054 .56413 L .6462 .5686 L 0 .838 .18 r
F
.63887 .50195 m .65169 .53568 L .65054 .56413 L F
.66202 .62297 m .65822 .65176 L .66448 .64689 L 0 1 .37 r
F
.66202 .62297 m .65528 .64707 L .65822 .65176 L F
.65731 .63707 m .65481 .64452 L .6558 .65589 L 0 .583 .344 r
F
.6559 .66325 m .66716 .66581 L .66331 .6598 L 0 1 .389 r
F
.65731 .63707 m .6558 .65589 L .65963 .66361 L 0 .583 .344 r
F
.66202 .62297 m .66448 .64689 L .66988 .63569 L 0 1 .37 r
F
.66988 .63569 m .66448 .64689 L .66331 .6598 L 0 1 .379 r
F
.65731 .63707 m .66626 .6468 L .66221 .63804 L 0 .583 .344 r
F
.66988 .63569 m .66331 .6598 L .66716 .66581 L 0 1 .379 r
F
.65731 .63707 m .66726 .6582 L .66626 .6468 L 0 .583 .344 r
F
.65731 .63707 m .66454 .66461 L .66726 .6582 L F
.65731 .63707 m .65963 .66361 L .66454 .66461 L F
.65312 .63798 m .66149 .63619 L .65739 .63143 L 0 .951 .341 r
F
.65312 .63798 m .66323 .64894 L .66149 .63619 L F
.65312 .63798 m .66145 .66118 L .66323 .64894 L F
.6559 .66325 m .65875 .68797 L .66521 .67789 L 0 1 .389 r
F
.6559 .66325 m .66521 .67789 L .66716 .66581 L F
.65062 .65578 m .65963 .66361 L .6558 .65589 L 0 .726 .357 r
F
.65062 .65578 m .66001 .6745 L .65963 .66361 L F
.65312 .63798 m .65717 .66774 L .66145 .66118 L 0 .951 .341 r
F
.65062 .65578 m .65668 .68126 L .66001 .6745 L 0 .726 .357 r
F
.65312 .63798 m .65324 .66423 L .65717 .66774 L 0 .951 .341 r
F
.65312 .63798 m .6515 .65147 L .65324 .66423 L F
.64121 .61181 m .65119 .59242 L .65418 .64252 L 0 .819 .187 r
F
.63145 .61394 m .64123 .63584 L .64037 .62263 L 0 .763 .334 r
F
.63145 .61394 m .63839 .64433 L .64123 .63584 L F
.63373 .65676 m .63036 .66484 L .63031 .67587 L 0 .85 .356 r
F
.63373 .65676 m .64253 .66351 L .63895 .65619 L F
.63373 .65676 m .63031 .67587 L .63363 .68251 L F
.63145 .61394 m .64037 .62263 L .63638 .61354 L 0 .763 .334 r
F
.63212 .61866 m .64258 .62721 L .64049 .61313 L 0 .992 .31 r
F
.64123 .63584 m .63839 .64434 L .63895 .65619 L 0 .74 .346 r
F
.64123 .63584 m .63895 .65619 L .64253 .66351 L F
.63212 .61866 m .64114 .64216 L .64258 .62721 L 0 .992 .31 r
F
.63212 .61866 m .637 .65158 L .64114 .64216 L F
.63212 .61866 m .63293 .64918 L .637 .65158 L F
.62849 .65784 m .637 .65158 L .63293 .64918 L 0 1 .324 r
F
.62849 .65784 m .63854 .66326 L .637 .65158 L F
.63854 .66326 m .64722 .65913 L .64313 .65585 L 0 1 .338 r
F
.65062 .65578 m .64753 .66334 L .64791 .6742 L 0 .726 .357 r
F
.65062 .65578 m .64791 .6742 L .65149 .68113 L F
.63854 .66326 m .64862 .6708 L .64722 .65913 L 0 1 .338 r
F
.64249 .67455 m .65149 .68113 L .64791 .6742 L 0 .842 .366 r
F
.64249 .67455 m .65124 .69145 L .65149 .68113 L F
.64249 .67455 m .64733 .69826 L .65124 .69145 L F
.63854 .66326 m .64639 .6831 L .64862 .6708 L 0 1 .338 r
F
.63854 .66326 m .6418 .69053 L .64639 .6831 L F
.62849 .65784 m .63651 .67644 L .63854 .66326 L 0 1 .324 r
F
.62849 .65784 m .63207 .68513 L .63651 .67644 L F
.62849 .65784 m .62819 .68352 L .63207 .68513 L F
.62783 .71112 m .63701 .62061 L .63968 .68204 L 0 .625 .212 r
F
.64258 .62721 m .64114 .64216 L .64313 .65585 L 0 .964 .325 r
F
.64862 .6708 m .64752 .69435 L .65126 .69706 L 0 1 .353 r
F
.64862 .6708 m .6464 .6831 L .64752 .69435 L F
.64121 .61181 m .64882 .68628 L .64411 .66237 L 0 .819 .187 r
F
.65062 .65578 m .65149 .68113 L .65668 .68126 L 0 .726 .357 r
F
.64862 .6708 m .65717 .66774 L .65324 .66423 L 0 1 .353 r
F
.66001 .6745 m .65668 .68126 L .65687 .69122 L 0 .721 .369 r
F
.64862 .6708 m .65831 .67898 L .65717 .66774 L 0 1 .353 r
F
.64862 .6708 m .65588 .69047 L .65831 .67898 L F
.66521 .67789 m .65879 .70323 L .66598 .69923 L 0 1 .399 r
F
.66521 .67789 m .656 .69883 L .65879 .70323 L F
.66521 .67789 m .65875 .68797 L .656 .69883 L F
.65124 .69145 m .66045 .69774 L .65687 .69122 L 0 .841 .377 r
F
.65124 .69145 m .66 .70738 L .66045 .69774 L F
.65124 .69145 m .65581 .7137 L .66 .70738 L F
.64862 .6708 m .65126 .69706 L .65588 .69047 L 0 1 .353 r
F
.64121 .61181 m .65315 .67765 L .64882 .68628 L 0 .819 .187 r
F
.64121 .61181 m .65418 .64252 L .65315 .67765 L F
.64261 .70064 m .65126 .69706 L .64752 .69435 L 0 1 .366 r
F
.64261 .70064 m .64382 .72389 L .64873 .71759 L F
.64261 .70064 m .6403 .72171 L .64382 .72389 L F
.64261 .70064 m .63979 .71174 L .6403 .72171 L F
.63841 .73286 m .64411 .66237 L .64882 .68628 L 0 .659 .2 r
F
.63841 .73286 m .63968 .68204 L .64411 .66237 L F
.63767 .69662 m .64161 .63743 L .64904 .63898 L 0 .556 .212 r
F
.64161 .63743 m .6462 .5686 L .64899 .63777 L F
.64161 .63743 m .64899 .63777 L .64904 .63898 L F
.64058 .73127 m .64882 .68628 L .65094 .72363 L 0 .659 .2 r
F
.64 .72734 m .64882 .68628 L .64058 .73127 L F
.63872 .73149 m .64882 .68628 L .63889 .73251 L F
.63767 .69662 m .64904 .63898 L .6482 .7103 L 0 .556 .212 r
F
.63767 .69662 m .6482 .7103 L .6481 .71156 L F
.6625 .61941 m .6606 .62631 L .66221 .63804 L 0 .397 .324 r
F
.6625 .61941 m .66221 .63804 L .66626 .6468 L F
.66988 .63569 m .66716 .66581 L .6744 .66239 L 0 1 .379 r
F
.6625 .61941 m .66626 .6468 L .67085 .64922 L 0 .397 .324 r
F
.65603 .60251 m .66149 .63619 L .6654 .63028 L 0 .799 .329 r
F
.65603 .60251 m .65739 .63143 L .66149 .63619 L F
.65603 .60251 m .65506 .61699 L .65739 .63143 L F
.66323 .64894 m .66145 .66118 L .66307 .67308 L 0 .95 .356 r
F
.65723 .62002 m .66302 .65407 L .65839 .63255 L 0 .891 .132 r
F
.65548 .60131 m .6576 .61614 L .65723 .62002 L F
.6576 .61614 m .66302 .65407 L .65723 .62002 L F
.6625 .61941 m .67085 .64922 L .67294 .64367 L 0 .397 .324 r
F
.67294 .64367 m .67085 .64922 L .67232 .65936 L 0 .368 .332 r
F
.66323 .64894 m .67174 .64788 L .66763 .64323 L 0 .95 .356 r
F
.67294 .64367 m .67232 .65936 L .67637 .66734 L 0 .368 .332 r
F
.66323 .64894 m .67336 .65977 L .67174 .64788 L 0 .95 .356 r
F
.66521 .67789 m .67278 .68951 L .67553 .67865 L 0 1 .399 r
F
.66521 .67789 m .67553 .67865 L .6724 .67389 L F
.66726 .6582 m .66538 .67478 L .66921 .68194 L 0 .57 .356 r
F
.66726 .6582 m .66454 .66461 L .66538 .67478 L F
.66726 .6582 m .66921 .68194 L .67428 .68313 L F
.66726 .6582 m .67637 .66734 L .67232 .65936 L F
.66726 .6582 m .67721 .67754 L .67637 .66734 L F
.66726 .6582 m .67428 .68313 L .67721 .67754 L F
.66323 .64894 m .67142 .67099 L .67336 .65977 L 0 .95 .356 r
F
.66323 .64894 m .66701 .67669 L .67142 .67099 L F
.66521 .67789 m .66598 .69923 L .67278 .68951 L 0 1 .399 r
F
.66001 .6745 m .66921 .68194 L .66538 .67478 L 0 .721 .369 r
F
.66323 .64894 m .66307 .67308 L .66701 .67669 L 0 .95 .356 r
F
.6576 .61614 m .66709 .65519 L .66302 .65407 L 0 .891 .132 r
F
.65548 .60131 m .65794 .6127 L .6576 .61614 L F
.65794 .6127 m .66709 .65519 L .6576 .61614 L F
.65603 .60251 m .66651 .61765 L .66417 .60322 L 0 .799 .329 r
F
.6625 .61941 m .67132 .6319 L .66709 .62179 L 0 .397 .324 r
F
.6625 .61941 m .67294 .64367 L .67132 .6319 L F
.65603 .60251 m .6654 .63028 L .66651 .61765 L 0 .799 .329 r
F
.65603 .60251 m .66417 .60322 L .65993 .59661 L F
.66651 .61765 m .66763 .64323 L .67174 .64788 L 0 .797 .347 r
F
.66651 .61765 m .6654 .63028 L .66763 .64323 L F
.65548 .60131 m .66489 .60402 L .66785 .63521 L 0 .891 .132 r
F
.65548 .60131 m .66785 .63521 L .66709 .65519 L F
.65737 .56578 m .66417 .60322 L .66769 .59908 L 0 .613 .317 r
F
.65737 .56578 m .65993 .59661 L .66417 .60322 L F
.65702 .56105 m .66489 .60402 L .66021 .5824 L 0 .734 .067 r
F
.65702 .56105 m .66867 .61337 L .66489 .60402 L F
.65702 .56105 m .66901 .60411 L .66867 .61337 L F
.65737 .56578 m .65702 .58056 L .65993 .59661 L 0 .613 .317 r
F
.65548 .60131 m .66021 .5824 L .66489 .60402 L 0 .891 .132 r
F
.65623 .63744 m .66292 .60203 L .66694 .60422 L 0 .323 .148 r
F
.65623 .63744 m .65834 .61618 L .66292 .60203 L F
.65315 .67766 m .65839 .63255 L .66302 .65407 L 0 .771 .179 r
F
.65315 .67766 m .65418 .64253 L .65839 .63255 L F
.65623 .63744 m .66694 .60422 L .66811 .61397 L 0 .323 .148 r
F
.65437 .65443 m .65834 .61618 L .65623 .63744 L 0 .433 .202 r
F
.65278 .66898 m .65412 .65625 L .65437 .65443 L F
.65412 .65625 m .65834 .61618 L .65437 .65443 L F
.65291 .66739 m .65479 .6496 L .65319 .6651 L F
.65479 .6496 m .65834 .61618 L .65487 .6491 L F
.65479 .6496 m .65487 .6491 L .65319 .6651 L F
.65623 .63744 m .66561 .62485 L .66257 .63432 L 0 .323 .148 r
F
.67294 .64367 m .67637 .66734 L .6811 .66994 L 0 .368 .332 r
F
.66651 .61765 m .67174 .64788 L .67575 .64296 L 0 .797 .347 r
F
.66243 .46816 m .66481 .51031 L .66957 .50531 L 0 .741 .316 r
F
.66243 .46816 m .66106 .50243 L .66481 .51031 L F
.66243 .46816 m .66005 .48436 L .66106 .50243 L F
.65599 .50828 m .66481 .51031 L .66106 .50243 L 0 .875 .324 r
F
.65599 .50828 m .66517 .527 L .66481 .51031 L F
.65599 .50828 m .6619 .5414 L .66517 .527 L F
.65573 .50773 m .65647 .51557 L .66034 .5309 L 0 .016 .154 r
F
.66517 .527 m .66208 .557 L .66558 .56341 L 0 .865 .334 r
F
.66517 .527 m .6619 .5414 L .66208 .557 L F
.6572 .53142 m .66477 .54355 L .66034 .5309 L 0 .34 .294 r
F
.66517 .527 m .66558 .56341 L .67085 .55826 L 0 .865 .334 r
F
.6572 .53142 m .66823 .56051 L .66477 .54355 L 0 .34 .294 r
F
.6572 .53142 m .66838 .57042 L .66823 .56051 L F
.6572 .53142 m .66523 .57088 L .66838 .57042 L F
.6572 .53142 m .66088 .56163 L .66523 .57088 L F
.6572 .53142 m .65745 .54472 L .66088 .56163 L F
.65573 .50773 m .66301 .52965 L .65853 .51373 L 0 .016 .154 r
F
.65573 .50773 m .66691 .54509 L .66301 .52965 L F
.65573 .50773 m .6676 .54966 L .66691 .54509 L F
.65573 .50773 m .66477 .54355 L .6676 .54966 L F
.65573 .50773 m .66034 .5309 L .66477 .54355 L F
.65765 .54991 m .65761 .55123 L .66095 .56437 L 0 0 .081 r
F
.65765 .54991 m .66095 .56437 L .66548 .58066 L F
.65334 .51075 m .65853 .51373 L .66301 .52965 L 0 .744 .076 r
F
.65765 .54991 m .66915 .59592 L .66577 .58264 L 0 0 .081 r
F
.65765 .54991 m .66548 .58066 L .669 .59421 L F
.65765 .54991 m .669 .59421 L .66915 .59592 L F
.65765 .54991 m .66577 .58264 L .66114 .56332 L F
.65334 .51075 m .66027 .5426 L .65584 .52656 L 0 .744 .076 r
F
.65334 .51075 m .66444 .55077 L .66027 .5426 L F
.65334 .51075 m .66556 .54555 L .66444 .55077 L F
.65334 .51075 m .66301 .52965 L .66556 .54555 L F
.65702 .56105 m .6574 .5541 L .66114 .56332 L 0 .734 .067 r
F
.65702 .56105 m .66114 .56332 L .66577 .58264 L F
.65054 .56414 m .65584 .52656 L .66027 .5426 L 0 .724 .173 r
F
.65702 .56105 m .66577 .58264 L .66901 .60411 L 0 .734 .067 r
F
.65054 .56414 m .66027 .5426 L .6625 .56829 L 0 .724 .173 r
F
.65548 .60131 m .6562 .58122 L .66021 .5824 L 0 .891 .132 r
F
.65054 .56414 m .6625 .56829 L .66102 .58657 L 0 .724 .173 r
F
.65054 .56414 m .65683 .59598 L .65273 .59011 L F
.65054 .56414 m .66102 .58657 L .65683 .59598 L F
.64818 .71116 m .65273 .59011 L .65683 .59598 L 0 .433 .202 r
F
.65532 .59904 m .66002 .48568 L .66424 .4984 L 0 .52 .203 r
F
.65334 .51075 m .65439 .50565 L .65853 .51373 L 0 .744 .076 r
F
.65532 .59904 m .65621 .52812 L .66002 .48568 L 0 .52 .203 r
F
.66517 .527 m .67418 .52938 L .67043 .52185 L 0 .865 .334 r
F
.66517 .527 m .67436 .54498 L .67418 .52938 L F
.66517 .527 m .67085 .55826 L .67436 .54498 L F
.67436 .54498 m .67084 .57285 L .67435 .57903 L 0 .86 .344 r
F
.67436 .54498 m .67085 .55826 L .67084 .57285 L F
.66691 .54509 m .6676 .54966 L .67141 .56048 L 0 0 .146 r
F
.67436 .54498 m .67435 .57903 L .6798 .57441 L 0 .86 .344 r
F
.66691 .54509 m .67141 .56048 L .67581 .57039 L 0 0 .146 r
F
.66691 .54509 m .6741 .56116 L .66969 .54999 L F
.66691 .54509 m .67793 .57205 L .6741 .56116 L F
.66691 .54509 m .67862 .57536 L .67793 .57205 L F
.66691 .54509 m .67581 .57039 L .67862 .57536 L F
.66444 .55077 m .66969 .54999 L .6741 .56116 L 0 .65 .072 r
F
.66444 .55077 m .66556 .54555 L .66969 .54999 L F
.66823 .56051 m .67581 .57039 L .67141 .56048 L 0 .312 .309 r
F
.66823 .56051 m .67919 .58378 L .67581 .57039 L F
.66444 .55077 m .6741 .56116 L .67651 .5723 L 0 .65 .072 r
F
.66823 .56051 m .66838 .57042 L .67174 .58376 L 0 .312 .309 r
F
.67364 .59281 m .68312 .59401 L .67961 .5881 L 0 .982 .362 r
F
.66823 .56051 m .67609 .59167 L .67928 .59169 L 0 .312 .309 r
F
.66823 .56051 m .67174 .58376 L .67609 .59167 L F
.66444 .55077 m .67113 .57151 L .66682 .56189 L 0 .65 .072 r
F
.66823 .56051 m .67928 .59169 L .67919 .58378 L 0 .312 .309 r
F
.66444 .55077 m .67529 .57598 L .67113 .57151 L 0 .65 .072 r
F
.66444 .55077 m .67651 .5723 L .67529 .57598 L F
.65532 .59904 m .66424 .4984 L .66633 .54484 L 0 .52 .203 r
F
.64879 .70301 m .65683 .59598 L .65709 .59957 L 0 .433 .202 r
F
.66102 .58657 m .66682 .56189 L .67113 .57151 L 0 .631 .145 r
F
.66102 .58657 m .6625 .56829 L .66682 .56189 L F
.66815 .58694 m .67609 .59167 L .67174 .58376 L 0 .603 .337 r
F
.66102 .58657 m .67113 .57151 L .67306 .58683 L 0 .631 .145 r
F
.67364 .59281 m .68221 .6071 L .68312 .59401 L 0 .982 .362 r
F
.67364 .59281 m .67748 .61864 L .68221 .6071 L F
.66815 .58694 m .67892 .60535 L .67609 .59167 L 0 .603 .337 r
F
.66815 .58694 m .67836 .61565 L .67892 .60535 L F
.66815 .58694 m .67476 .61881 L .67836 .61565 L F
.66915 .59592 m .669 .59421 L .67226 .60312 L 0 .431 0 r
F
.66102 .58657 m .67306 .58683 L .6713 .59768 L 0 .631 .145 r
F
.66102 .58657 m .66694 .60422 L .66292 .60203 L F
.66836 .59516 m .67677 .61674 L .67226 .60312 L 0 0 .154 r
F
.68221 .6071 m .67748 .61864 L .67712 .63226 L 0 .987 .372 r
F
.68221 .6071 m .67712 .63226 L .68136 .63889 L F
.66836 .59516 m .67954 .62781 L .67677 .61674 L 0 0 .154 r
F
.66836 .59516 m .67872 .62889 L .67954 .62781 L F
.66836 .59516 m .67481 .62086 L .67872 .62889 L F
.66915 .59592 m .67226 .60312 L .67677 .61674 L 0 .431 0 r
F
.66915 .59592 m .67727 .62407 L .67269 .60869 L F
.68221 .6071 m .68136 .63889 L .68836 .63576 L 0 .987 .372 r
F
.677 .63177 m .68535 .63289 L .68111 .62745 L 0 .807 .365 r
F
.69344 .62494 m .68836 .63576 L .68714 .64775 L 0 .991 .383 r
F
.677 .63177 m .68749 .64458 L .68535 .63289 L 0 .807 .365 r
F
.677 .63177 m .68611 .65472 L .68749 .64458 L F
.67954 .62781 m .67872 .62889 L .68139 .63731 L 0 0 .143 r
F
.66915 .59592 m .68056 .63305 L .67727 .62407 L 0 .431 0 r
F
.67954 .62781 m .68139 .63731 L .68576 .64747 L 0 0 .143 r
F
.68858 .66442 m .68247 .67459 L .68023 .68569 L 0 1 .399 r
F
.69344 .62494 m .68714 .64775 L .69059 .65292 L 0 .991 .383 r
F
.68749 .64458 m .68611 .65472 L .68816 .66537 L 0 .828 .383 r
F
.68858 .66442 m .68336 .69031 L .69052 .68641 L 0 1 .399 r
F
.68858 .66442 m .68023 .68569 L .68336 .69031 L F
.68858 .66442 m .69052 .68641 L .69696 .67658 L F
.68858 .66442 m .6992 .66548 L .69576 .66052 L F
.68858 .66442 m .69696 .67658 L .6992 .66548 L F
.68749 .64458 m .68816 .66537 L .69226 .66943 L 0 .828 .383 r
F
.69344 .62494 m .69059 .65292 L .6972 .64904 L 0 .991 .383 r
F
.68749 .64458 m .69226 .66943 L .69647 .66546 L 0 .828 .383 r
F
.67954 .62781 m .68576 .64747 L .68975 .6552 L 0 0 .143 r
F
.68188 .63232 m .68801 .64686 L .68352 .63549 L F
.67954 .62781 m .68298 .63555 L .68188 .63232 L F
.68298 .63555 m .68801 .64686 L .68188 .63232 L F
.66915 .59592 m .67331 .6073 L .68033 .62959 L 0 .431 0 r
F
.67331 .6073 m .67677 .61674 L .67772 .62018 L F
.67331 .6073 m .67772 .62018 L .68033 .62959 L F
.67954 .62781 m .68605 .64388 L .68353 .63677 L 0 0 .143 r
F
.67954 .62781 m .68975 .6552 L .69013 .65525 L F
.68605 .64388 m .69013 .65525 L .69068 .65532 L F
.67954 .62781 m .69013 .65525 L .68605 .64388 L F
.67089 .6016 m .68033 .62959 L .68056 .63305 L 0 .431 0 r
F
.67001 .59873 m .67205 .60484 L .67089 .6016 L F
.67205 .60484 m .68033 .62959 L .67089 .6016 L F
.66915 .59592 m .67109 .60176 L .67001 .59873 L F
.67109 .60176 m .68033 .62959 L .67001 .59873 L F
.68353 .63677 m .69068 .65532 L .68801 .64686 L 0 0 .143 r
F
.68605 .64388 m .69068 .65532 L .68353 .63677 L F
.66102 .58657 m .6713 .59768 L .66694 .60422 L 0 .631 .145 r
F
.65532 .59904 m .66633 .54484 L .66486 .59487 L 0 .52 .203 r
F
.66867 .61337 m .67269 .60869 L .67727 .62407 L 0 .769 .082 r
F
.66867 .61337 m .66901 .60411 L .67269 .60869 L F
.67794 .6369 m .67766 .64623 L .68189 .65522 L 0 .211 .267 r
F
.67794 .6369 m .67789 .65464 L .682 .65903 L 0 .807 .365 r
F
.677 .63177 m .67708 .63379 L .67794 .6369 L F
.677 .63177 m .67794 .6369 L .68611 .65472 L F
.67794 .6369 m .68396 .65697 L .68611 .65472 L F
.67703 .63265 m .67794 .6369 L .68626 .65993 L 0 .211 .267 r
F
.67794 .6369 m .68189 .65522 L .6835 .65695 L F
.67794 .6369 m .6835 .65695 L .68374 .65721 L F
.67794 .6369 m .682 .65903 L .68374 .65721 L 0 .807 .365 r
F
.67794 .6369 m .68374 .65721 L .68396 .65697 L F
.67794 .6369 m .68374 .65721 L .68626 .65993 L 0 .211 .267 r
F
.67708 .63379 m .67709 .63394 L .67794 .6369 L 0 .807 .365 r
F
.67709 .63394 m .67709 .63407 L .67794 .6369 L 0 .211 .267 r
F
.67709 .63407 m .67766 .64623 L .67794 .6369 L F
.67709 .63394 m .67789 .65464 L .67794 .6369 L 0 .807 .365 r
F
.67703 .63265 m .67709 .63394 L .67794 .6369 L 0 .211 .267 r
F
.67703 .63265 m .68576 .64747 L .68139 .63731 L F
.67703 .63265 m .68786 .65718 L .68576 .64747 L F
.67703 .63265 m .68626 .65993 L .68786 .65718 L F
.66867 .61337 m .67727 .62407 L .6805 .64328 L 0 .769 .082 r
F
.66867 .61337 m .67646 .64889 L .67186 .63255 L F
.66867 .61337 m .68018 .6535 L .67646 .64889 L F
.66867 .61337 m .6805 .64328 L .68018 .6535 L F
.66561 .62485 m .67299 .60714 L .67702 .60885 L 0 .261 .099 r
F
.66561 .62485 m .66811 .61397 L .67299 .60714 L F
.65864 .63763 m .66257 .63432 L .66143 .63786 L 0 .323 .148 r
F
.65623 .63744 m .66257 .63432 L .65864 .63763 L F
.66047 .639 m .66143 .63786 L .661 .6392 L F
.65623 .63744 m .66143 .63786 L .66047 .639 L F
.65208 .67494 m .65277 .66845 L .65216 .6744 L 0 .433 .202 r
F
.65277 .66845 m .65834 .61618 L .65291 .66739 L F
.65277 .66845 m .65291 .66739 L .65216 .6744 L F
.65033 .69129 m .6543 .65406 L .65023 .69237 L F
.6543 .65406 m .65834 .61618 L .65432 .65393 L F
.6543 .65406 m .65432 .65393 L .65023 .69237 L F
.65399 .65679 m .65834 .61618 L .65405 .6564 L F
.65808 .61855 m .65808 .61853 L .65834 .61618 L F
.64818 .71116 m .65808 .61853 L .65808 .61855 L F
.64818 .71116 m .64879 .70301 L .65808 .61853 L F
.64879 .70301 m .65709 .59957 L .65834 .61618 L F
.65623 .63744 m .66811 .61397 L .66561 .62485 L 0 .323 .148 r
F
.65532 .59904 m .66486 .59487 L .661 .63919 L 0 .52 .203 r
F
.66028 .6035 m .66092 .63518 L .66042 .60397 L 0 .571 .256 r
F
.66092 .63518 m .661 .63919 L .66094 .63517 L F
.66092 .63518 m .66094 .63517 L .66042 .60397 L F
.66561 .62485 m .67702 .60885 L .67798 .61476 L 0 .261 .099 r
F
.66561 .62485 m .67798 .61476 L .67522 .62096 L F
.66561 .62485 m .67032 .62786 L .66655 .63084 L F
.66561 .62485 m .67522 .62096 L .67032 .62786 L F
.66486 .59487 m .67031 .62785 L .66655 .63083 L 0 .496 .192 r
F
.65604 .56549 m .66655 .63083 L .66906 .62885 L 0 .548 .271 r
F
.66749 .62978 m .66658 .63081 L .669 .6289 L 0 1 .217 r
F
.66658 .63081 m .66655 .63084 L .669 .6289 L F
.669 .6289 m .66655 .63084 L .66904 .62887 L F
.66048 .63572 m .66075 .63738 L .66072 .63742 L 0 .52 .203 r
F
.65532 .59904 m .66051 .6357 L .66048 .63572 L F
.66051 .6357 m .66075 .63738 L .66048 .63572 L F
.67023 .62747 m .66906 .62885 L .67031 .62786 L 0 .548 .271 r
F
.66953 .62834 m .66904 .62887 L .67003 .62803 L 0 1 .217 r
F
.65604 .56549 m .66906 .62885 L .67023 .62747 L 0 .548 .271 r
F
.65623 .63744 m .661 .6392 L .65736 .64738 L 0 .323 .148 r
F
.65699 .63856 m .66098 .63924 L .65728 .64543 L 0 .52 .203 r
F
.65532 .59904 m .66048 .63572 L .65699 .63856 L F
.66048 .63572 m .66098 .63924 L .65699 .63856 L F
.65808 .6227 m .66037 .63563 L .66028 .6035 L 0 .571 .256 r
F
.66072 .63742 m .661 .63919 L .66098 .63924 L 0 .52 .203 r
F
.66075 .63738 m .661 .63919 L .66072 .63742 L F
.66037 .63563 m .661 .63919 L .66092 .63518 L 0 .571 .256 r
F
.66037 .63563 m .66092 .63518 L .66028 .6035 L F
.65728 .64543 m .66098 .63924 L .65736 .64737 L 0 .52 .203 r
F
.65093 .63786 m .64911 .63778 L .65273 .59011 L 0 .433 .202 r
F
.64701 .65843 m .64789 .56826 L .64953 .58192 L 0 .53 .215 r
F
.64789 .56826 m .64918 .4373 L .64953 .58192 L F
.64953 .58192 m .64918 .4373 L .65356 .45945 L F
.64701 .65843 m .64637 .52018 L .64918 .4373 L F
.65054 .56414 m .65169 .53569 L .65584 .52656 L 0 .724 .173 r
F
.64701 .65843 m .65356 .45945 L .65621 .52812 L 0 .53 .215 r
F
.64818 .71116 m .64904 .63876 L .64911 .63778 L 0 .433 .202 r
F
.64818 .71116 m .64911 .63778 L .65093 .63786 L F
.64701 .65843 m .65621 .52812 L .65532 .59904 L 0 .53 .215 r
F
.65013 .6929 m .65399 .65679 L .65014 .69306 L 0 .433 .202 r
F
.65399 .65679 m .65405 .6564 L .65014 .69306 L F
.65291 .66739 m .65319 .6651 L .65278 .66898 L F
.65332 .66408 m .65623 .63744 L .6547 .65793 L F
.65536 .64764 m .65519 .64904 L .65701 .64766 L 0 1 .332 r
F
.65706 .64742 m .65701 .64766 L .65736 .64738 L F
.65536 .64764 m .65701 .64766 L .65706 .64742 L F
.64818 .71116 m .65332 .66408 L .65371 .67117 L 0 .433 .202 r
F
.65332 .66408 m .6547 .65793 L .65371 .67117 L F
.66001 .6745 m .65687 .69122 L .66045 .69774 L 0 .721 .369 r
F
.66001 .6745 m .66045 .69774 L .66582 .69804 L F
.66001 .6745 m .6694 .69191 L .66921 .68194 L F
.66001 .6745 m .66582 .69804 L .6694 .69191 L F
.65831 .67898 m .66701 .67669 L .66307 .67308 L 0 1 .367 r
F
.65831 .67898 m .668 .68748 L .66701 .67669 L F
.65831 .67898 m .66538 .69825 L .668 .68748 L F
.65831 .67898 m .66061 .70416 L .66538 .69825 L F
.65831 .67898 m .65687 .70126 L .66061 .70416 L F
.65831 .67898 m .65588 .69047 L .65687 .70126 L F
.65315 .67766 m .66302 .65407 L .66566 .69461 L 0 .771 .179 r
F
.66867 .73437 m .65862 .75635 L .66681 .75305 L 0 1 .429 r
F
.66867 .73437 m .65621 .75235 L .65862 .75635 L F
.66867 .73437 m .66051 .74294 L .65621 .75235 L F
.66199 .72392 m .66051 .74294 L .66867 .73437 L 0 1 .424 r
F
.65714 .7372 m .66672 .7421 L .66342 .73672 L 0 .956 .403 r
F
.66 .70738 m .65515 .72271 L .65846 .72842 L 0 .846 .388 r
F
.66 .70738 m .65581 .7137 L .65515 .72271 L F
.66199 .72392 m .66867 .73437 L .6727 .72476 L 0 1 .424 r
F
.66199 .72392 m .6727 .72476 L .66992 .72052 L F
.66 .70738 m .65846 .72842 L .66428 .72825 L 0 .846 .388 r
F
.65714 .7372 m .65053 .75157 L .65353 .75671 L 0 .956 .403 r
F
.65714 .7372 m .65207 .74321 L .65053 .75157 L F
.65714 .7372 m .65353 .75671 L .6598 .75624 L F
.65714 .7372 m .6598 .75624 L .66517 .75047 L F
.65714 .7372 m .66517 .75047 L .66672 .7421 L F
.65231 .73856 m .66089 .74468 L .66138 .73601 L 0 1 .405 r
F
.65231 .73856 m .66138 .73601 L .65786 .73347 L F
.66096 .7139 m .65786 .73347 L .66138 .73601 L 0 1 .393 r
F
.66096 .7139 m .65769 .724 L .65786 .73347 L F
.65178 .70702 m .65769 .724 L .66096 .7139 L 0 1 .379 r
F
.65178 .70702 m .6526 .72976 L .65769 .724 L F
.67278 .68951 m .66575 .71409 L .67319 .71027 L 0 1 .407 r
F
.67278 .68951 m .66297 .70977 L .66575 .71409 L F
.67278 .68951 m .66598 .69923 L .66297 .70977 L F
.66 .70738 m .66941 .71329 L .66583 .7072 L 0 .846 .388 r
F
.66 .70738 m .66875 .72232 L .66941 .71329 L F
.66 .70738 m .66428 .72825 L .66875 .72232 L F
.65178 .70702 m .66096 .7139 L .66061 .70416 L 0 1 .379 r
F
.65178 .70702 m .66061 .70416 L .65687 .70126 L F
.65315 .67766 m .66022 .73784 L .65572 .71866 L 0 .771 .179 r
F
.66875 .72232 m .66342 .73672 L .66672 .7421 L 0 .857 .399 r
F
.66875 .72232 m .66428 .72825 L .66342 .73672 L F
.66096 .7139 m .66138 .73601 L .66664 .73066 L 0 1 .393 r
F
.66867 .73437 m .66681 .75305 L .67533 .74465 L 0 1 .429 r
F
.66867 .73437 m .67533 .74465 L .67964 .73523 L F
.66867 .73437 m .67964 .73523 L .67687 .73107 L F
.66875 .72232 m .66672 .7421 L .67274 .74192 L 0 .857 .399 r
F
.66875 .72232 m .67274 .74192 L .67748 .73631 L F
.68789 .71189 m .6804 .72107 L .67687 .73107 L 0 1 .421 r
F
.68034 .70085 m .6727 .72476 L .6804 .72107 L 0 1 .414 r
F
.68034 .70085 m .66992 .72052 L .6727 .72476 L F
.66875 .72232 m .67836 .72782 L .67478 .72213 L 0 .857 .399 r
F
.68789 .71189 m .67687 .73107 L .67964 .73523 L 0 1 .421 r
F
.66875 .72232 m .67748 .73631 L .67836 .72782 L 0 .857 .399 r
F
.66096 .7139 m .66664 .73066 L .67014 .72099 L 0 1 .393 r
F
.68034 .70085 m .67319 .71027 L .66992 .72052 L 0 1 .414 r
F
.6694 .69191 m .66583 .7072 L .66941 .71329 L 0 .724 .381 r
F
.67278 .68951 m .67319 .71027 L .68034 .70085 L 0 1 .407 r
F
.6694 .69191 m .66941 .71329 L .67496 .71366 L 0 .724 .381 r
F
.66096 .7139 m .67014 .72099 L .66996 .71152 L 0 1 .393 r
F
.66096 .7139 m .66996 .71152 L .66622 .70855 L F
.65315 .67766 m .6645 .72741 L .66022 .73784 L 0 .771 .179 r
F
.6694 .69191 m .66582 .69804 L .66583 .7072 L 0 .724 .381 r
F
.668 .68748 m .66538 .69825 L .66622 .70855 L 0 1 .382 r
F
.65315 .67766 m .66566 .69461 L .6645 .72741 L 0 .771 .179 r
F
.64855 .70911 m .65371 .67117 L .65252 .68709 L 0 .433 .202 r
F
.64818 .71116 m .65371 .67117 L .64855 .70911 L F
.65824 .6379 m .65736 .64737 L .65906 .64356 L 0 .571 .256 r
F
.64701 .65843 m .65532 .59904 L .65314 .66757 L 0 .53 .215 r
F
.64678 .55898 m .65717 .64575 L .65824 .6379 L 0 .571 .256 r
F
.65717 .64575 m .65736 .64737 L .65824 .6379 L F
.65216 .6744 m .65291 .66739 L .65278 .66898 L 0 .433 .202 r
F
.65185 .67711 m .65208 .67494 L .65216 .6744 L F
.65023 .69237 m .65185 .67711 L .65278 .66898 L F
.65069 .67753 m .65314 .66757 L .65252 .68707 L 0 .53 .215 r
F
.64701 .65843 m .65314 .66757 L .65069 .67753 L F
.66064 .63715 m .65906 .64356 L .661 .63919 L 0 .571 .256 r
F
.64678 .55898 m .65906 .64356 L .66064 .63715 L F
.65772 .63554 m .66116 .63413 L .66521 .63165 L 0 1 .217 r
F
.66549 .63143 m .66521 .63165 L .66622 .63104 L F
.65772 .63554 m .66521 .63165 L .66549 .63143 L F
.66631 .63097 m .66622 .63104 L .66655 .63084 L F
.65772 .63554 m .66622 .63104 L .66631 .63097 L F
.65604 .56549 m .66042 .60397 L .66655 .63083 L 0 .548 .271 r
F
.65772 .63554 m .66847 .62921 L .66953 .62834 L 0 1 .217 r
F
.66847 .62921 m .66904 .62887 L .66953 .62834 L F
.65772 .63554 m .66557 .63136 L .66749 .62978 L F
.66557 .63136 m .66655 .63084 L .66749 .62978 L F
.66 .63212 m .66013 .63303 L .66138 .63213 L 0 1 .516 r
F
.65769 .6321 m .66013 .63303 L .66 .63212 L F
.65769 .6321 m .65781 .63468 L .66013 .63303 L F
.64678 .55898 m .65124 .6127 L .65736 .64737 L 0 .571 .256 r
F
.65261 .63206 m .65732 .63455 L .65769 .6321 L 0 1 .516 r
F
.65231 .73856 m .64842 .74788 L .64794 .75655 L 0 1 .405 r
F
.64657 .74573 m .65094 .72363 L .64902 .74961 L 0 .659 .2 r
F
.64741 .72935 m .65094 .72363 L .64657 .74573 L F
.64372 .73276 m .63981 .75122 L .64306 .7533 L 0 1 .393 r
F
.64372 .73276 m .64009 .74241 L .63981 .75122 L F
.64058 .73127 m .64379 .7289 L .64187 .73832 L 0 .659 .2 r
F
.64379 .7289 m .65094 .72363 L .64374 .73529 L F
.64379 .7289 m .64374 .73529 L .64187 .73832 L F
.64818 .71116 m .65252 .68709 L .65252 .6871 L 0 .433 .202 r
F
.649 .72289 m .65252 .6871 L .64967 .73238 L F
.64818 .71116 m .65252 .6871 L .649 .72289 L F
.64907 .71562 m .65252 .68714 L .64967 .73236 L 0 .53 .215 r
F
.64948 .72972 m .64967 .73237 L .6515 .70332 L 0 .689 .238 r
F
.64701 .65843 m .65252 .68707 L .65252 .68714 L 0 .53 .215 r
F
.65003 .69387 m .65014 .69306 L .64979 .69635 L 0 .433 .202 r
F
.65013 .6929 m .65014 .69306 L .65003 .69387 L F
.64979 .69635 m .65033 .69129 L .65023 .69237 L F
.64818 .71116 m .65013 .6929 L .64979 .69635 L F
.64701 .65843 m .65252 .68714 L .64907 .71562 L 0 .53 .215 r
F
.64948 .72972 m .6515 .70332 L .65252 .68708 L 0 .689 .238 r
F
.6481 .71156 m .6482 .7103 L .64819 .71168 L 0 .556 .212 r
F
.6343 .57232 m .63625 .60928 L .64049 .61313 L 0 .851 .297 r
F
.6343 .57232 m .63361 .59177 L .63625 .60928 L F
.63212 .61866 m .64049 .61313 L .63625 .60928 L 0 .992 .31 r
F
.62898 .51885 m .64121 .61181 L .63701 .62061 L 0 .854 .197 r
F
.63498 .51712 m .63489 .54031 L .6381 .5626 L 0 .696 .284 r
F
.62898 .51885 m .64199 .56879 L .64121 .61181 L 0 .854 .197 r
F
.6337 .45506 m .63347 .47075 L .6367 .49566 L 0 .274 .252 r
F
.63412 .45203 m .63465 .47926 L .63841 .50807 L 0 .51 .269 r
F
.62898 .51885 m .63861 .49928 L .64199 .56879 L 0 .854 .197 r
F
.63767 .69662 m .6416 .54596 L .6462 .5686 L 0 .556 .212 r
F
.63767 .69662 m .63797 .59965 L .6416 .54596 L F
.63787 .56691 m .64948 .72972 L .65252 .68708 L 0 .689 .238 r
F
.64187 .73832 m .64741 .72935 L .64657 .74573 L 0 .659 .2 r
F
.63841 .73286 m .64058 .73127 L .64187 .73832 L F
.64187 .73832 m .64902 .74961 L .64604 .76314 L F
.63767 .69662 m .64819 .71168 L .64538 .75515 L 0 .556 .212 r
F
.62783 .71081 m .63701 .62061 L .62783 .71112 L 0 .625 .212 r
F
.62237 .41293 m .62305 .44998 L .627 .48453 L 0 .616 .26 r
F
.61431 .29222 m .62898 .51883 L .62421 .49575 L 0 .978 .185 r
F
.62487 .57097 m .62421 .49575 L .6283 .62632 L 0 .586 .223 r
F
.62164 .39525 m .6337 .45505 L .63019 .42359 L 0 .389 .258 r
F
.62164 .39525 m .63346 .47074 L .6337 .45505 L F
.62164 .39525 m .62974 .46837 L .63346 .47074 L F
.62164 .39525 m .62505 .4496 L .62974 .46837 L F
.62237 .41293 m .63015 .41774 L .6254 .39921 L 0 .616 .26 r
F
.62237 .41293 m .63412 .45203 L .63015 .41774 L F
.62237 .41293 m .63464 .47926 L .63412 .45203 L F
.62237 .41293 m .63159 .49324 L .63464 .47926 L F
.62237 .41293 m .627 .48453 L .63159 .49324 L F
.61431 .29222 m .62933 .45788 L .62898 .51883 L 0 .978 .185 r
F
.61431 .29222 m .62502 .34285 L .62933 .45788 L F
.62898 .51885 m .63342 .44973 L .63861 .49928 L 0 .854 .197 r
F
.62898 .51885 m .62933 .45791 L .63342 .44973 L F
.62898 .51885 m .63701 .62061 L .63225 .58899 L F
.62658 .64684 m .62885 .41769 L .63414 .48081 L 0 .658 .219 r
F
.62658 .64684 m .62563 .48608 L .62885 .41769 L F
.62779 .71123 m .62824 .63996 L .62825 .63993 L 0 .625 .212 r
F
.62824 .63996 m .62832 .62702 L .62825 .63993 L F
.62825 .63993 m .62832 .62702 L .62833 .62693 L F
.62993 .65264 m .62833 .62693 L .63225 .58899 L F
.62782 .70457 m .62783 .70838 L .62782 .7094 L 0 .586 .223 r
F
.62781 .70826 m .62782 .7094 L .62781 .71212 L F
.62782 .70457 m .62782 .7094 L .62781 .70826 L F
.62779 .71123 m .62833 .62693 L .62993 .65264 L 0 .625 .212 r
F
.63212 .61866 m .63084 .63506 L .63293 .64918 L 0 .992 .31 r
F
.62779 .71123 m .63225 .58899 L .63701 .62061 L 0 .625 .212 r
F
.62658 .64684 m .63414 .48081 L .63797 .59965 L 0 .658 .219 r
F
.62658 .64684 m .63797 .59965 L .63767 .69662 L F
.62716 .5019 m .63771 .66434 L .64332 .68013 L 0 .376 .227 r
F
.6442 .77038 m .64924 .76813 L .64886 .76551 L 0 1 .317 r
F
.63928 .77553 m .64364 .77245 L .6442 .77038 L F
.65358 .76506 m .65931 .77488 L .66464 .76627 L 0 1 .442 r
F
.65132 .7649 m .6523 .78265 L .65857 .777 L 0 1 .416 r
F
.65132 .7649 m .65857 .777 L .66103 .76911 L F
.65006 .76668 m .65291 .78045 L .65796 .77236 L 0 1 .431 r
F
.65006 .76668 m .64691 .78492 L .65291 .78045 L F
.64364 .77245 m .64929 .76846 L .6442 .77038 L 0 1 .317 r
F
.64929 .76846 m .65062 .76752 L .64924 .76813 L F
.64929 .76846 m .64924 .76813 L .6442 .77038 L F
.64768 .7576 m .64768 .75768 L .64768 .75757 L 0 0 .119 r
F
.63771 .66434 m .64164 .70437 L .64332 .68013 L 0 .376 .227 r
F
.64164 .70437 m .64396 .7279 L .64349 .6928 L F
.64164 .70437 m .64349 .6928 L .64332 .68013 L F
.64729 .75228 m .64768 .7576 L .64768 .75757 L 0 0 .119 r
F
.64683 .74619 m .64728 .7523 L .64729 .75228 L F
.64728 .7523 m .64768 .7576 L .64729 .75228 L F
.64682 .74619 m .64768 .7576 L .64683 .74619 L F
.64234 .68665 m .64302 .69573 L .64234 .68662 L F
.64648 .68757 m .64429 .68774 L .64967 .73237 L 0 .689 .238 r
F
.63787 .56691 m .64429 .68774 L .64648 .68757 L F
.63787 .56691 m .64331 .67961 L .64429 .68774 L F
.64276 .68786 m .64967 .73238 L .65252 .68709 L 0 .968 .234 r
F
.64302 .69573 m .64385 .70677 L .64302 .69566 L 0 0 .119 r
F
.64385 .70677 m .64385 .70662 L .64302 .69566 L F
.64302 .69573 m .64302 .69566 L .64234 .68662 L F
.64368 .70371 m .64535 .73275 L .64967 .73238 L 0 .968 .234 r
F
.64384 .70646 m .64682 .74619 L .64683 .74619 L 0 0 .119 r
F
.64234 .68662 m .64385 .70662 L .64384 .70646 L F
.64385 .70662 m .64682 .74619 L .64384 .70646 L F
.65358 .76506 m .66464 .76627 L .66223 .76231 L 0 1 .442 r
F
.65132 .7649 m .66103 .76911 L .65803 .76423 L 0 1 .416 r
F
.67533 .74465 m .66223 .76231 L .66464 .76627 L 0 1 .434 r
F
.67533 .74465 m .66681 .75305 L .66223 .76231 L F
.66517 .75047 m .65803 .76423 L .66103 .76911 L 0 .971 .413 r
F
.65006 .76668 m .65796 .77236 L .65931 .76454 L 0 1 .431 r
F
.66517 .75047 m .6598 .75624 L .65803 .76423 L 0 .971 .413 r
F
.65006 .76668 m .65931 .76454 L .65606 .76221 L 0 1 .431 r
F
.64886 .76551 m .65062 .76752 L .65181 .76242 L 0 1 .317 r
F
.64924 .76813 m .65062 .76752 L .64886 .76551 L F
.64527 .76948 m .65181 .76242 L .64937 .76534 L F
.63928 .77553 m .6442 .77038 L .64527 .76948 L F
.6442 .77038 m .65181 .76242 L .64527 .76948 L F
.65857 .77701 m .65023 .7913 L .65373 .7972 L 0 1 .425 r
F
.65857 .77701 m .6523 .78265 L .65023 .7913 L F
.64491 .79205 m .65205 .79745 L .6543 .79038 L 0 1 .455 r
F
.64491 .79205 m .6543 .79038 L .65135 .78818 L F
.64491 .79205 m .64611 .80467 L .65205 .79745 L F
.64523 .80099 m .65062 .76752 L .64659 .77725 L 0 1 .277 r
F
.65796 .77236 m .65291 .78045 L .65135 .78818 L 0 1 .441 r
F
.64523 .80099 m .65538 .77437 L .65062 .76752 L 0 1 .277 r
F
.64214 .77351 m .64659 .77725 L .65062 .76752 L 0 1 .317 r
F
.63928 .77553 m .64183 .77612 L .64214 .77351 L F
.64183 .77612 m .64659 .77725 L .64214 .77351 L F
.64368 .70371 m .64967 .73238 L .64276 .68786 L 0 .968 .234 r
F
.6479 .74897 m .65151 .70313 L .65168 .69834 L 0 .729 .063 r
F
.6479 .74897 m .65168 .69834 L .64791 .74896 L F
.63787 .56691 m .65252 .68708 L .65124 .6127 L 0 .689 .238 r
F
.62716 .5019 m .64332 .68013 L .63788 .56712 L 0 .376 .227 r
F
.64556 .6719 m .65252 .68709 L .65213 .65137 L 0 .968 .234 r
F
.64806 .66411 m .65213 .65137 L .65033 .64982 L F
.64806 .66411 m .65033 .64982 L .64879 .64848 L F
.64941 .63203 m .65056 .63276 L .65078 .63204 L 0 1 .516 r
F
.65078 .63204 m .6525 .6327 L .65261 .63206 L F
.65056 .63276 m .65732 .63455 L .65078 .63204 L F
.64879 .64848 m .65687 .63677 L .65247 .63951 L 0 1 .332 r
F
.65687 .63677 m .65697 .6361 L .65247 .63951 L F
.64879 .64848 m .65213 .65137 L .65519 .64904 L F
.64879 .64848 m .65519 .64904 L .65536 .64764 L F
.64879 .64848 m .6564 .63964 L .65687 .63677 L F
.64879 .64848 m .65536 .64764 L .65594 .64305 L F
.64879 .64848 m .65594 .64305 L .6564 .63964 L F
.66709 .65519 m .66785 .63521 L .67186 .63255 L 0 .818 .134 r
F
.66638 .65514 m .67032 .62787 L .66655 .63085 L 0 .771 .286 r
F
.66709 .65519 m .67186 .63255 L .67646 .64889 L 0 .818 .134 r
F
.66638 .65514 m .67588 .64552 L .67032 .62787 L 0 .771 .286 r
F
.65715 .67633 m .66638 .65514 L .661 .63921 L 0 .818 .278 r
F
.67336 .65977 m .67142 .67099 L .67292 .68207 L 0 .957 .372 r
F
.67336 .65977 m .682 .65903 L .67789 .65464 L F
.68337 .6654 m .68243 .67876 L .68647 .68599 L 0 .353 .341 r
F
.68337 .6654 m .6811 .66994 L .68243 .67876 L F
.67336 .65977 m .6835 .67012 L .682 .65903 L 0 .957 .372 r
F
.67721 .67754 m .68647 .68599 L .68243 .67876 L 0 .566 .368 r
F
.67336 .65977 m .68139 .68051 L .6835 .67012 L 0 .957 .372 r
F
.67278 .68951 m .68034 .70085 L .68336 .69031 L 0 1 .407 r
F
.67278 .68951 m .68336 .69031 L .68023 .68569 L F
.67721 .67754 m .67495 .69226 L .67878 .69886 L 0 .566 .368 r
F
.67721 .67754 m .67428 .68313 L .67495 .69226 L F
.68034 .70085 m .69117 .70164 L .68804 .69715 L 0 1 .414 r
F
.67721 .67754 m .67878 .69886 L .684 .70011 L 0 .566 .368 r
F
.67721 .67754 m .68715 .69516 L .68647 .68599 L F
.67721 .67754 m .684 .70011 L .68715 .69516 L F
.67336 .65977 m .67686 .68564 L .68139 .68051 L 0 .957 .372 r
F
.67336 .65977 m .67292 .68207 L .67686 .68564 L F
.66709 .65519 m .67646 .64889 L .67933 .67553 L 0 .818 .134 r
F
.6694 .69191 m .67878 .69886 L .67495 .69226 L 0 .724 .381 r
F
.6694 .69191 m .67878 .70804 L .67878 .69886 L F
.668 .68748 m .67686 .68564 L .67292 .68207 L 0 1 .382 r
F
.668 .68748 m .6777 .69594 L .67686 .68564 L F
.6694 .69191 m .67496 .71366 L .67878 .70804 L 0 .724 .381 r
F
.668 .68748 m .67488 .70611 L .6777 .69594 L 0 1 .382 r
F
.66709 .65519 m .67446 .69759 L .66991 .68197 L 0 .818 .134 r
F
.66709 .65519 m .67851 .69479 L .67446 .69759 L F
.66709 .65519 m .67933 .67553 L .67851 .69479 L F
.66638 .65514 m .67955 .67215 L .67588 .64552 L 0 .771 .286 r
F
.6777 .69594 m .68671 .69432 L .68277 .69089 L 0 1 .395 r
F
.68034 .70085 m .68789 .71189 L .69117 .70164 L 0 1 .414 r
F
.68789 .71189 m .67964 .73523 L .68759 .73162 L 0 1 .421 r
F
.68789 .71189 m .68759 .73162 L .69542 .72264 L F
.68034 .70085 m .6804 .72107 L .68789 .71189 L 0 1 .414 r
F
.68789 .71189 m .69542 .72264 L .69896 .71263 L 0 1 .421 r
F
.68789 .71189 m .69896 .71263 L .69585 .70827 L F
.68715 .69516 m .68451 .70838 L .68834 .71446 L 0 .573 .381 r
F
.68715 .69516 m .684 .70011 L .68451 .70838 L F
.6777 .69594 m .6874 .70417 L .68671 .69432 L 0 1 .395 r
F
.69696 .67658 m .69052 .68641 L .68804 .69715 L 0 1 .407 r
F
.68337 .6654 m .68647 .68599 L .69134 .68859 L 0 .353 .341 r
F
.6835 .67012 m .68277 .69089 L .68671 .69432 L 0 .971 .388 r
F
.6835 .67012 m .68139 .68051 L .68277 .69089 L F
.69696 .67658 m .68804 .69715 L .69117 .70164 L 0 1 .407 r
F
.6835 .67012 m .68671 .69432 L .69137 .68958 L 0 .971 .388 r
F
.67851 .69479 m .68334 .67052 L .6879 .68298 L 0 .744 .132 r
F
.67851 .69479 m .67933 .67553 L .68334 .67052 L F
.68715 .69516 m .68834 .71446 L .69372 .71567 L 0 .573 .381 r
F
.69696 .67658 m .69117 .70164 L .69857 .69785 L 0 1 .407 r
F
.69364 .67982 m .69346 .6833 L .69656 .70263 L 0 .991 .403 r
F
.68715 .69516 m .6963 .70267 L .69253 .69634 L 0 .573 .381 r
F
.6963 .70267 m .69629 .70265 L .69253 .69634 L F
.69629 .70265 m .69625 .70238 L .69253 .69634 L F
.69631 .70268 m .69625 .70238 L .69629 .70265 L F
.69301 .69198 m .69253 .69634 L .69625 .70238 L 0 .351 .35 r
F
.69346 .6833 m .69301 .69198 L .69625 .70238 L 0 .991 .403 r
F
.69301 .69198 m .69262 .69936 L .69625 .70238 L F
.69301 .69198 m .69134 .68859 L .69253 .69634 L 0 .351 .35 r
F
.69346 .6833 m .69183 .6882 L .69301 .69198 L 0 .991 .403 r
F
.69175 .68795 m .69134 .68859 L .69301 .69198 L 0 .351 .35 r
F
.69321 .68164 m .69137 .68958 L .69346 .6833 L 0 .991 .403 r
F
.69346 .6833 m .69625 .70238 L .69656 .70263 L F
.69379 .68478 m .69175 .68795 L .69301 .69198 L 0 .351 .35 r
F
.70532 .6883 m .69585 .70827 L .69896 .71263 L 0 1 .414 r
F
.70532 .6883 m .69857 .69785 L .69585 .70827 L F
.69542 .72264 m .68657 .74548 L .69477 .74192 L 0 1 .427 r
F
.69542 .72264 m .6838 .74141 L .68657 .74548 L F
.69542 .72264 m .68759 .73162 L .6838 .74141 L F
.69542 .72264 m .69477 .74192 L .70294 .7331 L F
.69542 .72264 m .70294 .7331 L .70675 .7233 L F
.69542 .72264 m .70675 .7233 L .70364 .71907 L F
.69707 .71118 m .69406 .72322 L .69788 .72882 L 0 .588 .393 r
F
.69707 .71118 m .69372 .71567 L .69406 .72322 L F
.68715 .69516 m .69707 .71118 L .69668 .70472 L 0 .573 .381 r
F
.69647 .70358 m .69668 .70472 L .69661 .70357 L 0 1 .409 r
F
.69635 .70267 m .69661 .70357 L .69656 .70263 L F
.68715 .69516 m .69668 .70472 L .69631 .70268 L 0 .573 .381 r
F
.68715 .69516 m .69372 .71567 L .69707 .71118 L F
.6874 .70417 m .69661 .70357 L .69635 .70267 L 0 1 .409 r
F
.69631 .70268 m .69668 .70472 L .69657 .70289 L 0 .573 .381 r
F
.6874 .70417 m .6971 .71208 L .69668 .70472 L 0 1 .409 r
F
.6874 .70417 m .69668 .70472 L .69647 .70358 L F
.69301 .69198 m .69625 .70238 L .69628 .70242 L 0 .351 .35 r
F
.69631 .70268 m .69656 .70263 L .69625 .70238 L 0 1 .409 r
F
.69517 .69861 m .69628 .70242 L .69657 .70289 L 0 .351 .35 r
F
.69301 .69198 m .69628 .70242 L .69517 .69861 L F
.69379 .68478 m .69301 .69198 L .69657 .70289 L F
.69301 .69198 m .69181 .68826 L .69291 .69377 L 0 .991 .403 r
F
.69183 .6882 m .69181 .68826 L .69301 .69198 L F
.69291 .69377 m .6917 .6886 L .69285 .69487 L F
.69181 .68826 m .6917 .6886 L .69291 .69377 L F
.68337 .6654 m .69134 .68859 L .69175 .68795 L 0 .353 .341 r
F
.6835 .67012 m .69137 .68958 L .69175 .68795 L 0 .971 .388 r
F
.68845 .67485 m .69175 .68795 L .69364 .67982 L F
.68337 .6654 m .69175 .68795 L .68845 .67485 L 0 .353 .341 r
F
.6835 .67012 m .69175 .68795 L .68845 .67485 L 0 .971 .388 r
F
.68845 .67485 m .69175 .68795 L .68953 .67687 L 0 .353 .341 r
F
.68953 .67687 m .69175 .68795 L .69379 .68478 L F
.68719 .66983 m .69364 .67982 L .69226 .66943 L 0 .971 .388 r
F
.68337 .6654 m .68845 .67485 L .68719 .66983 L 0 .353 .341 r
F
.6835 .67012 m .68845 .67485 L .68719 .66983 L 0 .971 .388 r
F
.68845 .67485 m .69364 .67982 L .68719 .66983 L F
.68719 .66983 m .68953 .67687 L .68852 .67137 L 0 .353 .341 r
F
.68845 .67485 m .68953 .67687 L .68719 .66983 L F
.68852 .67137 m .69379 .68478 L .69245 .67593 L F
.68953 .67687 m .69379 .68478 L .68852 .67137 L F
.69285 .69487 m .69137 .68958 L .69262 .69936 L 0 .991 .403 r
F
.6917 .6886 m .69137 .68958 L .69285 .69487 L F
.69364 .67982 m .69321 .68164 L .69346 .6833 L F
.6963 .70267 m .69631 .70268 L .69629 .70265 L 0 .573 .381 r
F
.69631 .70268 m .69657 .70289 L .69625 .70238 L F
.6874 .70417 m .69631 .70268 L .69262 .69936 L 0 1 .409 r
F
.69631 .70268 m .69625 .70238 L .69262 .69936 L F
.67851 .69479 m .6879 .68298 L .69067 .70579 L 0 .744 .132 r
F
.67878 .70804 m .68834 .71446 L .68451 .70838 L 0 .734 .393 r
F
.67878 .70804 m .68815 .72295 L .68834 .71446 L F
.68815 .72295 m .69788 .72882 L .69406 .72322 L 0 .75 .405 r
F
.68815 .72295 m .68729 .74136 L .6932 .74165 L F
.68815 .72295 m .6932 .74165 L .69751 .73672 L F
.68815 .72295 m .69751 .73672 L .69788 .72882 L F
.6874 .70417 m .68867 .72619 L .69389 .72138 L 0 1 .409 r
F
.68815 .72295 m .68372 .73606 L .68729 .74136 L 0 .75 .405 r
F
.68815 .72295 m .68408 .72817 L .68372 .73606 L F
.67878 .70804 m .68408 .72817 L .68815 .72295 L 0 .734 .393 r
F
.6874 .70417 m .68493 .72329 L .68867 .72619 L 0 1 .409 r
F
.6874 .70417 m .68439 .71386 L .68493 .72329 L F
.6777 .69594 m .68439 .71386 L .6874 .70417 L 0 1 .395 r
F
.6874 .70417 m .69389 .72138 L .6971 .71208 L 0 1 .409 r
F
.67851 .69479 m .69067 .70579 L .68978 .72384 L 0 .744 .132 r
F
.66638 .65514 m .67941 .69664 L .67955 .67215 L 0 .771 .286 r
F
.67878 .70804 m .67478 .72213 L .67836 .72782 L 0 .734 .393 r
F
.67878 .70804 m .67496 .71366 L .67478 .72213 L F
.67878 .70804 m .67836 .72782 L .68408 .72817 L F
.6777 .69594 m .67932 .71891 L .68439 .71386 L 0 1 .395 r
F
.6777 .69594 m .67558 .71595 L .67932 .71891 L F
.6777 .69594 m .67488 .70611 L .67558 .71595 L F
.67932 .72811 m .6885 .73513 L .68867 .72619 L 0 1 .417 r
F
.67932 .72811 m .68867 .72619 L .68493 .72329 L F
.67851 .69479 m .68572 .72903 L .68124 .71777 L 0 .744 .132 r
F
.67851 .69479 m .68978 .72384 L .68572 .72903 L F
.66638 .65514 m .67552 .70257 L .67941 .69664 L 0 .771 .286 r
F
.668 .68748 m .66996 .71152 L .67488 .70611 L 0 1 .382 r
F
.668 .68748 m .66622 .70855 L .66996 .71152 L F
.6645 .72741 m .66991 .68197 L .67446 .69759 L 0 .703 .176 r
F
.6645 .72741 m .66566 .69461 L .66991 .68197 L F
.67014 .72099 m .67015 .74245 L .67559 .73742 L 0 1 .405 r
F
.67014 .72099 m .66664 .73986 L .67015 .74245 L F
.67014 .72099 m .67559 .73742 L .67932 .72811 L F
.67014 .72099 m .66664 .73066 L .66664 .73986 L F
.67014 .72099 m .67932 .72811 L .67932 .71891 L F
.67014 .72099 m .67932 .71891 L .67558 .71595 L F
.6645 .72741 m .67446 .69759 L .67693 .73185 L 0 .703 .176 r
F
.66638 .65514 m .66993 .68472 L .67552 .70257 L 0 .771 .286 r
F
.65715 .67633 m .66993 .68472 L .66638 .65514 L 0 .818 .278 r
F
.65715 .67633 m .66975 .71389 L .66993 .68472 L F
.65715 .67633 m .66594 .72306 L .66975 .71389 L F
.65715 .67633 m .66052 .70689 L .66594 .72306 L F
.65231 .73856 m .65674 .7537 L .66089 .74468 L 0 1 .405 r
F
.65231 .73856 m .65119 .75878 L .65674 .7537 L F
.65231 .73856 m .64794 .75655 L .65119 .75878 L F
.64904 .75015 m .65572 .71866 L .65623 .72081 L 0 .732 .172 r
F
.6513 .74766 m .65623 .72081 L .66022 .73784 L F
.64904 .75015 m .65623 .72081 L .6513 .74766 L F
.64904 .75015 m .65095 .72387 L .65572 .71866 L F
.66089 .74468 m .65606 .76221 L .65931 .76454 L 0 1 .417 r
F
.66089 .74468 m .65674 .7537 L .65606 .76221 L F
.64904 .75015 m .66022 .73784 L .66025 .73849 L 0 .732 .172 r
F
.64936 .7648 m .65243 .75752 L .65237 .75756 L 0 1 .145 r
F
.65094 .75663 m .66025 .73856 L .65104 .7561 L F
.64936 .7648 m .66019 .73872 L .65094 .75663 L F
.66019 .73872 m .66025 .73856 L .65094 .75663 L F
.64904 .75015 m .65 .75751 L .64963 .7582 L 0 .732 .172 r
F
.64936 .7648 m .65104 .7561 L .65 .75751 L 0 1 .145 r
F
.66502 .78459 m .66045 .80161 L .67072 .79415 L 0 1 .449 r
F
.65931 .77488 m .65513 .79207 L .66502 .78459 L 0 1 .446 r
F
.66451 .82778 m .65481 .84439 L .66292 .84336 L 0 1 .453 r
F
.66451 .82778 m .65236 .84035 L .65481 .84439 L F
.66451 .82778 m .65651 .83323 L .65236 .84035 L F
.65772 .81707 m .65651 .83323 L .66451 .82778 L 0 1 .445 r
F
.65772 .81707 m .66451 .82778 L .6684 .82046 L F
.65772 .81707 m .6684 .82046 L .66557 .81616 L F
.66451 .82778 m .66292 .84336 L .67129 .83796 L 0 1 .453 r
F
.65809 .83326 m .65679 .84543 L .6648 .83939 L 0 1 .494 r
F
.67072 .79415 m .66576 .81102 L .6764 .80357 L 0 1 .452 r
F
.66806 .79197 m .66132 .80955 L .66872 .80886 L 0 1 .436 r
F
.66806 .79197 m .65848 .80502 L .66132 .80955 L F
.66806 .79197 m .66137 .79749 L .65848 .80502 L F
.65857 .77701 m .65373 .7972 L .66136 .79749 L 0 1 .425 r
F
.66451 .82778 m .67129 .83796 L .67546 .83083 L 0 1 .453 r
F
.65809 .83326 m .6648 .83939 L .66871 .83301 L 0 1 .494 r
F
.65857 .77701 m .66136 .79749 L .66806 .79196 L 0 1 .425 r
F
.65809 .83326 m .66871 .83301 L .66592 .83054 L 0 1 .494 r
F
.65772 .81707 m .64868 .83413 L .65651 .83323 L 0 1 .445 r
F
.65138 .82726 m .65809 .83326 L .66173 .82688 L 0 1 .491 r
F
.65138 .82726 m .66173 .82688 L .65894 .82446 L F
.67576 .80342 m .66557 .81616 L .6684 .82046 L 0 1 .444 r
F
.67576 .80342 m .66872 .80886 L .66557 .81616 L F
.66852 .81048 m .65894 .82446 L .66173 .82688 L 0 1 .477 r
F
.66852 .81048 m .66184 .81743 L .65894 .82446 L F
.65918 .80301 m .66184 .81743 L .66852 .81048 L 0 1 .47 r
F
.65918 .80301 m .65426 .82047 L .66184 .81743 L F
.65918 .80301 m .65081 .81758 L .65426 .82047 L F
.66806 .79197 m .66872 .80886 L .67576 .80342 L 0 1 .436 r
F
.65918 .80301 m .66852 .81048 L .67064 .80299 L 0 1 .47 r
F
.65918 .80301 m .65292 .8101 L .65081 .81758 L F
.65918 .80301 m .67064 .80299 L .66678 .79997 L F
.65205 .79745 m .65292 .8101 L .65918 .80301 L 0 1 .463 r
F
.65205 .79745 m .65918 .80301 L .66167 .796 L F
.65205 .79745 m .66167 .796 L .65872 .79374 L F
.66502 .78459 m .67072 .79415 L .67663 .78568 L 0 1 .449 r
F
.66502 .78459 m .67663 .78568 L .67423 .78185 L F
.65931 .77488 m .66502 .78459 L .67064 .77605 L 0 1 .446 r
F
.65857 .77701 m .66806 .79196 L .67014 .7833 L 0 1 .425 r
F
.65857 .77701 m .67014 .7833 L .66622 .77728 L F
.66585 .77819 m .66167 .796 L .6681 .79187 L 0 1 .449 r
F
.66585 .77819 m .65872 .79374 L .66167 .796 L F
.66585 .77819 m .66051 .7861 L .65872 .79374 L F
.65796 .77236 m .6543 .79038 L .66051 .7861 L 0 1 .441 r
F
.65796 .77236 m .65135 .78818 L .6543 .79038 L F
.65931 .77488 m .67064 .77605 L .66824 .77215 L 0 1 .446 r
F
.65796 .77236 m .66051 .7861 L .66585 .77819 L 0 1 .441 r
F
.65538 .77436 m .66025 .73901 L .65648 .75112 L 0 1 .29 r
F
.67533 .74465 m .66464 .76627 L .67309 .76303 L 0 1 .434 r
F
.66517 .75047 m .66103 .76911 L .66752 .76858 L 0 .971 .413 r
F
.66089 .74468 m .65931 .76454 L .66506 .75972 L 0 1 .417 r
F
.68198 .75475 m .67309 .76303 L .66824 .77215 L 0 1 .439 r
F
.67533 .74465 m .67309 .76303 L .68198 .75475 L 0 1 .434 r
F
.66517 .75047 m .66752 .76858 L .67318 .76299 L 0 .971 .413 r
F
.66517 .75047 m .67497 .75499 L .67167 .74993 L F
.66517 .75047 m .67318 .76299 L .67497 .75499 L F
.66089 .74468 m .66506 .75972 L .66947 .75097 L 0 1 .417 r
F
.66089 .74468 m .66947 .75097 L .67015 .74245 L F
.66089 .74468 m .67015 .74245 L .66664 .73986 L F
.65538 .77436 m .66494 .74549 L .66025 .73901 L 0 1 .29 r
F
.64936 .7648 m .65648 .75112 L .65762 .74746 L 0 1 .145 r
F
.65243 .75752 m .65762 .74746 L .66025 .73901 L F
.64936 .7648 m .65762 .74746 L .65243 .75752 L F
.64995 .85151 m .66093 .85415 L .65848 .8503 L 0 1 .463 r
F
.6648 .83939 m .65679 .84543 L .65262 .85183 L 0 1 .496 r
F
.64412 .84147 m .64995 .85151 L .65481 .84439 L 0 1 .454 r
F
.64412 .84147 m .65481 .84439 L .65236 .84035 L F
.65809 .83326 m .64898 .84814 L .65679 .84543 L 0 1 .494 r
F
.65809 .83326 m .64656 .84571 L .64898 .84814 L F
.65809 .83326 m .65046 .83933 L .64656 .84571 L F
.65138 .82726 m .65046 .83933 L .65809 .83326 L 0 1 .491 r
F
.64936 .7648 m .65181 .76219 L .65648 .75112 L 0 1 .145 r
F
.64523 .80099 m .65769 .79326 L .65538 .77437 L 0 1 .277 r
F
.64523 .80099 m .65636 .81705 L .65769 .79326 L F
.64523 .80099 m .65224 .82989 L .65636 .81705 L F
.64995 .85151 m .65577 .86107 L .66093 .85415 L 0 1 .463 r
F
.64437 .85375 m .65504 .85433 L .65262 .85183 L 0 1 .508 r
F
.65034 .85376 m .66068 .82057 L .65636 .81705 L 0 1 .27 r
F
.65034 .85376 m .66233 .83809 L .66068 .82057 L F
.65034 .85376 m .65636 .81705 L .65224 .82989 L F
.65577 .86107 m .66702 .86347 L .66459 .85979 L 0 1 .471 r
F
.67129 .83796 m .66093 .85415 L .6693 .85302 L 0 1 .461 r
F
.67129 .83796 m .65848 .8503 L .66093 .85415 L F
.65577 .86107 m .66156 .8702 L .66702 .86347 L 0 1 .471 r
F
.65014 .86001 m .65589 .86641 L .66108 .86065 L 0 1 .507 r
F
.67129 .83796 m .66292 .84336 L .65848 .8503 L 0 1 .461 r
F
.65014 .86001 m .66108 .86065 L .65867 .85811 L 0 1 .507 r
F
.67129 .83796 m .6693 .85302 L .67804 .84766 L 0 1 .461 r
F
.67148 .84562 m .65867 .85811 L .66108 .86065 L 0 1 .498 r
F
.64437 .85375 m .65014 .86001 L .65504 .85433 L 0 1 .508 r
F
.67148 .84562 m .66312 .85167 L .65867 .85811 L 0 1 .498 r
F
.6648 .83939 m .65504 .85433 L .66312 .85167 L 0 1 .496 r
F
.6648 .83939 m .65262 .85183 L .65504 .85433 L F
.65034 .85376 m .66045 .86196 L .66233 .83809 L 0 1 .27 r
F
.66733 .87896 m .65724 .88416 L .65121 .89055 L 0 1 .484 r
F
.66735 .87948 m .65726 .8848 L .65122 .89083 L 0 1 .506 r
F
.66162 .87292 m .64819 .88677 L .65726 .8848 L F
.66162 .87292 m .65726 .8848 L .66735 .87948 L F
.65589 .86641 m .65192 .87814 L .66162 .87292 L F
.66156 .8702 m .66733 .87896 L .67309 .87241 L 0 1 .478 r
F
.66156 .8702 m .67309 .87241 L .67067 .86888 L F
.65589 .86641 m .66162 .87292 L .66711 .86706 L 0 1 .506 r
F
.65589 .86641 m .66711 .86706 L .6647 .86449 L F
.6558 .89271 m .65098 .89542 L .65431 .89797 L 0 .831 .459 r
F
.6558 .89271 m .65161 .89316 L .65098 .89542 L F
.64699 .88627 m .65161 .89316 L .6558 .89271 L 0 .73 .44 r
F
.64699 .88627 m .6558 .89271 L .65625 .89051 L F
.64699 .88627 m .65625 .89051 L .65264 .88801 L F
.65585 .88643 m .65625 .89051 L .66165 .89223 L 0 .512 .345 r
F
.65585 .88643 m .65264 .88801 L .65625 .89051 L F
.65585 .88643 m .65247 .88627 L .65264 .88801 L F
.67309 .8874 m .66261 .89252 L .65628 .89877 L 0 1 .49 r
F
.65585 .88643 m .66165 .89223 L .66526 .89205 L 0 .512 .345 r
F
.64641 .87998 m .65247 .88627 L .65585 .88643 L 0 .437 .309 r
F
.65585 .88643 m .66526 .89205 L .6651 .8903 L 0 .512 .345 r
F
.65585 .88643 m .6651 .8903 L .66127 .88816 L F
.64641 .87998 m .65585 .88643 L .65551 .88469 L 0 .437 .309 r
F
.65334 .88217 m .65551 .88469 L .66048 .88702 L 0 .298 .206 r
F
.65334 .88217 m .66048 .88702 L .66328 .88765 L F
.65334 .88217 m .66328 .88765 L .66236 .88657 L F
.65334 .88217 m .66236 .88657 L .65833 .88451 L F
.65886 .88614 m .65682 .88432 L .65833 .88451 L 0 0 0 r
F
.65334 .88217 m .65166 .8822 L .65551 .88469 L 0 .298 .206 r
F
.65334 .88217 m .65073 .88112 L .65166 .8822 L F
.64291 .87511 m .64575 .87802 L .65073 .88112 L 0 .192 .185 r
F
.64291 .87511 m .65073 .88112 L .65333 .88217 L F
.64291 .87511 m .65333 .88217 L .65269 .88151 L F
.64936 .87918 m .65269 .88151 L .65212 .88092 L F
.64291 .87511 m .65269 .88151 L .64936 .87918 L F
.64291 .87511 m .64173 .87494 L .64575 .87802 L F
.64291 .87511 m .6405 .87369 L .64173 .87494 L F
.63713 .87222 m .64109 .87339 L .64613 .87796 L 0 .154 0 r
F
.64109 .87339 m .64154 .87352 L .64222 .87418 L F
.64291 .87511 m .65212 .88092 L .64789 .87821 L 0 .192 .185 r
F
.64109 .87339 m .64222 .87418 L .64613 .87796 L 0 .154 0 r
F
.64801 .88036 m .65212 .88092 L .65682 .88432 L 0 .049 0 r
F
.64801 .88036 m .65682 .88432 L .65886 .88614 L F
.64641 .87998 m .65551 .88469 L .65166 .8822 L 0 .437 .309 r
F
.64801 .88036 m .6571 .8859 L .65272 .88376 L 0 .049 0 r
F
.64801 .88036 m .65886 .88614 L .6571 .8859 L F
.64641 .87998 m .64723 .88404 L .65247 .88627 L 0 .437 .309 r
F
.65178 .88868 m .65272 .88376 L .6571 .8859 L 0 .203 .009 r
F
.65178 .88868 m .6571 .8859 L .66147 .88959 L F
.66526 .89205 m .66165 .89223 L .66165 .89406 L 0 .641 .381 r
F
.65178 .88868 m .66147 .88959 L .66292 .89236 L 0 .203 .009 r
F
.65178 .88868 m .66064 .89356 L .65616 .89238 L F
.65178 .88868 m .66292 .89236 L .66064 .89356 L F
.65303 .90055 m .66111 .90667 L .66262 .90402 L 0 1 .5 r
F
.67309 .8874 m .65831 .90199 L .66796 .90061 L 0 1 .49 r
F
.67309 .8874 m .65628 .89877 L .65831 .90199 L F
.65303 .90055 m .66262 .90402 L .65929 .90166 L 0 1 .5 r
F
.64492 .89396 m .65303 .90055 L .65431 .89797 L 0 .945 .489 r
F
.64492 .89396 m .65431 .89797 L .65098 .89542 L F
.6558 .89271 m .65431 .89797 L .66013 .89932 L 0 .831 .459 r
F
.6558 .89271 m .66013 .89932 L .66459 .89856 L F
.6558 .89271 m .66459 .89856 L .66524 .8963 L F
.6558 .89271 m .66524 .8963 L .66165 .89406 L F
.65417 .901 m .65338 .89555 L .65616 .89238 L 0 .254 .061 r
F
.65374 .89606 m .66425 .86107 L .66045 .86196 L 0 1 .259 r
F
.67305 .88607 m .67875 .89267 L .6851 .88655 L 0 1 .506 r
F
.67305 .88607 m .6851 .88655 L .68271 .88395 L F
.67148 .87968 m .67305 .88607 L .67912 .88004 L F
.66896 .88134 m .67305 .88607 L .67148 .87968 L F
.67148 .87968 m .67309 .8874 L .67915 .881 L 0 1 .484 r
F
.66733 .87896 m .66896 .88134 L .67148 .87968 L F
.66896 .88134 m .67309 .8874 L .67148 .87968 L F
.66735 .87948 m .66896 .88134 L .67148 .87968 L 0 1 .506 r
F
.67443 .87794 m .67912 .88004 L .67672 .87744 L F
.67148 .87968 m .67912 .88004 L .67443 .87794 L F
.67443 .87794 m .67915 .881 L .67673 .8776 L 0 1 .484 r
F
.66733 .87896 m .67148 .87968 L .67443 .87794 L F
.67148 .87968 m .67915 .881 L .67443 .87794 L F
.66735 .87948 m .67148 .87968 L .67443 .87794 L 0 1 .506 r
F
.66162 .87292 m .66735 .87948 L .67312 .87354 L F
.66162 .87292 m .67312 .87354 L .67072 .87094 L F
.66328 .88765 m .6651 .8903 L .67021 .89204 L 0 .403 .227 r
F
.66328 .88765 m .66127 .88816 L .6651 .8903 L F
.67309 .8874 m .66796 .90061 L .67882 .89555 L 0 1 .49 r
F
.66328 .88765 m .67021 .89204 L .6732 .89222 L 0 .403 .227 r
F
.65886 .88614 m .66236 .88657 L .66702 .88903 L 0 0 0 r
F
.65886 .88614 m .65833 .88451 L .66236 .88657 L F
.66328 .88765 m .66048 .88702 L .66127 .88816 L 0 .403 .227 r
F
.65886 .88614 m .66702 .88903 L .66921 .89025 L 0 0 0 r
F
.65886 .88614 m .66921 .89025 L .66772 .89007 L F
.65886 .88614 m .66772 .89007 L .66353 .88861 L F
.65374 .89606 m .66514 .87418 L .66425 .86107 L 0 1 .259 r
F
.66526 .89205 m .66165 .89406 L .66524 .8963 L 0 .641 .381 r
F
.66328 .88765 m .6732 .89222 L .67243 .89108 L 0 .403 .227 r
F
.66328 .88765 m .67243 .89108 L .66841 .88939 L F
.66292 .89236 m .66148 .88959 L .66353 .88861 L 0 .065 0 r
F
.65417 .901 m .65616 .89238 L .66064 .89356 L 0 .254 .061 r
F
.65417 .901 m .66064 .89356 L .66463 .89728 L F
.65374 .89606 m .66264 .89389 L .66514 .87418 L 0 1 .259 r
F
.65374 .89606 m .66045 .86196 L .65627 .87628 L F
.65014 .86001 m .64656 .87155 L .65589 .86641 L 0 1 .507 r
F
.65034 .85376 m .65627 .87628 L .66045 .86196 L 0 1 .27 r
F
.64729 .82272 m .64747 .82299 L .64733 .82166 L 0 .854 .256 r
F
.64729 .82272 m .64733 .82166 L .64523 .80099 L F
.63791 .81668 m .64747 .82299 L .63875 .80942 L F
.65138 .82726 m .64291 .84213 L .65046 .83933 L 0 1 .491 r
F
.65138 .82726 m .64048 .83978 L .64291 .84213 L F
.65138 .82726 m .64411 .83341 L .64048 .83978 L F
.64311 .82013 m .64411 .83341 L .65138 .82726 L 0 1 .485 r
F
.64311 .82013 m .63641 .83595 L .64411 .83341 L F
.64523 .80099 m .64747 .82299 L .65224 .82989 L 0 1 .277 r
F
.6386 .8477 m .64437 .85375 L .64898 .84814 L 0 1 .508 r
F
.6386 .8477 m .64898 .84814 L .64656 .84571 L F
.63476 .81461 m .64612 .85291 L .64747 .82299 L 0 .854 .256 r
F
.64004 .81272 m .6538 .85059 L .65022 .80394 L 0 .622 .253 r
F
.65023 .80448 m .65964 .88674 L .66381 .8878 L 0 .484 .258 r
F
.65169 .81501 m .66205 .8835 L .65619 .84749 L F
.65023 .80448 m .65178 .81481 L .65169 .81501 L F
.65178 .81481 m .66205 .8835 L .65169 .81501 L F
.69145 .86464 m .682 .87084 L .67672 .87744 L 0 1 .502 r
F
.68478 .85693 m .67309 .87241 L .68035 .87134 L 0 1 .475 r
F
.68245 .86883 m .68035 .87134 L .682 .87084 L 0 1 .501 r
F
.68245 .86883 m .68035 .87134 L .68201 .8711 L 0 1 .475 r
F
.68478 .85693 m .68035 .87134 L .68245 .86883 L F
.69145 .86464 m .67912 .88004 L .68826 .87729 L 0 1 .502 r
F
.69145 .86464 m .67672 .87744 L .67912 .88004 L F
.69145 .86464 m .68826 .87729 L .69808 .87101 L F
.68837 .86169 m .682 .87084 L .69145 .86464 L 0 1 .501 r
F
.68837 .86169 m .68201 .8711 L .69149 .86581 L 0 1 .475 r
F
.68478 .85693 m .68245 .86883 L .68837 .86169 L F
.68245 .86883 m .682 .87084 L .68837 .86169 L 0 1 .501 r
F
.68245 .86883 m .68201 .8711 L .68837 .86169 L 0 1 .475 r
F
.68481 .85828 m .68245 .86883 L .68837 .86169 L 0 1 .501 r
F
.68481 .85828 m .67312 .87354 L .68035 .87134 L F
.68481 .85828 m .68035 .87134 L .68245 .86883 L F
.68478 .85693 m .67067 .86888 L .67309 .87241 L 0 1 .475 r
F
.68481 .85828 m .67072 .87094 L .67312 .87354 L 0 1 .501 r
F
.66921 .89025 m .66702 .88903 L .66841 .88939 L 0 0 0 r
F
.66292 .89236 m .66353 .88861 L .66772 .89007 L 0 .065 0 r
F
.66592 .89082 m .67636 .87762 L .6762 .86732 L 0 1 .282 r
F
.67309 .8874 m .67882 .89555 L .68518 .88929 L 0 1 .49 r
F
.67309 .8874 m .68518 .88929 L .68277 .88601 L F
.66921 .89025 m .67243 .89108 L .6772 .89282 L 0 0 0 r
F
.66921 .89025 m .66841 .88939 L .67243 .89108 L F
.66921 .89025 m .6772 .89282 L .67953 .89344 L F
.66921 .89025 m .67953 .89344 L .67816 .89309 L F
.66921 .89025 m .67816 .89309 L .67399 .89199 L F
.66526 .89205 m .66524 .8963 L .67081 .89758 L 0 .641 .381 r
F
.66526 .89205 m .67081 .89758 L .67465 .89702 L F
.66526 .89205 m .67465 .89702 L .67467 .8952 L F
.66526 .89205 m .67467 .8952 L .67085 .89332 L F
.6732 .89222 m .67021 .89204 L .67085 .89332 L 0 .495 .246 r
F
.66292 .89236 m .66772 .89007 L .67201 .89258 L 0 .065 0 r
F
.66592 .89082 m .67339 .89175 L .67636 .87762 L 0 1 .282 r
F
.68478 .85693 m .67567 .86225 L .67067 .86888 L 0 1 .475 r
F
.68481 .85828 m .67572 .8644 L .67072 .87094 L 0 1 .501 r
F
.66592 .89082 m .6762 .86732 L .67301 .86689 L 0 1 .282 r
F
.66592 .89082 m .67301 .86689 L .66891 .87666 L F
.66559 .88578 m .67009 .88978 L .67429 .89137 L 0 .509 .325 r
F
.65321 .82117 m .66374 .88737 L .66485 .88642 L 0 .484 .258 r
F
.65228 .81705 m .66381 .8878 L .65321 .82117 L F
.65023 .80448 m .65228 .81705 L .65321 .82117 L F
.65023 .80448 m .66462 .88516 L .66205 .8835 L F
.6647 .88557 m .66485 .88642 L .66205 .8835 L F
.66205 .8835 m .66529 .88603 L .66559 .88578 L 0 .509 .325 r
F
.66529 .88603 m .67009 .88978 L .66559 .88578 L F
.66374 .88737 m .66381 .8878 L .66485 .88642 L 0 .484 .258 r
F
.67804 .84766 m .66459 .85979 L .66702 .86347 L 0 1 .468 r
F
.67804 .84766 m .6693 .85302 L .66459 .85979 L F
.67148 .84562 m .66108 .86065 L .66943 .858 L 0 1 .498 r
F
.66459 .89856 m .67335 .90392 L .67422 .90157 L 0 .926 .476 r
F
.66459 .89856 m .67422 .90157 L .67063 .89953 L F
.6732 .89222 m .67085 .89332 L .67467 .8952 L 0 .495 .246 r
F
.6732 .89222 m .67467 .8952 L .67992 .89641 L F
.6732 .89222 m .67992 .89641 L .6831 .89614 L F
.6732 .89222 m .6831 .89614 L .68248 .89486 L F
.6732 .89222 m .68248 .89486 L .67847 .89343 L F
.67356 .89446 m .67201 .89258 L .67399 .89199 L 0 0 0 r
F
.66292 .89236 m .67201 .89258 L .67356 .89446 L 0 .065 0 r
F
.66292 .89236 m .67356 .89446 L .67151 .89545 L F
.66292 .89236 m .67151 .89545 L .66722 .89488 L F
.66459 .89856 m .66262 .90402 L .66864 .90499 L 0 .926 .476 r
F
.66459 .89856 m .66864 .90499 L .67335 .90392 L F
.67465 .89702 m .67422 .90157 L .67995 .90242 L 0 .772 .414 r
F
.67465 .89702 m .67063 .89953 L .67422 .90157 L F
.67465 .89702 m .67081 .89758 L .67063 .89953 L F
.67465 .89702 m .67995 .90242 L .68402 .90151 L F
.66547 .90107 m .67151 .89545 L .6752 .89762 L 0 .121 .022 r
F
.67482 .89791 m .6752 .89762 L .67537 .89772 L F
.66547 .90107 m .6752 .89762 L .67482 .89791 L F
.66111 .90667 m .66355 .91385 L .66916 .9124 L 0 1 .509 r
F
.66111 .90667 m .66916 .9124 L .6709 .90966 L F
.66111 .90667 m .6709 .90966 L .66759 .90745 L F
.67335 .90392 m .66759 .90745 L .6709 .90966 L 0 1 .49 r
F
.67335 .90392 m .66864 .90499 L .66759 .90745 L F
.66572 .91144 m .6754 .8988 L .67547 .89798 L 0 1 .247 r
F
.671 .90062 m .67537 .89772 L .67545 .89792 L 0 .121 .022 r
F
.67369 .89903 m .67545 .89792 L .67547 .89798 L F
.671 .90062 m .67545 .89792 L .67369 .89903 L F
.66547 .90107 m .67482 .89791 L .671 .90062 L F
.67953 .89344 m .67847 .89343 L .68248 .89486 L 0 .392 .2 r
F
.67953 .89344 m .6772 .89282 L .67847 .89343 L F
.67356 .89446 m .67816 .89309 L .68252 .89473 L 0 0 0 r
F
.67356 .89446 m .67399 .89199 L .67816 .89309 L F
.67356 .89446 m .68252 .89473 L .68396 .89568 L F
.67356 .89446 m .68396 .89568 L .68395 .89568 L F
.67356 .89446 m .68397 .89568 L .68335 .89571 L F
.67953 .89344 m .68248 .89486 L .68735 .89598 L 0 .392 .2 r
F
.67953 .89344 m .68735 .89598 L .68983 .89604 L F
.67335 .90392 m .6709 .90966 L .67711 .91027 L 0 1 .49 r
F
.67335 .90392 m .67711 .91027 L .6821 .90888 L F
.67335 .90392 m .6821 .90888 L .68317 .90642 L F
.67335 .90392 m .68317 .90642 L .67959 .90453 L F
.67465 .89702 m .68402 .90151 L .68422 .89955 L 0 .772 .414 r
F
.67465 .89702 m .68422 .89955 L .6804 .89787 L F
.6831 .89614 m .68422 .89955 L .6896 .90029 L 0 .57 .3 r
F
.6831 .89614 m .6804 .89787 L .68422 .89955 L F
.6831 .89614 m .67992 .89641 L .6804 .89787 L F
.6831 .89614 m .6896 .90029 L .69298 .89958 L F
.6831 .89614 m .69298 .89958 L .69251 .89812 L F
.6831 .89614 m .69251 .89812 L .6885 .89687 L F
.67392 .90892 m .6835 .89573 L .68104 .89614 L 0 1 .282 r
F
.68397 .89568 m .68271 .90168 L .68419 .89567 L 0 1 .346 r
F
.68395 .89568 m .68396 .89568 L .68397 .89568 L 0 0 0 r
F
.68402 .90151 m .67995 .90242 L .67959 .90453 L 0 .893 .442 r
F
.67392 .90892 m .68271 .90168 L .68397 .89568 L 0 1 .282 r
F
.68335 .89571 m .68397 .89568 L .6835 .89573 L 0 0 0 r
F
.67953 .89344 m .68983 .89604 L .68858 .89544 L 0 .392 .2 r
F
.68419 .89568 m .68252 .89473 L .68441 .89457 L 0 0 0 r
F
.68417 .89581 m .68397 .89568 L .68419 .89568 L F
.68397 .89568 m .68252 .89473 L .68419 .89568 L F
.68354 .89567 m .68397 .89568 L .68414 .89485 L 0 1 .282 r
F
.6835 .89573 m .68397 .89568 L .68354 .89567 L F
.67392 .90892 m .68397 .89568 L .6835 .89573 L F
.6835 .89573 m .68397 .89568 L .68417 .89581 L 0 0 0 r
F
.68104 .89614 m .68417 .89581 L .6822 .8964 L F
.67392 .90892 m .68104 .89614 L .67803 .90009 L 0 1 .282 r
F
.67356 .89446 m .68321 .89569 L .68104 .89614 L 0 0 0 r
F
.67356 .89446 m .68104 .89614 L .67793 .89611 L F
.68104 .89614 m .6822 .8964 L .68066 .8963 L F
.68104 .89614 m .68066 .8963 L .67793 .89611 L F
.68104 .89614 m .68072 .89621 L .68066 .8963 L 0 1 .282 r
F
.68104 .89614 m .68066 .8963 L .67803 .90009 L F
.68104 .89614 m .68214 .89416 L .68072 .89621 L F
.68321 .89569 m .6835 .89573 L .68104 .89614 L 0 0 0 r
F
.6835 .89573 m .68417 .89581 L .68104 .89614 L F
.68104 .89614 m .6835 .89573 L .68112 .89599 L 0 1 .282 r
F
.68112 .89599 m .68414 .89485 L .68214 .89416 L F
.6835 .89573 m .68414 .89485 L .68112 .89599 L F
.68402 .90151 m .68317 .90642 L .68906 .90688 L 0 .893 .442 r
F
.68402 .90151 m .67959 .90453 L .68317 .90642 L F
.68402 .90151 m .68906 .90688 L .69336 .9056 L F
.68402 .90151 m .69336 .9056 L .69374 .90349 L F
.68402 .90151 m .69374 .90349 L .68994 .90196 L F
.68419 .89572 m .68271 .90168 L .68466 .90369 L 0 1 .346 r
F
.68983 .89604 m .69251 .89812 L .69748 .8987 L 0 .515 .231 r
F
.68983 .89604 m .6885 .89687 L .69251 .89812 L F
.68983 .89604 m .68735 .89598 L .6885 .89687 L F
.69372 .89655 m .69996 .89292 L .69877 .89037 L 0 1 .377 r
F
.68983 .89604 m .69748 .8987 L .69789 .89863 L 0 .515 .231 r
F
.68983 .89604 m .69789 .89863 L .69782 .89859 L F
.69996 .89292 m .69913 .89914 L .70246 .90056 L 0 1 .413 r
F
.69298 .89958 m .69926 .90379 L .70283 .90267 L 0 .714 .353 r
F
.69298 .89958 m .70283 .90267 L .70258 .90136 L F
.69336 .9056 m .69209 .91092 L .69816 .91101 L 0 .997 .465 r
F
.69336 .9056 m .69816 .91101 L .70269 .90938 L F
.69336 .9056 m .70269 .90938 L .70325 .9071 L F
.69336 .9056 m .70325 .9071 L .69945 .90569 L F
.70283 .90267 m .69945 .90569 L .70325 .9071 L 0 .862 .397 r
F
.70283 .90267 m .69926 .90379 L .69945 .90569 L F
.69325 .90921 m .70286 .90362 L .70258 .90136 L 0 1 .402 r
F
.70225 .90095 m .70258 .90136 L .70251 .90072 L F
.69298 .89958 m .70258 .90136 L .70243 .90117 L 0 .714 .353 r
F
.70225 .90095 m .70255 .90119 L .70228 .90095 L F
.69298 .89958 m .70241 .90116 L .70225 .90095 L F
.70241 .90116 m .70255 .90119 L .70225 .90095 L F
.69298 .89958 m .69374 .90349 L .69926 .90379 L F
.69325 .90921 m .70225 .90095 L .69861 .90311 L 0 1 .402 r
F
.70223 .90092 m .70251 .90072 L .70221 .9009 L F
.70226 .90094 m .70251 .90072 L .70223 .90092 L F
.7021 .9008 m .70221 .9009 L .70251 .90072 L 0 1 .413 r
F
.69913 .89914 m .69912 .89926 L .70246 .90056 L F
.69912 .89926 m .69851 .89988 L .7022 .9009 L 0 .606 .252 r
F
.70225 .90095 m .70226 .90094 L .70223 .90092 L 0 1 .402 r
F
.69298 .89958 m .70225 .90095 L .69851 .89988 L 0 .714 .353 r
F
.70225 .90095 m .70221 .9009 L .7022 .9009 L 0 1 .402 r
F
.70225 .90095 m .70251 .90099 L .7022 .9009 L 0 .714 .353 r
F
.70225 .90095 m .7022 .9009 L .69851 .89988 L F
.70225 .90095 m .7022 .9009 L .69861 .90311 L 0 1 .402 r
F
.69912 .89926 m .69861 .90311 L .70206 .90083 L 0 1 .413 r
F
.69912 .89926 m .70206 .90083 L .70246 .90056 L F
.6994 .89897 m .69912 .89926 L .7022 .9009 L 0 .606 .252 r
F
.70011 .89824 m .6994 .89897 L .70251 .90099 L F
.6994 .89897 m .7022 .9009 L .70251 .90099 L F
.69325 .90921 m .70258 .90136 L .70225 .90095 L 0 1 .402 r
F
.70243 .90117 m .70258 .90136 L .70255 .90119 L 0 .714 .353 r
F
.70228 .90095 m .70255 .90119 L .70251 .90099 L F
.70246 .90056 m .7021 .9008 L .70251 .90072 L 0 1 .413 r
F
.7021 .9008 m .69861 .90311 L .70221 .9009 L F
.69912 .89926 m .69751 .89977 L .69861 .90311 L F
.69996 .89292 m .69792 .89863 L .69912 .89926 L F
.69912 .89926 m .69748 .8987 L .69851 .89988 L 0 .606 .252 r
F
.69792 .89863 m .69748 .8987 L .69877 .89914 L F
.69792 .89863 m .69877 .89914 L .69912 .89926 L F
.69298 .89958 m .68994 .90196 L .69374 .90349 L 0 .714 .353 r
F
.69298 .89958 m .6896 .90029 L .68994 .90196 L F
.68998 .90113 m .69751 .89977 L .69792 .89863 L 0 1 .377 r
F
.69511 .89691 m .697 .89806 L .69996 .89292 L F
.697 .89806 m .69797 .89849 L .69996 .89292 L F
.69486 .89712 m .69792 .89863 L .69511 .89691 L F
.697 .89806 m .69792 .89863 L .69797 .89849 L F
.69486 .89712 m .69792 .89863 L .70011 .89824 L 0 .515 .231 r
F
.69393 .89692 m .69792 .89863 L .69486 .89712 L F
.69782 .89859 m .69789 .89863 L .69792 .89863 L F
.68983 .89604 m .69792 .89863 L .69393 .89692 L F
.68998 .90113 m .69792 .89863 L .69486 .89712 L 0 1 .377 r
F
.69395 .89666 m .69996 .89292 L .69372 .89655 L F
.69486 .89712 m .69505 .89695 L .69395 .89666 L F
.69505 .89695 m .69996 .89292 L .69395 .89666 L F
.69305 .89642 m .69877 .89037 L .69474 .89384 L F
.68983 .89604 m .69486 .89712 L .69367 .89659 L 0 .515 .231 r
F
.68998 .90113 m .69369 .89659 L .69305 .89642 L 0 1 .377 r
F
.69369 .89659 m .69877 .89037 L .69305 .89642 L F
.69305 .89642 m .69898 .89735 L .69482 .89663 L 0 .515 .231 r
F
.69302 .89642 m .69306 .89642 L .69305 .89642 L F
.69306 .89642 m .69898 .89735 L .69305 .89642 L F
.68983 .89604 m .69369 .89659 L .69302 .89642 L F
.69369 .89659 m .69898 .89735 L .69302 .89642 L F
.69367 .89659 m .70011 .89824 L .69898 .89735 L F
.69486 .89712 m .70011 .89824 L .69367 .89659 L F
.69792 .89863 m .69751 .89977 L .69912 .89926 L 0 1 .413 r
F
.70011 .89824 m .69792 .89863 L .69912 .89926 L 0 .606 .252 r
F
.68998 .90113 m .69486 .89712 L .69372 .89655 L 0 1 .377 r
F
.67953 .89344 m .68858 .89544 L .68441 .89457 L 0 .392 .2 r
F
.685 .89574 m .68441 .89457 L .68858 .89544 L 0 0 0 r
F
.68419 .89569 m .68466 .90369 L .685 .89574 L 0 1 .346 r
F
.68417 .89581 m .68419 .89569 L .685 .89574 L 0 0 0 r
F
.68419 .89569 m .68441 .89457 L .685 .89574 L F
.685 .89574 m .68466 .90369 L .68869 .89955 L 0 1 .346 r
F
.68414 .89485 m .68419 .89569 L .685 .89574 L F
.68414 .89485 m .685 .89574 L .69285 .89075 L F
.685 .89574 m .68869 .89955 L .69045 .89583 L F
.685 .89574 m .68858 .89544 L .69045 .89583 L 0 0 0 r
F
.685 .89574 m .69045 .89583 L .69285 .89075 L 0 1 .346 r
F
.685 .89574 m .69045 .89583 L .6905 .89584 L 0 0 0 r
F
.68417 .89581 m .685 .89574 L .69301 .89637 L F
.685 .89574 m .6905 .89584 L .69301 .89637 L F
.68419 .89567 m .68417 .89572 L .68419 .89572 L 0 1 .346 r
F
.68417 .89572 m .68271 .90168 L .68419 .89572 L F
.68414 .89485 m .68397 .89568 L .68419 .89567 L F
.66572 .91144 m .67121 .9006 L .66946 .90182 L 0 1 .247 r
F
.66572 .91144 m .67547 .89798 L .67121 .9006 L F
.66572 .91144 m .67187 .9099 L .6754 .8988 L F
.66946 .90182 m .67625 .90018 L .67367 .9026 L 0 .121 .022 r
F
.66933 .90216 m .66946 .90182 L .66845 .90284 L 0 1 .247 r
F
.66547 .90107 m .671 .90062 L .66946 .90182 L 0 .121 .022 r
F
.66572 .91144 m .66933 .90216 L .66845 .90284 L 0 1 .247 r
F
.66547 .90107 m .67367 .9026 L .66934 .90336 L 0 .121 .022 r
F
.66946 .90182 m .67339 .89175 L .66861 .90249 L 0 1 .247 r
F
.66946 .90182 m .66861 .90249 L .66845 .90284 L F
.671 .90062 m .67121 .9006 L .66946 .90182 L 0 .121 .022 r
F
.67121 .9006 m .67625 .90018 L .66946 .90182 L F
.66946 .90182 m .67121 .9006 L .66952 .90167 L 0 1 .247 r
F
.66952 .90167 m .67602 .89112 L .67339 .89175 L F
.671 .90062 m .67547 .89798 L .67121 .9006 L 0 .121 .022 r
F
.67482 .89791 m .67537 .89772 L .671 .90062 L F
.67121 .9006 m .67602 .89112 L .66952 .90167 L 0 1 .247 r
F
.67755 .89702 m .67537 .89772 L .67793 .89611 L 0 0 0 r
F
.67741 .89735 m .67547 .89798 L .67755 .89702 L F
.67547 .89798 m .67537 .89772 L .67755 .89702 L F
.67741 .89735 m .67803 .90009 L .68066 .8963 L 0 1 .313 r
F
.67741 .89735 m .6754 .8988 L .67803 .90009 L F
.67625 .90018 m .67741 .89735 L .6822 .8964 L 0 0 0 r
F
.67741 .89735 m .67793 .89611 L .68066 .8963 L F
.67741 .89735 m .68066 .8963 L .6822 .8964 L F
.67602 .89112 m .67547 .89798 L .67741 .89735 L 0 1 .313 r
F
.67547 .89798 m .6754 .8988 L .67741 .89735 L F
.67602 .89112 m .67741 .89735 L .68214 .89416 L F
.67741 .89735 m .68066 .8963 L .68214 .89416 L F
.67625 .90018 m .67547 .89798 L .67741 .89735 L 0 0 0 r
F
.67164 .89975 m .67547 .89798 L .67602 .89112 L 0 1 .247 r
F
.67121 .9006 m .67547 .89798 L .67164 .89975 L F
.67121 .9006 m .67547 .89798 L .67625 .90018 L 0 .121 .022 r
F
.66862 .9023 m .67339 .89175 L .66926 .9003 L 0 1 .247 r
F
.66845 .90284 m .66872 .90223 L .66862 .9023 L F
.66872 .90223 m .67339 .89175 L .66862 .9023 L F
.66547 .90107 m .66722 .89488 L .67151 .89545 L 0 .121 .022 r
F
.66592 .89082 m .66926 .9003 L .67339 .89175 L 0 1 .282 r
F
.66547 .90107 m .66463 .89728 L .66722 .89488 L 0 .121 .022 r
F
.66592 .89082 m .66606 .89991 L .66926 .9003 L 0 1 .282 r
F
.66111 .90667 m .65709 .91307 L .66355 .91385 L 0 1 .509 r
F
.65303 .90055 m .65579 .90784 L .66111 .90667 L 0 1 .5 r
F
.66459 .89856 m .65929 .90166 L .66262 .90402 L 0 .926 .476 r
F
.66459 .89856 m .66013 .89932 L .65929 .90166 L F
.65417 .901 m .66463 .89728 L .66546 .90107 L 0 .254 .061 r
F
.65417 .901 m .66546 .90107 L .66269 .90428 L F
.65417 .901 m .66269 .90428 L .65816 .90475 L F
.65515 .91775 m .66269 .90428 L .66427 .90558 L 0 .237 .085 r
F
.66137 .91013 m .66427 .90558 L .66475 .90599 L F
.65515 .91775 m .66427 .90558 L .66137 .91013 L F
.65515 .91775 m .66475 .90599 L .66427 .90667 L F
.65515 .91775 m .6648 .90603 L .66427 .90679 L F
.65525 .92231 m .66295 .91504 L .66467 .90664 L 0 1 .216 r
F
.66358 .90811 m .66467 .90664 L .6648 .90603 L F
.65525 .92231 m .66467 .90664 L .66358 .90811 L F
.65525 .92231 m .6648 .90603 L .6594 .91371 L F
.65706 .91699 m .65717 .91665 L .65639 .91795 L F
.65515 .91775 m .65861 .91447 L .65708 .9167 L 0 .237 .085 r
F
.65925 .91386 m .66486 .90608 L .6594 .91371 L F
.65515 .91775 m .66379 .90737 L .65925 .91386 L F
.66379 .90737 m .66486 .90608 L .65925 .91386 L F
.65515 .91775 m .65816 .90475 L .66269 .90428 L F
.65515 .91775 m .65708 .9167 L .65645 .91769 L F
.65708 .9167 m .65717 .91665 L .65645 .91769 L F
.65639 .91795 m .65645 .91769 L .65604 .91849 L 0 1 .216 r
F
.65645 .91769 m .66592 .89083 L .66264 .89389 L F
.65639 .91795 m .65652 .91758 L .65645 .91769 L F
.65652 .91758 m .66592 .89083 L .65645 .91769 L F
.65525 .92231 m .65639 .91795 L .65604 .91849 L F
.65525 .92231 m .65706 .91699 L .65639 .91795 L F
.65525 .92231 m .6594 .91371 L .65706 .91699 L F
.66916 .9124 m .66161 .9167 L .66462 .91905 L 0 1 .516 r
F
.66198 .92212 m .65676 .93081 L .66457 .93169 L 0 1 .523 r
F
.66916 .9124 m .66355 .91385 L .66161 .9167 L 0 1 .516 r
F
.65499 .93764 m .66571 .91144 L .66295 .91504 L 0 1 .154 r
F
.65499 .93764 m .66295 .91504 L .65866 .92616 L F
.65525 .92231 m .65866 .92616 L .66295 .91504 L 0 1 .216 r
F
.65602 .91848 m .6632 .91742 L .6587 .92073 L 0 .237 .085 r
F
.65515 .91775 m .65645 .91769 L .65602 .91848 L F
.65645 .91769 m .6632 .91742 L .65602 .91848 L F
.65645 .91769 m .66264 .89389 L .65611 .91824 L 0 1 .216 r
F
.65645 .91769 m .65611 .91824 L .65604 .91849 L F
.66916 .9124 m .66462 .91905 L .67129 .91952 L 0 1 .516 r
F
.66916 .9124 m .67129 .91952 L .6772 .91779 L F
.66916 .9124 m .6772 .91779 L .67917 .91493 L F
.66916 .9124 m .67917 .91493 L .67586 .91286 L F
.66572 .91144 m .66777 .91704 L .67187 .9099 L 0 1 .247 r
F
.66572 .91144 m .66512 .91771 L .66777 .91704 L F
.66198 .92212 m .66457 .93169 L .6715 .92963 L 0 1 .523 r
F
.66198 .92212 m .6715 .92963 L .67376 .9259 L F
.66198 .92212 m .67376 .9259 L .66983 .923 L F
.65499 .93764 m .66512 .91772 L .66571 .91144 L 0 1 .154 r
F
.65645 .91769 m .66642 .91163 L .6632 .91742 L 0 .237 .085 r
F
.65717 .91665 m .6565 .91763 L .65639 .91795 L 0 1 .216 r
F
.65706 .91699 m .65738 .91637 L .65717 .91665 L F
.65708 .9167 m .65834 .91508 L .65717 .91665 L 0 .237 .085 r
F
.65834 .91508 m .6594 .91371 L .65717 .91665 L F
.65861 .91447 m .6594 .91371 L .65708 .9167 L F
.6594 .91371 m .66606 .89992 L .65706 .91699 L 0 1 .216 r
F
.65717 .91665 m .66642 .91163 L .65645 .91769 L 0 .237 .085 r
F
.65717 .91665 m .65655 .91749 L .6565 .91763 L 0 1 .216 r
F
.65717 .91665 m .66592 .89083 L .65655 .91749 L F
.65612 .91811 m .66264 .89389 L .65838 .90711 L F
.65604 .91849 m .65616 .91805 L .65612 .91811 L F
.65616 .91805 m .66264 .89389 L .65612 .91811 L F
.65717 .91665 m .66606 .89992 L .66592 .89083 L F
.65738 .91637 m .66606 .89992 L .65717 .91665 L F
.65717 .91665 m .6594 .91371 L .65723 .91662 L 0 .237 .085 r
F
.65723 .91662 m .66623 .90722 L .66642 .91163 L F
.6594 .91371 m .66623 .90722 L .65723 .91662 L F
.66427 .90667 m .66475 .90599 L .6648 .90603 L F
.66427 .90679 m .6648 .90603 L .66486 .90608 L F
.6594 .91371 m .6648 .90603 L .66606 .89992 L 0 1 .216 r
F
.6594 .91371 m .66486 .90608 L .66623 .90722 L 0 .237 .085 r
F
.65515 .91775 m .65493 .9105 L .65816 .90475 L F
.65374 .89606 m .65838 .90711 L .66264 .89389 L 0 1 .259 r
F
.65818 .8961 m .66861 .894 L .66381 .8878 L 0 1 .333 r
F
.66205 .8835 m .66485 .88642 L .67009 .88978 L 0 .509 .325 r
F
.66861 .894 m .67429 .89137 L .67009 .88978 L 0 1 .432 r
F
.66861 .894 m .67912 .89483 L .67429 .89137 L F
.66205 .8835 m .67429 .89137 L .67531 .89389 L 0 .509 .325 r
F
.66205 .8835 m .66719 .89228 L .66305 .88601 L F
.67625 .90018 m .6822 .8964 L .6861 .89767 L 0 0 0 r
F
.67625 .90018 m .6861 .89767 L .68702 .89907 L F
.67625 .90018 m .68702 .89907 L .68448 .9007 L F
.67625 .90018 m .68448 .9007 L .68016 .90146 L F
.6821 .90888 m .67711 .91027 L .67586 .91286 L 0 1 .501 r
F
.67392 .90892 m .67861 .91048 L .68271 .90168 L 0 1 .282 r
F
.67722 .90648 m .68016 .90146 L .68448 .9007 L 0 0 0 r
F
.67722 .90648 m .67704 .90394 L .68016 .90146 L F
.66861 .894 m .67986 .90204 L .68136 .89784 L 0 1 .432 r
F
.66861 .894 m .68136 .89784 L .67912 .89483 L F
.66205 .8835 m .67246 .89567 L .66719 .89228 L 0 .509 .325 r
F
.66205 .8835 m .67531 .89389 L .67246 .89567 L F
.66186 .8595 m .66719 .89227 L .66305 .88599 L 0 .553 .195 r
F
.66107 .84193 m .66479 .87249 L .66186 .8595 L F
.66479 .87249 m .66719 .89227 L .66186 .8595 L F
.64958 .76307 m .65619 .84747 L .65124 .80298 L 0 .732 .172 r
F
.64969 .76284 m .65619 .84747 L .64958 .76307 L F
.64936 .7648 m .65 .75751 L .64963 .7582 L 0 1 .145 r
F
.64969 .75904 m .66107 .84193 L .65619 .84747 L 0 .732 .172 r
F
.64936 .7648 m .6497 .75632 L .64943 .75783 L 0 1 .145 r
F
.64969 .75904 m .65619 .84747 L .64941 .75919 L 0 .732 .172 r
F
.68198 .75475 m .66824 .77215 L .67064 .77605 L 0 1 .439 r
F
.67319 .76299 m .66752 .76858 L .66622 .77728 L 0 .993 .424 r
F
.65796 .77236 m .66585 .77819 L .66743 .77046 L 0 1 .441 r
F
.65796 .77236 m .66743 .77046 L .66418 .76807 L F
.66947 .75097 m .66418 .76807 L .66743 .77046 L 0 1 .428 r
F
.66947 .75097 m .66506 .75972 L .66418 .76807 L F
.65538 .77436 m .66745 .76627 L .66494 .74549 L 0 1 .29 r
F
.68198 .75475 m .67064 .77605 L .67936 .77284 L 0 1 .439 r
F
.67319 .76299 m .66622 .77728 L .67014 .7833 L 0 .993 .424 r
F
.68861 .76465 m .67423 .78185 L .67663 .78568 L 0 1 .443 r
F
.68861 .76465 m .67936 .77284 L .67423 .78185 L F
.67319 .76299 m .67014 .7833 L .67762 .78376 L 0 .993 .424 r
F
.66585 .77819 m .6681 .79187 L .67373 .78409 L 0 1 .449 r
F
.66585 .77819 m .67373 .78409 L .67553 .77645 L F
.66585 .77819 m .67553 .77645 L .67229 .77405 L F
.65538 .77436 m .66637 .78954 L .66745 .76627 L 0 1 .29 r
F
.67072 .79415 m .6764 .80357 L .68261 .79515 L 0 1 .452 r
F
.67072 .79415 m .68261 .79515 L .68022 .79138 L F
.66806 .79197 m .67576 .80342 L .67866 .79587 L 0 1 .436 r
F
.66806 .79197 m .67866 .79587 L .67548 .79127 L F
.67373 .78409 m .66678 .79997 L .67064 .80299 L 0 1 .457 r
F
.67373 .78409 m .6681 .79187 L .66678 .79997 L F
.66068 .82056 m .67064 .7949 L .66637 .78954 L 0 1 .288 r
F
.67576 .80342 m .6684 .82046 L .67605 .81965 L 0 1 .444 r
F
.66852 .81048 m .66173 .82688 L .66909 .82353 L 0 1 .477 r
F
.67576 .80342 m .67605 .81965 L .68344 .81426 L 0 1 .444 r
F
.66852 .81048 m .66909 .82353 L .67611 .81665 L 0 1 .477 r
F
.66852 .81048 m .67611 .81665 L .67903 .80961 L F
.66852 .81048 m .67903 .80961 L .67589 .80712 L F
.68861 .76465 m .67663 .78568 L .68562 .78247 L 0 1 .443 r
F
.68369 .77835 m .67548 .79127 L .67866 .79587 L 0 1 .435 r
F
.68369 .77835 m .67762 .78377 L .67548 .79127 L F
.67373 .78409 m .67064 .80299 L .67804 .79953 L 0 1 .457 r
F
.66068 .82056 m .67238 .81228 L .67064 .7949 L 0 1 .288 r
F
.65538 .77436 m .66241 .79977 L .66637 .78954 L 0 1 .29 r
F
.65538 .77436 m .6577 .79325 L .66241 .79977 L F
.66068 .82056 m .66637 .78954 L .66241 .79977 L 0 1 .288 r
F
.66451 .82778 m .67546 .83083 L .67264 .82675 L 0 1 .453 r
F
.68344 .81426 m .67546 .83083 L .68337 .8299 L F
.68344 .81426 m .67264 .82675 L .67546 .83083 L F
.68344 .81426 m .67605 .81965 L .67264 .82675 L F
.67611 .81665 m .66871 .83301 L .67632 .82972 L 0 1 .482 r
F
.67611 .81665 m .66592 .83054 L .66871 .83301 L F
.67611 .81665 m .66909 .82353 L .66592 .83054 L F
.66068 .82056 m .67067 .83309 L .67238 .81228 L 0 1 .288 r
F
.6648 .83939 m .66312 .85167 L .67148 .84562 L 0 1 .496 r
F
.67129 .83796 m .67804 .84766 L .6825 .84071 L 0 1 .461 r
F
.6648 .83939 m .67148 .84562 L .67568 .83922 L 0 1 .496 r
F
.67129 .83796 m .6825 .84071 L .67969 .83682 L 0 1 .461 r
F
.6648 .83939 m .67568 .83922 L .67289 .83672 L 0 1 .496 r
F
.66068 .82056 m .66662 .84345 L .67067 .83309 L 0 1 .288 r
F
.66068 .82056 m .66233 .83808 L .66662 .84345 L F
.65 .75751 m .66253 .79034 L .66107 .84193 L 0 .732 .172 r
F
.64904 .75015 m .65104 .7561 L .65 .75751 L F
.65104 .7561 m .66253 .79034 L .65 .75751 L F
.65 .75751 m .65104 .7561 L .65004 .75705 L 0 1 .145 r
F
.64963 .7582 m .65004 .75705 L .64965 .75777 L F
.65 .75751 m .65004 .75705 L .64963 .7582 L F
.64963 .7582 m .6501 .75825 L .64969 .75904 L 0 .732 .172 r
F
.65 .75751 m .6501 .75825 L .64963 .7582 L F
.6501 .75825 m .66107 .84193 L .64969 .75904 L F
.64904 .75015 m .66025 .73849 L .65469 .74859 L F
.65237 .75756 m .66025 .73901 L .66025 .73856 L 0 1 .145 r
F
.65243 .75752 m .66025 .73901 L .65237 .75756 L F
.64904 .75015 m .66062 .74697 L .65104 .7561 L 0 .732 .172 r
F
.64965 .75777 m .65715 .67633 L .65252 .6871 L 0 1 .145 r
F
.65004 .75705 m .65715 .67633 L .64965 .75777 L F
.65004 .75705 m .66052 .70689 L .65715 .67633 L F
.65104 .7561 m .66052 .70689 L .65004 .75705 L F
.64943 .75783 m .64958 .75423 L .6495 .7503 L F
.64958 .75423 m .65252 .6871 L .6495 .7503 L F
.64904 .75015 m .64969 .75904 L .64941 .75919 L 0 .732 .172 r
F
.6497 .75632 m .65252 .6871 L .64943 .75783 L 0 1 .145 r
F
.64771 .75661 m .64776 .75808 L .64967 .7324 L 0 .729 .063 r
F
.64187 .73832 m .64604 .76314 L .64485 .76853 L 0 .659 .2 r
F
.64187 .73832 m .64485 .76853 L .64448 .76885 L F
.64187 .73832 m .64448 .76885 L .64443 .76889 L F
.63854 .73365 m .64187 .73832 L .64443 .76889 L F
.63841 .73286 m .63842 .73289 L .63854 .73365 L F
.63842 .73289 m .64187 .73832 L .63854 .73365 L F
.63938 .7754 m .64527 .76948 L .64485 .76853 L 0 1 .317 r
F
.63928 .77553 m .64485 .76853 L .64436 .76896 L F
.64446 .76946 m .64448 .76949 L .6445 .76964 L 0 .659 .2 r
F
.63853 .73507 m .64435 .76896 L .64045 .77048 L F
.63934 .77525 m .64436 .76896 L .64045 .77048 L 0 1 .317 r
F
.63928 .77553 m .63941 .77536 L .63934 .77525 L F
.63941 .77536 m .64436 .76896 L .63934 .77525 L F
.63857 .73382 m .64436 .76896 L .63853 .73507 L 0 .659 .2 r
F
.64436 .76896 m .64435 .76896 L .63853 .73507 L F
.63841 .73286 m .64443 .76889 L .64439 .76893 L F
.64436 .76896 m .6445 .76877 L .6443 .76886 L 0 1 .317 r
F
.6441 .76906 m .6443 .76886 L .64045 .77048 L F
.64436 .76896 m .6443 .76886 L .6441 .76906 L F
.64438 .76896 m .64448 .76949 L .64446 .76946 L 0 .659 .2 r
F
.63841 .73286 m .6444 .76896 L .64438 .76896 L F
.6444 .76896 m .64448 .76949 L .64438 .76896 L F
.64045 .77048 m .64399 .76899 L .64047 .77042 L 0 1 .317 r
F
.64446 .76946 m .6445 .76964 L .64449 .76964 L 0 .659 .2 r
F
.64443 .76889 m .64456 .76983 L .6445 .76965 L F
.64448 .76885 m .64456 .76983 L .64443 .76889 L F
.64448 .76885 m .64485 .76853 L .64456 .76983 L F
.64447 .76963 m .6446 .76965 L .6445 .7688 L 0 .724 .238 r
F
.63932 .77549 m .64527 .76948 L .63938 .7754 L 0 1 .317 r
F
.63928 .77553 m .64173 .78069 L .64659 .77725 L F
.64047 .77146 m .64447 .76963 L .64047 .77078 L 0 .724 .238 r
F
.64004 .81272 m .6444 .77119 L .6438 .77123 L 0 .622 .253 r
F
.64037 .78118 m .6438 .77123 L .64047 .77146 L F
.64004 .81272 m .6438 .77123 L .64037 .78118 L F
.64446 .76979 m .64447 .76963 L .64446 .76979 L 0 .724 .238 r
F
.6444 .77119 m .64458 .77009 L .64445 .77009 L F
.64004 .81272 m .65022 .80394 L .64493 .77244 L 0 .622 .253 r
F
.64004 .81272 m .64493 .77244 L .64456 .77157 L F
.64004 .81272 m .64456 .77157 L .6444 .77119 L F
.64437 .85375 m .64119 .86508 L .65014 .86001 L 0 1 .508 r
F
.63476 .81461 m .64207 .87082 L .64612 .85291 L 0 .854 .256 r
F
.64801 .88036 m .64789 .87821 L .65212 .88092 L 0 .049 0 r
F
.65178 .88868 m .65044 .88495 L .65272 .88376 L 0 .203 .009 r
F
.65034 .85376 m .65192 .87277 L .65627 .87628 L 0 1 .27 r
F
.64699 .88627 m .64263 .88863 L .64597 .89142 L 0 .73 .44 r
F
.64699 .88627 m .64306 .88643 L .64263 .88863 L F
.64641 .87998 m .64361 .88124 L .64723 .88404 L 0 .437 .309 r
F
.64641 .87998 m .64326 .8795 L .64361 .88124 L F
.63713 .87222 m .64613 .87796 L .64801 .88036 L 0 .154 0 r
F
.63713 .87222 m .64613 .8798 L .64173 .87667 L F
.63713 .87222 m .64801 .88036 L .64613 .8798 L F
.64058 .88223 m .64173 .87667 L .64613 .8798 L 0 .303 .033 r
F
.64058 .88223 m .64613 .8798 L .65044 .88495 L F
.64058 .88223 m .65044 .88495 L .65178 .88868 L F
.64699 .88627 m .64597 .89142 L .65161 .89316 L 0 .73 .44 r
F
.64058 .88223 m .6494 .88973 L .64489 .88739 L 0 .303 .033 r
F
.64058 .88223 m .65178 .88868 L .6494 .88973 L F
.64281 .89807 m .64207 .89095 L .64489 .88739 L 0 .362 .084 r
F
.64017 .90051 m .65034 .85376 L .64612 .85291 L 0 1 .249 r
F
.64801 .88036 m .64613 .87796 L .64789 .87821 L 0 .049 0 r
F
.64492 .89396 m .64198 .89998 L .64801 .90144 L 0 .945 .489 r
F
.64492 .89396 m .64801 .90144 L .65303 .90055 L F
.64281 .89807 m .64489 .88739 L .6494 .88973 L 0 .362 .084 r
F
.64017 .90051 m .65192 .87277 L .65034 .85376 L 0 1 .249 r
F
.65303 .90055 m .64652 .90408 L .64955 .90673 L 0 1 .5 r
F
.65303 .90055 m .64801 .90144 L .64652 .90408 L F
.64281 .89807 m .6494 .88973 L .65338 .89555 L 0 .362 .084 r
F
.64281 .89807 m .65338 .89555 L .65417 .901 L F
.64281 .89807 m .65135 .9046 L .64679 .90393 L F
.64281 .89807 m .65417 .901 L .65135 .9046 L F
.64017 .90051 m .65006 .90242 L .65192 .87277 L 0 1 .249 r
F
.64004 .81272 m .65342 .89324 L .65379 .8518 L 0 .622 .253 r
F
.65316 .84885 m .65379 .8518 L .6538 .85059 L F
.64004 .81272 m .65379 .8518 L .65316 .84885 L F
.65023 .80448 m .6538 .85083 L .65455 .85542 L 0 .484 .258 r
F
.65784 .87101 m .65455 .85542 L .65964 .88674 L F
.65023 .80448 m .65455 .85542 L .65784 .87101 L F
.64058 .88223 m .63935 .8777 L .64173 .87667 L 0 .303 .033 r
F
.64017 .90051 m .64612 .85291 L .64207 .87082 L 0 1 .249 r
F
.64383 .92238 m .64679 .90393 L .65135 .9046 L 0 .367 .112 r
F
.64383 .92238 m .64357 .91152 L .64679 .90393 L F
.64017 .90051 m .64595 .92299 L .65006 .90242 L 0 1 .249 r
F
.64004 .81272 m .6493 .90297 L .65342 .89324 L 0 .622 .253 r
F
.64004 .81272 m .64355 .86816 L .6493 .90297 L F
.63476 .81461 m .63719 .85429 L .64207 .87082 L 0 .854 .256 r
F
.63028 .84428 m .64355 .86816 L .64004 .81272 L 0 .722 .24 r
F
.64093 .8565 m .65057 .81995 L .6446 .76965 L 0 .724 .238 r
F
.64456 .77157 m .64465 .77076 L .6444 .77119 L 0 .622 .253 r
F
.641 .85488 m .64453 .77148 L .64103 .85403 L 0 .724 .238 r
F
.64453 .77148 m .6446 .76965 L .64453 .77148 L F
.64453 .77148 m .64453 .77148 L .64103 .85403 L F
.64103 .85403 m .64453 .77148 L .6444 .77119 L F
.64453 .77148 m .64458 .77009 L .6444 .77119 L F
.64456 .77157 m .64493 .77244 L .64465 .77076 L 0 .622 .253 r
F
.6444 .77119 m .64465 .77076 L .64453 .77002 L F
.64446 .76979 m .64446 .76979 L .6444 .7712 L 0 .724 .238 r
F
.6444 .7712 m .6444 .7712 L .6409 .85105 L F
.64446 .76979 m .6444 .7712 L .6444 .7712 L F
.64103 .85403 m .64446 .76979 L .6409 .85105 L F
.64047 .77146 m .64418 .77014 L .64048 .77096 L 0 .622 .253 r
F
.6444 .77119 m .64447 .76963 L .64047 .77146 L 0 .724 .238 r
F
.64418 .77014 m .64453 .77002 L .64419 .7701 L 0 .622 .253 r
F
.64418 .77014 m .64419 .7701 L .64048 .77096 L F
.64447 .76937 m .64452 .7691 L .64449 .76914 L 0 .385 .231 r
F
.64446 .76918 m .64452 .7691 L .64452 .76914 L 0 .283 .182 r
F
.6444 .77119 m .64453 .77002 L .64047 .77146 L 0 .622 .253 r
F
.64447 .76937 m .64452 .76952 L .64452 .7691 L 0 .385 .231 r
F
.64045 .77048 m .6442 .77003 L .64048 .77094 L 0 .659 .2 r
F
.6442 .77003 m .64453 .77 L .6442 .77007 L F
.6442 .77003 m .6442 .77007 L .64048 .77094 L F
.6409 .85105 m .6444 .77119 L .64047 .77146 L 0 .724 .238 r
F
.64436 .76896 m .64447 .76963 L .64435 .76896 L 0 .659 .2 r
F
.64447 .76963 m .64447 .76963 L .64435 .76896 L F
.64435 .76896 m .64453 .77 L .64045 .77048 L F
.64439 .76893 m .64443 .76889 L .64448 .76949 L F
.64433 .76881 m .64449 .76966 L .64447 .76963 L F
.63841 .73286 m .64433 .76871 L .64433 .76881 L F
.64433 .76871 m .64449 .76966 L .64433 .76881 L F
.64447 .76963 m .644 .76904 L .64047 .77078 L 0 .724 .238 r
F
.64423 .76928 m .64048 .77092 L .6442 .77006 L 0 .385 .231 r
F
.64046 .77059 m .64048 .77092 L .64446 .76918 L F
.64385 .77005 m .64111 .77036 L .64392 .76936 L 0 .283 .182 r
F
.64316 .77005 m .64293 .77038 L .6442 .77008 L 0 1 .486 r
F
.63476 .81461 m .63791 .81668 L .63875 .80942 L 0 .854 .256 r
F
.63028 .84428 m .64004 .81272 L .63452 .77367 L 0 .722 .24 r
F
.63713 .87222 m .63729 .86999 L .64154 .87352 L 0 .154 0 r
F
.64017 .90051 m .6417 .92218 L .64595 .92299 L 0 1 .249 r
F
.63028 .84428 m .64356 .93952 L .64355 .86816 L 0 .722 .24 r
F
.63028 .84428 m .63999 .97888 L .64356 .93952 L F
.63028 .84428 m .63425 .93728 L .63999 .97888 L F
.63161 .91104 m .64093 .8565 L .63444 .77265 L 0 .689 .233 r
F
.63175 1.01449 m .63171 1.01192 L .6246 .89409 L 0 .644 .229 r
F
.61717 .96151 m .61674 .62252 L .61838 .74622 L 0 .61 .226 r
F
.63197 1.15931 m .62893 1.14442 L .62957 1.1325 L 0 .593 .124 r
F
.64828 1.06784 m .64094 1.06537 L .64902 1.06749 L 0 .362 .189 r
F
.64828 1.06784 m .63787 1.06428 L .64094 1.06537 L F
.64828 1.06784 m .64101 1.06533 L .63787 1.06428 L F
.6308 1.2213 m .63858 1.04005 L .64029 1.01097 L 0 .176 .162 r
F
.6308 1.2213 m .64029 1.01097 L .63858 1.00969 L F
.6308 1.2213 m .63121 1.1552 L .63456 1.07791 L F
.6308 1.2213 m .6353 1.08553 L .63258 1.19075 L F
.63096 1.13832 m .63258 1.19075 L .6353 1.08553 L 0 1 .192 r
F
.63027 1.35972 m .63331 1.2995 L .63843 1.3029 L 0 .452 .178 r
F
.63027 1.35972 m .6291 1.31213 L .63331 1.2995 L F
.63027 1.35972 m .62778 1.33789 L .6291 1.31213 L F
.62548 1.36181 m .63108 1.29229 L .63601 1.31942 L 0 .696 .195 r
F
.62548 1.36181 m .62625 1.29219 L .63108 1.29229 L F
.63027 1.35972 m .63843 1.3029 L .64109 1.32014 L 0 .452 .178 r
F
.63027 1.35972 m .64109 1.32014 L .63983 1.34601 L F
.63027 1.35972 m .63983 1.34601 L .63545 1.36323 L F
.63583 1.41814 m .63545 1.36323 L .63983 1.34601 L 0 .403 .187 r
F
.62548 1.36181 m .63601 1.31942 L .63778 1.35592 L 0 .696 .195 r
F
.63538 1.41819 m .63545 1.36323 L .63583 1.41814 L 0 .403 .187 r
F
.63538 1.41819 m .63374 1.39679 L .63545 1.36323 L F
.62548 1.36181 m .63778 1.35592 L .63541 1.38619 L 0 .696 .195 r
F
.62548 1.36181 m .63541 1.38619 L .63045 1.38963 L F
.62525 1.38259 m .62805 1.11357 L .63121 1.1552 L 0 .442 .218 r
F
.62869 1.30298 m .63121 1.1552 L .6308 1.2213 L F
.62665 1.3818 m .62862 1.28393 L .62869 1.30298 L F
.62862 1.28393 m .63121 1.1552 L .62869 1.30298 L F
.62525 1.38259 m .63121 1.1552 L .62665 1.3818 L F
.62711 1.38068 m .6308 1.2213 L .62926 1.37847 L F
.62665 1.3818 m .6308 1.2213 L .62711 1.38068 L F
.62864 1.31368 m .62813 1.27078 L .62805 1.29544 L 0 .646 .228 r
F
.62365 1.38285 m .62805 1.11357 L .62525 1.38259 L 0 .442 .218 r
F
.62726 1.26712 m .62039 .88844 L .61796 .9335 L 0 .646 .228 r
F
.62805 1.29544 m .62736 1.25892 L .62726 1.26712 L F
.62736 1.25892 m .62039 .88844 L .62726 1.26712 L F
.62805 1.29544 m .61796 .9335 L .6172 .96046 L F
.62871 1.31958 m .62838 1.24245 L .62769 1.23277 L 0 .581 .001 r
F
.6175 .90343 m .61838 .74622 L .61973 .84744 L 0 .61 .226 r
F
.6194 .6549 m .61929 .62853 L .62255 .67132 L 0 .586 .223 r
F
.62154 .65464 m .62012 .65866 L .62255 .67132 L 0 .459 .231 r
F
.62435 .78333 m .62595 .72649 L .62617 .72996 L 0 .586 .223 r
F
.62419 .78368 m .62595 .72649 L .62435 .78333 L F
.6223 .83997 m .62595 .72649 L .62284 .82766 L F
.62284 .82766 m .62419 .78368 L .62435 .78333 L F
.62363 .88232 m .62194 .84997 L .62186 .85109 L 0 .644 .229 r
F
.6222 .84642 m .6223 .83997 L .62284 .82766 L 0 .586 .223 r
F
.62194 .84997 m .6246 .89409 L .62283 .83794 L 0 .644 .229 r
F
.62201 .85198 m .62212 .8475 L .6222 .84642 L 0 .586 .223 r
F
.62212 .8475 m .6223 .83997 L .6222 .84642 L F
.62427 .85341 m .62973 .78929 L .62542 .79488 L 0 .814 .24 r
F
.62283 .83794 m .6246 .89409 L .63155 .9121 L 0 .644 .229 r
F
.62079 .85866 m .62017 .84049 L .62088 .8491 L 0 .586 .223 r
F
.63096 1.13832 m .63303 1.1132 L .63113 1.11109 L 0 1 .192 r
F
.63112 1.11295 m .63175 1.01449 L .62177 .85219 L 0 .644 .229 r
F
.62079 .85866 m .62255 .67132 L .62177 .85219 L 0 .586 .223 r
F
.62131 .85524 m .62177 .85219 L .62025 .82747 L 0 .644 .229 r
F
.63112 1.11295 m .62177 .85219 L .62131 .85524 L F
.62255 .67132 m .62301 .73888 L .62469 .70647 L 0 .459 .231 r
F
.62474 .69281 m .62255 .67132 L .62572 .70585 L F
.62474 .69281 m .62572 .70585 L .62583 .70578 L F
.62177 .85219 m .62255 .67132 L .62605 .70564 L 0 .586 .223 r
F
.62087 .85698 m .62025 .82747 L .6201 .83712 L 0 .644 .229 r
F
.63414 1.27916 m .63538 1.23712 L .64065 1.23838 L 0 .375 .155 r
F
.63414 1.27916 m .64065 1.23838 L .64394 1.24971 L F
.63414 1.27916 m .64394 1.24971 L .64344 1.26775 L F
.63538 1.22243 m .64475 1.2133 L .64102 1.22279 L 0 .312 .127 r
F
.64394 1.24971 m .64102 1.22279 L .64475 1.2133 L 0 .289 .138 r
F
.64394 1.24971 m .64065 1.23838 L .64102 1.22279 L F
.63414 1.27916 m .6316 1.24673 L .63538 1.23712 L 0 .375 .155 r
F
.63313 1.27188 m .63744 1.21898 L .6425 1.23373 L 0 .629 .179 r
F
.63313 1.27188 m .63291 1.22224 L .63744 1.21898 L F
.63414 1.27916 m .64344 1.26775 L .63946 1.28047 L 0 .375 .155 r
F
.64394 1.24971 m .64475 1.2133 L .65015 1.2125 L 0 .289 .138 r
F
.64394 1.24971 m .65015 1.2125 L .65363 1.22092 L F
.64394 1.24971 m .65363 1.22092 L .65332 1.23653 L F
.64394 1.24971 m .65332 1.23653 L .64938 1.24892 L F
.63313 1.27188 m .6425 1.23373 L .64472 1.25685 L 0 .629 .179 r
F
.64109 1.32013 m .64344 1.26775 L .6485 1.26785 L 0 .328 .164 r
F
.64109 1.32013 m .63946 1.28047 L .64344 1.26775 L F
.63313 1.27188 m .64472 1.25685 L .6429 1.27973 L 0 .629 .179 r
F
.64109 1.32013 m .63844 1.30289 L .63946 1.28047 L 0 .328 .164 r
F
.63313 1.27188 m .6429 1.27973 L .63822 1.28694 L 0 .629 .179 r
F
.64109 1.32013 m .6485 1.26785 L .65129 1.28071 L 0 .328 .164 r
F
.64109 1.32013 m .65129 1.28071 L .65032 1.30318 L F
.64109 1.32013 m .65032 1.30318 L .6462 1.32027 L F
.63778 1.35592 m .6429 1.27973 L .64775 1.2962 L 0 .57 .194 r
F
.63778 1.35592 m .63822 1.28694 L .6429 1.27973 L F
.63778 1.35592 m .63601 1.31942 L .63822 1.28694 L F
.64694 1.36932 m .65032 1.30318 L .65508 1.30115 L 0 .287 .169 r
F
.64694 1.36932 m .6462 1.32027 L .65032 1.30318 L F
.64694 1.36932 m .64473 1.34858 L .6462 1.32027 L F
.63619 1.41809 m .63983 1.34601 L .64473 1.34859 L 0 .403 .187 r
F
.63583 1.41814 m .63983 1.34601 L .63619 1.41809 L F
.63778 1.35592 m .64775 1.2962 L .64956 1.32566 L 0 .57 .194 r
F
.63663 1.418 m .64473 1.34859 L .64694 1.36933 L 0 .403 .187 r
F
.63619 1.41809 m .64473 1.34859 L .63663 1.418 L F
.63778 1.35592 m .64956 1.32566 L .64741 1.35862 L 0 .57 .194 r
F
.63778 1.35592 m .64741 1.35862 L .64268 1.37288 L F
.64111 1.37542 m .62116 .85115 L .62087 .85698 L 0 .644 .229 r
F
.62116 .85115 m .62025 .82747 L .62087 .85698 L F
.62964 .89581 m .6303 .84523 L .62941 .85545 L 0 1 .192 r
F
.62964 .89581 m .62941 .85545 L .62711 .79435 L 0 .644 .229 r
F
.62964 .89581 m .62941 .85545 L .62907 .85946 L 0 1 .192 r
F
.62283 .83794 m .62964 .89581 L .62711 .79435 L 0 .644 .229 r
F
.62964 .89581 m .63155 .9121 L .62941 .85545 L F
.62283 .83794 m .62674 .73908 L .62687 .79681 L 0 .586 .223 r
F
.62605 .70564 m .62711 .7211 L .62771 .73834 L 0 .459 .231 r
F
.62605 .70564 m .62771 .73834 L .62901 .77616 L F
.62674 .73908 m .62731 .72466 L .62718 .74618 L 0 .586 .223 r
F
.62674 .73908 m .62901 .77616 L .62748 .75102 L 0 .459 .231 r
F
.62674 .73908 m .62718 .74618 L .62687 .79681 L 0 .586 .223 r
F
.62731 .72466 m .62778 .71495 L .62701 .80581 L F
.6268 .80745 m .62701 .80581 L .62628 .89152 L F
.62731 .72466 m .62701 .80581 L .6268 .80745 L F
.62731 .72466 m .62781 .71212 L .62778 .71495 L F
.62779 .71123 m .63435 .7723 L .63033 .77314 L 0 .625 .212 r
F
.62784 .71169 m .63841 .73286 L .63449 .7723 L F
.63433 .77189 m .63445 .77273 L .63441 .77267 L F
.62784 .71169 m .63433 .77161 L .63433 .77189 L F
.63433 .77161 m .63445 .77273 L .63433 .77189 L F
.63109 1.11858 m .6212 .8654 L .63096 1.13832 L 0 .644 .229 r
F
.6212 .8654 m .62119 .8656 L .63096 1.13832 L F
.62101 .86048 m .62091 .85965 L .63096 1.13832 L F
.62022 .85394 m .62017 .84049 L .62079 .85866 L 0 .586 .223 r
F
.6201 .83712 m .62007 .83882 L .62079 .85866 L 0 .644 .229 r
F
.62091 .85965 m .62079 .85866 L .63096 1.13832 L F
.6201 .83712 m .62079 .85866 L .62091 .85965 L F
.62022 .85394 m .61969 .83466 L .62017 .84049 L 0 .586 .223 r
F
.6205 .88627 m .61999 .86146 L .62046 .88701 L 0 .646 .228 r
F
.61999 .86146 m .61992 .8638 L .6202 .87872 L F
.62143 .86907 m .62181 .85551 L .62201 .85198 L 0 .586 .223 r
F
.62046 .88701 m .62039 .88844 L .62736 1.25892 L 0 .646 .228 r
F
.62737 1.25862 m .62736 1.25892 L .62805 1.29544 L F
.62046 .88701 m .62736 1.25892 L .62737 1.25862 L F
.62891 1.19747 m .62838 1.24245 L .63258 1.19075 L 0 1 .192 r
F
.63349 1.37577 m .62891 1.19747 L .63065 1.3758 L 0 .644 .229 r
F
.62025 .86054 m .61987 .85099 L .62022 .85394 L 0 .586 .223 r
F
.62025 .86054 m .61999 .86146 L .62769 1.23277 L 0 .644 .229 r
F
.62029 .87772 m .6202 .87872 L .62039 .88844 L 0 .646 .228 r
F
.61999 .86146 m .6202 .87872 L .62029 .87772 L F
.61717 .96151 m .6175 .90343 L .61982 .85428 L 0 .61 .226 r
F
.6193 .88587 m .61982 .85428 L .61994 .8633 L F
.61717 .96151 m .61982 .85428 L .6193 .88587 L F
.61696 .95873 m .6145 .90742 L .6167 .62202 L F
.6288 1.34046 m .62838 1.24245 L .62871 1.31958 L 0 .581 .001 r
F
.62879 1.33773 m .61717 .96151 L .61657 1.06925 L 0 .646 .228 r
F
.62871 1.31958 m .61717 .96151 L .62879 1.33773 L F
.6288 1.34046 m .62871 1.31958 L .62886 1.35401 L 0 .581 .001 r
F
.62895 1.3761 m .61427 1.01867 L .62205 1.3772 L 0 .646 .228 r
F
.62895 1.37617 m .6288 1.34046 L .62886 1.35401 L 0 .581 .001 r
F
.62895 1.37617 m .62886 1.35401 L .62895 1.3761 L F
.62898 1.37804 m .62887 1.35226 L .62895 1.37617 L F
.62887 1.35226 m .62838 1.24245 L .6288 1.34046 L F
.62894 1.37246 m .6288 1.34046 L .62895 1.37617 L F
.62887 1.35226 m .6288 1.34046 L .62894 1.37246 L F
.63065 1.3758 m .62869 1.31524 L .63052 1.37585 L 0 .646 .228 r
F
.61446 .92666 m .61145 .4636 L .6145 .90742 L 0 .61 .226 r
F
.61445 .93364 m .6144 .92583 L .61446 .92666 L F
.6144 .92583 m .61145 .4636 L .61446 .92666 L F
.62869 1.31524 m .61728 .96291 L .62871 1.31958 L 0 .646 .228 r
F
.61445 .93364 m .61002 .5127 L .61196 .54449 L 0 .61 .226 r
F
.61427 1.01867 m .61002 .5127 L .61445 .93364 L F
.6145 .90742 m .6124 .55162 L .61515 .59665 L F
.6145 .90742 m .61515 .59665 L .6167 .62202 L F
.62885 1.35252 m .61427 1.01867 L .62895 1.3761 L 0 .646 .228 r
F
.61657 1.06925 m .61717 .96151 L .61427 1.01867 L F
.63052 1.37585 m .61427 1.01867 L .62988 1.37595 L F
.60242 .59228 m .60216 .57236 L .6017 .61138 L 0 1 .196 r
F
.60242 .59228 m .6017 .61138 L .60526 .96512 L F
.59869 .33723 m .59984 .38886 L .60375 .41106 L 0 .854 .242 r
F
.60374 .43965 m .6019 .40795 L .60199 .31205 L 0 .727 .225 r
F
.6019 .40795 m .59706 .32481 L .60199 .31205 L F
.59669 .3648 m .59569 .28048 L .59545 .27977 L 0 .267 .202 r
F
.59706 .32481 m .59565 .30053 L .59686 .30272 L 0 .727 .225 r
F
.59706 .32481 m .59686 .30272 L .60199 .31205 L F
.60179 .82192 m .60152 .79758 L .60177 .82156 L 0 1 .196 r
F
.59686 .30272 m .59565 .30053 L .5968 .29663 L 0 .727 .225 r
F
.60112 .45417 m .60166 .48921 L .60522 .50426 L 0 .942 .247 r
F
.60206 .53466 m .60207 .56007 L .60526 .57098 L 0 1 .254 r
F
.6017 .61138 m .59565 .30053 L .60374 .43965 L 0 .727 .225 r
F
.60063 .63962 m .59891 .52429 L .60162 .61362 L F
.59825 .53159 m .59669 .3648 L .59806 .52955 L 0 .267 .202 r
F
.59891 .52429 m .59584 .3194 L .59809 .43371 L 0 .727 .225 r
F
.59891 .52429 m .59809 .43371 L .60162 .61362 L F
.60212 .83203 m .60202 .82446 L .60526 .96512 L 0 .223 .192 r
F
.60202 .82446 m .60045 .70938 L .60204 .79362 L F
.60202 .82446 m .60204 .79362 L .60526 .96512 L F
.60152 .79758 m .60083 .73602 L .60159 .80537 L 0 1 .196 r
F
.59565 .29975 m .59564 .29957 L .59565 .29975 L 0 .267 .202 r
F
.59565 .30053 m .59548 .27986 L .60156 .28043 L 0 .727 .225 r
F
.60242 .59228 m .60093 .2795 L .59836 .27878 L 0 1 .196 r
F
.60778 1.0053 m .60359 .56136 L .60242 .59228 L F
.60359 .56136 m .60093 .2795 L .60242 .59228 L F
.59584 .3194 m .59581 .31669 L .59807 .43151 L 0 .727 .225 r
F
.59584 .3194 m .59807 .43151 L .59808 .43302 L F
.59809 .43371 m .60163 .61329 L .60162 .61362 L F
.59584 .3194 m .59808 .43302 L .59809 .43371 L F
.59808 .43302 m .60163 .61329 L .59809 .43371 L F
.60159 .80537 m .60088 .74176 L .6016 .80584 L 0 1 .196 r
F
.60088 .74176 m .60084 .73843 L .60089 .7421 L F
.59954 .6356 m .59851 .5792 L .59928 .61511 L 0 .223 .192 r
F
.60123 .67926 m .59884 .61858 L .59584 .3194 L 0 .727 .225 r
F
.60102 .70919 m .60032 .68027 L .60123 .67926 L F
.60032 .68027 m .59884 .61858 L .60004 .64905 L F
.60032 .68027 m .60004 .64905 L .60123 .67926 L F
.60085 .73912 m .60026 .721 L .60077 .73421 L F
.59985 .71854 m .59903 .63206 L .6009 .7671 L 0 .267 .202 r
F
.59985 .71854 m .6009 .7671 L .6011 .78182 L F
.59985 .71854 m .6011 .78182 L .60111 .78235 L F
.6011 .78182 m .6011 .78191 L .60111 .78235 L F
.59988 .72091 m .59985 .71854 L .60112 .78303 L F
.59985 .71854 m .60111 .78244 L .60112 .78303 L F
.60111 .7825 m .60111 .78244 L .60112 .78299 L 0 .727 .225 r
F
.60141 .80229 m .6014 .80121 L .60127 .79302 L 0 1 .196 r
F
.6014 .80121 m .60098 .75988 L .60127 .7924 L F
.6014 .80121 m .60127 .7924 L .60127 .79302 L F
.60098 .75988 m .60098 .76024 L .60127 .79239 L F
.60127 .7924 m .60127 .79239 L .60127 .79302 L F
.60098 .75988 m .60127 .79239 L .60127 .7924 L F
.6011 .78182 m .6009 .7671 L .6011 .78191 L 0 .267 .202 r
F
.60111 .78235 m .6011 .78191 L .60111 .78244 L F
.60112 .78295 m .59975 .70528 L .60085 .73912 L 0 .727 .225 r
F
.60112 .78299 m .60112 .78281 L .60112 .78295 L F
.60112 .78281 m .59975 .70528 L .60112 .78295 L F
.59975 .71353 m .59884 .61858 L .59985 .7184 L 0 .267 .202 r
F
.59975 .71353 m .59985 .7184 L .59988 .72091 L F
.59986 .72035 m .59975 .70944 L .59978 .71539 L 0 .223 .192 r
F
.60194 .83641 m .6004 .74706 L .59986 .72035 L F
.59884 .61858 m .59897 .62796 L .59988 .72091 L 0 .267 .202 r
F
.60077 .73421 m .59953 .66838 L .59896 .62676 L 0 .727 .225 r
F
.60201 .84106 m .60201 .83366 L .6025 .85975 L 0 .223 .192 r
F
.60304 .90288 m .60201 .84106 L .60279 .91082 L 0 1 .196 r
F
.60336 .89258 m .60201 .84106 L .60304 .90288 L F
.60204 .84222 m .60201 .84036 L .60201 .84106 L F
.60242 .85382 m .60212 .83203 L .60324 .888 L 0 .223 .192 r
F
.60389 .93492 m .60388 .91263 L .60336 .89258 L 0 1 .196 r
F
.60875 1.32479 m .60526 .96512 L .60389 .93492 L F
.60631 1.18796 m .60666 1.21416 L .60912 1.34962 L 0 .288 .209 r
F
.60335 1.01748 m .60912 1.34962 L .60894 1.33787 L F
.60097 .80855 m .60128 .81232 L .60097 .8086 L 0 .066 .149 r
F
.60116 .80162 m .60123 .84291 L .60352 .97787 L 0 .288 .209 r
F
.60471 1.06899 m .60129 .87388 L .60545 1.12507 L F
.60912 1.34962 m .60526 .96512 L .60875 1.32479 L 0 1 .196 r
F
.60875 1.32479 m .60389 .93492 L .6056 1.11822 L F
.60377 .99803 m .60129 .87388 L .60471 1.06899 L 0 .288 .209 r
F
.60377 .99803 m .60471 1.06899 L .60579 1.13079 L F
.60128 .86736 m .60129 .87388 L .60375 .99739 L F
.60119 .86249 m .60129 .87388 L .60128 .86736 L F
.60666 1.21533 m .60321 1.02426 L .60763 1.28252 L F
.60912 1.34962 m .60666 1.21416 L .60959 1.37818 L F
.60655 1.20793 m .60321 1.02426 L .60666 1.21533 L F
.6031 1.02113 m .60307 1.02016 L .60774 1.28976 L F
.6031 1.02113 m .60774 1.28976 L .60771 1.28816 L F
.60274 1.01096 m .60383 1.10616 L .60845 1.37959 L F
.60928 1.37893 m .60274 1.01096 L .60845 1.37959 L F
.60321 1.02426 m .6031 1.02113 L .60928 1.37893 L F
.60348 1.0108 m .60335 1.01748 L .60628 1.1854 L F
.60129 .87388 m .60628 1.1854 L .60557 1.13221 L F
.60307 1.02016 m .60274 1.01096 L .60792 1.30221 L F
.60307 1.02016 m .60792 1.30221 L .60774 1.28976 L F
.60385 1.02144 m .60346 .99966 L .60753 1.37675 L 0 1 .196 r
F
.60364 1.00156 m .60354 1.00055 L .60385 1.02144 L F
.60354 1.00055 m .60346 .99966 L .60385 1.02144 L F
.60666 1.21416 m .60655 1.20793 L .60678 1.22202 L 0 .288 .209 r
F
.60655 1.20793 m .60666 1.21533 L .60678 1.22202 L F
.60666 1.21416 m .60678 1.22202 L .60959 1.37818 L F
.60144 .89087 m .60072 .82328 L .60081 .82573 L 0 .267 .202 r
F
.60085 .82863 m .60081 .82573 L .60082 .82616 L F
.60144 .89087 m .60081 .82573 L .60085 .82863 L F
.60185 .83129 m .59978 .71539 L .60196 .83806 L 0 .223 .192 r
F
.59978 .71539 m .59978 .71598 L .602 .84067 L F
.60172 .76141 m .60136 .75106 L .60201 .84106 L 0 1 .196 r
F
.60136 .75106 m .60083 .73602 L .60201 .84106 L F
.60104 .70643 m .60083 .73602 L .60136 .75106 L F
.60526 .96512 m .60388 .91263 L .60389 .93492 L F
.59978 .71539 m .602 .84067 L .60199 .83967 L 0 .223 .192 r
F
.59978 .71636 m .60201 .84098 L .59979 .71662 L F
.603 .89673 m .60201 .84106 L .6025 .85975 L F
.60201 .84098 m .603 .89673 L .60201 .84091 L F
.60201 .84098 m .60201 .84091 L .59979 .71662 L F
.60098 .76057 m .60105 .77245 L .60122 .78931 L 0 1 .196 r
F
.60122 .78943 m .60122 .78931 L .60122 .78994 L F
.60098 .76057 m .60122 .78931 L .60122 .78943 L F
.60098 .76024 m .60122 .78944 L .60127 .79239 L F
.60098 .76057 m .60122 .78943 L .60098 .76024 L F
.60122 .78943 m .60122 .78994 L .60122 .78944 L F
.60122 .78943 m .60122 .78944 L .60098 .76024 L F
.59978 .71602 m .59978 .71607 L .60201 .84106 L 0 .223 .192 r
F
.60201 .84098 m .60201 .84106 L .603 .89673 L F
.59978 .71602 m .60201 .84106 L .60201 .84098 L F
.59968 .7072 m .59818 .55643 L .59818 .55645 L 0 .267 .202 r
F
.60206 .69583 m .60209 .69644 L .60234 .70796 L 0 .223 .192 r
F
.60387 .82742 m .6017 .61138 L .60159 .72666 L 0 1 .196 r
F
.60162 .61362 m .60163 .61329 L .60167 .61551 L 0 .727 .225 r
F
.60162 .61362 m .60167 .61551 L .60167 .61621 L F
.6017 .61138 m .60124 .67783 L .60159 .72666 L 0 1 .196 r
F
.60819 1.02413 m .60366 .55948 L .60778 1.0053 L F
.60366 .55948 m .60093 .2795 L .60359 .56136 L F
.60366 .55948 m .60359 .56136 L .60778 1.0053 L F
.59598 .33385 m .59565 .30053 L .59598 .33323 L 0 .267 .202 r
F
.59598 .33386 m .59598 .33364 L .59598 .33323 L F
.59581 .31658 m .59565 .30053 L .6017 .61138 L 0 .727 .225 r
F
.59581 .31669 m .6017 .61138 L .60163 .61329 L F
.59576 .31381 m .59581 .31658 L .59581 .31669 L F
.59581 .31658 m .6017 .61138 L .59581 .31669 L F
.59611 .33403 m .59599 .33387 L .59604 .32608 L 0 .267 .202 r
F
.59599 .33387 m .59598 .33386 L .59598 .33343 L F
.59599 .33387 m .59598 .33343 L .59604 .32608 L F
.59598 .33343 m .59598 .33323 L .59604 .32608 L F
.59598 .33386 m .59598 .33323 L .59598 .33343 L F
.59576 .31381 m .59565 .30053 L .59581 .31658 L 0 .727 .225 r
F
.61509 1.31465 m .61583 1.34767 L .61583 1.3482 L 0 .223 .192 r
F
.61509 1.31465 m .61583 1.3482 L .61583 1.34838 L F
.61433 1.28046 m .61509 1.31465 L .61583 1.34838 L F
.61583 1.34838 m .61583 1.34767 L .61654 1.38074 L F
.61477 1.29793 m .61478 1.29737 L .61654 1.38074 L F
.61695 1.38053 m .61093 1.14863 L .61635 1.38029 L 0 1 .196 r
F
.61093 1.14863 m .61123 1.16143 L .61151 1.17526 L 0 .223 .192 r
F
.61181 1.19138 m .61093 1.14863 L .61179 1.18877 L F
.61093 1.14863 m .61151 1.17526 L .61179 1.18877 L F
.60971 1.15379 m .60904 1.08758 L .60871 1.07674 L 0 1 .196 r
F
.61066 1.19438 m .60093 .2795 L .60971 1.15379 L F
.61304 1.37726 m .60589 .9857 L .61566 1.3786 L 0 .223 .192 r
F
.61304 1.37726 m .61301 1.37589 L .61304 1.37726 L F
.61301 1.37589 m .60589 .9857 L .61304 1.37726 L F
.61287 1.37002 m .61287 1.36982 L .61304 1.37726 L F
.61287 1.36982 m .60589 .9857 L .61301 1.37589 L F
.61287 1.36982 m .61301 1.37589 L .61304 1.37726 L F
.60389 .93492 m .60279 .91082 L .60377 .99803 L 0 1 .196 r
F
.60579 1.13079 m .60471 1.06899 L .6078 1.26292 L 0 .288 .209 r
F
.60959 1.37818 m .60666 1.21533 L .60928 1.37893 L F
.6096 1.37815 m .60912 1.34962 L .60959 1.37818 L F
.6096 1.37815 m .60912 1.34962 L .60957 1.37815 L 0 1 .196 r
F
.61263 1.37876 m .60912 1.34962 L .6096 1.37815 L F
.60964 1.37806 m .60912 1.34962 L .6096 1.37815 L 0 .288 .209 r
F
.60471 1.06899 m .60545 1.12507 L .60964 1.37806 L F
.60557 1.13221 m .60628 1.1854 L .60964 1.37806 L F
.6056 1.11822 m .60377 .99803 L .60802 1.37766 L 0 1 .196 r
F
.60389 .93492 m .60377 .99803 L .6056 1.11822 L F
.60541 1.08061 m .60377 .99803 L .61011 1.37746 L 0 .288 .209 r
F
.60377 .99803 m .60579 1.13079 L .61011 1.37746 L F
.60666 1.21533 m .60763 1.28252 L .60928 1.37893 L F
.60771 1.28816 m .60774 1.28976 L .60928 1.37893 L F
.60774 1.28976 m .60792 1.30221 L .60928 1.37893 L F
.60941 1.37812 m .60875 1.32479 L .60802 1.37766 L 0 1 .196 r
F
.60941 1.37812 m .60912 1.34962 L .60884 1.33216 L F
.61011 1.37746 m .60579 1.13079 L .60964 1.37806 L 0 .288 .209 r
F
.60579 1.13079 m .6078 1.26292 L .60964 1.37806 L F
.61032 1.37719 m .60541 1.08061 L .61011 1.37746 L F
.61293 1.37726 m .61271 1.36312 L .61111 1.36914 L 0 .646 .228 r
F
.6112 1.37414 m .61111 1.36914 L .61024 1.37242 L F
.61293 1.37726 m .61111 1.36914 L .6112 1.37414 L F
.61125 1.37721 m .61024 1.37242 L .61032 1.37719 L F
.61293 1.37726 m .6112 1.37414 L .61125 1.37721 L F
.6112 1.37414 m .61024 1.37242 L .61125 1.37721 L F
.60362 .93134 m .603 .89673 L .60395 .9452 L 0 .223 .192 r
F
.60362 .93134 m .60395 .9452 L .60452 .97418 L F
.60468 1.01946 m .60362 .93134 L .60464 1.01825 L 0 .646 .228 r
F
.60307 .90014 m .60301 .89696 L .6036 .93019 L 0 .223 .192 r
F
.60331 .91362 m .6036 .93019 L .6036 .93051 L F
.60418 .95457 m .603 .89673 L .60242 .85382 L F
.60452 .97418 m .60395 .9452 L .60418 .95457 L F
.60395 .9452 m .603 .89673 L .60418 .95457 L F
.60212 .83203 m .60526 .96512 L .60816 1.11956 L F
.60212 .83203 m .60816 1.11956 L .60644 1.04845 L F
.60212 .83203 m .61284 1.36879 L .61258 1.35609 L F
.60196 .83768 m .60179 .82192 L .60177 .82156 L 0 1 .196 r
F
.60185 .83129 m .60196 .83806 L .60199 .83967 L 0 .223 .192 r
F
.60331 .95763 m .60201 .84106 L .60329 .95679 L 0 1 .196 r
F
.60201 .84106 m .60179 .82192 L .602 .84069 L F
.60201 .84106 m .602 .84069 L .60329 .95679 L F
.60196 .83768 m .60177 .82156 L .60191 .83486 L F
.602 .84069 m .60179 .82192 L .60196 .83768 L F
.59968 .7072 m .59809 .54681 L .59874 .60845 L 0 .267 .202 r
F
.60904 1.08758 m .60093 .2795 L .60871 1.07674 L 0 1 .196 r
F
.60978 1.11154 m .60704 .62078 L .60376 .43776 L F
.60374 .43965 m .60156 .28043 L .60376 .43776 L 0 .727 .225 r
F
.60316 .48875 m .60376 .43776 L .60093 .2795 L 0 1 .196 r
F
.60978 1.11154 m .60376 .43776 L .60316 .48875 L F
.60589 .9857 m .60625 .99714 L .61566 1.3786 L 0 .223 .192 r
F
.60625 .99714 m .61005 1.12012 L .61566 1.3786 L F
.61026 1.12694 m .61093 1.14863 L .61566 1.3786 L F
.61005 1.12012 m .61026 1.12694 L .61566 1.3786 L F
.61566 1.3786 m .61181 1.19138 L .61179 1.18877 L F
.61771 1.37723 m .61399 1.14993 L .61351 1.37725 L 0 .646 .228 r
F
.60336 .89258 m .60387 .82742 L .60106 .70327 L 0 1 .196 r
F
.60336 .89258 m .60106 .70327 L .60104 .70643 L F
.60242 .85382 m .6027 .86734 L .60269 .86712 L 0 .223 .192 r
F
.60242 .85382 m .60324 .888 L .6027 .86734 L F
.60242 .85382 m .60701 1.07678 L .60675 1.06802 L F
.61271 1.36312 m .61267 1.36075 L .60634 1.09048 L 0 .646 .228 r
F
.61271 1.36312 m .60634 1.09048 L .60635 1.09109 L F
.60634 1.09048 m .60362 .93134 L .60468 1.01946 L F
.61267 1.36075 m .60362 .93134 L .60634 1.09048 L F
.60652 1.20564 m .60655 1.20793 L .60666 1.21416 L 0 .288 .209 r
F
.60875 1.32479 m .6056 1.11822 L .60802 1.37766 L 0 1 .196 r
F
.60884 1.33216 m .60912 1.34962 L .60875 1.32479 L F
.60957 1.37815 m .60912 1.34962 L .60941 1.37812 L F
.60894 1.33787 m .60912 1.34962 L .60964 1.37806 L 0 .288 .209 r
F
.61271 1.36312 m .60468 1.01946 L .60541 1.08061 L 0 .646 .228 r
F
.60984 1.37392 m .60541 1.08061 L .60898 1.37715 L F
.61271 1.36312 m .60541 1.08061 L .60984 1.37392 L F
.60375 .99246 m .60375 .99739 L .60541 1.08061 L 0 .288 .209 r
F
.60518 1.06536 m .60541 1.08061 L .60522 1.06727 L F
.60527 1.07085 m .60464 1.01825 L .60479 1.0375 L 0 .646 .228 r
F
.60418 .95457 m .60242 .85382 L .60588 1.02518 L 0 .223 .192 r
F
.60293 .87607 m .60179 .78137 L .60201 .84036 L 0 1 .196 r
F
.60336 .89258 m .60179 .78137 L .60293 .87607 L F
.60336 .89258 m .60172 .76141 L .60179 .78137 L F
.60172 .76141 m .60104 .70643 L .60136 .75106 L F
.60234 .8256 m .60083 .73602 L .60276 .78198 L 0 .727 .225 r
F
.60083 .73602 m .59884 .61858 L .60102 .70919 L F
.60083 .73602 m .60102 .70919 L .60276 .78198 L F
.59957 .69657 m .59793 .53129 L .59968 .7072 L 0 .267 .202 r
F
.59793 .53129 m .59793 .53133 L .59968 .7072 L F
.59787 .52599 m .59787 .5259 L .59954 .69411 L F
.59787 .52599 m .59954 .69411 L .59954 .69359 L F
.59873 .61761 m .59743 .48411 L .59875 .61991 L F
.59743 .48411 m .59716 .45598 L .59743 .48412 L F
.59743 .48411 m .59743 .48412 L .59875 .61991 L F
.59788 .52708 m .59788 .52708 L .59954 .69359 L F
.5979 .52976 m .59954 .69359 L .59954 .69355 L F
.59788 .52708 m .5979 .52976 L .5979 .52976 L F
.5979 .52976 m .59954 .69359 L .5979 .52976 L F
.59926 .66758 m .59788 .52708 L .59954 .69355 L F
.60077 .73421 m .59888 .62235 L .60083 .73602 L 0 .727 .225 r
F
.59786 .52545 m .59787 .52498 L .59957 .69657 L 0 .267 .202 r
F
.59786 .52545 m .59957 .69657 L .59954 .69411 L F
.598 .53978 m .59802 .54128 L .59896 .6366 L F
.60735 1.13622 m .60418 .95457 L .60915 1.18659 L 0 .223 .192 r
F
.60418 .95457 m .60588 1.02518 L .60915 1.18659 L F
.60104 .70643 m .60106 .70327 L .60092 .69725 L 0 1 .196 r
F
.6028 .78459 m .60356 .71281 L .60853 .96597 L 0 .727 .225 r
F
.60644 1.04845 m .60816 1.11956 L .61284 1.36879 L 0 .223 .192 r
F
.60526 .96512 m .60387 .82742 L .60388 .91263 L 0 1 .196 r
F
.60269 .86712 m .60642 1.0475 L .6063 1.04238 L 0 .223 .192 r
F
.6027 .86734 m .60642 1.0475 L .60269 .86712 L F
.6039 .92562 m .60396 .92437 L .60642 1.0475 L F
.6027 .86734 m .60396 .92437 L .6039 .92562 L F
.6027 .86734 m .60324 .888 L .60396 .92437 L F
.6063 1.04238 m .60642 1.0475 L .60701 1.07678 L F
.60675 1.06802 m .60701 1.07678 L .61266 1.36007 L F
.60163 .61329 m .6017 .61138 L .60869 .9703 L 0 .727 .225 r
F
.61284 1.36879 m .61274 1.36371 L .61275 1.3646 L 0 .646 .228 r
F
.61275 1.3646 m .61274 1.36371 L .61272 1.3631 L F
.61293 1.37726 m .61284 1.36879 L .61275 1.3646 L F
.61023 1.12609 m .60704 .62078 L .60978 1.11154 L 0 1 .196 r
F
.60906 .97797 m .60869 .9703 L .61284 1.36879 L 0 .646 .228 r
F
.61286 1.36935 m .61284 1.36879 L .61293 1.37726 L F
.61302 1.37726 m .61286 1.36935 L .61293 1.37726 L F
.61293 1.37726 m .61275 1.3646 L .61271 1.36312 L F
.60735 1.13622 m .60895 1.18112 L .613 1.37724 L 0 .223 .192 r
F
.60895 1.18112 m .60915 1.18659 L .61235 1.34517 L F
.61267 1.36075 m .60605 .91014 L .6054 .89539 L 0 .646 .228 r
F
.61271 1.36312 m .61268 1.36109 L .61267 1.36075 L F
.61268 1.36109 m .60605 .91014 L .61267 1.36075 L F
.60895 1.18112 m .61235 1.34517 L .61255 1.35482 L 0 .223 .192 r
F
.61258 1.35609 m .61284 1.36879 L .61266 1.36007 L F
.60413 .84166 m .60853 .96597 L .60856 .96747 L 0 .727 .225 r
F
.60413 .84166 m .60856 .96747 L .60536 .89444 L F
.60388 .91263 m .60387 .82742 L .60336 .89258 L 0 1 .196 r
F
.6028 .78459 m .60853 .96597 L .60413 .84166 L 0 .727 .225 r
F
.60163 .61329 m .60869 .9703 L .60858 .96789 L F
.60162 .61362 m .60855 .9666 L .60853 .96597 L F
.61275 1.3646 m .60606 .91039 L .61271 1.36312 L 0 .646 .228 r
F
.59808 .43302 m .59807 .43151 L .60163 .61329 L 0 .727 .225 r
F
.60159 .72666 m .60124 .67783 L .60106 .70327 L 0 1 .196 r
F
.60276 .78198 m .60123 .67926 L .60347 .70818 L 0 .727 .225 r
F
.60123 .67926 m .60063 .63962 L .60138 .6576 L F
.60123 .67926 m .60138 .6576 L .60347 .70818 L F
.60063 .63962 m .60162 .61362 L .60347 .70818 L F
.60106 .70327 m .59836 .27878 L .60092 .69725 L 0 1 .196 r
F
.60124 .67783 m .59836 .27878 L .60106 .70327 L F
.6017 .61138 m .59836 .27878 L .60124 .67783 L F
.60167 .61621 m .60167 .61551 L .60855 .9666 L 0 .727 .225 r
F
.59825 .30526 m .59686 .30272 L .59794 .2976 L F
.6028 .78459 m .60276 .78198 L .60356 .71281 L F
.60276 .78198 m .60347 .70818 L .60356 .71281 L F
.59949 .46434 m .59836 .27878 L .59675 .27804 L 0 1 .196 r
F
.59949 .46434 m .59675 .27804 L .59569 .27755 L F
.60092 .69725 m .59949 .46434 L .59569 .27755 L F
.60606 .91039 m .59674 .27754 L .60605 .91014 L 0 .646 .228 r
F
.60606 .91039 m .60605 .91014 L .61271 1.36312 L F
.61209 1.33289 m .61255 1.35482 L .613 1.37724 L 0 .223 .192 r
F
.60895 1.18112 m .61255 1.35482 L .61209 1.33289 L F
.61286 1.36927 m .61284 1.36879 L .61286 1.36935 L 0 .646 .228 r
F
.60906 .97797 m .61284 1.36879 L .61286 1.36927 L F
.61287 1.37002 m .61284 1.36879 L .61287 1.36982 L 0 .223 .192 r
F
.61286 1.36937 m .61286 1.36927 L .61286 1.36935 L 0 .646 .228 r
F
.613 1.37724 m .61284 1.36879 L .61287 1.37002 L 0 .223 .192 r
F
.61266 1.36007 m .61284 1.36879 L .613 1.37724 L F
.61284 1.36879 m .60869 .9703 L .61274 1.36371 L 0 .646 .228 r
F
.61194 1.03755 m .6017 .61138 L .60374 .43965 L 0 .727 .225 r
F
.60869 .9703 m .6017 .61138 L .61194 1.03755 L F
.60869 .9703 m .60448 .56758 L .60865 .96948 L 0 .646 .228 r
F
.60869 .9703 m .60865 .96948 L .61275 1.3646 L F
.61255 1.35482 m .61266 1.36007 L .613 1.37724 L 0 .223 .192 r
F
.60675 1.06802 m .61266 1.36007 L .61255 1.35482 L F
.60871 1.07674 m .60819 1.02413 L .60778 1.0053 L 0 1 .196 r
F
.61272 1.3631 m .60865 .96948 L .60606 .91039 L 0 .646 .228 r
F
.61274 1.36371 m .60865 .96948 L .61272 1.3631 L F
.61267 1.36075 m .60944 1.15401 L .60362 .93134 L F
.60944 1.15401 m .60432 .91713 L .60362 .93134 L F
.60336 .89258 m .60201 .84036 L .60204 .84222 L 0 1 .196 r
F
.60432 .91713 m .60234 .8256 L .60362 .93134 L 0 .646 .228 r
F
.6054 .89539 m .60234 .8256 L .60432 .91713 L F
.60113 .78358 m .59975 .70566 L .6015 .80807 L 0 .223 .192 r
F
.60112 .7835 m .60112 .78318 L .60113 .78358 L F
.60112 .78318 m .59975 .70566 L .60113 .78358 L F
.60111 .78236 m .6011 .78207 L .60109 .78124 L 0 .702 .227 r
F
.60128 .86882 m .59985 .72374 L .59994 .72781 L 0 .267 .202 r
F
.59985 .72374 m .59978 .71607 L .59994 .72781 L F
.59994 .72781 m .59978 .71607 L .59988 .72091 L F
.6011 .85398 m .60136 .8812 L .60136 .88128 L F
.60129 .87388 m .60175 .92554 L .60335 1.01748 L 0 .288 .209 r
F
.60213 .96584 m .60274 1.01096 L .60307 1.02016 L F
.60274 1.01103 m .60298 1.0361 L .60274 1.01135 L 0 .267 .202 r
F
.60274 1.01103 m .60274 1.01096 L .60298 1.0361 L F
.60297 1.0362 m .60298 1.0361 L .60619 1.37909 L F
.60397 1.15179 m .60396 1.14138 L .60619 1.37909 L F
.60619 1.37909 m .60274 1.01096 L .60222 .9725 L F
.60136 .8812 m .60357 1.11104 L .60357 1.11104 L F
.6011 .85398 m .60136 .88113 L .60136 .8812 L F
.60136 .88113 m .60357 1.11104 L .60136 .8812 L F
.60123 .84291 m .60074 .81346 L .60128 .86705 L 0 .288 .209 r
F
.59989 .73434 m .5998 .72831 L .60072 .82328 L 0 .267 .202 r
F
.6011 .85398 m .60349 1.10275 L .60349 1.10274 L F
.60074 .81628 m .60074 .8163 L .60084 .82653 L F
.6005 .79165 m .60074 .8163 L .60074 .81628 L F
.6005 .79165 m .6005 .79163 L .60074 .8163 L F
.60083 .82651 m .60084 .82653 L .60088 .83112 L F
.6005 .79165 m .60084 .82653 L .60083 .82651 L F
.60045 .78748 m .60075 .81801 L .60075 .81796 L F
.60046 .78746 m .60075 .81801 L .60045 .78748 L F
.60075 .81801 m .60075 .81801 L .60046 .78746 L F
.60075 .81801 m .60046 .78746 L .60046 .78746 L F
.6011 .85398 m .6011 .8541 L .60129 .87388 L F
.6011 .85398 m .60129 .87388 L .60132 .87713 L F
.6011 .85398 m .60132 .87721 L .60132 .87723 L F
.60108 .85281 m .60108 .85296 L .60342 1.09652 L F
.60108 .85281 m .60342 1.09652 L .60342 1.09655 L F
.6036 1.11504 m .60407 1.16359 L .60407 1.16365 L F
.60108 .85281 m .6036 1.115 L .6036 1.11504 L F
.6036 1.115 m .60407 1.16359 L .6036 1.11504 L F
.61194 1.03755 m .60374 .43965 L .61224 1.0438 L 0 .727 .225 r
F
.61399 1.14993 m .61309 1.09482 L .61351 1.37725 L 0 .646 .228 r
F
.61309 1.09482 m .61227 1.0443 L .61238 1.07471 L F
.61309 1.09482 m .61238 1.07471 L .61351 1.37725 L F
.61227 1.0443 m .60906 .97797 L .61351 1.37725 L F
.60374 .43965 m .60376 .43776 L .61692 1.37639 L 0 .727 .225 r
F
.61227 1.0443 m .60448 .56758 L .60906 .97797 L 0 .646 .228 r
F
.61445 .93454 m .61427 1.01867 L .61445 .93364 L 0 .61 .226 r
F
.61727 1.37638 m .61427 1.01911 L .61445 .93454 L F
.61427 1.01911 m .61427 1.01867 L .61445 .93454 L F
.61727 1.37638 m .61696 .96566 L .61771 1.37627 L F
.61696 .96566 m .61674 .66825 L .61714 .96213 L F
.61696 .96566 m .61714 .96213 L .61771 1.37627 L F
.61696 .96566 m .61463 .9288 L .61696 .95873 L F
.61507 1.00298 m .61463 .9288 L .61696 .96566 L F
.61463 .9288 m .6145 .90742 L .61696 .95873 L F
.61507 1.00298 m .61445 .93364 L .6145 .90742 L F
.61491 1.00607 m .61445 .93364 L .61507 1.00298 L F
.61674 .66825 m .61679 .66809 L .61771 1.37627 L F
.61427 1.01867 m .61289 1.03638 L .61409 1.10357 L 0 .646 .228 r
F
.61409 1.10357 m .61289 1.03638 L .61406 1.11924 L F
.61704 1.37638 m .60589 .46322 L .60997 .51204 L 0 .61 .226 r
F
.60376 .43776 m .60156 .28043 L .60587 .46296 L F
.60093 .2795 m .60376 .43776 L .60533 .47553 L 0 .537 .227 r
F
.60376 .43776 m .60704 .62078 L .60533 .47553 L F
.60093 .2795 m .60533 .47553 L .602 .27935 L F
.61692 1.37639 m .60376 .43776 L .60587 .46296 L 0 .61 .226 r
F
.61704 1.37638 m .60807 .28012 L .61727 1.37638 L F
.61717 .96151 m .60448 .56758 L .61427 1.01867 L 0 .646 .228 r
F
.61727 1.37638 m .61507 1.00298 L .61696 .96566 L 0 .61 .226 r
F
.61728 .96291 m .60448 .56758 L .61717 .96151 L 0 .646 .228 r
F
.61728 .96291 m .61717 .96151 L .62871 1.31958 L F
.61771 1.37627 m .61717 .96151 L .62041 .89895 L 0 .61 .226 r
F
.61727 1.37638 m .61491 1.00607 L .61507 1.00298 L F
.61692 1.37639 m .61282 1.03724 L .61704 1.37638 L F
.61282 1.03724 m .61284 1.03703 L .61704 1.37638 L F
.61288 1.03646 m .61289 1.03638 L .61704 1.37638 L F
.61195 .96566 m .61204 .96762 L .61704 1.37638 L F
.61809 1.376 m .62041 .89895 L .62493 1.37285 L F
.61771 1.37627 m .62041 .89895 L .61809 1.376 L F
.62237 1.37247 m .61619 1.09854 L .61694 1.37316 L 0 .501 .225 r
F
.61659 1.37637 m .61194 1.03755 L .61692 1.37639 L 0 .727 .225 r
F
.61194 1.03755 m .61224 1.0438 L .61692 1.37639 L F
.60216 .57236 m .59836 .27878 L .6017 .61138 L 0 1 .196 r
F
.60606 .91039 m .60448 .56758 L .59674 .27754 L 0 .646 .228 r
F
.61351 1.37725 m .6091 .98209 L .61286 1.36927 L F
.6091 .98209 m .60909 .98186 L .61286 1.36935 L F
.60853 .96597 m .60855 .9666 L .61659 1.37637 L 0 .727 .225 r
F
.60865 .96948 m .60448 .56758 L .60606 .91039 L 0 .646 .228 r
F
.6091 .98209 m .60906 .97797 L .60909 .98186 L F
.61659 1.37637 m .60869 .9703 L .61194 1.03755 L 0 .727 .225 r
F
.60906 .97797 m .60448 .56758 L .60869 .9703 L 0 .646 .228 r
F
.61282 1.03724 m .61195 .96566 L .61284 1.03703 L 0 .61 .226 r
F
.61289 1.03638 m .60448 .56758 L .61227 1.0443 L 0 .646 .228 r
F
.61427 1.01867 m .60448 .56758 L .61289 1.03638 L F
.60258 .56314 m .59718 .27446 L .59944 .2742 L 0 .548 .225 r
F
.60362 .93134 m .60358 .92849 L .60353 .92635 L 0 .646 .228 r
F
.60358 .92849 m .60234 .8256 L .6035 .92371 L F
.60358 .92849 m .6035 .92371 L .60353 .92635 L F
.59988 .72091 m .59897 .62796 L .59903 .63206 L 0 .267 .202 r
F
.60174 .82352 m .59975 .70944 L .60194 .83641 L 0 .223 .192 r
F
.6009 .74369 m .60085 .73929 L .60145 .80499 L 0 1 .196 r
F
.59975 .70566 m .60122 .79375 L .60174 .82352 L 0 .223 .192 r
F
.59975 .70566 m .60174 .82352 L .6015 .80807 L F
.60146 .80524 m .60145 .80499 L .60157 .8176 L 0 1 .196 r
F
.6009 .74369 m .60145 .80499 L .60146 .80524 L F
.60177 .82156 m .60188 .8328 L .60191 .83486 L F
.60177 .82156 m .6009 .74369 L .60157 .8176 L F
.60177 .82156 m .60168 .81974 L .60181 .82806 L F
.60177 .82156 m .60191 .84695 L .602 .84589 L F
.60191 .84695 m .60199 .86399 L .602 .85455 L F
.60191 .84695 m .602 .85455 L .602 .84589 L F
.59992 .72537 m .60117 .80901 L .60122 .83704 L 0 .267 .202 r
F
.59873 .65744 m .59877 .65899 L .59893 .6679 L 0 .223 .192 r
F
.59877 .65899 m .59922 .67853 L .59893 .6679 L F
.59893 .6679 m .59922 .67853 L .59959 .7036 L F
.59919 .65508 m .6004 .78111 L .6004 .78111 L 0 .267 .202 r
F
.5993 .66696 m .5993 .66687 L .6005 .79163 L F
.5993 .66696 m .6005 .79163 L .6005 .79165 L F
.59919 .65508 m .59919 .65507 L .6005 .79163 L F
.59919 .65508 m .6005 .79163 L .6005 .79163 L F
.5988 .61406 m .5988 .61404 L .60014 .75321 L F
.5988 .61404 m .5988 .61395 L .59884 .61858 L F
.5988 .61404 m .59884 .61858 L .60014 .75321 L F
.60111 .7825 m .59972 .70383 L .60111 .78244 L 0 .727 .225 r
F
.59942 .68236 m .59873 .65081 L .59873 .64303 L 0 .223 .192 r
F
.59958 .69761 m .59873 .65081 L .59942 .68236 L F
.5988 .61406 m .60014 .75321 L .60013 .75327 L 0 .267 .202 r
F
.59856 .63803 m .59223 .27873 L .59856 .63803 L 0 .727 .225 r
F
.59976 .71474 m .59934 .68979 L .59972 .71035 L 0 .223 .192 r
F
.59978 .71607 m .59934 .68979 L .59976 .71474 L F
.59978 .71607 m .59873 .65744 L .59934 .68979 L F
.59873 .65744 m .59201 .28027 L .59873 .65177 L F
.59873 .65177 m .59201 .28027 L .59873 .65081 L F
.59426 .40618 m .59393 .37543 L .59358 .3683 L F
.5964 .52632 m .59584 .48677 L .59561 .48214 L F
.59978 .71539 m .59691 .54858 L .59678 .54741 L F
.6015 .80807 m .60174 .82352 L .60307 .90014 L F
.60085 .73929 m .60098 .75988 L .60157 .8176 L 0 1 .196 r
F
.59885 .61944 m .59884 .61858 L .60083 .73602 L 0 .727 .225 r
F
.59888 .62235 m .59885 .61944 L .60083 .73602 L F
.60026 .721 m .60023 .71904 L .60077 .73421 L F
.59896 .63896 m .59754 .49372 L .59896 .6366 L 0 .267 .202 r
F
.59896 .64193 m .59875 .61991 L .59896 .64024 L F
.59896 .64193 m .59873 .61761 L .59875 .61991 L F
.59896 .63937 m .59896 .6366 L .59926 .66758 L F
.59873 .64303 m .59873 .61761 L .59919 .66057 L 0 .223 .192 r
F
.59942 .68236 m .59873 .64303 L .59919 .66057 L F
.59873 .64303 m .5924 .28081 L .59873 .61761 L F
.59873 .64303 m .59872 .64237 L .59872 .64237 L F
.59975 .70528 m .59972 .7038 L .60077 .73421 L 0 .727 .225 r
F
.59878 .6128 m .59878 .61283 L .59919 .65507 L 0 .267 .202 r
F
.5977 .49972 m .59919 .65507 L .59919 .65508 L F
.59768 .4975 m .5977 .49972 L .5977 .49972 L F
.59754 .49372 m .59729 .46837 L .59755 .49391 L F
.59754 .49372 m .59755 .49391 L .59896 .6366 L F
.59729 .46837 m .59717 .45567 L .59733 .47148 L F
.59729 .46837 m .59733 .47148 L .59896 .6366 L F
.59793 .53129 m .59771 .50855 L .59793 .53133 L F
.59809 .54681 m .59778 .51615 L .59811 .54723 L F
.59809 .54681 m .59811 .54723 L .59874 .60845 L F
.59778 .51615 m .59771 .50852 L .59779 .51629 L F
.59778 .51615 m .59779 .51629 L .59874 .60845 L F
.59818 .55645 m .59815 .55261 L .59815 .55264 L F
.59818 .55643 m .59815 .55261 L .59818 .55645 L F
.59815 .55261 m .59792 .53029 L .59815 .55264 L F
.59792 .53029 m .59786 .52406 L .59792 .53033 L F
.59786 .52406 m .59771 .50854 L .59786 .52411 L F
.59822 .55638 m .59771 .50852 L .59773 .50779 L F
.59874 .60845 m .59823 .55926 L .59842 .57526 L F
.59823 .55926 m .59771 .50852 L .59842 .57526 L F
.59745 .48434 m .59743 .48411 L .59785 .52742 L F
.59789 .53071 m .59716 .45598 L .59717 .45567 L F
.59786 .5277 m .59716 .45598 L .59789 .53071 L F
.59786 .5275 m .59759 .49899 L .59785 .52742 L F
.59787 .52762 m .59759 .49899 L .59786 .5275 L F
.59787 .52762 m .59745 .48434 L .59759 .49899 L F
.59789 .53071 m .59717 .45567 L .59792 .53332 L F
.59792 .53332 m .59745 .48481 L .59795 .53544 L F
.59745 .48481 m .59717 .45567 L .59745 .4849 L F
.59745 .48481 m .59745 .4849 L .59795 .53544 L F
.59662 .39997 m .59662 .39933 L .59747 .48536 L F
.59746 .48519 m .59747 .48536 L .59802 .54128 L F
.59662 .39997 m .59747 .48536 L .59746 .48519 L F
.59673 .41144 m .59802 .54128 L .598 .53978 L F
.59662 .39997 m .59673 .41147 L .59673 .41144 L F
.59673 .41147 m .59802 .54128 L .59673 .41144 L F
.59783 .52253 m .59784 .52203 L .59787 .52498 L F
.59783 .52253 m .59787 .52498 L .59786 .52545 L F
.5977 .5088 m .59771 .50854 L .59784 .52203 L F
.5977 .5088 m .59784 .52203 L .59783 .52253 L F
.59788 .52708 m .59787 .52599 L .59788 .52708 L F
.59787 .52599 m .5977 .5088 L .59787 .5259 L F
.5965 .38785 m .5965 .38714 L .59662 .39933 L F
.5965 .38785 m .59662 .39933 L .59662 .39997 L F
.59716 .45598 m .5965 .38785 L .59716 .45519 L F
.59716 .45598 m .59716 .45519 L .59717 .45567 L F
.5965 .38785 m .59598 .33385 L .5965 .38714 L F
.5977 .5088 m .59605 .34176 L .59771 .50854 L F
.59605 .34176 m .59605 .34147 L .59605 .34177 L F
.59605 .34176 m .59605 .34177 L .59771 .50854 L F
.59972 .7038 m .59914 .64764 L .60077 .73421 L 0 .727 .225 r
F
.60056 .72218 m .60113 .78398 L .60128 .7965 L 0 1 .196 r
F
.6011 .78121 m .60113 .78398 L .60056 .72218 L F
.60234 .8256 m .60231 .82439 L .60353 .92635 L 0 .646 .228 r
F
.61154 1.3758 m .60362 .93134 L .60452 .97418 L 0 .223 .192 r
F
.61048 1.31612 m .61039 1.31096 L .61154 1.3758 L F
.60326 .91005 m .60315 .90379 L .60312 .90218 L F
.6033 .91274 m .60312 .90218 L .60307 .90014 L F
.60355 .92851 m .6035 .92416 L .60273 .89444 L 0 .646 .228 r
F
.6035 .92416 m .60233 .82754 L .60258 .86972 L F
.60339 .91768 m .60312 .90218 L .6033 .91274 L 0 .223 .192 r
F
.60326 .91005 m .60312 .90218 L .60339 .91768 L F
.60315 .90379 m .60259 .87093 L .60307 .90014 L F
.60024 .6882 m .60121 .78929 L .60122 .78994 L 0 1 .196 r
F
.59678 .54741 m .59656 .52865 L .5964 .52632 L 0 .223 .192 r
F
.59691 .54858 m .59656 .52865 L .59678 .54741 L F
.59656 .52865 m .59584 .48677 L .5964 .52632 L F
.59561 .48214 m .59458 .41318 L .59426 .40618 L F
.59584 .48677 m .59458 .41318 L .59561 .48214 L F
.59458 .41318 m .59393 .37543 L .59426 .40618 L F
.59393 .37543 m .5938 .36785 L .59363 .36819 L F
.59393 .37543 m .59363 .36819 L .59358 .3683 L F
.6004 .74706 m .59975 .70944 L .59986 .72035 L F
.59961 .70022 m .59873 .65177 L .5996 .69937 L F
.59976 .71207 m .59531 .45506 L .59978 .71539 L F
.59531 .45506 m .5938 .36791 L .59529 .45477 L F
.59531 .45506 m .59529 .45477 L .59978 .71539 L F
.60605 .91014 m .59674 .27754 L .6054 .89539 L 0 .646 .228 r
F
.6006 .53903 m .59718 .27446 L .60258 .56314 L 0 .548 .225 r
F
.60944 1.15401 m .6054 .89539 L .60432 .91713 L 0 .646 .228 r
F
.60536 .89444 m .60856 .96747 L .61659 1.37637 L 0 .727 .225 r
F
.60858 .96789 m .60869 .9703 L .61659 1.37637 L F
.6054 .89539 m .59674 .27754 L .59575 .2775 L 0 .646 .228 r
F
.60397 .86273 m .6028 .78459 L .60536 .89444 L 0 .727 .225 r
F
.60104 .70643 m .59569 .27755 L .60083 .73602 L 0 1 .196 r
F
.60276 .78198 m .60102 .70919 L .60123 .67926 L 0 .727 .225 r
F
.61155 1.3758 m .60735 1.13622 L .613 1.37724 L 0 .223 .192 r
F
.61165 1.37574 m .60823 1.17351 L .60932 1.21999 L 0 .727 .225 r
F
.60823 1.17351 m .60234 .8256 L .60932 1.21999 L F
.60932 1.21999 m .60234 .8256 L .60276 .78198 L F
.6054 .89539 m .59575 .2775 L .60234 .8256 L 0 .646 .228 r
F
.60468 1.22699 m .60506 1.26725 L .60506 1.26722 L 0 .267 .202 r
F
.6036 1.11506 m .60456 1.21526 L .60456 1.21531 L F
.60108 .85281 m .6036 1.11504 L .6036 1.11506 L F
.6036 1.11504 m .60456 1.21526 L .6036 1.11506 L F
.59821 .50263 m .59821 .50263 L .60085 .73857 L 0 1 .196 r
F
.60085 .73857 m .60085 .73857 L .60089 .7421 L F
.59821 .50263 m .60085 .73857 L .60085 .73857 L F
.59745 .4353 m .59821 .50263 L .59821 .50263 L F
.59821 .50263 m .60085 .73857 L .59821 .50263 L F
.60476 1.23798 m .604 1.15839 L .60479 1.23853 L 0 .267 .202 r
F
.60336 1.0909 m .60108 .85281 L .60336 1.09055 L F
.60086 .82963 m .60087 .83014 L .60144 .89008 L F
.60086 .82963 m .60144 .89008 L .60148 .89418 L F
.60086 .82963 m .60348 1.10281 L .60348 1.10282 L F
.60078 .82168 m .60086 .82963 L .60086 .82963 L F
.60086 .82963 m .60348 1.10281 L .60086 .82963 L F
.60348 1.10281 m .60471 1.23035 L .60348 1.10281 L F
.60348 1.10281 m .60348 1.10281 L .60086 .82963 L F
.60087 .83051 m .60088 .83112 L .6014 .88528 L F
.60087 .83014 m .60137 .88179 L .60139 .88502 L F
.60087 .83051 m .60137 .88179 L .60087 .83014 L F
.6005 .79165 m .60087 .83051 L .60087 .83014 L F
.60137 .88179 m .6014 .88528 L .6014 .88517 L F
.60137 .88179 m .6014 .88517 L .60139 .88502 L F
.59992 .72537 m .60116 .80162 L .60117 .80901 L F
.60003 .72225 m .60002 .72151 L .60122 .79375 L 0 .223 .192 r
F
.59973 .70426 m .59975 .70944 L .60122 .79375 L F
.59992 .72537 m .60112 .7835 L .60116 .80162 L 0 .267 .202 r
F
.60116 .80162 m .60008 .7421 L .60123 .84291 L 0 .288 .209 r
F
.60046 .78745 m .60075 .81801 L .60046 .78746 L 0 .267 .202 r
F
.60003 .74375 m .60075 .81801 L .60003 .74376 L F
.60075 .81801 m .60075 .81801 L .60003 .74376 L F
.6005 .79165 m .60088 .83112 L .60087 .83051 L F
.6004 .78111 m .60088 .83113 L .6004 .78111 L F
.60088 .83113 m .6014 .88528 L .60088 .83113 L F
.60088 .83113 m .60088 .83113 L .6004 .78111 L F
.60348 1.10282 m .60471 1.23035 L .60471 1.23033 L F
.60348 1.10281 m .60471 1.23035 L .60348 1.10282 L F
.604 1.15839 m .60336 1.0909 L .60401 1.1578 L F
.60336 1.0909 m .60336 1.09055 L .60401 1.1578 L F
.604 1.15839 m .60401 1.1578 L .60479 1.23853 L F
.60342 1.09655 m .60342 1.09652 L .60407 1.16359 L F
.60407 1.16365 m .60407 1.16359 L .60506 1.26725 L F
.60136 .88128 m .60382 1.13718 L .60382 1.13717 L F
.60136 .8812 m .60382 1.13718 L .60136 .88128 L F
.60352 .97787 m .60123 .84291 L .60128 .86705 L 0 .288 .209 r
F
.60129 .87388 m .60335 1.01748 L .60348 1.0108 L F
.60352 .97787 m .60128 .86705 L .60362 .98586 L F
.60128 .86705 m .60119 .86249 L .60128 .86718 L F
.60128 .86705 m .60128 .86718 L .60362 .98586 L F
.60307 .90014 m .6036 .93019 L .60331 .91362 L 0 .223 .192 r
F
.6035 .92416 m .60234 .82653 L .60233 .82754 L 0 .646 .228 r
F
.60355 .92851 m .6035 .92434 L .6035 .92416 L F
.6035 .92434 m .60234 .82653 L .6035 .92416 L F
.60357 .92934 m .60353 .92635 L .60355 .92851 L F
.60353 .92635 m .60234 .82653 L .6035 .92434 L F
.60353 .92635 m .6035 .92434 L .60355 .92851 L F
.6033 .91274 m .60331 .91362 L .6034 .91857 L 0 .223 .192 r
F
.60339 .91793 m .6034 .91857 L .60768 1.15903 L F
.60768 1.15902 m .60768 1.15903 L .61093 1.34128 L F
.60339 .91793 m .60768 1.15903 L .60768 1.15902 L F
.60768 1.15902 m .61093 1.34128 L .61093 1.34128 L F
.60339 .91793 m .60768 1.15902 L .60768 1.15902 L F
.60768 1.15902 m .61093 1.34128 L .60768 1.15902 L F
.61046 1.31378 m .60813 1.18311 L .61154 1.3758 L F
.60813 1.18311 m .60339 .91768 L .60812 1.18337 L F
.60813 1.18311 m .60812 1.18337 L .61154 1.3758 L F
.62039 .88844 m .61982 .85837 L .61694 .95243 L 0 .646 .228 r
F
.6175 .90343 m .61973 .84744 L .61982 .85428 L 0 .61 .226 r
F
.61982 .85837 m .61843 .83281 L .61694 .95243 L 0 .646 .228 r
F
.61717 .96151 m .61994 .8633 L .62041 .89895 L 0 .61 .226 r
F
.61694 .95243 m .61879 .80366 L .60448 .56758 L 0 .646 .228 r
F
.6172 .96046 m .61796 .9335 L .61694 .95243 L F
.60986 .50833 m .60366 .28033 L .60996 .51089 L 0 .61 .226 r
F
.602 .27935 m .60824 .4914 L .60379 .27909 L 0 .537 .227 r
F
.60493 .45173 m .60589 .46322 L .602 .27935 L F
.6006 .27721 m .60448 .56758 L .6036 .27537 L 0 .646 .228 r
F
.60379 .27909 m .61002 .5127 L .61604 .61115 L 0 .537 .227 r
F
.60997 .51204 m .60986 .50833 L .60996 .51089 L 0 .61 .226 r
F
.60824 .4914 m .61002 .5127 L .60379 .27909 L 0 .537 .227 r
F
.6036 .27537 m .60448 .56758 L .61879 .80366 L 0 .646 .228 r
F
.60379 .27909 m .61604 .61115 L .60561 .27794 L 0 .537 .227 r
F
.61604 .61115 m .61674 .62252 L .60561 .27794 L F
.60561 .27794 m .6105 .42957 L .61047 .42277 L F
.60588 .28617 m .61181 .46267 L .60762 .3342 L F
.61181 .46267 m .61202 .4675 L .60573 .27626 L F
.6036 .27537 m .61879 .80366 L .6088 .37254 L 0 .646 .228 r
F
.60561 .27794 m .60588 .28617 L .60573 .27626 L 0 .537 .227 r
F
.60588 .28617 m .60762 .3342 L .60573 .27626 L F
.61252 .47615 m .61181 .45123 L .61368 .49558 L 0 .61 .226 r
F
.61252 .47615 m .61368 .49558 L .61666 .56626 L F
.61181 .45123 m .61079 .27923 L .61328 .4007 L F
.61181 .45123 m .61328 .4007 L .61666 .56626 L F
.60573 .27626 m .60779 .33892 L .60712 .27423 L 0 .537 .227 r
F
.60779 .33892 m .6142 .53405 L .61073 .40655 L F
.60779 .33892 m .61073 .40655 L .60712 .27423 L F
.61181 .46267 m .6142 .53405 L .61202 .4675 L F
.61293 .50108 m .61296 .50157 L .61065 .42862 L F
.61068 .43511 m .61484 .56385 L .61065 .42862 L F
.61484 .56385 m .61674 .62252 L .61487 .56297 L F
.61484 .56385 m .61487 .56297 L .61065 .42862 L F
.62437 .78276 m .62641 .72296 L .62456 .78236 L 0 .586 .223 r
F
.62529 .73158 m .62605 .70564 L .62675 .70822 L F
.62529 .73158 m .62675 .70822 L .62781 .71212 L F
.62154 .65464 m .62255 .67132 L .62474 .69281 L 0 .459 .231 r
F
.6142 .53405 m .62605 .70564 L .62674 .73908 L F
.6142 .53405 m .62221 .66438 L .61568 .52633 L F
.62093 1.21336 m .61842 1.01097 L .61577 .92108 L 0 .501 .225 r
F
.62372 1.37194 m .62091 1.18028 L .62093 1.21336 L F
.62091 1.18028 m .61842 1.01097 L .62093 1.21336 L F
.61563 .92191 m .61577 .92108 L .61536 .90692 L F
.62372 1.37194 m .61577 .92108 L .61563 .92191 L F
.61496 .91282 m .61536 .90692 L .6139 .85722 L F
.62372 1.37194 m .61536 .90692 L .61496 .91282 L F
.61982 .85837 m .61879 .80366 L .61843 .83281 L 0 .646 .228 r
F
.61999 .86146 m .61987 .85099 L .62025 .86054 L 0 .586 .223 r
F
.61987 .85099 m .61969 .83466 L .62022 .85394 L F
.61674 .62252 m .61758 .64799 L .61417 .53982 L 0 .537 .227 r
F
.61674 .62252 m .61417 .53982 L .61415 .53966 L F
.61674 .62252 m .61361 .52206 L .61359 .52186 L F
.61947 .82207 m .61952 .81958 L .61987 .85099 L 0 .61 .226 r
F
.61674 .62252 m .61952 .81958 L .61947 .82207 L F
.6133 .50716 m .61758 .64799 L .6142 .53405 L 0 .537 .227 r
F
.61302 .50228 m .61758 .64799 L .6133 .50716 L F
.6112 .44594 m .61758 .64799 L .61136 .44926 L F
.61674 .62252 m .61755 .64529 L .61952 .81958 L 0 .61 .226 r
F
.61939 .82696 m .61879 .80366 L .61934 .83 L 0 .644 .229 r
F
.61674 .62252 m .61999 .86146 L .61994 .8633 L 0 .61 .226 r
F
.61939 .82696 m .61934 .83 L .61999 .86146 L 0 .644 .229 r
F
.61986 .85181 m .61987 .85099 L .61999 .86146 L 0 .61 .226 r
F
.61674 .62252 m .61987 .85099 L .61986 .85181 L F
.62025 .86054 m .61939 .82696 L .61999 .86146 L 0 .644 .229 r
F
.6201 .83712 m .62025 .82747 L .61879 .80366 L F
.62181 .85551 m .62202 .84888 L .62201 .85198 L 0 .586 .223 r
F
.62202 .84888 m .6223 .83997 L .62212 .8475 L F
.62202 .84888 m .62212 .8475 L .62201 .85198 L F
.61952 .80984 m .62194 .84997 L .62283 .83794 L 0 .644 .229 r
F
.61999 .86146 m .61879 .80366 L .61992 .8638 L 0 .646 .228 r
F
.62357 .68693 m .62674 .73908 L .62403 .69443 L 0 .459 .231 r
F
.6216 .65497 m .62484 .70805 L .62357 .68693 L F
.62484 .70805 m .62674 .73908 L .62357 .68693 L F
.6216 .65497 m .62403 .69443 L .62221 .66438 L F
.61879 .80366 m .62079 .82066 L .62221 .66445 L 0 .644 .229 r
F
.6201 .83712 m .61879 .80366 L .62007 .83882 L F
.63096 1.13832 m .62079 .85866 L .62891 1.19747 L F
.62025 .86054 m .62022 .85394 L .62079 .85866 L 0 .586 .223 r
F
.62079 .85866 m .61879 .80366 L .62025 .86054 L 0 .644 .229 r
F
.62079 .85866 m .62025 .86054 L .62891 1.19747 L F
.62891 1.19747 m .62025 .86054 L .62769 1.23277 L F
.62029 .87772 m .62039 .88844 L .62046 .88701 L 0 .646 .228 r
F
.62818 1.25671 m .6205 .88627 L .62805 1.29544 L F
.6205 .88627 m .62046 .88701 L .62805 1.29544 L F
.62041 .89895 m .62025 .86054 L .62079 .85866 L 0 .586 .223 r
F
.62186 .85109 m .62194 .84997 L .61952 .80984 L 0 .644 .229 r
F
.61955 .81594 m .62177 .85219 L .61952 .80984 L F
.62177 .85219 m .62186 .85109 L .61952 .80984 L F
.61879 .80366 m .61955 .81594 L .61952 .80984 L F
.6142 .53405 m .6194 .6549 L .62012 .65866 L 0 .459 .231 r
F
.6142 .53405 m .62012 .65866 L .62154 .65464 L F
.61674 .62252 m .61296 .50157 L .61293 .50108 L 0 .537 .227 r
F
.61726 .63723 m .61755 .64529 L .6171 .63179 L F
.6171 .63179 m .61755 .64529 L .6142 .53405 L F
.61962 .70709 m .61755 .64529 L .6194 .6549 L 0 .586 .223 r
F
.61507 .54818 m .6216 .65497 L .62221 .66438 L 0 .459 .231 r
F
.6142 .53405 m .61503 .54748 L .61507 .54818 L F
.61503 .54748 m .6216 .65497 L .61507 .54818 L F
.6142 .53405 m .62154 .65464 L .62168 .65627 L F
.61788 .72271 m .62221 .66445 L .61568 .52642 L 0 .644 .229 r
F
.61879 .80366 m .62069 .72611 L .61788 .72271 L F
.62069 .72611 m .62221 .66445 L .61788 .72271 L F
.61591 .55682 m .61753 .56551 L .6222 .66428 L 0 .593 .223 r
F
.61976 .61457 m .62004 .61865 L .6222 .66434 L 0 .919 .089 r
F
.62091 .6409 m .61976 .61457 L .6222 .66434 L F
.61611 .58248 m .61591 .55682 L .6222 .66428 L 0 .593 .223 r
F
.61591 .55682 m .61568 .52638 L .61753 .56551 L F
.62092 .73868 m .61611 .58248 L .6222 .66441 L F
.61611 .58248 m .6222 .66428 L .6222 .66441 L F
.62041 .89895 m .61999 .86146 L .62028 .86677 L 0 .586 .223 r
F
.62041 .89895 m .62128 .87175 L .62143 .86907 L F
.62041 .89895 m .62205 .85748 L .62628 .89152 L F
.6212 .8654 m .62101 .86048 L .62119 .8656 L 0 .644 .229 r
F
.62101 .86048 m .6201 .83712 L .62091 .85965 L F
.62041 .89895 m .62079 .85866 L .62177 .85219 L 0 .586 .223 r
F
.62041 .89895 m .62111 .87501 L .62128 .87175 L F
.61994 .8633 m .61999 .86146 L .62041 .89895 L 0 .61 .226 r
F
.62041 .89895 m .62143 .86907 L .62205 .85748 L 0 .586 .223 r
F
.6159 .71081 m .61736 .7669 L .61591 .71082 L 0 .529 .227 r
F
.6246 .89409 m .6375 1.10807 L .63473 1.01661 L 0 .644 .229 r
F
.62041 .89895 m .62628 .89152 L .62473 1.05022 L 0 .586 .223 r
F
.61736 .7669 m .62473 1.05016 L .61736 .76689 L 0 .529 .227 r
F
.61736 .7669 m .61736 .76689 L .61591 .71082 L F
.62028 .86677 m .61999 .86146 L .62025 .86054 L 0 .586 .223 r
F
.62283 .83794 m .62711 .79435 L .62642 .77606 L 0 .644 .229 r
F
.62079 .82066 m .62283 .83794 L .62454 .72636 L F
.62405 .79208 m .62437 .78276 L .62426 .79171 L 0 .586 .223 r
F
.62437 .78276 m .62456 .78236 L .62426 .79171 L F
.62405 .79208 m .62426 .79171 L .62283 .83794 L F
.62283 .83794 m .62481 .77406 L .62536 .77388 L F
.62283 .83794 m .62642 .77606 L .62454 .72636 L 0 .644 .229 r
F
.6159 .71081 m .61462 .75307 L .62473 1.05016 L 0 .529 .227 r
F
.61806 .99899 m .61513 .78782 L .6139 .85722 L 0 .501 .225 r
F
.61817 .99435 m .61513 .78782 L .61806 .99899 L F
.61613 .89606 m .61591 .71082 L .61843 .88235 L 0 .593 .223 r
F
.61591 .71082 m .61585 .66256 L .61716 .71778 L F
.61585 .66256 m .61568 .52638 L .61685 .67758 L F
.61585 .66256 m .61685 .67758 L .61716 .71778 L F
.62079 .82066 m .62454 .72636 L .62221 .66445 L 0 .644 .229 r
F
.62092 .73868 m .6222 .66441 L .62353 .71798 L 0 .593 .223 r
F
.61734 .5793 m .6222 .66434 L .6222 .66437 L 0 .919 .089 r
F
.61716 .71778 m .61611 .58248 L .62092 .73868 L 0 .593 .223 r
F
.61136 .44926 m .61302 .50228 L .6133 .50716 L 0 .537 .227 r
F
.61415 .53966 m .61417 .53982 L .61361 .52206 L F
.61359 .52186 m .61361 .52206 L .61296 .50157 L F
.62205 .85748 m .62283 .83794 L .62322 .84406 L 0 .586 .223 r
F
.62205 .85748 m .62322 .84406 L .62628 .89152 L F
.62283 .83794 m .62687 .79681 L .62628 .89152 L F
.62205 .85748 m .6222 .84642 L .62283 .83794 L F
.62092 .73867 m .62473 1.05016 L .62628 .89148 L 0 .529 .227 r
F
.61591 .71082 m .61312 .66195 L .61568 .52638 L 0 .593 .223 r
F
.60909 .42499 m .61568 .52628 L .61876 .59149 L 0 .919 .089 r
F
.60621 .33447 m .60756 .36456 L .61312 .66195 L 0 .548 .225 r
F
.60787 .40179 m .61264 .47787 L .60909 .42499 L 0 .919 .089 r
F
.61264 .47787 m .61568 .52628 L .61289 .48351 L F
.61264 .47787 m .61289 .48351 L .60909 .42499 L F
.61648 .61229 m .61591 .71082 L .62092 .73867 L 0 .529 .227 r
F
.61309 .69144 m .60621 .33447 L .61312 .66195 L 0 .548 .225 r
F
.61303 .68938 m .60621 .33447 L .61309 .69144 L F
.61178 .67633 m .60621 .33447 L .61309 .69253 L F
.61215 .76581 m .61314 .6932 L .61003 .65457 L 0 .501 .225 r
F
.6139 .85722 m .61314 .6932 L .61215 .76581 L F
.6139 .85722 m .61462 .75307 L .61314 .6932 L F
.62128 .87175 m .62181 .85551 L .62143 .86907 L 0 .586 .223 r
F
.62128 .87175 m .62177 .85219 L .62202 .84888 L F
.62111 .87501 m .62177 .85219 L .62128 .87175 L F
.62143 .86907 m .6222 .84642 L .62205 .85748 L F
.61591 .71082 m .62473 1.05016 L .62092 .73867 L 0 .529 .227 r
F
.61314 .6932 m .61462 .75307 L .61388 .7178 L 0 .501 .225 r
F
.61344 .69714 m .61462 .75307 L .6159 .71081 L 0 .529 .227 r
F
.61599 .78294 m .61344 .69714 L .61591 .71082 L 0 .593 .223 r
F
.61314 .6932 m .61388 .7178 L .61344 .69714 L 0 .501 .225 r
F
.61513 .78782 m .61462 .75307 L .61442 .78159 L F
.61513 .78782 m .61442 .78159 L .6139 .85722 L F
.61568 .91524 m .6161 .92987 L .61619 .92815 L 0 .813 .228 r
F
.61842 1.01097 m .61817 .99435 L .61806 .99899 L 0 .501 .225 r
F
.6161 .92987 m .61942 1.04395 L .61619 .92815 L 0 .813 .228 r
F
.61546 .91787 m .61942 1.04395 L .61568 .91524 L F
.61615 .90959 m .62082 1.04562 L .62078 .98542 L F
.61546 .91787 m .61344 .69714 L .61615 .90959 L 0 .593 .223 r
F
.61619 1.09854 m .60623 .65773 L .61212 1.0998 L 0 .501 .225 r
F
.60411 .27515 m .6088 .37254 L .60652 .27409 L 0 .646 .228 r
F
.6036 .27537 m .6088 .37254 L .60411 .27515 L F
.60647 .60445 m .59944 .2742 L .60423 .27363 L 0 .548 .225 r
F
.60623 .65773 m .60674 .61384 L .60467 .58855 L 0 .501 .225 r
F
.62237 1.37247 m .60674 .61384 L .60623 .65773 L F
.61589 .55037 m .61876 .59149 L .62091 .6409 L 0 .919 .089 r
F
.60749 .55027 m .60449 .296 L .60621 .33447 L 0 .548 .225 r
F
.60749 .55027 m .60621 .33447 L .60843 .47047 L F
.61314 .6932 m .61312 .66195 L .6133 .68159 L F
.61344 .69714 m .61312 .66195 L .61591 .71082 L 0 .593 .223 r
F
.61381 .63012 m .61344 .69714 L .6159 .71081 L 0 .529 .227 r
F
.61314 .6932 m .6133 .68159 L .61344 .69714 L 0 .548 .225 r
F
.61157 .47228 m .61427 .51422 L .61589 .55037 L 0 .919 .089 r
F
.61694 1.37316 m .60519 .74588 L .60816 1.01194 L 0 .501 .225 r
F
.60651 .61103 m .60108 .42116 L .60647 .60445 L 0 .548 .225 r
F
.60519 .74588 m .60153 .55043 L .60465 .79224 L 0 .501 .225 r
F
.60519 .74588 m .60465 .79224 L .60816 1.01194 L F
.60623 .65773 m .60467 .58855 L .60598 .67878 L F
.60623 .65773 m .60598 .67878 L .61212 1.0998 L F
.61093 1.34128 m .61093 1.34128 L .61154 1.3758 L 0 .223 .192 r
F
.60339 .91768 m .60339 .91793 L .60812 1.18337 L F
.60812 1.18337 m .60812 1.18337 L .61154 1.3758 L F
.60339 .91768 m .60768 1.15902 L .60768 1.15902 L F
.61156 1.37569 m .61151 1.37282 L .61151 1.37282 L F
.61126 1.3596 m .60735 1.13622 L .61155 1.3758 L F
.60813 1.18305 m .60326 .91005 L .60813 1.18305 L F
.61094 1.34054 m .60326 .91005 L .60339 .91768 L F
.61151 1.37282 m .61094 1.34052 L .61094 1.34054 L F
.60813 1.18305 m .60326 .91005 L .60813 1.18305 L F
.59998 .57033 m .59718 .27446 L .6006 .53903 L 0 .928 .09 r
F
.59952 .49387 m .60042 .54784 L .6006 .53903 L 0 0 .043 r
F
.60042 .54784 m .60816 1.01194 L .6006 .53903 L F
.61094 1.34052 m .60813 1.18305 L .61094 1.34054 L 0 .223 .192 r
F
.60813 1.18305 m .60813 1.18305 L .61094 1.34054 L F
.61151 1.37282 m .60813 1.18305 L .61151 1.37282 L F
.60813 1.18305 m .60813 1.18305 L .61151 1.37282 L F
.6034 .91857 m .61039 1.31096 L .61048 1.31612 L F
.6034 .91857 m .6036 .93051 L .61039 1.31096 L F
.60768 1.15902 m .60812 1.18337 L .60812 1.18337 L F
.60768 1.15902 m .60812 1.18337 L .60768 1.15902 L F
.6033 .91274 m .6034 .91857 L .60339 .91793 L F
.60339 .91768 m .6033 .91274 L .60339 .91793 L F
.60315 .90379 m .60113 .78379 L .60259 .87093 L F
.60113 .78379 m .60113 .78382 L .60259 .87093 L F
.60127 .79239 m .60122 .78994 L .60127 .79302 L 0 1 .196 r
F
.60122 .78944 m .60122 .78994 L .60127 .79239 L F
.60112 .7835 m .6015 .80807 L .60307 .90014 L 0 .223 .192 r
F
.60194 .83681 m .60199 .83967 L .60301 .89696 L F
.60307 .90014 m .60194 .83641 L .60301 .89696 L F
.60194 .83641 m .60194 .83681 L .60301 .89696 L F
.60261 .87463 m .60261 .87471 L .60301 .89696 L F
.60199 .83967 m .60261 .87471 L .60261 .87463 L F
.60199 .83967 m .602 .84067 L .60261 .87471 L F
.60331 .91362 m .6036 .93051 L .6034 .91857 L F
.6033 .91274 m .60307 .90014 L .60331 .91362 L F
.60301 .89696 m .603 .89673 L .60362 .93134 L F
.60301 .89696 m .60362 .93134 L .6036 .93019 L F
.60307 .90014 m .60174 .82352 L .60194 .83641 L F
.602 .84067 m .603 .89673 L .60301 .89696 L F
.60201 .84091 m .603 .89673 L .602 .84067 L F
.6035 .92416 m .60258 .86972 L .60273 .89444 L 0 .646 .228 r
F
.61156 1.37569 m .60365 .92684 L .60315 .90379 L 0 .223 .192 r
F
.61156 1.37569 m .60315 .90379 L .60326 .91005 L F
.60106 .77334 m .60106 .77411 L .60121 .78929 L 0 1 .196 r
F
.60329 .95679 m .60196 .83768 L .60309 .94834 L F
.60185 .83129 m .60199 .83967 L .60194 .83681 L 0 .223 .192 r
F
.60196 .83768 m .60191 .83486 L .60309 .94834 L 0 1 .196 r
F
.60329 .95679 m .602 .84069 L .60196 .83768 L F
.60127 .79302 m .60122 .78994 L .60147 .81571 L F
.60191 .83486 m .60264 .91281 L .60302 .94157 L F
.60194 .83641 m .60185 .83129 L .60194 .83681 L 0 .223 .192 r
F
.60188 .8328 m .60264 .91281 L .60191 .83486 L 0 1 .196 r
F
.60157 .8176 m .60141 .80229 L .60147 .81571 L F
.60141 .80229 m .60127 .79302 L .60147 .81571 L F
.602 .84589 m .60199 .86399 L .60201 .86547 L F
.602 .84589 m .60201 .86547 L .60264 .91281 L F
.59975 .70944 m .5993 .68366 L .59976 .71207 L 0 .223 .192 r
F
.59992 .72537 m .59988 .72091 L .60112 .7835 L 0 .267 .202 r
F
.59988 .72091 m .60112 .78303 L .60112 .7835 L F
.59975 .70566 m .60002 .72151 L .60003 .72225 L 0 .223 .192 r
F
.59975 .70566 m .59973 .70426 L .60002 .72151 L F
.59973 .70426 m .59857 .63837 L .59975 .70944 L F
.59857 .63837 m .59535 .45581 L .5993 .68366 L F
.59535 .45581 m .5938 .36806 L .59532 .45533 L F
.59535 .45581 m .59532 .45533 L .5993 .68366 L F
.60181 .82806 m .60156 .81896 L .60191 .84695 L 0 1 .196 r
F
.60217 .84541 m .60211 .85146 L .60211 .85189 L 0 .646 .228 r
F
.60233 .82754 m .60216 .84486 L .60217 .84541 L F
.59857 .63837 m .5993 .68366 L .59975 .70944 L 0 .223 .192 r
F
.60113 .78422 m .59861 .64078 L .60175 .83464 L 0 .288 .209 r
F
.60168 .81974 m .60154 .81694 L .60181 .82806 L 0 1 .196 r
F
.60154 .81694 m .60147 .81571 L .60156 .81896 L F
.60154 .81694 m .60156 .81896 L .60181 .82806 L F
.60229 .86413 m .60113 .78398 L .60175 .83464 L 0 .288 .209 r
F
.60114 .78446 m .60113 .78398 L .60229 .86413 L F
.60216 .84486 m .6021 .85106 L .60217 .84541 L 0 .646 .228 r
F
.60366 .98898 m .60331 .95763 L .60329 .95679 L 0 1 .196 r
F
.60367 .9899 m .60331 .95763 L .60366 .98898 L F
.60377 .99803 m .60331 .95763 L .6037 .99318 L F
.60329 .95679 m .60322 .95387 L .60345 .97242 L F
.60496 1.04915 m .60175 .83464 L .60352 .97787 L 0 .288 .209 r
F
.60229 .86413 m .60175 .83464 L .60496 1.04915 L F
.6021 .85106 m .60199 .86294 L .60211 .85146 L 0 .646 .228 r
F
.6021 .85106 m .60211 .85146 L .60217 .84541 L F
.60264 .91281 m .6029 .94055 L .60302 .94157 L 0 1 .196 r
F
.6029 .94055 m .60346 .99966 L .60306 .94721 L F
.6029 .94055 m .60306 .94721 L .60302 .94157 L F
.60165 .87402 m .60275 .93429 L .60723 1.34942 L 0 .267 .202 r
F
.60165 .87402 m .60723 1.34942 L .60722 1.35049 L F
.60722 1.35049 m .60723 1.34942 L .60753 1.37675 L F
.60128 .86882 m .60125 .85178 L .60753 1.37675 L F
.60125 .85178 m .60165 .87402 L .60753 1.37675 L F
.60334 1.08903 m .60189 .94187 L .60144 .89087 L F
.60613 1.37866 m .60128 .86882 L .60753 1.37675 L F
.60613 1.37866 m .60129 .87388 L .60128 .86882 L F
.6014 .88528 m .6014 .88528 L .60088 .83113 L F
.60088 .83113 m .60088 .83113 L .6004 .78111 L F
.6014 .88528 m .60088 .83113 L .60088 .83113 L F
.60126 .87008 m .60108 .86185 L .60129 .87388 L 0 .288 .209 r
F
.60088 .83112 m .6014 .88528 L .6014 .88528 L 0 .267 .202 r
F
.6004 .78111 m .60088 .83113 L .60088 .83112 L F
.60088 .83113 m .6014 .88528 L .60088 .83112 L F
.60075 .81811 m .60075 .81811 L .60088 .83114 L F
.60088 .83113 m .60088 .83114 L .60201 .94918 L F
.60075 .81811 m .60088 .83114 L .60088 .83113 L F
.60119 .86249 m .60113 .86215 L .60122 .86629 L 0 .288 .209 r
F
.60113 .86215 m .60108 .86185 L .60122 .86629 L F
.60122 .86629 m .60108 .86185 L .60126 .87008 L F
.60119 .86249 m .60039 .8232 L .60108 .86185 L F
.60039 .8232 m .59216 .41586 L .60054 .83596 L F
.60039 .8232 m .60054 .83596 L .60129 .87388 L F
.60227 .98779 m .6009 .93281 L .6028 1.04502 L F
.60221 .98115 m .6009 .93281 L .60227 .98779 L F
.59771 .69413 m .59709 .68738 L .59815 .74533 L F
.5987 .75459 m .59815 .74533 L .60205 .96027 L F
.59771 .69413 m .59815 .74533 L .5987 .75459 L F
.5989 .78684 m .59815 .74533 L .59877 .784 L F
.59815 .74533 m .59709 .68738 L .59808 .74448 L F
.59815 .74533 m .59808 .74448 L .59877 .784 L F
.59808 .74448 m .59867 .78181 L .59877 .784 L F
.59877 .784 m .59867 .78181 L .60122 .92573 L F
.60161 .93573 m .5989 .78684 L .60122 .92573 L F
.5989 .78684 m .59877 .784 L .60122 .92573 L F
.59957 .80068 m .60179 .939 L .60135 .90309 L F
.59771 .69413 m .59944 .79807 L .59957 .80068 L F
.59944 .79807 m .60179 .939 L .59957 .80068 L F
.60581 1.37936 m .60263 1.04733 L .60608 1.37926 L 0 .267 .202 r
F
.60263 1.04733 m .60278 1.04521 L .60608 1.37926 L F
.60465 1.22589 m .60331 1.08853 L .60334 1.08903 L F
.6047 1.23322 m .60323 1.0814 L .6047 1.23325 L F
.60323 1.0814 m .60323 1.08141 L .6047 1.23325 L F
.59771 .69413 m .60205 .96027 L .60179 .939 L 0 .288 .209 r
F
.60431 1.18853 m .60431 1.18853 L .60431 1.18804 L 0 .267 .202 r
F
.60431 1.18804 m .60431 1.18804 L .60179 .92642 L F
.60431 1.18853 m .60431 1.18804 L .60431 1.18804 L F
.60179 .92642 m .60179 .92642 L .60132 .87723 L F
.60431 1.18804 m .60179 .92642 L .60179 .92642 L F
.60132 .87721 m .60401 1.15759 L .60132 .87723 L F
.60401 1.15759 m .60431 1.18853 L .60401 1.15759 L F
.60401 1.15759 m .60401 1.15759 L .60132 .87723 L F
.60181 .92803 m .60431 1.18845 L .60431 1.18843 L F
.60349 1.10274 m .6036 1.11427 L .6036 1.11425 L F
.60349 1.10275 m .6036 1.11427 L .60349 1.10274 L F
.60132 .87713 m .60129 .87388 L .6036 1.11427 L F
.60132 .87723 m .60446 1.20366 L .60446 1.2044 L F
.60129 .87388 m .59771 .69413 L .60175 .92554 L 0 .288 .209 r
F
.60201 .94917 m .60476 1.23557 L .60476 1.23557 L 0 .267 .202 r
F
.60201 .94917 m .60476 1.23557 L .60476 1.23557 L F
.60201 .94917 m .60201 .94918 L .60476 1.23557 L F
.60201 .94917 m .60476 1.23557 L .60476 1.23557 L F
.60181 .92803 m .60179 .92653 L .6044 1.1985 L F
.60181 .92803 m .6044 1.1985 L .6044 1.19846 L F
.60148 .89418 m .60144 .89008 L .60448 1.2061 L F
.60448 1.20611 m .60448 1.2061 L .60471 1.23035 L F
.60148 .89418 m .60448 1.2061 L .60448 1.20611 L F
.60467 .58855 m .60268 .56434 L .61212 1.0998 L 0 .501 .225 r
F
.61351 1.37725 m .61286 1.36927 L .61286 1.36937 L 0 .646 .228 r
F
.61351 1.37725 m .61286 1.36935 L .61302 1.37726 L F
.613 1.37724 m .61287 1.37002 L .61304 1.37726 L 0 .223 .192 r
F
.61165 1.37574 m .60397 .86273 L .61659 1.37637 L 0 .727 .225 r
F
.60397 .86273 m .60536 .89444 L .61659 1.37637 L F
.59602 .30008 m .59575 .2775 L .59602 .29994 L 0 .646 .228 r
F
.60083 .73602 m .59821 .50274 L .60088 .74176 L 0 1 .196 r
F
.59821 .50274 m .59821 .50269 L .60088 .74176 L F
.59746 .43532 m .59745 .4353 L .59821 .50263 L F
.59821 .50269 m .59821 .50263 L .60088 .74176 L F
.59746 .43532 m .59821 .50263 L .59821 .50269 L F
.60139 .88502 m .6014 .88528 L .60179 .92653 L 0 .267 .202 r
F
.60139 .88502 m .60179 .92653 L .60181 .92803 L F
.6014 .88528 m .60201 .94918 L .6014 .88528 L F
.6014 .88528 m .60201 .94918 L .60201 .94917 L F
.6014 .88528 m .60201 .94918 L .6014 .88528 L F
.60302 .97017 m .60274 .93401 L .59938 .7844 L 0 .702 .227 r
F
.60302 .97017 m .59938 .7844 L .5974 .69637 L F
.60161 .93573 m .60122 .92573 L .60221 .98115 L 0 .288 .209 r
F
.60161 .93573 m .60221 .98115 L .60213 .9704 L F
.60461 1.18094 m .60302 .97017 L .5974 .69637 L 0 .702 .227 r
F
.60541 1.18099 m .60274 .93401 L .60461 1.18094 L F
.60264 .91281 m .60201 .86547 L .60276 .93466 L 0 1 .196 r
F
.6029 .94055 m .60276 .93466 L .60346 .99966 L F
.60264 .91281 m .60276 .93466 L .6029 .94055 L F
.5938 .36806 m .5938 .36796 L .5993 .68366 L 0 .223 .192 r
F
.5993 .68366 m .59368 .3611 L .59976 .71207 L F
.59861 .64078 m .59861 .64092 L .60175 .83464 L 0 .288 .209 r
F
.59861 .64078 m .59857 .63871 L .59861 .64092 L F
.60003 .74319 m .60003 .74314 L .60079 .82171 L 0 .267 .202 r
F
.60078 .82163 m .59991 .73074 L .60078 .82168 L F
.6004 .78111 m .60075 .81811 L .60075 .81811 L F
.6004 .78111 m .60075 .81811 L .6004 .78111 L F
.6005 .79163 m .6005 .79163 L .60075 .81811 L F
.60033 .77714 m .60034 .77703 L .60082 .82616 L F
.60072 .82328 m .5999 .73872 L .60082 .82616 L F
.60044 .7909 m .59989 .73434 L .60043 .79066 L F
.5999 .73872 m .59993 .73782 L .60082 .82616 L F
.60013 .75327 m .60014 .75321 L .6011 .8541 L F
.60013 .75327 m .6011 .8541 L .6011 .85398 L F
.60082 .82616 m .59991 .73307 L .59991 .73074 L F
.59491 .47341 m .59429 .42022 L .59705 .59114 L F
.60067 .80606 m .59169 .2794 L .60074 .81346 L 0 .288 .209 r
F
.59982 .72493 m .59981 .72333 L .60034 .77703 L 0 .267 .202 r
F
.59982 .72638 m .59982 .72493 L .60034 .77703 L F
.60003 .74376 m .60046 .78746 L .60045 .78748 L F
.60046 .78746 m .60046 .78746 L .60003 .74376 L F
.60003 .74376 m .60046 .78745 L .60003 .74376 L F
.60046 .78745 m .60046 .78746 L .60003 .74376 L F
.60003 .74319 m .60003 .74375 L .60003 .7432 L F
.60003 .74375 m .60003 .74376 L .60003 .7432 L F
.60003 .7432 m .60003 .74376 L .60003 .74376 L F
.59991 .73074 m .60003 .74319 L .60003 .7432 L F
.60001 .7409 m .60001 .74085 L .60003 .74314 L F
.60001 .7409 m .60003 .74314 L .60003 .74319 L F
.59991 .73074 m .60001 .74085 L .60001 .7409 L F
.60008 .7421 m .59939 .70419 L .60067 .80606 L 0 .288 .209 r
F
.59939 .70419 m .59169 .2794 L .60067 .80606 L F
.60008 .7421 m .60074 .81346 L .60123 .84291 L F
.6007 .83255 m .59398 .42008 L .60058 .83268 L F
.59342 .42129 m .59448 .47469 L .59446 .47891 L 0 0 .08 r
F
.59346 .42013 m .59448 .47469 L .59342 .42129 L F
.60058 .83268 m .59398 .42008 L .59216 .41586 L 0 .288 .209 r
F
.5938 .36791 m .5938 .36785 L .59978 .71539 L 0 .223 .192 r
F
.60112 .78366 m .59857 .63871 L .60113 .78422 L 0 .288 .209 r
F
.5938 .36785 m .59368 .3611 L .59365 .36316 L 0 .223 .192 r
F
.5938 .36785 m .59365 .36316 L .59358 .3683 L F
.59978 .71539 m .59358 .3683 L .59978 .71598 L F
.59358 .3683 m .59978 .71602 L .59978 .71598 L F
.59873 .65717 m .59873 .65744 L .59978 .71607 L F
.59873 .65717 m .59978 .71607 L .59978 .71602 L F
.59358 .3683 m .59358 .36836 L .59873 .65744 L F
.59358 .3683 m .59873 .65744 L .59873 .65717 L F
.59358 .3683 m .59223 .27873 L .59201 .28027 L F
.59368 .3611 m .59223 .27873 L .59358 .3683 L F
.59857 .63871 m .59222 .27874 L .59904 .67646 L 0 .288 .209 r
F
.59978 .71602 m .59978 .71636 L .59978 .71598 L 0 .223 .192 r
F
.59978 .71636 m .59979 .71662 L .59978 .71598 L F
.59978 .71598 m .59979 .71662 L .59979 .71663 L F
.59976 .71613 m .59976 .71599 L .59979 .71885 L 0 .267 .202 r
F
.59979 .71942 m .59979 .71885 L .59991 .73074 L F
.59977 .71966 m .59976 .71659 L .59991 .73074 L F
.59857 .63871 m .59904 .67646 L .60175 .83464 L 0 .288 .209 r
F
.59977 .71981 m .59977 .71966 L .59981 .72333 L 0 .267 .202 r
F
.59991 .73307 m .59977 .71966 L .59991 .73074 L F
.59991 .73074 m .59991 .73054 L .60001 .74085 L F
.59358 .3683 m .59201 .28027 L .59358 .36836 L 0 .223 .192 r
F
.60175 .83464 m .59222 .27874 L .59169 .2794 L 0 .288 .209 r
F
.59984 .75321 m .59861 .64081 L .60111 .78302 L 0 .789 .222 r
F
.60122 .83704 m .60199 .86357 L .60275 .93429 L 0 .267 .202 r
F
.60122 .83704 m .60275 .93429 L .60165 .87402 L F
.60117 .80901 m .60199 .86357 L .60122 .83704 L F
.60117 .80901 m .60112 .7835 L .60199 .86357 L F
.60274 .93401 m .60111 .78261 L .59957 .72318 L 0 .702 .227 r
F
.60078 .82168 m .60079 .82171 L .60087 .83014 L 0 .267 .202 r
F
.60078 .82168 m .60087 .83014 L .60086 .82963 L F
.60075 .81801 m .60079 .82171 L .60075 .81801 L F
.60075 .81796 m .60079 .82171 L .60078 .82168 L F
.60075 .81801 m .60079 .82171 L .60075 .81796 L F
.60075 .81801 m .60079 .82171 L .60075 .81801 L F
.60082 .82616 m .60078 .82163 L .60083 .8263 L F
.60078 .82163 m .60078 .82168 L .60083 .8263 L F
.60108 .85281 m .60082 .82616 L .60108 .85296 L F
.60082 .82616 m .60083 .8263 L .60108 .85296 L F
.60074 .81346 m .59169 .2794 L .60116 .85999 L 0 .288 .209 r
F
.60116 .85999 m .59169 .2794 L .60119 .86249 L F
.59883 .72978 m .59222 .27873 L .59861 .64081 L 0 .789 .222 r
F
.59883 .72978 m .59861 .64081 L .59984 .75321 L F
.60753 1.37675 m .60541 1.18099 L .60461 1.18094 L 0 .702 .227 r
F
.6009 .93281 m .60014 .92133 L .60221 1.05305 L 0 .288 .209 r
F
.59709 .68738 m .59803 .74381 L .59808 .74448 L F
.59803 .74381 m .59867 .78181 L .59808 .74448 L F
.59709 .68738 m .59699 .6874 L .59798 .74306 L F
.59803 .74381 m .59798 .74306 L .59867 .78181 L F
.59709 .68738 m .59798 .74306 L .59803 .74381 L F
.60431 1.18853 m .60446 1.20366 L .60431 1.18853 L 0 .267 .202 r
F
.60431 1.18843 m .60446 1.20449 L .60446 1.20447 L F
.60431 1.18845 m .60446 1.20449 L .60431 1.18843 L F
.60382 1.13717 m .60448 1.20583 L .60448 1.20662 L F
.60382 1.13718 m .60486 1.24642 L .60382 1.13717 L F
.60357 1.11104 m .60424 1.18155 L .60424 1.18152 L F
.60424 1.18155 m .60476 1.23561 L .60424 1.18152 L F
.60424 1.18152 m .60476 1.23561 L .60476 1.23559 L F
.60357 1.11104 m .60476 1.23561 L .60357 1.11104 L F
.6036 1.11425 m .6036 1.11427 L .60446 1.20366 L F
.60446 1.2044 m .60446 1.20366 L .60476 1.23561 L F
.6044 1.19846 m .6044 1.1985 L .60527 1.28859 L F
.59702 .68739 m .59697 .68615 L .59699 .6874 L 0 .288 .209 r
F
.59709 .68738 m .59697 .68615 L .59702 .68739 L F
.59709 .68738 m .59216 .41586 L .59697 .68615 L F
.60753 1.37675 m .5974 .69637 L .59403 .61767 L 0 .702 .227 r
F
.60456 1.21531 m .60468 1.22694 L .60468 1.22699 L 0 .267 .202 r
F
.60456 1.21526 m .60468 1.22694 L .60456 1.21531 L F
.60468 1.22694 m .60506 1.26725 L .60468 1.22699 L F
.58099 .28457 m .5811 .3241 L .58145 .28454 L 0 .005 .124 r
F
.5811 .3241 m .58246 .37633 L .5827 .373 L F
.58246 .37633 m .58353 .41744 L .5827 .373 L F
.58146 .28372 m .58316 .49824 L .58213 .28379 L 0 0 .073 r
F
.58213 .28379 m .58316 .49824 L .59216 .41586 L F
.58087 .2845 m .5811 .3241 L .58099 .28457 L 0 .005 .124 r
F
.58173 .27985 m .58065 .62185 L .58023 .28042 L 0 0 .075 r
F
.58437 .27886 m .58134 .55834 L .58173 .27985 L F
.58134 .55834 m .58065 .62185 L .58173 .27985 L F
.58753 .27792 m .58065 .62185 L .58437 .27886 L F
.58753 .27792 m .58955 .46124 L .58065 .62185 L F
.58955 .46124 m .58445 .58621 L .58065 .62185 L F
.59032 .53109 m .58168 .65401 L .58065 .62185 L F
.57995 .28134 m .57987 .40706 L .57973 .28209 L F
.57035 .56383 m .57705 .30918 L .57987 .40706 L 0 .032 .122 r
F
.58011 .71169 m .58052 .71322 L .58075 .70505 L 0 .396 .268 r
F
.58052 .71322 m .58108 .70843 L .58075 .70505 L F
.58045 .71395 m .58052 .71322 L .58088 .7108 L 0 0 .101 r
F
.58052 .71322 m .58112 .70803 L .58088 .7108 L F
.58006 .71916 m .57983 .72037 L .58031 .7166 L F
.57961 .7226 m .57983 .72037 L .58006 .71916 L F
.58031 .7166 m .58011 .7175 L .58065 .71317 L F
.57983 .72037 m .58011 .7175 L .58031 .7166 L F
.58065 .71317 m .58045 .71395 L .58088 .7108 L F
.58011 .7175 m .58045 .71395 L .58065 .71317 L F
.57935 .72043 m .57959 .71879 L .57931 .72076 L 0 0 .081 r
F
.58075 .70505 m .58108 .70843 L .58129 .70659 L 0 .396 .268 r
F
.58088 .7108 m .5811 .70825 L .58129 .70659 L 0 0 .101 r
F
.58483 .90221 m .58638 .83872 L .58872 .91668 L 0 .145 .158 r
F
.57336 .52632 m .58483 .90221 L .58881 .85487 L 0 .09 .148 r
F
.58483 .90221 m .58855 1.02391 L .58872 .91668 L F
.58483 .90221 m .58872 .91668 L .58881 .85487 L F
.5835 1.0233 m .59007 1.21527 L .59016 1.21647 L 0 0 .1 r
F
.59392 1.31846 m .59415 1.32618 L .5915 1.25096 L F
.59315 1.29608 m .59045 1.22036 L .59049 1.22097 L F
.59045 1.22036 m .5891 1.1827 L .59049 1.22097 L F
.59049 1.22097 m .5891 1.1827 L .5891 1.18164 L F
.59033 1.22175 m .59027 1.21794 L .59049 1.22091 L 0 .877 .163 r
F
.59319 1.29757 m .5891 1.1827 L .59315 1.29608 L 0 0 .1 r
F
.59351 1.30653 m .5915 1.25096 L .59167 1.25502 L F
.59356 1.30859 m .5915 1.25096 L .59351 1.30653 L F
.59012 1.23142 m .59048 1.22486 L .59088 1.23312 L 0 .877 .163 r
F
.58908 1.1809 m .58895 1.17724 L .58907 1.1779 L 0 0 .1 r
F
.58895 1.17724 m .5835 1.0233 L .58904 1.17697 L F
.58895 1.17724 m .58904 1.17697 L .58907 1.1779 L F
.58908 1.1811 m .58908 1.1809 L .58908 1.17809 L F
.58908 1.1809 m .58907 1.1779 L .58908 1.17809 L F
.5891 1.18164 m .5891 1.1827 L .58907 1.18166 L F
.58907 1.18061 m .58907 1.18166 L .5835 1.0233 L F
.5891 1.18164 m .58907 1.18166 L .58907 1.18061 L F
.59167 1.25502 m .5915 1.25096 L .5891 1.1827 L F
.5835 1.0233 m .59217 1.26991 L .58786 1.14044 L F
.59217 1.26991 m .59281 1.288 L .59225 1.2714 L F
.59217 1.26991 m .59225 1.2714 L .58786 1.14044 L F
.59002 1.23121 m .59007 1.23055 L .59012 1.23142 L 0 .877 .163 r
F
.59007 1.23055 m .59048 1.22486 L .59012 1.23142 L F
.58071 1.07542 m .58101 1.07828 L .58087 1.07702 L 0 0 .105 r
F
.58101 1.07828 m .58112 1.07937 L .58087 1.07702 L F
.58071 1.07542 m .58087 1.07702 L .58067 1.07514 L F
.58064 1.07486 m .5812 1.08026 L .5807 1.07517 L F
.58124 1.08069 m .58123 1.08063 L .58127 1.08069 L 0 .67 .126 r
F
.58125 1.08059 m .58127 1.08069 L .58123 1.08063 L 0 .601 .12 r
F
.58121 1.08037 m .58123 1.08063 L .5807 1.07993 L F
.5812 1.08026 m .58121 1.08037 L .581 1.08019 L F
.58064 1.07926 m .58098 1.07988 L .5807 1.07993 L F
.58098 1.07988 m .581 1.08019 L .5807 1.07993 L F
.58199 1.08066 m .58444 1.11544 L .58257 1.08864 L 0 0 .123 r
F
.57943 1.12447 m .58483 .90221 L .59013 .96375 L 0 .145 .158 r
F
.58483 .90221 m .58872 .91668 L .59013 .96375 L F
.57029 .69856 m .57769 .73223 L .57842 .72701 L 0 .421 .28 r
F
.57769 .73223 m .57775 .73247 L .57842 .72701 L F
.57336 .52632 m .5758 .64942 L .58222 .86146 L 0 .09 .148 r
F
.57035 .56383 m .57987 .40706 L .58053 .58892 L 0 .032 .122 r
F
.57929 .61416 m .58053 .58892 L .58065 .62185 L F
.57035 .56383 m .58053 .58892 L .57929 .61416 L F
.57756 .73319 m .5776 .7329 L .57353 .72167 L 0 .462 .294 r
F
.56972 .71641 m .57641 .73824 L .57672 .73537 L F
.56819 .60425 m .56589 .61276 L .56635 .62261 L 0 1 .319 r
F
.56228 .62476 m .56926 .62721 L .56635 .62261 L 0 1 .329 r
F
.56228 .62476 m .56927 .63635 L .56926 .62721 L F
.56927 .63635 m .56612 .65373 L .56866 .65919 L 0 1 .339 r
F
.56927 .63635 m .56638 .64393 L .56612 .65373 L F
.56228 .62476 m .56638 .64393 L .56927 .63635 L 0 1 .329 r
F
.55531 .61655 m .562 .6168 L .55911 .61364 L 0 1 .318 r
F
.55531 .61655 m .56228 .62476 L .562 .6168 L F
.55531 .61655 m .55975 .63223 L .56228 .62476 L F
.55706 .62189 m .56796 .60981 L .56425 .60366 L 0 .713 .287 r
F
.56796 .60981 m .56862 .62485 L .57255 .64309 L 0 .445 .259 r
F
.55706 .62189 m .56862 .62485 L .56796 .60981 L 0 .713 .287 r
F
.56228 .62476 m .5623 .6461 L .56638 .64393 L 0 1 .329 r
F
.56228 .62476 m .55976 .64138 L .5623 .6461 L F
.56228 .62476 m .55975 .63223 L .55976 .64138 L F
.55706 .62189 m .56575 .63632 L .56862 .62485 L 0 .713 .287 r
F
.55581 .64277 m .5623 .6461 L .55976 .64138 L 0 1 .339 r
F
.55811 .64274 m .56941 .64563 L .56575 .63632 L 0 .634 .287 r
F
.55581 .64277 m .56187 .65461 L .5623 .6461 L 0 1 .339 r
F
.55811 .64274 m .5698 .65829 L .56941 .64563 L 0 .634 .287 r
F
.56941 .64563 m .5698 .65829 L .57361 .67761 L 0 .395 .26 r
F
.57019 .6753 m .57031 .6853 L .57393 .70302 L 0 .396 .268 r
F
.56358 .56504 m .57419 .71974 L .5758 .64942 L 0 .273 .213 r
F
.56187 .65461 m .56866 .65919 L .56612 .65373 L 0 1 .35 r
F
.56187 .65461 m .56793 .66819 L .56866 .65919 L F
.56793 .66819 m .56554 .68965 L .5701 .68917 L 0 1 .359 r
F
.55811 .64274 m .56665 .66453 L .5698 .65829 L 0 .634 .287 r
F
.56793 .66819 m .56339 .68393 L .56554 .68965 L 0 1 .359 r
F
.56793 .66819 m .56442 .67473 L .56339 .68393 L F
.56187 .65461 m .56442 .67473 L .56793 .66819 L 0 1 .35 r
F
.56187 .65461 m .56016 .67562 L .56442 .67473 L F
.56187 .65461 m .55801 .67026 L .56016 .67562 L F
.56187 .65461 m .55874 .66125 L .55801 .67026 L F
.55868 .66232 m .57019 .6753 L .56665 .66453 L 0 .602 .29 r
F
.55868 .66232 m .57031 .6853 L .57019 .6753 L F
.55868 .66232 m .56692 .68747 L .57031 .6853 L F
.56358 .56504 m .56957 .68639 L .57419 .71974 L 0 .273 .213 r
F
.57035 .56383 m .57527 .68123 L .57317 .67102 L 0 .032 .122 r
F
.56358 .56504 m .56504 .61988 L .56957 .68639 L 0 .273 .213 r
F
.57757 .73314 m .57762 .73296 L .57757 .73332 L 0 0 .054 r
F
.57757 .73309 m .57762 .73296 L .57757 .73314 L F
.57756 .73319 m .57762 .73296 L .5776 .7329 L 0 .462 .294 r
F
.57756 .73319 m .57736 .73463 L .57757 .73309 L 0 0 .054 r
F
.57736 .73458 m .57736 .73463 L .57756 .73319 L F
.57775 .73247 m .57776 .73253 L .57781 .73227 L 0 .421 .28 r
F
.57751 .73349 m .57757 .73309 L .57757 .73332 L 0 0 .054 r
F
.5773 .73509 m .5773 .73506 L .57731 .73498 L F
.57729 .73517 m .5773 .73506 L .5773 .73509 L F
.57729 .73517 m .57728 .73522 L .5773 .73506 L F
.57706 .73679 m .57711 .73643 L .57727 .73528 L F
.57711 .73643 m .57729 .73518 L .57727 .73528 L F
.57751 .73349 m .57757 .73332 L .5739 .75951 L F
.56972 .71641 m .57243 .73554 L .57587 .74442 L 0 .462 .294 r
F
.56972 .71641 m .57587 .74442 L .57589 .74436 L F
.57029 .69856 m .57014 .70624 L .57353 .72167 L 0 .421 .28 r
F
.56704 .69903 m .57913 .81554 L .57419 .71974 L 0 .146 .172 r
F
.57397 .94109 m .58178 .72301 L .57959 .66544 L 0 .191 .184 r
F
.57536 .68336 m .58065 .62185 L .57959 .66544 L 0 .032 .122 r
F
.57035 .56383 m .57929 .61416 L .57536 .68336 L F
.57929 .61416 m .58065 .62185 L .57536 .68336 L F
.57536 .68336 m .57959 .66544 L .57597 .5705 L 0 .191 .184 r
F
.57587 .74445 m .57585 .74451 L .57587 .74442 L 0 0 .054 r
F
.57587 .74445 m .57587 .74442 L .57589 .74435 L F
.57574 .74479 m .57573 .74494 L .57575 .74481 L 0 .512 .31 r
F
.57565 .7446 m .57563 .74507 L .57574 .74479 L F
.57397 .94109 m .57959 .66544 L .57536 .68336 L 0 .191 .184 r
F
.57536 .68336 m .57959 .66544 L .57776 .74059 L 0 .032 .122 r
F
.55873 .67977 m .57029 .69856 L .56692 .68747 L 0 .601 .296 r
F
.56704 .69903 m .57419 .71974 L .56957 .68639 L 0 .146 .172 r
F
.5753 .69493 m .57535 .68545 L .57368 .7278 L 0 .191 .184 r
F
.57535 .68545 m .57528 .68552 L .57368 .7278 L F
.57536 .68336 m .57397 .70797 L .57368 .7278 L F
.55581 .64277 m .55874 .66125 L .56187 .65461 L 0 1 .339 r
F
.55531 .61655 m .55595 .63516 L .55975 .63223 L 0 1 .318 r
F
.55553 .60129 m .55993 .61046 L .56425 .60366 L 0 .84 .285 r
F
.55553 .60129 m .5562 .60944 L .55993 .61046 L F
.54835 .61296 m .55531 .61655 L .55477 .61038 L 0 1 .303 r
F
.54835 .61296 m .55314 .62359 L .55531 .61655 L F
.54835 .61296 m .55477 .61038 L .55188 .60919 L F
.55259 .59628 m .55188 .60919 L .55477 .61038 L 0 1 .295 r
F
.55259 .59628 m .55094 .60314 L .55188 .60919 L F
.54835 .61296 m .54961 .62738 L .55314 .62359 L 0 1 .303 r
F
.54835 .61296 m .54708 .62537 L .54961 .62738 L F
.54835 .61296 m .54654 .61918 L .54708 .62537 L F
.54504 .62686 m .55553 .60129 L .55193 .6037 L 0 .993 .302 r
F
.54504 .62686 m .5562 .60944 L .55553 .60129 L F
.55706 .62189 m .56425 .60366 L .55993 .61046 L 0 .713 .287 r
F
.54371 .62808 m .54961 .62738 L .54708 .62537 L 0 1 .31 r
F
.54504 .62686 m .55346 .6212 L .5562 .60944 L 0 .993 .302 r
F
.55706 .62189 m .56126 .63654 L .56575 .63632 L 0 .713 .287 r
F
.55706 .62189 m .55754 .63035 L .56126 .63654 L F
.55811 .64274 m .56575 .63632 L .56126 .63654 L 0 .634 .287 r
F
.55811 .64274 m .56205 .66015 L .56665 .66453 L F
.55367 .59807 m .56291 .65699 L .56504 .61988 L 0 .397 .236 r
F
.55531 .61655 m .55342 .63157 L .55595 .63516 L 0 1 .318 r
F
.55531 .61655 m .55314 .62359 L .55342 .63157 L F
.54371 .62808 m .54975 .63357 L .54961 .62738 L 0 1 .31 r
F
.54371 .62808 m .54741 .63983 L .54975 .63357 L F
.54371 .62808 m .54404 .64256 L .54741 .63983 L F
.54614 .63786 m .55706 .62189 L .55346 .6212 L 0 .912 .306 r
F
.54975 .63357 m .55595 .63516 L .55342 .63157 L 0 1 .327 r
F
.54975 .63357 m .55581 .64277 L .55595 .63516 L F
.54975 .63357 m .55307 .64934 L .55581 .64277 L F
.54975 .63357 m .54941 .65135 L .55307 .64934 L F
.54975 .63357 m .54726 .64745 L .54941 .65135 L F
.54975 .63357 m .54741 .63983 L .54726 .64745 L F
.54614 .63786 m .55754 .63035 L .55706 .62189 L 0 .912 .306 r
F
.54614 .63786 m .55456 .63947 L .55754 .63035 L F
.55581 .64277 m .55479 .66265 L .55874 .66125 L 0 1 .339 r
F
.55581 .64277 m .55264 .65786 L .55479 .66265 L F
.55581 .64277 m .55307 .64934 L .55264 .65786 L F
.54378 .6487 m .54941 .65135 L .54726 .64745 L 0 1 .336 r
F
.5469 .64947 m .55811 .64274 L .55456 .63947 L 0 .844 .308 r
F
.55811 .64274 m .5584 .65082 L .56205 .66015 L 0 .634 .287 r
F
.5469 .64947 m .5584 .65082 L .55811 .64274 L 0 .844 .308 r
F
.55367 .59807 m .5586 .6508 L .56291 .65699 L 0 .397 .236 r
F
.54884 .65861 m .55479 .66265 L .55264 .65786 L 0 1 .35 r
F
.54884 .65861 m .55391 .67059 L .55479 .66265 L F
.54884 .65861 m .55059 .6764 L .55391 .67059 L F
.54884 .65861 m .54679 .67715 L .55059 .6764 L F
.54884 .65861 m .54506 .67234 L .54679 .67715 L F
.54884 .65861 m .54594 .66439 L .54506 .67234 L F
.54378 .6487 m .54594 .66439 L .54884 .65861 L 0 1 .336 r
F
.54729 .66111 m .55868 .66232 L .5552 .65712 L 0 .799 .31 r
F
.54729 .66111 m .55876 .66959 L .55868 .66232 L F
.55868 .66232 m .56665 .66453 L .56205 .66015 L 0 .602 .29 r
F
.55868 .66232 m .56229 .68037 L .56692 .68747 L F
.55868 .66232 m .55876 .66959 L .56229 .68037 L F
.55599 .66614 m .56291 .65699 L .5586 .6508 L 0 .269 .218 r
F
.55391 .67059 m .56016 .67562 L .55801 .67026 L 0 1 .362 r
F
.55391 .67059 m .55524 .68963 L .55898 .68392 L F
.55391 .67059 m .55113 .68997 L .55524 .68963 L F
.55391 .67059 m .5494 .68471 L .55113 .68997 L F
.55391 .67059 m .55059 .6764 L .5494 .68471 L F
.54729 .66111 m .55539 .67327 L .55876 .66959 L 0 .799 .31 r
F
.55873 .67977 m .56692 .68747 L .56229 .68037 L 0 .601 .296 r
F
.55599 .66614 m .56704 .69903 L .56291 .65699 L 0 .269 .218 r
F
.55806 .65606 m .5669 .61494 L .56894 .66418 L 0 .308 .195 r
F
.55898 .68392 m .55373 .69807 L .55547 .7036 L 0 1 .371 r
F
.55898 .68392 m .55524 .68963 L .55373 .69807 L F
.5473 .67232 m .55873 .67977 L .55539 .67327 L 0 .777 .313 r
F
.5473 .67232 m .55861 .68607 L .55873 .67977 L F
.55873 .67977 m .56197 .69715 L .56657 .70563 L 0 .601 .296 r
F
.55873 .67977 m .55861 .68607 L .56197 .69715 L F
.55827 .6948 m .56657 .70563 L .56197 .69715 L 0 .619 .304 r
F
.55827 .6948 m .56109 .71089 L .56561 .71992 L F
.55731 .70747 m .56561 .71992 L .56109 .71089 L 0 .65 .314 r
F
.55731 .70747 m .56405 .73119 L .56784 .73464 L F
.55599 .66614 m .56826 .74956 L .56704 .69903 L 0 .269 .218 r
F
.56953 .77555 m .56973 .77493 L .5699 .77428 L 0 0 0 r
F
.56973 .77493 m .57007 .77374 L .5699 .77428 L F
.56704 .69903 m .56826 .74956 L .57312 .84611 L 0 .146 .172 r
F
.55367 .77503 m .56042 .78206 L .55923 .77681 L 0 1 .425 r
F
.5561 .75376 m .54595 .77462 L .55174 .76896 L 0 1 .347 r
F
.5535 .74799 m .56014 .74477 L .55898 .74247 L 0 1 .337 r
F
.5535 .74799 m .5561 .75376 L .56014 .74477 L F
.5561 .75376 m .54519 .77241 L .54595 .77462 L 0 1 .347 r
F
.5561 .75376 m .54954 .76346 L .54519 .77241 L F
.5535 .74799 m .54954 .76346 L .5561 .75376 L 0 1 .337 r
F
.56136 .73903 m .55443 .75593 L .55958 .75687 L 0 1 .404 r
F
.56136 .73903 m .55319 .75058 L .55443 .75593 L F
.56136 .73903 m .55616 .74333 L .55319 .75058 L F
.55752 .72537 m .56136 .73903 L .56402 .73165 L 0 1 .399 r
F
.55088 .74221 m .55723 .739 L .55607 .73668 L 0 1 .321 r
F
.55088 .74221 m .5535 .74799 L .55723 .739 L F
.55752 .72537 m .55616 .74333 L .56136 .73903 L 0 1 .399 r
F
.55752 .72537 m .56402 .73165 L .56236 .72612 L F
.55351 .71132 m .55981 .7177 L .55807 .71202 L 0 1 .392 r
F
.55351 .71132 m .55752 .72537 L .55981 .7177 L F
.55731 .70747 m .55967 .72208 L .56405 .73119 L 0 .65 .314 r
F
.55585 .71803 m .56405 .73119 L .55967 .72208 L 0 .687 .325 r
F
.55585 .71803 m .56666 .74069 L .56405 .73119 L F
.55585 .71803 m .56576 .74423 L .56666 .74069 L F
.55585 .71803 m .56193 .74016 L .56576 .74423 L F
.55752 .72537 m .55132 .74259 L .55616 .74333 L 0 1 .399 r
F
.55752 .72537 m .55007 .73729 L .55132 .74259 L F
.55752 .72537 m .55273 .7299 L .55007 .73729 L F
.55351 .71132 m .55273 .7299 L .55752 .72537 L 0 1 .392 r
F
.55585 .71803 m .55774 .73119 L .56193 .74016 L 0 .687 .325 r
F
.55392 .72677 m .56193 .74016 L .55774 .73119 L 0 .727 .335 r
F
.55392 .72677 m .56423 .74898 L .56193 .74016 L F
.55392 .72677 m .56309 .75177 L .56423 .74898 L F
.55392 .72677 m .55927 .74733 L .56309 .75177 L F
.55154 .73396 m .56122 .75553 L .55927 .74733 L 0 .769 .346 r
F
.55154 .73396 m .55987 .75775 L .56122 .75553 L F
.5473 .67232 m .5551 .68751 L .55861 .68607 L 0 .777 .313 r
F
.55827 .6948 m .55795 .70013 L .56109 .71089 L 0 .619 .304 r
F
.56122 .75553 m .56919 .7697 L .56521 .76065 L 0 .684 .355 r
F
.56423 .74898 m .56309 .75177 L .56521 .76065 L 0 .626 .341 r
F
.56423 .74898 m .56521 .76065 L .56919 .7697 L F
.56666 .74069 m .56576 .74423 L .56824 .75423 L 0 .568 .326 r
F
.55599 .66614 m .56562 .76533 L .56826 .74956 L 0 .269 .218 r
F
.54548 .68456 m .55113 .68997 L .5494 .68471 L 0 1 .374 r
F
.54695 .68278 m .55827 .6948 L .5551 .68751 L 0 .773 .316 r
F
.54695 .68278 m .55795 .70013 L .55827 .6948 L F
.55599 .66614 m .56091 .73542 L .56562 .76533 L 0 .269 .218 r
F
.5495 .69763 m .55547 .7036 L .55373 .69807 L 0 1 .384 r
F
.54548 .68456 m .5495 .69763 L .55113 .68997 L 0 1 .374 r
F
.54695 .68278 m .55434 .69978 L .55795 .70013 L 0 .773 .316 r
F
.55731 .70747 m .55679 .71192 L .55967 .72208 L 0 .65 .314 r
F
.55599 .66614 m .55679 .69295 L .56091 .73542 L 0 .269 .218 r
F
.55101 .76234 m .55367 .77503 L .55745 .76899 L 0 1 .423 r
F
.55101 .76234 m .55745 .76899 L .55626 .76382 L F
.5537 .76481 m .56088 .77771 L .55752 .76975 L 0 .792 .377 r
F
.5537 .76481 m .56185 .78442 L .56088 .77771 L F
.5537 .76481 m .55977 .78539 L .56185 .78442 L F
.56185 .78442 m .55977 .78539 L .56046 .7914 L 0 .744 .39 r
F
.5577 .76072 m .55752 .76975 L .56088 .77771 L 0 .74 .367 r
F
.5577 .76072 m .56532 .77418 L .56163 .76573 L F
.5577 .76072 m .56668 .78147 L .56532 .77418 L F
.5577 .76072 m .56481 .78274 L .56668 .78147 L F
.5577 .76072 m .56088 .77771 L .56481 .78274 L F
.56122 .75553 m .55987 .75775 L .56163 .76573 L 0 .684 .355 r
F
.56122 .75553 m .56163 .76573 L .56532 .77418 L F
.55701 .81378 m .5537 .82159 L .55586 .81978 L 0 1 .179 r
F
.55218 .83515 m .55654 .81599 L .56023 .80435 L 0 0 .057 r
F
.55785 .73082 m .56562 .76533 L .56091 .73542 L 0 .213 .201 r
F
.56459 .79293 m .56673 .78483 L .56729 .78311 L 0 0 0 r
F
.56185 .80011 m .56634 .78621 L .56188 .79999 L F
.56361 .79464 m .56544 .789 L .56634 .78621 L F
.56703 .78402 m .56753 .78251 L .5681 .78072 L F
.56672 .78545 m .56621 .78986 L .56732 .78515 L 0 1 .146 r
F
.56717 .7843 m .56727 .78489 L .56737 .78353 L 0 .675 .379 r
F
.56737 .78353 m .56727 .78489 L .56751 .78394 L F
.56672 .78545 m .56771 .78313 L .56779 .78281 L 0 1 .146 r
F
.56706 .78627 m .56709 .78609 L .56711 .78604 L 0 0 0 r
F
.56672 .78545 m .56764 .78351 L .56771 .78313 L 0 1 .146 r
F
.56709 .78609 m .56846 .77885 L .56711 .78604 L 0 0 0 r
F
.56672 .78545 m .56754 .78404 L .56764 .78351 L 0 1 .146 r
F
.56778 .7817 m .5681 .78072 L .56778 .7817 L 0 0 0 r
F
.56706 .78627 m .56614 .78875 L .56846 .77885 L F
.55785 .73082 m .56985 .8165 L .56562 .76533 L 0 .213 .201 r
F
.56525 .78956 m .56516 .7898 L .56274 .7973 L 0 0 0 r
F
.56264 .79765 m .56525 .78956 L .56274 .7973 L F
.56371 .79433 m .56544 .789 L .56361 .79464 L F
.56466 .79149 m .56469 .79141 L .56488 .79089 L F
.56467 .79146 m .5649 .79083 L .56553 .78875 L F
.56467 .79146 m .56488 .79089 L .5649 .79083 L F
.56466 .79149 m .56488 .79089 L .56467 .79146 L F
.56459 .79293 m .56345 .79604 L .56545 .78888 L F
.55785 .73082 m .57073 .8549 L .56985 .8165 L 0 .213 .201 r
F
.56158 .80093 m .56371 .79433 L .56361 .79464 L 0 0 0 r
F
.56268 .80146 m .56351 .79922 L .56348 .79913 L 0 .922 .142 r
F
.55392 .72677 m .55531 .73862 L .55927 .74733 L 0 .727 .335 r
F
.55154 .73396 m .55927 .74733 L .55531 .73862 L 0 .769 .346 r
F
.55785 .73082 m .56761 .85004 L .57073 .8549 L 0 .213 .201 r
F
.55154 .73396 m .5561 .75308 L .55987 .75775 L 0 .769 .346 r
F
.55785 .73082 m .56261 .80538 L .56761 .85004 L 0 .213 .201 r
F
.55785 .73082 m .55845 .75447 L .56261 .80538 L F
.5535 .74799 m .54405 .76902 L .54954 .76346 L 0 1 .337 r
F
.5535 .74799 m .54329 .7667 L .54405 .76902 L F
.5535 .74799 m .54734 .75768 L .54329 .7667 L F
.55088 .74221 m .54734 .75768 L .5535 .74799 L 0 1 .321 r
F
.55634 .7879 m .54609 .80113 L .55195 .80328 L 0 1 .423 r
F
.55634 .7879 m .54531 .7961 L .54609 .80113 L F
.55634 .7879 m .5497 .79043 L .54531 .7961 L F
.55367 .77503 m .5497 .79043 L .55634 .7879 L 0 1 .425 r
F
.55367 .77503 m .54415 .78865 L .5497 .79043 L F
.55367 .77503 m .54337 .78375 L .54415 .78865 L F
.55367 .77503 m .54745 .77791 L .54337 .78375 L F
.55101 .76234 m .54745 .77791 L .55367 .77503 L 0 1 .423 r
F
.55101 .76234 m .5422 .77644 L .54745 .77791 L F
.55101 .76234 m .54142 .7716 L .5422 .77644 L F
.55101 .76234 m .5452 .76555 L .54142 .7716 L F
.55088 .74221 m .54214 .76324 L .54734 .75768 L 0 1 .321 r
F
.54822 .7492 m .5452 .76555 L .55101 .76234 L 0 1 .419 r
F
.55695 .80483 m .5541 .80503 L .55362 .80964 L 0 .845 .418 r
F
.55069 .78823 m .5541 .80503 L .55695 .80483 L 0 .86 .406 r
F
.55088 .74221 m .54138 .76094 L .54214 .76324 L 0 1 .321 r
F
.55088 .74221 m .54513 .75191 L .54138 .76094 L F
.54822 .7492 m .54023 .76418 L .5452 .76555 L 0 1 .419 r
F
.54822 .7492 m .53942 .75914 L .54023 .76418 L F
.54822 .7492 m .54284 .75272 L .53942 .75914 L F
.54543 .73615 m .54284 .75272 L .54822 .7492 L 0 1 .413 r
F
.54555 .74465 m .54841 .76129 L .55197 .76618 L 0 .851 .366 r
F
.55069 .78823 m .55712 .79965 L .55449 .79293 L 0 .86 .406 r
F
.55069 .78823 m .55695 .80483 L .55712 .79965 L F
.54925 .76799 m .55055 .78246 L .55423 .78736 L 0 .842 .386 r
F
.5565 .78665 m .55449 .79293 L .55712 .79965 L 0 .805 .399 r
F
.5565 .78665 m .55423 .78736 L .55449 .79293 L F
.54925 .76799 m .55594 .78044 L .55293 .77288 L 0 .842 .386 r
F
.54925 .76799 m .5565 .78665 L .55594 .78044 L F
.54925 .76799 m .55423 .78736 L .5565 .78665 L F
.55805 .80957 m .55651 .81312 L .5578 .80951 L 0 0 0 r
F
.55031 .83433 m .54558 .84398 L .54989 .84025 L 0 1 .277 r
F
.54091 .83281 m .52619 .83569 L .53332 .83202 L 0 1 .453 r
F
.54129 .83285 m .5409 .83292 L .54091 .83281 L F
.5409 .83292 m .52619 .83569 L .54091 .83281 L F
.53611 .83382 m .52595 .8345 L .52619 .83569 L F
.54129 .83285 m .53441 .83359 L .53611 .83382 L F
.53441 .83359 m .52595 .8345 L .53611 .83382 L F
.54129 .83285 m .53242 .83328 L .52595 .8345 L F
.53968 .83773 m .52593 .83242 L .53242 .83334 L 0 .467 .351 r
F
.52593 .83242 m .52555 .83227 L .53115 .83314 L F
.52593 .83242 m .53115 .83314 L .53242 .83334 L F
.53968 .83773 m .53242 .83334 L .5409 .83299 L F
.54078 .8345 m .5409 .83299 L .54129 .83297 L F
.53968 .83773 m .5409 .83299 L .54078 .8345 L F
.53839 .82835 m .53968 .83773 L .5455 .83815 L 0 1 .5 r
F
.5503 .8326 m .54424 .83532 L .54556 .84027 L 0 .957 .446 r
F
.54628 .83526 m .55031 .83433 L .55201 .83084 L 0 1 .205 r
F
.54628 .83526 m .55201 .83084 L .55027 .83131 L F
.55493 .82239 m .55027 .83131 L .55201 .83084 L 0 1 .235 r
F
.55493 .82239 m .55152 .82769 L .55027 .83131 L F
.55701 .81378 m .55419 .81901 L .5537 .82159 L 0 1 .179 r
F
.54931 .83854 m .55805 .80957 L .55654 .81599 L 0 0 .045 r
F
.54931 .83854 m .55651 .81312 L .55805 .80957 L F
.55218 .83515 m .55973 .80907 L .55589 .82342 L 0 0 .057 r
F
.55463 .83323 m .55589 .82342 L .55973 .80907 L 0 0 .07 r
F
.55666 .83344 m .5559 .83308 L .55838 .82007 L 0 0 .084 r
F
.55824 .83665 m .55766 .83497 L .56041 .81883 L 0 0 .096 r
F
.54782 .75651 m .55994 .83041 L .55618 .79839 L 0 .262 .225 r
F
.5496 .82726 m .55617 .81275 L .55323 .81954 L 0 0 0 r
F
.55405 .81844 m .55323 .81954 L .55617 .81275 L F
.54931 .83854 m .55289 .82344 L .55651 .81312 L 0 0 .045 r
F
.54931 .83854 m .55654 .81599 L .55296 .82814 L F
.55218 .83515 m .55296 .82814 L .55654 .81599 L 0 0 .057 r
F
.54782 .75651 m .56007 .8445 L .55994 .83041 L 0 .262 .225 r
F
.55069 .78823 m .5503 .80033 L .5541 .80503 L 0 .86 .406 r
F
.54543 .73615 m .53819 .75159 L .54284 .75272 L 0 1 .413 r
F
.54202 .74847 m .54841 .76129 L .5454 .75342 L 0 .891 .374 r
F
.54202 .74847 m .54925 .76799 L .54841 .76129 L F
.54202 .74847 m .54737 .76902 L .54925 .76799 L F
.54555 .74465 m .5454 .75342 L .54841 .76129 L 0 .851 .366 r
F
.54925 .76799 m .54792 .77522 L .55055 .78246 L 0 .842 .386 r
F
.54925 .76799 m .54737 .76902 L .54792 .77522 L F
.55463 .83323 m .5537 .83381 L .55589 .82342 L 0 0 .07 r
F
.55484 .86418 m .55194 .8631 L .55028 .86656 L 0 .88 .411 r
F
.54897 .87909 m .5465 .88243 L .54513 .88621 L 0 1 .323 r
F
.54718 .87822 m .54897 .87909 L .55026 .87653 L 0 1 .316 r
F
.54718 .87822 m .5465 .88243 L .54897 .87909 L F
.54718 .87822 m .55026 .87653 L .54951 .87647 L F
.55685 .86134 m .54647 .87343 L .55237 .86983 L 0 1 .388 r
F
.55685 .86134 m .54571 .87228 L .54647 .87343 L F
.55685 .86134 m .55016 .86709 L .54571 .87228 L F
.55422 .85848 m .55016 .86709 L .55685 .86134 L 0 1 .396 r
F
.55422 .85848 m .54456 .87045 L .55016 .86709 L F
.55422 .85848 m .54379 .86917 L .54456 .87045 L F
.55422 .85848 m .54793 .86404 L .54379 .86917 L F
.55158 .85553 m .54793 .86404 L .55422 .85848 L 0 1 .391 r
F
.54881 .85259 m .55158 .85553 L .55507 .85065 L 0 1 .375 r
F
.54881 .85259 m .55507 .85065 L .55383 .84952 L F
.54415 .87818 m .53532 .89221 L .54553 .88991 L 0 1 .444 r
F
.54897 .87909 m .54576 .8879 L .54815 .88129 L 0 1 .323 r
F
.54897 .87909 m .54513 .88621 L .54576 .8879 L F
.54718 .87822 m .54418 .88419 L .5465 .88243 L 0 1 .316 r
F
.54718 .87822 m .54354 .88317 L .54418 .88419 L F
.54718 .87822 m .54483 .88061 L .54354 .88317 L F
.54537 .87581 m .54483 .88061 L .54718 .87822 L 0 1 .368 r
F
.54537 .87581 m .54259 .88149 L .54483 .88061 L F
.54415 .87818 m .52748 .89036 L .53532 .89221 L 0 1 .444 r
F
.54415 .87818 m .52724 .8856 L .52748 .89036 L F
.54415 .87818 m .53438 .88038 L .52724 .8856 L F
.54276 .8642 m .53438 .88038 L .54415 .87818 L 0 1 .425 r
F
.54537 .87581 m .54195 .88026 L .54259 .88149 L 0 1 .368 r
F
.55171 .87642 m .54269 .88089 L .54805 .88498 L 0 1 .465 r
F
.54537 .87581 m .54718 .87822 L .54837 .87579 L 0 1 .368 r
F
.54537 .87581 m .54315 .87783 L .54195 .88026 L F
.54355 .87277 m .54315 .87783 L .54537 .87581 L 0 1 .391 r
F
.54355 .87277 m .541 .87832 L .54315 .87783 L F
.55171 .87642 m .54191 .87697 L .54269 .88089 L 0 1 .465 r
F
.54537 .87581 m .54837 .87579 L .54761 .87494 L 0 1 .368 r
F
.54355 .87277 m .54537 .87581 L .54647 .87344 L 0 1 .391 r
F
.55171 .87642 m .54577 .87505 L .54191 .87697 L 0 1 .465 r
F
.54355 .87277 m .54647 .87344 L .5457 .87228 L 0 1 .391 r
F
.54888 .8658 m .54577 .87505 L .55171 .87642 L 0 1 .464 r
F
.54888 .8658 m .55171 .87642 L .55522 .87423 L F
.54888 .8658 m .55522 .87423 L .55396 .86994 L F
.54925 .85757 m .52953 .86826 L .52976 .87123 L 0 1 .496 r
F
.54925 .85757 m .53788 .86241 L .52953 .86826 L F
.54132 .83916 m .54276 .8642 L .54922 .85342 L 0 1 .386 r
F
.55158 .85553 m .54263 .86724 L .54793 .86404 L 0 1 .391 r
F
.55158 .85553 m .54186 .86594 L .54263 .86724 L F
.55158 .85553 m .54569 .86092 L .54186 .86594 L F
.54881 .85259 m .54569 .86092 L .55158 .85553 L 0 1 .375 r
F
.54132 .83916 m .53343 .86676 L .54276 .8642 L 0 1 .386 r
F
.54881 .85259 m .54067 .864 L .54569 .86092 L 0 1 .375 r
F
.54881 .85259 m .53986 .86271 L .54067 .864 L F
.54881 .85259 m .54335 .85782 L .53986 .86271 L F
.54603 .85 m .54335 .85782 L .54881 .85259 L 0 1 .349 r
F
.54605 .85496 m .54888 .8658 L .55207 .86344 L 0 1 .461 r
F
.54605 .85496 m .55207 .86344 L .55081 .85907 L F
.55847 .85709 m .55081 .85907 L .55207 .86344 L 0 .978 .458 r
F
.55847 .85709 m .55355 .85634 L .55081 .85907 L F
.54603 .85 m .54881 .85259 L .55197 .84793 L 0 1 .349 r
F
.55439 .84516 m .54887 .85224 L .55355 .85634 L 0 .967 .453 r
F
.55439 .84516 m .55355 .85634 L .55847 .85709 L F
.55956 .85868 m .55984 .85093 L .56006 .85673 L 0 .17 .135 r
F
.55914 .85857 m .56 .87192 L .55956 .85868 L 0 .255 .224 r
F
.55847 .85709 m .55207 .86344 L .55703 .86732 L 0 .978 .458 r
F
.55819 .85832 m .55984 .85093 L .55956 .85868 L 0 .17 .135 r
F
.55819 .85832 m .55721 .85796 L .55984 .85093 L F
.55773 .85481 m .55819 .85832 L .55885 .85393 L 0 .255 .224 r
F
.55819 .85832 m .56 .87192 L .55915 .85867 L F
.55819 .85832 m .55915 .85867 L .55885 .85393 L F
.55507 .89846 m .55393 .90382 L .55696 .90175 L 0 1 .228 r
F
.54689 .90042 m .52847 .90768 L .52871 .91166 L 0 1 .471 r
F
.54689 .90042 m .53626 .90286 L .52847 .90768 L F
.54553 .88991 m .53626 .90286 L .54689 .90042 L 0 1 .459 r
F
.54553 .88991 m .5281 .90146 L .53626 .90286 L F
.53994 .89751 m .54777 .9094 L .54689 .89784 L 0 1 .369 r
F
.5571 .89668 m .54662 .9008 L .55259 .90528 L 0 .982 .458 r
F
.5571 .89668 m .54583 .89674 L .54662 .9008 L F
.5571 .89668 m .55032 .89497 L .54583 .89674 L F
.5544 .8865 m .54466 .89074 L .55032 .89497 L 0 1 .463 r
F
.54553 .88991 m .52785 .89716 L .5281 .90146 L 0 1 .459 r
F
.54553 .88991 m .53532 .89221 L .52785 .89716 L F
.53865 .89184 m .54575 .88791 L .54512 .88622 L 0 1 .391 r
F
.53865 .89184 m .53994 .89751 L .54575 .88791 L F
.5544 .8865 m .54387 .88679 L .54466 .89074 L 0 1 .463 r
F
.5544 .8865 m .54805 .88498 L .54387 .88679 L F
.55171 .87642 m .54805 .88498 L .5544 .8865 L 0 1 .465 r
F
.55171 .87642 m .5544 .8865 L .55828 .88459 L F
.55171 .87642 m .55828 .88459 L .55707 .88051 L F
.55596 .85798 m .55898 .84051 L .55938 .84398 L 0 .151 .126 r
F
.55595 .85798 m .55934 .88959 L .55596 .85798 L 0 .252 .226 r
F
.55517 .85788 m .55898 .84051 L .55596 .85798 L 0 .151 .126 r
F
.5559 .85761 m .55594 .85797 L .55591 .85761 L 0 .252 .226 r
F
.55594 .85797 m .55934 .88959 L .55595 .85797 L F
.55594 .85797 m .55595 .85797 L .55591 .85761 L F
.55596 .85798 m .55934 .88959 L .55967 .88362 L F
.55583 .85732 m .55583 .85737 L .55587 .85736 L F
.55583 .85737 m .55934 .88959 L .55587 .85741 L F
.55583 .85737 m .55587 .85741 L .55587 .85736 L F
.55517 .85788 m .55537 .85157 L .55898 .84051 L 0 .151 .126 r
F
.55517 .85788 m .55549 .86911 L .55934 .88959 L 0 .252 .226 r
F
.55419 .85781 m .55426 .85748 L .55517 .85788 L 0 .151 .126 r
F
.55426 .85748 m .55537 .85157 L .55517 .85788 L F
.55322 .85723 m .55766 .83497 L .55824 .83665 L 0 .132 .117 r
F
.5532 .85724 m .55766 .83497 L .55322 .85723 L F
.55305 .85777 m .55766 .83497 L .5531 .85775 L F
.55517 .85788 m .55934 .88959 L .55593 .85821 L 0 .252 .226 r
F
.55561 .85941 m .55517 .85788 L .55596 .85798 L 0 .151 .126 r
F
.55314 .85826 m .55812 .89966 L .55868 .89647 L 0 .252 .229 r
F
.55313 .85826 m .55812 .89966 L .55314 .85826 L F
.55256 .85786 m .55812 .89966 L .55307 .85784 L F
.55419 .85781 m .55549 .86911 L .55517 .85788 L 0 .252 .226 r
F
.55302 .85784 m .55766 .83497 L .55304 .85784 L 0 .132 .117 r
F
.55256 .85786 m .55423 .8783 L .55812 .89966 L 0 .252 .229 r
F
.54501 .8051 m .54685 .81807 L .54803 .8142 L 0 1 .432 r
F
.54603 .85 m .55197 .84793 L .55073 .84694 L 0 1 .349 r
F
.55439 .84516 m .54755 .84752 L .54887 .85224 L 0 .967 .453 r
F
.55439 .84516 m .54991 .84448 L .54755 .84752 L F
.55031 .83433 m .54428 .8436 L .54558 .84398 L 0 1 .277 r
F
.55031 .83433 m .54631 .83946 L .54428 .8436 L F
.54628 .83526 m .54631 .83946 L .55031 .83433 L 0 1 .205 r
F
.54685 .81807 m .54451 .81793 L .54325 .82162 L 0 1 .426 r
F
.54501 .8051 m .54451 .81793 L .54685 .81807 L 0 1 .432 r
F
.54501 .8051 m .54227 .81414 L .54451 .81793 L F
.54501 .8051 m .54163 .80925 L .54227 .81414 L F
.54501 .8051 m .5428 .80537 L .54163 .80925 L F
.54209 .80496 m .5462 .81925 L .54756 .81524 L 0 .949 .429 r
F
.54983 .82652 m .5459 .83392 L .54765 .83262 L 0 1 .175 r
F
.54983 .82652 m .54684 .8313 L .5459 .83392 L F
.53709 .81713 m .53839 .82835 L .54389 .82669 L 0 1 .501 r
F
.53709 .81713 m .54389 .82669 L .54324 .82162 L F
.5462 .81925 m .54225 .82769 L .54627 .83203 L 0 .95 .438 r
F
.5509 .82282 m .54847 .82722 L .54828 .82824 L 0 .894 .136 r
F
.54967 .82542 m .54847 .82722 L .5509 .82282 L 0 0 0 r
F
.54552 .83242 m .54983 .82652 L .55045 .82521 L 0 .863 .129 r
F
.5454 .83262 m .54983 .82652 L .54552 .83242 L F
.54499 .83322 m .54983 .82652 L .54509 .83304 L F
.54013 .831 m .5431 .84326 L .54556 .84027 L 0 .999 .45 r
F
.54013 .831 m .54556 .84027 L .54424 .83532 L F
.54224 .83816 m .54628 .83526 L .54765 .83262 L 0 .972 .169 r
F
.54224 .83816 m .54765 .83262 L .5459 .83392 L F
.54498 .83323 m .54684 .8313 L .54983 .82652 L 0 .863 .129 r
F
.54472 .83359 m .54484 .83346 L .54498 .83323 L F
.54484 .83346 m .54684 .8313 L .54498 .83323 L F
.54484 .83346 m .54328 .83664 L .54684 .8313 L F
.54472 .83359 m .54456 .83391 L .54484 .83346 L F
.54456 .83391 m .54328 .83664 L .54484 .83346 L F
.54519 .83288 m .55045 .82521 L .54828 .82824 L F
.54472 .83359 m .54509 .83305 L .54519 .83288 L F
.54509 .83305 m .55045 .82521 L .54519 .83288 L F
.54476 .83588 m .54502 .83389 L .54756 .82899 L 0 0 0 r
F
.54759 .82894 m .54756 .82899 L .5476 .8289 L F
.54476 .83588 m .54756 .82899 L .54759 .82894 L F
.54762 .82887 m .5476 .8289 L .54763 .82884 L F
.54476 .83588 m .5476 .8289 L .54762 .82887 L F
.54813 .82802 m .54763 .82884 L .54847 .82722 L F
.54476 .83588 m .54763 .82884 L .54813 .82802 L F
.54476 .83588 m .54812 .82804 L .54967 .82542 L F
.54812 .82804 m .54847 .82722 L .54967 .82542 L F
.54509 .83304 m .5454 .83262 L .54552 .83242 L 0 .863 .129 r
F
.54472 .83359 m .54499 .83322 L .54509 .83304 L F
.5509 .82282 m .54828 .82824 L .55045 .82521 L 0 .894 .136 r
F
.54476 .83588 m .54967 .82542 L .5508 .82365 L 0 0 0 r
F
.54967 .82542 m .5509 .82282 L .55081 .82353 L F
.54967 .82542 m .55081 .82353 L .5508 .82365 L F
.54476 .83588 m .5508 .82365 L .54822 .82919 L F
.5496 .82726 m .54822 .82919 L .5508 .82365 L F
.5496 .82726 m .54771 .83074 L .54822 .82919 L F
.54607 .8429 m .55405 .81844 L .55289 .82344 L 0 0 .034 r
F
.54607 .8429 m .55232 .82199 L .55405 .81844 L F
.54607 .8429 m .54881 .83112 L .55232 .82199 L F
.54603 .85 m .5392 .86005 L .54335 .85782 L 0 1 .349 r
F
.5392 .86005 m .53864 .86047 L .5389 .8607 L 0 1 .461 r
F
.5392 .86005 m .5389 .8607 L .53891 .86071 L F
.52048 .86143 m .52076 .86853 L .52917 .8639 L 0 1 .51 r
F
.52048 .86143 m .52917 .8639 L .52893 .86103 L F
.54132 .83916 m .52625 .86429 L .53343 .86676 L 0 1 .386 r
F
.536 .85273 m .53863 .86047 L .53781 .85623 L 0 1 .463 r
F
.5392 .86005 m .53782 .85973 L .53864 .86088 L 0 1 .349 r
F
.54603 .85 m .54123 .85569 L .5392 .86005 L F
.52104 .87585 m .52132 .88331 L .53036 .87873 L 0 1 .51 r
F
.52104 .87585 m .53036 .87873 L .53012 .87571 L F
.52076 .86853 m .52104 .87585 L .52976 .87123 L F
.52076 .86853 m .52976 .87123 L .52953 .86826 L F
.54276 .8642 m .52662 .87269 L .52687 .87803 L 0 1 .425 r
F
.54276 .8642 m .53343 .86676 L .52662 .87269 L F
.53796 .86289 m .53614 .86796 L .53804 .86778 L 0 1 .376 r
F
.53796 .86289 m .53734 .86381 L .53614 .86796 L F
.53796 .86331 m .53726 .86394 L .53615 .86963 L 0 1 .466 r
F
.53726 .86394 m .53546 .86555 L .53573 .86713 L F
.53734 .86381 m .53726 .86394 L .53573 .86713 L 0 1 .376 r
F
.53726 .86394 m .53573 .86713 L .53573 .86713 L F
.53734 .86381 m .53573 .86713 L .53614 .86796 L F
.54276 .8642 m .52687 .87803 L .53438 .88038 L 0 1 .425 r
F
.53347 .87631 m .52797 .88576 L .53477 .88015 L 0 1 .409 r
F
.51968 .88519 m .52748 .89036 L .52724 .8856 L 0 1 .457 r
F
.51968 .88519 m .51997 .89663 L .52748 .89036 L F
.52104 .87585 m .50901 .8864 L .52132 .88331 L 0 1 .51 r
F
.51968 .88519 m .5097 .90024 L .51997 .89663 L 0 1 .457 r
F
.51968 .88519 m .50213 .89984 L .5097 .90024 L F
.52104 .87585 m .49992 .88655 L .50901 .8864 L 0 1 .51 r
F
.52104 .87585 m .5001 .88365 L .49992 .88655 L F
.52104 .87585 m .50916 .87906 L .5001 .88365 L F
.52076 .86853 m .50916 .87906 L .52104 .87585 L F
.51939 .87259 m .51968 .88519 L .52687 .87803 L 0 1 .443 r
F
.51968 .88519 m .50232 .89569 L .50213 .89984 L 0 1 .457 r
F
.51968 .88519 m .50984 .88941 L .50232 .89569 L F
.51939 .87259 m .50984 .88941 L .51968 .88519 L 0 1 .443 r
F
.51771 .88273 m .52326 .89039 L .52303 .88724 L 0 1 .492 r
F
.53347 .87631 m .5291 .88128 L .52797 .88576 L 0 1 .409 r
F
.52578 .89025 m .52303 .88724 L .52326 .89039 L 0 .976 .478 r
F
.53607 .88405 m .52975 .89532 L .53736 .88794 L 0 1 .423 r
F
.51997 .89663 m .5281 .90146 L .52785 .89716 L 0 1 .468 r
F
.51997 .89663 m .52026 .90713 L .5281 .90146 L F
.53607 .88405 m .52491 .89781 L .52975 .89532 L 0 1 .423 r
F
.52491 .89781 m .52385 .89912 L .52474 .89855 L F
.52491 .89781 m .52362 .89488 L .52385 .89771 L 0 .891 .475 r
F
.52491 .89781 m .52481 .89851 L .52975 .89532 L 0 1 .423 r
F
.53865 .89184 m .53152 .90866 L .53994 .89751 L 0 1 .391 r
F
.52026 .90713 m .52054 .91692 L .52871 .91166 L 0 1 .477 r
F
.52026 .90713 m .52871 .91166 L .52847 .90768 L F
.52026 .90713 m .50941 .91995 L .52054 .91692 L F
.51943 .91134 m .51971 .91397 L .52694 .91328 L 0 1 .523 r
F
.51943 .91134 m .52694 .91328 L .5267 .91248 L F
.54296 .90634 m .5267 .91248 L .52694 .91328 L 0 1 .323 r
F
.54296 .90634 m .53357 .9095 L .5267 .91248 L F
.54296 .90634 m .52694 .91328 L .53449 .91132 L F
.54133 .91563 m .52634 .91164 L .53357 .9095 L 0 .46 .218 r
F
.54167 .9159 m .5413 .9158 L .54133 .91563 L F
.5413 .9158 m .52634 .91164 L .54133 .91563 L F
.54698 .91642 m .52874 .92501 L .53723 .92451 L 0 1 .528 r
F
.54698 .91642 m .5285 .92302 L .52874 .92501 L F
.54698 .91642 m .53632 .91933 L .5285 .92302 L F
.53646 .91445 m .5261 .91131 L .52634 .91164 L 0 .46 .218 r
F
.54167 .9159 m .53473 .91385 L .53646 .91445 L F
.53473 .91385 m .5261 .91131 L .53646 .91445 L F
.54167 .9159 m .53267 .91314 L .5261 .91131 L F
.53466 .91614 m .52603 .91086 L .53267 .91319 L 0 .07 .166 r
F
.53528 .91705 m .53379 .91605 L .53466 .91614 L F
.53379 .91605 m .52603 .91086 L .53466 .91614 L F
.52054 .91692 m .52083 .92616 L .52932 .92119 L 0 1 .485 r
F
.52083 .92616 m .50912 .93777 L .52111 .93497 L 0 1 .491 r
F
.52083 .92616 m .50026 .93728 L .50912 .93777 L F
.52083 .92616 m .50044 .93382 L .50026 .93728 L F
.52083 .92616 m .50926 .92905 L .50044 .93382 L F
.52054 .91692 m .50926 .92905 L .52083 .92616 L 0 1 .485 r
F
.52028 .92213 m .52056 .92718 L .52874 .92501 L 0 1 .54 r
F
.52028 .92213 m .52874 .92501 L .5285 .92302 L F
.51999 .91765 m .52028 .92213 L .52814 .92022 L 0 1 .539 r
F
.51999 .91765 m .52814 .92022 L .5279 .9185 L F
.53128 .91581 m .52543 .92154 L .52573 .92753 L 0 1 .369 r
F
.53061 .91517 m .52603 .91086 L .53379 .91605 L 0 .07 .166 r
F
.53248 .91593 m .53379 .91605 L .53528 .91705 L F
.53061 .91517 m .53379 .91605 L .53248 .91593 L F
.52603 .91086 m .5257 .91054 L .53127 .91266 L F
.52603 .91086 m .53127 .91266 L .53267 .91319 L F
.53061 .91517 m .5254 .90984 L .5257 .91054 L F
.53994 .89751 m .53152 .90866 L .52925 .91347 L 0 1 .369 r
F
.53128 .91581 m .52749 .91187 L .53061 .91517 L 0 .07 .166 r
F
.52769 .90991 m .52782 .91053 L .52795 .91047 L 0 1 .391 r
F
.52769 .90991 m .52795 .91047 L .53152 .90866 L F
.52769 .90991 m .52478 .90672 L .52501 .9082 L 0 .346 .296 r
F
.53865 .89184 m .52769 .90991 L .53152 .90866 L 0 1 .391 r
F
.52769 .90991 m .52501 .9082 L .52806 .91167 L 0 .346 .296 r
F
.52709 .9109 m .52786 .91185 L .53152 .90866 L 0 1 .391 r
F
.5415 .91955 m .53792 .92292 L .5417 .92225 L 0 1 .369 r
F
.53792 .92292 m .53892 .92398 L .5417 .92225 L F
.53528 .91705 m .5347 .9195 L .5415 .91955 L F
.5347 .9195 m .53271 .92783 L .53792 .92292 L F
.5347 .9195 m .53792 .92292 L .5415 .91955 L F
.53528 .91705 m .53386 .91861 L .5347 .9195 L F
.53128 .91581 m .53061 .91517 L .53528 .91705 L 0 .07 .166 r
F
.54104 .91753 m .53267 .91319 L .54129 .91591 L F
.54136 .91755 m .53528 .91705 L .5415 .91955 L 0 1 .369 r
F
.52111 .93497 m .52139 .94344 L .53052 .93885 L 0 1 .496 r
F
.50651 .94227 m .49998 .9417 L .4998 .94405 L 0 1 .538 r
F
.52111 .93497 m .51181 .94356 L .52139 .94344 L 0 1 .496 r
F
.51168 .94367 m .50898 .94519 L .51516 .94477 L 0 1 .538 r
F
.51168 .94367 m .51516 .94477 L .51544 .94475 L F
.51181 .94356 m .5115 .94361 L .51168 .94367 L 0 1 .496 r
F
.51168 .94367 m .4998 .94405 L .50898 .94519 L 0 1 .538 r
F
.5115 .94361 m .51149 .94361 L .51168 .94367 L 0 1 .496 r
F
.52111 .93497 m .50676 .9422 L .51181 .94356 L F
.50676 .9422 m .4998 .94405 L .511 .94369 L 0 1 .538 r
F
.50676 .9422 m .511 .94369 L .51168 .94367 L F
.50676 .9422 m .49998 .94238 L .49979 .94572 L 0 1 .496 r
F
.52111 .93497 m .50361 .9411 L .50676 .9422 L F
.50676 .9422 m .50252 .9413 L .50651 .94227 L 0 1 .538 r
F
.50361 .9411 m .50345 .94116 L .50676 .9422 L 0 1 .496 r
F
.52112 .93839 m .50345 .94116 L .50676 .9422 L 0 1 .538 r
F
.50345 .94116 m .50308 .94122 L .50676 .9422 L F
.50308 .94122 m .50252 .9413 L .50676 .9422 L F
.50252 .9413 m .49998 .9417 L .50651 .94227 L F
.50345 .94116 m .49998 .94238 L .50676 .9422 L 0 1 .496 r
F
.50676 .9422 m .49979 .94572 L .51181 .94356 L F
.51181 .94356 m .51222 .94366 L .52139 .94344 L F
.52112 .93839 m .50676 .9422 L .51168 .94367 L 0 1 .538 r
F
.51149 .94361 m .49979 .94572 L .51168 .94367 L 0 1 .496 r
F
.51168 .94367 m .49979 .94572 L .50897 .94617 L F
.51181 .94356 m .51168 .94367 L .51222 .94366 L F
.51168 .94367 m .50897 .94617 L .51544 .94475 L F
.51168 .94367 m .51544 .94475 L .52139 .94344 L F
.52112 .93839 m .51168 .94367 L .5214 .94435 L 0 1 .538 r
F
.51168 .94367 m .51544 .94475 L .5214 .94435 L F
.52112 .93839 m .5214 .94435 L .53053 .94193 L F
.52112 .93839 m .53053 .94193 L .53029 .93953 L F
.52111 .93497 m .50912 .93777 L .5028 .94095 L 0 1 .496 r
F
.50345 .94116 m .5028 .94095 L .49998 .94238 L F
.52111 .93497 m .5028 .94095 L .50345 .94116 L F
.52112 .93839 m .50912 .93928 L .5028 .94095 L 0 1 .538 r
F
.50345 .94116 m .5028 .94095 L .49998 .9417 L F
.52112 .93839 m .5028 .94095 L .50345 .94116 L F
.52084 .93264 m .52112 .93839 L .52994 .936 L 0 1 .539 r
F
.52084 .93264 m .52994 .936 L .5297 .9337 L F
.53969 .92482 m .52615 .93584 L .52641 .94094 L 0 1 .421 r
F
.5417 .92238 m .53934 .92443 L .53969 .92482 L F
.53934 .92443 m .52615 .93584 L .53969 .92482 L F
.53058 .91501 m .52902 .91559 L .53108 .91579 L 0 1 .369 r
F
.52996 .91403 m .52987 .91419 L .53058 .91501 L F
.52987 .91419 m .52933 .91367 L .53128 .91581 L 0 .07 .166 r
F
.52933 .91367 m .52997 .91445 L .53128 .91581 L F
.52749 .91187 m .5254 .90984 L .53061 .91517 L F
.52987 .91419 m .52902 .91559 L .53058 .91501 L 0 1 .369 r
F
.52987 .91419 m .52697 .91132 L .52749 .91187 L 0 .07 .166 r
F
.53126 .91554 m .52978 .91409 L .52987 .91419 L F
.52978 .91409 m .52697 .91132 L .52987 .91419 L F
.53136 .91564 m .53128 .91581 L .53166 .91593 L 0 1 .369 r
F
.53136 .91564 m .53166 .91593 L .53528 .91705 L F
.53528 .91705 m .53267 .91319 L .54104 .91753 L 0 .07 .166 r
F
.54167 .9159 m .53357 .9095 L .54296 .90634 L 0 .46 .218 r
F
.53994 .89751 m .53136 .91564 L .53528 .91705 L 0 1 .369 r
F
.53128 .91581 m .52573 .92753 L .53528 .91705 L F
.53934 .92443 m .53271 .92789 L .52615 .93584 L 0 1 .421 r
F
.5417 .92238 m .53899 .92404 L .53934 .92443 L F
.53899 .92404 m .53271 .92789 L .53934 .92443 L F
.53994 .89751 m .52996 .91403 L .53128 .91581 L 0 1 .369 r
F
.52996 .91403 m .53058 .91501 L .53128 .91581 L F
.53058 .91501 m .53108 .91579 L .53128 .91581 L F
.54005 .92409 m .53128 .91581 L .53179 .91597 L 0 .07 .166 r
F
.54005 .92409 m .5319 .916 L .53528 .91705 L F
.53994 .89751 m .52945 .91371 L .52987 .91419 L 0 1 .369 r
F
.53994 .89751 m .52925 .91347 L .52945 .91371 L F
.54005 .92409 m .53138 .91548 L .52925 .91347 L 0 .07 .166 r
F
.52946 .91371 m .52925 .91347 L .52824 .91252 L F
.54005 .92409 m .52925 .91347 L .52946 .91371 L F
.53286 .9173 m .52987 .91419 L .53128 .91581 L F
.54005 .92409 m .53126 .91554 L .53286 .9173 L F
.53126 .91554 m .52987 .91419 L .53286 .9173 L F
.54005 .92409 m .53101 .91527 L .53126 .91554 L F
.53101 .91527 m .52697 .91132 L .53126 .91554 L F
.54005 .92409 m .53528 .91705 L .54104 .91753 L F
.54136 .91755 m .54129 .91591 L .54167 .91603 L F
.5401 .92385 m .54104 .91754 L .54136 .91755 L F
.54104 .91754 m .54129 .91591 L .54136 .91755 L F
.54005 .92409 m .54129 .91591 L .5401 .92385 L F
.54136 .91755 m .5417 .92225 L .54372 .91796 L 0 1 .369 r
F
.5417 .92238 m .54315 .94559 L .5497 .93763 L 0 1 .421 r
F
.5417 .92238 m .53369 .94511 L .54315 .94559 L F
.5417 .92238 m .52641 .94094 L .53369 .94511 L F
.54005 .92409 m .54136 .91755 L .54784 .92183 L 0 .07 .166 r
F
.54136 .91755 m .54167 .91603 L .54372 .91796 L F
.54136 .91755 m .54372 .91796 L .54784 .92183 L F
.54136 .91755 m .54372 .91796 L .54387 .91764 L 0 1 .369 r
F
.53994 .89751 m .54136 .91755 L .54777 .9094 L F
.54136 .91755 m .54387 .91764 L .54777 .9094 L F
.53994 .89751 m .53528 .91705 L .54136 .91755 L F
.52862 .91294 m .52824 .91252 L .52697 .91132 L 0 .07 .166 r
F
.54005 .92409 m .52824 .91252 L .52862 .91294 L F
.5347 .9195 m .52573 .92753 L .53271 .92783 L 0 1 .369 r
F
.53386 .91861 m .52573 .92753 L .5347 .9195 L F
.54005 .92409 m .53154 .91564 L .53138 .91548 L 0 .07 .166 r
F
.52749 .91187 m .52697 .91132 L .5254 .90984 L F
.51915 .90957 m .51943 .91134 L .52634 .91164 L 0 1 .503 r
F
.51915 .90957 m .52634 .91164 L .5261 .91131 L F
.52769 .90991 m .52478 .91069 L .52502 .91432 L 0 1 .391 r
F
.53865 .89184 m .52668 .90811 L .52769 .90991 L F
.52668 .90811 m .52478 .90672 L .52769 .90991 L 0 .346 .296 r
F
.52026 .90713 m .50119 .91941 L .50941 .91995 L 0 1 .477 r
F
.52026 .90713 m .50137 .91565 L .50119 .91941 L F
.52026 .90713 m .50955 .91038 L .50137 .91565 L F
.51997 .89663 m .50955 .91038 L .52026 .90713 L 0 1 .468 r
F
.5188 .90678 m .51915 .90957 L .5257 .91054 L 0 .935 .479 r
F
.5188 .90678 m .5257 .91054 L .5254 .90984 L F
.52668 .90811 m .52478 .91069 L .52769 .90991 L 0 1 .391 r
F
.52697 .90832 m .52668 .90811 L .52769 .90991 L 0 .346 .296 r
F
.53875 .91692 m .52697 .90832 L .52769 .90991 L F
.53875 .91692 m .52769 .90991 L .53154 .91564 L F
.52769 .90991 m .52806 .91167 L .53154 .91564 L F
.52769 .90991 m .52709 .9109 L .52782 .91053 L 0 1 .391 r
F
.52933 .91367 m .52749 .91187 L .52997 .91445 L 0 .07 .166 r
F
.52709 .9109 m .52502 .91432 L .52786 .91185 L 0 1 .391 r
F
.52987 .91419 m .52828 .91552 L .52902 .91559 L 0 1 .369 r
F
.52945 .91371 m .52828 .91552 L .52987 .91419 L F
.52945 .91371 m .52925 .91347 L .52828 .91552 L F
.52902 .91559 m .52828 .91552 L .52543 .92154 L F
.52902 .91559 m .52543 .92154 L .53128 .91581 L F
.53792 .92292 m .53271 .92783 L .53892 .92398 L F
.53865 .89184 m .53063 .90104 L .52652 .90782 L 0 1 .391 r
F
.52668 .90811 m .52652 .90782 L .52478 .91069 L F
.53865 .89184 m .52652 .90782 L .52668 .90811 L F
.53875 .91692 m .53066 .91045 L .52652 .90782 L 0 .346 .296 r
F
.52668 .90811 m .52652 .90782 L .52478 .90672 L F
.53875 .91692 m .52652 .90782 L .52668 .90811 L F
.53736 .88794 m .53063 .90104 L .53865 .89184 L 0 1 .415 r
F
.53736 .88794 m .52559 .90423 L .53063 .90104 L F
.52559 .90423 m .52443 .90584 L .52551 .90501 L F
.52559 .90423 m .5242 .90157 L .52443 .90387 L 0 .69 .445 r
F
.52559 .90423 m .52563 .90491 L .53063 .90104 L 0 1 .415 r
F
.52559 .90423 m .52443 .90387 L .52551 .90501 L 0 .69 .445 r
F
.51997 .89663 m .50166 .90986 L .50955 .91038 L 0 1 .468 r
F
.51997 .89663 m .50184 .90591 L .50166 .90986 L F
.51997 .89663 m .5097 .90024 L .50184 .90591 L F
.51826 .89714 m .51853 .9028 L .52443 .90387 L 0 .948 .49 r
F
.52559 .90423 m .5242 .903 L .52443 .90584 L 0 1 .415 r
F
.53736 .88794 m .52508 .90199 L .52559 .90423 L F
.52508 .90199 m .5242 .90157 L .52559 .90423 L 0 .69 .445 r
F
.52508 .90199 m .5242 .903 L .52559 .90423 L 0 1 .415 r
F
.52547 .90218 m .52508 .90199 L .52559 .90423 L 0 .69 .445 r
F
.53744 .90791 m .52547 .90218 L .52559 .90423 L F
.52559 .90423 m .52551 .90501 L .52563 .90491 L 0 1 .415 r
F
.53744 .90791 m .52559 .90423 L .53066 .91045 L 0 .69 .445 r
F
.52559 .90423 m .52551 .90501 L .53066 .91045 L F
.51826 .89714 m .52443 .90387 L .5242 .90157 L 0 .948 .49 r
F
.53736 .88794 m .52975 .89532 L .52504 .90183 L 0 1 .415 r
F
.52508 .90199 m .52504 .90183 L .5242 .903 L F
.53736 .88794 m .52504 .90183 L .52508 .90199 L F
.53744 .90791 m .52977 .90329 L .52504 .90183 L 0 .69 .445 r
F
.52508 .90199 m .52504 .90183 L .5242 .90157 L F
.53744 .90791 m .52504 .90183 L .52508 .90199 L F
.52491 .89781 m .52385 .89771 L .52474 .89855 L 0 .891 .475 r
F
.52491 .89781 m .52362 .8968 L .52385 .89912 L 0 1 .423 r
F
.53607 .88405 m .52505 .89533 L .52491 .89781 L F
.52505 .89533 m .52362 .89488 L .52491 .89781 L 0 .891 .475 r
F
.52505 .89533 m .52362 .8968 L .52491 .89781 L 0 1 .423 r
F
.52528 .89541 m .52505 .89533 L .52491 .89781 L 0 .891 .475 r
F
.53612 .89884 m .52528 .89541 L .52491 .89781 L F
.52491 .89781 m .52474 .89855 L .52481 .89851 L 0 1 .423 r
F
.53612 .89884 m .52491 .89781 L .52977 .90329 L 0 .891 .475 r
F
.52491 .89781 m .52474 .89855 L .52977 .90329 L F
.51798 .89032 m .52385 .89771 L .52362 .89488 L 0 1 .493 r
F
.53607 .88405 m .52886 .89033 L .52507 .89501 L 0 1 .423 r
F
.52505 .89533 m .52507 .89501 L .52362 .8968 L F
.53607 .88405 m .52507 .89501 L .52505 .89533 L F
.53612 .89884 m .52887 .89536 L .52507 .89501 L 0 .891 .475 r
F
.52505 .89533 m .52507 .89501 L .52362 .89488 L F
.53612 .89884 m .52507 .89501 L .52505 .89533 L F
.53477 .88015 m .52886 .89033 L .53607 .88405 L 0 1 .42 r
F
.53477 .88015 m .5261 .89023 L .52886 .89033 L F
.5261 .89023 m .52542 .8923 L .52886 .89033 L F
.53481 .88973 m .5261 .89023 L .52887 .89536 L 0 .976 .478 r
F
.5261 .89023 m .52326 .89039 L .52542 .8923 L F
.5261 .89023 m .52542 .8923 L .52887 .89536 L F
.5261 .89023 m .52327 .89353 L .52542 .8923 L 0 1 .42 r
F
.5261 .89023 m .52304 .89149 L .52327 .89353 L F
.53477 .88015 m .52664 .88801 L .5261 .89023 L F
.5261 .89023 m .52652 .88798 L .52578 .89025 L 0 .976 .478 r
F
.52664 .88801 m .52652 .88798 L .5261 .89023 L F
.52652 .88798 m .52303 .88724 L .52578 .89025 L F
.52664 .88801 m .52304 .89149 L .5261 .89023 L 0 1 .42 r
F
.53481 .88973 m .52664 .88801 L .5261 .89023 L 0 .976 .478 r
F
.53477 .88015 m .52797 .88576 L .52688 .88702 L 0 1 .42 r
F
.52664 .88801 m .52688 .88702 L .52303 .88724 L 0 .976 .478 r
F
.52664 .88801 m .52688 .88702 L .52304 .89149 L 0 1 .42 r
F
.53477 .88015 m .52688 .88702 L .52664 .88801 L F
.53481 .88973 m .52797 .88696 L .52688 .88702 L 0 .976 .478 r
F
.53481 .88973 m .52688 .88702 L .52664 .88801 L F
.53349 .88054 m .5291 .88128 L .52797 .88696 L 0 1 .477 r
F
.5291 .88128 m .52268 .88237 L .52711 .88622 L F
.5291 .88128 m .52831 .88324 L .52797 .88576 L 0 1 .409 r
F
.52848 .88199 m .5271 .88622 L .52797 .88576 L F
.5291 .88128 m .52711 .88622 L .52797 .88696 L 0 1 .477 r
F
.5291 .88128 m .52848 .88199 L .52831 .88324 L 0 1 .409 r
F
.52848 .88199 m .52268 .88859 L .5271 .88622 L F
.53216 .8712 m .52707 .87824 L .52986 .87924 L 0 1 .475 r
F
.52957 .88 m .52954 .88 L .5291 .88128 L 0 1 .477 r
F
.52954 .88 m .52244 .87902 L .52902 .88126 L F
.52954 .88 m .52902 .88126 L .5291 .88128 L F
.5291 .88128 m .52244 .87902 L .52268 .88237 L F
.53216 .8712 m .52986 .87924 L .53243 .8731 L 0 1 .475 r
F
.53347 .87631 m .52957 .88 L .5291 .88128 L 0 1 .409 r
F
.52957 .88 m .52707 .87824 L .52244 .87902 L 0 1 .477 r
F
.53347 .87631 m .52986 .87924 L .52957 .88 L 0 1 .409 r
F
.53349 .88054 m .52986 .87924 L .52957 .88 L 0 1 .477 r
F
.52986 .87924 m .52707 .87824 L .52957 .88 L F
.52957 .88 m .52708 .88148 L .52245 .88675 L 0 1 .409 r
F
.52986 .87924 m .52708 .88148 L .52957 .88 L F
.53216 .87263 m .52708 .88148 L .52986 .87924 L 0 1 .393 r
F
.5325 .87356 m .52986 .87924 L .53347 .87631 L F
.5325 .87356 m .52986 .87924 L .53349 .88054 L 0 1 .475 r
F
.53243 .8731 m .52986 .87924 L .5325 .87356 L F
.53236 .87319 m .52986 .87924 L .5325 .87356 L 0 1 .393 r
F
.53216 .87263 m .52986 .87924 L .53236 .87319 L F
.5291 .88128 m .52951 .88007 L .5289 .88152 L 0 1 .409 r
F
.52957 .88 m .52951 .88007 L .5291 .88128 L F
.53349 .88054 m .52957 .88 L .5291 .88128 L 0 1 .477 r
F
.5289 .88152 m .52245 .88675 L .52268 .88859 L 0 1 .409 r
F
.52951 .88007 m .52245 .88675 L .5289 .88152 L F
.51939 .87259 m .52687 .87803 L .52662 .87269 L 0 1 .443 r
F
.53216 .8712 m .52208 .87388 L .52707 .87824 L 0 1 .475 r
F
.53216 .8712 m .52185 .87037 L .52208 .87388 L F
.53477 .88015 m .53607 .88405 L .54099 .87833 L 0 1 .42 r
F
.53477 .88015 m .54099 .87833 L .54035 .87697 L F
.53347 .87631 m .53477 .88015 L .53939 .8749 L 0 1 .409 r
F
.53347 .87631 m .53939 .8749 L .53875 .87349 L F
.53302 .87244 m .53347 .87631 L .53778 .8714 L 0 1 .393 r
F
.5325 .87356 m .53347 .87631 L .53302 .87244 L F
.53302 .87244 m .53349 .88054 L .53781 .8794 L 0 1 .475 r
F
.53216 .8712 m .5325 .87356 L .53302 .87244 L F
.5325 .87356 m .53349 .88054 L .53302 .87244 L F
.53216 .87263 m .5325 .87356 L .53302 .87244 L 0 1 .393 r
F
.53216 .8712 m .52616 .86922 L .52185 .87037 L 0 1 .475 r
F
.53302 .87244 m .53778 .8714 L .53318 .8721 L 0 1 .393 r
F
.53318 .8721 m .53781 .8794 L .53715 .87557 L 0 1 .475 r
F
.53216 .8712 m .53302 .87244 L .53318 .8721 L F
.53302 .87244 m .53781 .8794 L .53318 .8721 L F
.53318 .8721 m .53778 .8714 L .53713 .87002 L 0 1 .393 r
F
.53216 .87263 m .53302 .87244 L .53318 .8721 L F
.53077 .86121 m .52616 .86922 L .53216 .8712 L 0 1 .471 r
F
.53077 .86121 m .53216 .8712 L .534 .87047 L F
.534 .87047 m .534 .87047 L .53401 .87047 L 0 1 .368 r
F
.53521 .86815 m .53401 .87047 L .53614 .86797 L F
.53521 .86816 m .534 .87047 L .53615 .86963 L 0 1 .471 r
F
.53077 .86121 m .534 .87047 L .53521 .86816 L F
.53079 .86905 m .53216 .87263 L .534 .87047 L 0 1 .368 r
F
.53079 .86905 m .534 .87047 L .534 .87047 L F
.53079 .86905 m .53401 .87047 L .53521 .86815 L F
.53726 .86394 m .53573 .86713 L .53573 .86716 L 0 1 .466 r
F
.53077 .86121 m .53521 .86816 L .53546 .86555 L 0 1 .471 r
F
.53521 .86816 m .53522 .86812 L .53546 .86555 L F
.53079 .86905 m .53521 .86816 L .53546 .86661 L 0 1 .368 r
F
.53521 .86816 m .53614 .86797 L .53573 .86713 L F
.53522 .86818 m .53573 .86713 L .53546 .86555 L 0 1 .471 r
F
.53521 .86816 m .53573 .86713 L .53546 .86661 L 0 1 .368 r
F
.53521 .86816 m .53522 .86818 L .53522 .86812 L 0 1 .471 r
F
.53716 .86442 m .53573 .86716 L .53615 .86963 L 0 1 .466 r
F
.53726 .86394 m .53573 .86716 L .53716 .86442 L F
.53726 .86394 m .53547 .8666 L .53573 .86713 L 0 1 .376 r
F
.53522 .86818 m .53615 .86963 L .53573 .86713 L 0 1 .471 r
F
.536 .85273 m .53785 .86272 L .53863 .86047 L 0 1 .463 r
F
.53785 .86272 m .53833 .86175 L .53863 .86047 L F
.536 .85273 m .53624 .86284 L .53761 .86321 L F
.53785 .86274 m .53761 .86321 L .53796 .86289 L 0 1 .348 r
F
.53761 .86321 m .53624 .86284 L .53726 .86394 L 0 1 .466 r
F
.53726 .86394 m .5376 .86321 L .53721 .86401 L 0 1 .376 r
F
.53796 .86289 m .53761 .86321 L .53726 .86394 L F
.53761 .86321 m .5376 .86321 L .53726 .86394 L F
.53726 .86394 m .53624 .86284 L .53546 .86555 L 0 1 .466 r
F
.53796 .86331 m .53761 .86321 L .53726 .86394 L F
.53785 .86274 m .53761 .86321 L .53796 .86331 L 0 1 .463 r
F
.536 .85273 m .53761 .86321 L .53785 .86274 L F
.536 .85273 m .53443 .85935 L .53624 .86284 L F
.53602 .85998 m .53624 .86443 L .53761 .86321 L 0 1 .348 r
F
.53602 .85998 m .53761 .86321 L .53785 .86274 L F
.53602 .85998 m .53785 .86274 L .53864 .86088 L F
.53785 .86274 m .53796 .86289 L .5383 .86189 L F
.53785 .86272 m .53785 .86274 L .53833 .86175 L 0 1 .463 r
F
.53785 .86274 m .5383 .86189 L .53833 .86175 L F
.53785 .86274 m .5383 .86189 L .53864 .86088 L 0 1 .348 r
F
.53785 .86274 m .53796 .86331 L .5383 .86189 L 0 1 .463 r
F
.53721 .86401 m .53624 .86443 L .53547 .8666 L 0 1 .376 r
F
.5376 .86321 m .53624 .86443 L .53721 .86401 L F
.5392 .86005 m .53781 .85623 L .53864 .86047 L 0 1 .461 r
F
.54123 .85569 m .54122 .8557 L .5392 .86005 L 0 1 .349 r
F
.54605 .85496 m .54122 .8557 L .5392 .86005 L 0 1 .461 r
F
.54122 .8557 m .53781 .85623 L .5392 .86005 L F
.54122 .8557 m .53782 .85973 L .5392 .86005 L 0 1 .349 r
F
.5392 .86005 m .53864 .86088 L .53891 .86071 L F
.5392 .86005 m .53891 .86071 L .54335 .85782 L F
.54605 .85496 m .5392 .86005 L .54338 .86458 L 0 1 .461 r
F
.5392 .86005 m .53891 .86071 L .54338 .86458 L F
.5431 .84326 m .54099 .85386 L .54198 .85407 L 0 1 .456 r
F
.5431 .84326 m .54198 .85407 L .54451 .84884 L F
.5412 .8557 m .54099 .85386 L .53781 .85623 L 0 1 .461 r
F
.54122 .8557 m .54198 .85407 L .5412 .8557 L F
.54122 .8557 m .54198 .85407 L .54115 .85579 L 0 1 .349 r
F
.54603 .85 m .54198 .85407 L .54122 .8557 L F
.54198 .85407 m .54198 .85407 L .54122 .8557 L 0 1 .461 r
F
.54198 .85407 m .54198 .85407 L .54122 .8557 L 0 1 .349 r
F
.54605 .85496 m .54198 .85407 L .54122 .8557 L 0 1 .461 r
F
.54198 .85407 m .54099 .85386 L .5412 .8557 L F
.54312 .84793 m .54099 .85506 L .54198 .85407 L 0 1 .307 r
F
.54453 .84893 m .54198 .85407 L .54603 .85 L F
.54312 .84793 m .54198 .85407 L .54453 .84893 L F
.54451 .84884 m .54198 .85407 L .54605 .85495 L 0 1 .456 r
F
.54115 .85579 m .54099 .85507 L .53782 .85973 L 0 1 .349 r
F
.54198 .85407 m .54099 .85507 L .54115 .85579 L F
.54548 .84697 m .54603 .85 L .54883 .84562 L 0 1 .307 r
F
.54453 .84893 m .54603 .85 L .54548 .84697 L F
.54548 .84697 m .54605 .85495 L .54887 .85224 L 0 1 .456 r
F
.5431 .84326 m .54453 .84893 L .54548 .84697 L F
.54453 .84893 m .54605 .85495 L .54548 .84697 L F
.54312 .84793 m .54453 .84893 L .54548 .84697 L 0 1 .307 r
F
.54548 .84697 m .54883 .84562 L .54593 .84597 L F
.54593 .84597 m .54887 .85224 L .54755 .84752 L 0 1 .456 r
F
.5431 .84326 m .54548 .84697 L .54593 .84597 L F
.54548 .84697 m .54887 .85224 L .54593 .84597 L F
.54593 .84597 m .54883 .84562 L .54753 .84485 L 0 1 .307 r
F
.54312 .84793 m .54548 .84697 L .54593 .84597 L F
.5431 .84326 m .53654 .8496 L .54099 .85386 L 0 1 .456 r
F
.5402 .84679 m .54312 .84793 L .54558 .84398 L 0 1 .248 r
F
.5402 .84679 m .53853 .85281 L .54312 .84793 L F
.5402 .84679 m .54558 .84398 L .54428 .8436 L F
.5202 .85466 m .52048 .86143 L .52857 .85685 L 0 1 .512 r
F
.5202 .85466 m .52857 .85685 L .52834 .85414 L F
.54132 .83916 m .526 .85844 L .52625 .86429 L 0 1 .386 r
F
.54132 .83916 m .53246 .84766 L .526 .85844 L F
.5431 .84326 m .53849 .8423 L .53568 .84502 L 0 1 .456 r
F
.53968 .83773 m .52525 .83048 L .52555 .83227 L 0 .467 .351 r
F
.53968 .83773 m .5313 .83282 L .52525 .83048 L F
.53839 .82835 m .5313 .83281 L .53968 .83773 L 0 1 .5 r
F
.54013 .831 m .53849 .8423 L .5431 .84326 L 0 .999 .45 r
F
.54628 .83526 m .54232 .84342 L .54631 .83946 L 0 1 .205 r
F
.54248 .84789 m .5496 .82726 L .54881 .83112 L 0 0 .026 r
F
.54248 .84789 m .54771 .83074 L .5496 .82726 L F
.54607 .8429 m .55289 .82344 L .5496 .83371 L 0 0 .034 r
F
.54931 .83854 m .5496 .83371 L .55289 .82344 L 0 0 .045 r
F
.54248 .84789 m .54881 .83112 L .54585 .83978 L 0 0 .026 r
F
.54607 .8429 m .54585 .83978 L .54881 .83112 L 0 0 .034 r
F
.54931 .83854 m .54806 .8402 L .5496 .83371 L 0 0 .045 r
F
.55256 .85786 m .55766 .83497 L .55306 .85761 L 0 .132 .117 r
F
.55559 .8554 m .555 .8566 L .55572 .85634 L 0 .252 .226 r
F
.55123 .85689 m .55666 .83344 L .55402 .84667 L 0 .111 .11 r
F
.55123 .85689 m .55666 .83344 L .55123 .85689 L F
.55078 .85693 m .55666 .83344 L .55122 .85692 L F
.54501 .8051 m .54803 .8142 L .54725 .80888 L 0 1 .432 r
F
.54971 .80516 m .54756 .81524 L .55147 .81972 L 0 .9 .424 r
F
.54971 .80516 m .54578 .80946 L .54756 .81524 L F
.54971 .80516 m .5467 .80514 L .54578 .80946 L F
.54449 .7892 m .5467 .80514 L .54971 .80516 L 0 .91 .413 r
F
.55218 .83515 m .55108 .83638 L .55296 .82814 L 0 0 .057 r
F
.54843 .85709 m .5537 .83381 L .55463 .83323 L 0 .087 .104 r
F
.54843 .85709 m .5537 .83381 L .54843 .85709 L F
.54804 .85742 m .5537 .83381 L .54842 .85712 L F
.54651 .85605 m .55108 .83638 L .55218 .83515 L 0 .061 .097 r
F
.54641 .85611 m .55108 .83638 L .54651 .85605 L F
.54605 .85496 m .54338 .86458 L .54888 .8658 L 0 1 .461 r
F
.5455 .85882 m .54605 .85659 L .54584 .85851 L 0 .061 .097 r
F
.54605 .85659 m .55108 .83638 L .54632 .85647 L F
.54605 .85659 m .54632 .85647 L .54584 .85851 L F
.55501 .8586 m .55419 .85781 L .55517 .85788 L 0 .151 .126 r
F
.55372 .85803 m .55868 .89647 L .55549 .86911 L 0 .252 .229 r
F
.55371 .85797 m .55372 .85803 L .55372 .85803 L F
.55372 .85803 m .55868 .89647 L .55372 .85803 L F
.5537 .85796 m .55868 .89647 L .55371 .85797 L F
.55307 .85784 m .55824 .83665 L .55369 .85782 L 0 .132 .117 r
F
.55304 .85762 m .55307 .85784 L .55365 .85759 L 0 .252 .229 r
F
.55307 .85784 m .55868 .89647 L .55368 .85782 L F
.55307 .85784 m .55368 .85782 L .55365 .85759 L F
.55369 .85782 m .55824 .83665 L .55537 .85157 L 0 .132 .117 r
F
.55014 .85808 m .55017 .85828 L .55051 .85821 L 0 .253 .233 r
F
.55696 .90175 m .55282 .90809 L .55569 .90804 L 0 1 .445 r
F
.55696 .90175 m .55216 .90654 L .55282 .90809 L F
.55696 .90175 m .55393 .90382 L .55216 .90654 L F
.55885 .90642 m .55382 .91075 L .55448 .91274 L 0 1 .5 r
F
.55885 .90642 m .55569 .90804 L .55382 .91075 L F
.55696 .90175 m .55569 .90804 L .55885 .90642 L 0 1 .445 r
F
.5571 .89668 m .55259 .90528 L .55978 .90719 L 0 .982 .458 r
F
.5544 .8865 m .55032 .89497 L .5571 .89668 L 0 1 .463 r
F
.55026 .85896 m .55639 .9041 L .55061 .85901 L 0 .253 .233 r
F
.55515 .86127 m .55491 .85908 L .55561 .85941 L 0 .151 .126 r
F
.55056 .85837 m .55639 .9041 L .55714 .90293 L 0 .253 .233 r
F
.55056 .85836 m .55639 .9041 L .55056 .85837 L F
.55054 .8582 m .55639 .9041 L .55054 .8582 L F
.55185 .85788 m .55128 .85822 L .55423 .8783 L 0 .252 .229 r
F
.55014 .85808 m .55021 .85776 L .55051 .85801 L 0 .111 .11 r
F
.55021 .85776 m .5559 .83308 L .55062 .85752 L F
.55021 .85776 m .55062 .85752 L .55051 .85801 L F
.5531 .85775 m .5532 .85724 L .55322 .85723 L 0 .132 .117 r
F
.55338 .85587 m .55304 .85762 L .55365 .85759 L 0 .252 .229 r
F
.55058 .85774 m .5559 .83308 L .55666 .83344 L 0 .111 .11 r
F
.55051 .85801 m .55057 .85775 L .55058 .85774 L F
.55057 .85775 m .5559 .83308 L .55058 .85774 L F
.55021 .85776 m .55226 .84476 L .5559 .83308 L F
.55019 .85776 m .55226 .84476 L .55021 .85776 L F
.54963 .85789 m .55226 .84476 L .55014 .85808 L F
.54628 .83526 m .54102 .84356 L .54232 .84342 L 0 1 .205 r
F
.54628 .83526 m .54271 .84006 L .54102 .84356 L F
.54224 .83816 m .54271 .84006 L .54628 .83526 L 0 .972 .169 r
F
.54248 .84789 m .54435 .8388 L .54771 .83074 L 0 0 .026 r
F
.54355 .87277 m .54035 .87696 L .541 .87832 L 0 1 .391 r
F
.54355 .87277 m .54145 .87458 L .54035 .87696 L F
.54172 .86948 m .54355 .87277 L .54455 .87045 L 0 1 .397 r
F
.54172 .86948 m .54145 .87458 L .54355 .87277 L F
.54172 .86948 m .53939 .87489 L .54145 .87458 L F
.54172 .86948 m .54455 .87045 L .54378 .86917 L F
.54172 .86948 m .53875 .87349 L .53939 .87489 L F
.54888 .8658 m .5407 .87091 L .54577 .87505 L 0 1 .464 r
F
.54172 .86948 m .53975 .87117 L .53875 .87349 L 0 1 .397 r
F
.53989 .86617 m .54172 .86948 L .54263 .86724 L 0 1 .391 r
F
.53989 .86617 m .53975 .87117 L .54172 .86948 L F
.53989 .86617 m .54263 .86724 L .54185 .86594 L F
.54888 .8658 m .53987 .86677 L .5407 .87091 L 0 1 .464 r
F
.54888 .8658 m .54338 .86458 L .53987 .86677 L F
.54342 .85944 m .54415 .85613 L .54438 .85604 L 0 .035 .091 r
F
.54438 .85604 m .54806 .8402 L .54931 .83854 L F
.54415 .85613 m .54806 .8402 L .54438 .85604 L F
.5431 .84326 m .53568 .84502 L .53654 .8496 L 0 1 .456 r
F
.54312 .84793 m .53657 .85815 L .54099 .85506 L 0 1 .307 r
F
.54312 .84793 m .53572 .85719 L .53657 .85815 L F
.54312 .84793 m .53853 .85281 L .53572 .85719 L F
.53727 .84694 m .5402 .84679 L .54232 .84342 L 0 1 .195 r
F
.53727 .84694 m .54232 .84342 L .54102 .84356 L F
.54224 .83816 m .53905 .84431 L .54271 .84006 L 0 .972 .169 r
F
.54224 .83816 m .53774 .84517 L .53905 .84431 L F
.54224 .83816 m .53911 .84253 L .53774 .84517 L F
.54472 .83359 m .54152 .83899 L .54328 .83664 L 0 .863 .129 r
F
.54472 .83359 m .54214 .83768 L .54152 .83899 L F
.5435 .8361 m .54214 .83768 L .54472 .83359 L 0 0 0 r
F
.53891 .8426 m .54224 .83816 L .54328 .83664 L 0 .82 .12 r
F
.53848 .84319 m .54224 .83816 L .53864 .84297 L F
.53854 .84311 m .53864 .84297 L .53864 .84297 L F
.53848 .84319 m .53864 .84297 L .53854 .84311 L F
.53848 .84319 m .53911 .84253 L .54224 .83816 L F
.53818 .8436 m .53826 .8435 L .53848 .84319 L F
.53826 .8435 m .53911 .84253 L .53848 .84319 L F
.53818 .8436 m .54328 .83664 L .54152 .83899 L F
.53958 .8442 m .53889 .84347 L .54116 .83942 L 0 0 0 r
F
.54119 .83939 m .54116 .83942 L .54119 .83937 L F
.53958 .8442 m .54116 .83942 L .54119 .83939 L F
.54183 .83847 m .54119 .83937 L .54214 .83768 L F
.53958 .8442 m .54119 .83937 L .54183 .83847 L F
.53958 .8442 m .54183 .83847 L .5435 .8361 L F
.54183 .83847 m .54214 .83768 L .5435 .8361 L F
.53864 .84297 m .53882 .84274 L .53891 .8426 L 0 .82 .12 r
F
.53882 .84274 m .54224 .83816 L .53891 .8426 L F
.53818 .8436 m .53848 .84319 L .53864 .84297 L F
.54488 .83415 m .54472 .83359 L .54502 .83389 L 0 0 0 r
F
.53958 .8442 m .5435 .8361 L .54488 .83415 L F
.5435 .8361 m .54472 .83359 L .54488 .83415 L F
.53958 .8442 m .54502 .83389 L .54284 .83839 L F
.53858 .85324 m .54476 .83588 L .54435 .8388 L 0 0 .02 r
F
.53858 .85324 m .54272 .83925 L .54476 .83588 L F
.536 .85273 m .53374 .85516 L .53443 .85935 L 0 1 .463 r
F
.5402 .84679 m .53444 .85602 L .53853 .85281 L 0 1 .248 r
F
.52938 .85089 m .53443 .85935 L .53374 .85516 L 0 1 .467 r
F
.536 .85273 m .53441 .85232 L .53374 .85516 L 0 1 .463 r
F
.53395 .84131 m .53441 .85232 L .536 .85273 L 0 1 .458 r
F
.53395 .84131 m .536 .85273 L .53654 .8496 L F
.5402 .84679 m .53359 .8554 L .53444 .85602 L 0 1 .248 r
F
.5402 .84679 m .53606 .85145 L .53359 .8554 L F
.53727 .84694 m .53606 .85145 L .5402 .84679 L 0 1 .195 r
F
.53858 .85324 m .53955 .84636 L .54272 .83925 L 0 0 .02 r
F
.53858 .85324 m .54435 .8388 L .54176 .8461 L F
.54248 .84789 m .54095 .85 L .54176 .8461 L 0 0 .026 r
F
.54311 .85959 m .54329 .86091 L .54342 .85944 L 0 .264 .249 r
F
.54331 .86102 m .54838 .89763 L .54362 .86097 L F
.54383 .86208 m .54838 .89763 L .54967 .8996 L F
.54377 .86211 m .54838 .89763 L .54383 .86208 L F
.54433 .8627 m .54967 .8996 L .54774 .88249 L F
.55094 .85794 m .55714 .90293 L .55423 .8783 L 0 .253 .233 r
F
.55088 .8579 m .55714 .90293 L .55094 .85794 L F
.54992 .85648 m .54924 .8565 L .55226 .84476 L 0 .111 .11 r
F
.55012 .85538 m .55044 .85751 L .55051 .85524 L 0 .253 .233 r
F
.55051 .85801 m .55078 .85693 L .5509 .85794 L 0 .111 .11 r
F
.55051 .85801 m .55714 .90293 L .55088 .85795 L 0 .253 .233 r
F
.55051 .85801 m .5509 .85794 L .55091 .85806 L 0 .111 .11 r
F
.55044 .85751 m .55051 .85801 L .55085 .8577 L 0 .253 .233 r
F
.55051 .85801 m .55088 .85795 L .55085 .8577 L F
.55044 .85751 m .55085 .8577 L .55051 .85524 L F
.54424 .86274 m .54967 .8996 L .54433 .8627 L 0 .264 .249 r
F
.54844 .85827 m .54853 .85884 L .5488 .85822 L 0 .256 .238 r
F
.54853 .85884 m .5525 .88284 L .54887 .85865 L F
.54853 .85884 m .54887 .85865 L .5488 .85822 L F
.54342 .85944 m .54352 .86007 L .54373 .85925 L 0 .264 .249 r
F
.55048 .85801 m .55639 .9041 L .55051 .85801 L 0 .253 .233 r
F
.55054 .8582 m .55056 .85836 L .55056 .85837 L F
.55051 .85801 m .55054 .8582 L .55054 .8582 L F
.55046 .85969 m .55051 .85801 L .55091 .85806 L 0 .111 .11 r
F
.5437 .86122 m .54967 .8996 L .54401 .86115 L 0 .264 .249 r
F
.54352 .86007 m .5437 .86122 L .54385 .86006 L F
.54352 .86007 m .54385 .86006 L .54373 .85925 L F
.54329 .86091 m .54331 .86102 L .54359 .86076 L F
.54331 .86102 m .54362 .86097 L .54359 .86076 L F
.54329 .86091 m .54359 .86076 L .54342 .85944 L F
.54262 .85995 m .54191 .86069 L .54198 .86117 L F
.54269 .86056 m .54198 .86117 L .54478 .8792 L F
.54262 .85995 m .54198 .86117 L .54269 .86056 L F
.54648 .8573 m .55218 .83515 L .55009 .84507 L 0 .061 .097 r
F
.54415 .85969 m .54418 .85983 L .54419 .85966 L 0 .264 .249 r
F
.54803 .85745 m .55009 .84507 L .5537 .83381 L 0 .087 .104 r
F
.5442 .86001 m .54774 .88249 L .54424 .85998 L 0 .264 .249 r
F
.54374 .85932 m .54395 .85866 L .54413 .85924 L 0 .035 .091 r
F
.54873 .86006 m .55511 .90476 L .5525 .88284 L 0 .256 .238 r
F
.5487 .86006 m .55511 .90476 L .54873 .86006 L F
.54812 .85854 m .54836 .8601 L .54848 .85852 L F
.54836 .8601 m .55511 .90476 L .5487 .86006 L F
.54836 .8601 m .5487 .86006 L .54848 .85852 L F
.55189 .85819 m .55423 .8783 L .55256 .85786 L 0 .252 .229 r
F
.55265 .85957 m .55268 .8593 L .55272 .8593 L 0 .132 .117 r
F
.54746 .85783 m .55009 .84507 L .54803 .85745 L 0 .087 .104 r
F
.5464 .85737 m .55218 .83515 L .54648 .8573 L 0 .061 .097 r
F
.54608 .85765 m .54612 .8575 L .5464 .85737 L F
.54612 .8575 m .55218 .83515 L .5464 .85737 L F
.55267 .85741 m .55402 .84667 L .55766 .83497 L 0 .132 .117 r
F
.55312 .85428 m .55284 .85619 L .55338 .85587 L 0 .252 .229 r
F
.54974 .85813 m .54995 .85801 L .55014 .85808 L 0 .111 .11 r
F
.54613 .86129 m .55148 .90204 L .5526 .90332 L 0 .259 .243 r
F
.54613 .86129 m .55148 .90204 L .54613 .86129 L F
.54607 .86117 m .55148 .90204 L .54611 .86118 L F
.54848 .85852 m .5487 .86006 L .54873 .86006 L 0 .256 .238 r
F
.54584 .85939 m .54607 .86117 L .54584 .85939 L 0 .259 .243 r
F
.54607 .86117 m .55148 .90204 L .54607 .86117 L F
.54607 .86117 m .54607 .86117 L .54584 .85939 L F
.55181 .86183 m .55214 .85977 L .55232 .85961 L 0 .132 .117 r
F
.54958 .85815 m .5525 .88284 L .5501 .85808 L 0 .253 .233 r
F
.55014 .85808 m .5525 .88284 L .55639 .9041 L F
.5501 .85808 m .5525 .88284 L .55014 .85808 L F
.54549 .85916 m .54577 .86114 L .54583 .85937 L 0 .259 .243 r
F
.54577 .86114 m .55148 .90204 L .54607 .86117 L F
.54577 .86114 m .54607 .86117 L .54583 .85937 L F
.55206 .86186 m .55232 .85961 L .55261 .85958 L 0 .132 .117 r
F
.54622 .85966 m .5526 .90332 L .55032 .88393 L 0 .259 .243 r
F
.54619 .85951 m .54621 .85966 L .54622 .85966 L F
.54621 .85966 m .5526 .90332 L .54622 .85966 L F
.55304 .86023 m .55272 .8593 L .55323 .85951 L 0 .132 .117 r
F
.54583 .85937 m .5526 .90332 L .54619 .85951 L 0 .259 .243 r
F
.54342 .85944 m .5437 .85847 L .54374 .85932 L 0 .035 .091 r
F
.55282 .86101 m .5525 .86018 L .55304 .86023 L 0 .132 .117 r
F
.5482 .85902 m .55416 .90449 L .55511 .90476 L 0 .256 .238 r
F
.54818 .85902 m .55416 .90449 L .5482 .85902 L F
.54779 .85846 m .55416 .90449 L .54812 .8585 L F
.54797 .8584 m .54812 .8585 L .5481 .85836 L F
.54779 .85846 m .54812 .8585 L .54797 .8584 L F
.55477 .86286 m .55452 .86087 L .55515 .86127 L 0 .151 .126 r
F
.54779 .85846 m .55032 .88393 L .55416 .90449 L 0 .256 .238 r
F
.54734 .8588 m .55032 .88393 L .54779 .85846 L F
.55094 .85794 m .55423 .8783 L .55124 .85791 L 0 .253 .233 r
F
.55366 .85767 m .55369 .85782 L .55381 .85753 L 0 .252 .229 r
F
.55369 .85782 m .55549 .86911 L .55386 .85781 L F
.55369 .85782 m .55537 .85157 L .55386 .85781 L 0 .132 .117 r
F
.55369 .85782 m .55386 .85781 L .55381 .85753 L 0 .252 .229 r
F
.54391 .86029 m .54774 .88249 L .54422 .8601 L 0 .264 .249 r
F
.5481 .85836 m .55463 .83323 L .54839 .8582 L 0 .087 .104 r
F
.54817 .85834 m .54839 .8582 L .54837 .85829 L F
.5481 .85836 m .54839 .8582 L .54817 .85834 L F
.55617 .85334 m .55572 .85634 L .55624 .85378 L 0 .252 .226 r
F
.54844 .85827 m .55463 .83323 L .55226 .84476 L 0 .087 .104 r
F
.54835 .85835 m .55463 .83323 L .54844 .85827 L F
.54383 .858 m .5441 .85705 L .54412 .85791 L 0 .035 .091 r
F
.5441 .85705 m .54931 .83854 L .54435 .85703 L F
.5441 .85705 m .54435 .85703 L .54412 .85791 L F
.54789 .85839 m .54804 .85742 L .54803 .85828 L 0 .087 .104 r
F
.54779 .85846 m .54804 .85742 L .54788 .85843 L F
.54779 .85846 m .54746 .85783 L .54803 .85745 L F
.54777 .85855 m .54774 .85847 L .54779 .85846 L F
.54774 .85847 m .54746 .85783 L .54779 .85846 L F
.5456 .85841 m .54755 .84699 L .55108 .83638 L 0 .061 .097 r
F
.54557 .85842 m .54755 .84699 L .5456 .85841 L F
.54748 .85856 m .54746 .85783 L .54777 .85855 L 0 .087 .104 r
F
.54406 .85829 m .54755 .84699 L .54434 .85846 L 0 .035 .091 r
F
.54546 .85896 m .54774 .88249 L .55148 .90204 L 0 .259 .243 r
F
.54502 .85909 m .54508 .85872 L .54552 .85875 L 0 .061 .097 r
F
.545 .8591 m .54508 .85872 L .54502 .85909 L F
.54508 .85872 m .54755 .84699 L .54554 .85859 L F
.54508 .85872 m .54554 .85859 L .54552 .85875 L F
.54435 .85736 m .54931 .83854 L .54755 .84699 L 0 .035 .091 r
F
.54426 .85739 m .54931 .83854 L .54435 .85736 L F
.54316 .85939 m .5432 .85923 L .54341 .85912 L F
.545 .8591 m .54502 .8593 L .54546 .85896 L 0 .259 .243 r
F
.54502 .8593 m .54774 .88249 L .54546 .85896 L F
.54522 .85995 m .54546 .85896 L .54549 .85981 L 0 .061 .097 r
F
.54546 .85896 m .5455 .85882 L .5455 .85894 L F
.54546 .85896 m .5455 .85894 L .54549 .85981 L F
.54611 .86118 m .54613 .86129 L .54613 .86129 L 0 .259 .243 r
F
.54321 .86029 m .54478 .8792 L .54838 .89763 L 0 .264 .249 r
F
.54575 .85884 m .5455 .85882 L .54584 .85851 L 0 .061 .097 r
F
.54575 .85884 m .54549 .85916 L .54583 .85937 L 0 .259 .243 r
F
.54559 .85891 m .54549 .85916 L .54575 .85884 L F
.54549 .85981 m .5455 .85895 L .54575 .85884 L 0 .061 .097 r
F
.5455 .85895 m .5455 .85882 L .54575 .85884 L F
.54571 .85858 m .54559 .85891 L .54575 .85884 L 0 .259 .243 r
F
.5434 .85846 m .54464 .85005 L .54806 .8402 L 0 .035 .091 r
F
.54329 .85846 m .54464 .85005 L .5434 .85846 L F
.5426 .85976 m .54275 .85905 L .54311 .85959 L F
.54275 .85905 m .54464 .85005 L .54321 .85898 L F
.54275 .85905 m .54321 .85898 L .54311 .85959 L F
.54606 .85874 m .54583 .85937 L .54619 .85951 L 0 .259 .243 r
F
.54309 .86035 m .54478 .8792 L .54321 .86029 L 0 .264 .249 r
F
.53989 .86617 m .53714 .87002 L .53778 .8714 L 0 1 .391 r
F
.53989 .86617 m .53804 .86778 L .53714 .87002 L F
.53796 .86289 m .53989 .86617 L .54066 .864 L 0 1 .376 r
F
.53796 .86289 m .53804 .86778 L .53989 .86617 L F
.53796 .86289 m .54066 .864 L .53985 .86271 L F
.53989 .86617 m .53778 .8714 L .53975 .87117 L 0 1 .391 r
F
.53796 .86331 m .53806 .87308 L .53992 .87362 L 0 1 .466 r
F
.53796 .86331 m .53615 .86963 L .53806 .87308 L F
.53796 .86331 m .53992 .87362 L .5407 .87091 L F
.53796 .86331 m .5407 .87091 L .53987 .86677 L F
.5426 .85976 m .54304 .85982 L .5429 .85818 L 0 .264 .249 r
F
.543 .86001 m .5426 .85976 L .54311 .85959 L 0 .035 .091 r
F
.53736 .88794 m .54417 .88419 L .54354 .88317 L 0 1 .415 r
F
.53736 .88794 m .53865 .89184 L .54417 .88419 L F
.53607 .88405 m .54259 .88149 L .54195 .88026 L 0 1 .423 r
F
.53607 .88405 m .53736 .88794 L .54259 .88149 L F
.54179 .88337 m .54365 .89313 L .54465 .89074 L 0 .996 .466 r
F
.54179 .88337 m .54465 .89074 L .54387 .88679 L F
.53992 .87362 m .54179 .88337 L .54269 .88089 L 0 1 .467 r
F
.53992 .87362 m .54269 .88089 L .5419 .87697 L F
.53931 .86194 m .54267 .88791 L .54149 .87457 L 0 .279 .261 r
F
.53922 .86147 m .53929 .86195 L .53931 .86194 L F
.53929 .86195 m .54267 .88791 L .53931 .86194 L F
.54366 .85957 m .54342 .85944 L .54374 .85932 L 0 .035 .091 r
F
.53862 .861 m .53875 .86186 L .53911 .86079 L 0 .279 .261 r
F
.53875 .86186 m .54267 .88791 L .53921 .86155 L F
.53875 .86186 m .53921 .86155 L .53911 .86079 L F
.54364 .85966 m .54334 .85975 L .54366 .85957 L 0 .035 .091 r
F
.54169 .86142 m .54634 .8943 L .54478 .8792 L 0 .271 .255 r
F
.54155 .86062 m .54166 .86143 L .54169 .86142 L F
.54166 .86143 m .54634 .8943 L .54169 .86142 L F
.54598 .85871 m .54583 .85937 L .54606 .85874 L 0 .259 .243 r
F
.54575 .85884 m .54589 .85832 L .54601 .85876 L 0 .061 .097 r
F
.54571 .85858 m .54575 .85884 L .54602 .85853 L 0 .259 .243 r
F
.54575 .85884 m .54583 .85937 L .54597 .85877 L F
.54575 .85884 m .54597 .85877 L .54602 .85853 L F
.54571 .859 m .54575 .85884 L .54603 .85883 L 0 .061 .097 r
F
.54575 .85884 m .54601 .85876 L .54603 .85883 L F
.54583 .85937 m .54584 .85939 L .54584 .85939 L 0 .259 .243 r
F
.54585 .85945 m .54571 .859 L .54603 .85883 L 0 .061 .097 r
F
.54153 .86063 m .54156 .86087 L .54155 .86062 L 0 .271 .255 r
F
.54156 .86087 m .54634 .8943 L .54158 .86086 L F
.54156 .86087 m .54158 .86086 L .54155 .86062 L F
.54525 .85981 m .545 .85911 L .54552 .85875 L 0 .061 .097 r
F
.54587 .85759 m .54571 .85858 L .54602 .85853 L 0 .259 .243 r
F
.54781 .85645 m .54756 .85678 L .54786 .85675 L 0 .256 .238 r
F
.54249 .85672 m .54607 .8429 L .54464 .85005 L 0 .009 .084 r
F
.54242 .85673 m .54607 .8429 L .54249 .85672 L F
.54204 .858 m .54204 .85799 L .54208 .858 L F
.54204 .85799 m .54607 .8429 L .54209 .85798 L F
.54204 .85799 m .54209 .85798 L .54208 .858 L F
.54812 .85636 m .54786 .85675 L .54817 .85665 L 0 .256 .238 r
F
.54177 .85877 m .54607 .8429 L .54184 .85875 L 0 .009 .084 r
F
.54107 .86015 m .54129 .85937 L .54144 .86 L F
.54129 .85937 m .54607 .8429 L .54165 .85922 L F
.54129 .85937 m .54165 .85922 L .54144 .86 L F
.54113 .86059 m .54634 .8943 L .54151 .86048 L 0 .271 .255 r
F
.54284 .85979 m .54478 .8792 L .54304 .85982 L 0 .264 .249 r
F
.5426 .85976 m .54262 .85995 L .54284 .85979 L F
.54262 .85995 m .54478 .8792 L .54284 .85979 L F
.54302 .85961 m .54309 .86035 L .54311 .85959 L F
.54266 .86134 m .54311 .85959 L .54294 .86104 L 0 .035 .091 r
F
.54311 .85959 m .54316 .85939 L .54314 .85957 L F
.54311 .85959 m .54314 .85957 L .54294 .86104 L F
.5437 .86122 m .54401 .86115 L .54385 .86006 L 0 .264 .249 r
F
.54374 .85932 m .54424 .86274 L .54433 .8627 L F
.54374 .85932 m .54424 .86274 L .54374 .85932 L F
.54342 .85944 m .54377 .86211 L .54383 .86208 L F
.54144 .85999 m .54177 .85877 L .54184 .85875 L 0 .009 .084 r
F
.54144 .86 m .54144 .85999 L .54144 .85999 L F
.54144 .85999 m .54177 .85877 L .54144 .85999 L F
.5426 .85976 m .54191 .86069 L .54262 .85995 L 0 .264 .249 r
F
.54227 .85982 m .54191 .86069 L .5426 .85976 L F
.53911 .86079 m .53929 .86024 L .53938 .86073 L 0 0 .077 r
F
.53929 .86024 m .5414 .85388 L .53951 .8603 L F
.53929 .86024 m .53951 .8603 L .53938 .86073 L F
.54352 .86004 m .54332 .85981 L .54364 .85966 L 0 .035 .091 r
F
.54116 .8608 m .54491 .89185 L .54634 .8943 L 0 .271 .255 r
F
.54116 .8608 m .54491 .89185 L .54116 .8608 L F
.54078 .86064 m .54491 .89185 L .54116 .86074 L F
.54071 .86062 m .54072 .86065 L .54078 .86064 L F
.54072 .86065 m .54491 .89185 L .54078 .86064 L F
.54267 .86034 m .54251 .8602 L .54273 .86011 L 0 .035 .091 r
F
.54144 .85999 m .54179 .85992 L .54144 .86 L 0 .009 .084 r
F
.54144 .86 m .54144 .86 L .54179 .85992 L 0 .271 .255 r
F
.54144 .86 m .54478 .8792 L .54179 .85992 L F
.54144 .86 m .54153 .86063 L .54155 .86062 L F
.54143 .85993 m .54144 .86 L .54144 .86 L F
.54144 .86 m .54153 .86063 L .54144 .86 L F
.54144 .86 m .54179 .85992 L .54175 .86005 L 0 .009 .084 r
F
.54144 .86 m .54175 .86005 L .54131 .86157 L F
.54144 .86 m .54175 .86005 L .54144 .86 L F
.53924 .86153 m .54149 .87457 L .53947 .86131 L 0 .279 .261 r
F
.54068 .86034 m .5414 .85388 L .54467 .84485 L 0 .009 .084 r
F
.54064 .86036 m .54149 .87457 L .54068 .86034 L 0 .271 .255 r
F
.54005 .86057 m .54008 .86043 L .54068 .86034 L 0 .009 .084 r
F
.54008 .86043 m .5414 .85388 L .54068 .86034 L F
.54109 .86028 m .54071 .86062 L .54116 .86074 L 0 .271 .255 r
F
.54005 .86057 m .53943 .86056 L .5414 .85388 L 0 .009 .084 r
F
.54107 .86015 m .54074 .8601 L .54121 .85965 L F
.54107 .86015 m .54068 .86034 L .54109 .86028 L 0 .271 .255 r
F
.54092 .86024 m .54091 .86023 L .54107 .86015 L 0 .009 .084 r
F
.54091 .86023 m .54074 .8601 L .54107 .86015 L F
.54074 .8601 m .54086 .85964 L .54121 .85965 L F
.54545 .85686 m .54529 .8577 L .54557 .85768 L 0 .259 .243 r
F
.54124 .85817 m .54467 .84485 L .54158 .85807 L 0 .009 .084 r
F
.545 .8591 m .54413 .85924 L .54755 .84699 L 0 .061 .097 r
F
.545 .8591 m .54413 .85924 L .54774 .88249 L 0 .259 .243 r
F
.545 .85911 m .54413 .85924 L .545 .8591 L 0 .061 .097 r
F
.54205 .85675 m .54467 .84485 L .54607 .8429 L 0 .009 .084 r
F
.54606 .85874 m .55009 .84507 L .54645 .85867 L 0 .061 .097 r
F
.54605 .8587 m .55032 .88393 L .54645 .85867 L 0 .259 .243 r
F
.54609 .85875 m .54645 .85867 L .54639 .85889 L 0 .061 .097 r
F
.54606 .85874 m .54645 .85867 L .54609 .85875 L F
.54731 .85856 m .54645 .85867 L .55009 .84507 L 0 .087 .104 r
F
.5473 .85848 m .54645 .85867 L .54731 .85856 L 0 .256 .238 r
F
.5433 .85885 m .54332 .85876 L .54352 .85869 L 0 .035 .091 r
F
.55025 .85366 m .55012 .85538 L .55051 .85524 L 0 .253 .233 r
F
.54358 .85772 m .54806 .8402 L .54379 .8576 L 0 .035 .091 r
F
.54844 .85827 m .55226 .84476 L .5488 .85822 L 0 .087 .104 r
F
.54578 .82598 m .5499 .85387 L .55025 .85366 L 0 .253 .233 r
F
.5499 .85387 m .55012 .85538 L .55025 .85366 L F
.54332 .85876 m .54358 .85772 L .54355 .85859 L 0 .035 .091 r
F
.54358 .85772 m .54379 .8576 L .54355 .85859 L F
.54332 .85876 m .54355 .85859 L .54352 .85869 L F
.54959 .85399 m .54929 .85566 L .54978 .85541 L 0 .253 .233 r
F
.54578 .82598 m .54913 .85434 L .54959 .85399 L F
.54913 .85434 m .54929 .85566 L .54959 .85399 L F
.54584 .85851 m .54641 .85611 L .54651 .85605 L 0 .061 .097 r
F
.54476 .83588 m .54284 .83839 L .54502 .83389 L 0 0 0 r
F
.54476 .83588 m .54272 .83925 L .54284 .83839 L F
.54607 .8429 m .54467 .84485 L .54585 .83978 L 0 0 .034 r
F
.54431 .83328 m .54645 .85867 L .5473 .85848 L 0 .256 .238 r
F
.54431 .83328 m .54619 .85696 L .54645 .85867 L F
.54731 .85856 m .54652 .85913 L .55032 .88393 L F
.5471 .85961 m .54731 .85856 L .5475 .85968 L 0 .087 .104 r
F
.54731 .85856 m .54746 .85783 L .54748 .85845 L F
.54731 .85856 m .54748 .85845 L .5475 .85968 L F
.54731 .85856 m .54645 .85867 L .54652 .85913 L 0 .256 .238 r
F
.5473 .85861 m .54645 .85867 L .54731 .85856 L 0 .087 .104 r
F
.54719 .85915 m .54639 .8589 L .54645 .85867 L F
.54719 .85915 m .54645 .85867 L .5473 .85861 L F
.54196 .85677 m .54467 .84485 L .54205 .85675 L 0 .009 .084 r
F
.54156 .85814 m .54467 .84485 L .54166 .85809 L F
.54144 .85999 m .54464 .85005 L .54179 .85992 L F
.5426 .85976 m .54186 .85965 L .54464 .85005 L 0 .035 .091 r
F
.54606 .85874 m .54589 .85832 L .54628 .85798 L 0 .061 .097 r
F
.54603 .85883 m .54602 .85878 L .54606 .85874 L F
.54602 .85878 m .54589 .85832 L .54606 .85874 L F
.54589 .85832 m .54608 .85765 L .54628 .85798 L F
.54605 .8587 m .54611 .8587 L .54619 .85696 L 0 .259 .243 r
F
.54611 .8587 m .54645 .85867 L .54641 .85843 L F
.54628 .85798 m .54608 .85765 L .54648 .8573 L 0 .061 .097 r
F
.54611 .8587 m .54641 .85843 L .54619 .85696 L 0 .259 .243 r
F
.54248 .84789 m .54176 .8461 L .54435 .8388 L 0 0 .026 r
F
.54249 .83764 m .54605 .8587 L .54619 .85696 L 0 .259 .243 r
F
.54762 .85519 m .54752 .85646 L .54781 .85645 L 0 .256 .238 r
F
.54431 .83328 m .54735 .85527 L .54762 .85519 L F
.54735 .85527 m .54752 .85646 L .54762 .85519 L F
.54166 .85809 m .54196 .85677 L .54205 .85675 L 0 .009 .084 r
F
.54121 .85965 m .54156 .85814 L .54166 .85809 L F
.54791 .85505 m .54781 .85645 L .54812 .85636 L 0 .256 .238 r
F
.54431 .83328 m .54762 .85519 L .54791 .85505 L F
.54762 .85519 m .54781 .85645 L .54791 .85505 L F
.54383 .858 m .54412 .85791 L .54401 .85831 L 0 .035 .091 r
F
.54374 .85932 m .54426 .85739 L .54435 .85736 L F
.54341 .85945 m .54415 .85613 L .54342 .85944 L F
.54326 .85974 m .54415 .85613 L .54337 .85963 L F
.54249 .83764 m .54391 .85783 L .54413 .85924 L 0 .259 .243 r
F
.54395 .85866 m .54406 .85829 L .54426 .85877 L 0 .035 .091 r
F
.54406 .85829 m .54434 .85846 L .54426 .85877 L F
.54395 .85866 m .54426 .85877 L .54413 .85924 L F
.54249 .83764 m .54413 .85924 L .545 .8591 L 0 .259 .243 r
F
.54249 .83764 m .54518 .85694 L .54545 .85686 L F
.54518 .85694 m .54529 .8577 L .54545 .85686 L F
.54086 .85964 m .54124 .85817 L .54127 .85938 L 0 .009 .084 r
F
.54124 .85817 m .54158 .85807 L .54127 .85938 L F
.54086 .85964 m .54127 .85938 L .54121 .85965 L F
.54518 .85694 m .54486 .85788 L .54529 .8577 L 0 .259 .243 r
F
.54249 .83764 m .54478 .85719 L .54518 .85694 L F
.54478 .85719 m .54486 .85788 L .54518 .85694 L F
.53893 .85997 m .54248 .84789 L .53932 .85986 L 0 0 .077 r
F
.53963 .85921 m .54248 .84789 L .5414 .85388 L F
.53948 .85923 m .54248 .84789 L .53963 .85921 L F
.54013 .831 m .53438 .83798 L .53849 .8423 L 0 .999 .45 r
F
.53395 .84131 m .53654 .8496 L .53568 .84502 L 0 1 .458 r
F
.53432 .8488 m .53727 .84694 L .53905 .84431 L 0 .917 .162 r
F
.53432 .8488 m .53905 .84431 L .53774 .84517 L F
.53818 .8436 m .53577 .84714 L .53911 .84253 L 0 .82 .12 r
F
.53395 .84131 m .53268 .84862 L .53441 .85232 L 0 1 .458 r
F
.53727 .84694 m .5323 .85484 L .53606 .85145 L 0 1 .195 r
F
.52938 .85089 m .53077 .86121 L .53443 .85935 L 0 1 .467 r
F
.53727 .84694 m .53145 .8547 L .5323 .85484 L 0 1 .195 r
F
.53727 .84694 m .53357 .85131 L .53145 .8547 L F
.53432 .8488 m .53357 .85131 L .53727 .84694 L 0 .917 .162 r
F
.5341 .85215 m .53818 .8436 L .53889 .84347 L 0 0 0 r
F
.5341 .85215 m .53889 .84347 L .53712 .84711 L F
.53958 .8442 m .53712 .84711 L .53889 .84347 L F
.53958 .8442 m .53742 .84743 L .53712 .84711 L F
.534 .85754 m .53602 .85998 L .53657 .85815 L 0 1 .306 r
F
.534 .85754 m .53444 .86146 L .53602 .85998 L F
.534 .85754 m .53657 .85815 L .53572 .8572 L F
.5344 .85878 m .53958 .8442 L .53955 .84636 L 0 0 .016 r
F
.5344 .85878 m .53742 .84743 L .53958 .8442 L F
.5344 .85878 m .53955 .84636 L .53736 .85249 L F
.53858 .85324 m .53736 .85249 L .53955 .84636 L 0 0 .02 r
F
.54351 .85796 m .54332 .85877 L .54363 .85868 L 0 .264 .249 r
F
.53913 .85927 m .54095 .85 L .54248 .84789 L 0 0 .077 r
F
.53893 .85997 m .53906 .85929 L .53913 .85927 L F
.53906 .85929 m .54095 .85 L .53913 .85927 L F
.54321 .85809 m .543 .85881 L .54332 .85877 L 0 .264 .249 r
F
.54034 .83958 m .54291 .85817 L .54321 .85809 L F
.54291 .85817 m .543 .85881 L .54321 .85809 L F
.54034 .83958 m .54321 .85809 L .54351 .85796 L F
.54321 .85809 m .54332 .85877 L .54351 .85796 L F
.53882 .86034 m .53889 .85999 L .53893 .85997 L 0 0 .077 r
F
.53889 .85999 m .54095 .85 L .53893 .85997 L F
.53602 .85998 m .53864 .86088 L .53782 .85973 L 0 1 .348 r
F
.53395 .84131 m .53196 .84409 L .53268 .84862 L 0 1 .458 r
F
.53395 .84131 m .5325 .84096 L .53196 .84409 L F
.53839 .82835 m .52486 .8274 L .5313 .83281 L 0 1 .5 r
F
.53189 .82936 m .5325 .84096 L .53395 .84131 L 0 1 .452 r
F
.53432 .8488 m .53016 .85495 L .53357 .85131 L 0 .917 .162 r
F
.53137 .85287 m .53432 .8488 L .53577 .84714 L 0 0 0 r
F
.53137 .85287 m .53577 .84714 L .53445 .84891 L F
.53818 .8436 m .53445 .84891 L .53577 .84714 L 0 .82 .12 r
F
.53818 .8436 m .53548 .84739 L .53445 .84891 L F
.5341 .85215 m .53548 .84739 L .53818 .8436 L 0 0 0 r
F
.5341 .85215 m .53247 .85242 L .53548 .84739 L F
.5344 .85878 m .53447 .85369 L .53742 .84743 L 0 0 .016 r
F
.53893 .85997 m .53932 .85986 L .53907 .86081 L 0 0 .077 r
F
.53893 .8609 m .53907 .86081 L .53893 .86133 L F
.53893 .85997 m .53907 .86081 L .53893 .8609 L F
.53602 .85998 m .53445 .86468 L .53624 .86443 L 0 1 .348 r
F
.53603 .86199 m .53611 .8626 L .53668 .86172 L 0 .29 .268 r
F
.53992 .87362 m .53781 .8794 L .5398 .88274 L 0 1 .467 r
F
.53992 .87362 m .53716 .87557 L .53781 .8794 L F
.53992 .87362 m .53806 .87309 L .53716 .87557 L F
.53611 .8626 m .53869 .88075 L .53673 .8622 L 0 .29 .268 r
F
.53611 .8626 m .53673 .8622 L .53668 .86172 L F
.53863 .86097 m .53816 .861 L .53877 .86049 L 0 0 .077 r
F
.53671 .86188 m .53869 .88075 L .5379 .86895 L 0 .29 .268 r
F
.53668 .86172 m .5367 .86188 L .53671 .86188 L F
.5367 .86188 m .53869 .88075 L .53671 .86188 L F
.54005 .86057 m .54065 .86058 L .5406 .8598 L 0 .271 .255 r
F
.54056 .8608 m .54005 .86057 L .54068 .86034 L 0 .009 .084 r
F
.54068 .86034 m .54071 .86062 L .54109 .86028 L 0 .271 .255 r
F
.54094 .86057 m .54061 .86059 L .54102 .86031 L 0 .009 .084 r
F
.54179 .88337 m .54153 .89238 L .54365 .89313 L 0 .996 .466 r
F
.54179 .88337 m .53945 .88896 L .54153 .89238 L F
.54179 .88337 m .5388 .88514 L .53945 .88896 L F
.54179 .88337 m .5398 .88274 L .5388 .88514 L F
.53992 .87362 m .5398 .88274 L .54179 .88337 L 0 1 .467 r
F
.53875 .86186 m .54111 .88512 L .54267 .88791 L 0 .279 .261 r
F
.53874 .86187 m .54111 .88512 L .53875 .86186 L F
.53869 .86146 m .54111 .88512 L .53869 .86145 L F
.53866 .8613 m .54111 .88512 L .53867 .86129 L F
.5381 .86125 m .54111 .88512 L .53864 .86113 L F
.53941 .86072 m .53938 .86073 L .53943 .86056 L 0 .009 .084 r
F
.54001 .8602 m .53936 .86062 L .53938 .86073 L 0 .271 .255 r
F
.54005 .86057 m .53938 .86073 L .54149 .87457 L F
.54001 .8602 m .53938 .86073 L .54005 .86057 L F
.5392 .86148 m .54267 .88791 L .53922 .86147 L 0 .279 .261 r
F
.5381 .86125 m .5379 .86895 L .54111 .88512 L F
.53808 .86126 m .53808 .86126 L .5381 .86125 L 0 0 .077 r
F
.53725 .86157 m .5379 .86895 L .5381 .86125 L 0 .279 .261 r
F
.53723 .86167 m .53725 .86157 L .53808 .86133 L 0 0 .077 r
F
.53725 .86157 m .53786 .85823 L .53807 .86112 L F
.53725 .86157 m .53807 .86112 L .53808 .86133 L F
.53808 .86107 m .53725 .86157 L .5381 .86125 L 0 .279 .261 r
F
.53606 .86187 m .53615 .86156 L .53671 .86161 L 0 0 .07 r
F
.53615 .86156 m .53858 .85324 L .53675 .86141 L F
.53615 .86156 m .53675 .86141 L .53671 .86161 L F
.53862 .861 m .5381 .86125 L .53864 .86113 L 0 .279 .261 r
F
.53725 .86157 m .53686 .86179 L .5379 .86895 L F
.53676 .86218 m .5379 .86895 L .5369 .86207 L 0 .29 .268 r
F
.53611 .8626 m .53702 .87771 L .53869 .88075 L F
.53652 .86182 m .53603 .86199 L .53668 .86172 L 0 0 .07 r
F
.53598 .86214 m .53603 .86199 L .53652 .86182 L F
.53603 .86199 m .53536 .86304 L .53611 .8626 L 0 .29 .268 r
F
.53602 .85998 m .53377 .86347 L .53445 .86468 L 0 1 .348 r
F
.53602 .85998 m .53444 .86146 L .53377 .86347 L F
.5202 .85466 m .50944 .86482 L .52048 .86143 L 0 1 .512 r
F
.5191 .85901 m .52625 .86429 L .526 .85844 L 0 1 .425 r
F
.52938 .85089 m .52521 .85949 L .53077 .86121 L 0 1 .467 r
F
.53432 .8488 m .52929 .85543 L .53016 .85495 L 0 .917 .162 r
F
.53432 .8488 m .53108 .8528 L .52929 .85543 L F
.53137 .85287 m .53108 .8528 L .53432 .8488 L 0 0 0 r
F
.52076 .86853 m .50037 .87934 L .50916 .87906 L 0 1 .51 r
F
.52076 .86853 m .50056 .87648 L .50037 .87934 L F
.52076 .86853 m .5093 .87185 L .50056 .87648 L F
.52048 .86143 m .5093 .87185 L .52076 .86853 L F
.52048 .86143 m .50083 .87225 L .5093 .87185 L F
.52048 .86143 m .50101 .86947 L .50083 .87225 L F
.52048 .86143 m .50944 .86482 L .50101 .86947 L F
.5191 .85901 m .51939 .87259 L .52625 .86429 L 0 1 .425 r
F
.53077 .86121 m .52148 .86488 L .52616 .86922 L 0 1 .471 r
F
.52798 .8632 m .52942 .86589 L .53272 .8618 L 0 1 .28 r
F
.52798 .8632 m .53272 .8618 L .53201 .86078 L F
.53197 .85596 m .534 .85754 L .53444 .85602 L 0 1 .244 r
F
.53197 .85596 m .53256 .85895 L .534 .85754 L F
.53197 .85596 m .53094 .85951 L .53256 .85895 L F
.53197 .85596 m .53444 .85602 L .53359 .85541 L F
.53018 .86392 m .5341 .85215 L .53447 .85369 L 0 0 .014 r
F
.53 .86436 m .53013 .86395 L .53018 .86392 L F
.53013 .86395 m .5341 .85215 L .53018 .86392 L F
.53857 .86065 m .53808 .86107 L .53862 .86094 L 0 .279 .261 r
F
.53615 .86156 m .53694 .85545 L .53858 .85324 L 0 0 .07 r
F
.5381 .86125 m .53786 .85823 L .54095 .85 L 0 0 .077 r
F
.53808 .86126 m .53786 .85823 L .5381 .86125 L F
.53673 .86157 m .53858 .85324 L .53786 .85823 L 0 0 .07 r
F
.53671 .86158 m .53858 .85324 L .53673 .86157 L F
.53816 .861 m .53828 .86055 L .53877 .86049 L 0 0 .077 r
F
.53828 .86055 m .54095 .85 L .53882 .86034 L F
.53858 .85324 m .53694 .85545 L .53736 .85249 L 0 0 .02 r
F
.53536 .86304 m .53702 .87771 L .53611 .8626 L 0 .29 .268 r
F
.52942 .86589 m .53079 .86905 L .53444 .86468 L 0 1 .331 r
F
.52792 .83971 m .52938 .85089 L .53268 .84862 L 0 1 .462 r
F
.52942 .86589 m .53444 .86468 L .53376 .86347 L 0 1 .331 r
F
.52792 .83971 m .53268 .84862 L .53196 .84409 L 0 1 .462 r
F
.52646 .82799 m .52792 .83971 L .53088 .83714 L 0 1 .455 r
F
.534 .85754 m .53272 .8618 L .53444 .86146 L 0 1 .306 r
F
.52646 .82799 m .53088 .83714 L .53015 .83239 L 0 1 .455 r
F
.534 .85754 m .53201 .86078 L .53272 .8618 L 0 1 .306 r
F
.534 .85754 m .53256 .85895 L .53201 .86078 L F
.52993 .85554 m .53197 .85596 L .5323 .85484 L 0 1 .196 r
F
.52993 .85554 m .5323 .85484 L .53144 .8547 L F
.52993 .85554 m .53067 .85731 L .53197 .85596 L F
.52993 .85554 m .52915 .85815 L .53067 .85731 L F
.53077 .86121 m .52124 .86107 L .52148 .86488 L 0 1 .471 r
F
.53077 .86121 m .52521 .85949 L .52124 .86107 L F
.52508 .8606 m .52653 .86134 L .52915 .85815 L 0 .963 .189 r
F
.52508 .8606 m .52915 .85815 L .52844 .85793 L F
.5284 .85971 m .53137 .85287 L .53247 .85242 L 0 0 0 r
F
.5284 .85971 m .53247 .85242 L .53114 .85534 L F
.5341 .85215 m .53114 .85534 L .53247 .85242 L F
.5341 .85215 m .53184 .85522 L .53114 .85534 L F
.53197 .85596 m .53023 .85883 L .53094 .85951 L 0 1 .244 r
F
.53197 .85596 m .53067 .85731 L .53023 .85883 L F
.53 .86436 m .53184 .85522 L .5341 .85215 L 0 0 .014 r
F
.53 .86436 m .53447 .85369 L .53269 .85883 L F
.5344 .85878 m .53269 .85883 L .53447 .85369 L 0 0 .016 r
F
.5344 .85878 m .53266 .86102 L .53269 .85883 L F
.53318 .86316 m .53318 .86317 L .53322 .86314 L 0 .301 .275 r
F
.53318 .86317 m .53445 .87303 L .53406 .8628 L F
.53216 .87263 m .5221 .88411 L .52708 .88148 L 0 1 .393 r
F
.51939 .87259 m .5026 .88933 L .50984 .88941 L 0 1 .443 r
F
.51743 .87461 m .51771 .88273 L .52268 .88237 L 0 1 .488 r
F
.51743 .87461 m .52268 .88237 L .52244 .87902 L F
.53216 .87263 m .52186 .88242 L .5221 .88411 L 0 1 .393 r
F
.53216 .87263 m .52618 .8775 L .52186 .88242 L F
.53079 .86905 m .52618 .8775 L .53216 .87263 L 0 1 .368 r
F
.53322 .86353 m .53269 .86982 L .53445 .87303 L 0 .301 .275 r
F
.53528 .86234 m .53536 .86304 L .53603 .86199 L 0 .29 .268 r
F
.53318 .86313 m .5344 .85878 L .53401 .86282 L 0 0 .065 r
F
.53318 .86313 m .53266 .86102 L .5344 .85878 L F
.53318 .86316 m .53211 .86361 L .53318 .86313 L F
.53211 .86361 m .53266 .86102 L .53318 .86313 L F
.53137 .85287 m .528 .85676 L .53108 .8528 L 0 0 0 r
F
.52788 .85667 m .52993 .85554 L .53015 .85495 L 0 .903 .161 r
F
.52788 .85667 m .52877 .85681 L .52993 .85554 L F
.52788 .85667 m .53015 .85495 L .52929 .85543 L F
.53137 .85287 m .52713 .85805 L .528 .85676 L 0 0 0 r
F
.53137 .85287 m .52858 .85638 L .52713 .85805 L F
.52993 .85554 m .52844 .85793 L .52915 .85815 L 0 1 .196 r
F
.52993 .85554 m .52877 .85681 L .52844 .85793 L F
.5284 .85971 m .52858 .85638 L .53137 .85287 L 0 0 0 r
F
.52653 .86134 m .52798 .8632 L .53094 .85951 L 0 1 .215 r
F
.52653 .86134 m .53094 .85951 L .53023 .85883 L F
.53 .86436 m .52915 .86074 L .53184 .85522 L 0 0 .014 r
F
.53079 .86905 m .5215 .87996 L .52618 .8775 L 0 1 .368 r
F
.53079 .86905 m .52126 .87836 L .5215 .87996 L F
.53079 .86905 m .52524 .87369 L .52126 .87836 L F
.52942 .86589 m .52524 .87369 L .53079 .86905 L 0 1 .331 r
F
.52907 .83136 m .52999 .85563 L .53155 .86384 L 0 .301 .275 r
F
.53211 .86363 m .53155 .86384 L .53269 .86982 L F
.53156 .86384 m .53155 .86384 L .53157 .8638 L 0 0 .065 r
F
.53211 .86363 m .53157 .8638 L .53266 .86102 L F
.52907 .83136 m .53155 .86384 L .53211 .86363 L 0 .301 .275 r
F
.52942 .86589 m .52089 .87611 L .52524 .87369 L 0 1 .331 r
F
.53 .86489 m .52782 .86795 L .5292 .87984 L 0 .258 .269 r
F
.53349 .88054 m .52797 .88696 L .53481 .88973 L 0 1 .477 r
F
.53 .86489 m .5292 .87984 L .53195 .89214 L 0 .258 .269 r
F
.53481 .88973 m .52887 .89536 L .53612 .89884 L 0 .976 .478 r
F
.53 .86489 m .53459 .89022 L .53275 .87718 L 0 .258 .269 r
F
.53 .86489 m .53425 .89664 L .53459 .89022 L F
.53 .86489 m .53195 .89214 L .53425 .89664 L F
.52918 .87741 m .53002 .86773 L .53155 .86384 L 0 0 .065 r
F
.52918 .87741 m .53155 .86384 L .53156 .86384 L F
.52918 .87741 m .53157 .8638 L .53211 .86363 L F
.53211 .86363 m .53211 .86361 L .53318 .86316 L F
.5321 .86357 m .53211 .86363 L .53318 .86317 L 0 .301 .275 r
F
.53211 .86363 m .53269 .86982 L .53317 .86331 L F
.53211 .86363 m .53317 .86331 L .53318 .86317 L F
.52907 .83136 m .5321 .86357 L .53302 .86323 L F
.53318 .86316 m .53302 .86323 L .53318 .86317 L F
.52907 .83136 m .53302 .86323 L .53318 .86316 L F
.52918 .87741 m .53211 .86363 L .53318 .86316 L 0 0 .065 r
F
.53222 .8352 m .53405 .86258 L .53408 .86272 L 0 .29 .268 r
F
.53409 .86272 m .53408 .86272 L .53409 .8628 L F
.53222 .8352 m .53408 .86272 L .53409 .86272 L F
.53529 .86236 m .53409 .8628 L .53702 .87771 L F
.53401 .86282 m .5344 .85878 L .53406 .86281 L 0 0 .065 r
F
.5353 .86229 m .53409 .86279 L .53694 .85545 L 0 0 .07 r
F
.53528 .86234 m .53409 .86279 L .5353 .86229 L F
.53528 .86234 m .53409 .8628 L .53529 .86236 L 0 .29 .268 r
F
.53409 .86279 m .53409 .8628 L .53528 .86234 L F
.53445 .87303 m .53269 .86982 L .53275 .87718 L 0 .23 .255 r
F
.53234 .87462 m .53409 .86279 L .53528 .86234 L 0 0 .07 r
F
.53409 .86279 m .53409 .86279 L .53528 .86234 L F
.53222 .8352 m .53409 .86279 L .53528 .86234 L 0 .29 .268 r
F
.53318 .86316 m .53318 .86313 L .53401 .86282 L 0 0 .065 r
F
.53234 .87462 m .53527 .86239 L .53603 .86199 L 0 0 .07 r
F
.53527 .86239 m .53528 .86234 L .53577 .86211 L F
.53527 .86239 m .53577 .86211 L .53603 .86199 L F
.53318 .86317 m .53315 .86358 L .53322 .86353 L 0 .301 .275 r
F
.53315 .86358 m .53269 .86982 L .53322 .86353 L F
.53234 .87462 m .53405 .8629 L .53407 .86283 L 0 0 .07 r
F
.53409 .86283 m .53407 .86283 L .53409 .86279 L F
.53234 .87462 m .53407 .86283 L .53409 .86283 L F
.52918 .87741 m .53318 .86316 L .53405 .8629 L 0 0 .065 r
F
.53318 .86316 m .53406 .86281 L .53405 .8629 L F
.52907 .83136 m .53318 .86316 L .53405 .86258 L 0 .301 .275 r
F
.53318 .86316 m .53322 .86314 L .53405 .86258 L F
.53318 .86317 m .53406 .8628 L .53405 .86258 L F
.53234 .87462 m .53668 .86171 L .53524 .86712 L 0 0 .07 r
F
.53668 .86171 m .53786 .85823 L .53684 .86168 L F
.53668 .86172 m .53676 .86218 L .5367 .86171 L 0 .29 .268 r
F
.53668 .86171 m .53684 .86168 L .53668 .86172 L 0 0 .07 r
F
.53668 .86172 m .5367 .86171 L .5367 .86171 L 0 .29 .268 r
F
.53608 .86158 m .53694 .85545 L .53615 .86156 L 0 0 .07 r
F
.53528 .86234 m .5353 .86225 L .53603 .86199 L F
.5353 .86225 m .53694 .85545 L .53604 .86188 L F
.5353 .86225 m .53604 .86188 L .53603 .86199 L F
.53805 .86085 m .53723 .86141 L .53808 .86107 L 0 .279 .261 r
F
.53676 .86218 m .5369 .86207 L .53684 .86168 L 0 .29 .268 r
F
.53668 .86172 m .53671 .86158 L .53673 .86157 L 0 0 .07 r
F
.5367 .86172 m .53684 .86168 L .53518 .85025 L 0 .29 .268 r
F
.53676 .86218 m .53684 .86168 L .5367 .86172 L F
.53529 .87232 m .53524 .86712 L .53684 .86168 L 0 0 .077 r
F
.53725 .86155 m .53684 .86168 L .53786 .85823 L F
.53685 .86168 m .53686 .86179 L .53718 .86161 L 0 .279 .261 r
F
.53685 .86168 m .53718 .86161 L .53725 .86157 L F
.53685 .86162 m .53683 .86163 L .53684 .86168 L F
.53685 .86168 m .53684 .86168 L .53686 .86179 L F
.53685 .86162 m .53684 .86168 L .53685 .86168 L F
.53725 .86157 m .53684 .86168 L .53725 .86155 L 0 0 .077 r
F
.53529 .87232 m .53684 .86168 L .53725 .86157 L F
.53517 .83802 m .53722 .86127 L .53805 .86085 L 0 .279 .261 r
F
.53722 .86127 m .53723 .86141 L .53805 .86085 L F
.53668 .86172 m .53684 .86168 L .53524 .86712 L 0 0 .07 r
F
.53517 .83802 m .53685 .86168 L .53725 .86157 L 0 .279 .261 r
F
.53517 .83802 m .53805 .86085 L .53857 .86065 L F
.53805 .86085 m .53808 .86107 L .53857 .86065 L F
.53603 .86199 m .53608 .86158 L .53615 .86156 L 0 0 .07 r
F
.53528 .86225 m .53528 .86234 L .53603 .86199 L 0 .29 .268 r
F
.53579 .86035 m .53528 .86225 L .53603 .86199 L F
.53222 .8352 m .53511 .86078 L .53579 .86035 L F
.53511 .86078 m .53528 .86225 L .53579 .86035 L F
.53845 .86124 m .53808 .86133 L .5385 .86105 L 0 0 .077 r
F
.53529 .87232 m .53804 .86148 L .53845 .86124 L F
.53804 .86148 m .53808 .86133 L .53845 .86124 L F
.53862 .861 m .5385 .86105 L .53863 .86097 L F
.53529 .87232 m .5385 .86105 L .53862 .861 L F
.53808 .86133 m .53816 .861 L .53863 .86097 L F
.53862 .86094 m .5381 .86125 L .53862 .861 L 0 .279 .261 r
F
.53808 .86107 m .5381 .86125 L .53862 .86094 L F
.53723 .86141 m .53725 .86157 L .53808 .86107 L F
.53603 .86199 m .53606 .86187 L .53668 .86171 L 0 0 .07 r
F
.53606 .86187 m .53671 .86161 L .53668 .86171 L F
.53663 .86174 m .53668 .86171 L .53668 .86172 L F
.53603 .86199 m .53668 .86171 L .53663 .86174 L F
.53517 .83802 m .53518 .85025 L .53683 .86163 L 0 .279 .261 r
F
.53517 .83802 m .53683 .86163 L .53685 .86162 L F
.53808 .86133 m .53808 .86126 L .5381 .86125 L 0 0 .077 r
F
.53801 .87068 m .53841 .86403 L .53938 .86073 L 0 .009 .084 r
F
.53801 .87068 m .53938 .86073 L .53941 .86072 L F
.54005 .86057 m .54149 .87457 L .54065 .86058 L 0 .271 .255 r
F
.54068 .86034 m .54149 .87457 L .54491 .89185 L F
.53801 .87068 m .54056 .8608 L .54094 .86057 L 0 .009 .084 r
F
.54056 .8608 m .54061 .86059 L .54094 .86057 L F
.53869 .86145 m .53874 .86187 L .53875 .86186 L 0 .279 .261 r
F
.53867 .86129 m .53869 .86146 L .53869 .86145 L F
.54107 .86015 m .54113 .86059 L .54139 .86002 L 0 .271 .255 r
F
.5413 .86043 m .54107 .86015 L .54144 .86 L 0 .009 .084 r
F
.54116 .86074 m .54116 .8608 L .54116 .8608 L 0 .271 .255 r
F
.53801 .87068 m .54094 .86057 L .5413 .86043 L 0 .009 .084 r
F
.54094 .86057 m .54107 .86015 L .5413 .86043 L F
.53801 .87068 m .53997 .86095 L .54056 .8608 L F
.53997 .86095 m .54005 .86057 L .54056 .8608 L F
.53864 .86113 m .53866 .8613 L .53867 .86129 L 0 .279 .261 r
F
.53529 .87232 m .53723 .86167 L .53808 .86133 L 0 0 .077 r
F
.53222 .8352 m .53603 .86199 L .53668 .86172 L 0 .29 .268 r
F
.53789 .83958 m .53837 .85408 L .53936 .86062 L 0 .271 .255 r
F
.53911 .86079 m .53948 .85923 L .53963 .85921 L 0 0 .077 r
F
.53789 .83958 m .53936 .86062 L .54001 .8602 L 0 .271 .255 r
F
.5391 .86077 m .53862 .861 L .53911 .86079 L 0 .279 .261 r
F
.53877 .86049 m .53828 .86055 L .53882 .86034 L 0 0 .077 r
F
.53862 .861 m .53893 .85997 L .53893 .86087 L F
.53517 .83802 m .53862 .86094 L .5391 .86077 L 0 .279 .261 r
F
.53862 .86094 m .53862 .861 L .5391 .86077 L F
.53234 .87462 m .53598 .86214 L .53668 .86172 L 0 0 .07 r
F
.53222 .8352 m .53668 .86172 L .53518 .85025 L 0 .29 .268 r
F
.53668 .86172 m .5367 .86171 L .53518 .85025 L F
.54097 .85951 m .54068 .86034 L .54107 .86015 L 0 .271 .255 r
F
.53789 .83958 m .54059 .85966 L .54097 .85951 L F
.54059 .85966 m .54068 .86034 L .54097 .85951 L F
.53996 .85975 m .54005 .86057 L .5406 .8598 L F
.53924 .86153 m .53947 .86131 L .53938 .86073 L 0 .279 .261 r
F
.53935 .86073 m .53938 .86073 L .53936 .86062 L F
.53924 .86153 m .53938 .86073 L .53935 .86073 L F
.53801 .87068 m .53941 .86072 L .54005 .86057 L 0 .009 .084 r
F
.53941 .86072 m .53943 .86056 L .53996 .86057 L F
.53941 .86072 m .53996 .86057 L .54005 .86057 L F
.5406 .8598 m .54064 .86036 L .54068 .86034 L 0 .271 .255 r
F
.53789 .83958 m .53996 .85975 L .5406 .8598 L F
.54185 .85991 m .54179 .85992 L .54191 .86069 L 0 .264 .249 r
F
.54047 .86993 m .54183 .85991 L .54193 .85989 L 0 .035 .091 r
F
.54256 .85994 m .54193 .85989 L .5426 .85976 L F
.54047 .86993 m .54193 .85989 L .54256 .85994 L F
.54047 .86993 m .54247 .86038 L .54267 .86034 L F
.54247 .86038 m .54251 .8602 L .54267 .86034 L F
.54047 .86993 m .54323 .86013 L .54352 .86004 L F
.54323 .86013 m .54332 .85981 L .54352 .86004 L F
.53789 .83958 m .54144 .86 L .54129 .85672 L 0 .271 .255 r
F
.54144 .86 m .54179 .85992 L .54129 .85672 L F
.54183 .85991 m .54186 .85965 L .5426 .85976 L 0 .035 .091 r
F
.54254 .85918 m .54227 .85982 L .5426 .85976 L 0 .264 .249 r
F
.54208 .858 m .54242 .85673 L .54249 .85672 L 0 .009 .084 r
F
.54184 .85875 m .54204 .858 L .54208 .858 L F
.54034 .83958 m .54183 .8597 L .54254 .85918 L 0 .264 .249 r
F
.54183 .8597 m .54191 .86069 L .54254 .85918 L F
.54264 .87032 m .54392 .85999 L .54413 .85924 L 0 .061 .097 r
F
.54391 .86029 m .54422 .8601 L .54408 .85925 L 0 .264 .249 r
F
.54418 .85983 m .5442 .86001 L .54421 .85979 L F
.5442 .86001 m .54424 .85998 L .54421 .85979 L F
.54418 .85983 m .54421 .85979 L .54419 .85966 L F
.54408 .85925 m .54415 .85969 L .54411 .85924 L F
.54415 .85969 m .54419 .85966 L .54407 .85889 L F
.54264 .87032 m .54413 .85924 L .545 .85911 L 0 .061 .097 r
F
.5437 .85847 m .54383 .858 L .54401 .85831 L 0 .035 .091 r
F
.5437 .85847 m .54401 .85831 L .54374 .85932 L F
.54385 .85928 m .54408 .85925 L .54368 .85666 L 0 .264 .249 r
F
.54391 .86029 m .54408 .85925 L .54385 .85928 L F
.54529 .8577 m .54487 .85803 L .54529 .85773 L 0 .259 .243 r
F
.54486 .85788 m .54487 .85803 L .54529 .8577 L F
.54781 .85645 m .54786 .85675 L .54812 .85636 L 0 .256 .238 r
F
.54752 .85646 m .54756 .85678 L .54781 .85645 L F
.54552 .85875 m .54557 .85842 L .5456 .85841 L 0 .061 .097 r
F
.54557 .85768 m .54541 .85857 L .54571 .85858 L 0 .259 .243 r
F
.54529 .8577 m .54541 .85857 L .54557 .85768 L F
.54249 .83764 m .54557 .85768 L .54587 .85759 L F
.54557 .85768 m .54571 .85858 L .54587 .85759 L F
.54107 .86015 m .54139 .86002 L .54143 .85993 L 0 .271 .255 r
F
.54113 .86059 m .54151 .86048 L .54144 .86 L F
.53801 .87068 m .54144 .86 L .54131 .86157 L 0 .009 .084 r
F
.54144 .86 m .54144 .85999 L .54144 .86 L F
.54144 .86 m .54144 .86 L .54131 .86157 L F
.5414 .85999 m .54144 .86 L .54143 .85993 L 0 .271 .255 r
F
.54113 .86059 m .54144 .86 L .5414 .85999 L F
.54299 .86003 m .54273 .86011 L .543 .86001 L 0 .035 .091 r
F
.54047 .86993 m .54273 .86011 L .54299 .86003 L F
.54264 .87032 m .54482 .85993 L .54525 .85981 L 0 .061 .097 r
F
.54482 .85993 m .545 .85911 L .54525 .85981 L F
.54264 .87032 m .54555 .85959 L .54585 .85945 L F
.54555 .85959 m .54571 .859 L .54585 .85945 L F
.54332 .85981 m .54334 .85975 L .54364 .85966 L 0 .035 .091 r
F
.53789 .83958 m .54107 .86015 L .54143 .85993 L 0 .271 .255 r
F
.54102 .86031 m .54092 .86024 L .54107 .86015 L 0 .009 .084 r
F
.54061 .86059 m .54074 .8601 L .54102 .86031 L F
.53529 .87232 m .53911 .86079 L .53841 .86403 L 0 0 .077 r
F
.53911 .86079 m .53924 .86153 L .53935 .86073 L 0 .279 .261 r
F
.53911 .86079 m .5392 .86148 L .53922 .86147 L F
.53911 .86079 m .53938 .86073 L .53841 .86403 L 0 0 .077 r
F
.53911 .86079 m .53935 .86073 L .53936 .86062 L 0 .279 .261 r
F
.54334 .85975 m .54342 .85944 L .54366 .85957 L 0 .035 .091 r
F
.54251 .8602 m .5426 .85976 L .543 .86001 L F
.53843 .86166 m .53862 .861 L .53893 .86133 L 0 0 .077 r
F
.53862 .861 m .53893 .86087 L .53893 .86133 L F
.54363 .85868 m .54342 .85944 L .54373 .85925 L 0 .264 .249 r
F
.5433 .85885 m .54352 .85869 L .54343 .85906 L 0 .035 .091 r
F
.54332 .85877 m .54342 .85944 L .54363 .85868 L 0 .264 .249 r
F
.53517 .83802 m .53911 .86079 L .53837 .85408 L 0 .279 .261 r
F
.53906 .86082 m .53948 .85923 L .53911 .86079 L 0 0 .077 r
F
.53911 .86079 m .53936 .86062 L .53837 .85408 L 0 .279 .261 r
F
.53893 .86133 m .53906 .86082 L .53911 .86079 L 0 0 .077 r
F
.54183 .85991 m .54179 .85992 L .54186 .85965 L 0 .035 .091 r
F
.54185 .85991 m .54179 .85992 L .54185 .85991 L 0 .264 .249 r
F
.54181 .85945 m .54179 .85992 L .54185 .85991 L F
.54181 .85945 m .54172 .85951 L .54179 .85992 L F
.54047 .86993 m .54131 .86157 L .54179 .85992 L 0 .035 .091 r
F
.54047 .86993 m .54179 .85992 L .54183 .85991 L F
.54241 .85808 m .5426 .85976 L .5429 .85818 L 0 .264 .249 r
F
.54237 .85767 m .54241 .85808 L .54286 .85783 L F
.54241 .85808 m .5429 .85818 L .54286 .85783 L F
.54264 .87032 m .54603 .85883 L .5462 .8596 L 0 .061 .097 r
F
.54603 .85883 m .54606 .85874 L .54608 .85884 L F
.54603 .85883 m .54608 .85884 L .5462 .8596 L F
.54606 .85874 m .54639 .85889 L .5462 .8596 L F
.54602 .85853 m .54598 .85871 L .54606 .85874 L 0 .259 .243 r
F
.54541 .85857 m .54549 .85916 L .54571 .85858 L F
.54311 .85959 m .54329 .85846 L .5434 .85846 L 0 .035 .091 r
F
.54311 .85959 m .54309 .86035 L .54321 .86029 L 0 .264 .249 r
F
.54286 .85783 m .54302 .85961 L .54311 .85959 L F
.5445 .87218 m .5462 .8596 L .54639 .8589 L 0 .087 .104 r
F
.5445 .87218 m .54639 .8589 L .54719 .85915 L F
.54034 .83958 m .54237 .85767 L .54286 .85783 L 0 .264 .249 r
F
.54743 .85587 m .54726 .85811 L .54773 .85798 L 0 .256 .238 r
F
.54431 .83328 m .54703 .85617 L .54743 .85587 L F
.54703 .85617 m .54726 .85811 L .54743 .85587 L F
.5432 .85923 m .5433 .85885 L .54343 .85906 L 0 .035 .091 r
F
.5432 .85923 m .54343 .85906 L .54341 .85912 L F
.54529 .85773 m .545 .8591 L .54546 .85896 L 0 .259 .243 r
F
.54487 .85803 m .545 .8591 L .54529 .85773 L F
.545 .85911 m .545 .8591 L .54502 .85909 L 0 .061 .097 r
F
.54773 .85798 m .54731 .85856 L .54779 .85846 L 0 .256 .238 r
F
.54726 .85811 m .54731 .85856 L .54773 .85798 L F
.54731 .85856 m .54734 .8588 L .54779 .85846 L F
.54786 .85675 m .54778 .85836 L .5481 .85836 L F
.54756 .85678 m .54778 .85836 L .54786 .85675 L F
.54578 .82598 m .5481 .85355 L .54821 .85429 L 0 .253 .233 r
F
.54958 .85815 m .54924 .8565 L .54992 .85648 L 0 .111 .11 r
F
.54958 .85815 m .5488 .85822 L .5525 .88284 L 0 .253 .233 r
F
.54604 .87585 m .54896 .85821 L .54958 .85815 L 0 .111 .11 r
F
.54896 .85821 m .54924 .8565 L .54958 .85815 L F
.54914 .85437 m .54821 .85429 L .5488 .85822 L 0 .253 .233 r
F
.54604 .87585 m .54814 .86079 L .54924 .8565 L 0 .111 .11 r
F
.54914 .85437 m .5488 .85822 L .54958 .85815 L 0 .253 .233 r
F
.54578 .82598 m .54821 .85429 L .54914 .85437 L F
.55403 .85781 m .55386 .85781 L .55458 .8548 L 0 .151 .126 r
F
.55412 .8572 m .55381 .85753 L .55386 .85781 L 0 .252 .226 r
F
.55419 .85781 m .55386 .85781 L .55549 .86911 L F
.5481 .89016 m .55458 .8548 L .55476 .85482 L 0 .151 .126 r
F
.55412 .8572 m .55386 .85781 L .55419 .85781 L 0 .252 .226 r
F
.5481 .89016 m .55093 .86989 L .55386 .85781 L 0 .151 .126 r
F
.5481 .89016 m .55386 .85781 L .55403 .85781 L F
.55476 .85482 m .55458 .8548 L .55537 .85157 L F
.5476 .80023 m .55536 .85384 L .55617 .85334 L 0 .252 .226 r
F
.55536 .85384 m .55572 .85634 L .55617 .85334 L F
.54725 .88172 m .55369 .85782 L .55093 .86989 L 0 .132 .117 r
F
.55369 .85782 m .5537 .85796 L .55371 .85797 L 0 .252 .229 r
F
.55365 .85759 m .55368 .85781 L .55369 .85782 L F
.55368 .85781 m .5537 .85796 L .55369 .85782 L F
.55369 .85782 m .55386 .85781 L .55383 .85791 L 0 .132 .117 r
F
.55369 .85782 m .55383 .85791 L .55093 .86989 L F
.5481 .89016 m .55417 .86246 L .55477 .86286 L 0 .151 .126 r
F
.55417 .86246 m .55452 .86087 L .55477 .86286 L F
.54781 .85889 m .54789 .85839 L .54803 .85863 L 0 .087 .104 r
F
.54789 .85839 m .54803 .85828 L .54803 .85863 L F
.54778 .85836 m .54779 .85846 L .5481 .85836 L 0 .256 .238 r
F
.5473 .86051 m .54779 .85846 L .54757 .86038 L 0 .087 .104 r
F
.54779 .85846 m .54788 .85843 L .54757 .86038 L F
.54725 .88172 m .55235 .86081 L .55282 .86101 L 0 .132 .117 r
F
.55235 .86081 m .5525 .86018 L .55282 .86101 L F
.5481 .85836 m .54818 .85902 L .5482 .85902 L 0 .256 .238 r
F
.54813 .85835 m .54812 .85854 L .54844 .85827 L F
.5481 .85836 m .54837 .85829 L .54835 .85836 L 0 .087 .104 r
F
.5481 .85836 m .54835 .85836 L .54785 .86034 L F
.54757 .86038 m .5481 .85836 L .54785 .86034 L F
.54844 .85827 m .54812 .85854 L .54848 .85852 L 0 .256 .238 r
F
.5481 .85836 m .54804 .85742 L .54842 .85712 L 0 .087 .104 r
F
.54803 .85863 m .54803 .8584 L .5481 .85836 L F
.54803 .8584 m .54804 .85742 L .5481 .85836 L F
.54842 .85817 m .54813 .85835 L .54844 .85827 L 0 .256 .238 r
F
.54817 .85665 m .54813 .85834 L .54842 .85817 L F
.54813 .85834 m .54813 .85835 L .54842 .85817 L F
.54786 .85675 m .54812 .85854 L .54817 .85665 L F
.54978 .85541 m .54947 .85719 L .55 .85702 L 0 .253 .233 r
F
.54929 .85566 m .54947 .85719 L .54978 .85541 L F
.54328 .85667 m .54391 .86029 L .54368 .85666 L 0 .264 .249 r
F
.5525 .86018 m .55272 .8593 L .55304 .86023 L 0 .132 .117 r
F
.54725 .88172 m .55181 .86183 L .55206 .86186 L F
.55181 .86183 m .55232 .85961 L .55206 .86186 L F
.54725 .88172 m .55168 .86182 L .55181 .86183 L F
.55168 .86182 m .55214 .85977 L .55181 .86183 L F
.54947 .85719 m .54958 .85815 L .55 .85702 L 0 .253 .233 r
F
.54974 .85813 m .54963 .85789 L .54995 .85801 L 0 .111 .11 r
F
.54958 .85815 m .54963 .85789 L .54974 .85813 L F
.54958 .85815 m .5501 .85808 L .55 .85702 L 0 .253 .233 r
F
.54957 .85824 m .54958 .85815 L .54974 .85813 L 0 .111 .11 r
F
.54957 .85824 m .54974 .85813 L .55014 .85808 L F
.55 .85702 m .5501 .85808 L .55014 .85808 L 0 .253 .233 r
F
.55106 .85752 m .55402 .84667 L .55132 .8576 L 0 .111 .11 r
F
.55185 .85788 m .55402 .84667 L .55267 .85741 L 0 .132 .117 r
F
.54725 .88172 m .54972 .86403 L .55132 .8576 L F
.55185 .85788 m .55132 .8576 L .55402 .84667 L F
.55143 .8579 m .55124 .85791 L .55128 .85822 L 0 .252 .229 r
F
.55126 .85791 m .55132 .8576 L .55185 .85788 L 0 .132 .117 r
F
.55145 .85785 m .55124 .85791 L .55143 .8579 L 0 .252 .229 r
F
.54725 .88172 m .55126 .85791 L .55185 .85788 L 0 .132 .117 r
F
.55173 .85685 m .55185 .85788 L .5519 .85672 L 0 .252 .229 r
F
.55185 .85788 m .55189 .85819 L .55189 .8579 L F
.55185 .85788 m .55189 .8579 L .5519 .85672 L F
.54689 .81515 m .55259 .85452 L .55312 .85428 L F
.55259 .85452 m .55284 .85619 L .55312 .85428 L F
.54987 .86056 m .54971 .85996 L .55007 .85978 L 0 .111 .11 r
F
.54604 .87585 m .54955 .86062 L .54987 .86056 L F
.54955 .86062 m .54971 .85996 L .54987 .86056 L F
.54584 .85939 m .54607 .86117 L .54611 .86118 L 0 .259 .243 r
F
.55209 .86187 m .55261 .85958 L .55265 .85957 L 0 .132 .117 r
F
.54725 .88172 m .55206 .86186 L .55209 .86187 L F
.55206 .86186 m .55261 .85958 L .55209 .86187 L F
.55261 .85958 m .55268 .8593 L .55265 .85957 L F
.55261 .85958 m .55232 .85961 L .55268 .8593 L F
.5475 .85968 m .54748 .85856 L .54777 .85855 L 0 .087 .104 r
F
.5445 .87218 m .5471 .85961 L .5475 .85968 L F
.54047 .86993 m .54374 .85932 L .54392 .85999 L 0 .035 .091 r
F
.54374 .85932 m .54413 .85924 L .54392 .85999 L F
.54403 .85892 m .54408 .85925 L .54407 .85889 L 0 .264 .249 r
F
.54408 .85925 m .54411 .85924 L .54407 .85889 L F
.54604 .87585 m .55007 .85978 L .55046 .85969 L 0 .111 .11 r
F
.55026 .85896 m .55061 .85901 L .55053 .85843 L 0 .253 .233 r
F
.55007 .85978 m .55051 .85801 L .55046 .85969 L 0 .111 .11 r
F
.54971 .85996 m .54957 .85824 L .55014 .85808 L F
.54604 .87585 m .54922 .85997 L .54971 .85996 L F
.54922 .85997 m .54957 .85824 L .54971 .85996 L F
.5481 .89016 m .55549 .85989 L .55629 .86042 L 0 .151 .126 r
F
.55549 .85989 m .55577 .85874 L .55624 .86024 L F
.55549 .85989 m .55624 .86024 L .55629 .86042 L F
.55093 .85799 m .55099 .85797 L .54972 .86403 L 0 .111 .11 r
F
.55099 .85797 m .55124 .85791 L .55119 .85809 L F
.55099 .85797 m .55119 .85809 L .54972 .86403 L F
.5509 .85801 m .55078 .85693 L .55093 .85799 L F
.55051 .85524 m .55088 .8579 L .55094 .85794 L 0 .253 .233 r
F
.54373 .85925 m .54374 .85932 L .54374 .85932 L 0 .264 .249 r
F
.55017 .85828 m .55026 .85896 L .55053 .85843 L 0 .253 .233 r
F
.55017 .85828 m .55053 .85843 L .55051 .85821 L F
.55007 .85978 m .55014 .85808 L .55051 .85801 L 0 .111 .11 r
F
.54971 .85996 m .55014 .85808 L .55007 .85978 L F
.5445 .87218 m .54844 .85827 L .54814 .86079 L 0 .087 .104 r
F
.54844 .85827 m .5488 .85822 L .54814 .86079 L F
.54844 .85827 m .5488 .85822 L .54877 .85798 L 0 .256 .238 r
F
.54842 .85817 m .54844 .85827 L .54874 .8578 L F
.54844 .85827 m .54877 .85798 L .54874 .8578 L F
.54785 .86034 m .54835 .85835 L .54844 .85827 L 0 .087 .104 r
F
.5445 .87218 m .54757 .86038 L .54785 .86034 L F
.54264 .87032 m .54522 .85995 L .54549 .85981 L 0 .061 .097 r
F
.54316 .85939 m .54341 .85912 L .54294 .86104 L 0 .035 .091 r
F
.54332 .85877 m .54311 .85959 L .54342 .85944 L 0 .264 .249 r
F
.543 .85881 m .54311 .85959 L .54332 .85877 L F
.53529 .87232 m .53843 .86166 L .53893 .86133 L 0 0 .077 r
F
.54034 .83958 m .54129 .85672 L .54172 .85951 L 0 .264 .249 r
F
.54034 .83958 m .54172 .85951 L .54181 .85945 L F
.54245 .86216 m .54266 .86134 L .54275 .86184 L 0 .035 .091 r
F
.54266 .86134 m .54294 .86104 L .54275 .86184 L F
.54431 .83328 m .548 .85561 L .5481 .85355 L 0 .256 .238 r
F
.548 .85561 m .54842 .85817 L .54823 .85537 L F
.548 .85561 m .54823 .85537 L .5481 .85355 L F
.54842 .85712 m .54843 .85709 L .54843 .85709 L 0 .087 .104 r
F
.54842 .85817 m .54874 .8578 L .5481 .85355 L 0 .256 .238 r
F
.54757 .86038 m .54781 .85889 L .54803 .85863 L 0 .087 .104 r
F
.5445 .87218 m .5473 .86051 L .54757 .86038 L F
.54341 .85945 m .54341 .85945 L .54342 .85944 L 0 .035 .091 r
F
.54337 .85963 m .54341 .85945 L .54342 .85944 L F
.54368 .85666 m .54403 .85892 L .54391 .85783 L 0 .264 .249 r
F
.54403 .85892 m .54407 .85889 L .54391 .85783 L F
.54275 .86184 m .54326 .85974 L .54337 .85963 L 0 .035 .091 r
F
.54034 .83958 m .54328 .85667 L .54368 .85666 L 0 .264 .249 r
F
.5499 .85387 m .54973 .85504 L .55005 .8549 L 0 .253 .233 r
F
.54578 .82598 m .54959 .85399 L .5499 .85387 L F
.54959 .85399 m .54973 .85504 L .5499 .85387 L F
.54047 .86993 m .54245 .86216 L .54275 .86184 L 0 .035 .091 r
F
.54578 .82598 m .55025 .85366 L .54962 .84689 L 0 .253 .233 r
F
.55025 .85366 m .55094 .85794 L .55041 .85348 L F
.55025 .85366 m .55041 .85348 L .54962 .84689 L F
.55094 .85794 m .55106 .85752 L .55124 .85791 L 0 .111 .11 r
F
.55106 .85752 m .55132 .8576 L .55124 .85791 L F
.55094 .85794 m .55078 .85693 L .55122 .85692 L F
.55093 .85799 m .55092 .85795 L .55094 .85794 L F
.55092 .85795 m .55078 .85693 L .55094 .85794 L F
.55094 .85794 m .55124 .85791 L .55121 .85772 L 0 .253 .233 r
F
.55094 .85794 m .55121 .85772 L .54962 .84689 L F
.55093 .85799 m .55094 .85794 L .55124 .85791 L 0 .111 .11 r
F
.55192 .85299 m .55189 .85777 L .55256 .85786 L 0 .252 .229 r
F
.55256 .85786 m .55185 .85788 L .55267 .85741 L 0 .132 .117 r
F
.55221 .85787 m .55189 .85819 L .55241 .85793 L 0 .252 .229 r
F
.55189 .85788 m .55189 .85819 L .55221 .85787 L F
.55226 .85924 m .55185 .85788 L .55256 .85786 L 0 .132 .117 r
F
.55189 .85777 m .55189 .85788 L .55221 .85787 L 0 .252 .229 r
F
.55189 .85777 m .55241 .85793 L .55256 .85786 L F
.55135 .85351 m .55173 .85685 L .55192 .85299 L F
.55173 .85685 m .5519 .85672 L .55192 .85299 L F
.55284 .85619 m .55304 .85762 L .55338 .85587 L F
.55048 .858 m .55048 .85801 L .55051 .85801 L 0 .253 .233 r
F
.55452 .86087 m .55491 .85908 L .55515 .86127 L 0 .151 .126 r
F
.54725 .88172 m .55166 .85888 L .55226 .85924 L 0 .132 .117 r
F
.55166 .85888 m .55185 .85788 L .55226 .85924 L F
.54604 .87585 m .55093 .85799 L .54972 .86403 L 0 .111 .11 r
F
.55177 .85718 m .55121 .85772 L .55124 .85791 L 0 .252 .229 r
F
.55177 .85718 m .55124 .85791 L .55145 .85785 L F
.55177 .85718 m .55128 .85822 L .55185 .85788 L F
.55272 .8593 m .55268 .8593 L .55273 .85926 L 0 .132 .117 r
F
.55307 .85784 m .55313 .85826 L .55314 .85826 L 0 .252 .229 r
F
.55323 .85951 m .55307 .85784 L .55369 .85782 L 0 .132 .117 r
F
.55272 .8593 m .55307 .85784 L .55323 .85951 L F
.55577 .85874 m .55596 .85798 L .55608 .85884 L 0 .151 .126 r
F
.55577 .85874 m .55608 .85884 L .55629 .86042 L F
.5481 .89016 m .55413 .85817 L .55501 .8586 L F
.55413 .85817 m .55419 .85781 L .55501 .8586 L F
.55014 .85808 m .55019 .85776 L .55021 .85776 L 0 .111 .11 r
F
.54993 .85653 m .55014 .85808 L .55028 .85641 L 0 .253 .233 r
F
.55014 .85808 m .55051 .85821 L .55028 .85641 L F
.55005 .8549 m .54993 .85653 L .55028 .85641 L F
.54973 .85504 m .54993 .85653 L .55005 .8549 L F
.54689 .81515 m .54962 .84689 L .55121 .85772 L 0 .252 .229 r
F
.55122 .85692 m .55123 .85689 L .55123 .85689 L 0 .111 .11 r
F
.54689 .81515 m .55121 .85772 L .55177 .85718 L 0 .252 .229 r
F
.55091 .85806 m .5509 .85801 L .55093 .85799 L 0 .111 .11 r
F
.55028 .85641 m .55048 .858 L .55051 .85801 L 0 .253 .233 r
F
.55507 .85182 m .55488 .85564 L .55559 .8554 L 0 .252 .226 r
F
.5476 .80023 m .55444 .85232 L .55507 .85182 L F
.55444 .85232 m .55488 .85564 L .55507 .85182 L F
.55488 .85564 m .555 .8566 L .55559 .8554 L F
.55293 .85685 m .55256 .85786 L .55307 .85784 L 0 .252 .229 r
F
.55234 .85275 m .55252 .85687 L .55293 .85685 L F
.55252 .85687 m .55256 .85786 L .55293 .85685 L F
.54689 .81515 m .55192 .85299 L .55234 .85275 L F
.55192 .85299 m .55256 .85786 L .55234 .85275 L F
.54689 .81515 m .55135 .85351 L .55192 .85299 L F
.55235 .85884 m .55256 .85786 L .55292 .85833 L 0 .132 .117 r
F
.55256 .85786 m .55306 .85761 L .55292 .85833 L F
.55227 .85919 m .55235 .85884 L .55288 .85854 L F
.55235 .85884 m .55292 .85833 L .55288 .85854 L F
.54689 .81515 m .55366 .85767 L .55072 .83611 L 0 .252 .229 r
F
.55366 .85767 m .55381 .85753 L .55072 .83611 L F
.5476 .80023 m .55072 .83611 L .55381 .85753 L 0 .252 .226 r
F
.5476 .80023 m .55381 .85753 L .55412 .8572 L F
.55214 .85977 m .55227 .85919 L .55273 .85926 L 0 .132 .117 r
F
.55227 .85919 m .55288 .85854 L .55273 .85926 L F
.55491 .85908 m .55517 .85788 L .55561 .85941 L 0 .151 .126 r
F
.55299 .85797 m .55302 .85784 L .55302 .85795 L 0 .132 .117 r
F
.55302 .85784 m .55304 .85784 L .55302 .85795 L F
.55285 .85867 m .55299 .85797 L .55288 .85865 L F
.55299 .85797 m .55302 .85795 L .55288 .85865 L F
.555 .8566 m .55419 .85781 L .55517 .85788 L 0 .252 .226 r
F
.5476 .80023 m .55412 .8572 L .555 .8566 L F
.55412 .8572 m .55419 .85781 L .555 .8566 L F
.55501 .85661 m .55517 .85788 L .55583 .85732 L F
.55517 .85788 m .55593 .85821 L .55583 .85732 L F
.555 .8566 m .55501 .85661 L .55572 .85634 L F
.55501 .85661 m .55583 .85732 L .55572 .85634 L F
.55711 .85844 m .55714 .85813 L .55717 .85814 L 0 .17 .135 r
F
.55572 .85634 m .55596 .85798 L .55649 .85593 L 0 .252 .226 r
F
.55596 .85798 m .55967 .88362 L .55673 .85805 L F
.55596 .85798 m .55938 .84398 L .55673 .85805 L 0 .151 .126 r
F
.55596 .85798 m .55673 .85805 L .55649 .85593 L 0 .252 .226 r
F
.55596 .85798 m .55673 .85805 L .55671 .8582 L 0 .151 .126 r
F
.55978 .90719 m .54858 .91147 L .55486 .91628 L 0 .953 .447 r
F
.55978 .90719 m .54779 .90711 L .54858 .91147 L F
.55978 .90719 m .55259 .90528 L .54779 .90711 L F
.54967 .8996 m .54838 .89763 L .55005 .91125 L 0 .126 .198 r
F
.54859 .90147 m .55709 .85842 L .55711 .85844 L 0 .17 .135 r
F
.55709 .85842 m .55714 .85813 L .55711 .85844 L F
.55819 .85832 m .55714 .85813 L .56 .87192 L 0 .255 .224 r
F
.54859 .90147 m .55919 .86012 L .55678 .87424 L 0 .17 .135 r
F
.55885 .85393 m .55956 .85868 L .55911 .8537 L 0 .255 .224 r
F
.55956 .85868 m .5601 .8623 L .55969 .85871 L F
.55956 .85868 m .55969 .85871 L .55911 .8537 L F
.55919 .86012 m .55956 .85868 L .55939 .86028 L 0 .17 .135 r
F
.55956 .85868 m .56006 .85673 L .55969 .85871 L F
.55956 .85868 m .55969 .85871 L .55939 .86028 L F
.55919 .86012 m .55939 .86028 L .55678 .87424 L F
.55596 .85798 m .55671 .8582 L .55629 .86042 L 0 .151 .126 r
F
.55591 .85761 m .55595 .85798 L .55596 .85798 L 0 .252 .226 r
F
.55587 .85736 m .5559 .85761 L .55591 .85761 L F
.55919 .86012 m .55819 .85832 L .55956 .85868 L 0 .17 .135 r
F
.54859 .90147 m .558 .85921 L .55919 .86012 L F
.558 .85921 m .55819 .85832 L .55919 .86012 L F
.54859 .90147 m .55629 .86042 L .55705 .85838 L F
.55709 .85842 m .55705 .85838 L .55714 .85813 L F
.54859 .90147 m .55705 .85838 L .55709 .85842 L F
.55572 .85634 m .55583 .85732 L .55587 .85736 L 0 .252 .226 r
F
.55288 .85865 m .55305 .85777 L .5531 .85775 L 0 .132 .117 r
F
.55572 .85634 m .55649 .85593 L .55624 .85378 L 0 .252 .226 r
F
.54449 .7892 m .54971 .80516 L .5503 .80033 L 0 .91 .413 r
F
.54449 .7892 m .5503 .80033 L .54809 .79388 L F
.55069 .78823 m .54809 .79388 L .5503 .80033 L 0 .86 .406 r
F
.55069 .78823 m .54825 .78869 L .54809 .79388 L F
.54443 .77035 m .54825 .78869 L .55069 .78823 L 0 .888 .394 r
F
.55405 .81844 m .55232 .82199 L .55323 .81954 L 0 0 0 r
F
.54791 .78075 m .55624 .85378 L .55714 .85813 L 0 .255 .224 r
F
.55717 .85814 m .55714 .85813 L .55721 .85796 L 0 .17 .135 r
F
.54859 .90147 m .55721 .85796 L .55819 .85832 L F
.54791 .78075 m .55714 .85813 L .55819 .85832 L 0 .255 .224 r
F
.55956 .85868 m .56 .87192 L .5601 .8623 L F
.55885 .85393 m .55914 .85857 L .55956 .85868 L F
.54791 .78075 m .55773 .85481 L .55885 .85393 L F
.55273 .85926 m .55285 .85867 L .55288 .85865 L 0 .132 .117 r
F
.54791 .78075 m .55885 .85393 L .55648 .8307 L 0 .255 .224 r
F
.55885 .85393 m .55911 .8537 L .55648 .8307 L F
.54782 .75651 m .55648 .8307 L .56007 .8445 L 0 .262 .225 r
F
.56158 .80093 m .56185 .80011 L .56188 .79999 L 0 0 0 r
F
.55918 .78652 m .56761 .85004 L .56261 .80538 L 0 .179 .191 r
F
.55918 .78652 m .55956 .80555 L .56364 .85708 L F
.55944 .84168 m .56211 .71857 L .56032 .74298 L 0 .533 .236 r
F
.55806 .65606 m .56894 .66418 L .56863 .67985 L 0 .308 .195 r
F
.56764 .68554 m .56863 .67985 L .56847 .68807 L F
.55806 .65606 m .56863 .67985 L .56764 .68554 L F
.55806 .65606 m .56847 .68807 L .56656 .69725 L F
.55806 .65606 m .56799 .70421 L .5657 .70981 L F
.56799 .70421 m .56814 .70491 L .5657 .70981 L F
.56656 .69725 m .56847 .68807 L .56814 .70491 L F
.56764 .78355 m .56779 .78403 L .56781 .78393 L 0 .675 .379 r
F
.55944 .84168 m .56989 .76808 L .56817 .70614 L 0 .533 .236 r
F
.55944 .84168 m .56817 .70614 L .56805 .70632 L F
.55944 .84168 m .56814 .70491 L .56626 .69793 L F
.56206 .7152 m .56237 .71568 L .56216 .71656 L 0 .308 .195 r
F
.56237 .71568 m .5625 .7159 L .56216 .71656 L F
.55944 .84168 m .56527 .71881 L .56211 .71857 L 0 .533 .236 r
F
.56527 .71881 m .5657 .70981 L .56276 .71699 L F
.56527 .71881 m .56276 .71699 L .56211 .71857 L F
.55585 .71803 m .55514 .72172 L .55774 .73119 L 0 .687 .325 r
F
.55392 .72677 m .55302 .72981 L .55531 .73862 L 0 .727 .335 r
F
.55351 .71132 m .54816 .72921 L .55273 .7299 L 0 1 .392 r
F
.5495 .69763 m .55351 .71132 L .55547 .7036 L 0 1 .384 r
F
.55351 .71132 m .54687 .72375 L .54816 .72921 L 0 1 .392 r
F
.55351 .71132 m .54916 .71608 L .54687 .72375 L F
.5495 .69763 m .54916 .71608 L .55351 .71132 L 0 1 .384 r
F
.5495 .69763 m .54492 .71565 L .54916 .71608 L F
.5495 .69763 m .54362 .7103 L .54492 .71565 L F
.5495 .69763 m .54558 .70257 L .54362 .7103 L F
.54548 .68456 m .54558 .70257 L .5495 .69763 L 0 1 .374 r
F
.54622 .6923 m .55679 .71192 L .55731 .70747 L 0 .783 .322 r
F
.54622 .6923 m .55313 .71022 L .55679 .71192 L F
.54622 .6923 m .54879 .7035 L .55313 .71022 L F
.54622 .6923 m .54583 .69582 L .54879 .7035 L F
.54548 .68456 m .54167 .70244 L .54558 .70257 L 0 1 .374 r
F
.54513 .7008 m .55313 .71022 L .54879 .7035 L 0 .803 .328 r
F
.54513 .7008 m .55585 .71803 L .55313 .71022 L F
.54513 .7008 m .55514 .72172 L .55585 .71803 L F
.54513 .7008 m .55147 .719 L .55514 .72172 L F
.54646 .69518 m .55785 .73082 L .55402 .70474 L 0 .303 .234 r
F
.54513 .7008 m .54731 .71171 L .55147 .719 L 0 .803 .328 r
F
.54369 .70827 m .55147 .719 L .54731 .71171 L 0 .828 .335 r
F
.54369 .70827 m .55392 .72677 L .55147 .719 L F
.54369 .70827 m .55302 .72981 L .55392 .72677 L F
.54646 .69518 m .55845 .75447 L .55785 .73082 L 0 .303 .234 r
F
.54369 .70827 m .54939 .72636 L .55302 .72981 L 0 .828 .335 r
F
.54543 .73615 m .54822 .7492 L .55132 .74259 L 0 1 .413 r
F
.54874 .73986 m .5561 .75308 L .55242 .74465 L 0 .811 .356 r
F
.54874 .73986 m .5577 .76072 L .5561 .75308 L F
.54822 .7492 m .55101 .76234 L .55443 .75593 L 0 1 .419 r
F
.54822 .7492 m .55443 .75593 L .55319 .75058 L F
.54874 .73986 m .55615 .76247 L .5577 .76072 L 0 .811 .356 r
F
.55154 .73396 m .55242 .74465 L .5561 .75308 L 0 .769 .346 r
F
.54646 .69518 m .55536 .75613 L .55845 .75447 L 0 .303 .234 r
F
.5547 .73688 m .55812 .7406 L .55938 .72218 L 0 .743 .238 r
F
.5547 .73688 m .55938 .72218 L .55928 .72227 L F
.5547 .73688 m .5594 .72191 L .55543 .73078 L F
.55543 .73078 m .5594 .72191 L .55953 .72 L F
.55459 .72062 m .5546 .72057 L .55618 .7243 L 0 .564 .207 r
F
.55618 .7243 m .55618 .7243 L .55621 .72436 L F
.55459 .72062 m .55618 .7243 L .55618 .7243 L F
.55459 .72062 m .55621 .72436 L .55619 .72438 L F
.55806 .65606 m .56211 .71585 L .56003 .70601 L 0 .308 .195 r
F
.5546 .72057 m .56003 .70601 L .56128 .71771 L 0 .564 .207 r
F
.55543 .73078 m .55953 .72 L .55619 .72438 L 0 .743 .238 r
F
.56211 .71585 m .56216 .71656 L .56204 .716 L 0 .308 .195 r
F
.56211 .71585 m .56204 .716 L .56003 .70601 L F
.56188 .71636 m .56128 .71771 L .56107 .71577 L F
.56216 .71656 m .56128 .71771 L .56188 .71636 L F
.55812 .7406 m .56105 .72367 L .56128 .71771 L 0 .743 .238 r
F
.55812 .7406 m .56128 .71771 L .5594 .72191 L F
.56115 .71788 m .56128 .71771 L .56129 .71782 L 0 .564 .207 r
F
.5546 .72057 m .56128 .71771 L .56115 .71788 L F
.5546 .72057 m .56129 .71782 L .55621 .72436 L F
.56216 .71656 m .56107 .71577 L .56003 .70601 L 0 .308 .195 r
F
.55806 .65606 m .5657 .70981 L .56206 .7152 L F
.55953 .72 m .56128 .71771 L .56327 .66516 L 0 .743 .238 r
F
.5594 .72191 m .56128 .71771 L .55953 .72 L F
.5657 .70981 m .56242 .71606 L .56211 .71857 L 0 .533 .236 r
F
.5657 .70981 m .56776 .72428 L .5625 .7159 L 0 .308 .195 r
F
.5657 .70981 m .5625 .7159 L .56206 .7152 L F
.5657 .70981 m .56732 .67562 L .56242 .71606 L 0 .533 .236 r
F
.56216 .71656 m .56327 .66516 L .56128 .71771 L F
.56216 .71656 m .56128 .71771 L .56116 .7207 L F
.56211 .71857 m .56214 .71734 L .56105 .72367 L F
.56214 .71734 m .56216 .71656 L .56203 .71739 L F
.56214 .71734 m .56203 .71739 L .56105 .72367 L F
.56216 .71656 m .56116 .7207 L .56105 .72367 L F
.56211 .71857 m .56105 .72367 L .56032 .74298 L F
.56216 .71656 m .56391 .7425 L .56128 .71771 L 0 .308 .195 r
F
.55928 .72227 m .55938 .72218 L .5594 .72191 L 0 .743 .238 r
F
.55812 .7406 m .56032 .74298 L .56105 .72367 L F
.55621 .72436 m .56129 .71782 L .56391 .7425 L 0 .564 .207 r
F
.5547 .73688 m .55619 .72438 L .55532 .72568 L 0 .743 .238 r
F
.55459 .72062 m .55532 .72563 L .55505 .72608 L 0 .564 .207 r
F
.56246 .53592 m .56141 .5449 L .56343 .54925 L 0 1 .272 r
F
.55281 .55853 m .56246 .53592 L .56031 .53663 L 0 1 .238 r
F
.55281 .55853 m .56141 .5449 L .56246 .53592 L F
.55281 .55853 m .55784 .55684 L .56141 .5449 L F
.55603 .52947 m .56226 .51531 L .56573 .49755 L 0 1 .185 r
F
.55464 .54365 m .56468 .51235 L .56226 .51531 L 0 1 .217 r
F
.55464 .54365 m .56386 .52197 L .56468 .51235 L F
.56333 .53481 m .5689 .46308 L .56526 .49804 L 0 .865 .263 r
F
.55968 .55782 m .55842 .56607 L .5601 .57131 L 0 1 .28 r
F
.55054 .57346 m .55968 .55782 L .55784 .55684 L 0 1 .252 r
F
.55054 .57346 m .55842 .56607 L .55968 .55782 L F
.55054 .57346 m .55486 .57571 L .55842 .56607 L F
.5564 .56891 m .56442 .54859 L .56333 .53481 L 0 .987 .277 r
F
.54786 .58801 m .55638 .57793 L .55486 .57571 L 0 1 .262 r
F
.54786 .58801 m .55492 .58547 L .55638 .57793 L F
.55356 .58291 m .55518 .57778 L .5564 .56891 L 0 .987 .277 r
F
.55518 .57778 m .56442 .54859 L .5564 .56891 L F
.55518 .57778 m .56219 .56979 L .56442 .54859 L F
.55356 .58291 m .5547 .58119 L .55518 .57778 L F
.55638 .57793 m .55492 .58547 L .55623 .59123 L 0 1 .288 r
F
.5547 .58119 m .56219 .56979 L .55518 .57778 L 0 .987 .277 r
F
.56358 .56504 m .5689 .4631 L .56526 .49805 L 0 .273 .213 r
F
.56633 .50031 m .56469 .50867 L .56682 .49315 L 0 .057 .123 r
F
.55054 .57346 m .55784 .55684 L .55411 .56381 L 0 1 .252 r
F
.55281 .55853 m .55411 .56381 L .55784 .55684 L 0 1 .238 r
F
.54786 .58801 m .55486 .57571 L .55137 .58031 L 0 1 .262 r
F
.55054 .57346 m .55137 .58031 L .55486 .57571 L 0 1 .252 r
F
.55356 .58291 m .5564 .56891 L .55965 .54037 L 0 .987 .277 r
F
.5564 .56891 m .56333 .53481 L .56057 .53898 L F
.5564 .56891 m .56057 .53898 L .55965 .54037 L F
.55464 .54365 m .56031 .53663 L .56386 .52197 L 0 1 .217 r
F
.5547 .58119 m .5581 .58428 L .56219 .56979 L 0 .987 .277 r
F
.55356 .58291 m .55438 .58315 L .5547 .58119 L F
.55438 .58315 m .5581 .58428 L .5547 .58119 L F
.54786 .58801 m .55142 .59316 L .55492 .58547 L 0 1 .262 r
F
.55356 .58291 m .5544 .58992 L .5581 .58428 L 0 .987 .277 r
F
.55367 .59807 m .56358 .56504 L .56023 .54399 L 0 .397 .236 r
F
.55451 .58995 m .56023 .54399 L .55965 .54037 L F
.55367 .59807 m .56023 .54399 L .55451 .58995 L F
.55553 .60129 m .56219 .56979 L .5581 .58428 L 0 .84 .285 r
F
.55367 .59807 m .56504 .61988 L .56358 .56504 L 0 .397 .236 r
F
.56086 .57945 m .56181 .54792 L .56312 .52906 L 0 .057 .123 r
F
.56356 .52629 m .56312 .52906 L .56426 .51248 L F
.56086 .57945 m .56312 .52906 L .56356 .52629 L F
.56462 .50991 m .56426 .51248 L .56526 .49805 L F
.56086 .57945 m .56426 .51248 L .56462 .50991 L F
.56086 .57945 m .56443 .51354 L .56633 .50031 L F
.56443 .51354 m .56469 .50867 L .56633 .50031 L F
.56682 .49315 m .56526 .49804 L .56889 .46314 L F
.56526 .49804 m .56526 .49805 L .56889 .46314 L F
.56889 .46314 m .56526 .49805 L .5689 .46309 L F
.56469 .50867 m .56526 .49805 L .56682 .49315 L F
.56086 .57945 m .5689 .46309 L .57107 .49072 L F
.56086 .57945 m .57107 .49072 L .57035 .56383 L F
.5448 .60193 m .55259 .59628 L .55142 .59316 L 0 1 .27 r
F
.5448 .60193 m .55094 .60314 L .55259 .59628 L F
.55356 .58291 m .55965 .54037 L .55582 .56163 L 0 .987 .277 r
F
.5448 .60193 m .55142 .59316 L .54821 .59588 L 0 1 .27 r
F
.54786 .58801 m .54821 .59588 L .55142 .59316 L 0 1 .262 r
F
.5448 .60193 m .54754 .6092 L .55094 .60314 L 0 1 .27 r
F
.54139 .61508 m .54835 .61296 L .54754 .6092 L 0 1 .276 r
F
.54139 .61508 m .54654 .61918 L .54835 .61296 L F
.54139 .61508 m .54754 .6092 L .54465 .61041 L F
.5448 .60193 m .54465 .61041 L .54754 .6092 L 0 1 .27 r
F
.54139 .61508 m .54328 .62387 L .54654 .61918 L 0 1 .276 r
F
.54648 .60719 m .5544 .58992 L .55356 .58291 L 0 1 .295 r
F
.54359 .61707 m .5452 .61304 L .54648 .60719 L F
.5452 .61304 m .5544 .58992 L .54648 .60719 L F
.5452 .61304 m .55193 .6037 L .5544 .58992 L F
.54359 .61707 m .54469 .61532 L .5452 .61304 L F
.54469 .61532 m .55193 .6037 L .5452 .61304 L F
.55367 .59807 m .55965 .54037 L .55582 .56163 L 0 .397 .236 r
F
.55716 .55959 m .55526 .567 L .55757 .55644 L 0 .039 .115 r
F
.54359 .61707 m .54648 .60719 L .55 .5886 L 0 1 .295 r
F
.54648 .60719 m .55356 .58291 L .55088 .58721 L F
.54648 .60719 m .55088 .58721 L .55 .5886 L F
.54359 .61707 m .54779 .61508 L .55193 .6037 L F
.54359 .61707 m .54421 .62082 L .54779 .61508 L F
.54363 .62485 m .55367 .59807 L .55052 .58995 L 0 .502 .25 r
F
.55142 .604 m .55229 .58891 L .55484 .56918 L 0 .039 .115 r
F
.55492 .56883 m .55484 .56918 L .55502 .5678 L F
.55142 .604 m .55484 .56918 L .55492 .56883 L F
.5449 .61762 m .55052 .58995 L .55 .58861 L 0 .502 .25 r
F
.54363 .62485 m .55052 .58995 L .5449 .61762 L F
.55535 .5662 m .55502 .5678 L .55582 .56163 L 0 .039 .115 r
F
.55142 .604 m .55502 .5678 L .55535 .5662 L F
.55142 .604 m .55505 .56902 L .55716 .55959 L F
.55505 .56902 m .55526 .567 L .55716 .55959 L F
.55757 .55644 m .55582 .56162 L .55965 .5404 L F
.55582 .56162 m .55582 .56163 L .55965 .5404 L F
.55965 .5404 m .55582 .56163 L .55965 .54037 L F
.55526 .567 m .55582 .56163 L .55757 .55644 L F
.55142 .604 m .55965 .54037 L .56181 .54792 L F
.55367 .59807 m .55465 .62548 L .5586 .6508 L 0 .397 .236 r
F
.54504 .62686 m .55193 .6037 L .54779 .61508 L 0 .993 .302 r
F
.54614 .63786 m .55346 .6212 L .54913 .62874 L 0 .912 .306 r
F
.54504 .62686 m .54913 .62874 L .55346 .6212 L 0 .993 .302 r
F
.54363 .62485 m .55465 .62548 L .55367 .59807 L 0 .502 .25 r
F
.55142 .604 m .56181 .54792 L .56086 .57945 L 0 .039 .115 r
F
.56086 .57945 m .57035 .56383 L .5669 .61494 L 0 .057 .123 r
F
.56086 .57945 m .5669 .61494 L .56304 .60831 L F
.55142 .604 m .56086 .57945 L .55733 .60696 L 0 .039 .115 r
F
.54504 .62686 m .54552 .63116 L .54913 .62874 L 0 .993 .302 r
F
.54371 .62808 m .54189 .63992 L .54404 .64256 L 0 1 .31 r
F
.54371 .62808 m .54175 .63372 L .54189 .63992 L F
.53766 .62739 m .54175 .63372 L .54371 .62808 L 0 1 .281 r
F
.53766 .62739 m .53867 .63724 L .54175 .63372 L F
.53366 .63882 m .53872 .64176 L .53867 .63724 L 0 1 .284 r
F
.53366 .63882 m .53664 .64685 L .53872 .64176 L F
.53366 .63882 m .53377 .6494 L .53664 .64685 L F
.53446 .64796 m .54504 .62686 L .54154 .63043 L 0 1 .32 r
F
.53446 .64796 m .54552 .63116 L .54504 .62686 L F
.5469 .64947 m .55456 .63947 L .5501 .64317 L 0 .844 .308 r
F
.54614 .63786 m .5501 .64317 L .55456 .63947 L 0 .912 .306 r
F
.54363 .62485 m .55221 .64722 L .55465 .62548 L 0 .502 .25 r
F
.53872 .64176 m .54378 .6487 L .54404 .64256 L 0 1 .317 r
F
.53872 .64176 m .54129 .65426 L .54378 .6487 L F
.53872 .64176 m .54404 .64256 L .54189 .63992 L F
.53872 .64176 m .53811 .65611 L .54129 .65426 L F
.53872 .64176 m .53638 .653 L .53811 .65611 L F
.53872 .64176 m .53664 .64685 L .53638 .653 L F
.53446 .64796 m .54263 .6396 L .54552 .63116 L 0 1 .32 r
F
.54614 .63786 m .54649 .64248 L .5501 .64317 L 0 .912 .306 r
F
.53519 .65352 m .54614 .63786 L .54263 .6396 L 0 1 .324 r
F
.53519 .65352 m .54649 .64248 L .54614 .63786 L F
.54363 .62485 m .54798 .64861 L .55221 .64722 L 0 .502 .25 r
F
.54893 .64214 m .55733 .60696 L .55926 .62582 L 0 .209 .16 r
F
.54378 .6487 m .54884 .65861 L .54941 .65135 L 0 1 .336 r
F
.5469 .64947 m .5552 .65712 L .5584 .65082 L 0 .844 .308 r
F
.55806 .65606 m .56304 .60831 L .5669 .61494 L 0 .308 .195 r
F
.55806 .65606 m .55926 .62582 L .56304 .60831 L F
.54622 .6923 m .55731 .70747 L .55434 .69978 L 0 .783 .322 r
F
.54378 .6487 m .54245 .66564 L .54594 .66439 L 0 1 .336 r
F
.54378 .6487 m .54072 .66152 L .54245 .66564 L F
.53746 .66213 m .54245 .66564 L .54072 .66152 L 0 1 .345 r
F
.53746 .66213 m .54147 .67254 L .54245 .66564 L F
.53746 .66213 m .53842 .67762 L .54147 .67254 L F
.53746 .66213 m .53516 .67824 L .53842 .67762 L F
.53746 .66213 m .53385 .67398 L .53516 .67824 L F
.53746 .66213 m .53484 .66707 L .53385 .67398 L F
.53593 .66566 m .54729 .66111 L .54385 .65951 L 0 .973 .328 r
F
.54729 .66111 m .55081 .67088 L .55539 .67327 L 0 .799 .31 r
F
.54729 .66111 m .54734 .66567 L .55081 .67088 L F
.53593 .66566 m .54734 .66567 L .54729 .66111 L 0 .973 .328 r
F
.53593 .66566 m .54396 .66938 L .54734 .66567 L F
.5473 .67232 m .55539 .67327 L .55081 .67088 L 0 .777 .313 r
F
.5473 .67232 m .55055 .68312 L .5551 .68751 L F
.54695 .68278 m .5551 .68751 L .55055 .68312 L 0 .773 .316 r
F
.54521 .66026 m .55679 .69295 L .55599 .66614 L 0 .384 .242 r
F
.5473 .67232 m .54721 .67661 L .55055 .68312 L 0 .777 .313 r
F
.54695 .68278 m .54987 .69399 L .55434 .69978 L 0 .773 .316 r
F
.54622 .6923 m .55434 .69978 L .54987 .69399 L 0 .783 .322 r
F
.54521 .66026 m .55402 .70474 L .55679 .69295 L 0 .384 .242 r
F
.54893 .64214 m .55926 .62582 L .55806 .65606 L 0 .209 .16 r
F
.5469 .64947 m .55066 .65744 L .5552 .65712 L 0 .844 .308 r
F
.54729 .66111 m .5552 .65712 L .55066 .65744 L 0 .799 .31 r
F
.5469 .64947 m .5471 .65416 L .55066 .65744 L 0 .844 .308 r
F
.54378 .6487 m .54129 .65426 L .54072 .66152 L 0 1 .336 r
F
.53344 .65411 m .53746 .66213 L .53811 .65611 L 0 1 .323 r
F
.53344 .65411 m .53484 .66707 L .53746 .66213 L F
.53568 .65948 m .5471 .65416 L .5469 .64947 L 0 1 .326 r
F
.53568 .65948 m .54385 .65951 L .5471 .65416 L F
.54521 .66026 m .55221 .64722 L .54798 .64861 L 0 .384 .242 r
F
.54521 .66026 m .55599 .66614 L .55221 .64722 L F
.54893 .64214 m .55806 .65606 L .55444 .67136 L 0 .209 .16 r
F
.54147 .67254 m .54548 .68456 L .54679 .67715 L 0 1 .361 r
F
.53593 .67188 m .5473 .67232 L .54396 .66938 L 0 .945 .33 r
F
.54147 .67254 m .54679 .67715 L .54506 .67234 L 0 1 .361 r
F
.54147 .67254 m .542 .68963 L .54548 .68456 L F
.54147 .67254 m .53841 .68984 L .542 .68963 L F
.54147 .67254 m .53711 .68504 L .53841 .68984 L F
.54147 .67254 m .53842 .67762 L .53711 .68504 L F
.53593 .67188 m .54721 .67661 L .5473 .67232 L 0 .945 .33 r
F
.54695 .68278 m .5467 .68671 L .54987 .69399 L 0 .773 .316 r
F
.54521 .66026 m .54952 .69352 L .55402 .70474 L 0 .384 .242 r
F
.53593 .67188 m .54373 .67874 L .54721 .67661 L 0 .945 .33 r
F
.54521 .66026 m .54575 .67446 L .54952 .69352 L 0 .384 .242 r
F
.546 .67804 m .55444 .67136 L .55606 .69674 L 0 .32 .184 r
F
.54646 .69518 m .55402 .70474 L .54952 .69352 L 0 .303 .234 r
F
.546 .67804 m .55606 .69674 L .55459 .72062 L 0 .32 .184 r
F
.55459 .72062 m .55606 .69674 L .56003 .70601 L 0 .564 .207 r
F
.54874 .73986 m .55247 .75767 L .55615 .76247 L 0 .811 .356 r
F
.5577 .76072 m .55615 .76247 L .55752 .76975 L 0 .74 .367 r
F
.54543 .73615 m .55132 .74259 L .55007 .73729 L 0 1 .413 r
F
.54252 .72269 m .54543 .73615 L .54816 .72921 L 0 1 .406 r
F
.54252 .72269 m .54816 .72921 L .54687 .72375 L F
.5396 .70948 m .54252 .72269 L .54492 .71565 L 0 1 .397 r
F
.54191 .71475 m .55047 .73646 L .55154 .73396 L 0 .857 .342 r
F
.54191 .71475 m .54692 .73248 L .55047 .73646 L F
.5537 .76481 m .55594 .78044 L .55977 .78539 L 0 .792 .377 r
F
.54733 .72773 m .55918 .78652 L .55536 .75613 L 0 .277 .228 r
F
.54555 .74465 m .55247 .75767 L .54911 .74953 L 0 .851 .366 r
F
.54555 .74465 m .5537 .76481 L .55247 .75767 L F
.54555 .74465 m .55197 .76618 L .5537 .76481 L F
.54874 .73986 m .54911 .74953 L .55247 .75767 L 0 .811 .356 r
F
.5537 .76481 m .55197 .76618 L .55293 .77288 L 0 .792 .377 r
F
.5537 .76481 m .55293 .77288 L .55594 .78044 L F
.54733 .72773 m .55956 .80555 L .55918 .78652 L 0 .277 .228 r
F
.5547 .73688 m .5566 .77427 L .56032 .74298 L 0 .743 .238 r
F
.55532 .72563 m .56391 .7425 L .56558 .79532 L 0 .564 .207 r
F
.55459 .72062 m .55619 .72438 L .55532 .72563 L F
.55545 .72545 m .55619 .72438 L .55568 .72504 L 0 .743 .238 r
F
.55532 .72568 m .55619 .72438 L .55545 .72545 L F
.55619 .72438 m .5562 .7244 L .55532 .72563 L 0 .564 .207 r
F
.5562 .7244 m .56391 .7425 L .55532 .72563 L F
.55505 .72602 m .56372 .57539 L .56145 .53244 L 0 .743 .238 r
F
.55505 .72608 m .55506 .72602 L .55505 .72602 L F
.55506 .72602 m .56372 .57539 L .55505 .72602 L F
.5547 .73688 m .55532 .72563 L .55505 .72608 L F
.55532 .72563 m .56372 .57539 L .55505 .72608 L F
.55505 .72608 m .55532 .72563 L .55505 .72609 L 0 .564 .207 r
F
.56898 .78205 m .56923 .78063 L .56926 .78056 L 0 0 .024 r
F
.55944 .84168 m .56915 .86761 L .56989 .76808 L 0 .533 .236 r
F
.55505 .72609 m .56558 .79532 L .56386 .82919 L 0 .564 .207 r
F
.55532 .72563 m .56558 .79532 L .55505 .72609 L F
.55532 .72563 m .55568 .72504 L .55533 .72549 L 0 .743 .238 r
F
.55532 .72568 m .55568 .72504 L .55532 .72563 L F
.5547 .73688 m .55505 .72618 L .55489 .72633 L F
.54733 .72773 m .55618 .79839 L .55956 .80555 L 0 .277 .228 r
F
.55489 .72633 m .56386 .82919 L .5598 .81948 L 0 .564 .207 r
F
.55459 .72062 m .55505 .72608 L .55489 .72633 L F
.55505 .72618 m .55505 .72608 L .55489 .72633 L 0 .743 .238 r
F
.55505 .72608 m .56386 .82919 L .55489 .72633 L 0 .564 .207 r
F
.55505 .72608 m .55506 .72584 L .55489 .72633 L 0 .743 .238 r
F
.55506 .72584 m .56145 .53244 L .5549 .72605 L F
.55506 .72584 m .5549 .72605 L .55489 .72633 L F
.55533 .72549 m .56327 .66516 L .56372 .57539 L F
.55619 .72438 m .56327 .66516 L .55533 .72549 L F
.55459 .72062 m .55489 .72633 L .55476 .72644 L 0 .564 .207 r
F
.55142 .604 m .55733 .60696 L .55358 .61177 L 0 .039 .115 r
F
.54893 .64214 m .55358 .61177 L .55733 .60696 L 0 .209 .16 r
F
.55476 .72623 m .55786 .56174 L .55527 .64513 L 0 .743 .238 r
F
.5547 .73688 m .55489 .72633 L .55476 .72645 L F
.55476 .72645 m .55489 .72636 L .55476 .72647 L 0 .564 .207 r
F
.55476 .72644 m .55479 .72642 L .55476 .72645 L F
.55479 .72642 m .55489 .72636 L .55476 .72645 L F
.55476 .72645 m .55489 .72605 L .55476 .72623 L 0 .743 .238 r
F
.55489 .72633 m .55489 .72605 L .55476 .72645 L F
.55489 .72605 m .55786 .56174 L .55476 .72623 L F
.55619 .72438 m .55953 .72 L .56327 .66516 L F
.55619 .72438 m .55621 .72436 L .56391 .7425 L 0 .564 .207 r
F
.55489 .72605 m .56145 .53244 L .55786 .56174 L 0 .743 .238 r
F
.55489 .72633 m .5549 .72605 L .55489 .72605 L F
.5549 .72605 m .56145 .53244 L .55489 .72605 L F
.55489 .72633 m .55489 .72636 L .55476 .72644 L 0 .564 .207 r
F
.54191 .71475 m .55154 .73396 L .54939 .72636 L 0 .857 .342 r
F
.55154 .73396 m .55047 .73646 L .55242 .74465 L 0 .769 .346 r
F
.54646 .69518 m .55065 .73469 L .55536 .75613 L 0 .303 .234 r
F
.54733 .72773 m .55536 .75613 L .55065 .73469 L 0 .277 .228 r
F
.54252 .72269 m .54048 .73995 L .54543 .73615 L 0 1 .406 r
F
.54252 .72269 m .53613 .7389 L .54048 .73995 L F
.54252 .72269 m .53528 .73369 L .53613 .7389 L F
.54252 .72269 m .53802 .72674 L .53528 .73369 L F
.5396 .70948 m .53802 .72674 L .54252 .72269 L 0 1 .397 r
F
.53982 .72031 m .54874 .73986 L .54692 .73248 L 0 .888 .35 r
F
.53982 .72031 m .54751 .74189 L .54874 .73986 L F
.54874 .73986 m .54751 .74189 L .54911 .74953 L 0 .811 .356 r
F
.54733 .72773 m .55135 .76997 L .55618 .79839 L 0 .277 .228 r
F
.54782 .75651 m .55618 .79839 L .55135 .76997 L 0 .262 .225 r
F
.54443 .77035 m .55055 .78246 L .54792 .77522 L 0 .888 .394 r
F
.54443 .77035 m .55069 .78823 L .55055 .78246 L F
.54782 .75651 m .5516 .79846 L .55648 .8307 L 0 .262 .225 r
F
.54782 .75651 m .54791 .76678 L .5516 .79846 L F
.54791 .78075 m .55648 .8307 L .5516 .79846 L 0 .255 .224 r
F
.54791 .78075 m .55139 .82028 L .55624 .85378 L F
.54443 .77035 m .54476 .78382 L .54825 .78869 L 0 .888 .394 r
F
.54791 .78075 m .54784 .7891 L .55139 .82028 L 0 .255 .224 r
F
.5476 .80023 m .55624 .85378 L .55139 .82028 L 0 .252 .226 r
F
.5476 .80023 m .54736 .80671 L .55072 .83611 L F
.54689 .81515 m .54649 .81993 L .54962 .84689 L 0 .252 .229 r
F
.54578 .82598 m .54524 .82927 L .5481 .85355 L 0 .253 .233 r
F
.54689 .84392 m .5566 .77427 L .5547 .73688 L 0 .586 .244 r
F
.54689 .84392 m .5555 .82759 L .5566 .77427 L F
.55476 .72647 m .5598 .81948 L .55616 .77301 L 0 .564 .207 r
F
.55489 .72636 m .5598 .81948 L .55476 .72647 L F
.56216 .71656 m .56732 .67562 L .56327 .66516 L 0 .533 .236 r
F
.56211 .71857 m .56242 .71606 L .56216 .71656 L F
.56242 .71606 m .56732 .67562 L .56216 .71656 L F
.56216 .71656 m .56776 .72428 L .56391 .7425 L 0 .308 .195 r
F
.5625 .7159 m .56776 .72428 L .56216 .71656 L F
.56805 .70632 m .56817 .70614 L .56814 .70491 L 0 .533 .236 r
F
.56626 .69793 m .56814 .70491 L .56732 .67562 L F
.57043 .69797 m .57103 .70229 L .57129 .69536 L 0 .771 .231 r
F
.57103 .70229 m .57367 .72124 L .5742 .68657 L F
.57043 .69797 m .5713 .6894 L .57185 .69369 L 0 .627 .217 r
F
.5713 .6894 m .57317 .67102 L .5742 .68657 L F
.5713 .6894 m .5742 .68657 L .57185 .69369 L F
.57527 .68123 m .57512 .68199 L .57317 .67102 L 0 .032 .122 r
F
.57536 .68336 m .5742 .68657 L .57317 .67102 L F
.57043 .69797 m .56894 .66418 L .57317 .67102 L 0 .627 .217 r
F
.56814 .70491 m .56989 .76808 L .57043 .69797 L 0 .771 .231 r
F
.56776 .72428 m .56814 .70491 L .57043 .69797 L 0 .627 .217 r
F
.56814 .70491 m .56894 .66418 L .57043 .69797 L F
.57043 .69797 m .56989 .76808 L .57367 .72124 L 0 .771 .231 r
F
.56732 .67562 m .56814 .70491 L .57043 .69797 L F
.57129 .69536 m .5742 .68657 L .57597 .5705 L F
.57103 .70229 m .5742 .68657 L .57129 .69536 L F
.57527 .68123 m .57536 .68336 L .57512 .68199 L 0 .032 .122 r
F
.57536 .68336 m .57597 .5705 L .57397 .70797 L 0 .191 .184 r
F
.57368 .7278 m .57428 .68634 L .57367 .72124 L F
.57428 .68634 m .5742 .68657 L .57367 .72124 L F
.57397 .94109 m .5753 .69493 L .57368 .7278 L F
.57185 .69369 m .5742 .68657 L .57776 .74059 L 0 .627 .217 r
F
.57767 .74044 m .57043 .69797 L .57776 .74059 L F
.56776 .72428 m .56929 .70921 L .57767 .74044 L F
.56929 .70921 m .57043 .69797 L .57767 .74044 L F
.5657 .70981 m .56814 .70491 L .56676 .71727 L 0 .308 .195 r
F
.56676 .71727 m .56814 .70491 L .56776 .72428 L F
.56732 .67562 m .56959 .6919 L .57597 .5705 L 0 .771 .231 r
F
.56959 .6919 m .57043 .69797 L .57141 .67559 L F
.56959 .6919 m .57141 .67559 L .57597 .5705 L F
.57043 .69797 m .57129 .69536 L .57597 .5705 L F
.57043 .69797 m .57185 .69369 L .57776 .74059 L 0 .627 .217 r
F
.57535 .68545 m .57536 .68336 L .57528 .68552 L 0 .191 .184 r
F
.57536 .68336 m .57776 .74059 L .5742 .68657 L 0 .032 .122 r
F
.57428 .68634 m .57597 .5705 L .5742 .68657 L 0 .191 .184 r
F
.58132 .6628 m .58178 .72301 L .58171 .67296 L 0 .004 .122 r
F
.58137 .66166 m .58171 .67296 L .58168 .65401 L F
.58132 .6628 m .58171 .67296 L .58137 .66166 L F
.5812 .65949 m .58178 .72301 L .58129 .6592 L F
.58361 1.23839 m .59441 1.33429 L .59444 1.33589 L 0 .994 .102 r
F
.58567 1.2215 m .59438 1.33273 L .58944 1.27896 L 0 .877 .163 r
F
.59438 1.33273 m .59441 1.33429 L .58944 1.27896 L F
.59016 1.21647 m .59027 1.21794 L .59018 1.21869 L F
.5902 1.21752 m .5901 1.21616 L .59065 1.23081 L 0 0 .1 r
F
.58898 1.22889 m .59018 1.21869 L .59033 1.22175 L 0 .877 .163 r
F
.59018 1.21869 m .59027 1.21794 L .59033 1.22175 L F
.58993 1.22389 m .59033 1.22175 L .59002 1.23121 L F
.59033 1.22175 m .59048 1.22486 L .59002 1.23121 L F
.59281 1.288 m .59305 1.29295 L .58786 1.14044 L 0 0 .1 r
F
.58955 .46124 m .59032 .53109 L .58445 .58621 L 0 0 .075 r
F
.59152 .96221 m .59273 .95439 L .59175 1.22243 L 0 0 .08 r
F
.59 .92249 m .58881 .85487 L .58997 .92221 L 0 0 .073 r
F
.5906 .92909 m .59082 .98583 L .59053 .9283 L 0 0 .08 r
F
.58809 .62015 m .58178 .72301 L .6 1.20464 L 0 .004 .122 r
F
.58112 .27828 m .58168 .65401 L .58809 .62015 L F
.58168 .65401 m .58178 .72301 L .58809 .62015 L F
.58129 .6592 m .58132 .66007 L .58132 .65885 L F
.58124 .65632 m .58065 .62185 L .58168 .65401 L 0 0 .075 r
F
.58132 .6628 m .58168 .65401 L .58132 .65885 L 0 .004 .122 r
F
.58134 .66436 m .5811 .65275 L .58121 .65631 L 0 0 .075 r
F
.59099 1.10093 m .59013 .96375 L .5909 1.05051 L 0 0 .08 r
F
.59082 .98583 m .59175 1.22243 L .59068 .99343 L F
.58919 1.19803 m .58973 1.20954 L .58928 1.19898 L 0 0 .062 r
F
.58862 1.18467 m .58602 1.12347 L .58867 1.18185 L F
.58894 1.19225 m .58928 1.19898 L .58602 1.12347 L F
.58919 1.19795 m .58918 1.19666 L .58926 1.19857 L F
.58919 1.19803 m .58928 1.19898 L .58894 1.19225 L F
.58768 1.18151 m .58816 1.17662 L .58837 1.18073 L 0 .686 .18 r
F
.58668 1.18265 m .58744 1.17866 L .58768 1.18151 L F
.58928 1.20025 m .58919 1.19795 L .58928 1.20008 L 0 0 .062 r
F
.58929 1.20031 m .58973 1.20954 L .58919 1.19803 L F
.58928 1.20025 m .58946 1.20379 L .58924 1.20516 L 0 .686 .18 r
F
.58929 1.20034 m .58879 1.18873 L .58929 1.20032 L 0 0 .062 r
F
.58766 1.18438 m .58784 1.18381 L .58791 1.18482 L 0 .686 .18 r
F
.58668 1.18265 m .58752 1.18169 L .58766 1.18438 L F
.58668 1.18265 m .58928 1.20025 L .58924 1.20516 L F
.58879 1.18873 m .58602 1.12347 L .58879 1.18869 L 0 0 .062 r
F
.58444 1.11544 m .58501 1.12361 L .58447 1.11581 L 0 0 .123 r
F
.58501 1.12361 m .58604 1.1382 L .58447 1.11581 L F
.58447 1.11581 m .58604 1.1382 L .58449 1.116 L F
.58604 1.1382 m .58696 1.15115 L .58607 1.13852 L F
.58604 1.1382 m .58607 1.13852 L .58449 1.116 L F
.5843 1.11569 m .58414 1.11417 L .58437 1.11661 L F
.58414 1.11417 m .58392 1.11205 L .58437 1.11661 L F
.58382 1.11346 m .58406 1.11379 L .58437 1.12217 L 0 .762 .122 r
F
.5854 1.12889 m .58528 1.12723 L .58528 1.12728 L 0 0 .123 r
F
.58624 1.14133 m .58625 1.14151 L .58311 1.13875 L 0 .762 .122 r
F
.58534 1.12798 m .58534 1.12799 L .58528 1.12723 L 0 0 .123 r
F
.58612 1.13962 m .58624 1.14133 L .58311 1.13875 L 0 .762 .122 r
F
.58462 1.11944 m .5843 1.11569 L .58449 1.11814 L 0 0 .123 r
F
.58683 1.14817 m .58697 1.15012 L .58684 1.14835 L F
.58394 1.11026 m .58354 1.1068 L .58448 1.11778 L F
.58263 1.09992 m .58305 1.10075 L .58344 1.10758 L 0 .67 .126 r
F
.58263 1.09992 m .58344 1.10758 L .58285 1.10766 L F
.5843 1.11569 m .58274 1.09734 L .58392 1.11205 L 0 0 .123 r
F
.58444 1.11544 m .58449 1.116 L .58257 1.08864 L F
.57294 1.13153 m .57793 1.12547 L .58041 1.13179 L 0 .346 .058 r
F
.57294 1.13153 m .58041 1.13179 L .57829 1.13441 L F
.58503 1.1489 m .57829 1.13441 L .58041 1.13179 L 0 .389 .079 r
F
.58503 1.1489 m .58026 1.14174 L .57829 1.13441 L F
.57874 1.15649 m .58026 1.14174 L .58503 1.1489 L 0 .473 .083 r
F
.57874 1.15649 m .58503 1.1489 L .58665 1.15674 L F
.57874 1.15649 m .58665 1.15674 L .58401 1.16001 L F
.58186 1.18641 m .58003 1.16448 L .5851 1.16922 L 0 .601 .1 r
F
.57793 1.12547 m .56976 1.11377 L .57145 1.11169 L 0 .305 .054 r
F
.57793 1.12547 m .57253 1.11967 L .56976 1.11377 L F
.57294 1.13153 m .57253 1.11967 L .57793 1.12547 L 0 .346 .058 r
F
.57377 1.11531 m .578 1.11958 L .58311 1.13875 L 0 .866 .108 r
F
.57874 1.15649 m .57503 1.13824 L .58026 1.14174 L 0 .473 .083 r
F
.57377 1.11531 m .58684 1.16578 L .58668 1.18265 L 0 .866 .108 r
F
.57377 1.11531 m .58311 1.13875 L .58684 1.16578 L F
.57943 1.12447 m .59013 .96375 L .59175 1.22243 L 0 .145 .158 r
F
.59864 1.26951 m .58682 .85618 L .58178 .72301 L 0 .004 .122 r
F
.59175 1.22243 m .59099 1.10093 L .5909 1.05051 L 0 0 .08 r
F
.59175 1.22243 m .59088 1.04291 L .59088 1.03791 L F
.59578 1.38797 m .59556 1.37309 L .596 1.38808 L 0 .994 .102 r
F
.59578 1.38797 m .59444 1.33589 L .59556 1.37309 L F
.59281 1.288 m .59438 1.33273 L .59305 1.29295 L 0 0 .1 r
F
.59428 1.32875 m .59356 1.30859 L .59426 1.32775 L F
.59428 1.32486 m .59392 1.31839 L .59449 1.33508 L 0 0 .116 r
F
.59428 1.32486 m .59449 1.33508 L .59467 1.33799 L F
.59444 1.33589 m .59441 1.33429 L .59449 1.33508 L 0 .994 .102 r
F
.59444 1.33589 m .59449 1.33508 L .59467 1.33799 L F
.58924 1.20516 m .58939 1.20607 L .58948 1.20731 L 0 .686 .18 r
F
.58567 1.2215 m .58888 1.22865 L .58981 1.24534 L 0 .877 .163 r
F
.59008 1.21657 m .59016 1.21647 L .59018 1.21869 L F
.59008 1.21657 m .59018 1.21869 L .58898 1.22889 L F
.58974 1.20961 m .58974 1.20962 L .58973 1.20954 L 0 0 .062 r
F
.58898 1.22889 m .58993 1.22389 L .59002 1.23121 L 0 .877 .163 r
F
.58567 1.2215 m .58911 1.21765 L .58898 1.22889 L F
.58567 1.2215 m .58916 1.21316 L .58911 1.21765 L F
.57442 1.19149 m .58186 1.18641 L .58235 1.19547 L 0 .677 .098 r
F
.57442 1.19149 m .58235 1.19547 L .57925 1.19767 L F
.58234 1.22046 m .58235 1.19547 L .58726 1.20238 L 0 .707 .112 r
F
.58234 1.22046 m .57925 1.19767 L .58235 1.19547 L F
.57377 1.11531 m .57888 1.14825 L .57745 1.14215 L 0 .866 .108 r
F
.57888 1.14825 m .58263 1.17245 L .57895 1.15092 L F
.57888 1.14825 m .57895 1.15092 L .57745 1.14215 L F
.58003 1.3205 m .58939 1.35163 L .58477 1.34136 L 0 .897 .137 r
F
.58385 1.36951 m .58477 1.34136 L .58939 1.35163 L 0 .908 .151 r
F
.58385 1.36951 m .58239 1.34897 L .58477 1.34136 L F
.58385 1.36951 m .58939 1.35163 L .59418 1.37844 L F
.58609 1.29495 m .58382 1.278 L .58504 1.26537 L 0 .805 .145 r
F
.57563 1.2788 m .57917 1.26157 L .58382 1.278 L 0 .881 .12 r
F
.5677 1.13724 m .56795 1.12508 L .57294 1.13153 L 0 .405 .061 r
F
.5677 1.13724 m .57294 1.13153 L .57503 1.13824 L F
.5677 1.13724 m .57503 1.13824 L .5728 1.14072 L F
.56242 1.14181 m .5677 1.13724 L .56945 1.14408 L 0 .474 .061 r
F
.56242 1.14181 m .56945 1.14408 L .5672 1.14609 L F
.57239 1.16268 m .56945 1.14408 L .57439 1.14853 L 0 .554 .084 r
F
.57239 1.16268 m .5672 1.14609 L .56945 1.14408 L F
.57239 1.16268 m .57439 1.14853 L .57874 1.15649 L F
.57239 1.16268 m .56846 1.15405 L .5672 1.14609 L F
.57239 1.16268 m .57874 1.15649 L .58003 1.16448 L F
.56598 1.16646 m .56846 1.15405 L .57239 1.16268 L 0 .62 .081 r
F
.57239 1.16268 m .58003 1.16448 L .57736 1.16716 L 0 .554 .084 r
F
.56598 1.16646 m .57239 1.16268 L .57334 1.17041 L 0 .62 .081 r
F
.56598 1.16646 m .57334 1.17041 L .57065 1.17207 L F
.57442 1.19149 m .57334 1.17041 L .57814 1.17654 L 0 .677 .098 r
F
.57442 1.19149 m .57065 1.17207 L .57334 1.17041 L F
.57442 1.19149 m .57814 1.17654 L .58186 1.18641 L F
.57442 1.19149 m .5711 1.18108 L .57065 1.17207 L F
.5669 1.19172 m .5711 1.18108 L .57442 1.19149 L 0 .734 .093 r
F
.5669 1.19172 m .57442 1.19149 L .57458 1.1994 L F
.5669 1.19172 m .57458 1.1994 L .57144 1.19952 L F
.57383 1.22074 m .57458 1.1994 L .57924 1.20835 L 0 .777 .107 r
F
.57383 1.22074 m .57144 1.19952 L .57458 1.1994 L F
.57383 1.22074 m .57924 1.20835 L .58234 1.22046 L F
.57383 1.22074 m .58234 1.22046 L .58204 1.22966 L F
.57383 1.22074 m .58204 1.22966 L .57852 1.22977 L F
.58024 1.25465 m .57774 1.24045 L .57852 1.22977 L 0 .798 .124 r
F
.57067 1.24305 m .5732 1.22706 L .57774 1.24045 L 0 .856 .108 r
F
.57067 1.24305 m .57774 1.24045 L .58024 1.25465 L F
.56428 1.11137 m .5682 1.1066 L .57145 1.11169 L 0 .263 .024 r
F
.56428 1.11137 m .57145 1.11169 L .56976 1.11377 L F
.57294 1.13153 m .56721 1.11681 L .57253 1.11967 L 0 .346 .058 r
F
.57294 1.13153 m .56551 1.11878 L .56721 1.11681 L F
.57294 1.13153 m .56795 1.12508 L .56551 1.11878 L F
.57874 1.15649 m .5728 1.14072 L .57503 1.13824 L 0 .473 .083 r
F
.57874 1.15649 m .57439 1.14853 L .5728 1.14072 L F
.58234 1.22046 m .57924 1.20835 L .57925 1.19767 L 0 .707 .112 r
F
.57075 1.11967 m .57782 1.19121 L .5739 1.15372 L 0 .634 .042 r
F
.57782 1.19121 m .579 1.20318 L .57784 1.19193 L F
.57782 1.19121 m .57784 1.19193 L .5739 1.15372 L F
.56626 1.09274 m .56941 1.10809 L .56851 1.10531 L 0 .554 .01 r
F
.56941 1.10809 m .57265 1.1238 L .56962 1.11028 L F
.56941 1.10809 m .56962 1.11028 L .56851 1.10531 L F
.57279 1.14383 m .5739 1.15372 L .579 1.20318 L 0 .548 0 r
F
.56593 1.09018 m .56933 1.10721 L .56626 1.09274 L 0 .554 .01 r
F
.56933 1.10721 m .57265 1.1238 L .56941 1.10809 L F
.56933 1.10721 m .56941 1.10809 L .56626 1.09274 L F
.5639 1.07823 m .57265 1.1238 L .56465 1.08377 L F
.56465 1.08377 m .56593 1.09018 L .56626 1.09274 L F
.56568 1.06706 m .55978 1.06714 L .56045 1.06907 L 0 1 .504 r
F
.56568 1.06706 m .56202 1.06628 L .55978 1.06714 L F
.56376 1.06228 m .55878 1.06417 L .56202 1.06628 L 0 1 .496 r
F
.56376 1.06228 m .55811 1.06214 L .55878 1.06417 L F
.56376 1.06228 m .56024 1.06133 L .55811 1.06214 L F
.56184 1.05719 m .56024 1.06133 L .56376 1.06228 L 0 .942 .485 r
F
.56184 1.05719 m .55709 1.05897 L .56024 1.06133 L F
.57233 1.06308 m .55705 1.07278 L .55787 1.07272 L 0 .912 .211 r
F
.57233 1.06308 m .56325 1.06864 L .55705 1.07278 L F
.55044 1.0639 m .56045 1.06907 L .55978 1.06714 L 0 1 .525 r
F
.54908 1.05858 m .55044 1.0639 L .55877 1.06417 L 0 1 .52 r
F
.56376 1.06228 m .56202 1.06628 L .56568 1.06706 L 0 1 .496 r
F
.54908 1.05858 m .55877 1.06417 L .5581 1.06214 L 0 1 .52 r
F
.56184 1.05719 m .56376 1.06228 L .5658 1.06152 L 0 .942 .485 r
F
.56184 1.05719 m .5658 1.06152 L .56499 1.05955 L F
.55991 1.05162 m .56184 1.05719 L .56378 1.05647 L 0 .811 .466 r
F
.55991 1.05162 m .56378 1.05647 L .56296 1.05434 L F
.56877 1.04902 m .55565 1.066 L .56325 1.06864 L 0 .968 .385 r
F
.54771 1.05283 m .54908 1.05858 L .55709 1.05897 L 0 1 .512 r
F
.54771 1.05283 m .55709 1.05897 L .55641 1.05678 L F
.56184 1.05719 m .55642 1.05679 L .55709 1.05897 L 0 .942 .485 r
F
.56184 1.05719 m .55845 1.05602 L .55642 1.05679 L F
.55991 1.05162 m .55845 1.05602 L .56184 1.05719 L 0 .811 .466 r
F
.55991 1.05162 m .5554 1.05331 L .55845 1.05602 L F
.56877 1.04902 m .55458 1.0569 L .55565 1.066 L 0 .968 .385 r
F
.56024 1.0592 m .5639 1.07823 L .56465 1.08377 L 0 .554 .01 r
F
.55991 1.05162 m .55472 1.05086 L .5554 1.05331 L 0 .811 .466 r
F
.55991 1.05162 m .55665 1.05014 L .55472 1.05086 L F
.55796 1.04524 m .55665 1.05014 L .55991 1.05162 L 0 .623 .431 r
F
.55796 1.04524 m .55369 1.04684 L .55665 1.05014 L F
.55796 1.04524 m .55301 1.04392 L .55369 1.04684 L F
.55796 1.04524 m .55483 1.04324 L .55301 1.04392 L F
.55599 1.03743 m .55483 1.04324 L .55796 1.04524 L 0 .344 .356 r
F
.55599 1.03743 m .55197 1.03878 L .55483 1.04324 L F
.55599 1.03743 m .55128 1.03484 L .55197 1.03878 L F
.55599 1.03743 m .55796 1.04524 L .55969 1.04467 L F
.55599 1.03743 m .553 1.03426 L .55128 1.03484 L F
.55399 1.02581 m .55021 1.02424 L .553 1.03426 L 0 .062 .169 r
F
.554 1.02574 m .55396 1.02573 L .55399 1.02581 L F
.55396 1.02573 m .55021 1.02424 L .55399 1.02581 L F
.54354 1.02912 m .54494 1.03887 L .55197 1.03878 L 0 .994 .467 r
F
.5514 1.00358 m .54024 1.00786 L .55273 1.00806 L 0 1 .53 r
F
.54208 1.00785 m .5502 1.02413 L .54947 1.01382 L 0 1 .464 r
F
.54208 1.00785 m .54354 1.02912 L .5502 1.02413 L F
.54354 1.02912 m .55197 1.03878 L .55127 1.03483 L 0 .994 .467 r
F
.554 1.02574 m .54947 1.01405 L .55021 1.02424 L 0 .062 .169 r
F
.55389 1.02548 m .5511 1.01469 L .54947 1.01405 L F
.554 1.02574 m .55127 1.01535 L .55389 1.02548 L F
.55127 1.01535 m .5511 1.01469 L .55389 1.02548 L F
.55116 1.01747 m .54951 1.01261 L .55109 1.01467 L 0 .836 .089 r
F
.5511 1.01468 m .55109 1.01467 L .55109 1.01467 L F
.55116 1.01747 m .55109 1.01467 L .5511 1.01468 L F
.55172 1.04131 m .54833 1.01107 L .54951 1.01261 L F
.55172 1.04131 m .54951 1.01261 L .55116 1.01747 L F
.55172 1.04131 m .55109 1.01467 L .554 1.02574 L F
.55599 1.03743 m .55969 1.04467 L .55886 1.0419 L 0 .344 .356 r
F
.554 1.02574 m .553 1.03426 L .55599 1.03743 L 0 .062 .169 r
F
.554 1.02574 m .55599 1.03743 L .55762 1.03809 L F
.55172 1.04131 m .554 1.02574 L .55546 1.03871 L 0 .836 .089 r
F
.554 1.02574 m .55762 1.03809 L .5568 1.03579 L 0 .062 .169 r
F
.55172 1.04131 m .55546 1.03871 L .5545 1.04493 L 0 .836 .089 r
F
.56602 1.03474 m .55233 1.03225 L .55316 1.04232 L 0 .619 .331 r
F
.55796 1.04524 m .55991 1.05162 L .56174 1.05094 L 0 .623 .431 r
F
.55796 1.04524 m .56174 1.05094 L .56092 1.04855 L F
.56602 1.03474 m .55316 1.04232 L .5602 1.04949 L 0 .619 .331 r
F
.56877 1.04902 m .5602 1.04962 L .55458 1.0569 L 0 .968 .385 r
F
.54244 1.01308 m .53394 1.02545 L .54354 1.02912 L 0 1 .464 r
F
.54208 1.00785 m .54072 1.0108 L .54244 1.01308 L F
.54072 1.0108 m .53394 1.02545 L .54244 1.01308 L F
.5514 1.00358 m .53071 1.0064 L .54024 1.00786 L 0 1 .53 r
F
.5514 1.00358 m .53047 1.00466 L .53071 1.0064 L F
.52091 .99146 m .52119 .9987 L .53009 .99622 L 0 1 .522 r
F
.5514 1.00358 m .53933 1.00345 L .53047 1.00466 L 0 1 .53 r
F
.52091 .99146 m .50908 .99912 L .52119 .9987 L 0 1 .522 r
F
.52091 .99146 m .50013 .99727 L .50908 .99912 L F
.52091 .99146 m .50032 .99438 L .50013 .99727 L F
.52091 .99146 m .50922 .99189 L .50032 .99438 L F
.52062 .98385 m .52091 .99146 L .52949 .98885 L 0 1 .518 r
F
.52062 .98385 m .50922 .99189 L .52091 .99146 L F
.52035 .99106 m .52064 .99433 L .52891 .99467 L 0 1 .491 r
F
.52035 .99106 m .52891 .99467 L .52867 .99342 L F
.52007 .98845 m .52035 .99106 L .52831 .99177 L 0 1 .457 r
F
.54072 1.0108 m .52657 1.01948 L .53394 1.02545 L 0 1 .464 r
F
.54208 1.00785 m .53978 1.00958 L .54072 1.0108 L F
.53978 1.00958 m .52657 1.01948 L .54072 1.0108 L F
.53978 1.00958 m .52632 1.01518 L .52657 1.01948 L F
.54208 1.00785 m .53938 1.00911 L .53978 1.00958 L F
.53938 1.00911 m .52632 1.01518 L .53978 1.00958 L F
.52119 .9987 m .52147 1.00566 L .5307 1.00326 L 0 1 .526 r
F
.52119 .9987 m .51167 1.00443 L .52147 1.00566 L F
.51167 1.00443 m .50894 1.00508 L .51545 1.00586 L 0 1 .53 r
F
.51167 1.00443 m .51545 1.00586 L .51547 1.00586 L F
.51167 1.00443 m .49967 1.00262 L .50894 1.00508 L F
.52119 .9987 m .5067 1.00248 L .51167 1.00443 L 0 1 .526 r
F
.5212 1.00219 m .5067 1.00248 L .51167 1.00443 L 0 1 .53 r
F
.5067 1.00248 m .49967 1.00262 L .51164 1.00443 L F
.5067 1.00248 m .49986 1.00084 L .49967 1.00262 L F
.52119 .9987 m .50336 1.00106 L .5067 1.00248 L 0 1 .526 r
F
.5212 1.00219 m .50336 1.00106 L .5067 1.00248 L 0 1 .53 r
F
.50336 1.00106 m .49986 1.00084 L .5067 1.00248 L F
.50336 1.00106 m .50317 1.00108 L .5067 1.00248 L 0 1 .526 r
F
.5067 1.00248 m .49985 1.00152 L .49967 1.00431 L F
.50317 1.00108 m .49985 1.00152 L .5067 1.00248 L F
.5067 1.00248 m .51164 1.00443 L .51167 1.00443 L 0 1 .53 r
F
.5067 1.00248 m .50657 1.00251 L .51167 1.00443 L 0 1 .526 r
F
.51167 1.00443 m .49967 1.00431 L .50894 1.00608 L F
.50657 1.00251 m .49967 1.00431 L .51167 1.00443 L F
.51167 1.00443 m .50894 1.00608 L .51547 1.00586 L F
.51167 1.00443 m .51547 1.00586 L .52147 1.00566 L F
.5212 1.00219 m .51167 1.00443 L .52148 1.00658 L 0 1 .53 r
F
.51167 1.00443 m .51547 1.00586 L .52148 1.00658 L F
.5212 1.00219 m .52148 1.00658 L .53071 1.0064 L F
.5212 1.00219 m .53071 1.0064 L .53047 1.00466 L F
.53494 1.00353 m .52589 1.00823 L .53297 1.01014 L 0 1 .417 r
F
.54469 .98801 m .52771 .98974 L .53567 .98984 L 0 .761 .254 r
F
.54469 .98801 m .52747 .98923 L .52771 .98974 L F
.54469 .98801 m .53475 .98849 L .52747 .98923 L F
.54335 .98883 m .53475 .98849 L .54469 .98801 L 0 0 0 r
F
.52062 .98385 m .52949 .98885 L .52925 .98578 L 0 1 .518 r
F
.54335 .98883 m .52711 .9889 L .53475 .98849 L 0 0 0 r
F
.54335 .98883 m .52687 .98897 L .52711 .9889 L F
.54335 .98883 m .53383 .98894 L .52687 .98897 L F
.54205 1.00119 m .53383 .98894 L .54335 .98883 L 0 .016 0 r
F
.51979 .98674 m .52007 .98845 L .52771 .98974 L 0 .852 .406 r
F
.51979 .98674 m .52771 .98974 L .52747 .98923 L F
.54205 1.00119 m .52651 .98945 L .53383 .98894 L 0 .016 0 r
F
.52007 .98845 m .52831 .99177 L .52807 .99083 L 0 1 .457 r
F
.54205 1.00119 m .52626 .99004 L .52651 .98945 L 0 .016 0 r
F
.54205 1.00119 m .53292 .99506 L .52626 .99004 L F
.54187 1.00261 m .53292 .99512 L .54205 1.00133 L 0 .239 0 r
F
.54175 1.00351 m .53558 1.0014 L .54187 1.00261 L F
.53558 1.0014 m .53292 .99512 L .54187 1.00261 L F
.54175 1.00351 m .54208 1.00771 L .54414 1.00447 L 0 1 .417 r
F
.53938 1.00911 m .53297 1.0102 L .52632 1.01518 L 0 1 .464 r
F
.54208 1.00785 m .53898 1.00865 L .53938 1.00911 L F
.53898 1.00865 m .53297 1.0102 L .53938 1.00911 L F
.52119 .9987 m .50908 .99912 L .5027 1.00078 L 0 1 .526 r
F
.50336 1.00106 m .5027 1.00078 L .49985 1.00152 L F
.52119 .9987 m .5027 1.00078 L .50336 1.00106 L F
.5212 1.00219 m .50908 1.00065 L .5027 1.00078 L 0 1 .53 r
F
.50336 1.00106 m .5027 1.00078 L .49986 1.00084 L F
.5212 1.00219 m .5027 1.00078 L .50336 1.00106 L F
.52092 .99808 m .5212 1.00219 L .53011 1.00213 L 0 1 .523 r
F
.52092 .99808 m .53011 1.00213 L .52987 1.00051 L F
.53152 .99938 m .52589 1.00823 L .53494 1.00353 L 0 1 .417 r
F
.53152 .99938 m .52558 1.00326 L .52589 1.00823 L F
.53112 .99895 m .52557 .99125 L .52852 .99506 L 0 .239 0 r
F
.53075 .99855 m .52557 .99125 L .53112 .99895 L F
.53009 .99784 m .52558 1.00326 L .53152 .99938 L 0 1 .417 r
F
.53137 .99969 m .53012 .99787 L .53253 1.00105 L 0 .239 0 r
F
.53012 .99787 m .52557 .99125 L .53075 .99855 L F
.53012 .99787 m .53075 .99855 L .53253 1.00105 L F
.53137 .99969 m .52928 .99665 L .52931 .99669 L F
.53133 .99964 m .52948 .99695 L .53137 .99969 L F
.52948 .99695 m .52556 .99126 L .52949 .99696 L F
.52948 .99695 m .52949 .99696 L .53137 .99969 L F
.52931 .99669 m .52556 .99126 L .52557 .99125 L F
.52928 .99665 m .52556 .99126 L .52931 .99669 L F
.52852 .99506 m .52557 .99125 L .52577 .99094 L F
.53088 .99841 m .52577 .99094 L .52724 .99289 L F
.53494 1.00353 m .53297 1.01014 L .53892 1.00856 L 0 1 .417 r
F
.54043 1.01286 m .53012 .99745 L .53088 .99841 L 0 .239 0 r
F
.53012 .99745 m .52577 .99094 L .53088 .99841 L F
.53558 1.0014 m .52586 .99081 L .53292 .99512 L F
.5419 1.00542 m .53494 1.00353 L .54208 1.00771 L 0 1 .417 r
F
.53558 1.0014 m .53494 1.00353 L .5419 1.00542 L F
.53494 1.00353 m .53892 1.00856 L .54208 1.00771 L F
.53307 1.00015 m .53152 .99938 L .53273 1.00085 L F
.53152 .99938 m .53088 .99841 L .53558 1.0014 L 0 .239 0 r
F
.53088 .99841 m .52586 .99081 L .53558 1.0014 L F
.54031 .98554 m .53152 .99938 L .53307 1.00015 L 0 1 .417 r
F
.53558 1.0014 m .53273 1.00085 L .53494 1.00353 L F
.54031 .98554 m .53273 1.00085 L .53558 1.0014 L F
.54043 1.01286 m .53152 .99938 L .53558 1.0014 L 0 .239 0 r
F
.54031 .98554 m .53558 1.0014 L .5419 1.00542 L 0 1 .417 r
F
.52064 .99433 m .52092 .99808 L .52951 .99818 L 0 1 .511 r
F
.52064 .99433 m .52951 .99818 L .52927 .99671 L F
.53009 .99784 m .52946 .99716 L .52558 1.00326 L 0 1 .417 r
F
.54043 1.01286 m .53179 1.00069 L .52964 .99744 L 0 .239 0 r
F
.53022 .99803 m .52964 .99744 L .52556 .99126 L F
.54043 1.01286 m .52964 .99744 L .53022 .99803 L F
.52732 .99506 m .52494 .9946 L .52517 .99741 L 0 1 .458 r
F
.52724 .99289 m .52577 .99094 L .52586 .99081 L 0 .239 0 r
F
.53901 .98224 m .52789 .99444 L .53177 .99352 L 0 1 .458 r
F
.52789 .99444 m .52516 .99113 L .52826 .99559 L 0 0 .146 r
F
.52789 .99444 m .52732 .99506 L .52801 .99482 L 0 1 .458 r
F
.52789 .99444 m .52493 .99052 L .52516 .99113 L 0 0 .146 r
F
.52789 .99444 m .5281 .99479 L .53177 .99352 L 0 1 .458 r
F
.53901 .98224 m .52713 .99268 L .52789 .99444 L F
.52732 .99506 m .52806 .99571 L .53177 .99352 L F
.54031 .98554 m .53177 .99352 L .52946 .99716 L 0 1 .417 r
F
.54031 .98554 m .52946 .99716 L .53009 .99784 L F
.54031 .98554 m .53009 .99784 L .53152 .99938 L F
.54043 1.01286 m .53577 1.00185 L .54175 1.00351 L 0 .239 0 r
F
.53912 1.00805 m .52722 .99335 L .52789 .99444 L 0 0 .146 r
F
.52713 .99268 m .52686 .99291 L .52789 .99444 L 0 1 .458 r
F
.52686 .99291 m .52597 .99369 L .52789 .99444 L F
.52722 .99335 m .52686 .99291 L .52789 .99444 L 0 0 .146 r
F
.52686 .99291 m .52493 .99052 L .52789 .99444 L F
.52789 .99444 m .52801 .99482 L .5281 .99479 L 0 1 .458 r
F
.52789 .99444 m .52826 .99559 L .52861 .9961 L 0 0 .146 r
F
.53253 1.00105 m .53075 .99855 L .53112 .99895 L 0 .239 0 r
F
.54043 1.01286 m .53137 .99969 L .53253 1.00105 L F
.54043 1.01286 m .53133 .99964 L .53137 .99969 L F
.53912 1.00805 m .52789 .99444 L .53179 1.00069 L 0 0 .146 r
F
.52789 .99444 m .52861 .9961 L .53179 1.00069 L F
.52789 .99444 m .52597 .99369 L .52732 .99506 L 0 1 .458 r
F
.52597 .99369 m .52494 .9946 L .52732 .99506 L F
.52732 .99506 m .52517 .99741 L .52806 .99571 L F
.54043 1.01286 m .54175 1.00351 L .54832 1.01078 L 0 .239 0 r
F
.54175 1.00351 m .54205 1.00133 L .54414 1.00447 L F
.54175 1.00351 m .54414 1.00447 L .54832 1.01078 L F
.54175 1.00351 m .54414 1.00447 L .5443 1.00421 L 0 1 .417 r
F
.54031 .98554 m .54175 1.00351 L .54825 .99799 L F
.54175 1.00351 m .5443 1.00421 L .54825 .99799 L F
.53577 1.00185 m .53558 1.0014 L .54175 1.00351 L 0 .239 0 r
F
.54043 1.01286 m .54832 1.01078 L .54753 1.01719 L F
.55172 1.04131 m .54753 1.01732 L .54833 1.01107 L 0 .836 .089 r
F
.54791 1.01236 m .54979 1.02202 L .55112 1.02158 L 0 .31 .331 r
F
.56602 1.03474 m .55784 1.029 L .55233 1.03225 L 0 .619 .331 r
F
.5493 1.01942 m .55791 1.04665 L .55297 1.03118 L 0 .423 0 r
F
.5493 1.01942 m .56163 1.05656 L .55791 1.04665 L F
.5493 1.01942 m .56165 1.05424 L .56163 1.05656 L F
.5493 1.01942 m .55795 1.0424 L .56165 1.05424 L F
.55172 1.04131 m .54898 1.03028 L .54753 1.01732 L 0 .836 .089 r
F
.54791 1.01236 m .54722 1.01847 L .54979 1.02202 L 0 .31 .331 r
F
.53901 .98224 m .53177 .99352 L .54031 .98554 L 0 1 .458 r
F
.54791 1.01236 m .54481 1.01341 L .54722 1.01847 L 0 .31 .331 r
F
.54791 1.01236 m .54416 1.01021 L .54481 1.01341 L F
.54791 1.01236 m .54548 1.00976 L .54416 1.01021 L F
.54603 1.00429 m .54317 1.00557 L .54548 1.00976 L 0 .332 .342 r
F
.54603 1.00429 m .54251 1.00258 L .54317 1.00557 L F
.53514 .98795 m .53647 .99468 L .54152 .99819 L 0 .322 .328 r
F
.54603 1.00429 m .54374 1.00203 L .54251 1.00258 L 0 .332 .342 r
F
.53514 .98795 m .54152 .99819 L .54086 .99532 L 0 .322 .328 r
F
.53901 .98224 m .53087 .98809 L .5267 .99267 L 0 1 .458 r
F
.52686 .99291 m .5267 .99267 L .52494 .9946 L F
.53901 .98224 m .5267 .99267 L .52686 .99291 L F
.53912 1.00805 m .5309 .99776 L .5267 .99267 L 0 0 .146 r
F
.52062 .98385 m .5006 .98996 L .50922 .99189 L 0 1 .518 r
F
.52062 .98385 m .50079 .98695 L .5006 .98996 L F
.51979 .98674 m .50965 .98624 L .52007 .98845 L 0 .852 .406 r
F
.52062 .98385 m .50937 .98433 L .50079 .98695 L 0 1 .518 r
F
.51979 .98674 m .50198 .98376 L .50965 .98624 L 0 .852 .406 r
F
.51979 .98674 m .50217 .98266 L .50198 .98376 L F
.52034 .97574 m .50937 .98433 L .52062 .98385 L 0 1 .512 r
F
.52034 .97574 m .50107 .98233 L .50937 .98433 L F
.51979 .98674 m .50979 .98394 L .50217 .98266 L 0 .852 .406 r
F
.51922 .98655 m .52651 .98945 L .52626 .99004 L 0 .438 .279 r
F
.5195 .98616 m .51586 .98533 L .51979 .98674 L 0 .596 .34 r
F
.51586 .98533 m .50979 .98394 L .51651 .98582 L F
.51586 .98533 m .51651 .98582 L .51979 .98674 L F
.52034 .97574 m .50126 .97917 L .50107 .98233 L 0 1 .512 r
F
.5195 .98616 m .50263 .98021 L .50245 .98114 L 0 .596 .34 r
F
.5195 .98616 m .50994 .98236 L .50263 .98021 L F
.5195 .98616 m .50335 .98141 L .50979 .98394 L F
.50335 .98141 m .50245 .98114 L .50301 .98136 L F
.50335 .98141 m .50301 .98136 L .50979 .98394 L F
.52034 .97574 m .50951 .97635 L .50126 .97917 L 0 1 .512 r
F
.51056 .98248 m .5031 .97804 L .50291 .97888 L 0 .438 .279 r
F
.51922 .98655 m .50994 .98236 L .51236 .98332 L F
.51922 .98655 m .5154 .98453 L .5195 .98616 L F
.51222 .98285 m .51008 .98132 L .5031 .97804 L F
.51922 .98655 m .51008 .98132 L .51222 .98285 L F
.51008 .98132 m .51008 .98132 L .51222 .98285 L F
.51887 .98648 m .51008 .98132 L .51922 .98655 L 0 .324 .248 r
F
.51922 .98655 m .51188 .98267 L .51056 .98248 L 0 .438 .279 r
F
.51887 .98648 m .50375 .97677 L .51008 .98132 L 0 .324 .248 r
F
.50375 .97677 m .50342 .97656 L .51006 .98131 L F
.50375 .97677 m .51006 .98131 L .51008 .98132 L F
.51188 .98267 m .5031 .97804 L .51056 .98248 L 0 .438 .279 r
F
.51492 .98461 m .50291 .97888 L .50994 .98236 L F
.51922 .98655 m .51464 .98439 L .51492 .98461 L F
.51464 .98439 m .50291 .97888 L .51492 .98461 L F
.51887 .98648 m .51922 .98655 L .52586 .99081 L 0 .324 .248 r
F
.52576 .99009 m .52572 .99027 L .52577 .99025 L 0 1 .492 r
F
.52576 .99009 m .52577 .99025 L .53087 .98809 L F
.5195 .98616 m .51979 .98674 L .52711 .9889 L 0 .596 .34 r
F
.5195 .98616 m .52711 .9889 L .52687 .98897 L F
.51922 .98655 m .5195 .98616 L .52651 .98945 L 0 .438 .279 r
F
.52576 .99009 m .52435 .98755 L .52458 .98899 L 0 .184 .202 r
F
.53772 .98082 m .52576 .99009 L .53087 .98809 L 0 1 .492 r
F
.51887 .98648 m .52586 .99081 L .52556 .99126 L 0 .324 .248 r
F
.52529 .99045 m .52538 .99063 L .53087 .98809 L 0 1 .492 r
F
.52576 .99009 m .52458 .98899 L .52567 .9905 L 0 .184 .202 r
F
.5186 .98457 m .51887 .98648 L .52516 .99113 L 0 .311 .272 r
F
.5186 .98457 m .52516 .99113 L .52493 .99052 L F
.52576 .99009 m .52435 .98902 L .52459 .991 L 0 1 .492 r
F
.53772 .98082 m .52524 .98847 L .52576 .99009 L F
.52524 .98847 m .52435 .98755 L .52576 .99009 L 0 .184 .202 r
F
.52524 .98847 m .52435 .98902 L .52576 .99009 L 0 1 .492 r
F
.52573 .98897 m .52524 .98847 L .52576 .99009 L 0 .184 .202 r
F
.5378 1.00139 m .52573 .98897 L .52576 .99009 L F
.5378 1.00139 m .52576 .99009 L .5309 .99776 L F
.52576 .99009 m .52567 .9905 L .5309 .99776 L F
.52576 .99009 m .52529 .99045 L .52572 .99027 L 0 1 .492 r
F
.52529 .99045 m .52459 .991 L .52538 .99063 L F
.52686 .99291 m .5267 .99267 L .52601 .99182 L 0 0 .146 r
F
.52604 .99189 m .52601 .99182 L .52493 .99052 L F
.52686 .99291 m .52601 .99182 L .52604 .99189 L F
.53912 1.00805 m .5267 .99267 L .52686 .99291 L F
.53772 .98082 m .53087 .98809 L .53901 .98224 L 0 1 .492 r
F
.51832 .98099 m .5186 .98457 L .52458 .98899 L 0 .328 .31 r
F
.52034 .97574 m .52062 .98385 L .52888 .98103 L 0 1 .512 r
F
.51832 .98099 m .52458 .98899 L .52435 .98755 L 0 .328 .31 r
F
.53772 .98082 m .52998 .98465 L .52521 .98835 L 0 1 .492 r
F
.52524 .98847 m .52521 .98835 L .52435 .98902 L F
.53772 .98082 m .52521 .98835 L .52524 .98847 L F
.5378 1.00139 m .53 .99285 L .52521 .98835 L 0 .184 .202 r
F
.52524 .98847 m .52521 .98835 L .52435 .98755 L F
.5378 1.00139 m .52521 .98835 L .52524 .98847 L F
.53642 .97944 m .52998 .98465 L .53772 .98082 L 0 1 .48 r
F
.53642 .97944 m .52508 .98583 L .52998 .98465 L F
.52508 .98583 m .524 .98644 L .5249 .98617 L F
.52508 .98583 m .52376 .98302 L .524 .98499 L 0 .286 .291 r
F
.52508 .98583 m .52494 .98616 L .52998 .98465 L 0 1 .48 r
F
.52508 .98583 m .524 .98499 L .5249 .98617 L 0 .286 .291 r
F
.52508 .98583 m .52377 .98499 L .524 .98644 L 0 1 .48 r
F
.53642 .97944 m .52522 .98435 L .52508 .98583 L F
.52522 .98435 m .52377 .98499 L .52508 .98583 L F
.52557 .98468 m .52522 .98435 L .52508 .98583 L 0 .286 .291 r
F
.52522 .98435 m .52376 .98302 L .52508 .98583 L F
.53647 .99468 m .52557 .98468 L .52508 .98583 L F
.52508 .98583 m .5249 .98617 L .52494 .98616 L 0 1 .48 r
F
.53647 .99468 m .52508 .98583 L .53 .99285 L 0 .286 .291 r
F
.52508 .98583 m .5249 .98617 L .53 .99285 L F
.53381 .98108 m .53514 .98795 L .53987 .99104 L 0 .331 .34 r
F
.51805 .97623 m .51832 .98099 L .524 .98499 L 0 .35 .342 r
F
.51805 .97623 m .524 .98499 L .52376 .98302 L F
.53642 .97944 m .52909 .98199 L .52523 .98416 L 0 1 .48 r
F
.52522 .98435 m .52523 .98416 L .52377 .98499 L F
.53642 .97944 m .52523 .98416 L .52522 .98435 L F
.53647 .99468 m .5291 .98716 L .52523 .98416 L 0 .286 .291 r
F
.52522 .98435 m .52523 .98416 L .52376 .98302 L F
.53647 .99468 m .52523 .98416 L .52522 .98435 L F
.53511 .97806 m .52909 .98199 L .53642 .97944 L 0 1 .439 r
F
.52034 .97574 m .52888 .98103 L .52864 .97774 L 0 1 .512 r
F
.53511 .97806 m .52629 .98181 L .52909 .98199 L 0 1 .439 r
F
.52629 .98181 m .52341 .97982 L .52559 .98264 L 0 .322 .328 r
F
.52629 .98181 m .52341 .98304 L .52559 .98264 L 0 1 .439 r
F
.52629 .98181 m .52317 .97752 L .52341 .97982 L 0 .322 .328 r
F
.52629 .98181 m .52562 .98263 L .52909 .98199 L 0 1 .439 r
F
.52629 .98181 m .52318 .98189 L .52341 .98304 L F
.53511 .97806 m .52684 .98072 L .52629 .98181 L F
.52684 .98072 m .52317 .97752 L .52629 .98181 L 0 .322 .328 r
F
.52684 .98072 m .52318 .98189 L .52629 .98181 L 0 1 .439 r
F
.52705 .9809 m .52684 .98072 L .52629 .98181 L 0 .322 .328 r
F
.53514 .98795 m .52705 .9809 L .52629 .98181 L F
.52629 .98181 m .52559 .98264 L .52562 .98263 L 0 1 .439 r
F
.53514 .98795 m .52629 .98181 L .5291 .98716 L 0 .322 .328 r
F
.52629 .98181 m .52559 .98264 L .5291 .98716 L F
.52005 .96696 m .52034 .97574 L .52827 .97259 L 0 1 .505 r
F
.53511 .97806 m .52819 .97976 L .52707 .98024 L 0 1 .439 r
F
.52684 .98072 m .52708 .98023 L .52317 .97752 L 0 .322 .328 r
F
.52684 .98072 m .52707 .98024 L .52678 .98074 L 0 1 .439 r
F
.53511 .97806 m .52708 .98023 L .52684 .98072 L F
.52708 .98023 m .52707 .98024 L .52684 .98072 L F
.53514 .98795 m .52819 .981 L .52708 .98023 L 0 .322 .328 r
F
.53514 .98795 m .52708 .98023 L .52684 .98072 L F
.5338 .97672 m .52819 .97976 L .53511 .97806 L 0 1 .394 r
F
.5338 .97672 m .52935 .97817 L .52819 .97976 L F
.52935 .97817 m .52855 .97766 L .52842 .97895 L 0 .331 .34 r
F
.52855 .97766 m .52281 .97391 L .5273 .97983 L F
.52935 .97817 m .52732 .97985 L .52819 .97976 L 0 1 .394 r
F
.52855 .97766 m .5273 .97983 L .52757 .98018 L 0 .331 .34 r
F
.52838 .97927 m .52757 .98018 L .52819 .981 L F
.52855 .97766 m .52757 .98018 L .52838 .97927 L F
.52005 .96696 m .50951 .97635 L .52034 .97574 L 0 1 .505 r
F
.51777 .97068 m .51805 .97623 L .52341 .97982 L 0 .364 .362 r
F
.51777 .97068 m .52341 .97982 L .52317 .97752 L F
.52935 .97817 m .52259 .97935 L .52282 .98031 L 0 1 .394 r
F
.52935 .97817 m .52258 .9714 L .52281 .97391 L 0 .331 .34 r
F
.5338 .97672 m .52983 .97765 L .52935 .97817 L 0 1 .394 r
F
.53381 .98108 m .52983 .97765 L .52935 .97817 L 0 .331 .34 r
F
.52983 .97765 m .52258 .9714 L .52935 .97817 L F
.52983 .97765 m .52981 .97765 L .52935 .97817 L 0 1 .394 r
F
.52981 .97765 m .52259 .97935 L .52935 .97817 L F
.52935 .97817 m .52282 .98031 L .52732 .97985 L F
.53381 .98108 m .52935 .97817 L .52819 .981 L 0 .331 .34 r
F
.52935 .97817 m .52842 .97895 L .52819 .981 L F
.52678 .98074 m .52707 .98024 L .52318 .98189 L 0 1 .439 r
F
.53381 .98108 m .52819 .981 L .53514 .98795 L 0 .331 .34 r
F
.53005 .97992 m .53425 .98495 L .5374 .98912 L 0 .163 0 r
F
.53005 .97992 m .5374 .98912 L .53849 .99082 L F
.53005 .97992 m .53849 .99082 L .53669 .98867 L F
.53173 .98235 m .53669 .98867 L .54003 .99341 L 0 .182 0 r
F
.53173 .98235 m .54003 .99341 L .54101 .99516 L F
.53395 .98568 m .53399 .98585 L .53447 .98662 L 0 .1 .183 r
F
.53233 .98321 m .53889 .99245 L .53507 .98709 L 0 .182 0 r
F
.53231 .98318 m .53889 .99245 L .53233 .98321 L F
.53188 .98256 m .53889 .99245 L .53189 .98257 L F
.52005 .96696 m .52827 .97259 L .52802 .969 L 0 1 .505 r
F
.52983 .97765 m .52728 .97446 L .52258 .9714 L 0 .331 .34 r
F
.5338 .97672 m .53012 .97734 L .52983 .97765 L 0 1 .394 r
F
.53381 .98108 m .53012 .97734 L .52983 .97765 L 0 .331 .34 r
F
.53012 .97734 m .52728 .97446 L .52975 .97755 L F
.53247 .97398 m .52728 .97446 L .53012 .97734 L 0 .327 .341 r
F
.53281 .97578 m .53012 .97734 L .53015 .97733 L 0 1 .351 r
F
.53281 .97578 m .53015 .97733 L .5338 .97672 L F
.5338 .97672 m .53511 .97806 L .53981 .97652 L 0 1 .394 r
F
.5338 .97672 m .53981 .97652 L .53916 .97616 L F
.53334 .97548 m .5338 .97672 L .53819 .97562 L 0 1 .351 r
F
.53247 .97398 m .53281 .97578 L .53333 .97547 L 0 .327 .341 r
F
.53248 .97546 m .53281 .97578 L .53334 .97548 L 0 1 .351 r
F
.53281 .97578 m .5338 .97672 L .53334 .97548 L F
.53334 .97548 m .53381 .98108 L .53822 .98389 L 0 .327 .341 r
F
.53352 .97542 m .53819 .97562 L .53753 .97526 L 0 1 .351 r
F
.53333 .97547 m .53334 .97549 L .53334 .97548 L 0 .327 .341 r
F
.53334 .97548 m .53819 .97562 L .53352 .97542 L 0 1 .351 r
F
.53511 .97806 m .53642 .97944 L .54143 .9773 L 0 1 .439 r
F
.53511 .97806 m .54143 .9773 L .54078 .97701 L F
.53351 .97542 m .53822 .98389 L .53756 .98099 L 0 .327 .341 r
F
.53247 .97398 m .53334 .97548 L .53351 .97542 L F
.53351 .97542 m .53334 .97548 L .53352 .97542 L 0 1 .351 r
F
.53334 .97548 m .53822 .98389 L .53351 .97542 L 0 .327 .341 r
F
.53248 .97546 m .53334 .97548 L .53351 .97542 L 0 1 .351 r
F
.53334 .97549 m .53334 .97549 L .53334 .97548 L 0 .327 .341 r
F
.53334 .97549 m .53381 .98108 L .53334 .97548 L F
.53281 .97578 m .53381 .98108 L .53333 .97547 L F
.53281 .97578 m .53012 .97734 L .53381 .98108 L F
.53247 .97398 m .53012 .97734 L .53281 .97578 L F
.53281 .97577 m .53012 .97734 L .53281 .97578 L 0 1 .351 r
F
.53248 .97546 m .52729 .97781 L .53012 .97734 L F
.53248 .97546 m .53012 .97734 L .53281 .97577 L F
.53012 .97734 m .52975 .97755 L .52983 .97765 L 0 .331 .34 r
F
.52983 .97765 m .52729 .97781 L .52259 .97935 L 0 1 .394 r
F
.53012 .97734 m .52729 .97781 L .52983 .97765 L F
.53247 .97398 m .52222 .96748 L .52728 .97446 L 0 .327 .341 r
F
.51976 .95729 m .52005 .96696 L .52765 .96329 L 0 1 .496 r
F
.53247 .97398 m .52198 .96477 L .52222 .96748 L 0 .327 .341 r
F
.53248 .97546 m .52223 .97801 L .52729 .97781 L 0 1 .351 r
F
.53248 .97546 m .522 .97718 L .52223 .97801 L F
.53248 .97546 m .52638 .97609 L .522 .97718 L F
.53109 .97427 m .52638 .97608 L .53248 .97546 L 0 .916 .309 r
F
.53109 .97427 m .52163 .97599 L .52638 .97608 L F
.53109 .97427 m .52138 .97524 L .52163 .97599 L F
.53109 .97427 m .52544 .9745 L .52138 .97524 L F
.5297 .97325 m .52544 .9745 L .53109 .97427 L 0 .751 .269 r
F
.5297 .97325 m .52101 .97418 L .52544 .9745 L F
.52005 .96696 m .50154 .97432 L .50951 .97635 L 0 1 .505 r
F
.52005 .96696 m .50173 .971 L .50154 .97432 L F
.52005 .96696 m .50966 .96784 L .50173 .971 L F
.51976 .95729 m .50966 .96784 L .52005 .96696 L 0 1 .496 r
F
.51749 .96455 m .51777 .97068 L .52281 .97391 L 0 .379 .37 r
F
.51749 .96455 m .52281 .97391 L .52258 .9714 L F
.5297 .97325 m .52076 .97353 L .52101 .97418 L 0 .751 .269 r
F
.5297 .97325 m .52448 .97313 L .52076 .97353 L F
.52824 .97238 m .52448 .97313 L .5297 .97325 L 0 .673 .251 r
F
.52824 .97238 m .52037 .97262 L .52448 .97313 L F
.52824 .97238 m .52011 .97205 L .52037 .97262 L F
.52824 .97238 m .52348 .97194 L .52011 .97205 L F
.52677 .97171 m .52348 .97194 L .52824 .97238 L 0 .594 .239 r
F
.52677 .97171 m .51972 .97127 L .52348 .97194 L F
.52677 .97171 m .51946 .97081 L .51972 .97127 L F
.52677 .97171 m .52248 .97099 L .51946 .97081 L F
.52529 .97122 m .52248 .97099 L .52677 .97171 L 0 .503 .224 r
F
.52529 .97122 m .52677 .97171 L .52944 .97216 L F
.52529 .97122 m .52944 .97216 L .52871 .97204 L F
.52381 .97086 m .52529 .97122 L .52762 .97189 L 0 .407 .208 r
F
.52381 .97086 m .52762 .97189 L .52688 .97181 L F
.52605 .97228 m .52711 .97203 L .52815 .9724 L 0 0 0 r
F
.52605 .97228 m .52578 .97169 L .52711 .97203 L F
.52605 .97228 m .52815 .9724 L .52827 .97266 L F
.52605 .97228 m .52827 .97266 L .52739 .97263 L F
.52868 .97494 m .52606 .97249 L .52886 .97368 L F
.52868 .97494 m .52517 .97233 L .52606 .97249 L F
.52868 .97494 m .52629 .97338 L .52517 .97233 L F
.52561 .9739 m .52629 .97338 L .52868 .97494 L F
.52561 .9739 m .52868 .97494 L .52944 .9758 L F
.52561 .9739 m .52944 .9758 L .52807 .97538 L F
.5303 .97795 m .52807 .97538 L .52944 .9758 L 0 .068 0 r
F
.5303 .97795 m .52844 .9763 L .52807 .97538 L F
.52605 .975 m .52844 .9763 L .5303 .97795 L 0 .07 0 r
F
.52605 .975 m .5303 .97795 L .53032 .97825 L F
.53381 .98108 m .53987 .99104 L .53921 .9882 L 0 .331 .34 r
F
.52944 .97872 m .53303 .9805 L .53482 .98225 L 0 .142 0 r
F
.52944 .97872 m .53032 .97825 L .53303 .9805 L F
.52605 .975 m .53032 .97825 L .52848 .97702 L 0 .07 0 r
F
.52944 .97872 m .52848 .97702 L .53032 .97825 L 0 .142 0 r
F
.52944 .97872 m .53482 .98225 L .53445 .98246 L F
.52944 .97872 m .53445 .98246 L .53216 .98097 L F
.52619 .97477 m .5314 .98103 L .53267 .98259 L 0 .101 0 r
F
.52944 .97872 m .5281 .97722 L .52848 .97702 L 0 .142 0 r
F
.52252 .97139 m .52561 .9739 L .52601 .97429 L 0 .01 .142 r
F
.52605 .975 m .52601 .97429 L .52844 .9763 L 0 .07 0 r
F
.52252 .97139 m .52601 .97429 L .52464 .97324 L 0 .01 .142 r
F
.52404 .97211 m .52944 .97872 L .52873 .97777 L 0 0 .133 r
F
.52619 .97477 m .52873 .97777 L .5314 .98103 L 0 .101 0 r
F
.52619 .97477 m .53267 .98259 L .53158 .98131 L F
.5282 .97738 m .53451 .98499 L .53569 .98663 L 0 .136 0 r
F
.5282 .97738 m .53158 .98131 L .53451 .98499 L F
.52404 .97211 m .5281 .97722 L .52944 .97872 L 0 0 .133 r
F
.52619 .97477 m .53158 .98131 L .52886 .97803 L 0 .101 0 r
F
.5282 .97738 m .52886 .97803 L .53158 .98131 L 0 .136 0 r
F
.5282 .97738 m .53569 .98663 L .53425 .98495 L F
.5282 .97738 m .53425 .98495 L .53113 .98107 L F
.53005 .97992 m .53113 .98107 L .53425 .98495 L 0 .163 0 r
F
.53005 .97992 m .53669 .98867 L .53321 .9841 L F
.53173 .98235 m .53321 .9841 L .53669 .98867 L 0 .182 0 r
F
.53173 .98235 m .53108 .98139 L .53321 .9841 L F
.53173 .98235 m .54101 .99516 L .53889 .99245 L F
.53349 .985 m .53507 .98709 L .53889 .99245 L 0 .192 0 r
F
.53321 .98461 m .53344 .98492 L .53349 .985 L F
.53344 .98492 m .53507 .98709 L .53349 .985 L F
.54415 .99685 m .54374 1.00203 L .54603 1.00429 L 0 .329 .337 r
F
.54415 .99685 m .54153 .99819 L .54374 1.00203 L F
.54415 .99685 m .54087 .99532 L .54153 .99819 L F
.53447 .98662 m .54443 1.00227 L .54516 1.00406 L 0 .196 0 r
F
.53533 .988 m .53512 .98768 L .5355 .98831 L 0 .101 .187 r
F
.53267 .98259 m .5314 .98103 L .53216 .98097 L 0 .204 0 r
F
.53321 .98461 m .53264 .98373 L .53313 .98441 L 0 .192 0 r
F
.53347 .98495 m .53313 .98441 L .53507 .98709 L F
.53321 .98461 m .53313 .98441 L .53347 .98495 L F
.53624 .98948 m .53601 .98913 L .53629 .98958 L 0 .097 .188 r
F
.53247 .97398 m .52637 .96755 L .52198 .96477 L 0 .327 .341 r
F
.53107 .96616 m .52637 .96755 L .53247 .97398 L 0 .316 .336 r
F
.52677 .97171 m .52824 .97238 L .53126 .97256 L 0 .594 .239 r
F
.52677 .97171 m .53126 .97256 L .53054 .97238 L F
.53321 .98461 m .53889 .99245 L .54239 .99781 L 0 .192 0 r
F
.53371 .98538 m .54081 .99623 L .53671 .98997 L F
.53321 .98461 m .5337 .98535 L .53371 .98538 L F
.5337 .98535 m .54081 .99623 L .53371 .98538 L F
.53587 .98877 m .53589 .9889 L .53624 .98948 L 0 .097 .188 r
F
.53321 .98461 m .54325 .9996 L .54081 .99623 L 0 .192 0 r
F
.53321 .98461 m .54239 .99781 L .54325 .9996 L F
.5247 .96779 m .53559 .98833 L .53587 .98877 L 0 .097 .188 r
F
.53447 .98662 m .54081 .99623 L .54443 1.00227 L 0 .196 0 r
F
.53559 .98833 m .53589 .9889 L .53587 .98877 L 0 .097 .188 r
F
.53589 .9889 m .53601 .98913 L .53624 .98948 L F
.53447 .98662 m .53671 .98997 L .54081 .99623 L 0 .196 0 r
F
.52431 .96772 m .53498 .98743 L .53533 .988 L 0 .101 .187 r
F
.53498 .98743 m .53512 .98768 L .53533 .988 L F
.5238 .96742 m .53363 .9852 L .53395 .98568 L 0 .1 .183 r
F
.53363 .9852 m .53399 .98585 L .53395 .98568 L F
.53189 .98257 m .53231 .98318 L .53233 .98321 L 0 .182 0 r
F
.53173 .98235 m .53188 .98256 L .53189 .98257 L F
.53301 .98426 m .53264 .98373 L .53321 .98461 L 0 .098 .183 r
F
.52318 .96691 m .53256 .98358 L .53301 .98426 L F
.53256 .98358 m .53264 .98373 L .53301 .98426 L F
.53447 .98662 m .54516 1.00406 L .54244 .99993 L 0 .196 0 r
F
.53447 .98662 m .54244 .99993 L .53809 .99265 L F
.5355 .98831 m .53809 .99265 L .54244 .99993 L 0 0 .104 r
F
.54603 1.00429 m .54548 1.00976 L .54791 1.01236 L 0 .332 .342 r
F
.54342 1.00383 m .54795 1.01241 L .54475 1.00647 L 0 0 .111 r
F
.54462 1.00649 m .54475 1.00647 L .5485 1.01455 L 0 0 .117 r
F
.53557 .98843 m .54218 1.00025 L .54256 1.00121 L 0 0 .104 r
F
.54209 1.00057 m .54376 1.0034 L .54469 1.0055 L 0 0 .111 r
F
.53555 .9884 m .54398 1.00346 L .53557 .98843 L 0 0 .104 r
F
.54398 1.00346 m .54674 1.00839 L .54398 1.00346 L F
.54398 1.00346 m .54398 1.00346 L .53557 .98843 L F
.54418 1.00625 m .5488 1.01583 L .54539 1.00889 L 0 0 .117 r
F
.53557 .98844 m .54256 1.00121 L .5392 .99505 L 0 0 .104 r
F
.5355 .98831 m .53512 .98768 L .53809 .99265 L F
.5355 .98831 m .53555 .9884 L .53557 .98843 L F
.5355 .98831 m .53557 .98843 L .53557 .98844 L F
.53557 .98843 m .54256 1.00121 L .53557 .98844 L F
.5355 .98831 m .54615 1.00668 L .54674 1.00839 L F
.5405 .99798 m .54351 1.00371 L .54342 1.00383 L 0 0 .111 r
F
.53629 .98958 m .54076 .99833 L .5405 .99798 L F
.54076 .99833 m .54351 1.00371 L .5405 .99798 L F
.5355 .98831 m .54244 .99993 L .54368 1.00219 L 0 0 .104 r
F
.5431 1.00142 m .54368 1.00219 L .54615 1.00668 L F
.53632 .98963 m .5405 .99798 L .54004 .997 L 0 0 .111 r
F
.5405 .99798 m .54342 1.00383 L .54109 .99912 L F
.5405 .99798 m .54109 .99912 L .54004 .997 L F
.53554 .98838 m .54368 1.00219 L .5431 1.00142 L 0 0 .104 r
F
.5355 .98831 m .53554 .98837 L .53554 .98838 L F
.53554 .98837 m .54368 1.00219 L .53554 .98838 L F
.53629 .98958 m .53601 .98913 L .5392 .99505 L 0 0 .111 r
F
.53629 .98958 m .53632 .98963 L .53632 .98963 L F
.53632 .98963 m .54277 1.00252 L .53632 .98963 L F
.54277 1.00252 m .54277 1.00252 L .53632 .98963 L F
.5422 1.00144 m .54258 1.00204 L .54279 1.00268 L 0 0 .117 r
F
.53629 .98958 m .5392 .99505 L .54376 1.0034 L 0 0 .111 r
F
.53629 .98958 m .54187 .99991 L .53637 .98972 L F
.54603 1.00429 m .54791 1.01236 L .54914 1.01182 L 0 .332 .342 r
F
.53629 .98958 m .54751 1.01085 L .54795 1.01241 L 0 0 .111 r
F
.53629 .98958 m .54187 .99991 L .54187 .99991 L F
.54256 1.00121 m .54242 1.00095 L .5392 .99505 L 0 0 .104 r
F
.53637 .98972 m .54187 .99991 L .54209 1.00057 L 0 0 .111 r
F
.53684 .99031 m .54004 .997 L .54249 1.00194 L 0 0 .117 r
F
.53684 .99031 m .54249 1.00194 L .5422 1.00128 L F
.54053 .99786 m .54416 1.0053 L .54386 1.00466 L F
.53684 .99031 m .54056 .99793 L .54053 .99786 L F
.54056 .99793 m .54416 1.0053 L .54053 .99786 L F
.53717 .99101 m .54182 1.0005 L .5422 1.00144 L F
.53725 .99115 m .54182 1.00049 L .53717 .99101 L F
.54182 1.00049 m .54258 1.00204 L .54182 1.0005 L F
.54182 1.00049 m .54182 1.0005 L .53717 .99101 L F
.54426 1.00693 m .54569 1.01035 L .5482 1.01643 L 0 0 .125 r
F
.54384 1.00552 m .54416 1.00593 L .54418 1.00625 L 0 0 .117 r
F
.53647 .99468 m .54317 1.00557 L .54251 1.00258 L 0 .286 .291 r
F
.53684 .99031 m .53665 .99009 L .54004 .997 L 0 0 .117 r
F
.53684 .99031 m .54325 1.004 L .54384 1.00552 L F
.54325 1.004 m .54416 1.00593 L .54384 1.00552 L F
.53684 .99031 m .5485 1.01455 L .5488 1.01583 L F
.54211 1.00155 m .54253 1.00262 L .54539 1.00889 L 0 0 .122 r
F
.53712 .9904 m .54058 .99836 L .54253 1.00262 L F
.53712 .9904 m .54253 1.00262 L .54211 1.00155 L F
.54133 .9998 m .54134 .99985 L .53795 .99227 L F
.54389 1.0063 m .54845 1.01733 L .54562 1.01054 L 0 0 .125 r
F
.54384 1.00552 m .54368 1.00514 L .54253 1.00262 L 0 0 .117 r
F
.54256 1.00272 m .54253 1.00262 L .54058 .99836 L F
.54384 1.00552 m .54253 1.00262 L .54256 1.00272 L F
.53839 .99201 m .5392 .99407 L .53829 .99176 L 0 0 .127 r
F
.53684 .99031 m .54264 1.00291 L .54058 .99836 L 0 0 .117 r
F
.53712 .9904 m .53704 .99045 L .54058 .99836 L 0 0 .122 r
F
.53747 .99122 m .54466 1.00774 L .53743 .99113 L F
.54466 1.00774 m .54467 1.00778 L .53743 .99113 L F
.53811 .99261 m .54129 .99973 L .53795 .99227 L F
.54129 .99973 m .54133 .9998 L .53795 .99227 L F
.53743 .99113 m .5437 1.00555 L .54569 1.01035 L F
.54077 .99862 m .54297 1.00347 L .54311 1.00391 L F
.53795 .99227 m .54044 .99783 L .54077 .99862 L F
.54044 .99783 m .54297 1.00347 L .54077 .99862 L F
.54264 1.00291 m .54384 1.00552 L .54256 1.00272 L 0 0 .117 r
F
.54318 1.00395 m .5432 1.00399 L .54134 .99985 L 0 0 .122 r
F
.5437 1.00555 m .54925 1.01831 L .54569 1.01035 L F
.54342 1.00383 m .54372 1.0044 L .54004 .997 L 0 0 .111 r
F
.53712 .9904 m .53747 .99122 L .53743 .99113 L 0 0 .122 r
F
.53712 .9904 m .54245 1.00282 L .54082 .99892 L F
.54245 1.00282 m .54569 1.01035 L .54225 1.00227 L F
.54245 1.00282 m .54225 1.00227 L .54082 .99892 L F
.54264 1.00291 m .54256 1.00272 L .54058 .99836 L 0 0 .117 r
F
.53712 .9904 m .54911 1.01745 L .54925 1.01831 L 0 0 .122 r
F
.53714 .98974 m .54082 .99892 L .54097 .99928 L 0 0 .125 r
F
.54012 .99693 m .54097 .99928 L .54569 1.01035 L F
.53714 .98974 m .54097 .99928 L .54012 .99693 L F
.54259 1.00303 m .54933 1.01915 L .5493 1.01942 L F
.53714 .98974 m .5407 .99833 L .54259 1.00303 L F
.5407 .99833 m .54933 1.01915 L .54259 1.00303 L F
.54376 1.00589 m .54838 1.01716 L .54377 1.00591 L F
.54838 1.01716 m .54839 1.01719 L .53805 .99197 L F
.54377 1.00591 m .54845 1.01733 L .54389 1.0063 L F
.54318 1.00395 m .54134 .99985 L .54133 .9998 L 0 0 .122 r
F
.54346 1.00499 m .54569 1.01035 L .5435 1.00508 L 0 0 .125 r
F
.5435 1.00508 m .54569 1.01035 L .54426 1.00693 L F
.54129 .99973 m .54318 1.00395 L .54133 .9998 L 0 0 .122 r
F
.53777 .99046 m .54562 1.01054 L .54914 1.01925 L 0 0 .127 r
F
.5369 .98824 m .53788 .99075 L .53777 .99046 L F
.53788 .99075 m .54562 1.01054 L .53777 .99046 L F
.53876 .99294 m .54681 1.01331 L .5452 1.00914 L F
.5369 .98824 m .53891 .99333 L .53876 .99294 L F
.53891 .99333 m .54681 1.01331 L .53876 .99294 L F
.54845 1.01733 m .5486 1.01773 L .54562 1.01054 L 0 0 .125 r
F
.54681 1.01331 m .54895 1.01875 L .54726 1.0144 L 0 0 .127 r
F
.54681 1.01331 m .54726 1.0144 L .5452 1.00914 L F
.53831 .9926 m .54376 1.00589 L .53821 .99235 L 0 0 .125 r
F
.54376 1.00589 m .54377 1.00591 L .53821 .99235 L F
.54311 1.00391 m .5432 1.00399 L .54363 1.00508 L 0 0 .122 r
F
.54297 1.00347 m .5432 1.00399 L .54311 1.00391 L F
.5392 .99407 m .54914 1.01925 L .53913 .99389 L 0 0 .127 r
F
.5392 .99407 m .53913 .99389 L .53829 .99176 L F
.53908 .99377 m .54914 1.01925 L .54895 1.01875 L F
.53829 .99176 m .53913 .99389 L .53908 .99377 L F
.53913 .99389 m .54914 1.01925 L .53908 .99377 L F
.54384 1.00552 m .54539 1.00889 L .54368 1.00514 L 0 0 .117 r
F
.53811 .99209 m .53831 .9926 L .53805 .99197 L 0 0 .125 r
F
.53831 .9926 m .53821 .99235 L .53805 .99197 L F
.54466 1.00774 m .54925 1.01831 L .54467 1.00778 L 0 0 .122 r
F
.54838 1.01716 m .5493 1.01942 L .54839 1.01719 L 0 0 .125 r
F
.53805 .99197 m .54377 1.00591 L .54389 1.0063 L F
.5369 .98824 m .53839 .99201 L .53829 .99176 L 0 0 .127 r
F
.54845 1.01733 m .5493 1.01942 L .5486 1.01773 L 0 0 .125 r
F
.53827 .99246 m .54346 1.00499 L .53821 .99231 L F
.54346 1.00499 m .5435 1.00508 L .53821 .99231 L F
.53821 .99231 m .5435 1.00508 L .54426 1.00693 L F
.54318 1.00395 m .54539 1.00889 L .5432 1.00399 L 0 0 .122 r
F
.5482 1.01643 m .54569 1.01035 L .54933 1.01915 L 0 0 .125 r
F
.53714 .98974 m .53827 .99246 L .53821 .99231 L F
.53714 .98974 m .53811 .99209 L .53805 .99197 L F
.5422 1.00128 m .54249 1.00194 L .54416 1.0053 L 0 0 .117 r
F
.54386 1.00466 m .54416 1.0053 L .54475 1.00647 L F
.54182 1.0005 m .54258 1.00204 L .5422 1.00144 L F
.54363 1.00508 m .54539 1.00889 L .54911 1.01745 L 0 0 .122 r
F
.5432 1.00399 m .54539 1.00889 L .54363 1.00508 L F
.53712 .9904 m .53811 .99261 L .53795 .99227 L F
.54277 1.00252 m .54342 1.00383 L .54277 1.00252 L 0 0 .111 r
F
.53684 .99031 m .53725 .99115 L .53717 .99101 L 0 0 .117 r
F
.54256 1.00121 m .54304 1.00178 L .54376 1.0034 L 0 0 .104 r
F
.54256 1.00121 m .54376 1.0034 L .54242 1.00095 L F
.54416 1.00593 m .5488 1.01583 L .54418 1.00625 L 0 0 .117 r
F
.54187 .99991 m .54376 1.0034 L .54209 1.00057 L 0 0 .111 r
F
.54342 1.00383 m .54475 1.00647 L .54372 1.0044 L F
.54279 1.00268 m .5441 1.00515 L .54462 1.00649 L 0 0 .117 r
F
.54258 1.00204 m .5441 1.00515 L .54279 1.00268 L F
.5441 1.00515 m .54475 1.00647 L .54462 1.00649 L F
.54218 1.00025 m .54304 1.00178 L .54256 1.00121 L 0 0 .104 r
F
.54304 1.00178 m .54387 1.00327 L .54376 1.0034 L F
.54469 1.0055 m .54376 1.0034 L .54751 1.01085 L 0 0 .111 r
F
.54351 1.00371 m .54795 1.01241 L .54342 1.00383 L F
.54387 1.00327 m .54674 1.00839 L .54376 1.0034 L 0 0 .104 r
F
.54895 1.01875 m .56122 1.06007 L .55735 1.04803 L 0 .394 0 r
F
.54895 1.01875 m .56145 1.05906 L .56122 1.06007 L F
.55236 1.02972 m .55791 1.04665 L .56145 1.05906 L F
.55744 1.04859 m .55735 1.04803 L .5607 1.06013 L 0 0 .069 r
F
.54895 1.01875 m .54914 1.01925 L .55121 1.02569 L 0 .394 0 r
F
.55105 1.02523 m .55121 1.02569 L .55297 1.03118 L F
.54895 1.01875 m .55121 1.02569 L .55105 1.02523 L F
.54895 1.01875 m .55735 1.04803 L .55246 1.03104 L F
.55179 1.02758 m .55297 1.03118 L .55791 1.04665 L F
.54895 1.01875 m .55238 1.02936 L .55179 1.02758 L F
.55238 1.02936 m .55297 1.03118 L .55179 1.02758 L F
.54965 1.02118 m .55876 1.05389 L .55629 1.04534 L 0 0 .069 r
F
.54895 1.01875 m .55087 1.02472 L .55138 1.02659 L 0 .394 0 r
F
.54821 1.01592 m .54855 1.01732 L .55246 1.03104 L 0 0 .069 r
F
.54821 1.01592 m .54975 1.02148 L .54965 1.02118 L F
.54975 1.02148 m .55876 1.05389 L .54965 1.02118 L F
.54821 1.01592 m .55246 1.03104 L .55735 1.04803 L F
.54993 1.02203 m .55528 1.04076 L .55744 1.04859 L F
.54821 1.01592 m .55001 1.02225 L .54993 1.02203 L F
.55001 1.02225 m .55528 1.04076 L .54993 1.02203 L F
.55528 1.04076 m .55735 1.04803 L .55744 1.04859 L F
.55138 1.02659 m .55179 1.02758 L .55236 1.02972 L 0 .394 0 r
F
.55087 1.02472 m .55179 1.02758 L .55138 1.02659 L F
.55179 1.02758 m .55791 1.04665 L .55236 1.02972 L F
.55876 1.05389 m .56024 1.0592 L .55925 1.05572 L 0 0 .069 r
F
.55876 1.05389 m .55925 1.05572 L .55629 1.04534 L F
.56252 1.07109 m .57318 1.12141 L .57265 1.1238 L 0 .554 .01 r
F
.56024 1.0592 m .56216 1.06842 L .56252 1.07109 L F
.56216 1.06842 m .57318 1.12141 L .56252 1.07109 L F
.57075 1.11967 m .57806 1.18714 L .579 1.20318 L 0 .634 .042 r
F
.57806 1.18714 m .58097 1.21404 L .57926 1.20517 L F
.58097 1.21404 m .58228 1.22607 L .58121 1.2187 L F
.57563 1.2788 m .58382 1.278 L .58609 1.29495 L 0 .881 .12 r
F
.57563 1.2788 m .58609 1.29495 L .58458 1.30243 L F
.58003 1.3205 m .58458 1.30243 L .58931 1.32312 L 0 .897 .137 r
F
.58003 1.3205 m .58931 1.32312 L .59133 1.34376 L F
.58003 1.3205 m .59133 1.34376 L .58939 1.35163 L F
.58385 1.36951 m .59418 1.37844 L .59596 1.40409 L 0 .908 .151 r
F
.59032 1.38277 m .58364 1.26564 L .5904 1.38404 L 0 .66 .042 r
F
.58064 1.21229 m .58086 1.21623 L .57926 1.20517 L 0 .634 .042 r
F
.58228 1.22607 m .58239 1.22904 L .58133 1.22097 L F
.58121 1.2187 m .58133 1.22097 L .57926 1.20517 L F
.58228 1.22607 m .58133 1.22097 L .58121 1.2187 L F
.59018 1.3817 m .58879 1.35779 L .58406 1.27385 L 0 .66 .042 r
F
.58879 1.35779 m .58876 1.35713 L .58406 1.27385 L F
.58406 1.27385 m .58877 1.35741 L .58433 1.281 L F
.58097 1.21404 m .58121 1.2187 L .58086 1.21623 L 0 .634 .042 r
F
.58097 1.21404 m .58086 1.21623 L .58064 1.21229 L F
.57806 1.18714 m .57926 1.20517 L .579 1.20318 L F
.58141 1.21809 m .58457 1.23519 L .58361 1.23839 L F
.57075 1.11967 m .58068 1.20266 L .58141 1.21809 L F
.58068 1.20266 m .58457 1.23519 L .58141 1.21809 L F
.5904 1.38404 m .5838 1.26844 L .59065 1.38542 L 0 .66 .042 r
F
.5793 1.19794 m .58176 1.22605 L .58026 1.20646 L 0 .548 0 r
F
.57941 1.20239 m .58176 1.22605 L .5793 1.19794 L F
.57462 1.15967 m .57947 1.20477 L .57663 1.17434 L F
.57947 1.20477 m .58176 1.22605 L .57941 1.20239 L F
.57947 1.20477 m .57941 1.20239 L .57663 1.17434 L F
.58066 1.21579 m .58076 1.21772 L .58108 1.22038 L F
.58102 1.21948 m .58108 1.22038 L .58128 1.22208 L F
.58066 1.21579 m .58108 1.22038 L .58102 1.21948 L F
.58066 1.21579 m .58128 1.22208 L .58124 1.22141 L F
.58119 1.2207 m .58143 1.22331 L .58135 1.22218 L F
.58066 1.21579 m .58124 1.22141 L .58119 1.2207 L F
.58124 1.22141 m .58143 1.22331 L .58119 1.2207 L F
.58024 1.25465 m .57852 1.22977 L .58204 1.22966 L 0 .798 .124 r
F
.5839 1.27074 m .58058 1.21201 L .58364 1.26564 L 0 .66 .042 r
F
.58058 1.21201 m .58026 1.20646 L .58059 1.2122 L F
.58058 1.21201 m .58059 1.2122 L .58364 1.26564 L F
.58364 1.26564 m .58059 1.2122 L .58333 1.26023 L F
.58059 1.2122 m .58026 1.20646 L .5806 1.21237 L F
.58059 1.2122 m .5806 1.21237 L .58333 1.26023 L F
.5839 1.27074 m .58406 1.27385 L .58057 1.21192 L F
.58058 1.21201 m .58057 1.21192 L .58026 1.20646 L F
.5839 1.27074 m .58057 1.21192 L .58058 1.21201 L F
.58124 1.22141 m .58128 1.22208 L .58143 1.22331 L 0 .548 0 r
F
.5838 1.26844 m .5806 1.21237 L .58354 1.26282 L 0 .66 .042 r
F
.5806 1.21237 m .58026 1.20646 L .58062 1.21269 L F
.5806 1.21237 m .58062 1.21269 L .58354 1.26282 L F
.58135 1.22218 m .58143 1.22331 L .58176 1.22605 L 0 .548 0 r
F
.5838 1.26844 m .58354 1.26282 L .59065 1.38542 L 0 .66 .042 r
F
.59018 1.3817 m .58406 1.27385 L .5839 1.27074 L F
.58364 1.26564 m .58333 1.26023 L .5904 1.38404 L F
.59018 1.3817 m .5839 1.27074 L .59032 1.38277 L F
.5839 1.27074 m .58364 1.26564 L .59032 1.38277 L F
.58026 1.20646 m .58406 1.27385 L .58321 1.26174 L F
.58406 1.27385 m .58433 1.281 L .58321 1.26174 L F
.58228 1.22607 m .58361 1.23839 L .58239 1.22904 L 0 .634 .042 r
F
.57377 1.11531 m .58668 1.18265 L .58263 1.17245 L 0 .866 .108 r
F
.58186 1.18641 m .57736 1.16716 L .58003 1.16448 L 0 .601 .1 r
F
.58186 1.18641 m .57814 1.17654 L .57736 1.16716 L F
.57265 1.1238 m .58567 1.2215 L .58132 1.20024 L 0 .858 .085 r
F
.57265 1.1238 m .58618 1.20654 L .58567 1.2215 L F
.57265 1.1238 m .58263 1.17245 L .58618 1.20654 L F
.57429 1.13179 m .57745 1.14215 L .58263 1.17245 L F
.57265 1.1238 m .5741 1.12937 L .57429 1.13179 L F
.5741 1.12937 m .57745 1.14215 L .57429 1.13179 L F
.5751 1.16087 m .5793 1.19794 L .57678 1.17324 L 0 .548 0 r
F
.5793 1.19794 m .58024 1.20622 L .5793 1.19726 L F
.5793 1.19794 m .5793 1.19726 L .57678 1.17324 L F
.57638 1.039 m .57638 1.03904 L .57638 1.03902 L 0 0 .096 r
F
.56924 1.03668 m .57632 1.03863 L .57686 1.04221 L 0 .491 .102 r
F
.56602 1.03474 m .56877 1.04896 L .57429 1.04571 L 0 .619 .331 r
F
.56602 1.03474 m .57429 1.04571 L .57308 1.04191 L F
.57139 1.05011 m .57341 1.04146 L .57693 1.04265 L 0 .545 .109 r
F
.57323 1.02201 m .57357 1.02348 L .57359 1.02359 L 0 .511 0 r
F
.56652 1.02518 m .57345 1.02224 L .57418 1.02577 L 0 .435 .092 r
F
.56924 1.03668 m .57672 1.04211 L .57341 1.04146 L 0 .491 .102 r
F
.57295 1.06551 m .57899 1.0611 L .57961 1.06799 L 0 .601 .12 r
F
.57139 1.05011 m .57719 1.04989 L .57802 1.05409 L 0 .545 .109 r
F
.57295 1.06551 m .57901 1.05931 L .5792 1.06095 L 0 .601 .12 r
F
.57139 1.05011 m .57894 1.0587 L .57553 1.05684 L 0 .545 .109 r
F
.57295 1.06551 m .57908 1.0678 L .5797 1.07315 L 0 .601 .12 r
F
.56652 1.02518 m .57286 1.01906 L .57357 1.02219 L 0 .435 .092 r
F
.56341 .98347 m .56715 .99718 L .5676 .99836 L 0 0 .086 r
F
.56353 .99878 m .56713 .99719 L .5676 .99836 L 0 .247 .049 r
F
.56454 .98737 m .56765 .99849 L .56772 .99838 L 0 0 .086 r
F
.56547 .9683 m .55265 .96017 L .55953 .95775 L 0 .223 .103 r
F
.5591 .95503 m .56587 .99057 L .56672 .99262 L 0 0 .125 r
F
.56359 .98409 m .56446 .98717 L .56454 .98737 L 0 0 .086 r
F
.56715 .99718 m .56657 .99562 L .56719 .99731 L F
.56715 .99718 m .56657 .99562 L .56717 .99717 L 0 .247 .049 r
F
.56341 .98347 m .56657 .99562 L .56715 .99718 L 0 0 .086 r
F
.56353 .99878 m .56657 .99562 L .56715 .99718 L 0 .247 .049 r
F
.56341 .98347 m .56611 .99439 L .56657 .99562 L 0 0 .086 r
F
.56353 .99878 m .56505 .99211 L .56527 .99215 L 0 .247 .049 r
F
.56353 .99878 m .56527 .99215 L .56657 .99562 L F
.56598 .99384 m .56523 .99201 L .56536 .99246 L 0 0 .086 r
F
.56598 .99384 m .56536 .99246 L .56613 .99447 L F
.56341 .98347 m .56523 .99201 L .56598 .99384 L F
.56877 1.04902 m .56325 1.06864 L .57233 1.06308 L 0 .968 .385 r
F
.56602 1.03474 m .5602 1.04949 L .56877 1.04896 L 0 .619 .331 r
F
.55947 .9946 m .56343 1.00274 L .56629 1.0051 L 0 .121 .189 r
F
.55947 .9946 m .56629 1.0051 L .56457 1.00189 L F
.55776 .96663 m .56504 .99136 L .5619 .97996 L 0 0 .121 r
F
.56341 .98347 m .5619 .97996 L .56504 .99136 L 0 0 .086 r
F
.55794 .99266 m .56505 .99211 L .562 .99335 L 0 .197 .023 r
F
.56353 .99878 m .562 .99335 L .56505 .99211 L 0 .247 .049 r
F
.5591 .95503 m .56241 .97602 L .56658 .99429 L 0 0 .125 r
F
.56862 1.00609 m .56665 1.00301 L .56773 .99954 L 0 .286 .069 r
F
.56343 1.00274 m .55605 .99717 L .56144 1.00408 L 0 .165 .208 r
F
.56343 1.00274 m .55477 .99403 L .55605 .99717 L F
.56343 1.00274 m .55793 .9964 L .55477 .99403 L F
.55947 .9946 m .55793 .9964 L .56343 1.00274 L 0 .121 .189 r
F
.55948 1.00703 m .56261 1.00103 L .56665 1.00301 L 0 .329 .065 r
F
.55948 1.00703 m .56665 1.00301 L .56862 1.00609 L F
.55948 1.00703 m .56862 1.00609 L .56729 1.00867 L F
.55948 1.00703 m .56729 1.00867 L .56354 1.00901 L F
.56325 1.01538 m .56354 1.00901 L .56729 1.00867 L 0 .375 .08 r
F
.56325 1.01538 m .57144 1.01788 L .56739 1.01795 L F
.56652 1.02518 m .56739 1.01795 L .57144 1.01788 L 0 .435 .092 r
F
.56652 1.02518 m .56527 1.02107 L .56739 1.01795 L F
.56924 1.03668 m .56822 1.03186 L .57069 1.02864 L 0 .491 .102 r
F
.56331 1.02523 m .55112 1.02159 L .55784 1.029 L 0 .518 .396 r
F
.56331 1.02523 m .55784 1.029 L .56602 1.03474 L F
.558 1.02549 m .56419 1.02573 L .56822 1.03186 L 0 .507 .078 r
F
.558 1.02549 m .56822 1.03186 L .56924 1.03668 L F
.558 1.02549 m .56924 1.03668 L .56658 1.03659 L F
.55967 1.03385 m .56658 1.03659 L .5706 1.0445 L 0 .564 .082 r
F
.57139 1.05011 m .5706 1.0445 L .57341 1.04146 L 0 .545 .109 r
F
.55794 .99266 m .55845 .98719 L .5625 .98788 L 0 .197 .023 r
F
.56353 .99878 m .56135 .99621 L .562 .99335 L 0 .247 .049 r
F
.55819 .97933 m .56569 .99667 L .56118 .99409 L 0 .256 .176 r
F
.56612 .97788 m .57284 1.01889 L .57339 1.02112 L 0 0 .101 r
F
.56612 .97788 m .57137 1.01078 L .57198 1.01413 L F
.56612 .97788 m .57198 1.01413 L .57218 1.01485 L F
.56612 .97788 m .5725 1.01579 L .5727 1.01643 L F
.56612 .97788 m .57255 1.01615 L .5725 1.01579 L F
.56287 .9668 m .56827 .9956 L .56849 .99587 L 0 0 .111 r
F
.56587 .99057 m .56658 .99429 L .56672 .99262 L 0 0 .125 r
F
.56341 .98347 m .56357 .98403 L .56359 .98409 L 0 0 .086 r
F
.5591 .95503 m .56672 .99262 L .56716 .99278 L 0 0 .125 r
F
.56287 .9668 m .56895 1.00008 L .56914 1.00022 L 0 0 .111 r
F
.55776 .96663 m .55835 .97334 L .56249 .98666 L 0 0 .121 r
F
.55511 .90476 m .56612 .97788 L .56366 .95812 L 0 .106 .182 r
F
.55511 .90476 m .56489 .97355 L .56612 .97788 L F
.55487 .94309 m .56341 .98347 L .56241 .97602 L 0 0 .138 r
F
.55487 .94309 m .5612 .97658 L .56341 .98347 L F
.55714 .90293 m .56881 .98736 L .56598 .96341 L 0 .108 .179 r
F
.55714 .90293 m .56781 .9838 L .56881 .98736 L F
.55714 .90293 m .56366 .95812 L .56781 .9838 L F
.55868 .89647 m .57088 .99359 L .5677 .96448 L 0 .116 .179 r
F
.55868 .89647 m .57013 .99156 L .57088 .99359 L F
.55868 .89647 m .56598 .96341 L .57013 .99156 L F
.56341 .98347 m .5612 .97658 L .5619 .97996 L 0 0 .086 r
F
.5591 .95503 m .56716 .99278 L .56326 .97323 L 0 0 .125 r
F
.56287 .9668 m .56326 .97323 L .56716 .99278 L 0 0 .111 r
F
.56287 .9668 m .57137 1.01078 L .56713 .9876 L F
.56612 .97788 m .56489 .97355 L .56713 .9876 L 0 0 .101 r
F
.56612 .97788 m .56713 .9876 L .57137 1.01078 L F
.55819 .97933 m .56946 .97338 L .56569 .99667 L 0 .256 .176 r
F
.55967 1.03385 m .56842 1.04894 L .56368 1.04177 L 0 .564 .082 r
F
.55967 1.03385 m .57139 1.05011 L .56842 1.04894 L F
.55967 1.03385 m .5706 1.0445 L .57139 1.05011 L F
.56084 1.04229 m .56368 1.04177 L .56842 1.04894 L 0 .619 .082 r
F
.57342 1.01882 m .57633 1.03811 L .57632 1.0381 L 0 0 .096 r
F
.56881 .98736 m .57343 1.01915 L .57363 1.01974 L F
.56881 .98736 m .57363 1.01974 L .57342 1.01882 L F
.56881 .98736 m .57686 1.04221 L .57317 1.01565 L F
.57688 1.04229 m .57693 1.04265 L .57687 1.04229 L 0 .491 .102 r
F
.57689 1.04232 m .57693 1.04265 L .57688 1.04229 L F
.57695 1.04257 m .57693 1.04265 L .57688 1.04229 L F
.57629 1.0384 m .57638 1.039 L .57633 1.03869 L 0 0 .096 r
F
.57638 1.039 m .57638 1.03902 L .57633 1.03869 L F
.57638 1.03904 m .57641 1.03926 L .57633 1.03869 L F
.57687 1.04229 m .57693 1.04265 L .57341 1.04146 L 0 .491 .102 r
F
.57341 1.01876 m .57629 1.0384 L .57341 1.01872 L 0 0 .096 r
F
.57629 1.0384 m .57633 1.03869 L .57341 1.01872 L F
.5737 1.0229 m .57418 1.02577 L .57409 1.02461 L 0 0 .101 r
F
.57418 1.02577 m .57459 1.02779 L .57409 1.02461 L F
.57342 1.01882 m .5736 1.02005 L .57341 1.01876 L 0 0 .096 r
F
.57672 1.04211 m .57686 1.04221 L .57673 1.04218 L 0 .491 .102 r
F
.57672 1.04211 m .57673 1.04218 L .57341 1.04146 L F
.5765 1.03981 m .5765 1.03983 L .57629 1.03839 L 0 0 .096 r
F
.57686 1.04221 m .57687 1.04229 L .57341 1.04146 L 0 .491 .102 r
F
.57628 1.03835 m .57629 1.03839 L .57341 1.01872 L 0 0 .096 r
F
.57339 1.02112 m .57312 1.02023 L .57356 1.02217 L 0 0 .101 r
F
.57312 1.02023 m .57355 1.0221 L .57356 1.02217 L F
.57284 1.01889 m .57299 1.01976 L .57339 1.02112 L F
.57218 1.01485 m .57198 1.01413 L .57299 1.01976 L F
.5727 1.01643 m .5737 1.0229 L .57409 1.02461 L F
.5725 1.01579 m .5737 1.0229 L .5727 1.01643 L F
.56881 .98736 m .57342 1.01882 L .57341 1.01872 L 0 0 .096 r
F
.5725 1.01579 m .57356 1.02217 L .5737 1.0229 L 0 0 .101 r
F
.57255 1.01615 m .57356 1.02217 L .5725 1.01579 L F
.57088 .99359 m .57013 .99156 L .57317 1.01565 L 0 0 .097 r
F
.57229 .99375 m .57181 .99453 L .57524 1.02704 L 0 0 .105 r
F
.57295 .98334 m .57278 .98896 L .5766 1.0333 L 0 0 .114 r
F
.56084 1.04229 m .56842 1.04894 L .5724 1.05911 L 0 .619 .082 r
F
.56084 1.04229 m .56969 1.06266 L .56481 1.05246 L F
.56084 1.04229 m .57295 1.06551 L .56969 1.06266 L F
.56084 1.04229 m .5724 1.05911 L .57295 1.06551 L F
.56151 1.05019 m .56481 1.05246 L .56969 1.06266 L 0 .664 .077 r
F
.56151 1.05019 m .56969 1.06266 L .57358 1.07555 L F
.56807 1.06244 m .57679 .98056 L .5798 1.03691 L 0 .294 .194 r
F
.56779 1.06304 m .56796 1.06144 L .56807 1.06244 L F
.56796 1.06144 m .57679 .98056 L .56807 1.06244 L F
.57713 1.17299 m .58132 1.20024 L .58457 1.23519 L 0 .634 .042 r
F
.57075 1.11967 m .57646 1.16313 L .57713 1.17299 L F
.57646 1.16313 m .58132 1.20024 L .57713 1.17299 L F
.59065 1.38542 m .58026 1.20646 L .58729 1.32116 L 0 .66 .042 r
F
.58361 1.23839 m .58457 1.23519 L .58944 1.27896 L 0 .994 .102 r
F
.59083 1.38597 m .58361 1.23839 L .59105 1.38622 L F
.59083 1.38597 m .58729 1.32116 L .58361 1.23839 L F
.59105 1.38622 m .58361 1.23839 L .59279 1.38697 L F
.59279 1.38697 m .58361 1.23839 L .59578 1.38797 L F
.59065 1.38542 m .58729 1.32116 L .59083 1.38597 L 0 .66 .042 r
F
.57943 1.12447 m .58091 1.1362 L .58877 1.35728 L 0 .145 .158 r
F
.58091 1.1362 m .59175 1.22243 L .58877 1.35728 L F
.58877 1.35728 m .59175 1.22243 L .58877 1.35734 L F
.58026 1.20646 m .58176 1.22605 L .58729 1.32116 L 0 .66 .042 r
F
.57943 1.12447 m .58877 1.35734 L .58321 1.2617 L 0 .145 .158 r
F
.5839 1.22025 m .58321 1.26167 L .58877 1.3573 L 0 .191 .184 r
F
.58126 1.19393 m .58321 1.26167 L .5839 1.22025 L F
.57894 1.0587 m .57901 1.05931 L .57553 1.05684 L 0 .545 .109 r
F
.56946 .97338 m .58028 .92423 L .57679 .98056 L 0 .16 .157 r
F
.56946 .97338 m .57679 .98056 L .57239 .99087 L F
.56895 1.00008 m .57144 1.01371 L .56914 1.00022 L 0 0 .111 r
F
.56796 1.06144 m .57239 .99087 L .57679 .98056 L 0 .294 .194 r
F
.57388 1.08254 m .57358 1.07555 L .57701 1.07511 L 0 .67 .126 r
F
.57908 1.0678 m .57961 1.06799 L .5797 1.07315 L 0 .601 .12 r
F
.57961 1.06799 m .57991 1.07125 L .5797 1.07315 L F
.57295 1.06551 m .5724 1.05911 L .57553 1.05684 L F
.56151 1.05019 m .57388 1.08254 L .57036 1.07717 L 0 .664 .077 r
F
.56151 1.05019 m .57358 1.07555 L .57388 1.08254 L F
.56163 1.05656 m .57413 1.09303 L .57417 1.10002 L 0 .668 .064 r
F
.56163 1.05656 m .57036 1.07717 L .57413 1.09303 L F
.57417 1.10002 m .57413 1.09303 L .57785 1.0963 L 0 .762 .122 r
F
.56839 1.0662 m .5798 1.03691 L .57943 1.12447 L 0 .294 .194 r
F
.56779 1.06304 m .56807 1.06244 L .56839 1.0662 L F
.56807 1.06244 m .5798 1.03691 L .56839 1.0662 L F
.56151 1.05019 m .57036 1.07717 L .56538 1.06305 L 0 .664 .077 r
F
.56163 1.05656 m .5704 1.09112 L .56538 1.07233 L 0 .668 .064 r
F
.56163 1.05656 m .57417 1.10002 L .5704 1.09112 L F
.56163 1.05656 m .56538 1.06305 L .57036 1.07717 L F
.56122 1.06007 m .57377 1.11531 L .5698 1.10186 L 0 .584 .041 r
F
.56122 1.06007 m .57401 1.10957 L .57377 1.11531 L F
.56122 1.06007 m .5704 1.09112 L .57401 1.10957 L F
.56122 1.06007 m .56538 1.07233 L .5704 1.09112 L F
.56246 1.06988 m .5698 1.10186 L .57318 1.12141 L 0 .554 .01 r
F
.56024 1.0592 m .56216 1.06777 L .56246 1.06988 L F
.56216 1.06777 m .5698 1.10186 L .56246 1.06988 L F
.57265 1.1238 m .57318 1.12141 L .57745 1.14215 L 0 .858 .085 r
F
.57265 1.1238 m .58132 1.20024 L .57611 1.15737 L F
.57075 1.11967 m .5716 1.12306 L .57611 1.15737 L 0 .634 .042 r
F
.57075 1.11967 m .57611 1.15737 L .5767 1.16224 L F
.57675 1.16534 m .5767 1.16224 L .58132 1.20024 L F
.57075 1.11967 m .5767 1.16224 L .57675 1.16534 L F
.56956 1.08547 m .56892 1.07327 L .57553 1.16123 L 0 .294 .194 r
F
.56779 1.06304 m .56892 1.07327 L .56956 1.08547 L F
.56779 1.06304 m .56839 1.0662 L .56892 1.07327 L F
.57377 1.11531 m .57401 1.10957 L .578 1.11958 L 0 .866 .108 r
F
.56839 1.0662 m .57943 1.12447 L .57623 1.15459 L 0 .294 .194 r
F
.56839 1.0662 m .57623 1.15459 L .57553 1.16123 L F
.56779 1.06304 m .56791 1.06116 L .56796 1.06144 L F
.56791 1.06116 m .57239 .99087 L .56796 1.06144 L F
.56059 1.01695 m .54914 1.01182 L .55554 1.01899 L 0 .401 .377 r
F
.56059 1.01695 m .55554 1.01899 L .56331 1.02523 L F
.55586 1.01756 m .56527 1.02107 L .56652 1.02518 L 0 .45 .071 r
F
.55586 1.01756 m .56652 1.02518 L .56419 1.02573 L F
.56331 1.02523 m .55033 1.01744 L .55112 1.02159 L 0 .518 .396 r
F
.56331 1.02523 m .55554 1.01899 L .55033 1.01744 L F
.56059 1.01695 m .54835 1.00849 L .54914 1.01182 L 0 .401 .377 r
F
.56059 1.01695 m .55325 1.01068 L .54835 1.00849 L F
.55788 1.00935 m .55325 1.01068 L .56059 1.01695 L 0 .344 .349 r
F
.55788 1.00935 m .56059 1.01695 L .56521 1.01938 L F
.55788 1.00935 m .56521 1.01938 L .564 1.01634 L F
.55516 1.00207 m .55788 1.00935 L .56218 1.01187 L 0 .311 .322 r
F
.55516 1.00207 m .56218 1.01187 L .56096 1.00896 L F
.55243 .99479 m .55516 1.00207 L .55914 1.0046 L 0 .279 .3 r
F
.55243 .99479 m .55914 1.0046 L .55792 1.0017 L F
.55524 .99987 m .56135 .99621 L .56353 .99878 L 0 .294 .046 r
F
.55947 .9946 m .55285 .98914 L .55793 .9964 L 0 .121 .189 r
F
.55524 .99987 m .55742 .99461 L .56135 .99621 L 0 .294 .046 r
F
.55524 .99987 m .56353 .99878 L .56261 1.00103 L F
.55524 .99987 m .56261 1.00103 L .55918 1.00147 L F
.55948 1.00703 m .55918 1.00147 L .56261 1.00103 L 0 .329 .065 r
F
.55948 1.00703 m .55784 1.00404 L .55918 1.00147 L F
.55788 1.00935 m .55096 1.0031 L .54637 1.0007 L 0 .344 .349 r
F
.55516 1.00207 m .55096 1.0031 L .55788 1.00935 L 0 .311 .322 r
F
.55027 1.00352 m .55784 1.00404 L .55948 1.00703 L 0 .351 .047 r
F
.55027 1.00352 m .55948 1.00703 L .55788 1.00811 L F
.55788 1.00935 m .54716 1.00372 L .55325 1.01068 L 0 .344 .349 r
F
.55788 1.00935 m .54637 1.0007 L .54716 1.00372 L F
.55327 1.01022 m .55788 1.00811 L .5618 1.01188 L 0 .391 .06 r
F
.55327 1.01022 m .5618 1.01188 L .56325 1.01538 L F
.55327 1.01022 m .56325 1.01538 L .56128 1.01629 L F
.55327 1.01022 m .56128 1.01629 L .5572 1.014 L F
.55586 1.01756 m .56128 1.01629 L .56527 1.02107 L 0 .45 .071 r
F
.55586 1.01756 m .5572 1.014 L .56128 1.01629 L F
.55586 1.01756 m .56419 1.02573 L .55985 1.02235 L F
.54603 1.00429 m .54914 1.01182 L .54835 1.00849 L 0 .332 .342 r
F
.54674 1.00839 m .55333 1.01549 L .5572 1.02225 L 0 .402 .016 r
F
.54674 1.00839 m .5572 1.02225 L .558 1.02549 L F
.55653 1.02251 m .56118 .99409 L .56569 .99667 L 0 .381 .193 r
F
.57068 1.00988 m .57071 1.00999 L .56977 1.00634 L 0 .418 0 r
F
.56779 1.06304 m .56853 1.02605 L .57239 .99087 L 0 .294 .194 r
F
.56325 1.01538 m .5618 1.01188 L .56354 1.00901 L 0 .375 .08 r
F
.558 1.02549 m .55985 1.02235 L .56419 1.02573 L 0 .507 .078 r
F
.558 1.02549 m .5572 1.02225 L .55985 1.02235 L F
.55653 1.02251 m .56569 .99667 L .56853 1.02605 L 0 .381 .193 r
F
.54674 1.00839 m .558 1.02549 L .55517 1.02244 L 0 .402 .016 r
F
.558 1.02549 m .56658 1.03659 L .56202 1.03164 L 0 .507 .078 r
F
.54795 1.01241 m .55906 1.03046 L .55967 1.03385 L 0 .42 .011 r
F
.54795 1.01241 m .55517 1.02244 L .55906 1.03046 L F
.55967 1.03385 m .56202 1.03164 L .56658 1.03659 L 0 .564 .082 r
F
.55967 1.03385 m .55906 1.03046 L .56202 1.03164 L F
.56084 1.04229 m .56043 1.03892 L .56368 1.04177 L 0 .619 .082 r
F
.55653 1.02251 m .56853 1.02605 L .56779 1.06304 L 0 .381 .193 r
F
.55783 1.05053 m .5607 1.06013 L .56024 1.0592 L 0 0 .069 r
F
.55418 1.03741 m .55747 1.04888 L .55783 1.05053 L F
.55747 1.04888 m .5607 1.06013 L .55783 1.05053 L F
.55396 1.0365 m .55742 1.04862 L .55418 1.03741 L F
.55742 1.04862 m .5607 1.06013 L .55747 1.04888 L F
.55742 1.04862 m .55747 1.04888 L .55418 1.03741 L F
.55258 1.03155 m .5607 1.06013 L .55279 1.0324 L F
.55105 1.02597 m .5607 1.06013 L .55151 1.02782 L F
.55824 1.05096 m .55939 1.05599 L .55871 1.05265 L 0 0 .086 r
F
.5493 1.01942 m .54933 1.01915 L .55303 1.02898 L 0 .423 0 r
F
.5493 1.01942 m .55303 1.02898 L .55795 1.0424 L F
.54707 1.01074 m .55829 1.05195 L .55824 1.05096 L 0 0 .086 r
F
.55829 1.05195 m .55939 1.05599 L .55824 1.05096 L F
.55665 1.03998 m .55754 1.04579 L .55817 1.04945 L 0 0 .06 r
F
.54707 1.01074 m .55629 1.04534 L .55829 1.05222 L 0 0 .086 r
F
.55829 1.05195 m .55829 1.05222 L .55939 1.05599 L F
.54707 1.01074 m .55829 1.05222 L .55829 1.05195 L F
.57025 1.11919 m .5702 1.1184 L .57216 1.13713 L 0 .548 0 r
F
.57233 1.13893 m .57216 1.13713 L .5739 1.15372 L F
.57233 1.13893 m .5739 1.15372 L .57279 1.14383 L F
.57054 1.12164 m .57279 1.14383 L .5736 1.15012 L F
.56962 1.11335 m .56992 1.11412 L .57002 1.11556 L 0 .496 0 r
F
.56799 1.1043 m .56931 1.111 L .56962 1.11335 L F
.56931 1.111 m .56992 1.11412 L .56962 1.11335 L F
.5677 1.10234 m .56992 1.11412 L .56799 1.1043 L F
.57002 1.11556 m .5716 1.12306 L .57075 1.11967 L F
.56992 1.11412 m .5716 1.12306 L .57002 1.11556 L F
.57167 1.12891 m .5751 1.16087 L .57553 1.16125 L 0 .548 0 r
F
.56628 1.09396 m .5699 1.11374 L .56691 1.09809 L 0 .496 0 r
F
.5699 1.11374 m .56992 1.11412 L .56628 1.09476 L F
.56628 1.09476 m .56714 1.09954 L .56719 1.10052 L F
.57018 1.11861 m .57025 1.11919 L .57027 1.11945 L 0 .548 0 r
F
.56714 1.09954 m .56799 1.1043 L .56782 1.10391 L 0 .496 0 r
F
.56799 1.1043 m .57002 1.11556 L .56836 1.10678 L F
.56799 1.1043 m .56836 1.10678 L .56782 1.10391 L F
.57041 1.12046 m .57031 1.12009 L .57054 1.12164 L 0 .548 0 r
F
.57002 1.11556 m .57003 1.11575 L .56782 1.10391 L 0 .496 0 r
F
.56544 1.08938 m .56628 1.09396 L .56628 1.09476 L F
.56628 1.09396 m .56691 1.09809 L .56628 1.09476 L F
.56628 1.09476 m .5677 1.10234 L .56799 1.1043 L F
.55871 1.05265 m .56544 1.08938 L .56628 1.09476 L F
.56251 1.07381 m .56628 1.09476 L .56651 1.09687 L F
.56628 1.09476 m .56719 1.10052 L .56651 1.09687 L F
.57002 1.11711 m .57017 1.11841 L .57018 1.11861 L 0 .548 0 r
F
.56728 1.09944 m .56851 1.10531 L .56988 1.11315 L 0 .496 0 r
F
.56908 1.1093 m .56988 1.11315 L .5699 1.11374 L F
.56728 1.09944 m .56893 1.10814 L .56908 1.1093 L F
.56893 1.10814 m .56988 1.11315 L .56908 1.1093 L F
.57002 1.11556 m .57075 1.11967 L .57003 1.11575 L F
.56809 1.0989 m .57109 1.12408 L .57076 1.12097 L 0 .548 0 r
F
.57109 1.12408 m .57167 1.12891 L .57124 1.12512 L F
.57109 1.12408 m .57124 1.12512 L .57076 1.12097 L F
.56332 1.07432 m .56925 1.10931 L .56809 1.0989 L 0 0 .06 r
F
.56024 1.0592 m .56851 1.10531 L .56357 1.07847 L 0 .554 .01 r
F
.56181 1.06837 m .56925 1.10931 L .56332 1.07432 L 0 0 .06 r
F
.56809 1.0989 m .57001 1.11697 L .57002 1.11711 L 0 .548 0 r
F
.57001 1.11697 m .57017 1.11841 L .57002 1.11711 L F
.5699 1.11374 m .56988 1.11315 L .5716 1.12306 L 0 .496 0 r
F
.55871 1.05265 m .56664 1.09528 L .56728 1.09944 L F
.56664 1.09528 m .56851 1.10531 L .56728 1.09944 L F
.57021 1.1186 m .5702 1.11908 L .57041 1.12046 L 0 .548 0 r
F
.56809 1.0989 m .5702 1.1184 L .57025 1.11919 L F
.56843 1.10208 m .57003 1.11745 L .57021 1.1186 L F
.57017 1.11841 m .57025 1.11919 L .57018 1.11861 L F
.56853 1.10534 m .56855 1.10613 L .56925 1.10931 L 0 0 .06 r
F
.56809 1.0989 m .57233 1.13893 L .57279 1.14383 L 0 .548 0 r
F
.57003 1.11745 m .5702 1.11908 L .57021 1.1186 L F
.55871 1.05265 m .56357 1.07847 L .56851 1.10531 L 0 .496 0 r
F
.55871 1.05265 m .55939 1.05599 L .56357 1.07847 L F
.56181 1.06837 m .56651 1.09687 L .56855 1.10613 L 0 0 .06 r
F
.56181 1.06837 m .56855 1.10613 L .56853 1.10534 L F
.56809 1.0989 m .56844 1.1022 L .56843 1.10208 L 0 .548 0 r
F
.56844 1.1022 m .5702 1.11908 L .56843 1.10208 L F
.5702 1.11908 m .57031 1.12009 L .57041 1.12046 L F
.56714 1.09954 m .56782 1.10391 L .56719 1.10052 L 0 .496 0 r
F
.57143 1.12691 m .57099 1.12448 L .57167 1.12891 L 0 .548 0 r
F
.56809 1.0989 m .57082 1.12302 L .57143 1.12691 L F
.57082 1.12302 m .57099 1.12448 L .57143 1.12691 L F
.57099 1.12448 m .5751 1.16087 L .57167 1.12891 L F
.5699 1.11374 m .5716 1.12306 L .56992 1.11412 L 0 .496 0 r
F
.57027 1.11945 m .57216 1.13713 L .57233 1.13893 L 0 .548 0 r
F
.57025 1.11919 m .57216 1.13713 L .57027 1.11945 L F
.57167 1.12891 m .57553 1.16125 L .57196 1.13107 L F
.57167 1.12891 m .57196 1.13107 L .57076 1.12097 L F
.57031 1.12009 m .57279 1.14383 L .57054 1.12164 L F
.56809 1.0989 m .56925 1.10931 L .5702 1.1184 L F
.56122 1.06007 m .5698 1.10186 L .56478 1.07835 L 0 .584 .041 r
F
.56216 1.06777 m .56478 1.07835 L .5698 1.10186 L 0 .554 .01 r
F
.56024 1.0592 m .56189 1.06617 L .56216 1.06777 L F
.56189 1.06617 m .56478 1.07835 L .56216 1.06777 L F
.56779 1.06304 m .57553 1.16123 L .57076 1.12095 L 0 .294 .194 r
F
.56406 .98089 m .57076 1.12094 L .57553 1.16121 L 0 .224 .198 r
F
.57114 1.12144 m .57277 1.13626 L .57279 1.13643 L 0 0 .077 r
F
.54795 1.01241 m .55967 1.03385 L .55657 1.02954 L 0 .42 .011 r
F
.54791 1.01236 m .55112 1.02158 L .55032 1.01743 L 0 .31 .331 r
F
.5488 1.01583 m .56084 1.04229 L .5575 1.0364 L 0 .433 0 r
F
.5488 1.01583 m .56043 1.03892 L .56084 1.04229 L F
.5488 1.01583 m .55657 1.02954 L .56043 1.03892 L F
.54925 1.01831 m .56151 1.05019 L .55795 1.0424 L 0 .435 0 r
F
.54925 1.01831 m .5613 1.04712 L .56151 1.05019 L F
.54925 1.01831 m .5575 1.0364 L .5613 1.04712 L F
.56151 1.05019 m .5613 1.04712 L .56481 1.05246 L 0 .664 .077 r
F
.56163 1.05656 m .56165 1.05424 L .56538 1.06305 L 0 .668 .064 r
F
.56122 1.06007 m .56145 1.05906 L .56538 1.07233 L 0 .584 .041 r
F
.55653 1.02251 m .5605 1.03682 L .56441 1.07267 L 0 .381 .193 r
F
.5605 1.03682 m .56779 1.06304 L .56482 1.07151 L F
.5605 1.03682 m .56482 1.07151 L .56441 1.07267 L F
.57007 1.10651 m .56971 1.10437 L .57076 1.12094 L 0 .224 .198 r
F
.57017 1.11451 m .57076 1.12096 L .5717 1.12894 L 0 0 .077 r
F
.56472 1.06314 m .56963 1.11018 L .57017 1.11451 L F
.56963 1.11018 m .57076 1.12096 L .57017 1.11451 L F
.56406 .98089 m .56586 1.04343 L .56971 1.10437 L 0 .224 .198 r
F
.56406 .98089 m .56971 1.10437 L .57007 1.10651 L F
.56024 1.0592 m .5607 1.06013 L .56478 1.07835 L 0 .554 .01 r
F
.55922 1.0416 m .56441 1.07267 L .56383 1.07434 L 0 .381 .193 r
F
.55653 1.02251 m .56441 1.07267 L .55922 1.0416 L F
.56472 1.06314 m .57112 1.12133 L .57114 1.12144 L 0 0 .077 r
F
.57112 1.12133 m .57277 1.13626 L .57114 1.12144 L F
.57279 1.13643 m .57538 1.16001 L .57542 1.16031 L F
.57277 1.13626 m .57538 1.16001 L .57279 1.13643 L F
.55825 1.04942 m .56043 1.06246 L .56056 1.06307 L 0 0 .06 r
F
.55665 1.03998 m .55825 1.0495 L .55825 1.04942 L F
.55825 1.0495 m .56043 1.06246 L .55825 1.04942 L F
.55814 1.04889 m .55817 1.04945 L .56043 1.06246 L F
.55665 1.03998 m .55817 1.04945 L .55814 1.04889 L F
.55871 1.05265 m .56651 1.09687 L .56175 1.07008 L 0 .496 0 r
F
.56056 1.06307 m .56043 1.06246 L .56175 1.07008 L 0 0 .06 r
F
.55871 1.05265 m .56128 1.06693 L .56154 1.06866 L 0 .496 0 r
F
.56101 1.06512 m .56175 1.07008 L .56651 1.09687 L 0 0 .06 r
F
.55665 1.03998 m .56056 1.06307 L .56101 1.06512 L F
.56056 1.06307 m .56175 1.07008 L .56101 1.06512 L F
.55665 1.03998 m .56101 1.06512 L .56181 1.06837 L F
.56101 1.06512 m .56651 1.09687 L .56181 1.06837 L F
.55279 1.0324 m .55396 1.0365 L .55418 1.03741 L 0 0 .069 r
F
.55151 1.02782 m .55258 1.03155 L .55279 1.0324 L F
.55665 1.03998 m .56332 1.07432 L .56383 1.07435 L 0 0 .06 r
F
.56332 1.07432 m .56809 1.0989 L .56496 1.08086 L F
.56332 1.07432 m .56496 1.08086 L .56383 1.07435 L F
.57254 1.13423 m .5717 1.12894 L .57538 1.16001 L 0 0 .077 r
F
.56472 1.06314 m .5717 1.12894 L .57254 1.13423 L F
.56406 .98089 m .5749 1.15136 L .57688 1.08203 L 0 .224 .198 r
F
.5749 1.15136 m .57553 1.16121 L .57564 1.15431 L F
.5749 1.15136 m .57564 1.15431 L .57688 1.08203 L F
.55947 .9946 m .55157 .98577 L .55285 .98914 L 0 .121 .189 r
F
.55947 .9946 m .5544 .9881 L .55157 .98577 L F
.55531 .98498 m .5496 .9803 L .5544 .9881 L 0 .09 .18 r
F
.55531 .98498 m .54825 .97639 L .5496 .9803 L F
.55531 .98498 m .5507 .97838 L .54825 .97639 L F
.55074 .98141 m .55697 .98087 L .55474 .98178 L 0 0 0 r
F
.55822 .98527 m .55474 .98178 L .55697 .98087 L 0 .054 0 r
F
.55822 .98527 m .55528 .98367 L .55474 .98178 L F
.5467 .97844 m .55285 .98914 L .55157 .98577 L 0 .22 .265 r
F
.5519 .98745 m .55528 .98367 L .55822 .98527 L 0 .132 0 r
F
.5519 .98745 m .5514 .98297 L .55528 .98367 L F
.5519 .98745 m .55822 .98527 L .55845 .98719 L F
.5519 .98745 m .55845 .98719 L .55579 .98814 L F
.55794 .99266 m .55579 .98814 L .55845 .98719 L 0 .197 .023 r
F
.55794 .99266 m .55557 .99049 L .55579 .98814 L F
.54031 .98554 m .54825 .99799 L .54737 .98746 L 0 1 .417 r
F
.55243 .99479 m .5432 .98893 L .54866 .99581 L 0 .279 .3 r
F
.55243 .99479 m .54241 .98599 L .5432 .98893 L F
.55243 .99479 m .54636 .9885 L .54241 .98599 L F
.54957 .9869 m .54636 .98849 L .55243 .99479 L 0 .247 .28 r
F
.54957 .9869 m .55243 .99479 L .55605 .99717 L F
.54957 .9869 m .55605 .99717 L .55477 .99403 L F
.55057 .99367 m .55557 .99049 L .55794 .99266 L 0 .249 .022 r
F
.55057 .99367 m .5518 .98913 L .55557 .99049 L F
.55057 .99367 m .55794 .99266 L .55742 .99461 L F
.55057 .99367 m .55742 .99461 L .55436 .99504 L F
.55524 .99987 m .55436 .99504 L .55742 .99461 L 0 .294 .046 r
F
.55115 .97549 m .54493 .97418 L .54626 .97394 L 0 0 0 r
F
.55115 .97549 m .54703 .97485 L .54493 .97418 L F
.54703 .97677 m .54703 .97485 L .55115 .97549 L F
.54703 .97677 m .55115 .97549 L .55292 .97643 L F
.54703 .97677 m .55292 .97643 L .55113 .97705 L F
.55598 .97938 m .55113 .97705 L .55292 .97643 L F
.55598 .97938 m .55244 .97831 L .55113 .97705 L F
.55074 .98141 m .55244 .97831 L .55598 .97938 L F
.55074 .98141 m .54846 .97794 L .55244 .97831 L F
.55074 .98141 m .55598 .97938 L .55697 .98087 L F
.54687 .97338 m .55819 .97933 L .55441 .98844 L 0 .302 .173 r
F
.55516 1.00207 m .54518 .99624 L .55096 1.0031 L 0 .311 .322 r
F
.55516 1.00207 m .54439 .99332 L .54518 .99624 L F
.55516 1.00207 m .54866 .99581 L .54439 .99332 L F
.55243 .99479 m .54866 .99581 L .55516 1.00207 L 0 .279 .3 r
F
.55027 1.00352 m .55402 1.00101 L .55784 1.00404 L 0 .351 .047 r
F
.55027 1.00352 m .55788 1.00811 L .55409 1.00656 L F
.55327 1.01022 m .55409 1.00656 L .55788 1.00811 L 0 .391 .06 r
F
.55586 1.01756 m .55487 1.01454 L .5572 1.014 L 0 .45 .071 r
F
.55653 1.02251 m .55726 1.00512 L .56118 .99409 L 0 .381 .193 r
F
.55382 .98152 m .56586 1.04343 L .56406 .98089 L 0 .242 .209 r
F
.55057 .99367 m .54913 .98948 L .5518 .98913 L 0 .249 .022 r
F
.55057 .99367 m .5486 .99142 L .54913 .98948 L F
.54227 .98961 m .54415 .99685 L .54518 .99624 L 0 .315 .327 r
F
.54227 .98961 m .54518 .99624 L .54439 .99332 L F
.54316 .99192 m .5486 .99142 L .55057 .99367 L 0 .275 .007 r
F
.55524 .99987 m .55342 .99729 L .55436 .99504 L 0 .294 .046 r
F
.54316 .99192 m .55057 .99367 L .54975 .9948 L 0 .275 .007 r
F
.54316 .99192 m .54975 .9948 L .54666 .99404 L F
.54689 .99744 m .54975 .9948 L .55342 .99729 L 0 .317 .029 r
F
.54689 .99744 m .54666 .99404 L .54975 .9948 L F
.54689 .99744 m .55342 .99729 L .55524 .99987 L F
.54689 .99744 m .54543 .99517 L .54666 .99404 L F
.54689 .99744 m .55524 .99987 L .55402 1.00101 L F
.54689 .99744 m .55402 1.00101 L .55057 .99994 L F
.55027 1.00352 m .55057 .99994 L .55402 1.00101 L 0 .351 .047 r
F
.5455 .99445 m .55441 .98844 L .55726 1.00512 L 0 .413 .181 r
F
.54227 .98961 m .54199 .99475 L .54415 .99685 L 0 .315 .327 r
F
.54227 .98961 m .53988 .99104 L .54199 .99475 L F
.53849 .99082 m .54543 .99517 L .54689 .99744 L 0 .296 0 r
F
.53849 .99082 m .54689 .99744 L .54538 .99703 L F
.55027 1.00352 m .54896 1.00102 L .55057 .99994 L 0 .351 .047 r
F
.54415 .99685 m .54603 1.00429 L .54716 1.00372 L 0 .329 .337 r
F
.54415 .99685 m .54716 1.00372 L .54637 1.0007 L F
.54101 .99516 m .54538 .99703 L .54896 1.00102 L 0 .329 0 r
F
.54415 .99685 m .54199 .99475 L .54087 .99532 L 0 .329 .337 r
F
.54101 .99516 m .54896 1.00102 L .55027 1.00352 L 0 .329 0 r
F
.54101 .99516 m .55027 1.00352 L .5484 1.00272 L F
.55327 1.01022 m .55212 1.00746 L .55409 1.00656 L 0 .391 .06 r
F
.54325 .9996 m .5484 1.00272 L .55212 1.00746 L 0 .357 .01 r
F
.54325 .9996 m .55212 1.00746 L .55327 1.01022 L F
.54325 .9996 m .55327 1.01022 L .55106 1.00888 L F
.54516 1.00406 m .55106 1.00888 L .55487 1.01454 L 0 .381 .015 r
F
.54516 1.00406 m .55487 1.01454 L .55586 1.01756 L F
.54516 1.00406 m .55586 1.01756 L .55333 1.01549 L F
.5455 .99445 m .55726 1.00512 L .55653 1.02251 L 0 .413 .181 r
F
.55382 .98152 m .56383 1.07433 L .56586 1.04343 L 0 .242 .209 r
F
.56076 1.01987 m .57108 1.08303 L .57265 1.06801 L 0 .09 .167 r
F
.56076 1.01987 m .56682 1.0648 L .57108 1.08303 L F
.56472 1.06314 m .57108 1.08303 L .56682 1.0648 L 0 0 .077 r
F
.56472 1.06314 m .57573 1.12503 L .57108 1.08303 L F
.56472 1.06314 m .57767 1.16304 L .57573 1.12503 L F
.56472 1.06314 m .57553 1.16124 L .57767 1.16304 L F
.56809 1.0574 m .57193 1.13082 L .57174 1.12925 L 0 1 .154 r
F
.56809 1.0989 m .57462 1.15967 L .57663 1.17434 L 0 .548 0 r
F
.5736 1.15012 m .579 1.20318 L .58076 1.21772 L F
.5736 1.15012 m .58076 1.21772 L .58066 1.21579 L F
.57279 1.14383 m .579 1.20318 L .5736 1.15012 L F
.57067 1.24305 m .58024 1.25465 L .57917 1.26157 L 0 .856 .108 r
F
.57067 1.24305 m .57917 1.26157 L .57523 1.25653 L F
.57563 1.2788 m .57523 1.25653 L .57917 1.26157 L 0 .881 .12 r
F
.5684 1.13516 m .58112 1.29054 L .57573 1.1659 L 0 0 .122 r
F
.5751 1.16087 m .57678 1.17324 L .57553 1.16125 L 0 .548 0 r
F
.57499 1.1593 m .57573 1.1659 L .57553 1.16127 L 0 0 .122 r
F
.5684 1.13516 m .57573 1.1659 L .57499 1.1593 L F
.5677 1.13724 m .56288 1.12162 L .56795 1.12508 L 0 .405 .061 r
F
.5677 1.13724 m .56109 1.12345 L .56288 1.12162 L F
.5677 1.13724 m .56315 1.13013 L .56109 1.12345 L F
.56242 1.14181 m .56315 1.13013 L .5677 1.13724 L 0 .474 .061 r
F
.55665 1.03998 m .56181 1.06837 L .56332 1.07432 L 0 0 .06 r
F
.55044 1.0639 m .55179 1.06894 L .56045 1.06907 L 0 1 .525 r
F
.56428 1.11137 m .56218 1.1019 L .5682 1.1066 L 0 .263 .024 r
F
.56034 1.11585 m .56428 1.11137 L .56721 1.11681 L 0 .307 .027 r
F
.56034 1.11585 m .56721 1.11681 L .56551 1.11878 L F
.55676 1.05755 m .5684 1.13516 L .56383 1.07436 L 0 .109 .162 r
F
.56428 1.11137 m .55673 1.09951 L .56218 1.1019 L 0 .263 .024 r
F
.56428 1.11137 m .55546 1.10101 L .55673 1.09951 L F
.56428 1.11137 m .55869 1.10609 L .55546 1.10101 L F
.56034 1.11585 m .55869 1.10609 L .56428 1.11137 L 0 .307 .027 r
F
.56598 1.16646 m .56382 1.14848 L .56846 1.15405 L 0 .62 .081 r
F
.5669 1.19172 m .56658 1.17334 L .5711 1.18108 L 0 .734 .093 r
F
.55676 1.05755 m .56998 1.19475 L .5684 1.13516 L 0 .109 .162 r
F
.5562 1.11998 m .56034 1.11585 L .56288 1.12162 L 0 .352 .029 r
F
.5562 1.11998 m .56288 1.12162 L .56109 1.12345 L F
.56242 1.14181 m .55839 1.12589 L .56315 1.13013 L 0 .474 .061 r
F
.55709 1.14448 m .56242 1.14181 L .56382 1.14848 L 0 .524 .057 r
F
.55709 1.14448 m .56382 1.14848 L .56155 1.14967 L F
.56598 1.16646 m .56155 1.14967 L .56382 1.14848 L 0 .62 .081 r
F
.56598 1.16646 m .56247 1.15737 L .56155 1.14967 L F
.5595 1.16648 m .56247 1.15737 L .56598 1.16646 L 0 .657 .074 r
F
.5595 1.16648 m .56598 1.16646 L .56658 1.17334 L F
.5595 1.16648 m .56658 1.17334 L .56386 1.17338 L F
.5669 1.19172 m .56386 1.17338 L .56658 1.17334 L 0 .734 .093 r
F
.5669 1.19172 m .56399 1.18124 L .56386 1.17338 L F
.55929 1.185 m .56399 1.18124 L .5669 1.19172 L 0 .741 .08 r
F
.55929 1.185 m .5669 1.19172 L .56671 1.19746 L F
.56521 1.21209 m .56671 1.19746 L .57112 1.20864 L 0 .812 .096 r
F
.55676 1.05755 m .56736 1.20026 L .56998 1.19475 L 0 .109 .162 r
F
.5684 1.13516 m .57553 1.16127 L .57076 1.12098 L 0 0 .122 r
F
.57383 1.22074 m .57112 1.20864 L .57144 1.19952 L 0 .777 .107 r
F
.56521 1.21209 m .57112 1.20864 L .57383 1.22074 L 0 .812 .096 r
F
.56521 1.21209 m .57383 1.22074 L .5732 1.22706 L F
.57563 1.2788 m .57371 1.26388 L .57523 1.25653 L 0 .881 .12 r
F
.57563 1.2788 m .58458 1.30243 L .58029 1.29535 L F
.56859 1.2755 m .57381 1.27913 L .57834 1.30306 L 0 .914 .1 r
F
.56859 1.2755 m .58003 1.3205 L .57779 1.31896 L F
.56859 1.2755 m .57834 1.30306 L .58003 1.3205 L F
.5716 1.3082 m .57779 1.31896 L .58239 1.34897 L 0 .945 .104 r
F
.5716 1.3082 m .58118 1.36487 L .57618 1.33817 L F
.5716 1.3082 m .58385 1.36951 L .58118 1.36487 L F
.5716 1.3082 m .58239 1.34897 L .58385 1.36951 L F
.57403 1.34244 m .57618 1.33817 L .58118 1.36487 L 0 .963 .104 r
F
.58455 1.41093 m .57403 1.34244 L .58585 1.40305 L F
.57403 1.34244 m .58118 1.36487 L .58585 1.40305 L F
.58302 1.38578 m .5684 1.13516 L .5817 1.38638 L 0 0 .122 r
F
.58003 1.3205 m .58029 1.29535 L .58458 1.30243 L 0 .897 .137 r
F
.58003 1.3205 m .57834 1.30306 L .58029 1.29535 L F
.58302 1.38578 m .58112 1.29054 L .5684 1.13516 L 0 0 .122 r
F
.56521 1.21209 m .5732 1.22706 L .56963 1.22334 L 0 .812 .096 r
F
.57067 1.24305 m .56963 1.22334 L .5732 1.22706 L 0 .856 .108 r
F
.56504 1.24517 m .57563 1.2788 L .57381 1.27913 L 0 .873 .094 r
F
.56504 1.24517 m .57371 1.26388 L .57563 1.2788 L F
.56859 1.2755 m .57779 1.31896 L .57311 1.29945 L 0 .914 .1 r
F
.5716 1.3082 m .57311 1.29945 L .57779 1.31896 L 0 .945 .104 r
F
.58282 1.40958 m .57403 1.34244 L .58292 1.40969 L 0 .963 .104 r
F
.58282 1.40958 m .57865 1.38043 L .57403 1.34244 L F
.58292 1.40969 m .57403 1.34244 L .58455 1.41093 L F
.58229 1.40905 m .57865 1.38043 L .58282 1.40958 L 0 .953 .097 r
F
.58229 1.40905 m .57582 1.37618 L .57865 1.38043 L F
.5817 1.38638 m .5684 1.13516 L .5791 1.38791 L 0 0 .122 r
F
.56504 1.24517 m .56928 1.24448 L .57371 1.26388 L 0 .873 .094 r
F
.56504 1.24517 m .57381 1.27913 L .56947 1.26461 L F
.56859 1.2755 m .56947 1.26461 L .57381 1.27913 L 0 .914 .1 r
F
.5791 1.38791 m .5684 1.13516 L .57548 1.32507 L 0 0 .122 r
F
.5684 1.13516 m .56998 1.19475 L .57548 1.32507 L F
.56539 1.14755 m .57076 1.12097 L .57553 1.16126 L 0 .64 .21 r
F
.56539 1.14755 m .57849 1.24611 L .5776 1.31996 L F
.56539 1.14755 m .57553 1.16126 L .57849 1.24611 L F
.57304 1.15218 m .57758 1.23895 L .57294 1.15181 L 0 1 .154 r
F
.57758 1.23895 m .57755 1.23844 L .57294 1.15181 L F
.5772 1.23302 m .57795 1.24592 L .57796 1.24751 L F
.57174 1.12925 m .57755 1.23844 L .5772 1.23302 L F
.57755 1.23844 m .57795 1.24592 L .5772 1.23302 L F
.54957 .9869 m .54118 .9814 L .54636 .98849 L 0 .247 .28 r
F
.54957 .9869 m .54035 .97822 L .54118 .9814 L F
.54957 .9869 m .54394 .98057 L .54035 .97822 L F
.5467 .97844 m .54394 .98057 L .54957 .9869 L 0 .22 .265 r
F
.5467 .97844 m .54957 .9869 L .55285 .98914 L F
.54372 .97352 m .53614 .97309 L .537 .97324 L 0 .565 .208 r
F
.53641 .96583 m .53909 .97327 L .53825 .96986 L 0 .255 .292 r
F
.54372 .97352 m .53902 .97321 L .53614 .97309 L 0 .565 .208 r
F
.54075 .97389 m .53902 .97321 L .54372 .97352 L 0 0 0 r
F
.54075 .97389 m .54372 .97352 L .54626 .97394 L F
.54075 .97389 m .54626 .97394 L .54493 .97418 L F
.54703 .97677 m .54294 .97457 L .54703 .97485 L F
.54703 .97677 m .5416 .97485 L .54294 .97457 L F
.54703 .97677 m .54336 .97579 L .5416 .97485 L F
.54289 .97798 m .54336 .97579 L .54703 .97677 L F
.54289 .97798 m .54703 .97677 L .54846 .97794 L F
.54289 .97798 m .54846 .97794 L .54666 .97851 L F
.55074 .98141 m .54666 .97851 L .54846 .97794 L F
.55074 .98141 m .54764 .98 L .54666 .97851 L F
.54547 .98291 m .54764 .98 L .55074 .98141 L 0 .05 0 r
F
.54547 .98291 m .54397 .97926 L .54764 .98 L F
.54547 .98291 m .55074 .98141 L .5514 .98297 L F
.54547 .98291 m .5514 .98297 L .54916 .98365 L F
.5519 .98745 m .54916 .98365 L .5514 .98297 L 0 .132 0 r
F
.5519 .98745 m .54937 .98557 L .54916 .98365 L F
.54553 .98824 m .54937 .98557 L .5519 .98745 L 0 .19 0 r
F
.54553 .98824 m .54579 .98434 L .54937 .98557 L F
.54553 .98824 m .5519 .98745 L .5518 .98913 L F
.54553 .98824 m .5518 .98913 L .54913 .98948 L F
.53641 .96583 m .5348 .96836 L .53664 .97238 L 0 .255 .292 r
F
.53641 .96583 m .5341 .96496 L .5348 .96836 L F
.53641 .96583 m .53479 .96388 L .5341 .96496 L F
.54454 .95751 m .5274 .95926 L .52765 .96329 L 0 1 .474 r
F
.54454 .95751 m .53464 .95679 L .5274 .95926 L F
.54315 .94559 m .52703 .9528 L .53464 .95679 L 0 1 .453 r
F
.53433 .95606 m .53479 .96388 L .53641 .96583 L 0 .237 .284 r
F
.53433 .95606 m .53641 .96583 L .53697 .96437 L F
.5437 .96866 m .53697 .96437 L .54151 .97207 L 0 .197 .254 r
F
.53776 .97435 m .54075 .97389 L .54294 .97457 L 0 0 0 r
F
.5384 .97434 m .53848 .98031 L .54038 .98229 L 0 .275 .303 r
F
.5384 .97434 m .53654 .97645 L .53848 .98031 L F
.5384 .97434 m .54038 .98229 L .54118 .9814 L F
.5384 .97434 m .54118 .9814 L .54035 .97821 L F
.53776 .97435 m .54294 .97457 L .5416 .97485 L 0 0 0 r
F
.54289 .97798 m .53959 .97526 L .54336 .97579 L F
.53558 .96464 m .54687 .97338 L .54317 .97612 L 0 .335 .161 r
F
.54687 .97338 m .55441 .98844 L .54991 .98349 L 0 .302 .173 r
F
.54316 .99192 m .5451 .98931 L .5486 .99142 L 0 .275 .007 r
F
.5455 .99445 m .54991 .98349 L .55441 .98844 L 0 .413 .181 r
F
.5455 .99445 m .54609 .98606 L .54991 .98349 L F
.54356 .97329 m .55505 1.01233 L .55382 .98152 L 0 .258 .221 r
F
.54547 .98291 m .54216 .97968 L .54397 .97926 L 0 .05 0 r
F
.54547 .98291 m .5428 .98124 L .54216 .97968 L F
.54038 .98229 m .54024 .98758 L .54227 .98961 L 0 .297 .315 r
F
.54038 .98229 m .53822 .98389 L .54024 .98758 L F
.54038 .98229 m .54227 .98961 L .5432 .98893 L F
.54038 .98229 m .5432 .98893 L .5424 .98599 L F
.54016 .9834 m .5428 .98124 L .54547 .98291 L 0 .116 0 r
F
.54016 .9834 m .54547 .98291 L .54579 .98434 L F
.54016 .9834 m .54579 .98434 L .54353 .98458 L F
.54553 .98824 m .54353 .98458 L .54579 .98434 L 0 .19 0 r
F
.54325 .9996 m .55106 1.00888 L .54696 1.00434 L 0 .357 .01 r
F
.54516 1.00406 m .54696 1.00434 L .55106 1.00888 L 0 .381 .015 r
F
.54516 1.00406 m .55333 1.01549 L .54897 1.00972 L F
.54674 1.00839 m .54897 1.00972 L .55333 1.01549 L 0 .402 .016 r
F
.54674 1.00839 m .55517 1.02244 L .5506 1.01515 L F
.54038 .98229 m .53756 .981 L .53822 .98389 L 0 .297 .315 r
F
.53107 .96616 m .53247 .97398 L .53413 .97499 L 0 .316 .336 r
F
.53107 .96616 m .53413 .97499 L .53429 .97495 L F
.53107 .96616 m .53435 .97512 L .53558 .97464 L F
.53558 .97464 m .53653 .97472 L .53613 .97451 L 0 .916 .309 r
F
.53107 .96616 m .53558 .97464 L .53584 .97328 L 0 .316 .336 r
F
.53558 .97464 m .53613 .97451 L .53611 .9745 L 0 .916 .309 r
F
.53558 .97464 m .53654 .97644 L .53611 .9745 L 0 .316 .336 r
F
.53558 .97464 m .53611 .9745 L .53584 .97328 L F
.53558 .97464 m .53611 .9745 L .53585 .97437 L 0 .916 .309 r
F
.53109 .97427 m .53558 .97464 L .53585 .97437 L F
.53429 .97495 m .53413 .97499 L .53435 .97512 L 0 .316 .336 r
F
.53558 .97464 m .53435 .97512 L .53653 .97472 L 0 .916 .309 r
F
.53558 .97464 m .53435 .97512 L .53654 .97644 L 0 .316 .336 r
F
.53109 .97427 m .53248 .97546 L .53435 .97512 L 0 .916 .309 r
F
.53109 .97427 m .53435 .97512 L .53558 .97464 L F
.54038 .98229 m .53848 .98031 L .53756 .981 L 0 .297 .315 r
F
.5384 .97434 m .53768 .97404 L .53654 .97645 L 0 .275 .303 r
F
.53768 .97404 m .53584 .97328 L .53611 .9745 L F
.5384 .97392 m .53768 .97404 L .53653 .97472 L 0 .73 .242 r
F
.53768 .97404 m .53611 .9745 L .53653 .97472 L F
.53768 .97404 m .53611 .9745 L .53654 .97645 L 0 .275 .303 r
F
.53768 .97404 m .53585 .97437 L .53611 .9745 L 0 .73 .242 r
F
.53475 .97481 m .53397 .9734 L .53776 .97435 L 0 0 0 r
F
.53475 .97481 m .53776 .97435 L .53959 .97526 L F
.53475 .97481 m .53959 .97526 L .53825 .97553 L F
.53172 .97511 m .53475 .97481 L .53623 .97587 L F
.53872 .97885 m .53966 .97669 L .54289 .97798 L F
.53872 .97885 m .53623 .97587 L .53966 .97669 L F
.53872 .97885 m .54289 .97798 L .54397 .97926 L F
.53172 .97511 m .53623 .97587 L .53488 .97605 L F
.53872 .97885 m .53488 .97605 L .53623 .97587 L F
.53872 .97885 m .53595 .97733 L .53488 .97605 L F
.53872 .97885 m .54397 .97926 L .54216 .97968 L F
.53453 .97901 m .53595 .97733 L .53872 .97885 L 0 .024 0 r
F
.53453 .97901 m .53872 .97885 L .53945 .98007 L F
.54016 .9834 m .53945 .98007 L .5428 .98124 L 0 .116 0 r
F
.53453 .97901 m .53945 .98007 L .53763 .98018 L 0 .024 0 r
F
.54016 .9834 m .53763 .98018 L .53945 .98007 L 0 .116 0 r
F
.54016 .9834 m .53794 .9816 L .53763 .98018 L F
.53482 .98225 m .53794 .9816 L .54016 .9834 L 0 .152 0 r
F
.54553 .98824 m .54342 .98625 L .54353 .98458 L 0 .19 0 r
F
.53482 .98225 m .54016 .9834 L .54014 .9844 L 0 .152 0 r
F
.53912 .98688 m .54342 .98625 L .54553 .98824 L 0 .22 0 r
F
.53912 .98688 m .54014 .9844 L .54342 .98625 L F
.53482 .98225 m .54014 .9844 L .53787 .98393 L 0 .152 0 r
F
.53912 .98688 m .53787 .98393 L .54014 .9844 L 0 .22 0 r
F
.53912 .98688 m .54553 .98824 L .5451 .98931 L F
.53912 .98688 m .5451 .98931 L .54241 .98874 L F
.54316 .99192 m .54241 .98874 L .5451 .98931 L 0 .275 .007 r
F
.53481 .97463 m .54609 .98606 L .5455 .99445 L 0 .408 .165 r
F
.53462 .97428 m .53471 .97437 L .53481 .97463 L F
.53471 .97437 m .54609 .98606 L .53481 .97463 L F
.54795 1.01241 m .54751 1.01085 L .5506 1.01515 L 0 .42 .011 r
F
.54795 1.01241 m .5506 1.01515 L .55517 1.02244 L F
.54795 1.01241 m .55657 1.02954 L .55183 1.02042 L F
.5488 1.01583 m .5485 1.01455 L .55183 1.02042 L 0 .433 0 r
F
.5488 1.01583 m .55183 1.02042 L .55657 1.02954 L F
.5488 1.01583 m .5575 1.0364 L .55265 1.02519 L F
.54101 .99516 m .5484 1.00272 L .5446 .99915 L 0 .329 0 r
F
.54325 .9996 m .5446 .99915 L .5484 1.00272 L 0 .357 .01 r
F
.54674 1.00839 m .54615 1.00668 L .54897 1.00972 L 0 .402 .016 r
F
.5455 .99445 m .55269 1.02512 L .54832 1.01117 L 0 .413 .181 r
F
.5455 .99445 m .55653 1.02251 L .55323 1.02475 L F
.5482 1.00597 m .55323 1.02475 L .55269 1.02512 L F
.5455 .99445 m .55323 1.02475 L .5482 1.00597 L F
.55653 1.02251 m .56383 1.07434 L .55933 1.05215 L 0 .381 .193 r
F
.55382 .98152 m .55505 1.01233 L .55849 1.04437 L 0 .242 .209 r
F
.55882 1.04557 m .55849 1.04437 L .55933 1.05214 L F
.55382 .98152 m .55849 1.04437 L .55882 1.04557 L F
.55113 1.01628 m .54831 1.01117 L .55268 1.02511 L 0 .258 .221 r
F
.54289 .97798 m .53825 .97553 L .53959 .97526 L 0 0 0 r
F
.54289 .97798 m .53966 .97669 L .53825 .97553 L F
.53471 .97437 m .54317 .97612 L .54609 .98606 L 0 .408 .165 r
F
.53462 .97428 m .53468 .97429 L .53471 .97437 L F
.53468 .97429 m .54317 .97612 L .53471 .97437 L F
.55059 1.01322 m .54793 1.00811 L .55113 1.01628 L 0 .258 .221 r
F
.54356 .97329 m .54768 1.00609 L .55059 1.01322 L F
.54768 1.00609 m .54793 1.00811 L .55059 1.01322 L F
.54793 1.00811 m .54831 1.01117 L .55113 1.01628 L F
.54356 .97329 m .55268 1.02511 L .55505 1.01233 L F
.55382 .98152 m .55933 1.05214 L .56383 1.07433 L 0 .242 .209 r
F
.55105 1.00049 m .56241 1.03775 L .56076 1.01987 L 0 .032 .151 r
F
.55105 1.00049 m .56052 1.04063 L .56241 1.03775 L F
.55408 1.02196 m .56472 1.06314 L .56052 1.04063 L 0 0 .104 r
F
.54925 1.01831 m .55265 1.02519 L .5575 1.0364 L 0 .435 0 r
F
.55408 1.02196 m .56615 1.0791 L .56472 1.06314 L 0 0 .104 r
F
.54925 1.01831 m .55795 1.0424 L .55303 1.02898 L 0 .435 0 r
F
.55408 1.02196 m .56383 1.07434 L .56615 1.0791 L 0 0 .104 r
F
.56076 1.01987 m .56606 1.00318 L .56233 1.00508 L 0 .09 .167 r
F
.56966 1.00598 m .56968 1.00602 L .56977 1.00634 L 0 .418 0 r
F
.56862 1.00609 m .56966 1.00598 L .56977 1.00634 L 0 .286 .069 r
F
.56859 1.00183 m .56959 1.00567 L .56968 1.00602 L 0 .418 0 r
F
.56859 1.00183 m .56966 1.00598 L .56977 1.00634 L F
.56862 1.00609 m .56919 1.00427 L .56945 1.00522 L 0 .286 .069 r
F
.56923 1.00413 m .568 .99942 L .56808 .99971 L 0 .418 0 r
F
.56862 1.00609 m .56824 1.00007 L .56923 1.00413 L 0 .286 .069 r
F
.56859 1.00183 m .56941 1.00489 L .56949 1.00518 L 0 .418 0 r
F
.56949 1.00518 m .56923 1.00413 L .5695 1.00517 L 0 .286 .069 r
F
.56923 1.00413 m .56942 1.00352 L .5695 1.00517 L F
.56859 1.00183 m .568 .99942 L .56923 1.00413 L 0 .418 0 r
F
.56827 1.00044 m .568 .99942 L .56824 1.00007 L 0 .286 .069 r
F
.56859 1.00183 m .56923 1.00413 L .56942 1.00492 L 0 .418 0 r
F
.56862 1.00609 m .56773 .99954 L .568 .99942 L 0 .286 .069 r
F
.5676 .99836 m .568 .99942 L .56773 .99954 L 0 .247 .049 r
F
.56713 .99719 m .56715 .99718 L .5676 .99836 L F
.56765 .99849 m .56796 .99926 L .56772 .99838 L 0 0 .086 r
F
.56859 1.00183 m .56658 .99429 L .56772 .99838 L 0 .418 0 r
F
.56672 .99262 m .56658 .99429 L .56859 1.00183 L 0 0 .125 r
F
.56672 .99262 m .56859 1.00183 L .56745 .99459 L F
.56672 .99262 m .56745 .99459 L .56716 .99278 L F
.56946 .97338 m .56997 .94007 L .57349 .88455 L 0 .16 .157 r
F
.56881 .98736 m .56781 .9838 L .57045 1.002 L 0 0 .096 r
F
.5526 .90332 m .56287 .9668 L .56079 .95038 L 0 .112 .188 r
F
.5526 .90332 m .56142 .96213 L .56287 .9668 L F
.55511 .90476 m .56079 .95038 L .56489 .97355 L 0 .106 .182 r
F
.55487 .94309 m .56241 .97602 L .55888 .95923 L 0 0 .138 r
F
.55487 .94309 m .55719 .96039 L .5612 .97658 L F
.55714 .90293 m .56598 .96341 L .56124 .92821 L 0 .108 .179 r
F
.55868 .89647 m .5677 .96448 L .56276 .92406 L 0 .116 .179 r
F
.55868 .89647 m .56124 .92821 L .56598 .96341 L F
.5591 .95503 m .55888 .95923 L .56241 .97602 L 0 0 .125 r
F
.56287 .9668 m .56142 .96213 L .56326 .97323 L 0 0 .111 r
F
.55819 .97933 m .56997 .94007 L .56946 .97338 L 0 .256 .176 r
F
.56406 .98089 m .57688 1.08203 L .57397 .94109 L 0 .224 .198 r
F
.56076 1.01987 m .57048 1.03 L .56606 1.00318 L 0 .09 .167 r
F
.56076 1.01987 m .57265 1.06801 L .57048 1.03 L F
.56076 1.01987 m .56241 1.03775 L .56682 1.0648 L F
.56539 1.14755 m .56644 1.11517 L .57076 1.12097 L 0 .64 .21 r
F
.56063 1.01705 m .56737 1.10506 L .56632 1.09613 L 0 1 .121 r
F
.55181 1.05709 m .55564 1.06612 L .55458 1.05718 L 0 1 .26 r
F
.55181 1.05709 m .55434 1.0797 L .55564 1.06612 L F
.54633 1.04642 m .54771 1.05283 L .55539 1.05331 L 0 1 .501 r
F
.54633 1.04642 m .55539 1.05331 L .55471 1.05086 L F
.54494 1.03887 m .54633 1.04642 L .55369 1.04683 L 0 1 .485 r
F
.54494 1.03887 m .55369 1.04683 L .553 1.04392 L F
.54979 1.02202 m .54644 1.02017 L .54898 1.03027 L 0 .117 .189 r
F
.54979 1.02202 m .54579 1.01767 L .54644 1.02017 L F
.54979 1.02202 m .54722 1.01847 L .54579 1.01767 L F
.54979 1.02202 m .54898 1.03027 L .55172 1.04129 L F
.54979 1.02202 m .55172 1.04129 L .55316 1.04211 L F
.55179 1.06894 m .54051 1.07196 L .55314 1.0738 L 0 1 .528 r
F
.55179 1.06894 m .53088 1.06899 L .54051 1.07196 L F
.55179 1.06894 m .53064 1.06687 L .53088 1.06899 L F
.55179 1.06894 m .53959 1.06685 L .53064 1.06687 L F
.55044 1.0639 m .53959 1.06685 L .55179 1.06894 L 0 1 .525 r
F
.55181 1.05709 m .55153 1.08888 L .55434 1.0797 L 0 1 .26 r
F
.55181 1.05709 m .54876 1.08882 L .55153 1.08888 L F
.55181 1.05709 m .54787 1.07954 L .54876 1.08882 L F
.55007 1.0715 m .55181 1.05711 L .55325 1.05651 L 0 0 0 r
F
.55007 1.0715 m .55325 1.05651 L .55253 1.06456 L F
.54559 1.01203 m .55782 1.08698 L .55676 1.05755 L 0 .182 .195 r
F
.56242 1.14181 m .55659 1.12732 L .55839 1.12589 L 0 .474 .061 r
F
.56242 1.14181 m .55831 1.13414 L .55659 1.12732 L F
.55709 1.14448 m .55831 1.13414 L .56242 1.14181 L 0 .524 .057 r
F
.55676 1.05755 m .56233 1.1479 L .56736 1.20026 L 0 .109 .162 r
F
.56034 1.11585 m .55356 1.10317 L .55869 1.10609 L 0 .307 .027 r
F
.56034 1.11585 m .55228 1.10456 L .55356 1.10317 L F
.56034 1.11585 m .55518 1.10998 L .55228 1.10456 L F
.5562 1.11998 m .55518 1.10998 L .56034 1.11585 L 0 .352 .029 r
F
.55676 1.05755 m .55782 1.08698 L .56233 1.1479 L 0 .109 .162 r
F
.55434 1.06291 m .56383 1.07435 L .56644 1.11517 L 0 .587 .2 r
F
.56063 1.01705 m .56719 1.1083 L .56346 1.06715 L 0 1 .121 r
F
.56719 1.1083 m .56747 1.11208 L .56694 1.10621 L F
.56719 1.1083 m .56694 1.10621 L .56346 1.06715 L F
.55408 1.02196 m .55933 1.05215 L .56383 1.07434 L 0 0 .104 r
F
.55665 1.03998 m .56383 1.07435 L .55933 1.05216 L 0 0 .06 r
F
.55676 1.05755 m .56383 1.07436 L .55933 1.05216 L 0 .109 .162 r
F
.55434 1.06291 m .55933 1.05216 L .56383 1.07435 L 0 .587 .2 r
F
.55114 .97368 m .54489 .96556 L .54624 .97007 L 0 .077 .178 r
F
.55114 .97368 m .54698 .9671 L .54489 .96556 L F
.54695 .96004 m .54698 .9671 L .55114 .97368 L 0 .083 .186 r
F
.54695 .96004 m .55114 .97368 L .5529 .97449 L F
.54695 .96004 m .5529 .97449 L .55109 .96898 L F
.55596 .97678 m .55109 .96898 L .5529 .97449 L 0 0 .148 r
F
.55596 .97678 m .55239 .96996 L .55109 .96898 L F
.55061 .95897 m .54835 .95973 L .55239 .96996 L 0 0 .155 r
F
.55061 .95897 m .55239 .96996 L .55596 .97678 L F
.55061 .95897 m .55694 .97647 L .55466 .96922 L F
.55061 .95897 m .55596 .97678 L .55694 .97647 L F
.54315 .94559 m .54454 .95751 L .55146 .95443 L 0 1 .453 r
F
.54315 .94559 m .55146 .95443 L .55077 .94958 L F
.55168 .95102 m .55124 .95682 L .55518 .96893 L 0 0 .146 r
F
.55815 .97582 m .55466 .96922 L .55694 .97647 L 0 0 .125 r
F
.55815 .97582 m .55518 .96893 L .55466 .96922 L F
.55168 .95102 m .55518 .96893 L .55815 .97582 L 0 0 .146 r
F
.55168 .95102 m .55835 .97334 L .55563 .96314 L F
.55168 .95102 m .55815 .97582 L .55835 .97334 L F
.54924 .92584 m .55256 .94639 L .55174 .93564 L 0 .422 .381 r
F
.55021 .93121 m .55776 .96663 L .55719 .96039 L 0 .02 .154 r
F
.55021 .93121 m .55537 .96026 L .55776 .96663 L F
.55776 .96663 m .55563 .96314 L .55835 .97334 L 0 0 .121 r
F
.55776 .96663 m .55537 .96026 L .55563 .96314 L F
.54687 .97338 m .55872 .96232 L .55819 .97933 L 0 .302 .173 r
F
.54068 .95745 m .5437 .96866 L .54624 .97007 L 0 .184 .25 r
F
.54068 .95745 m .54624 .97007 L .54489 .96556 L F
.54695 .96004 m .54286 .95818 L .54698 .9671 L 0 .083 .186 r
F
.54924 .92584 m .55116 .94724 L .55256 .94639 L 0 .422 .381 r
F
.55021 .93121 m .55154 .94572 L .55537 .96026 L 0 .02 .154 r
F
.55021 .93121 m .55719 .96039 L .55404 .94572 L F
.55487 .94309 m .55404 .94572 L .55719 .96039 L 0 0 .138 r
F
.54687 .97338 m .55567 .9523 L .55872 .96232 L 0 .302 .173 r
F
.55061 .95897 m .54653 .95291 L .54835 .95973 L 0 0 .155 r
F
.55061 .95897 m .54749 .95258 L .54653 .95291 L F
.54524 .93637 m .54749 .95258 L .55061 .95897 L 0 .066 .179 r
F
.54524 .93637 m .55124 .95682 L .54895 .94755 L F
.54524 .93637 m .55061 .95897 L .55124 .95682 L F
.55168 .95102 m .54895 .94755 L .55124 .95682 L 0 0 .146 r
F
.54687 .97338 m .55108 .95585 L .55567 .9523 L 0 .302 .173 r
F
.54687 .97338 m .54731 .96488 L .55108 .95585 L F
.5437 .96866 m .53609 .96046 L .53697 .96437 L 0 .197 .254 r
F
.5437 .96866 m .53897 .96229 L .53609 .96046 L F
.54068 .95745 m .53897 .96229 L .5437 .96866 L 0 .184 .25 r
F
.53558 .96464 m .54731 .96488 L .54687 .97338 L 0 .335 .161 r
F
.54356 .97329 m .55382 .98152 L .54991 .95949 L 0 .258 .221 r
F
.54967 .8996 m .5591 .95503 L .55741 .94128 L 0 .126 .198 r
F
.54967 .8996 m .55746 .95025 L .5591 .95503 L F
.54967 .8996 m .55358 .93146 L .55746 .95025 L F
.5526 .90332 m .56079 .95038 L .55658 .92397 L 0 .112 .188 r
F
.5526 .90332 m .55741 .94128 L .56142 .96213 L F
.55511 .90476 m .55658 .92397 L .56079 .95038 L 0 .106 .182 r
F
.5591 .95503 m .55746 .95025 L .55888 .95923 L 0 0 .125 r
F
.54005 .92409 m .54784 .92183 L .54704 .92674 L 0 .07 .166 r
F
.55116 .94726 m .54705 .92687 L .54784 .92211 L 0 .769 .079 r
F
.55116 .94726 m .54846 .93764 L .54705 .92687 L F
.54924 .92584 m .54597 .92785 L .54846 .93763 L 0 .422 .381 r
F
.54924 .92584 m .54532 .92439 L .54597 .92785 L F
.54924 .92584 m .54672 .92353 L .54532 .92439 L F
.54924 .92584 m .54846 .93763 L .55116 .94724 L F
.54737 .91373 m .54435 .91867 L .54672 .92353 L 0 .778 .433 r
F
.54518 .9195 m .55168 .95102 L .55154 .94572 L 0 .088 .189 r
F
.54518 .9195 m .54914 .94507 L .55168 .95102 L F
.55168 .95102 m .54914 .94507 L .54895 .94755 L 0 0 .146 r
F
.54967 .8996 m .55741 .94128 L .55353 .91826 L 0 .126 .198 r
F
.5526 .90332 m .55353 .91826 L .55741 .94128 L 0 .112 .188 r
F
.55487 .94309 m .55305 .93832 L .55404 .94572 L 0 0 .138 r
F
.54786 .95245 m .55936 .93841 L .55567 .9523 L 0 .255 .163 r
F
.55382 .98152 m .55979 .94188 L .55586 .95142 L 0 .242 .209 r
F
.55511 .90476 m .56366 .95812 L .55916 .92765 L 0 .106 .182 r
F
.55714 .90293 m .55916 .92765 L .56366 .95812 L 0 .108 .179 r
F
.55819 .97933 m .56698 .9256 L .56997 .94007 L 0 .256 .176 r
F
.55819 .97933 m .56249 .93932 L .56698 .9256 L F
.55819 .97933 m .55872 .96232 L .56249 .93932 L F
.55382 .98152 m .56406 .98089 L .55979 .94188 L 0 .242 .209 r
F
.54762 .97793 m .55632 .97767 L .55243 .96711 L 0 .219 .235 r
F
.54762 .97793 m .55815 .99412 L .55632 .97767 L F
.54762 .97793 m .55669 1.00269 L .55815 .99412 L F
.54762 .97793 m .55292 .99761 L .55669 1.00269 L F
.55105 1.00049 m .55669 1.00269 L .55292 .99761 L 0 .032 .151 r
F
.55105 1.00049 m .56076 1.01987 L .55669 1.00269 L F
.55105 1.00049 m .55636 1.02659 L .56052 1.04063 L F
.55408 1.02196 m .56052 1.04063 L .55636 1.02659 L 0 0 .104 r
F
.55815 1.03484 m .5628 1.07278 L .55899 1.04385 L 0 .978 .107 r
F
.55793 1.03247 m .55978 1.04385 L .55806 1.03379 L F
.55273 .97639 m .55956 1.04171 L .55793 1.03247 L F
.55956 1.04171 m .55978 1.04385 L .55793 1.03247 L F
.55273 .97639 m .55767 1.02964 L .55439 1.00484 L F
.55767 1.02964 m .55899 1.04385 L .5568 1.02528 L F
.55767 1.02964 m .5568 1.02528 L .55439 1.00484 L F
.53433 .95606 m .53697 .96437 L .53609 .96045 L 0 .237 .284 r
F
.54315 .94559 m .53464 .95679 L .54454 .95751 L 0 1 .453 r
F
.54068 .95745 m .53478 .9542 L .53897 .96229 L 0 .184 .25 r
F
.54695 .96004 m .5415 .95284 L .54286 .95818 L 0 .083 .186 r
F
.53558 .96464 m .54418 .95829 L .54731 .96488 L 0 .335 .161 r
F
.54356 .97329 m .54991 .95949 L .54592 .96068 L 0 .258 .221 r
F
.54068 .95745 m .5339 .94977 L .53478 .9542 L 0 .184 .25 r
F
.54068 .95745 m .53642 .95115 L .5339 .94977 L F
.54315 .94559 m .52678 .94821 L .52703 .9528 L 0 1 .453 r
F
.54315 .94559 m .53369 .94511 L .52678 .94821 L F
.53764 .94425 m .53642 .95115 L .54068 .95745 L 0 .182 .251 r
F
.53764 .94425 m .54068 .95745 L .54286 .95818 L F
.53764 .94425 m .54286 .95818 L .5415 .95284 L F
.53629 .95484 m .54418 .95829 L .53958 .95798 L 0 .29 .156 r
F
.54695 .96004 m .54325 .95363 L .5415 .95284 L 0 .083 .186 r
F
.54273 .94327 m .53947 .94401 L .54325 .95363 L 0 .108 .204 r
F
.54273 .94327 m .54325 .95363 L .54695 .96004 L F
.54273 .94327 m .54695 .96004 L .54835 .95973 L F
.54273 .94327 m .54835 .95973 L .54653 .95291 L F
.54524 .93637 m .54378 .94141 L .54749 .95258 L 0 .066 .179 r
F
.53629 .95484 m .54786 .95245 L .54418 .95829 L 0 .29 .156 r
F
.53224 .94501 m .53285 .95413 L .53433 .95606 L 0 .226 .279 r
F
.53224 .94501 m .5312 .94938 L .53285 .95413 L F
.53224 .94501 m .53046 .94498 L .5312 .94938 L F
.53224 .94501 m .53433 .95606 L .53477 .9542 L F
.53224 .94501 m .53477 .9542 L .53389 .94976 L F
.53764 .94425 m .53257 .94258 L .53642 .95115 L 0 .182 .251 r
F
.51947 .9465 m .52703 .9528 L .52678 .94821 L 0 1 .486 r
F
.51947 .9465 m .51976 .95729 L .52703 .9528 L F
.52084 .93264 m .50912 .93928 L .52112 .93839 L 0 1 .539 r
F
.51917 .93476 m .51947 .9465 L .52641 .94094 L 0 1 .473 r
F
.52818 .94807 m .52034 .944 L .52444 .95151 L 0 .289 .321 r
F
.52818 .94807 m .52008 .9402 L .52034 .944 L F
.52818 .94807 m .52343 .94194 L .52008 .9402 L F
.51917 .93476 m .52641 .94094 L .52615 .93584 L 0 1 .473 r
F
.5267 .93717 m .52343 .94194 L .52818 .94807 L 0 .278 .313 r
F
.5267 .93717 m .52818 .94807 L .53119 .94938 L F
.5267 .93717 m .53119 .94938 L .53046 .94498 L F
.53224 .94501 m .53091 .9431 L .53046 .94498 L 0 .226 .279 r
F
.53013 .93219 m .53091 .9431 L .53224 .94501 L 0 .223 .277 r
F
.53013 .93219 m .53224 .94501 L .53257 .94258 L F
.53764 .94425 m .53169 .93744 L .53257 .94258 L 0 .182 .251 r
F
.53764 .94425 m .53386 .93814 L .53169 .93744 L F
.53459 .92841 m .53386 .93814 L .53764 .94425 L 0 .193 .256 r
F
.52495 .94887 m .53685 .94155 L .53674 .94525 L 0 .29 .138 r
F
.53629 .95484 m .54486 .94125 L .54815 .94438 L 0 .29 .156 r
F
.54273 .94327 m .5381 .93757 L .53947 .94401 L 0 .108 .204 r
F
.54273 .94327 m .5395 .93725 L .5381 .93757 L F
.53875 .91692 m .53154 .91564 L .54005 .92409 L 0 .346 .296 r
F
.5385 .92246 m .5395 .93725 L .54273 .94327 L 0 .149 .227 r
F
.5385 .92246 m .54273 .94327 L .54378 .94141 L F
.53629 .95484 m .54017 .94513 L .54486 .94125 L 0 .29 .156 r
F
.52818 .94807 m .52444 .95151 L .52966 .95773 L 0 .289 .321 r
F
.52818 .94807 m .52966 .95773 L .53303 .95949 L F
.52818 .94807 m .53303 .95949 L .53229 .9556 L F
.52495 .94887 m .53674 .94525 L .53313 .9486 L 0 .29 .138 r
F
.53629 .95484 m .5365 .95095 L .54017 .94513 L 0 .29 .156 r
F
.52966 .95773 m .52444 .95151 L .52073 .94933 L 0 .303 .329 r
F
.52471 .95242 m .53313 .9486 L .5365 .95095 L 0 .305 .14 r
F
.53629 .95484 m .54815 .94438 L .54786 .95245 L 0 .29 .156 r
F
.52471 .95242 m .5365 .95095 L .53629 .95484 L 0 .305 .14 r
F
.53558 .96464 m .53958 .95798 L .54418 .95829 L 0 .335 .161 r
F
.53558 .96464 m .53589 .9607 L .53958 .95798 L F
.53187 .94493 m .53993 .96055 L .5422 .95004 L 0 .326 .244 r
F
.52495 .94887 m .53313 .9486 L .52843 .94936 L 0 .29 .138 r
F
.52471 .95242 m .52843 .94936 L .53313 .9486 L 0 .305 .14 r
F
.53433 .95606 m .5323 .9556 L .53303 .95949 L 0 .237 .284 r
F
.53433 .95606 m .53285 .95413 L .5323 .9556 L F
.52471 .95242 m .53629 .95484 L .53267 .95647 L 0 .305 .14 r
F
.53187 .94493 m .53595 .9592 L .53993 .96055 L 0 .326 .244 r
F
.52966 .95773 m .5348 .96835 L .5341 .96496 L 0 .303 .329 r
F
.53433 .95606 m .53303 .95949 L .53479 .96388 L 0 .237 .284 r
F
.51976 .95729 m .52765 .96329 L .5274 .95926 L 0 1 .496 r
F
.52966 .95773 m .52098 .95264 L .52541 .95984 L 0 .303 .329 r
F
.52966 .95773 m .52541 .95984 L .53107 .96616 L F
.52966 .95773 m .53107 .96616 L .5348 .96835 L F
.52434 .95595 m .53558 .96464 L .532 .96441 L 0 .338 .142 r
F
.52434 .95595 m .53589 .9607 L .53558 .96464 L F
.52966 .95773 m .52073 .94933 L .52098 .95264 L 0 .303 .329 r
F
.52434 .95595 m .53267 .95647 L .53589 .9607 L 0 .338 .142 r
F
.53337 .96386 m .53993 .96055 L .53595 .9592 L 0 .274 .233 r
F
.53558 .96464 m .54317 .97612 L .53869 .97124 L 0 .335 .161 r
F
.53337 .96386 m .54356 .97329 L .53993 .96055 L 0 .274 .233 r
F
.53612 .95875 m .54538 .9648 L .54383 .95636 L 0 .26 .268 r
F
.54383 .95636 m .54538 .9648 L .54907 .96941 L 0 .341 .27 r
F
.54762 .97793 m .55243 .96711 L .54907 .96941 L 0 .219 .235 r
F
.53459 .92841 m .53764 .94425 L .53947 .94401 L 0 .193 .256 r
F
.53459 .92841 m .53947 .94401 L .5381 .93757 L F
.5385 .92246 m .54378 .94141 L .54195 .9329 L 0 .149 .227 r
F
.54524 .93637 m .54195 .9329 L .54378 .94141 L 0 .066 .179 r
F
.54524 .93637 m .54257 .93074 L .54195 .9329 L F
.53875 .91692 m .54005 .92409 L .54596 .92785 L 0 .346 .296 r
F
.53875 .91692 m .54596 .92785 L .54532 .92439 L F
.53744 .90791 m .53875 .91692 L .54434 .91867 L 0 .69 .445 r
F
.53744 .90791 m .54434 .91867 L .54369 .91451 L F
.53612 .89884 m .53744 .90791 L .54271 .9084 L 0 .891 .475 r
F
.53984 .90798 m .54524 .93637 L .54552 .93184 L 0 .149 .222 r
F
.53984 .90798 m .54257 .93074 L .54524 .93637 L F
.54518 .9195 m .54552 .93184 L .54914 .94507 L 0 .088 .189 r
F
.54518 .9195 m .55154 .94572 L .54881 .93272 L F
.53674 .94525 m .54848 .93294 L .54486 .94125 L 0 .265 .151 r
F
.53674 .94525 m .54486 .94125 L .54017 .94513 L F
.55021 .93121 m .54881 .93272 L .55154 .94572 L 0 .02 .154 r
F
.53984 .90798 m .54552 .93184 L .54322 .92015 L 0 .149 .222 r
F
.54737 .91373 m .54369 .91451 L .54435 .91867 L 0 .778 .433 r
F
.54737 .91373 m .54672 .92353 L .54924 .92584 L F
.54737 .91373 m .54499 .91239 L .54369 .91451 L F
.54737 .91373 m .54924 .92584 L .55054 .92373 L F
.54551 .90312 m .54499 .91239 L .54737 .91373 L 0 .895 .451 r
F
.54551 .90312 m .54272 .90841 L .54499 .91239 L F
.54551 .90312 m .54206 .90444 L .54272 .90841 L F
.54551 .90312 m .54326 .90217 L .54206 .90444 L F
.54365 .89313 m .54326 .90217 L .54551 .90312 L 0 .959 .461 r
F
.54365 .89313 m .54108 .89857 L .54326 .90217 L F
.54365 .89313 m .54043 .89471 L .54108 .89857 L F
.54365 .89313 m .54153 .89238 L .54043 .89471 L F
.54267 .88791 m .54824 .9265 L .55021 .93121 L 0 .173 .225 r
F
.54267 .88791 m .54471 .91096 L .54824 .9265 L F
.54518 .9195 m .54322 .92015 L .54552 .93184 L 0 .088 .189 r
F
.53674 .94525 m .54519 .92586 L .54862 .92573 L 0 .265 .151 r
F
.5385 .92246 m .53606 .92682 L .5395 .93725 L 0 .149 .227 r
F
.53984 .90798 m .53919 .91856 L .54257 .93074 L 0 .149 .222 r
F
.53674 .94525 m .54048 .93323 L .54519 .92586 L 0 .265 .151 r
F
.55021 .93121 m .54824 .9265 L .54881 .93272 L 0 .02 .154 r
F
.53674 .94525 m .54862 .92573 L .54848 .93294 L 0 .265 .151 r
F
.54634 .8943 m .55358 .93146 L .55005 .91125 L 0 .147 .21 r
F
.54634 .8943 m .55487 .94309 L .55358 .93146 L F
.54634 .8943 m .55305 .93832 L .55487 .94309 L F
.54737 .91373 m .55054 .92373 L .54975 .91859 L 0 .778 .433 r
F
.54551 .90312 m .54737 .91373 L .54857 .91147 L 0 .895 .451 r
F
.54551 .90312 m .54857 .91147 L .54779 .90711 L F
.54634 .8943 m .54933 .92128 L .55305 .93832 L 0 .147 .21 r
F
.54967 .8996 m .55005 .91125 L .55358 .93146 L 0 .126 .198 r
F
.55511 .90476 m .55416 .90449 L .55658 .92397 L 0 .106 .182 r
F
.55714 .90293 m .55639 .9041 L .55916 .92765 L 0 .108 .179 r
F
.54786 .95245 m .55648 .92017 L .55969 .92352 L 0 .255 .163 r
F
.54786 .95245 m .55185 .93055 L .55648 .92017 L F
.54786 .95245 m .55969 .92352 L .55936 .93841 L F
.54786 .95245 m .54815 .94438 L .55185 .93055 L F
.54786 .95245 m .55567 .9523 L .55108 .95585 L F
.54123 .93473 m .54991 .95949 L .55187 .93684 L 0 .349 .239 r
F
.54123 .93473 m .54592 .96068 L .54991 .95949 L F
.54123 .93473 m .5422 .95004 L .54592 .96068 L F
.53674 .94525 m .53685 .94155 L .54048 .93323 L 0 .265 .151 r
F
.53013 .93219 m .53257 .94258 L .53169 .93743 L 0 .223 .277 r
F
.52495 .94887 m .53337 .94106 L .53685 .94155 L 0 .29 .138 r
F
.53187 .94493 m .5422 .95004 L .54123 .93473 L 0 .326 .244 r
F
.53974 .93711 m .54487 .9446 L .54782 .93735 L 0 .475 .283 r
F
.53974 .93711 m .54141 .94449 L .54487 .9446 L F
.54383 .95636 m .54782 .93735 L .54487 .9446 L 0 .341 .27 r
F
.54383 .95636 m .5515 .94192 L .54782 .93735 L F
.54383 .95636 m .55348 .95531 L .5515 .94192 L F
.54383 .95636 m .55243 .96711 L .55348 .95531 L F
.54383 .95636 m .54907 .96941 L .55243 .96711 L F
.54762 .97793 m .54904 .98699 L .55292 .99761 L 0 .219 .235 r
F
.5445 .94106 m .54852 .97817 L .54509 .9583 L 0 .899 .096 r
F
.54852 .97817 m .54933 .98568 L .54765 .97478 L F
.54852 .97817 m .54765 .97478 L .54509 .9583 L F
.53612 .95875 m .54383 .95636 L .54044 .95157 L 0 .26 .268 r
F
.53612 .95875 m .54402 .96994 L .54538 .9648 L F
.54852 .97817 m .55322 1.00656 L .54933 .98568 L 0 .899 .096 r
F
.5445 .94106 m .5504 .9854 L .54852 .97817 L F
.5504 .9854 m .55322 1.00656 L .54852 .97817 L F
.54933 .98568 m .5495 .98354 L .54774 .97584 L 0 0 .054 r
F
.54246 .95492 m .5495 .98354 L .54743 .9758 L 0 .457 0 r
F
.54159 .95124 m .54288 .95652 L .54246 .95492 L F
.54288 .95652 m .5495 .98354 L .54246 .95492 L F
.53307 .94717 m .54141 .94449 L .53974 .93711 L 0 .33 .29 r
F
.53307 .94717 m .54044 .95157 L .54141 .94449 L F
.53949 .94242 m .54245 .9546 L .54159 .95124 L 0 .457 0 r
F
.54245 .9546 m .5495 .98354 L .54159 .95124 L F
.5445 .94106 m .55439 1.00484 L .55322 1.00656 L 0 .899 .096 r
F
.5445 .94106 m .55206 .98174 L .55439 1.00484 L F
.5445 .94106 m .54783 .95447 L .55206 .98174 L F
.53949 .94242 m .54774 .97584 L .5495 .98354 L 0 .457 0 r
F
.53949 .94242 m .54345 .95821 L .54774 .97584 L F
.55273 .97639 m .55439 1.00484 L .55206 .98174 L 0 .978 .107 r
F
.54367 .95954 m .55384 .99061 L .55137 .97767 L 0 0 .142 r
F
.53949 .94242 m .54743 .9758 L .54294 .95783 L 0 .457 0 r
F
.54294 .95783 m .5439 .96072 L .54367 .95954 L 0 0 .142 r
F
.5439 .96072 m .55384 .99061 L .54367 .95954 L F
.55273 .97639 m .56346 1.06715 L .5628 1.07278 L 0 .978 .107 r
F
.55359 1.0077 m .55786 1.03058 L .56015 1.04167 L 0 0 .054 r
F
.54933 .98568 m .55447 1.01274 L .55359 1.0077 L F
.55447 1.01274 m .55786 1.03058 L .55359 1.0077 L F
.55269 1.00248 m .56015 1.04167 L .55854 1.03172 L F
.54933 .98568 m .55359 1.0077 L .55269 1.00248 L F
.55359 1.0077 m .56015 1.04167 L .55269 1.00248 L F
.55806 1.03379 m .55995 1.04548 L .55815 1.03484 L 0 .978 .107 r
F
.55978 1.04385 m .55995 1.04548 L .55806 1.03379 L F
.55995 1.04548 m .5628 1.07278 L .55815 1.03484 L F
.55159 .99595 m .55854 1.03172 L .55412 1.00744 L 0 0 .054 r
F
.54933 .98568 m .55269 1.00248 L .55159 .99595 L F
.55269 1.00248 m .55854 1.03172 L .55159 .99595 L F
.55899 1.04385 m .5628 1.07278 L .56343 1.07711 L 0 0 .072 r
F
.56747 1.11208 m .56737 1.11128 L .56346 1.06715 L 0 1 .121 r
F
.56756 1.11342 m .56692 1.10792 L .56346 1.06715 L F
.56632 1.09613 m .56765 1.11241 L .56719 1.1083 L F
.56737 1.10506 m .56858 1.12088 L .56632 1.09613 L F
.56858 1.12088 m .57227 1.169 L .56765 1.11241 L F
.56858 1.12088 m .56765 1.11241 L .56632 1.09613 L F
.56223 1.06709 m .56343 1.07711 L .56475 1.08613 L 0 0 .072 r
F
.56063 1.01705 m .57233 1.15431 L .57227 1.169 L 0 1 .121 r
F
.56424 1.08158 m .56475 1.08613 L .5678 1.10715 L 0 0 .072 r
F
.56223 1.06709 m .56475 1.08613 L .56424 1.08158 L F
.55899 1.04385 m .56343 1.07711 L .56223 1.06709 L F
.56472 1.06314 m .56615 1.0791 L .57076 1.12096 L 0 0 .077 r
F
.56063 1.01705 m .56868 1.09274 L .57233 1.15431 L 0 1 .121 r
F
.56809 1.0574 m .57233 1.15431 L .56868 1.09274 L 0 1 .154 r
F
.56091 1.05604 m .57065 1.12395 L .56949 1.11044 L 0 0 .072 r
F
.55899 1.04385 m .56152 1.06123 L .56091 1.05604 L F
.56152 1.06123 m .57065 1.12395 L .56091 1.05604 L F
.56747 1.11208 m .56756 1.11342 L .56737 1.11128 L 0 1 .121 r
F
.56756 1.11342 m .56849 1.12631 L .56692 1.10792 L F
.55273 .97639 m .56053 1.03095 L .56346 1.06715 L 0 .978 .107 r
F
.56063 1.01705 m .56346 1.06715 L .56053 1.03095 L 0 1 .121 r
F
.55942 1.04305 m .56512 1.0758 L .56015 1.04167 L 0 0 .072 r
F
.55899 1.04385 m .56029 1.05064 L .55942 1.04305 L F
.56029 1.05064 m .56512 1.0758 L .55942 1.04305 L F
.5635 1.07481 m .5678 1.10715 L .57065 1.12395 L F
.55899 1.04385 m .56424 1.08158 L .5635 1.07481 L F
.56424 1.08158 m .5678 1.10715 L .5635 1.07481 L F
.56719 1.1083 m .57227 1.169 L .56849 1.12631 L 0 1 .121 r
F
.56765 1.11241 m .57227 1.169 L .56719 1.1083 L F
.5526 .90332 m .55148 .90204 L .55353 .91826 L 0 .112 .188 r
F
.54872 .91577 m .56025 .86757 L .56028 .87624 L 0 .191 .144 r
F
.54872 .91577 m .55678 .87424 L .56025 .86757 L F
.54872 .91577 m .55218 .89185 L .55678 .87424 L F
.54872 .91577 m .56028 .87624 L .55685 .89399 L F
.54872 .91577 m .55685 .89399 L .55221 .90902 L F
.54365 .89313 m .54551 .90312 L .54661 .9008 L 0 .959 .461 r
F
.54365 .89313 m .54661 .9008 L .54583 .89674 L F
.54267 .88791 m .55021 .93121 L .54933 .92128 L 0 .173 .225 r
F
.55868 .89647 m .55812 .89966 L .56124 .92821 L 0 .116 .179 r
F
.54848 .93294 m .55685 .89399 L .5602 .89162 L 0 .218 .153 r
F
.54848 .93294 m .55221 .90902 L .55685 .89399 L F
.54848 .93294 m .5602 .89162 L .56005 .90347 L F
.56005 .90347 m .5602 .89162 L .56368 .86186 L 0 .141 .14 r
F
.54859 .90147 m .55678 .87424 L .55218 .89185 L 0 .17 .135 r
F
.5505 .90805 m .56131 .89453 L .55944 .84168 L 0 .408 .236 r
F
.54848 .93294 m .56005 .90347 L .55648 .92017 L 0 .218 .153 r
F
.54848 .93294 m .55648 .92017 L .55185 .93055 L F
.56005 .90347 m .56779 .87091 L .56332 .89456 L 0 .141 .14 r
F
.55936 .93841 m .56779 .87091 L .57089 .87175 L 0 .189 .157 r
F
.55936 .93841 m .56332 .89456 L .56779 .87091 L F
.55936 .93841 m .57089 .87175 L .57058 .89657 L F
.55936 .93841 m .55969 .92352 L .56332 .89456 L F
.54848 .93294 m .54862 .92573 L .55221 .90902 L 0 .218 .153 r
F
.55936 .93841 m .57058 .89657 L .56698 .9256 L 0 .189 .157 r
F
.55936 .93841 m .56698 .9256 L .56249 .93932 L F
.5505 .90805 m .55979 .94188 L .56131 .89453 L 0 .408 .236 r
F
.5505 .90805 m .55586 .95142 L .55979 .94188 L F
.54267 .88791 m .54933 .92128 L .54619 .90339 L 0 .173 .225 r
F
.54634 .8943 m .54619 .90339 L .54933 .92128 L 0 .147 .21 r
F
.5481 .89016 m .55629 .86042 L .55175 .87896 L 0 .151 .126 r
F
.54859 .90147 m .55175 .87896 L .55629 .86042 L 0 .17 .135 r
F
.54859 .90147 m .54844 .89659 L .55175 .87896 L F
.54872 .91577 m .54871 .90969 L .55218 .89185 L 0 .191 .144 r
F
.5505 .90805 m .5555 .82759 L .55207 .8612 L 0 .408 .236 r
F
.5505 .90805 m .55944 .84168 L .5555 .82759 L F
.53869 .88075 m .54518 .9195 L .54471 .91096 L 0 .201 .24 r
F
.53612 .89884 m .54271 .9084 L .54206 .90443 L 0 .891 .475 r
F
.53481 .88973 m .53612 .89884 L .54108 .89857 L 0 .976 .478 r
F
.53481 .88973 m .54108 .89857 L .54043 .89471 L F
.53869 .88075 m .54308 .91487 L .54518 .9195 L 0 .201 .24 r
F
.54518 .9195 m .54308 .91487 L .54322 .92015 L 0 .088 .189 r
F
.53694 .93622 m .54871 .90969 L .54872 .91577 L 0 .245 .146 r
F
.53694 .93622 m .54519 .91265 L .54871 .90969 L F
.54634 .8943 m .54491 .89185 L .54619 .90339 L 0 .147 .21 r
F
.53869 .88075 m .54471 .91096 L .54198 .89498 L 0 .201 .24 r
F
.53349 .88054 m .53481 .88973 L .53945 .88896 L 0 1 .477 r
F
.53349 .88054 m .53945 .88896 L .53879 .88514 L F
.53869 .88075 m .53978 .90059 L .54308 .91487 L 0 .201 .24 r
F
.54267 .88791 m .54198 .89498 L .54471 .91096 L 0 .173 .225 r
F
.53689 .92799 m .54844 .89659 L .54859 .90147 L 0 .231 .141 r
F
.53689 .92799 m .54486 .90184 L .54844 .89659 L F
.53689 .92799 m .54859 .90147 L .54519 .91265 L F
.53689 .92799 m .54519 .91265 L .54049 .9227 L F
.53694 .93622 m .54049 .9227 L .54519 .91265 L 0 .245 .146 r
F
.53694 .93622 m .54872 .91577 L .54519 .92586 L F
.53694 .93622 m .54519 .92586 L .54048 .93323 L F
.54123 .93473 m .5505 .90805 L .5468 .89758 L 0 .349 .239 r
F
.5505 .90805 m .55187 .93684 L .55586 .95142 L 0 .408 .236 r
F
.54123 .93473 m .55187 .93684 L .5505 .90805 L 0 .349 .239 r
F
.54635 .91413 m .55507 .90264 L .55529 .88565 L 0 .645 .274 r
F
.54635 .91413 m .55529 .88565 L .55512 .88525 L F
.54132 .7806 m .54414 .78866 L .54337 .78376 L 0 1 .432 r
F
.53947 .76858 m .54132 .7806 L .5422 .77645 L 0 1 .429 r
F
.53947 .76858 m .5422 .77645 L .54142 .7716 L F
.53754 .75607 m .53947 .76858 L .54023 .76418 L 0 1 .424 r
F
.53754 .75607 m .54023 .76418 L .53941 .75914 L F
.5356 .74358 m .53754 .75607 L .53819 .7516 L 0 1 .418 r
F
.5356 .74358 m .53819 .7516 L .53738 .74657 L F
.54317 .79272 m .5428 .80537 L .54501 .8051 L 0 1 .433 r
F
.54317 .79272 m .54501 .8051 L .54609 .80113 L F
.54317 .79272 m .54609 .80113 L .54531 .7961 L F
.54449 .7892 m .5431 .80047 L .5467 .80514 L 0 .91 .413 r
F
.54317 .79272 m .54066 .80199 L .5428 .80537 L 0 1 .433 r
F
.54317 .79272 m .54001 .79722 L .54066 .80199 L F
.54317 .79272 m .54108 .79324 L .54001 .79722 L F
.54132 .7806 m .54108 .79324 L .54317 .79272 L 0 1 .432 r
F
.54132 .7806 m .54317 .79272 L .54414 .78866 L F
.54449 .7892 m .54132 .79425 L .5431 .80047 L 0 .91 .413 r
F
.54449 .7892 m .54191 .78942 L .54132 .79425 L F
.54543 .73615 m .53738 .74657 L .53819 .75159 L 0 1 .413 r
F
.54543 .73615 m .54048 .73995 L .53738 .74657 L F
.53358 .73063 m .5356 .74357 L .53613 .7389 L 0 1 .411 r
F
.53358 .73063 m .53405 .74461 L .5356 .74357 L F
.53358 .73063 m .53235 .74155 L .53405 .74461 L F
.53358 .73063 m .53164 .73643 L .53235 .74155 L F
.53358 .73063 m .53216 .73175 L .53164 .73643 L F
.5319 .73211 m .53816 .75146 L .53741 .7449 L 0 .98 .372 r
F
.5356 .74358 m .53585 .757 L .53754 .75607 L 0 1 .418 r
F
.5356 .74358 m .53407 .75401 L .53585 .757 L F
.5356 .74358 m .53339 .74909 L .53407 .75401 L F
.5356 .74358 m .53405 .74461 L .53339 .74909 L F
.5319 .73211 m .53655 .75244 L .53816 .75146 L 0 .98 .372 r
F
.54132 .7806 m .53904 .79008 L .54108 .79324 L 0 1 .432 r
F
.54132 .7806 m .53839 .78536 L .53904 .79008 L F
.54132 .7806 m .53937 .78129 L .53839 .78536 L F
.53947 .76858 m .53937 .78129 L .54132 .7806 L 0 1 .429 r
F
.53947 .76858 m .53742 .77827 L .53937 .78129 L F
.53927 .77201 m .54191 .78942 L .54449 .7892 L 0 .931 .401 r
F
.53754 .75607 m .53765 .7694 L .53947 .76858 L 0 1 .424 r
F
.53754 .75607 m .53577 .76633 L .53765 .7694 L F
.53754 .75607 m .53509 .7614 L .53577 .76633 L F
.53754 .75607 m .53585 .757 L .53509 .7614 L F
.53816 .75146 m .537 .75872 L .53922 .76611 L 0 .928 .382 r
F
.53816 .75146 m .53655 .75244 L .537 .75872 L F
.53927 .77201 m .54449 .7892 L .54476 .78382 L 0 .931 .401 r
F
.53927 .77201 m .54476 .78382 L .54254 .77687 L F
.53816 .75146 m .53922 .76611 L .5424 .7711 L 0 .928 .382 r
F
.54443 .77035 m .54254 .77687 L .54476 .78382 L 0 .888 .394 r
F
.54443 .77035 m .5424 .7711 L .54254 .77687 L F
.53592 .74229 m .54736 .80671 L .5476 .80023 L 0 .351 .25 r
F
.53592 .74229 m .5437 .79313 L .54736 .80671 L F
.54733 .72773 m .54758 .73977 L .55135 .76997 L 0 .277 .228 r
F
.54689 .84392 m .5547 .73688 L .55106 .74371 L 0 .586 .244 r
F
.54209 .80496 m .54756 .81524 L .54578 .80946 L 0 .949 .429 r
F
.54689 .84392 m .55106 .74371 L .54806 .79038 L 0 .586 .244 r
F
.53816 .75146 m .5424 .7711 L .54443 .77035 L 0 .928 .382 r
F
.53592 .74229 m .5476 .80023 L .54423 .77829 L 0 .351 .25 r
F
.53947 .76858 m .53677 .77356 L .53742 .77827 L 0 1 .429 r
F
.53947 .76858 m .53765 .76941 L .53677 .77356 L F
.53405 .7537 m .53922 .76611 L .537 .75872 L 0 .964 .389 r
F
.53405 .7537 m .53927 .77201 L .53922 .76611 L F
.53592 .74229 m .53908 .7687 L .5437 .79313 L 0 .351 .25 r
F
.53544 .75344 m .5437 .79313 L .53908 .7687 L 0 .353 .252 r
F
.53927 .77201 m .53864 .78455 L .54191 .78942 L 0 .931 .401 r
F
.53186 .77168 m .53317 .78312 L .53741 .77828 L 0 1 .449 r
F
.53186 .77168 m .53741 .77828 L .53676 .77356 L F
.53927 .77201 m .53686 .77786 L .53864 .78455 L 0 .931 .401 r
F
.53927 .77201 m .53712 .77248 L .53686 .77786 L F
.53405 .7537 m .53712 .77248 L .53927 .77201 L 0 .964 .389 r
F
.53544 .75344 m .54689 .81515 L .5437 .79313 L 0 .353 .252 r
F
.53544 .75344 m .54649 .81993 L .54689 .81515 L F
.53317 .78312 m .53448 .7945 L .53903 .79008 L 0 1 .457 r
F
.53797 .78957 m .54209 .80496 L .5431 .80047 L 0 .955 .418 r
F
.53797 .78957 m .5431 .80047 L .54132 .79425 L F
.53544 .75344 m .54281 .80444 L .54649 .81993 L 0 .353 .252 r
F
.54304 .79278 m .54461 .8116 L .54806 .79038 L 0 .688 .246 r
F
.54689 .84392 m .55207 .8612 L .5555 .82759 L 0 .586 .244 r
F
.54573 .7953 m .55476 .85546 L .55529 .88533 L 0 .698 .198 r
F
.55529 .88532 m .55529 .88533 L .5553 .88541 L F
.54573 .7953 m .55529 .88533 L .55529 .88532 L F
.54573 .7953 m .5553 .88541 L .55474 .88441 L F
.55169 .87929 m .55274 .88016 L .55185 .87826 L 0 .645 .274 r
F
.54635 .91413 m .55474 .88441 L .55169 .87929 L F
.54604 .87585 m .54547 .87415 L .54814 .86079 L 0 .111 .11 r
F
.54725 .88172 m .54681 .8791 L .54972 .86403 L 0 .132 .117 r
F
.54689 .84392 m .54837 .86825 L .55207 .8612 L 0 .586 .244 r
F
.54573 .7953 m .55474 .88441 L .55182 .87782 L 0 .698 .198 r
F
.55474 .88441 m .55206 .87872 L .55182 .87782 L F
.55474 .88441 m .55534 .88231 L .55274 .88016 L 0 .645 .274 r
F
.55474 .88441 m .55274 .88016 L .55169 .87929 L F
.54635 .91413 m .55515 .88514 L .55474 .88441 L F
.55474 .88441 m .55539 .89083 L .55206 .87872 L 0 .698 .198 r
F
.55185 .87826 m .55539 .89083 L .55296 .89334 L F
.55182 .87782 m .55206 .87872 L .55185 .87826 L F
.55206 .87872 m .55539 .89083 L .55185 .87826 L F
.55185 .87826 m .55534 .88231 L .55283 .87189 L 0 .645 .274 r
F
.55274 .88016 m .55534 .88231 L .55185 .87826 L F
.55474 .88441 m .55531 .88463 L .5549 .88384 L F
.55515 .88514 m .55531 .88463 L .55474 .88441 L F
.55474 .88441 m .5553 .88541 L .55539 .89083 L 0 .698 .198 r
F
.55512 .88525 m .55529 .88565 L .55531 .88463 L 0 .645 .274 r
F
.5549 .88384 m .55531 .88463 L .55534 .88231 L F
.5481 .89016 m .5478 .88647 L .55093 .86989 L 0 .151 .126 r
F
.54573 .7953 m .55169 .87614 L .54905 .86703 L 0 .698 .198 r
F
.54431 .83328 m .54362 .83533 L .54619 .85696 L 0 .256 .238 r
F
.5445 .87218 m .5438 .87125 L .5462 .8596 L 0 .087 .104 r
F
.5462 .81925 m .54092 .82245 L .54225 .82769 L 0 .95 .438 r
F
.5462 .81925 m .54261 .81883 L .54092 .82245 L F
.54209 .80496 m .54261 .81883 L .5462 .81925 L 0 .949 .429 r
F
.54573 .7953 m .54905 .86703 L .54629 .82989 L 0 .698 .198 r
F
.54267 .88791 m .54111 .88512 L .54198 .89498 L 0 .173 .225 r
F
.53612 .89884 m .52977 .90329 L .53744 .90791 L 0 .891 .475 r
F
.53744 .90791 m .53066 .91045 L .53875 .91692 L 0 .69 .445 r
F
.53425 .89664 m .53263 .90575 L .53573 .91707 L 0 .201 .251 r
F
.53445 .87303 m .53978 .90059 L .53749 .88621 L 0 .23 .255 r
F
.53445 .87303 m .53984 .90798 L .53978 .90059 L F
.53445 .87303 m .53763 .90343 L .53984 .90798 L F
.53445 .87303 m .53459 .89022 L .53763 .90343 L F
.53425 .89664 m .53919 .91856 L .53736 .90796 L 0 .201 .251 r
F
.53425 .89664 m .5385 .92246 L .53919 .91856 L F
.53425 .89664 m .53573 .91707 L .5385 .92246 L F
.53869 .88075 m .53749 .88621 L .53978 .90059 L 0 .201 .24 r
F
.5342 .90554 m .5438 .87125 L .5445 .87218 L 0 .197 .121 r
F
.5342 .90554 m .5445 .87218 L .54191 .88292 L F
.53523 .90952 m .54547 .87415 L .54604 .87585 L 0 .205 .127 r
F
.53523 .90952 m .54191 .88292 L .54547 .87415 L F
.53523 .90952 m .54604 .87585 L .5432 .88719 L F
.5342 .90554 m .54031 .88032 L .5438 .87125 L 0 .197 .121 r
F
.5342 .90554 m .54191 .88292 L .53771 .89638 L F
.53523 .90952 m .53771 .89638 L .54191 .88292 L 0 .205 .127 r
F
.53862 .89855 m .54837 .86825 L .54689 .84392 L 0 .475 .248 r
F
.5444 .86733 m .54657 .86948 L .54448 .86676 L 0 .698 .282 r
F
.53984 .90798 m .53736 .90796 L .53919 .91856 L 0 .149 .222 r
F
.53984 .90798 m .53763 .90343 L .53736 .90796 L F
.53602 .91458 m .54681 .8791 L .54725 .88172 L 0 .212 .132 r
F
.53602 .91458 m .5432 .88719 L .54681 .8791 L F
.53602 .91458 m .54725 .88172 L .54419 .89341 L F
.53523 .90952 m .5432 .88719 L .53882 .90066 L 0 .205 .127 r
F
.53602 .91458 m .53882 .90066 L .5432 .88719 L 0 .212 .132 r
F
.5385 .92246 m .53469 .91894 L .53606 .92682 L 0 .149 .227 r
F
.5385 .92246 m .53573 .91707 L .53469 .91894 L F
.53658 .92074 m .5478 .88647 L .5481 .89016 L 0 .221 .137 r
F
.53658 .92074 m .54419 .89341 L .5478 .88647 L F
.53658 .92074 m .5481 .89016 L .54486 .90184 L F
.53602 .91458 m .54419 .89341 L .53966 .90641 L 0 .212 .132 r
F
.53658 .92074 m .53966 .90641 L .54419 .89341 L 0 .221 .137 r
F
.53862 .89855 m .5468 .89758 L .54837 .86825 L 0 .475 .248 r
F
.5409 .89353 m .54628 .87073 L .5444 .86733 L 0 .698 .282 r
F
.54628 .87073 m .54657 .86948 L .5444 .86733 L F
.54047 .86993 m .53952 .87011 L .54131 .86157 L 0 .035 .091 r
F
.52846 .88543 m .53263 .90575 L .53126 .89605 L 0 .247 .273 r
F
.52846 .88543 m .53153 .90911 L .53263 .90575 L F
.53425 .89664 m .53126 .89605 L .53263 .90575 L 0 .201 .251 r
F
.53425 .89664 m .53195 .89214 L .53126 .89605 L F
.53445 .87303 m .53275 .87718 L .53459 .89022 L 0 .23 .255 r
F
.53869 .88075 m .53702 .87771 L .53749 .88621 L 0 .201 .24 r
F
.53149 .90054 m .53952 .87011 L .54047 .86993 L 0 .176 .109 r
F
.53149 .90054 m .53629 .87899 L .53952 .87011 L F
.53149 .90054 m .54047 .86993 L .53843 .8791 L F
.53295 .90258 m .54181 .87002 L .54264 .87032 L 0 .187 .114 r
F
.53295 .90258 m .53843 .8791 L .54181 .87002 L F
.53295 .90258 m .54264 .87032 L .54031 .88032 L F
.53295 .90258 m .54031 .88032 L .53635 .89341 L F
.5342 .90554 m .53635 .89341 L .54031 .88032 L 0 .197 .121 r
F
.53709 .81713 m .53042 .82548 L .53839 .82835 L 0 1 .501 r
F
.53715 .81804 m .54013 .831 L .54225 .82769 L 0 .995 .442 r
F
.53715 .81804 m .54225 .82769 L .54092 .82245 L F
.53049 .75966 m .53186 .77168 L .53577 .76633 L 0 1 .441 r
F
.53049 .75966 m .53577 .76633 L .53509 .76141 L F
.53317 .78312 m .53903 .79008 L .53839 .78536 L 0 1 .457 r
F
.53384 .773 m .53797 .78957 L .53864 .78455 L 0 .971 .407 r
F
.53384 .773 m .53864 .78455 L .53686 .77786 L F
.52911 .74758 m .53049 .75966 L .53407 .75402 L 0 1 .434 r
F
.52911 .74758 m .53407 .75402 L .53339 .74909 L F
.53405 .7537 m .53418 .76746 L .53712 .77248 L 0 .964 .389 r
F
.53471 .76274 m .54578 .82598 L .54281 .80444 L 0 .36 .255 r
F
.53579 .80582 m .53709 .81713 L .54227 .81414 L 0 1 .481 r
F
.53579 .80582 m .54227 .81414 L .54162 .80925 L F
.54209 .80496 m .53893 .81433 L .54261 .81883 L 0 .949 .429 r
F
.54209 .80496 m .5376 .80874 L .53893 .81433 L F
.54209 .80496 m .53895 .80472 L .5376 .80874 L F
.53448 .7945 m .53579 .80582 L .54065 .802 L 0 1 .467 r
F
.53448 .7945 m .54065 .802 L .54001 .79722 L F
.53797 .78957 m .53895 .80472 L .54209 .80496 L 0 .955 .418 r
F
.53471 .76274 m .54524 .82927 L .54578 .82598 L 0 .36 .255 r
F
.53471 .76274 m .54158 .81261 L .54524 .82927 L F
.53797 .78957 m .5356 .80005 L .53895 .80472 L 0 .955 .418 r
F
.53448 .7945 m .52865 .80615 L .53579 .80582 L 0 1 .467 r
F
.53448 .7945 m .52312 .80344 L .52865 .80615 L F
.53448 .7945 m .52289 .79948 L .52312 .80344 L F
.53448 .7945 m .52776 .79565 L .52289 .79948 L F
.53317 .78312 m .52776 .79565 L .53448 .7945 L 0 1 .457 r
F
.53797 .78957 m .53426 .79404 L .5356 .80005 L 0 .955 .418 r
F
.53797 .78957 m .53528 .78955 L .53426 .79404 L F
.53384 .773 m .53528 .78955 L .53797 .78957 L 0 .971 .407 r
F
.52911 .74758 m .52503 .76225 L .53049 .75966 L 0 1 .434 r
F
.5297 .75526 m .53384 .773 L .53418 .76746 L 0 .998 .396 r
F
.53375 .77022 m .54431 .83328 L .54158 .81261 L 0 .369 .259 r
F
.53375 .77022 m .54362 .83533 L .54431 .83328 L F
.53375 .77022 m .54004 .81807 L .54362 .83533 L F
.53709 .81713 m .52428 .821 L .53042 .82548 L 0 1 .501 r
F
.53709 .81713 m .52405 .81787 L .52428 .821 L F
.53709 .81713 m .52954 .81621 L .52405 .81787 L F
.53579 .80582 m .52954 .81621 L .53709 .81713 L 0 1 .481 r
F
.53579 .80582 m .52371 .81279 L .52954 .81621 L F
.53579 .80582 m .52347 .80914 L .52371 .81279 L F
.53579 .80582 m .52865 .80615 L .52347 .80914 L F
.53417 .8042 m .53715 .81804 L .53893 .81433 L 0 .993 .433 r
F
.53417 .8042 m .53893 .81433 L .5376 .80874 L F
.53317 .78312 m .52254 .79342 L .52776 .79565 L 0 1 .457 r
F
.53317 .78312 m .52231 .78928 L .52254 .79342 L F
.53317 .78312 m .52686 .78487 L .52231 .78928 L F
.53186 .77168 m .52686 .78487 L .53317 .78312 L 0 1 .449 r
F
.53384 .773 m .53226 .78469 L .53528 .78955 L 0 .971 .407 r
F
.53384 .773 m .53092 .77823 L .53226 .78469 L F
.53255 .77598 m .54249 .83764 L .54004 .81807 L 0 .38 .263 r
F
.53255 .77598 m .54166 .83866 L .54249 .83764 L F
.53118 .78936 m .53417 .8042 L .5356 .80005 L 0 .997 .423 r
F
.53118 .78936 m .5356 .80005 L .53426 .79404 L F
.53255 .77598 m .5382 .82127 L .54166 .83866 L 0 .38 .263 r
F
.54013 .831 m .53352 .83318 L .53438 .83798 L 0 .999 .45 r
F
.54013 .831 m .53598 .83019 L .53352 .83318 L F
.53839 .82835 m .52463 .82508 L .52486 .8274 L 0 1 .5 r
F
.53839 .82835 m .53042 .82548 L .52463 .82508 L F
.53715 .81804 m .53222 .82578 L .53598 .83019 L 0 .995 .442 r
F
.53715 .81804 m .53135 .82071 L .53222 .82578 L F
.53715 .81804 m .53598 .83019 L .54013 .831 L F
.53715 .81804 m .53346 .81739 L .53135 .82071 L F
.53417 .8042 m .53346 .81739 L .53715 .81804 L 0 .993 .433 r
F
.53186 .77168 m .52196 .78299 L .52686 .78487 L 0 1 .449 r
F
.53186 .77168 m .52172 .77874 L .52196 .78299 L F
.53186 .77168 m .52597 .77389 L .52172 .77874 L F
.52819 .77338 m .53118 .78936 L .53226 .78469 L 0 1 .412 r
F
.52819 .77338 m .53226 .78469 L .53092 .77823 L F
.53114 .78014 m .54034 .83958 L .5382 .82127 L 0 .39 .267 r
F
.53114 .78014 m .53939 .83978 L .54034 .83958 L F
.53789 .83958 m .53683 .83912 L .53837 .85408 L 0 .271 .255 r
F
.54034 .83958 m .53939 .83978 L .54129 .85672 L 0 .264 .249 r
F
.54249 .83764 m .54166 .83866 L .54391 .85783 L 0 .259 .243 r
F
.53578 .86641 m .54341 .84435 L .54461 .8116 L 0 .566 .251 r
F
.53862 .89855 m .54341 .84435 L .54023 .86923 L 0 .475 .248 r
F
.54264 .87032 m .54181 .87002 L .54392 .85999 L 0 .061 .097 r
F
.53862 .89855 m .54689 .84392 L .54341 .84435 L 0 .475 .248 r
F
.53801 .87068 m .53695 .87125 L .53841 .86403 L 0 .009 .084 r
F
.53578 .86641 m .54023 .86923 L .54341 .84435 L 0 .566 .251 r
F
.52846 .88543 m .52869 .90388 L .53153 .90911 L 0 .247 .273 r
F
.52984 .89932 m .53695 .87125 L .53801 .87068 L 0 .164 .105 r
F
.52984 .89932 m .5339 .87978 L .53695 .87125 L F
.52984 .89932 m .53801 .87068 L .53629 .87899 L F
.53578 .86641 m .53695 .87873 L .54023 .86923 L 0 .566 .251 r
F
.53417 .8042 m .53004 .81286 L .53346 .81739 L 0 .993 .433 r
F
.53417 .8042 m .52917 .80746 L .53004 .81286 L F
.53417 .8042 m .53094 .80375 L .52917 .80746 L F
.53118 .78936 m .52786 .79907 L .53094 .80375 L 0 .997 .423 r
F
.53118 .78936 m .52699 .79328 L .52786 .79907 L F
.53118 .78936 m .53094 .80375 L .53417 .8042 L F
.53118 .78936 m .52841 .78912 L .52699 .79328 L F
.52819 .77338 m .52841 .78912 L .53118 .78936 L 0 1 .412 r
F
.52953 .78285 m .53789 .83958 L .53608 .82256 L 0 .401 .271 r
F
.52953 .78285 m .53683 .83912 L .53789 .83958 L F
.52953 .78285 m .53371 .82229 L .53683 .83912 L F
.53189 .82936 m .53395 .84131 L .53438 .83798 L 0 1 .452 r
F
.53189 .82936 m .53438 .83798 L .53351 .83318 L F
.53816 .75146 m .54398 .76408 L .54135 .75645 L 0 .928 .382 r
F
.53816 .75146 m .54443 .77035 L .54398 .76408 L F
.53592 .74229 m .54423 .77829 L .53954 .75565 L 0 .351 .25 r
F
.53592 .74229 m .53576 .74697 L .53908 .7687 L F
.53544 .75344 m .53832 .77917 L .54281 .80444 L 0 .353 .252 r
F
.53544 .75344 m .53518 .75738 L .53832 .77917 L F
.53471 .76274 m .54281 .80444 L .53832 .77917 L 0 .36 .255 r
F
.53471 .76274 m .53729 .78725 L .54158 .81261 L F
.53471 .76274 m .53436 .76595 L .53729 .78725 L F
.53375 .77022 m .54158 .81261 L .53729 .78725 L 0 .369 .259 r
F
.53375 .77022 m .53598 .79317 L .54004 .81807 L F
.52819 .77338 m .52568 .78426 L .52841 .78912 L 0 1 .412 r
F
.52774 .78427 m .53517 .83802 L .53371 .82229 L 0 .411 .275 r
F
.52774 .78427 m .53402 .83702 L .53517 .83802 L F
.52982 .81672 m .53189 .82936 L .53221 .82578 L 0 1 .444 r
F
.52982 .81672 m .53221 .82578 L .53134 .82071 L F
.52774 .78427 m .53112 .82073 L .53402 .83702 L 0 .411 .275 r
F
.53255 .77598 m .54004 .81807 L .53598 .79317 L 0 .38 .263 r
F
.53255 .77598 m .53442 .79717 L .5382 .82127 L F
.52953 .78285 m .53608 .82256 L .53263 .79952 L 0 .401 .271 r
F
.53114 .78014 m .5382 .82127 L .53442 .79717 L 0 .39 .267 r
F
.53114 .78014 m .53608 .82256 L .53939 .83978 L F
.53114 .78014 m .53263 .79952 L .53608 .82256 L F
.53273 .83929 m .54063 .76863 L .53898 .7552 L 0 .624 .253 r
F
.53273 .83929 m .5398 .80211 L .54063 .76863 L F
.53578 .86641 m .54304 .79278 L .5398 .80211 L 0 .566 .251 r
F
.53578 .86641 m .54461 .8116 L .54304 .79278 L F
.53578 .86641 m .5398 .80211 L .53701 .83349 L F
.53517 .83802 m .53402 .83702 L .53518 .85025 L 0 .279 .261 r
F
.53273 .83929 m .53701 .83349 L .5398 .80211 L 0 .624 .253 r
F
.53273 .83929 m .53398 .84951 L .53701 .83349 L F
.53497 .81648 m .53953 .8582 L .53785 .85546 L 0 .691 .18 r
F
.53153 .90911 m .52724 .90548 L .52813 .91282 L 0 .215 .264 r
F
.53153 .90911 m .52869 .90388 L .52724 .90548 L F
.53529 .87232 m .53414 .87317 L .53524 .86712 L 0 0 .077 r
F
.52846 .88543 m .5259 .89327 L .52869 .90388 L 0 .247 .273 r
F
.52801 .89882 m .53414 .87317 L .53529 .87232 L 0 .151 .101 r
F
.52801 .89882 m .53529 .87232 L .5339 .87978 L F
.52801 .89882 m .5339 .87978 L .53088 .89065 L F
.52984 .89932 m .53088 .89065 L .5339 .87978 L 0 .164 .105 r
F
.52984 .89932 m .53629 .87899 L .53292 .89071 L F
.53149 .90054 m .53292 .89071 L .53629 .87899 L 0 .176 .109 r
F
.53149 .90054 m .53085 .89996 L .53292 .89071 L F
.52054 .91692 m .50072 .92853 L .50926 .92905 L 0 1 .485 r
F
.52054 .91692 m .50091 .92493 L .50072 .92853 L F
.52054 .91692 m .50941 .91995 L .50091 .92493 L F
.51971 .91397 m .51999 .91765 L .52754 .9162 L 0 1 .534 r
F
.51971 .91397 m .52754 .9162 L .5273 .91487 L F
.52028 .92213 m .5094 .92808 L .52056 .92718 L 0 1 .54 r
F
.52028 .92213 m .50117 .92719 L .5094 .92808 L F
.52028 .92213 m .50136 .92511 L .50117 .92719 L F
.52028 .92213 m .50954 .92294 L .50136 .92511 L F
.51999 .91765 m .50954 .92294 L .52028 .92213 L 0 1 .539 r
F
.51881 .92087 m .52573 .92753 L .52543 .92154 L 0 1 .457 r
F
.52084 .93264 m .50025 .93823 L .50912 .93928 L 0 1 .539 r
F
.52084 .93264 m .50044 .93595 L .50025 .93823 L F
.52084 .93264 m .50926 .93355 L .50044 .93595 L F
.52056 .92718 m .52084 .93264 L .52934 .93033 L 0 1 .54 r
F
.52056 .92718 m .50926 .93355 L .52084 .93264 L F
.52056 .92718 m .50071 .93259 L .50926 .93355 L F
.52056 .92718 m .52934 .93033 L .5291 .92815 L F
.52056 .92718 m .5009 .9304 L .50071 .93259 L F
.52056 .92718 m .5094 .92808 L .5009 .9304 L F
.51881 .92087 m .51917 .93475 L .52573 .92753 L 0 1 .457 r
F
.5252 .92461 m .51902 .92303 L .52242 .93117 L 0 .272 .306 r
F
.51999 .91765 m .50163 .9221 L .50954 .92294 L 0 1 .539 r
F
.51999 .91765 m .50182 .92015 L .50163 .9221 L F
.51999 .91765 m .50969 .91824 L .50182 .92015 L F
.51971 .91397 m .50969 .91824 L .51999 .91765 L 0 1 .534 r
F
.51971 .91397 m .5021 .91735 L .50969 .91824 L F
.51971 .91397 m .50228 .91555 L .5021 .91735 L F
.51971 .91397 m .50983 .91411 L .50228 .91555 L F
.51943 .91134 m .50983 .91411 L .51971 .91397 L 0 1 .523 r
F
.51854 .91209 m .51881 .92086 L .52502 .91432 L 0 1 .45 r
F
.5252 .92461 m .51875 .91815 L .51902 .92303 L 0 .272 .306 r
F
.5252 .92461 m .5214 .91882 L .51875 .91815 L F
.51854 .91209 m .52502 .91432 L .52478 .91069 L 0 1 .45 r
F
.52371 .90986 m .5214 .91882 L .5252 .92461 L 0 .272 .301 r
F
.52371 .90986 m .5252 .92461 L .52751 .92447 L F
.52371 .90986 m .52751 .92447 L .52677 .91847 L F
.5259 .89878 m .52565 .90858 L .52699 .91528 L 0 .246 .282 r
F
.5259 .89878 m .52699 .91528 L .52802 .91702 L F
.5259 .89878 m .52802 .91702 L .52813 .91282 L F
.5259 .89878 m .52813 .91282 L .52724 .90548 L F
.52239 .92732 m .53085 .89996 L .53149 .90054 L 0 .256 .123 r
F
.52239 .92732 m .52782 .90753 L .53085 .89996 L F
.52831 .90912 m .53695 .87873 L .53578 .86641 L 0 .474 .256 r
F
.53519 .87863 m .53953 .8582 L .53786 .85562 L 0 .735 .292 r
F
.54266 .86135 m .54461 .86497 L .54269 .86212 L 0 .702 .19 r
F
.54053 .81042 m .54451 .86365 L .54266 .86135 L F
.54451 .86365 m .54461 .86497 L .54266 .86135 L F
.53519 .87863 m .54078 .87602 L .54254 .86232 L 0 .735 .292 r
F
.53519 .87863 m .54254 .86232 L .5425 .86226 L F
.53519 .87863 m .54252 .86222 L .54215 .86175 L F
.54252 .86222 m .54256 .86212 L .54231 .8619 L F
.54252 .86222 m .54231 .8619 L .54215 .86175 L F
.54448 .86676 m .54496 .86596 L .54465 .86549 L 0 .698 .282 r
F
.54657 .86948 m .54665 .86914 L .54448 .86676 L F
.54053 .81042 m .54665 .86914 L .54465 .86549 L 0 .702 .19 r
F
.54053 .81042 m .54905 .86703 L .54907 .87287 L F
.5409 .89353 m .5491 .87678 L .54907 .87287 L 0 .698 .282 r
F
.5409 .89353 m .54907 .87287 L .54665 .86914 L F
.55169 .87614 m .55182 .87782 L .55123 .87554 L 0 .698 .198 r
F
.55169 .87614 m .55123 .87554 L .54905 .86703 L F
.54635 .91413 m .55185 .87826 L .5491 .87678 L 0 .645 .274 r
F
.55182 .87782 m .55185 .87826 L .55018 .87462 L 0 .698 .198 r
F
.55185 .87826 m .55027 .87525 L .55018 .87462 L F
.55182 .87782 m .55018 .87462 L .54905 .86703 L F
.55185 .87826 m .55283 .87189 L .55027 .87525 L 0 .645 .274 r
F
.55185 .87826 m .55027 .87525 L .5491 .87678 L F
.55185 .87826 m .55296 .89334 L .55027 .87525 L 0 .698 .198 r
F
.53658 .92074 m .54486 .90184 L .54022 .91374 L 0 .221 .137 r
F
.53689 .92799 m .54022 .91374 L .54486 .90184 L 0 .231 .141 r
F
.53862 .89855 m .54321 .91225 L .5468 .89758 L 0 .475 .248 r
F
.54123 .93473 m .5468 .89758 L .54321 .91225 L 0 .349 .239 r
F
.54635 .91413 m .5491 .87678 L .54663 .89376 L 0 .645 .274 r
F
.5409 .89353 m .54663 .89376 L .5491 .87678 L 0 .698 .282 r
F
.54665 .86914 m .54907 .87287 L .54916 .89322 L 0 .702 .19 r
F
.54053 .81042 m .54907 .87287 L .54665 .86914 L F
.54053 .81042 m .54629 .82989 L .54905 .86703 L F
.54665 .86914 m .54907 .87287 L .54897 .85932 L 0 .698 .282 r
F
.54665 .86914 m .54897 .85932 L .54494 .86601 L F
.54665 .86914 m .54494 .86601 L .54448 .86676 L F
.54665 .86914 m .54669 .86947 L .54465 .86549 L 0 .702 .19 r
F
.54465 .86549 m .54916 .89322 L .54652 .89055 L F
.54669 .86947 m .54916 .89322 L .54465 .86549 L F
.54268 .86251 m .54295 .86269 L .5427 .86228 L 0 .698 .282 r
F
.54269 .86212 m .54465 .86549 L .5427 .86228 L 0 .702 .19 r
F
.54461 .86497 m .54465 .86549 L .54269 .86212 L F
.54466 .86541 m .54485 .86397 L .54268 .86251 L 0 .698 .282 r
F
.5427 .86228 m .54465 .86549 L .54271 .86256 L 0 .702 .19 r
F
.54295 .86269 m .54336 .86297 L .5427 .86228 L 0 .698 .282 r
F
.54336 .86297 m .54485 .86397 L .54322 .86269 L F
.54336 .86297 m .54322 .86269 L .5427 .86228 L F
.5409 .89353 m .54466 .86541 L .54268 .86251 L F
.5395 .85785 m .53977 .85851 L .53953 .8582 L 0 .691 .18 r
F
.53519 .87863 m .54217 .86169 L .53953 .8582 L 0 .735 .292 r
F
.54053 .81042 m .54269 .86224 L .5406 .83605 L 0 .702 .19 r
F
.54269 .86224 m .5427 .86228 L .54269 .86224 L F
.54269 .86224 m .54269 .86224 L .5406 .83605 L F
.53497 .81648 m .5406 .83605 L .54256 .86212 L 0 .691 .18 r
F
.5409 .89353 m .54269 .86231 L .54078 .87602 L 0 .698 .282 r
F
.54269 .86231 m .54269 .8623 L .54078 .87602 L F
.5427 .86228 m .54256 .86212 L .54078 .87602 L F
.5425 .86226 m .54254 .86232 L .54256 .86212 L 0 .735 .292 r
F
.54215 .86155 m .54256 .86212 L .54285 .86591 L 0 .691 .18 r
F
.53497 .81648 m .54256 .86212 L .54215 .86155 L F
.54269 .86231 m .5427 .86228 L .54269 .8623 L 0 .698 .282 r
F
.5427 .86228 m .54282 .86012 L .54256 .86212 L F
.5427 .86228 m .54257 .86218 L .54256 .86212 L 0 .702 .19 r
F
.5427 .86228 m .54256 .86212 L .5406 .83605 L F
.53978 .85827 m .54285 .86591 L .5395 .85785 L 0 .691 .18 r
F
.53497 .81648 m .54217 .86169 L .53945 .85745 L F
.54217 .86169 m .54285 .86591 L .53945 .85745 L F
.53953 .8582 m .54226 .86148 L .53965 .85763 L 0 .735 .292 r
F
.54217 .86169 m .54226 .86148 L .53953 .8582 L F
.53953 .8582 m .54285 .86591 L .54246 .88497 L 0 .691 .18 r
F
.53977 .85851 m .54285 .86591 L .53953 .8582 L F
.53945 .85745 m .53978 .85827 L .5395 .85785 L F
.53234 .87462 m .53184 .87065 L .53405 .8629 L 0 0 .07 r
F
.52801 .89882 m .5313 .88127 L .53414 .87317 L 0 .151 .101 r
F
.52984 .89932 m .52913 .89904 L .53088 .89065 L 0 .164 .105 r
F
.52156 .92598 m .52913 .89904 L .52984 .89932 L 0 .254 .119 r
F
.52156 .92598 m .52984 .89932 L .52782 .90753 L F
.52831 .90912 m .53578 .86641 L .53277 .8712 L 0 .474 .256 r
F
.53606 .85467 m .53786 .85562 L .53611 .85315 L 0 .735 .292 r
F
.53519 .87863 m .53768 .85718 L .53606 .85467 L F
.53768 .85718 m .53786 .85562 L .53606 .85467 L F
.52918 .87741 m .53405 .8629 L .53184 .87065 L 0 0 .065 r
F
.53189 .82936 m .53088 .83714 L .5325 .84096 L 0 1 .452 r
F
.51939 .87259 m .50279 .88499 L .5026 .88933 L 0 1 .443 r
F
.51939 .87259 m .50999 .87782 L .50279 .88499 L F
.5191 .85901 m .50999 .87782 L .51939 .87259 L 0 1 .425 r
F
.51715 .86606 m .51743 .87461 L .52208 .87388 L 0 1 .483 r
F
.51715 .86606 m .52208 .87388 L .52185 .87037 L F
.52942 .86589 m .52064 .87471 L .52089 .87611 L 0 1 .331 r
F
.52942 .86589 m .5243 .87032 L .52064 .87471 L F
.52798 .8632 m .5243 .87032 L .52942 .86589 L 0 1 .28 r
F
.52798 .8632 m .52026 .87274 L .5243 .87032 L F
.52798 .8632 m .52 .87153 L .52026 .87274 L F
.52798 .8632 m .52331 .86744 L .52 .87153 L F
.52653 .86134 m .52331 .86744 L .52798 .8632 L 0 1 .215 r
F
.52738 .86587 m .5292 .87984 L .52782 .86795 L 0 .285 .282 r
F
.52696 .8661 m .5284 .85971 L .52915 .86074 L 0 0 .014 r
F
.52644 .86639 m .52846 .88543 L .52696 .8661 L 0 .285 .282 r
F
.52687 .86615 m .52687 .86615 L .52696 .8661 L 0 0 .014 r
F
.52687 .86615 m .5284 .85971 L .52696 .8661 L F
.52696 .8661 m .52846 .88543 L .5292 .87984 L 0 .285 .282 r
F
.5263 .86684 m .52644 .86639 L .52678 .86655 L 0 0 .014 r
F
.52644 .86639 m .5284 .85971 L .52687 .86615 L F
.52644 .86639 m .52687 .86615 L .52678 .86655 L F
.52644 .86639 m .5261 .88098 L .52846 .88543 L 0 .285 .282 r
F
.52938 .85089 m .52086 .85523 L .52521 .85949 L 0 1 .467 r
F
.52653 .86134 m .51962 .86996 L .52331 .86744 L 0 1 .215 r
F
.52653 .86134 m .51936 .86908 L .51962 .86996 L F
.52653 .86134 m .52232 .86538 L .51936 .86908 L F
.52508 .8606 m .52232 .86538 L .52653 .86134 L 0 .963 .189 r
F
.52363 .86132 m .52508 .8606 L .52736 .85804 L 0 .861 .15 r
F
.52457 .86041 m .52736 .85804 L .52664 .85842 L F
.52363 .86132 m .52423 .86079 L .52457 .86041 L F
.52423 .86079 m .52736 .85804 L .52457 .86041 L F
.52582 .85979 m .52556 .85956 L .52675 .85798 L 0 0 0 r
F
.52683 .85789 m .52675 .85798 L .52686 .85783 L F
.52582 .85979 m .52675 .85798 L .52683 .85789 L F
.52363 .86132 m .52133 .8644 L .52508 .8606 L 0 .861 .15 r
F
.52216 .86393 m .52363 .86132 L .52556 .85957 L 0 0 0 r
F
.52582 .85979 m .52483 .86072 L .52556 .85956 L F
.52216 .86393 m .52556 .85957 L .52483 .86072 L F
.52582 .85979 m .52495 .86082 L .52483 .86072 L F
.52376 .86544 m .52582 .85979 L .52583 .86074 L F
.52376 .86544 m .52495 .86082 L .52582 .85979 L F
.5284 .85971 m .52496 .86305 L .52583 .86074 L F
.52376 .86544 m .52583 .86074 L .52496 .86306 L F
.5284 .85971 m .52606 .86261 L .52496 .86305 L F
.52568 .8668 m .52365 .86746 L .52606 .86261 L 0 0 .014 r
F
.52568 .86686 m .52366 .86946 L .5261 .88098 L 0 .285 .282 r
F
.52562 .86689 m .52366 .86946 L .52568 .86686 L F
.52388 .86778 m .52366 .86946 L .52568 .86681 L F
.52388 .86778 m .52353 .86796 L .52366 .86946 L F
.51992 .84839 m .5202 .85466 L .52798 .85025 L 0 1 .514 r
F
.52938 .85089 m .52061 .85125 L .52086 .85523 L 0 1 .467 r
F
.52938 .85089 m .52426 .84939 L .52061 .85125 L F
.52508 .8606 m .51897 .86807 L .52232 .86538 L 0 .963 .189 r
F
.5202 .85466 m .50129 .86535 L .50944 .86482 L 0 1 .512 r
F
.5191 .85901 m .50307 .87841 L .50999 .87782 L 0 1 .425 r
F
.5191 .85901 m .50326 .87396 L .50307 .87841 L F
.5191 .85901 m .51014 .86564 L .50326 .87396 L F
.51686 .85672 m .51715 .86606 L .52148 .86488 L 0 1 .478 r
F
.51686 .85672 m .52148 .86488 L .52124 .86107 L F
.52508 .8606 m .51871 .8676 L .51897 .86807 L 0 .963 .189 r
F
.52508 .8606 m .52133 .8644 L .51871 .8676 L F
.52363 .86132 m .51831 .86731 L .52133 .8644 L 0 .861 .15 r
F
.52363 .86132 m .51805 .86739 L .51831 .86731 L F
.52363 .86132 m .52033 .86482 L .51805 .86739 L F
.52216 .86393 m .52033 .86482 L .52363 .86132 L 0 0 0 r
F
.52069 .86894 m .52216 .86393 L .52374 .86319 L F
.52376 .86544 m .52302 .86534 L .52375 .86319 L F
.52069 .86894 m .52374 .86319 L .52302 .86534 L F
.52376 .86544 m .52302 .8663 L .52302 .86534 L F
.5235 .86797 m .52376 .86544 L .52365 .86746 L 0 0 .015 r
F
.52311 .86817 m .52311 .86818 L .5235 .86797 L 0 .302 .289 r
F
.52311 .86818 m .52377 .87661 L .5235 .86797 L F
.52311 .86818 m .5235 .86797 L .5235 .86797 L F
.5235 .86797 m .52377 .87661 L .52365 .86945 L F
.52541 .8699 m .52353 .86795 L .52388 .86778 L 0 0 .014 r
F
.52353 .86795 m .52353 .86795 L .52353 .86795 L 0 .285 .282 r
F
.52353 .86795 m .52353 .86795 L .52353 .86796 L F
.5235 .86797 m .52365 .86945 L .52353 .86795 L 0 .302 .289 r
F
.52311 .86818 m .52304 .87524 L .52377 .87661 L F
.52311 .86815 m .52302 .8663 L .52376 .86544 L 0 0 .015 r
F
.52311 .86817 m .52376 .86544 L .5235 .86797 L F
.52376 .86544 m .52375 .86319 L .52495 .86082 L 0 0 0 r
F
.52538 .85644 m .52276 .85855 L .52353 .86795 L 0 .285 .282 r
F
.52267 .86843 m .52304 .87524 L .52311 .86818 L 0 .302 .289 r
F
.52266 .8684 m .52222 .86863 L .52302 .8663 L 0 0 .015 r
F
.52266 .86837 m .52221 .86858 L .52222 .86863 L 0 .302 .289 r
F
.52266 .8684 m .52222 .86863 L .52304 .87524 L F
.52266 .86837 m .52222 .86863 L .52266 .8684 L F
.52167 .87422 m .52192 .86947 L .52222 .86863 L 0 0 .015 r
F
.52167 .87422 m .52222 .86863 L .52266 .8684 L F
.52167 .87422 m .5235 .86797 L .52278 .87103 L F
.5235 .86797 m .52365 .86746 L .52353 .86795 L F
.5235 .86797 m .52353 .86795 L .52278 .87103 L F
.52216 .86393 m .51766 .86803 L .52033 .86482 L 0 0 0 r
F
.52216 .86393 m .5174 .86881 L .51766 .86803 L F
.52216 .86393 m .51933 .86705 L .5174 .86881 L F
.52069 .86894 m .51933 .86705 L .52216 .86393 L F
.52164 .84956 m .52192 .86624 L .52221 .86858 L 0 .302 .289 r
F
.52164 .84956 m .52221 .86858 L .52266 .86837 L F
.52353 .86795 m .52353 .86795 L .52353 .86795 L 0 .285 .282 r
F
.52538 .85644 m .52353 .86795 L .52353 .86795 L F
.52311 .86817 m .52311 .86816 L .52311 .86815 L 0 0 .015 r
F
.52311 .86816 m .52302 .8663 L .52311 .86815 L F
.52311 .86817 m .52267 .86843 L .52311 .86818 L 0 .302 .289 r
F
.52266 .8684 m .52267 .86843 L .52311 .86817 L F
.52167 .87422 m .52266 .8684 L .52311 .86817 L 0 0 .015 r
F
.52266 .8684 m .52302 .8663 L .52311 .86817 L F
.52164 .84956 m .52266 .8684 L .52311 .86817 L 0 .302 .289 r
F
.52541 .8699 m .52278 .87103 L .52353 .86795 L 0 0 .014 r
F
.52311 .86817 m .52311 .86817 L .5235 .86797 L 0 0 .015 r
F
.52164 .84956 m .52311 .86817 L .5235 .86797 L 0 .302 .289 r
F
.52538 .85644 m .52353 .86795 L .52353 .86795 L 0 .285 .282 r
F
.52167 .87422 m .52311 .86817 L .5235 .86797 L 0 0 .015 r
F
.52164 .84956 m .5235 .86797 L .52276 .85855 L 0 .302 .289 r
F
.5235 .86797 m .52353 .86795 L .52276 .85855 L F
.52388 .86778 m .52353 .86795 L .52365 .86746 L 0 0 .014 r
F
.52568 .86681 m .52562 .86689 L .52568 .86686 L 0 .285 .282 r
F
.52568 .86681 m .52388 .86778 L .52568 .8668 L 0 0 .014 r
F
.52388 .86778 m .52365 .86746 L .52568 .8668 L F
.52538 .85644 m .52388 .86778 L .52568 .86681 L 0 .285 .282 r
F
.52541 .8699 m .52388 .86778 L .52568 .86681 L 0 0 .014 r
F
.52538 .85644 m .52353 .86796 L .52388 .86778 L 0 .285 .282 r
F
.52538 .85644 m .52568 .86679 L .52644 .86639 L F
.52644 .86639 m .52606 .86261 L .5284 .85971 L 0 0 .014 r
F
.52568 .86681 m .5261 .88098 L .52644 .86639 L 0 .285 .282 r
F
.52541 .8699 m .52568 .86681 L .52644 .86639 L 0 0 .014 r
F
.52568 .86681 m .52606 .86261 L .52644 .86639 L F
.52568 .86679 m .52568 .86681 L .52644 .86639 L 0 .285 .282 r
F
.52788 .85667 m .52664 .85842 L .52736 .85804 L 0 .903 .161 r
F
.52582 .85979 m .52788 .85667 L .528 .85676 L 0 0 0 r
F
.52788 .85667 m .52686 .85783 L .52664 .85842 L 0 .903 .161 r
F
.52582 .85979 m .52686 .85783 L .52788 .85667 L 0 0 0 r
F
.52582 .85979 m .528 .85676 L .52713 .85805 L F
.5284 .85971 m .52583 .86074 L .52858 .85638 L F
.52538 .85644 m .52644 .86639 L .52696 .8661 L 0 .285 .282 r
F
.52739 .86589 m .52915 .86074 L .52782 .86503 L 0 0 .014 r
F
.52696 .8661 m .5292 .87984 L .52739 .8659 L 0 .285 .282 r
F
.52541 .8699 m .52696 .8661 L .52739 .86589 L 0 0 .014 r
F
.52696 .8661 m .52915 .86074 L .52739 .86589 L F
.52696 .8661 m .52739 .8659 L .52738 .86587 L 0 .285 .282 r
F
.52538 .85644 m .52696 .8661 L .52738 .86587 L F
.52678 .86655 m .52687 .86615 L .52696 .8661 L 0 0 .014 r
F
.52541 .8699 m .5263 .86684 L .52678 .86655 L F
.51992 .84839 m .52798 .85025 L .52774 .84778 L 0 1 .514 r
F
.51964 .84284 m .51992 .84839 L .52738 .84434 L 0 1 .519 r
F
.51964 .84284 m .52738 .84434 L .52714 .84223 L F
.51936 .83824 m .51964 .84284 L .52678 .83942 L 0 1 .527 r
F
.51936 .83824 m .52678 .83942 L .52654 .8378 L F
.52792 .83971 m .52426 .84939 L .52938 .85089 L 0 1 .462 r
F
.52792 .83971 m .52023 .84501 L .52426 .84939 L F
.52792 .83971 m .51997 .84068 L .52023 .84501 L F
.52792 .83971 m .52327 .83841 L .51997 .84068 L F
.51908 .83442 m .51936 .83824 L .52619 .83569 L 0 1 .537 r
F
.51908 .83442 m .52619 .83569 L .52595 .8345 L F
.51873 .82905 m .51908 .83442 L .52555 .83227 L 0 1 .538 r
F
.51873 .82905 m .52555 .83227 L .52525 .83048 L F
.52646 .82799 m .52327 .83841 L .52792 .83971 L 0 1 .455 r
F
.52646 .82799 m .51958 .83401 L .52327 .83841 L F
.52646 .82799 m .51932 .82945 L .51958 .83401 L F
.51846 .82308 m .51873 .82905 L .52486 .8274 L 0 1 .529 r
F
.52646 .82799 m .52227 .82687 L .51932 .82945 L 0 1 .455 r
F
.51846 .82308 m .52486 .8274 L .52463 .82508 L 0 1 .529 r
F
.51819 .81546 m .51846 .82308 L .52428 .821 L 0 1 .516 r
F
.51819 .81546 m .52428 .821 L .52405 .81787 L F
.525 .81559 m .52227 .82687 L .52646 .82799 L 0 1 .447 r
F
.52788 .85667 m .52736 .85804 L .52877 .85681 L 0 .903 .161 r
F
.53 .86436 m .52782 .86503 L .52915 .86074 L 0 0 .014 r
F
.53 .86436 m .52982 .86457 L .52782 .86503 L F
.53 .86489 m .52982 .86457 L .52782 .86795 L 0 .258 .269 r
F
.52982 .86457 m .52795 .8656 L .52782 .86503 L 0 0 .014 r
F
.52982 .86457 m .52817 .86155 L .52795 .8656 L 0 .258 .269 r
F
.52982 .86457 m .52795 .8656 L .52782 .86795 L F
.52982 .86457 m .528 .86581 L .52795 .8656 L 0 0 .014 r
F
.52982 .86457 m .52818 .86659 L .528 .86581 L F
.52575 .82669 m .52817 .86155 L .52982 .86457 L 0 .32 .281 r
F
.52586 .88055 m .52818 .86659 L .52982 .86457 L 0 0 .06 r
F
.52996 .86452 m .52982 .86457 L .53 .86436 L F
.52985 .86456 m .52982 .86457 L .52986 .86464 L 0 .32 .281 r
F
.52586 .88055 m .52982 .86457 L .52996 .86452 L 0 0 .06 r
F
.52985 .86456 m .52982 .86457 L .52985 .86456 L 0 .32 .281 r
F
.52575 .82669 m .52982 .86457 L .52985 .86456 L F
.52996 .86457 m .52986 .86464 L .53 .86489 L F
.52586 .88055 m .52996 .86452 L .53002 .86773 L 0 0 .06 r
F
.52575 .82669 m .52996 .86452 L .52999 .85563 L 0 .32 .281 r
F
.52996 .86452 m .53 .86489 L .53 .8645 L F
.52996 .86452 m .53 .86436 L .53 .8645 L 0 0 .06 r
F
.52996 .86452 m .53 .8645 L .52999 .85563 L 0 .32 .281 r
F
.52996 .86452 m .53 .8645 L .53 .86451 L 0 0 .06 r
F
.52996 .86452 m .53 .86451 L .53002 .86773 L F
.52996 .86452 m .52986 .86464 L .52996 .86457 L 0 .32 .281 r
F
.52575 .82669 m .52985 .86456 L .52996 .86452 L F
.52985 .86456 m .52986 .86464 L .52996 .86452 L F
.52575 .82669 m .52999 .85563 L .52815 .83997 L F
.52907 .83136 m .53405 .86258 L .53176 .84548 L 0 .301 .275 r
F
.52907 .83136 m .52815 .83997 L .52999 .85563 L F
.52846 .88543 m .525 .88434 L .5259 .89327 L 0 .247 .273 r
F
.52846 .88543 m .5261 .88098 L .525 .88434 L F
.53189 .82936 m .53016 .83239 L .53088 .83714 L 0 1 .452 r
F
.53222 .8352 m .53098 .83377 L .53176 .84548 L 0 .29 .268 r
F
.53222 .8352 m .53176 .84548 L .53405 .86258 L F
.52586 .88055 m .53002 .86773 L .52823 .87448 L 0 0 .06 r
F
.52918 .87741 m .52823 .87448 L .53002 .86773 L 0 0 .065 r
F
.52918 .87741 m .52787 .87864 L .52823 .87448 L F
.51798 .89032 m .51826 .89714 L .52385 .89771 L 0 1 .493 r
F
.51826 .89714 m .51044 .89906 L .51853 .9028 L 0 .948 .49 r
F
.51799 .89889 m .52385 .89912 L .52362 .8968 L 0 1 .445 r
F
.51853 .9028 m .5103 .90341 L .5188 .90678 L 0 .906 .482 r
F
.51853 .9028 m .50406 .89949 L .5103 .90341 L F
.51853 .9028 m .50424 .89765 L .50406 .89949 L F
.51853 .9028 m .5188 .90678 L .52501 .9082 L F
.51853 .9028 m .51044 .89906 L .50424 .89765 L F
.51853 .9028 m .52501 .9082 L .52478 .90672 L F
.51799 .89889 m .51826 .90493 L .52385 .89912 L 0 1 .445 r
F
.51798 .89032 m .51057 .89355 L .51826 .89714 L 0 1 .493 r
F
.51772 .89358 m .52327 .89353 L .52304 .89149 L 0 1 .437 r
F
.51826 .89714 m .50451 .89464 L .51044 .89906 L 0 .948 .49 r
F
.51826 .89714 m .50468 .89248 L .50451 .89464 L F
.51826 .89714 m .51057 .89355 L .50468 .89248 L F
.51772 .89358 m .51799 .89889 L .52327 .89353 L 0 1 .437 r
F
.5222 .89223 m .52565 .90858 L .52491 .90139 L 0 .28 .298 r
F
.52377 .87661 m .52379 .88946 L .52502 .89719 L 0 .271 .285 r
F
.52377 .87661 m .5259 .89327 L .525 .88434 L F
.52377 .87661 m .5259 .89878 L .5259 .89327 L F
.52377 .87661 m .52502 .89719 L .5259 .89878 L F
.52391 .89955 m .52918 .87741 L .5285 .8833 L 0 .125 .092 r
F
.52391 .89955 m .52787 .87864 L .52918 .87741 L F
.52391 .89955 m .52554 .88572 L .52787 .87864 L F
.52391 .89955 m .5285 .8833 L .52626 .8924 L F
.52603 .89893 m .52626 .8924 L .5285 .8833 L 0 .138 .097 r
F
.52629 .89328 m .53273 .83929 L .52997 .84868 L 0 .523 .258 r
F
.52629 .89328 m .53398 .84951 L .53273 .83929 L F
.53234 .87462 m .5311 .87569 L .53184 .87065 L 0 0 .07 r
F
.52603 .89893 m .5311 .87569 L .53234 .87462 L 0 .138 .097 r
F
.52603 .89893 m .5285 .8833 L .5311 .87569 L F
.52629 .89328 m .53277 .8712 L .53398 .84951 L 0 .523 .258 r
F
.53189 .82936 m .53059 .82905 L .53016 .83239 L 0 1 .452 r
F
.52982 .81672 m .52907 .82507 L .53059 .82905 L 0 1 .444 r
F
.52982 .81672 m .52834 .82005 L .52907 .82507 L F
.52982 .81672 m .52867 .81648 L .52834 .82005 L F
.52982 .81672 m .53059 .82905 L .53189 .82936 L F
.52776 .80327 m .52867 .81648 L .52982 .81672 L 0 1 .435 r
F
.52776 .80327 m .52982 .81672 L .53004 .81286 L F
.52776 .80327 m .53004 .81286 L .52917 .80746 L F
.52568 .78884 m .52776 .80327 L .52786 .79907 L 0 1 .425 r
F
.52568 .78884 m .52786 .79907 L .52699 .79328 L F
.5258 .78455 m .53098 .83377 L .53222 .8352 L 0 .423 .279 r
F
.52776 .80327 m .52726 .81229 L .52867 .81648 L 0 1 .435 r
F
.52776 .80327 m .52653 .80695 L .52726 .81229 L F
.52776 .80327 m .52674 .80308 L .52653 .80695 L F
.52568 .78884 m .52674 .80308 L .52776 .80327 L 0 1 .425 r
F
.5258 .78455 m .52834 .8181 L .53098 .83377 L 0 .423 .279 r
F
.525 .81559 m .52646 .82799 L .52907 .82507 L 0 1 .447 r
F
.525 .81559 m .52907 .82507 L .52834 .82005 L F
.52353 .80239 m .525 .81559 L .52725 .81229 L 0 1 .439 r
F
.52353 .80239 m .52725 .81229 L .52653 .80695 L F
.51737 .78717 m .52254 .79342 L .52231 .78928 L 0 1 .478 r
F
.52205 .78824 m .52353 .80239 L .52543 .79865 L 0 1 .429 r
F
.52568 .78884 m .52544 .79865 L .52674 .80308 L 0 1 .425 r
F
.52205 .78824 m .52543 .79865 L .52471 .79293 L 0 1 .429 r
F
.52568 .78884 m .52471 .79293 L .52544 .79865 L 0 1 .425 r
F
.52568 .78884 m .52481 .78872 L .52471 .79293 L F
.5236 .77332 m .52361 .78401 L .52481 .78872 L 0 1 .414 r
F
.52371 .78381 m .52907 .83136 L .52834 .8181 L 0 .435 .283 r
F
.52371 .78381 m .52776 .82958 L .52907 .83136 L F
.52371 .78381 m .5254 .81458 L .52776 .82958 L F
.52575 .82669 m .52576 .84823 L .52817 .86155 L 0 .32 .281 r
F
.52907 .83136 m .52776 .82958 L .52815 .83997 L 0 .301 .275 r
F
.52541 .8699 m .52353 .87208 L .52278 .87103 L 0 0 .014 r
F
.52069 .87092 m .52379 .88946 L .52304 .88074 L 0 .295 .296 r
F
.51771 .88273 m .51798 .89032 L .52326 .89039 L 0 1 .492 r
F
.51798 .89032 m .50495 .88899 L .51057 .89355 L 0 1 .493 r
F
.51798 .89032 m .50513 .88651 L .50495 .88899 L F
.51798 .89032 m .51071 .88707 L .50513 .88651 L F
.51771 .88273 m .51071 .88707 L .51798 .89032 L 0 1 .492 r
F
.51744 .88877 m .51772 .89358 L .52268 .88859 L 0 1 .422 r
F
.51744 .88877 m .52268 .88859 L .52245 .88675 L F
.51716 .88439 m .51744 .88877 L .5221 .88411 L 0 1 .399 r
F
.51716 .88439 m .5221 .88411 L .52186 .88242 L F
.51771 .88273 m .5054 .88257 L .51071 .88707 L 0 1 .492 r
F
.51771 .88273 m .50558 .8798 L .5054 .88257 L F
.51771 .88273 m .51085 .87987 L .50558 .8798 L F
.51743 .87461 m .51085 .87987 L .51771 .88273 L 0 1 .488 r
F
.51688 .88025 m .51716 .88439 L .5215 .87996 L 0 1 .367 r
F
.51688 .88025 m .5215 .87996 L .52126 .87836 L F
.52069 .87092 m .5222 .89223 L .52379 .88946 L 0 .295 .296 r
F
.52377 .87661 m .52304 .88075 L .52379 .88946 L 0 .271 .285 r
F
.52239 .88392 m .52541 .8699 L .52581 .87263 L 0 0 .057 r
F
.52377 .87661 m .52304 .87524 L .52304 .88075 L 0 .271 .285 r
F
.52239 .88392 m .52353 .87208 L .52541 .8699 L 0 0 .057 r
F
.52239 .88392 m .52581 .87263 L .52447 .87847 L F
.52414 .87929 m .52951 .81751 L .52702 .83052 L 0 .556 .26 r
F
.52414 .87929 m .53082 .82558 L .52951 .81751 L F
.52414 .87929 m .52997 .84868 L .53082 .82558 L F
.52914 .81691 m .53283 .84954 L .53119 .84711 L 0 .666 .167 r
F
.52927 .86802 m .53283 .84954 L .53121 .84744 L 0 .765 .303 r
F
.53497 .81648 m .53775 .85401 L .53605 .85107 L 0 .691 .18 r
F
.53497 .81648 m .53611 .85291 L .53456 .83516 L F
.53611 .85291 m .53585 .85273 L .53456 .83516 L F
.53263 .85056 m .53347 .85027 L .53283 .84954 L 0 .765 .303 r
F
.52927 .86802 m .53515 .85226 L .53263 .85056 L F
.5258 .78455 m .53222 .8352 L .53112 .82073 L 0 .423 .279 r
F
.53384 .773 m .5316 .77322 L .53092 .77823 L 0 .971 .407 r
F
.53049 .75966 m .52597 .77388 L .53186 .77168 L 0 1 .441 r
F
.53049 .75966 m .52136 .77214 L .52597 .77388 L F
.53049 .75966 m .52111 .7676 L .52136 .77214 L F
.53049 .75966 m .52503 .76225 L .52111 .7676 L F
.5297 .75526 m .5316 .77322 L .53384 .773 L 0 .998 .396 r
F
.53375 .77022 m .5333 .77272 L .53598 .79317 L 0 .369 .259 r
F
.52774 .78427 m .53371 .82229 L .53062 .80043 L 0 .411 .275 r
F
.52953 .78285 m .53062 .80043 L .53371 .82229 L 0 .401 .271 r
F
.53273 .83929 m .53898 .7552 L .53597 .77091 L 0 .624 .253 r
F
.53255 .77598 m .53201 .77782 L .53442 .79717 L 0 .38 .263 r
F
.53273 .83929 m .53597 .77091 L .5336 .80549 L 0 .624 .253 r
F
.52914 .81691 m .53517 .85221 L .53283 .84954 L 0 .666 .167 r
F
.53515 .85226 m .53517 .85221 L .53263 .85056 L 0 .765 .303 r
F
.5258 .78455 m .53112 .82073 L .52843 .8001 L 0 .423 .279 r
F
.52774 .78427 m .52843 .8001 L .53112 .82073 L 0 .411 .275 r
F
.52951 .81751 m .53082 .82558 L .5336 .80549 L 0 .661 .255 r
F
.52914 .81691 m .53456 .83516 L .53585 .85273 L 0 .666 .167 r
F
.52914 .81691 m .53585 .85273 L .53517 .85221 L F
.53517 .85221 m .53625 .84929 L .53292 .85046 L 0 .765 .303 r
F
.53517 .85221 m .53292 .85046 L .53263 .85056 L F
.53519 .87863 m .53611 .85318 L .53466 .86376 L 0 .735 .292 r
F
.53775 .85401 m .53792 .85635 L .53605 .85107 L 0 .691 .18 r
F
.53149 .90054 m .53843 .8791 L .53475 .89157 L 0 .176 .109 r
F
.53295 .90258 m .53475 .89157 L .53843 .8791 L 0 .187 .114 r
F
.53295 .90258 m .53239 .90166 L .53475 .89157 L F
.5342 .90554 m .53372 .90424 L .53635 .89341 L 0 .197 .121 r
F
.52239 .92732 m .53149 .90054 L .52918 .90897 L 0 .256 .123 r
F
.52802 .91702 m .52677 .91847 L .52751 .92447 L 0 .23 .278 r
F
.52802 .91702 m .52699 .91528 L .52677 .91847 L F
.53153 .90911 m .52813 .91282 L .53128 .92264 L 0 .215 .264 r
F
.52312 .92899 m .53239 .90166 L .53295 .90258 L 0 .258 .126 r
F
.52312 .92899 m .52918 .90897 L .53239 .90166 L F
.52831 .90912 m .53538 .89789 L .53695 .87873 L 0 .474 .256 r
F
.53519 .87863 m .5375 .88396 L .54078 .87602 L 0 .735 .292 r
F
.53792 .85635 m .53968 .88021 L .53636 .8536 L 0 .691 .18 r
F
.53792 .85635 m .53636 .8536 L .53605 .85107 L F
.53611 .85318 m .53611 .85315 L .53586 .85288 L 0 .735 .292 r
F
.53605 .85107 m .53635 .85349 L .53611 .85315 L 0 .691 .18 r
F
.53611 .85315 m .53625 .84929 L .53588 .85273 L 0 .735 .292 r
F
.53611 .85318 m .53586 .85288 L .53466 .86376 L F
.53611 .85291 m .53629 .85877 L .53585 .85273 L 0 .691 .18 r
F
.53611 .85315 m .53588 .85273 L .53586 .85288 L 0 .735 .292 r
F
.52927 .86802 m .53466 .86376 L .53582 .85319 L 0 .765 .303 r
F
.52927 .86802 m .53582 .85319 L .53576 .8531 L F
.52927 .86802 m .53586 .85288 L .53517 .85221 L F
.52586 .88055 m .52581 .87263 L .52818 .86659 L 0 0 .06 r
F
.52629 .89328 m .52997 .84868 L .52752 .87149 L 0 .523 .258 r
F
.52586 .88055 m .52447 .87847 L .52581 .87263 L 0 0 .06 r
F
.52414 .87929 m .52752 .87149 L .52997 .84868 L 0 .556 .26 r
F
.52927 .86802 m .53121 .84744 L .53044 .84651 L 0 .765 .303 r
F
.52944 .84553 m .53044 .84651 L .52944 .8453 L F
.52927 .86802 m .53044 .84651 L .52944 .84553 L F
.525 .81559 m .51892 .82241 L .52227 .82687 L 0 1 .447 r
F
.5223 .82133 m .52576 .84823 L .52439 .83384 L 0 .349 .287 r
F
.5223 .82133 m .52538 .85644 L .52576 .84823 L F
.5223 .82133 m .5235 .85298 L .52538 .85644 L F
.52575 .82669 m .52439 .83384 L .52576 .84823 L 0 .32 .281 r
F
.52538 .85644 m .5235 .85298 L .52276 .85855 L 0 .285 .282 r
F
.52414 .87929 m .52702 .83052 L .52501 .85603 L 0 .556 .26 r
F
.525 .81559 m .51866 .81758 L .51892 .82241 L 0 1 .447 r
F
.525 .81559 m .52126 .81466 L .51866 .81758 L F
.51792 .80668 m .51819 .81546 L .52371 .81279 L 0 1 .502 r
F
.51792 .80668 m .52371 .81279 L .52347 .80914 L F
.52353 .80239 m .52126 .81466 L .525 .81559 L 0 1 .439 r
F
.51765 .79717 m .51792 .80668 L .52312 .80344 L 0 1 .489 r
F
.51765 .79717 m .52312 .80344 L .52289 .79948 L F
.51737 .78717 m .51765 .79717 L .52254 .79342 L 0 1 .478 r
F
.5171 .77683 m .51737 .78717 L .52196 .78299 L 0 1 .468 r
F
.5171 .77683 m .52196 .78299 L .52172 .77874 L F
.52353 .80239 m .51827 .8101 L .52126 .81466 L 0 1 .439 r
F
.52353 .80239 m .518 .80496 L .51827 .8101 L F
.52353 .80239 m .52026 .80166 L .518 .80496 L F
.52205 .78824 m .52026 .80166 L .52353 .80239 L 0 1 .429 r
F
.51737 .78717 m .51088 .79804 L .51765 .79717 L 0 1 .478 r
F
.52205 .78824 m .51761 .79697 L .52026 .80166 L 0 1 .429 r
F
.52205 .78824 m .51734 .79147 L .51761 .79697 L F
.52205 .78824 m .51925 .78772 L .51734 .79147 L F
.52058 .77301 m .51925 .78772 L .52205 .78824 L 0 1 .419 r
F
.52058 .77301 m .52205 .78824 L .52361 .78401 L F
.52152 .78218 m .52438 .82462 L .52575 .82669 L 0 .448 .286 r
F
.52152 .78218 m .52233 .81031 L .52438 .82462 L F
.52575 .82669 m .52438 .82462 L .52439 .83384 L 0 .32 .281 r
F
.5202 .85466 m .50147 .86265 L .50129 .86535 L 0 1 .512 r
F
.5202 .85466 m .50958 .85807 L .50147 .86265 L F
.51992 .84839 m .50958 .85807 L .5202 .85466 L 0 1 .514 r
F
.51992 .84839 m .50175 .85869 L .50958 .85807 L F
.51992 .84839 m .50193 .8561 L .50175 .85869 L F
.51992 .84839 m .50972 .85168 L .50193 .8561 L F
.51964 .84284 m .50972 .85168 L .51992 .84839 L 0 1 .519 r
F
.51657 .84694 m .51686 .85672 L .52086 .85523 L 0 1 .472 r
F
.51657 .84694 m .52086 .85523 L .52061 .85125 L F
.5171 .77683 m .51102 .7885 L .51737 .78717 L 0 1 .468 r
F
.52058 .77301 m .51695 .78288 L .51925 .78772 L 0 1 .419 r
F
.51923 .77977 m .5223 .82133 L .52233 .81031 L 0 .463 .29 r
F
.51923 .77977 m .52089 .81902 L .5223 .82133 L F
.52152 .78218 m .5254 .81458 L .52357 .79642 L 0 .448 .286 r
F
.52152 .78218 m .52575 .82669 L .5254 .81458 L F
.52371 .78381 m .52357 .79642 L .5254 .81458 L 0 .435 .283 r
F
.51951 .81672 m .52141 .84044 L .52051 .8272 L 0 .372 .291 r
F
.51951 .81672 m .52164 .84956 L .52141 .84044 L F
.51951 .81672 m .52105 .84847 L .52164 .84956 L F
.51951 .81672 m .52005 .83797 L .52105 .84847 L F
.5223 .82133 m .52089 .81902 L .52051 .8272 L 0 .349 .287 r
F
.5223 .82133 m .52051 .8272 L .52141 .84044 L F
.5223 .82133 m .52141 .84044 L .5235 .85298 L F
.51964 .84284 m .50221 .85231 L .50972 .85168 L 0 1 .519 r
F
.51964 .84284 m .50239 .84984 L .50221 .85231 L F
.51964 .84284 m .50987 .84578 L .50239 .84984 L F
.51936 .83824 m .50987 .84578 L .51964 .84284 L 0 1 .527 r
F
.51936 .83824 m .50267 .84623 L .50987 .84578 L F
.51936 .83824 m .50286 .84388 L .50267 .84623 L F
.51936 .83824 m .51001 .84045 L .50286 .84388 L F
.51908 .83442 m .51001 .84045 L .51936 .83824 L 0 1 .537 r
F
.51908 .83442 m .50314 .84038 L .51001 .84045 L F
.51626 .83626 m .51657 .84694 L .52023 .84501 L 0 1 .466 r
F
.51918 .84499 m .52192 .86624 L .52117 .85562 L 0 .325 .295 r
F
.51715 .86606 m .51099 .87209 L .51743 .87461 L 0 1 .483 r
F
.52069 .86894 m .517 .87065 L .51933 .86705 L 0 0 0 r
F
.51598 .87112 m .51962 .86996 L .51936 .86908 L 0 1 .211 r
F
.52069 .86894 m .51912 .87028 L .517 .87065 L 0 0 0 r
F
.51743 .87461 m .50585 .87547 L .51085 .87987 L 0 1 .488 r
F
.51743 .87461 m .50603 .87245 L .50585 .87547 L F
.51743 .87461 m .51099 .87209 L .50603 .87245 L F
.51659 .87661 m .51688 .88025 L .52089 .87611 L 0 1 .321 r
F
.51659 .87661 m .52089 .87611 L .52064 .87471 L F
.51628 .87346 m .51659 .87661 L .52026 .87274 L 0 1 .26 r
F
.51628 .87346 m .52026 .87274 L .52 .87153 L F
.51598 .87112 m .51628 .87346 L .51962 .86996 L 0 1 .211 r
F
.51912 .87028 m .51682 .87181 L .51701 .8774 L 0 .295 .296 r
F
.51912 .87028 m .51861 .87072 L .51847 .87071 L 0 0 0 r
F
.51912 .87028 m .51847 .87071 L .517 .87065 L F
.52069 .87092 m .51912 .87028 L .51701 .8774 L 0 .295 .296 r
F
.51861 .87072 m .51678 .87206 L .517 .87065 L 0 0 0 r
F
.51567 .86982 m .51598 .87112 L .51897 .86807 L 0 .923 .183 r
F
.51912 .87028 m .51674 .86932 L .51682 .87181 L 0 .295 .296 r
F
.51715 .86606 m .5063 .86778 L .51099 .87209 L 0 1 .483 r
F
.51715 .86606 m .50649 .86457 L .5063 .86778 L F
.51715 .86606 m .51113 .86383 L .50649 .86457 L F
.51686 .85672 m .51113 .86383 L .51715 .86606 L 0 1 .478 r
F
.51567 .86982 m .51897 .86807 L .51871 .8676 L 0 .923 .183 r
F
.51537 .86983 m .51567 .86982 L .51831 .86731 L 0 0 0 r
F
.51537 .86983 m .51831 .86731 L .51805 .86739 L F
.51506 .87155 m .51537 .86983 L .51766 .86803 L F
.51506 .87155 m .51766 .86803 L .5174 .86881 L F
.51598 .87112 m .51158 .87725 L .51628 .87346 L 0 1 .211 r
F
.51598 .87112 m .50819 .87931 L .51158 .87725 L F
.51598 .87112 m .50839 .87825 L .50819 .87931 L F
.51598 .87112 m .51173 .87474 L .50839 .87825 L F
.51632 .8721 m .51506 .87155 L .517 .87065 L 0 0 0 r
F
.51474 .85997 m .51632 .8721 L .51674 .86932 L 0 .341 .309 r
F
.51632 .8721 m .51701 .8774 L .51682 .87182 L F
.51632 .8721 m .51682 .87182 L .51674 .86932 L F
.51628 .87346 m .50769 .88251 L .51142 .88057 L 0 1 .26 r
F
.51628 .87346 m .50789 .88113 L .50769 .88251 L F
.51628 .87346 m .51158 .87725 L .50789 .88113 L F
.51659 .87661 m .51127 .88437 L .51688 .88025 L 0 1 .321 r
F
.51659 .87661 m .50721 .88629 L .51127 .88437 L F
.51659 .87661 m .5074 .88472 L .50721 .88629 L F
.51659 .87661 m .51142 .88057 L .5074 .88472 L F
.51628 .87346 m .51142 .88057 L .51659 .87661 L 0 1 .26 r
F
.51495 .87293 m .5122 .87478 L .51506 .87973 L 0 .341 .309 r
F
.51632 .8721 m .51506 .87973 L .51701 .8774 L F
.51495 .87289 m .51495 .87287 L .51603 .87226 L 0 0 0 r
F
.51495 .87289 m .51603 .87226 L .51632 .8721 L F
.51495 .87287 m .51506 .87155 L .51632 .8721 L F
.51567 .86982 m .51173 .87474 L .51598 .87112 L 0 .923 .183 r
F
.51567 .86982 m .50869 .87696 L .51173 .87474 L F
.51567 .86982 m .50889 .8763 L .50869 .87696 L F
.51567 .86982 m .51189 .87324 L .50889 .8763 L F
.51537 .86983 m .51189 .87324 L .51567 .86982 L 0 0 0 r
F
.51537 .86983 m .50919 .87568 L .51189 .87324 L F
.51537 .86983 m .5094 .87552 L .50919 .87568 L F
.51537 .86983 m .51204 .87301 L .5094 .87552 L F
.51506 .87155 m .51204 .87301 L .51537 .86983 L F
.51506 .87155 m .5097 .87575 L .51204 .87301 L F
.51506 .87155 m .51017 .87597 L .5097 .87575 L F
.51506 .87973 m .51015 .87599 L .5097 .88211 L 0 .322 .315 r
F
.51017 .87597 m .51015 .87599 L .50989 .87619 L 0 0 0 r
F
.51017 .87597 m .50989 .87619 L .5097 .87575 L F
.51015 .87599 m .5099 .8758 L .50989 .87619 L 0 .322 .315 r
F
.51015 .87599 m .50989 .87619 L .5097 .88211 L F
.51015 .87599 m .5099 .87622 L .50989 .87619 L 0 0 0 r
F
.50706 .87754 m .50621 .87809 L .50919 .87568 L F
.50706 .87754 m .50919 .87568 L .5094 .87552 L F
.50621 .87809 m .50869 .87696 L .50889 .8763 L 0 .883 .176 r
F
.49212 .87585 m .50037 .87934 L .50056 .87648 L 0 1 .518 r
F
.49669 .87476 m .50307 .87841 L .50326 .87396 L 0 1 .447 r
F
.49135 .88295 m .49058 .89015 L .49992 .88655 L 0 1 .517 r
F
.49135 .88295 m .49992 .88655 L .5001 .88365 L F
.49212 .87585 m .49135 .88295 L .50037 .87934 L 0 1 .518 r
F
.49669 .87476 m .49589 .88538 L .50307 .87841 L 0 1 .447 r
F
.5006 .87566 m .5054 .88257 L .50558 .8798 L 0 1 .501 r
F
.50137 .86827 m .5006 .87566 L .50585 .87547 L 0 1 .495 r
F
.50137 .86827 m .50585 .87547 L .50603 .87245 L F
.5006 .87566 m .49984 .88249 L .5054 .88257 L 0 1 .501 r
F
.50621 .87809 m .50112 .88307 L .50536 .87986 L 0 .883 .176 r
F
.49589 .88538 m .5026 .88933 L .50279 .88499 L 0 1 .46 r
F
.49589 .88538 m .49509 .89577 L .5026 .88933 L F
.49589 .88538 m .48526 .90005 L .49509 .89577 L F
.49135 .88295 m .4783 .89205 L .49058 .89015 L 0 1 .517 r
F
.49589 .88538 m .47834 .90046 L .48526 .90005 L 0 1 .46 r
F
.49589 .88538 m .47896 .89671 L .47834 .90046 L F
.49589 .88538 m .48649 .89025 L .47896 .89671 L F
.49135 .88295 m .46953 .89135 L .4783 .89205 L 0 1 .517 r
F
.49135 .88295 m .47013 .88852 L .46953 .89135 L F
.49135 .88295 m .47949 .88492 L .47013 .88852 L F
.49212 .87585 m .47949 .88492 L .49135 .88295 L 0 1 .518 r
F
.49669 .87476 m .48649 .89025 L .49589 .88538 L 0 1 .447 r
F
.49984 .88249 m .49146 .88575 L .49909 .88867 L 0 1 .507 r
F
.49984 .88249 m .49909 .88867 L .50495 .88899 L F
.49984 .88249 m .50495 .88899 L .50513 .88651 L F
.50621 .87809 m .49843 .88486 L .50112 .88307 L 0 .883 .176 r
F
.50621 .87809 m .4991 .88405 L .49843 .88486 L F
.50621 .87809 m .50243 .88115 L .4991 .88405 L F
.50706 .87754 m .50243 .88115 L .50621 .87809 L 0 0 0 r
F
.50706 .87754 m .5009 .88253 L .50243 .88115 L F
.49509 .89577 m .50213 .89984 L .50232 .89569 L 0 1 .471 r
F
.49509 .89577 m .4943 .90578 L .50213 .89984 L F
.49509 .89577 m .48403 .90957 L .4943 .90578 L F
.49509 .89577 m .47678 .90967 L .48403 .90957 L F
.49509 .89577 m .4774 .90601 L .47678 .90967 L F
.49509 .89577 m .48526 .90005 L .4774 .90601 L F
.49759 .89896 m .48147 .89906 L .48764 .90254 L 0 1 .525 r
F
.49759 .89896 m .48224 .89645 L .48147 .89906 L F
.49759 .89896 m .48914 .89641 L .48224 .89645 L F
.49834 .89415 m .48914 .89641 L .49759 .89896 L 0 1 .519 r
F
.49834 .89415 m .48325 .89291 L .48914 .89641 L F
.49834 .89415 m .48383 .8908 L .48325 .89291 L F
.49834 .89415 m .4903 .89133 L .48383 .8908 L F
.49909 .88867 m .4903 .89133 L .49834 .89415 L 0 1 .513 r
F
.49909 .88867 m .49834 .89415 L .50451 .89464 L F
.49909 .88867 m .50451 .89464 L .50468 .89248 L F
.50288 .89012 m .49261 .89776 L .49198 .89965 L 0 1 .363 r
F
.50288 .89012 m .49728 .89367 L .49261 .89776 L F
.50368 .88612 m .49728 .89367 L .50288 .89012 L 0 1 .309 r
F
.50368 .88612 m .49355 .89508 L .49728 .89367 L F
.50368 .88612 m .49418 .8934 L .49355 .89508 L F
.50368 .88612 m .49852 .88956 L .49418 .8934 L F
.50452 .88259 m .49852 .88956 L .50368 .88612 L 0 1 .242 r
F
.49669 .87476 m .47989 .89107 L .48649 .89025 L 0 1 .447 r
F
.49909 .88867 m .48471 .88752 L .4903 .89133 L 0 1 .513 r
F
.49669 .87476 m .48052 .88728 L .47989 .89107 L 0 1 .447 r
F
.49909 .88867 m .48529 .88526 L .48471 .88752 L 0 1 .513 r
F
.49909 .88867 m .49146 .88575 L .48529 .88526 L F
.50452 .88259 m .49514 .89103 L .49852 .88956 L 0 1 .242 r
F
.50452 .88259 m .4958 .88954 L .49514 .89103 L F
.50452 .88259 m .49982 .88592 L .4958 .88954 L F
.50536 .87986 m .49982 .88592 L .50452 .88259 L 0 .987 .208 r
F
.50536 .87986 m .49678 .88754 L .49982 .88592 L F
.50536 .87986 m .49744 .88636 L .49678 .88754 L F
.50536 .87986 m .50112 .88307 L .49744 .88636 L F
.5009 .88253 m .50025 .88304 L .50241 .89049 L 0 .398 .338 r
F
.5009 .88253 m .50009 .88318 L .50025 .88304 L 0 0 0 r
F
.5009 .88253 m .50025 .88304 L .50243 .88115 L F
.50368 .88612 m .50288 .89012 L .50721 .88629 L 0 1 .309 r
F
.50368 .88612 m .50721 .88629 L .5074 .88472 L F
.50452 .88259 m .50368 .88612 L .50769 .88251 L 0 1 .242 r
F
.50706 .88285 m .5009 .88253 L .50241 .89049 L 0 .398 .338 r
F
.5009 .88253 m .50009 .88248 L .50025 .88304 L F
.5009 .88253 m .50075 .88283 L .50009 .88318 L 0 0 0 r
F
.50706 .87754 m .50395 .88015 L .5009 .88253 L F
.50452 .88259 m .50769 .88251 L .50789 .88113 L 0 1 .242 r
F
.50536 .87986 m .50452 .88259 L .50819 .87931 L 0 .987 .208 r
F
.50706 .88285 m .50395 .88015 L .5009 .88253 L 0 .398 .338 r
F
.50395 .88015 m .50075 .88283 L .5009 .88253 L 0 0 0 r
F
.5009 .88253 m .50077 .87739 L .50009 .88248 L 0 .398 .338 r
F
.50395 .88015 m .50077 .87739 L .5009 .88253 L F
.50382 .88026 m .50374 .88041 L .50075 .88283 L 0 0 0 r
F
.50395 .88015 m .50375 .87754 L .50077 .87739 L 0 .398 .338 r
F
.50706 .88285 m .50491 .8794 L .50395 .88015 L F
.50491 .8794 m .50375 .87754 L .50395 .88015 L F
.50395 .88015 m .50491 .8794 L .50382 .88026 L 0 0 0 r
F
.50706 .87754 m .50491 .8794 L .50395 .88015 L F
.50491 .8794 m .50374 .88041 L .50382 .88026 L F
.50793 .86738 m .50375 .87754 L .50491 .8794 L 0 .397 .328 r
F
.50493 .87939 m .50491 .8794 L .50492 .87942 L F
.50536 .87986 m .50819 .87931 L .50839 .87825 L 0 .987 .208 r
F
.50621 .87809 m .50536 .87986 L .50869 .87696 L 0 .883 .176 r
F
.50734 .87786 m .50492 .87942 L .50706 .88285 L 0 .397 .328 r
F
.50906 .87675 m .50706 .87754 L .5097 .87575 L 0 0 0 r
F
.50905 .87676 m .50903 .87677 L .50906 .87675 L F
.50903 .87677 m .50706 .87754 L .50906 .87675 L F
.50905 .87676 m .50706 .88285 L .5097 .88211 L 0 .397 .328 r
F
.50734 .87786 m .50732 .87785 L .50905 .87676 L 0 0 0 r
F
.50732 .87785 m .50706 .87754 L .50905 .87676 L F
.50793 .86738 m .50734 .87786 L .50905 .87676 L 0 .397 .328 r
F
.50734 .87786 m .50706 .88285 L .50905 .87676 L F
.50792 .87854 m .50734 .87786 L .50905 .87676 L 0 0 0 r
F
.50792 .87854 m .50374 .88041 L .50491 .8794 L F
.50734 .87786 m .50491 .8794 L .50706 .87754 L F
.50792 .87854 m .50491 .8794 L .50734 .87786 L F
.50493 .87939 m .50491 .8794 L .50493 .87939 L 0 .397 .328 r
F
.50793 .86738 m .50491 .8794 L .50493 .87939 L F
.50793 .86738 m .50492 .87942 L .50734 .87786 L F
.50793 .86738 m .50905 .87676 L .5099 .8758 L F
.50905 .87676 m .50906 .87682 L .50918 .87668 L F
.50906 .87682 m .5097 .88211 L .50989 .87619 L F
.50792 .87854 m .50905 .87676 L .5099 .87622 L 0 0 0 r
F
.50905 .87676 m .5097 .87575 L .50989 .87619 L F
.50905 .87676 m .50918 .87668 L .50919 .87666 L 0 .397 .328 r
F
.50906 .87682 m .50989 .87619 L .5099 .8758 L F
.50905 .87676 m .50989 .87619 L .5099 .87622 L 0 0 0 r
F
.50905 .87676 m .50919 .87666 L .5099 .8758 L 0 .397 .328 r
F
.51506 .87155 m .5122 .87442 L .51112 .87526 L 0 0 0 r
F
.51506 .87973 m .51112 .87526 L .51015 .87599 L 0 .322 .315 r
F
.51015 .87599 m .51112 .87526 L .5099 .87622 L 0 0 0 r
F
.51506 .87155 m .51112 .87526 L .51015 .87599 L F
.51506 .87973 m .5122 .87478 L .51112 .87526 L 0 .322 .315 r
F
.51015 .87599 m .51112 .87526 L .5099 .8758 L F
.51495 .87289 m .5122 .87442 L .51506 .87155 L 0 0 0 r
F
.51495 .87289 m .51444 .87324 L .51495 .87293 L 0 .341 .309 r
F
.51444 .87324 m .5122 .87478 L .51495 .87293 L F
.51225 .87446 m .5122 .87478 L .51495 .87289 L F
.51474 .85997 m .51021 .86544 L .51214 .87451 L F
.51226 .87444 m .51214 .87451 L .5122 .87478 L F
.51475 .87544 m .51021 .87753 L .51214 .87451 L 0 0 0 r
F
.51226 .87444 m .51214 .87451 L .5122 .87442 L F
.51475 .87544 m .51214 .87451 L .51226 .87444 L F
.51226 .87444 m .51214 .87451 L .51214 .87451 L 0 .341 .309 r
F
.51474 .85997 m .51214 .87451 L .51226 .87444 L F
.51351 .87372 m .51224 .87444 L .51495 .87289 L 0 0 0 r
F
.51224 .87444 m .5122 .87442 L .51495 .87289 L F
.51474 .85997 m .51226 .87444 L .51495 .87289 L 0 .341 .309 r
F
.51226 .87444 m .51225 .87446 L .51495 .87289 L F
.51495 .87291 m .51351 .87372 L .51495 .87289 L 0 0 0 r
F
.51475 .87544 m .51226 .87444 L .51495 .87291 L F
.51226 .87444 m .51224 .87444 L .51495 .87291 L F
.51474 .85997 m .51495 .87289 L .51632 .8721 L 0 .341 .309 r
F
.51495 .87289 m .51495 .87293 L .51603 .87227 L F
.51495 .87289 m .51603 .87227 L .51632 .8721 L F
.51495 .87293 m .51506 .87973 L .51632 .8721 L F
.51475 .87544 m .51632 .8721 L .51674 .87232 L 0 0 0 r
F
.51632 .8721 m .51632 .87209 L .51633 .87209 L F
.51632 .8721 m .51633 .87209 L .51674 .87232 L F
.51632 .87209 m .517 .87065 L .51682 .87179 L F
.51632 .87209 m .51682 .87179 L .51674 .87232 L F
.51475 .87544 m .51495 .87289 L .51632 .8721 L F
.51912 .87028 m .51832 .87159 L .51674 .87232 L F
.52069 .86894 m .52002 .86969 L .51912 .87028 L F
.52002 .86969 m .51832 .87159 L .51912 .87028 L F
.51912 .87028 m .51832 .86654 L .51674 .86932 L 0 .295 .296 r
F
.52069 .87092 m .52002 .86969 L .51912 .87028 L F
.52002 .86969 m .51832 .86654 L .51912 .87028 L F
.52069 .87092 m .51701 .8774 L .51935 .88721 L F
.51921 .87694 m .51832 .87159 L .52002 .86969 L 0 0 .015 r
F
.52061 .8694 m .52002 .86969 L .52069 .86894 L F
.52061 .8694 m .52002 .86969 L .52069 .87092 L 0 .325 .295 r
F
.51921 .87694 m .52002 .86969 L .52061 .8694 L 0 0 .015 r
F
.51918 .84499 m .51832 .86654 L .52002 .86969 L 0 .325 .295 r
F
.51918 .84499 m .52002 .86969 L .52061 .8694 L F
.51918 .84499 m .5206 .86926 L .52192 .86624 L F
.52061 .8694 m .52069 .87092 L .52116 .86914 L F
.52069 .87092 m .51935 .88721 L .5222 .89223 L 0 .295 .296 r
F
.51921 .87694 m .52061 .8694 L .52192 .86947 L 0 0 .015 r
F
.52061 .8694 m .52069 .86894 L .52116 .86914 L F
.52061 .8694 m .52116 .86914 L .52192 .86947 L F
.5206 .86926 m .52061 .8694 L .52125 .86879 L 0 .325 .295 r
F
.52061 .8694 m .52116 .86914 L .52125 .86879 L F
.5206 .86926 m .52125 .86879 L .52192 .86624 L F
.51861 .87072 m .51674 .87232 L .51678 .87206 L 0 0 0 r
F
.51954 .85746 m .52395 .81655 L .52406 .79324 L 0 .591 .263 r
F
.52371 .78381 m .52834 .8181 L .52606 .79871 L 0 .435 .283 r
F
.52188 .86733 m .52614 .80092 L .52395 .81655 L 0 .577 .261 r
F
.5258 .78455 m .52606 .79871 L .52834 .8181 L 0 .423 .279 r
F
.52188 .86733 m .5275 .80695 L .52614 .80092 L 0 .577 .261 r
F
.52188 .86733 m .52702 .83052 L .5275 .80695 L F
.52164 .84956 m .52117 .85562 L .52192 .86624 L 0 .302 .289 r
F
.52188 .86733 m .52395 .81655 L .52238 .84356 L 0 .577 .261 r
F
.52164 .84956 m .52105 .84847 L .52117 .85562 L 0 .302 .289 r
F
.51954 .85746 m .52238 .84356 L .52395 .81655 L 0 .591 .263 r
F
.52188 .86733 m .52501 .85603 L .52702 .83052 L 0 .577 .261 r
F
.52312 .81406 m .52858 .84418 L .52628 .84228 L 0 .631 .154 r
F
.52858 .84418 m .52866 .84461 L .52628 .84228 L F
.5232 .86061 m .52628 .84228 L .52448 .84079 L 0 .791 .315 r
F
.5232 .86061 m .52851 .84506 L .52628 .84228 L F
.52851 .84506 m .52866 .84461 L .52628 .84228 L F
.52448 .84079 m .52461 .84045 L .52451 .84033 L F
.52628 .84228 m .52461 .84045 L .52448 .84079 L F
.52914 .81691 m .53112 .84614 L .52942 .84359 L 0 .666 .167 r
F
.52188 .86733 m .5228 .87186 L .52501 .85603 L 0 .577 .261 r
F
.5232 .86061 m .52833 .85536 L .52922 .84509 L 0 .791 .315 r
F
.52312 .81406 m .52827 .83048 L .52922 .84509 L 0 .631 .154 r
F
.52312 .81406 m .52922 .84509 L .52866 .84461 L F
.52914 .81691 m .52944 .8453 L .52827 .83048 L 0 .666 .167 r
F
.52927 .86802 m .52944 .8453 L .52833 .85536 L 0 .765 .303 r
F
.52944 .8453 m .52948 .84911 L .52922 .84509 L 0 .666 .167 r
F
.52944 .8453 m .52922 .84509 L .52827 .83048 L F
.52944 .8453 m .52946 .84228 L .52922 .84509 L 0 .765 .303 r
F
.52944 .8453 m .52922 .84509 L .52833 .85536 L F
.52866 .84461 m .52922 .84509 L .52946 .84228 L 0 .791 .315 r
F
.5232 .86061 m .52922 .84509 L .52866 .84461 L F
.52866 .84461 m .52922 .84509 L .52948 .84911 L 0 .631 .154 r
F
.5232 .86061 m .52564 .86323 L .52833 .85536 L 0 .791 .315 r
F
.52628 .84228 m .52818 .85917 L .52456 .84039 L 0 .631 .154 r
F
.52628 .84228 m .52456 .84039 L .5245 .84004 L F
.52312 .81406 m .52628 .84228 L .5245 .84004 L F
.52628 .84228 m .52811 .83143 L .52461 .84045 L 0 .791 .315 r
F
.52461 .84045 m .52462 .84044 L .52451 .84033 L F
.52451 .84033 m .52818 .85917 L .52523 .85384 L 0 .631 .154 r
F
.5245 .84004 m .52456 .84039 L .52451 .84033 L F
.52456 .84039 m .52818 .85917 L .52451 .84033 L F
.52312 .81406 m .52451 .84033 L .52251 .83827 L F
.51626 .83626 m .52023 .84501 L .51997 .84068 L 0 1 .466 r
F
.51923 .77977 m .52233 .81031 L .52096 .79334 L 0 .463 .29 r
F
.52152 .78218 m .52096 .79334 L .52233 .81031 L 0 .448 .286 r
F
.52371 .78381 m .52285 .78326 L .52357 .79642 L 0 .435 .283 r
F
.51954 .85746 m .52406 .79324 L .52265 .78902 L 0 .591 .263 r
F
.52312 .81406 m .52251 .83825 L .52181 .82395 L 0 .631 .154 r
F
.51954 .85746 m .52048 .86115 L .52238 .84356 L 0 .591 .263 r
F
.52251 .83827 m .52248 .83824 L .52185 .84974 L 0 .791 .315 r
F
.51819 .81546 m .51047 .82274 L .51846 .82308 L 0 1 .516 r
F
.51819 .81546 m .50461 .82034 L .51047 .82274 L F
.51819 .81546 m .50478 .81747 L .50461 .82034 L F
.51819 .81546 m .51061 .81538 L .50478 .81747 L F
.51792 .80668 m .51061 .81538 L .51819 .81546 L 0 1 .502 r
F
.51873 .82905 m .51015 .83551 L .51908 .83442 L 0 1 .538 r
F
.51873 .82905 m .50363 .83409 L .51015 .83551 L F
.51873 .82905 m .50386 .8311 L .50363 .83409 L F
.51873 .82905 m .51033 .82894 L .50386 .8311 L F
.51846 .82308 m .51033 .82894 L .51873 .82905 L 0 1 .529 r
F
.51596 .82501 m .51958 .83401 L .51932 .82945 L 0 1 .459 r
F
.51846 .82308 m .50417 .82695 L .51033 .82894 L 0 1 .529 r
F
.51846 .82308 m .50434 .8244 L .50417 .82695 L F
.51846 .82308 m .51047 .82274 L .50434 .8244 L F
.51565 .8131 m .51596 .82501 L .51892 .82241 L 0 1 .451 r
F
.51565 .8131 m .51892 .82241 L .51866 .81758 L F
.51767 .81349 m .52005 .83796 L .5193 .82506 L 0 .394 .295 r
F
.51908 .83442 m .50332 .83806 L .50314 .84038 L 0 1 .537 r
F
.51908 .83442 m .51015 .83551 L .50332 .83806 L F
.51596 .82501 m .51626 .83626 L .51958 .83401 L 0 1 .459 r
F
.51767 .81349 m .51918 .84499 L .52005 .83796 L 0 .394 .295 r
F
.51951 .81672 m .5193 .82506 L .52005 .83797 L 0 .372 .291 r
F
.51923 .77977 m .51917 .8054 L .52089 .81902 L 0 .463 .29 r
F
.51954 .85746 m .52265 .78902 L .52077 .80639 L 0 .591 .263 r
F
.51954 .85746 m .52077 .80639 L .51966 .83393 L F
.51967 .83535 m .52083 .83672 L .51973 .83593 L 0 .586 .139 r
F
.52083 .83672 m .52121 .83718 L .51973 .83593 L F
.51792 .80668 m .50505 .81293 L .51061 .81538 L 0 1 .502 r
F
.51792 .80668 m .50523 .80974 L .50505 .81293 L F
.51792 .80668 m .51074 .80707 L .50523 .80974 L F
.51765 .79717 m .51074 .80707 L .51792 .80668 L 0 1 .489 r
F
.51765 .79717 m .5055 .80476 L .51074 .80707 L F
.51534 .8004 m .51565 .8131 L .51827 .8101 L 0 1 .442 r
F
.51765 .79717 m .50568 .8013 L .5055 .80476 L 0 1 .489 r
F
.51765 .79717 m .51088 .79804 L .50568 .8013 L F
.51737 .78717 m .50594 .79594 L .51088 .79804 L 0 1 .478 r
F
.51737 .78717 m .50612 .79225 L .50594 .79594 L F
.51737 .78717 m .51102 .7885 L .50612 .79225 L F
.5171 .77683 m .50639 .7866 L .51102 .7885 L 0 1 .468 r
F
.5171 .77683 m .50657 .78274 L .50639 .7866 L F
.5171 .77683 m .51116 .77855 L .50657 .78274 L F
.51681 .76576 m .51116 .77855 L .5171 .77683 L 0 1 .458 r
F
.51534 .8004 m .51827 .8101 L .518 .80496 L 0 1 .442 r
F
.51503 .78679 m .51534 .8004 L .51761 .79697 L 0 1 .433 r
F
.51503 .78679 m .51761 .79697 L .51734 .79147 L F
.51472 .77212 m .51503 .78679 L .51695 .78288 L 0 1 .423 r
F
.51472 .77212 m .51695 .78288 L .51668 .77695 L F
.51616 .77561 m .51767 .81349 L .51817 .80377 L 0 .485 .294 r
F
.51616 .77561 m .51625 .81095 L .51767 .81349 L F
.51565 .8131 m .51174 .82367 L .51596 .82501 L 0 1 .451 r
F
.51767 .81349 m .51625 .81095 L .51538 .81795 L 0 .394 .295 r
F
.51596 .82501 m .51159 .83472 L .51626 .83626 L 0 1 .459 r
F
.51596 .82501 m .50823 .83029 L .51159 .83472 L F
.51596 .82501 m .50843 .82593 L .50823 .83029 L F
.51596 .82501 m .51174 .82367 L .50843 .82593 L F
.51767 .81349 m .51538 .81795 L .51565 .82986 L 0 .394 .295 r
F
.51767 .81349 m .51728 .84145 L .51918 .84499 L F
.51767 .81349 m .51565 .82986 L .51728 .84145 L F
.51951 .81672 m .51907 .81597 L .5193 .82506 L 0 .372 .291 r
F
.51616 .77561 m .51817 .80377 L .51743 .78829 L 0 .485 .294 r
F
.51681 .76576 m .5171 .77683 L .52136 .77214 L 0 1 .458 r
F
.52058 .77301 m .51668 .77695 L .51695 .78288 L 0 1 .419 r
F
.51738 .77743 m .51917 .8054 L .51827 .78958 L 0 .474 .291 r
F
.51738 .77743 m .51951 .81672 L .51917 .8054 L F
.51738 .77743 m .51907 .81597 L .51951 .81672 L F
.51738 .77743 m .51817 .80377 L .51907 .81597 L F
.51738 .77743 m .51743 .78829 L .51817 .80377 L F
.51923 .77977 m .5183 .77861 L .51827 .78958 L 0 .463 .29 r
F
.51923 .77977 m .51827 .78958 L .51917 .8054 L F
.51657 .84694 m .51128 .85474 L .51686 .85672 L 0 1 .472 r
F
.51657 .84694 m .50724 .85044 L .51128 .85474 L F
.51657 .84694 m .50743 .84669 L .50724 .85044 L F
.51657 .84694 m .51143 .84519 L .50743 .84669 L F
.51626 .83626 m .51143 .84518 L .51657 .84694 L 0 1 .466 r
F
.51918 .84499 m .51606 .84613 L .51633 .85592 L 0 .325 .295 r
F
.51918 .84499 m .51728 .84145 L .51606 .84613 L F
.51713 .84965 m .51907 .7812 L .51752 .79958 L 0 .6 .265 r
F
.51713 .84965 m .52051 .78386 L .51907 .7812 L F
.51713 .84965 m .52077 .80639 L .52051 .78386 L F
.51713 .84965 m .51752 .79958 L .51688 .8269 L F
.51626 .83626 m .50773 .84078 L .51143 .84518 L 0 1 .466 r
F
.51626 .83626 m .50793 .83665 L .50773 .84078 L F
.51626 .83626 m .51159 .83472 L .50793 .83665 L F
.51565 .8131 m .50873 .81919 L .51174 .82367 L 0 1 .451 r
F
.51565 .8131 m .50893 .81456 L .50873 .81919 L F
.51565 .8131 m .5119 .81195 L .50893 .81456 L F
.51534 .8004 m .5119 .81195 L .51565 .8131 L 0 1 .442 r
F
.51411 .80701 m .51565 .82986 L .51538 .81795 L 0 .431 .3 r
F
.51411 .80701 m .51443 .83607 L .51565 .82986 L F
.51443 .83607 m .51633 .85592 L .51606 .84613 L 0 .377 .304 r
F
.51686 .85672 m .50677 .85948 L .51113 .86383 L 0 1 .478 r
F
.51686 .85672 m .50696 .85593 L .50677 .85948 L F
.51686 .85672 m .51128 .85474 L .50696 .85593 L F
.51443 .83607 m .51474 .85997 L .51633 .85592 L 0 .377 .304 r
F
.51469 .84381 m .51688 .8269 L .51752 .79958 L 0 .607 .267 r
F
.51713 .84965 m .51966 .83393 L .52077 .80639 L 0 .6 .265 r
F
.51918 .84499 m .51633 .85592 L .51832 .86654 L 0 .325 .295 r
F
.51713 .84965 m .5181 .85253 L .51966 .83393 L 0 .6 .265 r
F
.51699 .80941 m .5224 .83818 L .51967 .83535 L 0 .586 .139 r
F
.51534 .8004 m .50924 .80739 L .5119 .81195 L 0 1 .442 r
F
.51534 .8004 m .50944 .80245 L .50924 .80739 L F
.51534 .8004 m .51206 .79946 L .50944 .80245 L F
.51503 .78679 m .51206 .79946 L .51534 .8004 L 0 1 .433 r
F
.51616 .77561 m .51498 .79822 L .51625 .81095 L 0 .485 .294 r
F
.51469 .84381 m .51752 .79958 L .51689 .77818 L 0 .607 .267 r
F
.51469 .84381 m .51567 .84591 L .51688 .8269 L F
.51699 .80941 m .51762 .83397 L .51544 .82846 L 0 .586 .139 r
F
.5188 .90678 m .5103 .90341 L .50376 .90244 L 0 .935 .479 r
F
.51915 .90957 m .50303 .90887 L .50998 .91061 L 0 1 .503 r
F
.51915 .90957 m .50321 .90728 L .50303 .90887 L F
.51915 .90957 m .51012 .90758 L .50321 .90728 L F
.5188 .90678 m .51012 .90757 L .51915 .90957 L 0 .935 .479 r
F
.5188 .90678 m .50353 .90452 L .51012 .90757 L F
.5188 .90678 m .50376 .90244 L .50353 .90452 L F
.51799 .89889 m .51057 .91036 L .51826 .90493 L 0 1 .445 r
F
.51943 .91134 m .50275 .91131 L .50256 .91297 L 0 1 .523 r
F
.51943 .91134 m .50998 .91061 L .50275 .91131 L F
.51799 .89889 m .50492 .91248 L .51057 .91036 L 0 1 .445 r
F
.51799 .89889 m .5051 .90986 L .50492 .91248 L F
.51799 .89889 m .51071 .90403 L .5051 .90986 L F
.51772 .89358 m .51071 .90403 L .51799 .89889 L 0 1 .437 r
F
.51772 .89358 m .50537 .90613 L .51071 .90403 L F
.51772 .89358 m .50555 .90378 L .50537 .90613 L F
.51772 .89358 m .51085 .8984 L .50555 .90378 L F
.51744 .88877 m .51085 .8984 L .51772 .89358 L 0 1 .422 r
F
.51744 .88877 m .50582 .90043 L .51085 .8984 L F
.51744 .88877 m .506 .89832 L .50582 .90043 L F
.51744 .88877 m .51099 .89331 L .506 .89832 L F
.51716 .88439 m .51099 .89331 L .51744 .88877 L 0 1 .399 r
F
.51716 .88439 m .50627 .89529 L .51099 .89331 L F
.51716 .88439 m .50646 .89338 L .50627 .89529 L F
.51716 .88439 m .51113 .8887 L .50646 .89338 L F
.51688 .88025 m .51113 .8887 L .51716 .88439 L 0 1 .367 r
F
.51688 .88025 m .50673 .8906 L .51113 .8887 L F
.51688 .88025 m .50692 .88881 L .50673 .8906 L F
.51688 .88025 m .51127 .88437 L .50692 .88881 L F
.51915 .90957 m .50998 .91061 L .51943 .91134 L 0 1 .503 r
F
.51943 .91134 m .50256 .91297 L .50983 .91411 L 0 1 .523 r
F
.51826 .90493 m .51043 .91761 L .51854 .91209 L 0 1 .448 r
F
.51826 .90493 m .50447 .91956 L .51043 .91761 L F
.51826 .90493 m .50465 .91664 L .50447 .91956 L F
.51826 .90493 m .51057 .91036 L .50465 .91664 L F
.51537 .89624 m .51188 .90455 L .51569 .91022 L 0 .318 .323 r
F
.51537 .89624 m .51569 .91022 L .51835 .91022 L F
.51537 .89624 m .51835 .91022 L .51808 .90454 L F
.51506 .87973 m .51537 .89624 L .51768 .89523 L 0 .322 .315 r
F
.51506 .87973 m .51768 .89523 L .51741 .8885 L F
.51921 .87694 m .51634 .87567 L .51832 .87159 L 0 0 .015 r
F
.51506 .87973 m .5097 .88211 L .51204 .89086 L 0 .322 .315 r
F
.51506 .87973 m .51204 .89086 L .51537 .89624 L F
.51444 .88207 m .51475 .87544 L .51634 .87567 L 0 0 .016 r
F
.51444 .88207 m .51634 .87567 L .51608 .87847 L F
.51921 .87694 m .51608 .87847 L .51634 .87567 L 0 0 .015 r
F
.51921 .87694 m .51731 .87901 L .51608 .87847 L F
.5222 .89223 m .51935 .88721 L .51741 .8885 L 0 .28 .298 r
F
.51772 .88853 m .51568 .8837 L .51731 .87901 L 0 0 .054 r
F
.51772 .88853 m .51541 .88788 L .51568 .8837 L F
.51772 .88853 m .51629 .88996 L .51541 .88788 L F
.51537 .89624 m .50918 .89626 L .51188 .90455 L 0 .318 .323 r
F
.51537 .89624 m .50939 .89088 L .50918 .89626 L F
.51537 .89624 m .51204 .89086 L .50939 .89088 L F
.51622 .90424 m .51501 .89537 L .51629 .88996 L 0 .099 .082 r
F
.51622 .90424 m .51474 .90118 L .51501 .89537 L F
.51622 .90424 m .51526 .90499 L .51474 .90118 L F
.51516 .90547 m .5181 .85253 L .51713 .84965 L 0 .492 .266 r
F
.51702 .8556 m .51973 .83593 L .51761 .83438 L 0 .814 .327 r
F
.51412 .8921 m .51444 .88207 L .51568 .8837 L 0 0 .053 r
F
.51412 .8921 m .51568 .8837 L .51541 .88788 L F
.51516 .90547 m .51713 .84965 L .51592 .86443 L 0 .492 .266 r
F
.51702 .8556 m .51762 .83397 L .51544 .83535 L 0 .814 .327 r
F
.51762 .83397 m .51624 .83276 L .51544 .82846 L 0 .586 .139 r
F
.51761 .83438 m .51776 .83409 L .51762 .83397 L 0 .814 .327 r
F
.51699 .80941 m .51973 .83593 L .51762 .83397 L 0 .586 .139 r
F
.5224 .83818 m .5224 .83819 L .51967 .83535 L F
.51702 .8556 m .5224 .83819 L .51967 .83638 L 0 .814 .327 r
F
.52251 .83825 m .52248 .83823 L .52181 .82395 L 0 .631 .154 r
F
.5232 .86061 m .52251 .8383 L .52185 .84974 L 0 .791 .315 r
F
.52251 .8383 m .52251 .83829 L .52185 .84974 L F
.51699 .80941 m .52181 .82395 L .52248 .83824 L 0 .586 .139 r
F
.51772 .88853 m .51731 .87901 L .51921 .87694 L 0 0 .054 r
F
.5222 .89223 m .51741 .8885 L .51768 .89523 L 0 .28 .298 r
F
.51622 .90424 m .51629 .88996 L .51772 .88853 L 0 .099 .082 r
F
.51516 .90547 m .51799 .87076 L .5181 .85253 L 0 .492 .266 r
F
.51702 .8556 m .52185 .84974 L .52248 .83824 L 0 .814 .327 r
F
.5224 .83819 m .52248 .83824 L .5225 .83871 L 0 .586 .139 r
F
.51699 .80941 m .52248 .83824 L .5224 .83819 L F
.5224 .83819 m .52248 .83824 L .5225 .83787 L 0 .814 .327 r
F
.51702 .8556 m .52248 .83824 L .5224 .83819 L F
.5224 .83818 m .5225 .83787 L .51967 .83638 L F
.5224 .83819 m .5225 .83871 L .52121 .83718 L 0 .586 .139 r
F
.5224 .83819 m .52121 .83718 L .51967 .83535 L F
.5224 .83819 m .5224 .83818 L .52239 .83817 L 0 .814 .327 r
F
.5224 .83819 m .52239 .83817 L .51967 .83638 L F
.51973 .83593 m .52076 .82846 L .51776 .8341 L F
.51973 .83593 m .51776 .8341 L .51761 .83438 L F
.51973 .83593 m .51975 .83608 L .51762 .83397 L 0 .586 .139 r
F
.51762 .83397 m .52078 .84609 L .5178 .84109 L F
.51967 .83638 m .52127 .83722 L .51973 .83593 L 0 .814 .327 r
F
.51975 .83608 m .52078 .84609 L .51762 .83397 L 0 .586 .139 r
F
.51762 .83397 m .51779 .82776 L .51628 .83265 L 0 .814 .327 r
F
.51762 .83397 m .51628 .83265 L .51624 .83276 L F
.51762 .83397 m .51624 .83276 L .51544 .83535 L F
.51762 .83397 m .51626 .83287 L .51624 .83276 L 0 .586 .139 r
F
.51762 .83397 m .5178 .84109 L .51626 .83287 L F
.51762 .83397 m .52076 .82846 L .51779 .82776 L 0 .814 .327 r
F
.51776 .83409 m .52076 .82846 L .51762 .83397 L F
.51973 .83593 m .5225 .83787 L .52076 .82846 L F
.52127 .83722 m .5225 .83787 L .51973 .83593 L F
.51973 .83593 m .5225 .83871 L .52078 .84609 L 0 .586 .139 r
F
.52121 .83718 m .5225 .83871 L .51973 .83593 L F
.52251 .8383 m .52251 .83827 L .52251 .83829 L 0 .791 .315 r
F
.52251 .83825 m .52251 .83827 L .52248 .83823 L 0 .631 .154 r
F
.52251 .83827 m .52248 .83824 L .52248 .83823 L F
.52251 .83827 m .5225 .83787 L .52248 .83824 L 0 .791 .315 r
F
.52251 .83827 m .5225 .83871 L .52248 .83824 L 0 .631 .154 r
F
.52251 .83827 m .52518 .83003 L .5225 .83787 L 0 .791 .315 r
F
.5232 .86061 m .52451 .84033 L .52251 .83827 L F
.52451 .84033 m .52518 .83003 L .52251 .83827 L F
.52251 .83827 m .52451 .84033 L .52251 .83844 L 0 .631 .154 r
F
.52251 .83844 m .52523 .85384 L .5225 .83871 L F
.52451 .84033 m .52523 .85384 L .52251 .83844 L F
.52451 .84033 m .52811 .83143 L .52518 .83003 L 0 .791 .315 r
F
.52462 .84044 m .52811 .83143 L .52451 .84033 L F
.52628 .84228 m .52946 .84228 L .52811 .83143 L F
.52866 .84461 m .52946 .84228 L .52628 .84228 L F
.52628 .84228 m .5287 .84481 L .52631 .84249 L 0 .631 .154 r
F
.52866 .84461 m .5287 .84481 L .52628 .84228 L F
.52631 .84249 m .52948 .84911 L .52818 .85917 L F
.5287 .84481 m .52948 .84911 L .52631 .84249 L F
.52927 .86802 m .53166 .8718 L .53466 .86376 L 0 .765 .303 r
F
.53112 .84614 m .53255 .86721 L .52942 .84359 L 0 .666 .167 r
F
.52944 .8453 m .53121 .84744 L .52944 .84494 L 0 .765 .303 r
F
.52944 .8453 m .53255 .86721 L .52948 .84911 L 0 .666 .167 r
F
.52942 .84359 m .52969 .8456 L .52944 .8453 L F
.52969 .8456 m .53255 .86721 L .52944 .8453 L F
.53576 .8531 m .53582 .85319 L .53586 .85288 L 0 .765 .303 r
F
.53517 .85221 m .53548 .85245 L .53549 .85252 L 0 .666 .167 r
F
.53548 .85245 m .53585 .85273 L .53586 .85288 L F
.53517 .85221 m .53586 .85288 L .53625 .84929 L 0 .765 .303 r
F
.53517 .85221 m .53549 .85252 L .53629 .85877 L 0 .666 .167 r
F
.53548 .85245 m .53586 .85288 L .53629 .85877 L F
.53283 .84954 m .53629 .85877 L .53543 .8726 L F
.53517 .85221 m .53629 .85877 L .53283 .84954 L F
.53283 .84954 m .53625 .84929 L .53531 .83667 L 0 .765 .303 r
F
.53347 .85027 m .53625 .84929 L .53283 .84954 L F
.53283 .84954 m .53284 .84968 L .53237 .84895 L 0 .666 .167 r
F
.53283 .84954 m .53237 .84895 L .53119 .84711 L F
.53284 .84968 m .53543 .8726 L .53119 .84711 L F
.53121 .84744 m .53531 .83667 L .53245 .83427 L 0 .765 .303 r
F
.53283 .84954 m .53531 .83667 L .53121 .84744 L F
.52944 .84494 m .53245 .83427 L .52946 .84228 L F
.53119 .84711 m .53125 .84749 L .53121 .84744 L 0 .666 .167 r
F
.53121 .84744 m .53245 .83427 L .52944 .84494 L 0 .765 .303 r
F
.53121 .84744 m .53543 .8726 L .53255 .86721 L 0 .666 .167 r
F
.53125 .84749 m .53543 .8726 L .53121 .84744 L F
.53611 .85315 m .53786 .85562 L .53613 .85271 L 0 .735 .292 r
F
.53611 .85315 m .53968 .88021 L .53629 .85877 L 0 .691 .18 r
F
.53635 .85349 m .53968 .88021 L .53611 .85315 L F
.54215 .86175 m .54256 .86212 L .54282 .86012 L 0 .735 .292 r
F
.5427 .86228 m .54285 .86591 L .54257 .86218 L 0 .702 .19 r
F
.5427 .86228 m .54633 .85298 L .54282 .86012 L 0 .698 .282 r
F
.54485 .86397 m .54633 .85298 L .5427 .86228 L F
.53789 .85544 m .54228 .8453 L .53952 .84139 L 0 .735 .292 r
F
.53786 .85562 m .53792 .85548 L .53789 .85544 L F
.53792 .85548 m .54228 .8453 L .53789 .85544 L F
.53965 .85763 m .54282 .86012 L .54228 .8453 L F
.54226 .86148 m .54282 .86012 L .53965 .85763 L F
.53953 .8582 m .53958 .85859 L .53836 .85639 L 0 .691 .18 r
F
.53953 .8582 m .53836 .85639 L .53785 .85546 L F
.53958 .85859 m .54246 .88497 L .53785 .85546 L F
.53953 .8582 m .54228 .8453 L .53786 .85562 L 0 .735 .292 r
F
.53613 .85271 m .53952 .84139 L .53625 .84929 L F
.53785 .85546 m .53788 .85565 L .53786 .85562 L 0 .691 .18 r
F
.53786 .85562 m .53952 .84139 L .53613 .85271 L 0 .735 .292 r
F
.53786 .85562 m .54246 .88497 L .53968 .88021 L 0 .691 .18 r
F
.53788 .85565 m .54246 .88497 L .53786 .85562 L F
.54271 .86256 m .54652 .89055 L .54285 .86591 L 0 .702 .19 r
F
.54465 .86549 m .54652 .89055 L .54271 .86256 L F
.54465 .86549 m .54897 .85932 L .54633 .85298 L 0 .698 .282 r
F
.54496 .86596 m .54897 .85932 L .54465 .86549 L F
.5515 .94192 m .55507 .90264 L .55219 .91935 L 0 .546 .266 r
F
.5515 .94192 m .559 .90301 L .55507 .90264 L F
.54635 .91413 m .55219 .91935 L .55507 .90264 L 0 .645 .274 r
F
.5515 .94192 m .56139 .92023 L .559 .90301 L 0 .546 .266 r
F
.5515 .94192 m .56072 .94283 L .56139 .92023 L F
.5515 .94192 m .55743 .9557 L .56072 .94283 L F
.5515 .94192 m .55348 .95531 L .55743 .9557 L F
.55632 .97767 m .56072 .94283 L .55743 .9557 L 0 .331 .25 r
F
.56406 .98089 m .56915 .86761 L .5655 .90581 L 0 .224 .198 r
F
.55632 .97767 m .56488 .95363 L .56072 .94283 L 0 .331 .25 r
F
.56406 .98089 m .57397 .94109 L .56915 .86761 L 0 .224 .198 r
F
.55632 .97767 m .56715 .98105 L .56488 .95363 L 0 .331 .25 r
F
.55632 .97767 m .56606 1.00318 L .56715 .98105 L F
.55632 .97767 m .56233 1.00508 L .56606 1.00318 L F
.55632 .97767 m .55815 .99412 L .56233 1.00508 L F
.55296 .89334 m .56369 1.03436 L .56063 1.01705 L 0 .881 .187 r
F
.55296 .89334 m .5633 .99894 L .56369 1.03436 L F
.55273 .97639 m .55594 .99221 L .56053 1.03095 L 0 .978 .107 r
F
.56063 1.01705 m .56369 1.03436 L .56868 1.09274 L 0 1 .121 r
F
.55592 1.00794 m .56374 1.03233 L .55881 1.00874 L 0 .084 .173 r
F
.55412 1.00744 m .55663 1.01395 L .55592 1.00794 L F
.55663 1.01395 m .56374 1.03233 L .55592 1.00794 L F
.56849 1.12631 m .57227 1.169 L .57433 1.18913 L 0 0 .084 r
F
.57174 1.12925 m .57796 1.24751 L .57771 1.24362 L 0 1 .154 r
F
.57174 1.12925 m .57796 1.24841 L .57708 1.23413 L F
.56809 1.0574 m .57729 1.23842 L .57233 1.15431 L F
.57729 1.23842 m .57799 1.25204 L .57685 1.23243 L F
.57729 1.23842 m .57685 1.23243 L .57233 1.15431 L F
.58112 1.29054 m .58877 1.35749 L .58321 1.26179 L 0 0 .08 r
F
.58385 1.36951 m .59358 1.41191 L .58864 1.39652 L 0 .908 .151 r
F
.58385 1.36951 m .59596 1.40409 L .59358 1.41191 L F
.58937 1.38164 m .58112 1.29054 L .58479 1.38412 L 0 0 .08 r
F
.58937 1.38164 m .58877 1.35749 L .58112 1.29054 L F
.58481 1.34416 m .58321 1.26177 L .58877 1.35745 L 0 .718 .217 r
F
.58479 1.38412 m .58112 1.29054 L .58374 1.38463 L 0 0 .08 r
F
.58374 1.38463 m .58112 1.29054 L .58338 1.38488 L F
.58338 1.38488 m .58112 1.29054 L .58328 1.38514 L F
.58328 1.38514 m .58112 1.29054 L .58302 1.38578 L F
.5776 1.31996 m .58234 1.27079 L .58481 1.34416 L 0 .718 .217 r
F
.58234 1.27079 m .58321 1.26177 L .58481 1.34416 L F
.5834 1.32549 m .5827 1.30509 L .58333 1.32285 L 0 1 .183 r
F
.57573 1.12503 m .57767 1.16304 L .57928 1.19166 L 0 0 .041 r
F
.57573 1.12503 m .57928 1.19166 L .57928 1.19073 L F
.58024 1.20622 m .58023 1.20618 L .5793 1.19724 L 0 .548 0 r
F
.58024 1.20622 m .5793 1.19724 L .5793 1.19726 L F
.57927 1.18977 m .58052 1.21371 L .58075 1.21682 L 0 0 .041 r
F
.57573 1.12503 m .57928 1.19073 L .57927 1.18977 L F
.57928 1.19073 m .58052 1.21371 L .57927 1.18977 L F
.5793 1.19726 m .5793 1.19724 L .57553 1.16125 L 0 .548 0 r
F
.57573 1.12503 m .57891 1.18279 L .57887 1.18093 L 0 0 .041 r
F
.57663 1.17434 m .57941 1.20239 L .5793 1.19794 L 0 .548 0 r
F
.57573 1.12503 m .57894 1.18362 L .57891 1.18279 L 0 0 .041 r
F
.57904 1.11707 m .57791 1.1114 L .58155 1.21448 L 0 .191 .184 r
F
.58166 1.21576 m .58155 1.21448 L .58187 1.22362 L F
.57904 1.11707 m .58155 1.21448 L .58166 1.21576 L F
.58224 1.22792 m .58187 1.22362 L .58321 1.26167 L F
.57904 1.11707 m .58187 1.22362 L .58224 1.22792 L F
.57943 1.12447 m .5798 1.03691 L .58281 .91469 L 0 .145 .158 r
F
.57397 .94109 m .58877 1.3573 L .58792 1.1087 L 0 .191 .184 r
F
.57573 1.12503 m .58877 1.35737 L .59003 1.34131 L 0 0 .041 r
F
.58936 1.31856 m .59003 1.34131 L .59052 1.33502 L F
.57573 1.12503 m .59003 1.34131 L .58936 1.31856 L F
.5853 1.29548 m .58478 1.28771 L .58877 1.35737 L F
.58478 1.28771 m .58433 1.28103 L .58872 1.3565 L F
.58478 1.28771 m .58872 1.3565 L .58877 1.35737 L F
.58879 1.35779 m .58877 1.35741 L .58876 1.35713 L 0 .66 .042 r
F
.57397 .94109 m .57688 1.08203 L .57791 1.1114 L 0 .191 .184 r
F
.57397 .94109 m .57791 1.1114 L .57904 1.11707 L F
.57397 .94109 m .58126 1.19393 L .5839 1.22025 L F
.57397 .94109 m .58792 1.1087 L .58178 .72301 L F
.57048 1.03 m .58209 1.0595 L .58084 1.01964 L 0 .259 .218 r
F
.5795 1.00594 m .58084 1.01964 L .58034 1.00371 L F
.57048 1.03 m .58084 1.01964 L .5795 1.00594 L F
.57048 1.03 m .58034 1.00371 L .57866 .98773 L F
.55944 .84168 m .5655 .90581 L .56915 .86761 L 0 .533 .236 r
F
.56522 .85924 m .56814 .90846 L .56734 .9064 L 0 .821 .209 r
F
.56386 .82919 m .56614 .86868 L .56522 .85924 L F
.56614 .86868 m .56887 .91619 L .56522 .85924 L F
.56887 .91619 m .56853 .91509 L .56522 .85924 L F
.56724 .92902 m .56967 .93016 L .568 .92113 L 0 .65 .25 r
F
.56488 .95363 m .56852 .93577 L .56724 .92902 L F
.56852 .93577 m .56967 .93016 L .56724 .92902 L F
.56659 .91281 m .56773 .91987 L .56666 .91491 L 0 .821 .209 r
F
.56468 .85407 m .56754 .91591 L .56659 .91281 L F
.56754 .91591 m .56773 .91987 L .56659 .91281 L F
.56657 .91685 m .568 .92113 L .56666 .91491 L 0 .65 .25 r
F
.56488 .95363 m .5679 .92221 L .56657 .91685 L F
.5679 .92221 m .568 .92113 L .56657 .91685 L F
.55969 .88912 m .56169 .89982 L .56043 .89802 L 0 .867 .199 r
F
.55944 .84168 m .56131 .89453 L .5655 .90581 L 0 .533 .236 r
F
.55883 .87867 m .56202 .89851 L .55969 .88912 L 0 .867 .199 r
F
.56035 .8988 m .56184 .90491 L .56046 .89846 L 0 .763 .255 r
F
.559 .90301 m .56133 .90457 L .56035 .8988 L F
.56133 .90457 m .56184 .90491 L .56035 .8988 L F
.55883 .87867 m .55994 .89633 L .55966 .89467 L 0 .867 .199 r
F
.55959 .89682 m .55978 .89591 L .5597 .89557 L 0 .763 .255 r
F
.559 .90301 m .55989 .89725 L .55959 .89682 L F
.55994 .89633 m .55996 .89675 L .55966 .89467 L 0 .867 .199 r
F
.55989 .89725 m .55996 .89675 L .55959 .89682 L 0 .763 .255 r
F
.55996 .89675 m .55978 .89591 L .55959 .89682 L F
.55939 .88766 m .56022 .89746 L .55994 .89633 L 0 .867 .199 r
F
.559 .90301 m .56046 .89846 L .55989 .89725 L 0 .763 .255 r
F
.56022 .89746 m .56024 .89768 L .55994 .89633 L 0 .867 .199 r
F
.56046 .89846 m .56003 .897 L .55989 .89725 L 0 .763 .255 r
F
.56522 .85924 m .568 .92123 L .56468 .85407 L 0 .821 .209 r
F
.56776 .72428 m .57473 .95127 L .57032 .85116 L 0 .627 .217 r
F
.56814 .90846 m .56874 .91855 L .56734 .9064 L 0 .821 .209 r
F
.57048 1.03 m .57446 .95654 L .57148 .97855 L 0 .259 .218 r
F
.57446 .95654 m .57428 .95531 L .57148 .97855 L F
.56386 .82919 m .57032 .85116 L .57334 .92189 L 0 .821 .209 r
F
.57185 .91991 m .57334 .92189 L .57458 .95096 L F
.56386 .82919 m .57334 .92189 L .57185 .91991 L F
.56386 .82919 m .57458 .95096 L .57458 .95096 L F
.56386 .82919 m .57458 .95096 L .57376 .94694 L F
.57458 .95096 m .57458 .95098 L .57457 .95092 L F
.57458 .95096 m .57457 .95092 L .57376 .94694 L F
.57348 .94867 m .57389 .94843 L .57284 .94735 L 0 .65 .25 r
F
.57467 .95202 m .57454 .9513 L .57148 .97855 L 0 .259 .218 r
F
.57446 .95654 m .57474 .95149 L .57428 .95531 L F
.57048 1.03 m .57967 .98252 L .57752 .96678 L F
.57473 .95129 m .57752 .96678 L .57474 .95149 L 0 .627 .217 r
F
.56776 .72428 m .57698 .95326 L .57473 .95129 L F
.57698 .95326 m .57752 .96678 L .57473 .95129 L F
.56488 .95363 m .57148 .97855 L .57417 .95461 L 0 .65 .25 r
F
.57361 .95153 m .57417 .95461 L .57454 .9513 L F
.56488 .95363 m .57417 .95461 L .57361 .95153 L F
.56874 .91855 m .56931 .92808 L .56765 .91134 L 0 .821 .209 r
F
.56488 .95363 m .57454 .9513 L .57451 .95116 L 0 .65 .25 r
F
.56488 .95363 m .57451 .95116 L .57243 .94927 L F
.57451 .95116 m .57456 .95114 L .57449 .95108 L F
.57451 .95116 m .57449 .95108 L .57243 .94927 L F
.57376 .94694 m .57389 .94843 L .56917 .92139 L 0 .821 .209 r
F
.57243 .94927 m .57456 .95114 L .57458 .95098 L 0 .65 .25 r
F
.57243 .94927 m .57458 .95098 L .57389 .94843 L F
.57451 .95116 m .57454 .9513 L .57456 .95114 L F
.57048 1.03 m .57752 .96678 L .57474 .95149 L 0 .259 .218 r
F
.57389 .94843 m .57458 .95098 L .57508 .96264 L 0 .821 .209 r
F
.57376 .94694 m .57458 .95098 L .57389 .94843 L F
.57458 .95096 m .57458 .95096 L .57458 .95098 L F
.57473 .95127 m .57458 .95096 L .57032 .85116 L 0 .627 .217 r
F
.57389 .94843 m .57458 .95098 L .57494 .94783 L 0 .65 .25 r
F
.57389 .94843 m .57364 .94753 L .57284 .94735 L F
.57132 .93909 m .57225 .94134 L .56967 .93016 L F
.57389 .94843 m .57164 .93865 L .56917 .92139 L 0 .821 .209 r
F
.56488 .95363 m .57312 .94887 L .56967 .93016 L 0 .65 .25 r
F
.57048 1.03 m .58168 1.11354 L .58261 1.06084 L 0 .259 .218 r
F
.56966 .93004 m .57508 .96264 L .57705 1.05852 L 0 .821 .209 r
F
.56917 .92139 m .57164 .93865 L .56966 .93004 L F
.57284 .94735 m .57364 .94753 L .57132 .93909 L 0 .65 .25 r
F
.57164 .93865 m .57166 .93878 L .56966 .93004 L 0 .821 .209 r
F
.57364 .94753 m .57368 .94754 L .57132 .93909 L 0 .65 .25 r
F
.57368 .94754 m .57225 .94134 L .57132 .93909 L F
.57312 .94887 m .57348 .94867 L .57284 .94735 L F
.57166 .93878 m .57508 .96264 L .56972 .93036 L 0 .821 .209 r
F
.57166 .93878 m .56972 .93036 L .56966 .93004 L F
.57389 .94843 m .57166 .93878 L .57164 .93865 L F
.56874 .91391 m .57376 .94694 L .56917 .92139 L F
.56386 .82919 m .57144 .91937 L .56874 .91391 L F
.57144 .91937 m .57376 .94694 L .56874 .91391 L F
.55901 .90286 m .55969 .89566 L .55939 .89505 L 0 .763 .255 r
F
.55996 .89675 m .55972 .89564 L .55966 .89467 L 0 .867 .199 r
F
.55966 .89467 m .55972 .89564 L .5597 .89557 L F
.55883 .87867 m .55966 .89467 L .55937 .89334 L F
.55969 .89566 m .5597 .89556 L .55939 .89505 L 0 .763 .255 r
F
.55966 .89467 m .5597 .89557 L .55937 .89334 L 0 .867 .199 r
F
.5597 .89557 m .55944 .89457 L .55937 .89334 L F
.56202 .89851 m .56268 .90259 L .55969 .88912 L F
.56544 .91144 m .56666 .91491 L .56544 .91183 L 0 .821 .209 r
F
.56386 .82919 m .56659 .91281 L .56544 .91144 L F
.56659 .91281 m .56666 .91491 L .56544 .91144 L F
.56268 .90259 m .56319 .90581 L .56195 .90124 L 0 .867 .199 r
F
.559 .90301 m .55913 .90396 L .56223 .90561 L 0 .763 .255 r
F
.56217 .90534 m .56223 .90561 L .56334 .9062 L F
.559 .90301 m .56223 .90561 L .56217 .90534 L F
.55971 .88933 m .56046 .89846 L .55939 .88766 L 0 .867 .199 r
F
.559 .90301 m .56334 .9062 L .56319 .90581 L 0 .763 .255 r
F
.55913 .90396 m .56139 .92023 L .56454 .91038 L F
.55913 .90396 m .56454 .91038 L .5647 .90987 L F
.55883 .87867 m .56097 .86504 L .56436 .90573 L 0 .867 .199 r
F
.56369 .90448 m .56436 .90573 L .5647 .90987 L F
.55883 .87867 m .56436 .90573 L .56369 .90448 L F
.55902 .90287 m .55959 .89682 L .55901 .90286 L 0 .763 .255 r
F
.55883 .87867 m .5647 .90987 L .56319 .90581 L 0 .867 .199 r
F
.56046 .89846 m .56022 .89746 L .55939 .88766 L F
.56268 .90259 m .56195 .90124 L .55969 .88912 L F
.56386 .82919 m .56522 .85924 L .56468 .85407 L 0 .821 .209 r
F
.56386 .82919 m .56558 .79532 L .57032 .85116 L F
.55959 .89682 m .56613 .82717 L .55958 .89681 L 0 .763 .255 r
F
.55959 .89682 m .55958 .89681 L .55901 .90286 L F
.56334 .9062 m .5647 .90987 L .5655 .90736 L F
.55913 .90396 m .5647 .90987 L .56334 .9062 L F
.56488 .95363 m .56666 .91491 L .56544 .91183 L 0 .65 .25 r
F
.56319 .90581 m .5647 .90987 L .56562 .92086 L 0 .867 .199 r
F
.56488 .95363 m .56715 .98105 L .57148 .97855 L 0 .65 .25 r
F
.56046 .89846 m .5698 1.01122 L .56022 .89746 L 0 .867 .199 r
F
.5621 .90508 m .56319 .90581 L .56046 .89846 L 0 .763 .255 r
F
.56319 .90581 m .56562 .92086 L .56241 .90371 L 0 .867 .199 r
F
.56319 .90581 m .56241 .90371 L .56195 .90124 L F
.56319 .90581 m .56334 .9062 L .5655 .90736 L 0 .763 .255 r
F
.56544 .91183 m .56666 .91491 L .56548 .90937 L 0 .65 .25 r
F
.56544 .91183 m .5698 1.01122 L .56562 .92086 L 0 .821 .209 r
F
.56666 .91491 m .5698 1.01122 L .56544 .91183 L F
.5597 .89556 m .56613 .82717 L .55944 .89456 L 0 .763 .255 r
F
.5597 .89556 m .55944 .89456 L .55939 .89505 L F
.5597 .89557 m .56809 1.0574 L .55944 .89457 L 0 .867 .199 r
F
.55941 .89449 m .56809 1.0574 L .5633 .99894 L F
.55937 .89334 m .55944 .89457 L .55941 .89449 L F
.55944 .89457 m .56809 1.0574 L .55941 .89449 L F
.55883 .87867 m .55971 .88933 L .55939 .88766 L F
.55045 .76675 m .56097 .86504 L .55883 .87867 L 0 .664 .204 r
F
.55045 .76675 m .5598 .81948 L .56097 .86504 L F
.55941 .89449 m .56613 .82717 L .56206 .83978 L 0 .763 .255 r
F
.55939 .89505 m .55944 .89456 L .55941 .89449 L F
.55944 .89456 m .56613 .82717 L .55941 .89449 L F
.57368 .94754 m .57494 .94783 L .57225 .94134 L 0 .65 .25 r
F
.57225 .94134 m .57494 .94783 L .56967 .93016 L F
.57389 .94843 m .57508 .96264 L .57166 .93878 L 0 .821 .209 r
F
.56931 .92808 m .57705 1.05852 L .56841 .92321 L F
.56931 .92808 m .56841 .92321 L .56765 .91134 L F
.57474 .95149 m .57752 .96678 L .57494 .94783 L 0 .259 .218 r
F
.56776 .72428 m .57954 .97021 L .57752 .96678 L 0 .627 .217 r
F
.57474 .95149 m .57752 .96678 L .57508 .96264 L F
.57389 .94843 m .57494 .94783 L .57364 .94753 L 0 .65 .25 r
F
.559 .90301 m .55902 .90287 L .55901 .90286 L 0 .763 .255 r
F
.57467 .95143 m .57458 .95098 L .57454 .9513 L 0 .259 .218 r
F
.57474 .95149 m .57458 .95098 L .57467 .95143 L F
.57474 .95149 m .57454 .9513 L .57467 .95202 L F
.56874 .91855 m .56765 .91134 L .56734 .9064 L 0 .821 .209 r
F
.57473 .95127 m .57474 .95149 L .57458 .95096 L 0 .627 .217 r
F
.57474 .95149 m .57458 .95098 L .57458 .95096 L F
.57474 .95149 m .57494 .94783 L .57458 .95098 L 0 .259 .218 r
F
.57474 .95149 m .57508 .96264 L .57458 .95098 L 0 .627 .217 r
F
.56967 .93016 m .57494 .94783 L .5755 .90161 L 0 .65 .25 r
F
.56887 .91619 m .56967 .93016 L .56853 .91509 L 0 .821 .209 r
F
.56967 .93016 m .56967 .9302 L .56967 .93015 L F
.56967 .93016 m .56967 .93015 L .56853 .91509 L F
.57048 1.03 m .57745 1.10395 L .58168 1.11354 L 0 .259 .218 r
F
.568 .92123 m .57475 1.07123 L .56773 .91995 L 0 .821 .209 r
F
.568 .92123 m .56773 .91995 L .56468 .85407 L F
.56548 .90937 m .56858 .87318 L .5655 .90736 L 0 .65 .25 r
F
.56666 .91491 m .56858 .87318 L .56548 .90937 L F
.56024 .89768 m .5698 1.01122 L .55998 .8968 L 0 .867 .199 r
F
.56024 .89768 m .55998 .8968 L .55994 .89633 L F
.56043 .89802 m .56206 .90181 L .56046 .89846 L F
.56169 .89982 m .56206 .90181 L .56043 .89802 L F
.56046 .89846 m .56203 .89359 L .56003 .897 L 0 .763 .255 r
F
.55996 .89675 m .56203 .89359 L .56098 .89013 L F
.55989 .89725 m .56003 .897 L .55996 .89675 L F
.56003 .897 m .56203 .89359 L .55996 .89675 L F
.55996 .89675 m .5698 1.01122 L .5709 1.07076 L 0 .867 .199 r
F
.55994 .89633 m .55998 .8968 L .55996 .89675 L F
.55998 .8968 m .5698 1.01122 L .55996 .89675 L F
.55996 .89675 m .5709 1.07076 L .55972 .89564 L F
.55996 .89675 m .56098 .89013 L .55978 .89591 L 0 .763 .255 r
F
.5597 .89557 m .56098 .89013 L .56036 .88856 L F
.55978 .89591 m .56098 .89013 L .5597 .89557 L F
.5597 .89557 m .5709 1.07076 L .56809 1.0574 L 0 .867 .199 r
F
.55972 .89564 m .5709 1.07076 L .5597 .89557 L F
.56184 .90491 m .5621 .90508 L .56046 .89846 L 0 .763 .255 r
F
.56206 .90181 m .56241 .90371 L .56046 .89846 L 0 .867 .199 r
F
.56046 .89846 m .56475 .90685 L .56133 .89577 L 0 .763 .255 r
F
.56319 .90581 m .56475 .90685 L .56046 .89846 L F
.56046 .89846 m .56562 .92086 L .5698 1.01122 L 0 .867 .199 r
F
.56241 .90371 m .56562 .92086 L .56046 .89846 L F
.56133 .89577 m .5655 .90736 L .56858 .87318 L 0 .763 .255 r
F
.56475 .90685 m .5655 .90736 L .56133 .89577 L F
.56666 .91491 m .568 .92113 L .5667 .91407 L 0 .65 .25 r
F
.56666 .91491 m .57475 1.07123 L .5698 1.01122 L 0 .821 .209 r
F
.56773 .91987 m .57475 1.07123 L .56666 .91491 L F
.568 .92113 m .57705 1.05852 L .57475 1.07123 L F
.56734 .9064 m .56842 .92343 L .568 .92113 L F
.56842 .92343 m .57705 1.05852 L .568 .92113 L F
.56967 .9302 m .56932 .92826 L .56853 .91509 L F
.568 .92113 m .5755 .90161 L .57284 .87073 L 0 .65 .25 r
F
.56967 .93016 m .5755 .90161 L .568 .92113 L F
.5667 .91407 m .57284 .87073 L .56858 .87318 L F
.568 .92113 m .57284 .87073 L .5667 .91407 L F
.56967 .9302 m .57705 1.05852 L .56932 .92826 L 0 .821 .209 r
F
.56098 .89013 m .56858 .87318 L .56883 .83892 L 0 .763 .255 r
F
.56203 .89359 m .56858 .87318 L .56098 .89013 L F
.56036 .88856 m .56883 .83892 L .56613 .82717 L F
.56098 .89013 m .56883 .83892 L .56036 .88856 L F
.57866 .98773 m .58034 1.00371 L .57967 .98252 L 0 .259 .218 r
F
.58209 1.0595 m .58261 1.06084 L .58041 1.00215 L F
.58209 1.0595 m .58041 1.00215 L .57967 .98252 L F
.59431 1.38132 m .59175 1.22243 L .59476 1.38141 L 0 0 .08 r
F
.59476 1.38141 m .59175 1.22243 L .59856 1.38076 L F
.6017 1.3768 m .58178 .72301 L .59439 1.37827 L 0 .004 .122 r
F
.59864 1.26951 m .58178 .72301 L .6017 1.3768 L F
.59439 1.37827 m .59025 1.16333 L .59354 1.37917 L F
.5877 1.03039 m .58178 .72301 L .5877 1.05339 L F
.58637 .97781 m .5812 .65949 L .58122 .6604 L 0 0 .075 r
F
.58921 1.17086 m .58178 .72301 L .58792 1.1087 L 0 .004 .122 r
F
.59354 1.37917 m .58905 1.1287 L .58921 1.17086 L F
.58905 1.1287 m .58178 .72301 L .58921 1.17086 L F
.60194 1.37676 m .6 1.20464 L .58682 .85618 L F
.58718 .57576 m .6 1.20464 L .59032 .53109 L F
.59032 .53109 m .59417 .87949 L .58168 .65401 L 0 0 .075 r
F
.59417 .87949 m .59695 1.1311 L .59151 .96096 L F
.59417 .87949 m .59151 .96096 L .58168 .65401 L F
.58752 1.04869 m .58636 .97784 L .58637 .97781 L F
.58725 1.21097 m .58797 1.06887 L .58694 1.10037 L 0 .689 .054 r
F
.58751 1.04865 m .58636 .97784 L .58752 1.04869 L 0 0 .075 r
F
.59025 1.16333 m .5877 1.03039 L .59068 1.21988 L 0 .004 .122 r
F
.5877 1.03039 m .5877 1.05339 L .59068 1.21988 L F
.57954 .97021 m .5797 .95412 L .5809 .98115 L 0 .992 .198 r
F
.58052 .98082 m .5809 .98115 L .58125 .9888 L F
.57954 .97021 m .5809 .98115 L .58052 .98082 L F
.58012 .98181 m .58125 .9888 L .58015 .98245 L F
.57954 .97021 m .58091 .98516 L .58012 .98181 L F
.58091 .98516 m .58125 .9888 L .58012 .98181 L F
.5797 .95412 m .58055 .86819 L .58483 1.0225 L F
.58797 1.06887 m .58799 1.06474 L .58694 1.10037 L 0 .689 .054 r
F
.58799 1.06474 m .58782 1.06241 L .58694 1.10037 L F
.58806 1.05203 m .5874 1.04798 L .58694 1.10037 L F
.58694 1.10037 m .5874 1.04798 L .58679 1.04418 L F
.5797 .95412 m .58483 1.0225 L .58502 1.02959 L 0 .992 .198 r
F
.59025 1.16333 m .59068 1.21988 L .59354 1.37917 L 0 .004 .122 r
F
.60194 1.37676 m .58682 .85618 L .59864 1.26951 L F
.58133 .65877 m .58168 .65401 L .59695 1.1311 L 0 0 .075 r
F
.59354 1.37917 m .58792 1.1087 L .59308 1.37966 L 0 .004 .122 r
F
.58725 1.21097 m .59335 1.23529 L .59249 1.20546 L 0 .689 .054 r
F
.58725 1.21097 m .59249 1.20546 L .58806 1.05203 L F
.59249 1.20546 m .59721 1.20049 L .58806 1.05203 L F
.58799 1.06474 m .58806 1.05203 L .58782 1.06241 L F
.59716 1.37593 m .58725 1.21097 L .59196 1.37762 L F
.60043 1.37486 m .59545 1.313 L .59716 1.37593 L F
.59545 1.313 m .58725 1.21097 L .59716 1.37593 L F
.58129 .6592 m .58132 .6628 L .58132 .66007 L 0 .004 .122 r
F
.58121 .65631 m .58129 .6592 L .5875 1.01942 L 0 0 .075 r
F
.60194 1.37676 m .59864 1.26951 L .6017 1.3768 L 0 .004 .122 r
F
.60043 1.37486 m .59855 1.25604 L .58725 1.21097 L 0 .689 .054 r
F
.58745 1.01754 m .5875 1.01942 L .59362 1.37524 L 0 0 .075 r
F
.58121 .65631 m .5875 1.01942 L .58745 1.01754 L F
.59281 1.37509 m .587 1.01545 L .59362 1.37524 L F
.587 1.01545 m .58121 .65631 L .58802 1.05059 L F
.587 1.01545 m .58802 1.05059 L .59362 1.37524 L F
.58697 1.04194 m .58675 1.0415 L .58573 .97124 L F
.59281 1.37509 m .58573 .97124 L .58693 1.01305 L F
.5797 .95412 m .58502 1.02959 L .58164 .99768 L 0 .992 .198 r
F
.58015 .98245 m .58125 .9888 L .58164 .99768 L F
.57967 .98252 m .5815 1.03104 L .58183 1.02953 L 0 .848 .228 r
F
.58003 .98564 m .58183 1.02953 L .584 1.01993 L F
.57967 .98252 m .58183 1.02953 L .58003 .98564 L F
.57999 .98368 m .584 1.01993 L .58026 .98465 L F
.57967 .98252 m .58015 .98666 L .57999 .98368 L F
.58015 .98666 m .584 1.01993 L .57999 .98368 L F
.57976 .98018 m .57977 .97978 L .57973 .98015 L F
.57977 .97978 m .57977 .97944 L .57977 .9798 L 0 .992 .198 r
F
.57977 .97944 m .57954 .97021 L .57982 .98023 L F
.5798 .98002 m .57982 .98023 L .57983 .98057 L F
.57977 .97944 m .57982 .98023 L .5798 .98002 L F
.5797 .97741 m .57954 .97021 L .57973 .97832 L F
.58693 1.01305 m .58573 .97124 L .5812 .65949 L 0 0 .075 r
F
.59622 1.18456 m .58129 .6592 L .59695 1.1311 L F
.58806 1.05203 m .58129 .6592 L .59622 1.18456 L F
.58754 1.04884 m .58122 .6604 L .58134 .66436 L F
.58752 1.04869 m .58122 .6604 L .58754 1.04884 L F
.58636 .97784 m .5812 .65949 L .58637 .97781 L F
.57973 .97832 m .57954 .97021 L .57977 .97944 L 0 .992 .198 r
F
.58129 .6592 m .58133 .65877 L .59695 1.1311 L 0 0 .075 r
F
.5815 1.03104 m .58261 1.06084 L .58446 1.03694 L 0 .848 .228 r
F
.5815 1.03104 m .58446 1.03694 L .58502 1.02959 L F
.5815 1.03104 m .58502 1.02959 L .584 1.01993 L F
.57983 .98057 m .57954 .97021 L .58026 .98465 L 0 .992 .198 r
F
.5798 .98084 m .58831 .9074 L .58807 .87556 L 0 .848 .228 r
F
.58015 .98245 m .58164 .99768 L .58026 .98465 L 0 .992 .198 r
F
.57987 .98325 m .58669 1.00802 L .5798 .98084 L 0 .848 .228 r
F
.57573 1.12503 m .58725 1.21097 L .58168 1.11354 L 0 0 .041 r
F
.57573 1.12503 m .59052 1.33502 L .58725 1.21097 L F
.59105 1.37808 m .58725 1.21097 L .5912 1.37854 L 0 .689 .054 r
F
.5912 1.37854 m .58725 1.21097 L .59052 1.33502 L F
.5912 1.37854 m .59052 1.33502 L .59154 1.37957 L F
.59196 1.37762 m .58725 1.21097 L .59105 1.37808 L F
.59051 1.37427 m .57983 .98057 L .58828 1.14686 L 0 .992 .198 r
F
.5798 .98084 m .57989 .98117 L .57983 .98062 L 0 .848 .228 r
F
.57983 .98057 m .58026 .98465 L .58828 1.14686 L 0 .992 .198 r
F
.584 1.01993 m .58502 1.02959 L .58669 1.00802 L 0 .848 .228 r
F
.57972 .97842 m .58604 .70724 L .58215 .75533 L F
.5797 .98004 m .57973 .97869 L .57972 .97842 L F
.5797 .97741 m .57973 .97832 L .57975 .9791 L 0 .992 .198 r
F
.5797 .97741 m .57975 .9791 L .57972 .97851 L F
.57973 .97869 m .58604 .70724 L .57972 .97842 L 0 .848 .228 r
F
.57974 .97946 m .57975 .97916 L .57975 .9791 L F
.57975 .97954 m .57976 .97926 L .57974 .97946 L F
.57976 .97926 m .58765 .7655 L .57975 .97916 L F
.57976 .97926 m .57975 .97916 L .57974 .97946 L F
.57967 .98252 m .57983 .98057 L .57976 .98018 L F
.57977 .97944 m .57983 .98057 L .57978 .97981 L 0 .992 .198 r
F
.57983 .98057 m .58807 .87556 L .57978 .9799 L 0 .848 .228 r
F
.57973 .97832 m .57977 .97944 L .57977 .97978 L 0 .992 .198 r
F
.57975 .97907 m .57977 .97978 L .57985 .98312 L F
.57973 .97832 m .57977 .97978 L .57975 .97907 L F
.57983 .98057 m .57978 .9799 L .57978 .97994 L 0 .848 .228 r
F
.57979 .98037 m .57978 .97994 L .57976 .98018 L F
.57983 .98057 m .57978 .97994 L .57979 .98037 L F
.57977 .97978 m .57977 .9798 L .57978 .97981 L 0 .992 .198 r
F
.57967 .98252 m .57987 .98325 L .5798 .98084 L 0 .848 .228 r
F
.57977 .97978 m .57978 .97981 L .59051 1.37427 L 0 .992 .198 r
F
.57978 .97981 m .57983 .98057 L .59051 1.37427 L F
.57977 .97978 m .58807 .87556 L .58765 .7655 L 0 .848 .228 r
F
.57976 .98018 m .57978 .9799 L .57977 .97978 L F
.57978 .9799 m .58807 .87556 L .57977 .97978 L F
.57977 .97978 m .58765 .7655 L .57975 .97954 L F
.57973 .98015 m .57975 .9791 L .5797 .98004 L F
.57975 .9791 m .57973 .97832 L .57976 .97933 L 0 .992 .198 r
F
.57975 .9791 m .58604 .70724 L .57973 .97854 L 0 .848 .228 r
F
.57975 .9791 m .57973 .97854 L .5797 .98004 L F
.57981 .98179 m .57975 .9791 L .57985 .98312 L 0 .992 .198 r
F
.57975 .9791 m .57976 .97933 L .57985 .98312 L F
.58131 1.38092 m .5776 1.31996 L .58877 1.35745 L 0 .718 .217 r
F
.58131 1.38092 m .58877 1.35745 L .58926 1.38139 L F
.57972 .97863 m .57975 .9791 L .58891 1.37223 L 0 .992 .198 r
F
.57972 .97851 m .57975 .9791 L .57972 .97863 L F
.57967 .98252 m .57976 .98018 L .57973 .98015 L 0 .848 .228 r
F
.58798 1.37104 m .57972 .97855 L .58891 1.37223 L 0 .992 .198 r
F
.56776 .72428 m .58055 .86819 L .57954 .97021 L 0 .627 .217 r
F
.56776 .72428 m .57776 .74059 L .58055 .86819 L F
.58737 1.37094 m .5797 .97835 L .58798 1.37104 L 0 .992 .198 r
F
.5797 .97835 m .57954 .97021 L .57972 .97842 L F
.57973 .98015 m .57975 .97954 L .57974 .97946 L 0 .848 .228 r
F
.5797 .97835 m .57972 .97842 L .58798 1.37104 L 0 .992 .198 r
F
.57967 .98252 m .57972 .97842 L .57967 .97818 L 0 .848 .228 r
F
.57977 .97978 m .57975 .97954 L .57973 .98015 L F
.57967 .98252 m .57973 .98015 L .5797 .98004 L F
.58737 1.37094 m .5835 1.22617 L .57954 .97021 L 0 .992 .198 r
F
.57967 .97818 m .57972 .97842 L .57967 .97718 L 0 .848 .228 r
F
.57967 .97718 m .58215 .75533 L .57953 .85118 L F
.57972 .97842 m .5797 .97741 L .57972 .97855 L 0 .992 .198 r
F
.57972 .97842 m .58215 .75533 L .57967 .97718 L 0 .848 .228 r
F
.57972 .97855 m .57972 .97842 L .57972 .97863 L 0 .992 .198 r
F
.57972 .97842 m .57972 .97855 L .57972 .97863 L F
.57972 .97855 m .57972 .97863 L .58891 1.37223 L F
.57975 .9791 m .58765 .7655 L .58604 .70724 L 0 .848 .228 r
F
.57975 .97916 m .58765 .7655 L .57975 .9791 L F
.58919 1.37326 m .57977 .97978 L .59051 1.37427 L 0 .992 .198 r
F
.58026 .98465 m .58164 .99768 L .58828 1.14686 L F
.58026 .98465 m .584 1.01993 L .58669 1.00802 L 0 .848 .228 r
F
.59281 1.37509 m .58828 1.14686 L .58675 1.0415 L 0 0 .075 r
F
.59281 1.37509 m .58675 1.0415 L .58697 1.04194 L F
.59249 1.20546 m .59855 1.25604 L .59721 1.20049 L 0 .689 .054 r
F
.59335 1.23529 m .59855 1.25604 L .59249 1.20546 L F
.59362 1.37524 m .59695 1.1311 L .59784 1.37444 L 0 0 .075 r
F
.58806 1.05203 m .59721 1.20049 L .58902 .86344 L 0 .689 .054 r
F
.59362 1.37524 m .58806 1.05203 L .59622 1.18456 L 0 0 .075 r
F
.58164 .99768 m .58502 1.02959 L .58828 1.14686 L 0 .992 .198 r
F
.57983 .98062 m .58669 1.00802 L .58831 .9074 L 0 .848 .228 r
F
.57989 .98117 m .58669 1.00802 L .57983 .98062 L F
.58806 1.05203 m .58902 .86344 L .5874 1.04798 L 0 .689 .054 r
F
.59281 1.37509 m .58752 1.04869 L .58754 1.04884 L 0 0 .075 r
F
.59281 1.37509 m .58751 1.04865 L .58752 1.04869 L F
.58679 1.04418 m .58902 .86344 L .58669 1.00802 L 0 .689 .054 r
F
.5874 1.04798 m .58902 .86344 L .58679 1.04418 L F
.58765 .7655 m .58902 .86344 L .5887 .73677 L 0 .848 .228 r
F
.58807 .87556 m .58902 .86344 L .58765 .7655 L F
.58765 .7655 m .5887 .73677 L .58764 .72495 L F
.58765 .7655 m .58764 .72495 L .58604 .70724 L F
.58807 .87556 m .58831 .9074 L .58902 .86344 L F
.58109 1.03632 m .57981 .98179 L .58131 1.04382 L 0 .992 .198 r
F
.57981 .98179 m .57985 .98312 L .58131 1.04382 L F
.58909 1.37291 m .58109 1.03632 L .58919 1.37326 L F
.58877 1.36598 m .58109 1.03632 L .58909 1.37291 L F
.58109 1.03632 m .58131 1.04382 L .58919 1.37326 L F
.57048 1.03 m .57265 1.06801 L .57745 1.10395 L 0 .259 .218 r
F
.57573 1.12503 m .58168 1.11354 L .57745 1.10395 L 0 0 .041 r
F
.57475 1.07123 m .57705 1.05852 L .5835 1.22617 L 0 1 .183 r
F
.57519 1.07564 m .58408 1.10765 L .58206 1.07814 L 0 .333 .247 r
F
.57691 1.13525 m .57475 1.07123 L .57699 1.137 L 0 1 .183 r
F
.56809 1.0574 m .5709 1.07076 L .57644 1.1657 L 0 1 .154 r
F
.5776 1.31996 m .57849 1.24611 L .58321 1.26177 L 0 .718 .217 r
F
.57475 1.07123 m .58116 1.28259 L .57644 1.1657 L 0 1 .183 r
F
.58433 1.36644 m .5828 1.31928 L .58475 1.36736 L F
.57327 1.17289 m .57419 1.18183 L .57257 1.1617 L 0 0 .084 r
F
.58241 1.30716 m .58143 1.27704 L .58305 1.31695 L 0 1 .183 r
F
.58143 1.27704 m .57475 1.07123 L .58193 1.28381 L F
.58143 1.27704 m .58193 1.28381 L .58305 1.31695 L F
.56809 1.0574 m .58116 1.28259 L .58186 1.32076 L 0 1 .154 r
F
.57542 1.16031 m .57538 1.16001 L .57553 1.16124 L 0 0 .077 r
F
.56809 1.0574 m .57644 1.1657 L .58116 1.28259 L 0 1 .154 r
F
.58433 1.36644 m .58116 1.28259 L .58006 1.2462 L 0 1 .183 r
F
.58068 1.25412 m .58006 1.2462 L .57475 1.07123 L F
.58433 1.36644 m .58006 1.2462 L .58068 1.25412 L F
.56651 1.07541 m .57589 1.10639 L .57105 1.07413 L 0 .178 .202 r
F
.56512 1.0758 m .56695 1.08098 L .56651 1.07541 L F
.56695 1.08098 m .57589 1.10639 L .56651 1.07541 L F
.57887 1.18093 m .58359 1.26741 L .58301 1.25467 L 0 0 .041 r
F
.57928 1.19073 m .57928 1.19166 L .58052 1.21371 L F
.57887 1.18093 m .58433 1.28103 L .58435 1.28132 L F
.58024 1.20622 m .58026 1.20646 L .58023 1.20618 L 0 .548 0 r
F
.57891 1.18279 m .58433 1.28103 L .57887 1.18093 L 0 0 .041 r
F
.57891 1.18279 m .58321 1.26172 L .58433 1.28103 L F
.57894 1.18362 m .58321 1.26172 L .57891 1.18279 L F
.58491 1.36904 m .57475 1.07123 L .58613 1.37039 L 0 1 .183 r
F
.58359 1.26741 m .58435 1.28132 L .58381 1.27064 L 0 0 .041 r
F
.58359 1.26741 m .58381 1.27064 L .58301 1.25467 L F
.58075 1.21682 m .58052 1.21371 L .58321 1.26172 L F
.58301 1.25467 m .58435 1.28132 L .5853 1.29548 L F
.58613 1.37039 m .57475 1.07123 L .5835 1.22617 L 0 1 .183 r
F
.56695 1.08098 m .57752 1.13253 L .57589 1.10639 L 0 .178 .202 r
F
.56512 1.0758 m .5673 1.08576 L .56695 1.08098 L F
.5673 1.08576 m .57752 1.13253 L .56695 1.08098 L F
.5827 1.30509 m .57763 1.15664 L .5828 1.30728 L 0 1 .183 r
F
.5831 1.31826 m .57763 1.15664 L .5834 1.32549 L F
.5835 1.3305 m .58305 1.31695 L .58357 1.33212 L F
.58305 1.31695 m .57763 1.15664 L .5831 1.31826 L F
.58305 1.31695 m .5831 1.31826 L .58357 1.33212 L F
.57419 1.18183 m .57965 1.23497 L .57349 1.17109 L 0 0 .084 r
F
.57763 1.15664 m .57766 1.15724 L .58333 1.32285 L 0 1 .183 r
F
.57691 1.13525 m .57699 1.137 L .58333 1.32285 L F
.57965 1.23497 m .58117 1.24975 L .57959 1.23363 L 0 0 .084 r
F
.57965 1.23497 m .57959 1.23363 L .57349 1.17109 L F
.57419 1.18183 m .57349 1.17109 L .57257 1.1617 L F
.5828 1.31928 m .58241 1.30716 L .5835 1.3305 L 0 1 .183 r
F
.58241 1.30716 m .58305 1.31695 L .5835 1.3305 L F
.5828 1.31928 m .5835 1.3305 L .58475 1.36736 L F
.57 1.13946 m .57327 1.16775 L .56956 1.13339 L 0 0 .084 r
F
.57327 1.16775 m .58045 1.23001 L .57306 1.16448 L F
.57327 1.16775 m .57306 1.16448 L .56956 1.13339 L F
.57105 1.07413 m .57568 1.08604 L .57519 1.07564 L 0 .333 .247 r
F
.57568 1.08604 m .58408 1.10765 L .57519 1.07564 L F
.58891 1.37223 m .58877 1.36598 L .58909 1.37291 L 0 .992 .198 r
F
.5827 1.30509 m .5828 1.30728 L .58333 1.32285 L 0 1 .183 r
F
.57327 1.17289 m .5777 1.22198 L .57982 1.23898 L 0 0 .084 r
F
.57965 1.23497 m .57982 1.23898 L .58117 1.24975 L F
.57327 1.17289 m .57982 1.23898 L .57965 1.23497 L F
.57888 1.2164 m .58117 1.24975 L .58045 1.23001 L F
.57257 1.1617 m .57959 1.23363 L .57888 1.2164 L F
.57959 1.23363 m .58117 1.24975 L .57888 1.2164 L F
.58357 1.33212 m .5831 1.31826 L .5834 1.32549 L 0 1 .183 r
F
.5836 1.33346 m .5835 1.3305 L .58357 1.33212 L F
.56956 1.13339 m .57886 1.21591 L .57605 1.17636 L 0 0 .084 r
F
.57886 1.21591 m .58045 1.23001 L .57843 1.20543 L F
.57886 1.21591 m .57843 1.20543 L .57605 1.17636 L F
.56849 1.12631 m .57 1.13946 L .56956 1.13339 L F
.5739 1.18247 m .57433 1.18913 L .5777 1.22198 L F
.56849 1.12631 m .57433 1.18913 L .5739 1.18247 L F
.56849 1.12631 m .57327 1.17289 L .57257 1.1617 L F
.57771 1.24362 m .57796 1.24751 L .57796 1.24841 L 0 1 .154 r
F
.57708 1.23413 m .57796 1.24841 L .57799 1.25204 L F
.57304 1.15218 m .57294 1.15181 L .57174 1.12925 L F
.57193 1.13082 m .57304 1.15218 L .57174 1.12925 L F
.57026 1.12438 m .57605 1.17636 L .57065 1.12395 L 0 0 .084 r
F
.56849 1.12631 m .5717 1.14756 L .57026 1.12438 L F
.5717 1.14756 m .57605 1.17636 L .57026 1.12438 L F
.56849 1.12631 m .5739 1.18247 L .57327 1.17289 L F
.5739 1.18247 m .5777 1.22198 L .57327 1.17289 L F
.57758 1.23895 m .57795 1.24592 L .57755 1.23844 L 0 1 .154 r
F
.57795 1.24592 m .58121 1.30842 L .57806 1.25326 L F
.57795 1.24592 m .57806 1.25326 L .57799 1.25204 L F
.54821 1.01592 m .55105 1.02597 L .55151 1.02782 L 0 0 .069 r
F
.58121 1.30842 m .58186 1.32076 L .58127 1.31025 L 0 1 .154 r
F
.58121 1.30842 m .58127 1.31025 L .57799 1.25204 L F
.57763 1.15664 m .57691 1.13525 L .57766 1.15724 L 0 1 .183 r
F
.58475 1.36736 m .5836 1.33346 L .58491 1.36904 L F
.5836 1.33346 m .58333 1.32285 L .58491 1.36904 L F
.58122 .6604 m .5812 .65949 L .58121 .65946 L 0 0 .075 r
F
.58122 .6604 m .5811 .65275 L .58134 .66436 L F
.58124 .65632 m .58168 .65401 L .58133 .65877 L F
.58132 .65885 m .58168 .65401 L .58112 .27828 L 0 .004 .122 r
F
.58129 .6592 m .58132 .65885 L .58112 .27828 L F
.58129 .6592 m .58124 .65632 L .58133 .65877 L 0 0 .075 r
F
.58121 .65631 m .58065 .62185 L .58129 .6592 L F
.5812 .65949 m .58129 .6592 L .58121 .64863 L 0 .004 .122 r
F
.58121 .65946 m .5812 .65949 L .5811 .65275 L 0 0 .075 r
F
.58121 .65631 m .5811 .65275 L .58065 .62185 L F
.57838 .27883 m .58129 .6592 L .58112 .27828 L 0 .004 .122 r
F
.58112 .27828 m .58718 .57576 L .59032 .53109 L F
.57769 .27863 m .5812 .65949 L .57838 .27883 L F
.5812 .65949 m .58121 .64863 L .57838 .27883 L F
.58468 .27742 m .59032 .53109 L .58667 .27694 L F
.58112 .27828 m .59032 .53109 L .58468 .27742 L F
.59398 .42008 m .59169 .2794 L .59204 .38039 L 0 .288 .209 r
F
.59398 .42008 m .59204 .38039 L .59216 .41586 L F
.59759 .7007 m .59381 .61242 L .59234 .36968 L 0 .789 .222 r
F
.59178 .27866 m .59381 .61242 L .58753 .27792 L F
.59381 .61242 m .59032 .53109 L .58753 .27792 L F
.60554 1.37947 m .60169 1.06025 L .60178 1.05903 L 0 .267 .202 r
F
.60486 1.24634 m .60527 1.28859 L .60527 1.28856 L F
.60486 1.24637 m .60527 1.28859 L .60486 1.24634 L F
.60486 1.2464 m .60533 1.29473 L .60533 1.29471 L F
.60486 1.24642 m .60533 1.29473 L .60486 1.2464 L F
.60476 1.23559 m .60476 1.23561 L .60533 1.29473 L F
.60487 1.25095 m .6047 1.23322 L .60487 1.25099 L F
.6047 1.23322 m .6047 1.23325 L .60487 1.25099 L F
.60476 1.23557 m .60493 1.25344 L .60493 1.25344 L F
.60476 1.23557 m .60493 1.25344 L .60476 1.23557 L F
.60476 1.23557 m .60556 1.31839 L .60556 1.31839 L F
.60476 1.23557 m .60556 1.31839 L .60476 1.23557 L F
.60476 1.23557 m .60476 1.23557 L .60556 1.31839 L F
.60493 1.25344 m .6061 1.3753 L .6061 1.3753 L F
.60493 1.25344 m .6061 1.3753 L .60493 1.25344 L F
.60606 1.37381 m .60487 1.25095 L .60606 1.37385 L F
.60487 1.25095 m .60487 1.25099 L .60606 1.37385 L F
.60606 1.37385 m .60462 1.22477 L .60465 1.22589 L F
.60506 1.26722 m .60506 1.26725 L .60613 1.37866 L F
.60611 1.37892 m .60476 1.23798 L .60613 1.37866 L F
.60476 1.23798 m .60479 1.23853 L .60613 1.37866 L F
.60471 1.23033 m .60471 1.23035 L .60613 1.37866 L F
.60709 1.37674 m .58798 .27702 L .58667 .27694 L 0 .702 .227 r
F
.60556 1.31839 m .60556 1.31839 L .6061 1.3753 L 0 .267 .202 r
F
.60533 1.29471 m .60533 1.29473 L .60613 1.37866 L F
.60527 1.28856 m .60527 1.28859 L .60613 1.37866 L F
.60709 1.37674 m .58667 .27694 L .6 1.20464 L 0 .702 .227 r
F
.59381 .61242 m .59695 1.1311 L .59032 .53109 L 0 .789 .222 r
F
.60446 1.20447 m .60486 1.24637 L .60486 1.24634 L 0 .267 .202 r
F
.60446 1.20449 m .60486 1.24637 L .60446 1.20447 L F
.60448 1.20583 m .60486 1.24642 L .60448 1.20662 L F
.60448 1.20662 m .60486 1.24642 L .60486 1.2464 L F
.60753 1.37675 m .59403 .61767 L .60709 1.37674 L 0 .702 .227 r
F
.59403 .61767 m .58798 .27702 L .59381 .61242 L F
.59403 .61767 m .59381 .61242 L .60709 1.37674 L F
.59771 .81789 m .59761 .85832 L .59381 .61242 L 0 .789 .222 r
F
.59761 .85832 m .59695 1.1311 L .59443 .71561 L F
.59761 .85832 m .59443 .71561 L .59381 .61242 L F
.59842 .8553 m .59791 .95157 L .59771 .81789 L F
.59791 .95157 m .59695 1.1311 L .59771 .81789 L F
.59821 1.15826 m .59695 1.1311 L .59842 .8553 L F
.60119 .86249 m .6007 .83255 L .60058 .83268 L 0 .288 .209 r
F
.60074 .81346 m .60116 .85999 L .60128 .86705 L F
.60128 .86705 m .60116 .85999 L .60119 .86249 L F
.60119 .86249 m .60128 .86736 L .60128 .86735 L F
.5974 .69637 m .59512 .5519 L .58798 .27702 L 0 .702 .227 r
F
.60274 .93401 m .59852 .72252 L .5974 .69637 L F
.59843 .72046 m .59234 .36968 L .59704 .62759 L 0 .789 .222 r
F
.59759 .7007 m .59234 .36968 L .59843 .72046 L F
.60042 .81743 m .59984 .75321 L .59852 .72252 L 0 .702 .227 r
F
.60125 .85178 m .60122 .83704 L .60165 .87402 L 0 .267 .202 r
F
.60274 .93401 m .59957 .72318 L .60042 .81743 L 0 .702 .227 r
F
.60719 1.34683 m .60101 .79785 L .60032 .92593 L 0 .93 .212 r
F
.6006 .8505 m .59178 .27866 L .59222 .27873 L 0 .789 .222 r
F
.60056 .85561 m .59178 .27866 L .6006 .8505 L F
.59922 1.13192 m .59821 1.15826 L .5983 1.18271 L 0 .93 .212 r
F
.59889 1.19413 m .5983 1.18271 L .59855 1.25604 L F
.59922 1.13192 m .5983 1.18271 L .59889 1.19413 L F
.60611 1.37892 m .60606 1.37381 L .60606 1.37385 L 0 .267 .202 r
F
.6061 1.3753 m .6061 1.3753 L .60613 1.37866 L F
.60709 1.37674 m .6 1.20464 L .60596 1.37669 L 0 .702 .227 r
F
.60753 1.37675 m .60719 1.34683 L .59855 1.25604 L 0 .93 .212 r
F
.60719 1.34683 m .60151 .99854 L .59855 1.25604 L F
.60151 .99854 m .60032 .92593 L .59938 1.10165 L F
.60151 .99854 m .59938 1.10165 L .59855 1.25604 L F
.59788 1.17452 m .59695 1.1311 L .59821 1.15826 L 0 .789 .222 r
F
.59806 1.17798 m .59821 1.15826 L .59812 1.17926 L F
.59788 1.17452 m .598 1.16861 L .59806 1.17798 L F
.598 1.16861 m .59821 1.15826 L .59806 1.17798 L F
.5981 1.18492 m .59788 1.17452 L .59812 1.17926 L F
.59821 1.20284 m .59855 1.25604 L .5981 1.18492 L 0 .93 .212 r
F
.59814 1.18445 m .59821 1.15826 L .59812 1.17911 L F
.59819 1.1985 m .5982 1.18384 L .59814 1.18445 L F
.5982 1.18384 m .59821 1.15826 L .59814 1.18445 L F
.59771 1.17134 m .59788 1.17452 L .5981 1.18492 L 0 .789 .222 r
F
.59816 1.19466 m .59821 1.20284 L .59813 1.1902 L 0 .93 .212 r
F
.59813 1.1902 m .5981 1.18492 L .598 1.16909 L F
.59821 1.20284 m .5981 1.18492 L .59813 1.1902 L F
.5981 1.18492 m .59819 1.1985 L .59812 1.17911 L F
.59819 1.1985 m .59855 1.25604 L .59821 1.15826 L F
.60753 1.37675 m .59855 1.25604 L .60476 1.37602 L F
.60476 1.37602 m .59855 1.25604 L .60043 1.37486 L F
.59813 1.1905 m .5981 1.18492 L .60214 1.37435 L 0 .789 .222 r
F
.59803 1.18571 m .5981 1.18492 L .59813 1.1905 L F
.59771 1.17134 m .5981 1.18492 L .59803 1.18571 L F
.60155 1.37411 m .59816 1.19466 L .60214 1.37435 L F
.59816 1.19466 m .59771 1.17134 L .59813 1.1905 L F
.59816 1.19466 m .59813 1.1905 L .60214 1.37435 L F
.59799 1.16926 m .59816 1.19466 L .598 1.16909 L 0 .93 .212 r
F
.59816 1.19466 m .59813 1.1902 L .598 1.16909 L F
.60101 .79785 m .60012 .91317 L .60032 .92593 L F
.60386 1.08061 m .59843 .72046 L .60366 1.05899 L 0 .789 .222 r
F
.59843 .72046 m .59178 .27866 L .59855 .72306 L F
.59843 .72046 m .59855 .72306 L .60366 1.05899 L F
.59852 .72252 m .59512 .5519 L .5974 .69637 L 0 .702 .227 r
F
.59849 .75725 m .59381 .61242 L .59759 .7007 L 0 .789 .222 r
F
.60032 .92593 m .59821 1.15826 L .59922 1.13192 L 0 .93 .212 r
F
.60012 .91317 m .59821 1.15826 L .60032 .92593 L F
.60244 .92461 m .6024 .9216 L .60431 1.13042 L 0 .928 .09 r
F
.60433 1.1314 m .60431 1.13042 L .60496 1.20039 L F
.60244 .92461 m .60431 1.13042 L .60433 1.1314 L F
.60417 1.044 m .60385 1.02144 L .60753 1.37675 L 0 1 .196 r
F
.60375 .99246 m .60541 1.08061 L .60518 1.06536 L 0 .288 .209 r
F
.60802 1.37766 m .60465 1.07713 L .60462 1.07475 L 0 1 .196 r
F
.60802 1.37766 m .60462 1.07475 L .60753 1.37675 L F
.60898 1.37715 m .60532 1.07448 L .60742 1.36043 L 0 .646 .228 r
F
.60768 1.37679 m .60742 1.36043 L .60754 1.37675 L F
.60898 1.37715 m .60742 1.36043 L .60768 1.37679 L F
.59704 .62759 m .59234 .36968 L .59178 .27866 L 0 .789 .222 r
F
.59254 .29668 m .59025 .27715 L .59223 .27873 L 0 1 .169 r
F
.60052 .75521 m .59165 .34232 L .59254 .29668 L F
.59165 .34232 m .59025 .27715 L .59254 .29668 L F
.60111 .78261 m .60111 .78245 L .58798 .27702 L 0 .702 .227 r
F
.6011 .78217 m .59861 .64067 L .60111 .78255 L 0 1 .169 r
F
.60111 .78245 m .6011 .78218 L .6011 .78192 L 0 .702 .227 r
F
.60111 .78245 m .6011 .78192 L .58798 .27702 L F
.60111 .7829 m .6011 .78217 L .60112 .78302 L 0 1 .169 r
F
.6011 .78217 m .60111 .78255 L .60112 .78302 L F
.59861 .64067 m .59223 .27873 L .5986 .64047 L F
.59861 .64067 m .5986 .64047 L .60112 .78302 L F
.60313 .97468 m .60107 .79077 L .60294 .96908 L 0 .93 .212 r
F
.60107 .79077 m .60106 .79101 L .60294 .96908 L F
.6006 .8505 m .59883 .72978 L .60112 .78392 L 0 .789 .222 r
F
.60321 .97712 m .601 .78461 L .60313 .97468 L 0 .93 .212 r
F
.60321 .97712 m .60112 .7835 L .60107 .79068 L F
.60113 .7842 m .60112 .78392 L .60112 .78355 L 0 .789 .222 r
F
.60112 .78392 m .59883 .72978 L .60112 .78352 L F
.60112 .78392 m .60112 .78352 L .60112 .78355 L F
.60107 .79068 m .60112 .78302 L .601 .78461 L 0 .93 .212 r
F
.60112 .7835 m .60112 .78302 L .60107 .79068 L F
.59883 .72978 m .60111 .78302 L .60112 .7835 L 0 .789 .222 r
F
.60112 .78352 m .60112 .7835 L .60112 .78355 L F
.59883 .72978 m .60112 .7835 L .60112 .78352 L F
.6011 .78192 m .59025 .27715 L .58798 .27702 L 0 .702 .227 r
F
.5938 .36806 m .59368 .3611 L .5938 .36796 L 0 .223 .192 r
F
.5938 .36791 m .59368 .3611 L .5938 .36785 L F
.60084 .77351 m .59223 .27873 L .60111 .7829 L 0 1 .169 r
F
.60084 .77003 m .59031 .27715 L .60084 .77017 L 0 .702 .227 r
F
.60084 .77017 m .59031 .27715 L .59025 .27715 L F
.60111 .78236 m .59025 .27715 L .6011 .78192 L F
.59657 .57745 m .58956 .2766 L .59025 .27715 L 0 1 .169 r
F
.59629 .57634 m .58956 .2766 L .59657 .57745 L F
.59852 .72252 m .59957 .72318 L .59512 .5519 L 0 .702 .227 r
F
.59984 .75321 m .59957 .72318 L .59852 .72252 L F
.59999 .74449 m .58956 .2766 L .60031 .75536 L 0 1 .169 r
F
.60101 .79785 m .60072 .7693 L .60067 .76775 L 0 .93 .212 r
F
.60084 .77351 m .59025 .27715 L .60052 .75521 L 0 1 .169 r
F
.60104 .79433 m .60081 .77253 L .60101 .79785 L 0 .93 .212 r
F
.60081 .77253 m .60072 .7693 L .60101 .79785 L F
.60186 .87337 m .60104 .79433 L .60101 .79785 L F
.60031 .75536 m .59025 .27715 L .60084 .77351 L 0 1 .169 r
F
.59875 .60899 m .59919 .65507 L .59875 .60898 L 0 .267 .202 r
F
.5993 .66696 m .59768 .4975 L .5993 .66687 L F
.59972 .7038 m .59223 .27873 L .59914 .64764 L 0 .727 .225 r
F
.59972 .70383 m .59856 .63803 L .59972 .7038 L F
.59856 .63803 m .59856 .63803 L .59972 .7038 L F
.59972 .70383 m .59972 .7038 L .60111 .78244 L F
.60033 .73799 m .60109 .78131 L .60109 .78105 L 0 0 .043 r
F
.60041 .74289 m .60111 .78253 L .60109 .78131 L F
.60111 .78255 m .5986 .64009 L .60111 .7825 L 0 .727 .225 r
F
.5986 .64009 m .59223 .27873 L .5986 .64006 L F
.5986 .64009 m .5986 .64006 L .60111 .7825 L F
.60109 .78146 m .60093 .77241 L .60095 .77472 L 0 .702 .227 r
F
.60093 .77241 m .60076 .76245 L .60095 .77472 L F
.60095 .77472 m .60076 .76245 L .60084 .76975 L F
.6011 .78207 m .60107 .7801 L .60109 .78146 L F
.60085 .76737 m .60085 .76739 L .60106 .77958 L 0 0 .043 r
F
.59765 .49443 m .5988 .61395 L .5988 .61406 L 0 .267 .202 r
F
.5961 .34657 m .59605 .34147 L .59605 .3413 L F
.5961 .34657 m .59605 .3413 L .59611 .33403 L F
.59777 .50677 m .5961 .34657 L .59611 .33403 L F
.59771 .50854 m .59605 .34147 L .59777 .50677 L F
.59598 .33386 m .59598 .33385 L .59598 .33364 L F
.59605 .34147 m .59598 .33385 L .59611 .33403 L F
.59884 .61858 m .5976 .54474 L .59584 .3194 L 0 .727 .225 r
F
.5977 .49972 m .59875 .60899 L .5977 .49972 L 0 .267 .202 r
F
.59875 .60899 m .59875 .60898 L .5977 .49972 L F
.59768 .4975 m .59768 .49749 L .59878 .61283 L F
.59768 .4975 m .59878 .61283 L .59878 .6128 L F
.59619 .46255 m .59621 .46289 L .59884 .61858 L 0 .727 .225 r
F
.59619 .46255 m .59884 .61858 L .59885 .61944 L F
.59888 .62235 m .59619 .46255 L .59885 .61944 L F
.59619 .46255 m .59311 .27946 L .59621 .46289 L F
.59903 .63206 m .59557 .27763 L .59566 .27747 L 0 .267 .202 r
F
.59897 .62796 m .59557 .27763 L .59903 .63206 L F
.59896 .62676 m .59914 .64764 L .59888 .62235 L 0 .727 .225 r
F
.59953 .66838 m .59914 .64764 L .59896 .62676 L F
.60026 .721 m .59975 .70528 L .60023 .71904 L F
.59903 .63206 m .59566 .27747 L .60111 .78244 L 0 .267 .202 r
F
.59598 .33323 m .59545 .27977 L .59604 .32608 L F
.59565 .30053 m .59525 .27984 L .59548 .27986 L 0 .727 .225 r
F
.59564 .29957 m .59545 .27977 L .59565 .30053 L 0 .267 .202 r
F
.59565 .30053 m .59545 .27977 L .59598 .33323 L F
.59584 .3194 m .59576 .31381 L .59581 .31669 L 0 .727 .225 r
F
.59888 .62235 m .59223 .27873 L .59311 .27946 L F
.59914 .64764 m .59223 .27873 L .59888 .62235 L F
.59584 .3194 m .5976 .54474 L .59576 .31381 L F
.59842 .57526 m .59822 .55638 L .59777 .50677 L 0 .267 .202 r
F
.59822 .55638 m .59773 .50779 L .59777 .50677 L F
.5976 .54474 m .59311 .27946 L .59576 .31381 L 0 .727 .225 r
F
.59576 .31381 m .59525 .27984 L .59565 .30053 L F
.59884 .61858 m .59846 .57817 L .59897 .62796 L 0 .267 .202 r
F
.59846 .57817 m .59557 .27763 L .59853 .58261 L F
.59846 .57817 m .59853 .58261 L .59897 .62796 L F
.59765 .49443 m .5956 .2808 L .59765 .49432 L F
.5956 .2808 m .59557 .27763 L .5956 .28079 L F
.5956 .2808 m .5956 .28079 L .59765 .49432 L F
.59765 .49443 m .59765 .49432 L .5988 .61395 L F
.59768 .4975 m .59765 .49443 L .59768 .49749 L F
.59604 .32608 m .59545 .27977 L .59557 .27763 L F
.6011 .78207 m .59565 .27747 L .59241 .27728 L 0 .702 .227 r
F
.60086 .76742 m .60045 .74365 L .60044 .74387 L 0 0 .043 r
F
.60111 .78244 m .59566 .27747 L .60111 .78247 L 0 .267 .202 r
F
.6003 .73439 m .59566 .27747 L .59515 .27728 L 0 .93 .212 r
F
.60038 .73952 m .59566 .27747 L .6003 .73439 L F
.60017 .72682 m .60006 .72032 L .60016 .72782 L 0 0 .043 r
F
.59662 .51906 m .59563 .46132 L .59681 .53065 L F
.59563 .46132 m .59563 .46129 L .59683 .53183 L F
.59685 .53289 m .59685 .53287 L .59972 .70201 L F
.59971 .69982 m .59686 .53308 L .59972 .70201 L F
.59686 .53308 m .59662 .51906 L .59686 .53303 L F
.59686 .53308 m .59686 .53303 L .59972 .70201 L F
.59572 .28372 m .59566 .27747 L .59572 .28367 L 0 .93 .212 r
F
.59662 .51906 m .59681 .53065 L .59972 .70201 L 0 0 .043 r
F
.59548 .45264 m .59547 .45224 L .59562 .46104 L F
.59563 .46129 m .59562 .46104 L .59972 .70201 L F
.59548 .45264 m .59562 .46104 L .59563 .46129 L F
.61694 1.37316 m .60268 .56434 L .60167 .55783 L 0 .501 .225 r
F
.60258 .56314 m .59944 .2742 L .60268 .56434 L 0 .548 .225 r
F
.60268 .56434 m .60262 .5613 L .60234 .56028 L 0 .501 .225 r
F
.60268 .56434 m .60234 .56028 L .60167 .55783 L F
.59972 .70383 m .59223 .27873 L .59223 .27873 L 0 .727 .225 r
F
.59972 .70384 m .59223 .27873 L .59972 .70383 L F
.59514 .44383 m .59396 .36346 L .59391 .37405 L 0 0 .043 r
F
.60084 .76975 m .60047 .74826 L .60056 .75648 L 0 .702 .227 r
F
.59846 .63193 m .59546 .45205 L .59514 .44383 L 0 0 .043 r
F
.59972 .70315 m .59719 .55385 L .59846 .63193 L F
.59719 .55385 m .59546 .45205 L .59846 .63193 L F
.59546 .45205 m .59396 .36346 L .59514 .44383 L F
.59972 .70315 m .59536 .45593 L .59972 .7037 L F
.59536 .45593 m .59536 .45592 L .59972 .7037 L F
.59514 .44383 m .59514 .44374 L .59972 .7037 L F
.59508 .44011 m .59508 .44016 L .59514 .44366 L F
.59514 .44373 m .59514 .44366 L .59972 .70378 L F
.59508 .44011 m .59514 .44366 L .59514 .44373 L F
.59514 .44373 m .59972 .70378 L .59972 .70377 L F
.59508 .44011 m .59514 .44373 L .59514 .44373 L F
.59514 .44373 m .59972 .70378 L .59514 .44373 L F
.60228 .82176 m .60234 .8256 L .6023 .82348 L 0 .727 .225 r
F
.60228 .82176 m .6023 .82348 L .60221 .81951 L F
.60083 .73602 m .60088 .74176 L .60159 .80537 L 0 1 .196 r
F
.60085 .73907 m .60228 .82176 L .60221 .81951 L 0 .727 .225 r
F
.60085 .73893 m .60234 .8256 L .60085 .73907 L F
.60228 .82174 m .60227 .82146 L .60234 .8256 L F
.60085 .73893 m .60227 .82146 L .60228 .82174 L F
.60085 .73893 m .60083 .73602 L .60227 .82146 L F
.59602 .30008 m .59602 .29994 L .60231 .82439 L 0 .646 .228 r
F
.60234 .8256 m .59602 .30008 L .60231 .82439 L F
.60041 .74289 m .60041 .7429 L .60111 .78255 L 0 0 .043 r
F
.60111 .78253 m .60111 .78255 L .60112 .78284 L F
.60041 .74289 m .60111 .78255 L .60111 .78253 L F
.5988 .58476 m .5988 .58477 L .60038 .73952 L 0 .93 .212 r
F
.60111 .7825 m .59972 .70384 L .59972 .70383 L 0 .727 .225 r
F
.6003 .73439 m .59515 .27728 L .59582 .47011 L 0 .93 .212 r
F
.59974 .69611 m .59972 .70201 L .60016 .72782 L 0 0 .043 r
F
.59969 .69209 m .59969 .69377 L .59974 .69611 L F
.59969 .69377 m .59972 .70201 L .59974 .69611 L F
.5988 .58476 m .60038 .73952 L .60038 .73952 L 0 .93 .212 r
F
.6004 .74158 m .60047 .74826 L .60084 .76975 L 0 .702 .227 r
F
.60085 .76735 m .59972 .70315 L .60085 .76739 L 0 0 .043 r
F
.60076 .76245 m .6004 .74158 L .60084 .76975 L 0 .702 .227 r
F
.6004 .74125 m .6004 .74158 L .60086 .76799 L F
.60085 .76762 m .6004 .74125 L .60086 .76799 L F
.6011 .78198 m .60109 .78124 L .59031 .27715 L F
.59972 .70315 m .59972 .7037 L .60085 .76739 L 0 0 .043 r
F
.60072 .7693 m .60045 .74367 L .60067 .76775 L 0 .93 .212 r
F
.60045 .74367 m .59572 .28372 L .60038 .73952 L F
.60045 .74367 m .60038 .73952 L .60067 .76775 L F
.60044 .74387 m .60041 .74127 L .60016 .72782 L 0 0 .043 r
F
.60111 .78261 m .60111 .78236 L .6011 .78218 L 0 .702 .227 r
F
.60111 .78244 m .60111 .78255 L .60112 .78303 L 0 .267 .202 r
F
.60112 .78302 m .60111 .78255 L .60096 .77769 L 0 .93 .212 r
F
.6019 .87006 m .6009 .77566 L .60186 .87337 L F
.6009 .77566 m .60075 .76117 L .60089 .77519 L F
.6009 .77566 m .60089 .77519 L .60186 .87337 L F
.60075 .76117 m .6006 .75247 L .60186 .87337 L F
.60105 .79556 m .60104 .79521 L .60113 .7842 L 0 .789 .222 r
F
.60065 .85377 m .60104 .79521 L .60105 .79556 L F
.60065 .85377 m .6006 .8505 L .60104 .79521 L F
.6006 .8505 m .60112 .78392 L .60113 .7842 L F
.60053 .85972 m .59759 .7007 L .59843 .72046 L F
.61154 1.3758 m .61126 1.3596 L .61155 1.3758 L 0 .223 .192 r
F
.61156 1.37569 m .61046 1.31378 L .61154 1.3758 L F
.6036 .93019 m .60362 .93134 L .61154 1.3758 L F
.60527 1.07085 m .60468 1.01946 L .60464 1.01825 L 0 .646 .228 r
F
.60898 1.37715 m .60541 1.08061 L .60527 1.07085 L F
.60541 1.08061 m .60468 1.01946 L .60527 1.07085 L F
.60352 .97787 m .60362 .98586 L .60522 1.06727 L 0 .288 .209 r
F
.60509 1.05833 m .60522 1.06727 L .6113 1.37592 L F
.60352 .97787 m .60522 1.06727 L .60509 1.05833 L F
.61156 1.37569 m .60496 1.04915 L .6113 1.37592 L F
.60496 1.04915 m .60352 .97787 L .60509 1.05833 L F
.60496 1.04915 m .60509 1.05833 L .6113 1.37592 L F
.60532 1.07448 m .60485 1.0452 L .60754 1.37675 L 0 .646 .228 r
F
.60309 .94834 m .60346 .99966 L .60364 1.00156 L 0 1 .196 r
F
.60302 .94157 m .60306 .94721 L .60309 .94834 L F
.60306 .94721 m .60346 .99966 L .60309 .94834 L F
.60039 .87747 m .59759 .7007 L .60053 .85972 L 0 .789 .222 r
F
.60353 .97999 m .60309 .94834 L .60385 1.02144 L 0 1 .196 r
F
.60353 .97999 m .60385 1.02144 L .60417 1.044 L F
.60462 1.07475 m .60377 .99803 L .6037 .99318 L F
.60465 1.07713 m .60377 .99803 L .60462 1.07475 L F
.60362 .98586 m .60375 .99694 L .60375 .99246 L 0 .288 .209 r
F
.6037 .99318 m .60367 .9899 L .60366 .98898 L 0 1 .196 r
F
.60462 1.07475 m .60366 .98898 L .60417 1.044 L F
.60366 .98898 m .60345 .97242 L .60417 1.044 L F
.60462 1.07475 m .60417 1.044 L .60753 1.37675 L F
.60464 1.01825 m .60323 .9777 L .60754 1.37675 L 0 .646 .228 r
F
.60046 .88157 m .59842 .8553 L .59849 .75725 L 0 .789 .222 r
F
.60753 1.37675 m .60321 .97712 L .60294 .96908 L 0 .93 .212 r
F
.60623 1.25637 m .60344 .99947 L .606 1.31358 L 0 .928 .09 r
F
.60623 1.25637 m .606 1.31358 L .60605 1.31974 L F
.60494 1.19889 m .59821 1.15826 L .59842 .8553 L 0 .789 .222 r
F
.60344 .99947 m .60308 .99509 L .60496 1.20039 L 0 .928 .09 r
F
.60344 .99947 m .60496 1.20039 L .606 1.31358 L F
.60753 1.37675 m .60623 1.25637 L .6066 1.37514 L F
.60614 1.32888 m .59821 1.15826 L .60494 1.19889 L 0 .789 .222 r
F
.60623 1.25637 m .60605 1.31923 L .6066 1.37514 L 0 .928 .09 r
F
.60605 1.31923 m .60605 1.32033 L .60614 1.32888 L F
.60605 1.31923 m .60614 1.32888 L .6066 1.37514 L F
.59812 1.17926 m .59821 1.15826 L .60614 1.32888 L 0 .789 .222 r
F
.60753 1.37675 m .60346 .99973 L .60344 .99947 L 0 .928 .09 r
F
.60621 1.33514 m .60614 1.32888 L .60829 1.37529 L 0 .789 .222 r
F
.60829 1.37529 m .60614 1.32888 L .60494 1.19889 L F
.606 1.31358 m .60496 1.20039 L .60605 1.32033 L 0 .928 .09 r
F
.60419 1.1165 m .60005 .94105 L .60046 .88157 L 0 .789 .222 r
F
.60829 1.37529 m .60494 1.19889 L .60419 1.1165 L F
.60494 1.19889 m .60005 .94105 L .60419 1.1165 L F
.60226 .97452 m .60039 .87747 L .60053 .85972 L F
.60829 1.37529 m .60298 1.04075 L .60226 .97452 L F
.60298 1.04075 m .60039 .87747 L .60226 .97452 L F
.60101 .79785 m .59897 .75167 L .60069 .8389 L 0 .93 .212 r
F
.59842 .8553 m .59381 .61242 L .59849 .75725 L 0 .789 .222 r
F
.59897 .75167 m .59662 .69863 L .60069 .8389 L 0 .93 .212 r
F
.60005 .94105 m .59842 .8553 L .60046 .88157 L 0 .789 .222 r
F
.60069 .8389 m .59662 .69863 L .60012 .91317 L 0 .93 .212 r
F
.60101 .79785 m .60067 .76775 L .59867 .73362 L F
.5991 .75463 m .59867 .73362 L .59662 .69863 L F
.60101 .79785 m .59867 .73362 L .5991 .75463 L F
.592 .40212 m .59204 .40202 L .59371 .48618 L 0 1 .169 r
F
.592 .40212 m .59371 .48618 L .5937 .48728 L F
.5937 .48758 m .59634 .61902 L .59549 .57755 L F
.592 .40212 m .5937 .48728 L .5937 .48758 L F
.5937 .48728 m .59634 .61902 L .5937 .48758 L F
.59634 .61902 m .58956 .2766 L .5974 .62813 L F
.59634 .61902 m .5974 .62813 L .59999 .74449 L F
.59403 .61767 m .5974 .69637 L .58798 .27702 L 0 .702 .227 r
F
.59658 .69646 m .59662 .69863 L .59634 .61902 L 0 .93 .212 r
F
.59634 .61901 m .59634 .61902 L .59632 .61488 L F
.59658 .69646 m .59634 .61902 L .59634 .61901 L F
.59351 .46971 m .59329 .43419 L .59329 .43417 L F
.59352 .46983 m .59329 .43419 L .59351 .46971 L F
.5912 .36098 m .58942 .27567 L .58956 .2766 L 0 1 .169 r
F
.59112 .35894 m .58942 .27567 L .5912 .36098 L F
.59536 .45593 m .59514 .44383 L .59536 .45592 L 0 0 .043 r
F
.59514 .44383 m .59368 .36097 L .59514 .44374 L F
.59788 .59927 m .59972 .70377 L .59788 .59926 L F
.59972 .70377 m .59972 .70377 L .59788 .59926 L F
.59788 .59925 m .59972 .70377 L .59788 .59901 L F
.59972 .70377 m .59972 .70376 L .59788 .59901 L F
.59788 .59901 m .59972 .70376 L .59972 .7037 L F
.59788 .59926 m .59972 .70377 L .59788 .59925 L F
.59972 .70377 m .59972 .70377 L .59788 .59925 L F
.59548 .46322 m .59788 .59926 L .59548 .46322 L F
.59788 .59926 m .59788 .59925 L .59548 .46322 L F
.59517 .44543 m .59548 .46322 L .59517 .44543 L F
.59548 .46322 m .59548 .46322 L .59517 .44543 L F
.59442 .40305 m .59517 .44543 L .59442 .40304 L F
.59517 .44543 m .59517 .44543 L .59442 .40304 L F
.59514 .44374 m .59788 .59925 L .59788 .59901 L F
.59442 .40304 m .59514 .44373 L .59514 .44374 L F
.59514 .44373 m .59788 .59925 L .59514 .44374 L F
.59368 .36097 m .59246 .27695 L .59223 .27873 L F
.5925 .29411 m .59223 .27873 L .5925 .29413 L F
.5925 .29411 m .5925 .29413 L .59368 .36103 L F
.59368 .36097 m .5925 .29411 L .59368 .36103 L F
.59309 .40689 m .59241 .27728 L .59031 .27715 L 0 .702 .227 r
F
.59442 .40305 m .59788 .59927 L .59442 .40305 L 0 0 .043 r
F
.59788 .59927 m .59788 .59926 L .59442 .40305 L F
.60056 .75648 m .59534 .44918 L .59309 .40689 L 0 .702 .227 r
F
.59412 .38582 m .59442 .40305 L .59412 .38582 L 0 0 .043 r
F
.59442 .40305 m .59442 .40305 L .59412 .38582 L F
.59412 .38582 m .59442 .40305 L .59442 .40304 L F
.59368 .36097 m .59412 .38582 L .59412 .38582 L F
.59485 .42742 m .59485 .4274 L .59508 .44016 L F
.59485 .42742 m .59508 .44016 L .59508 .44011 L F
.59368 .36097 m .59485 .4274 L .59485 .42742 L F
.59368 .36097 m .59368 .36103 L .59485 .4274 L F
.59391 .37405 m .59378 .35303 L .59368 .36097 L F
.59396 .36346 m .59378 .35303 L .59391 .37405 L F
.59378 .35303 m .59246 .27695 L .59368 .36097 L F
.59534 .44918 m .59241 .27728 L .59309 .40689 L 0 .702 .227 r
F
.59219 .39452 m .5904 .27425 L .59128 .3521 L 0 1 .169 r
F
.59337 .44996 m .59256 .40223 L .59219 .39452 L F
.59256 .40223 m .5904 .27425 L .59219 .39452 L F
.5937 .48925 m .5919 .40237 L .592 .40212 L F
.59369 .49212 m .5919 .40237 L .5937 .48925 L F
.59433 .59426 m .59468 .54026 L .59449 .53155 L 0 .93 .212 r
F
.5937 .48728 m .59371 .48618 L .59634 .61902 L 0 1 .169 r
F
.60016 .72782 m .59972 .70201 L .59972 .70315 L 0 0 .043 r
F
.59697 .54069 m .59434 .38603 L .59718 .55305 L F
.59434 .38603 m .59396 .36346 L .59434 .38595 L F
.59434 .38603 m .59434 .38595 L .59495 .42172 L F
.59495 .42176 m .59495 .42172 L .59972 .70315 L F
.59434 .38603 m .59495 .42172 L .59495 .42176 L F
.60153 .55043 m .6006 .53903 L .60465 .79224 L 0 .501 .225 r
F
.6066 1.37514 m .60614 1.32888 L .60644 1.35629 L 0 .928 .09 r
F
.60667 1.37504 m .60624 1.33755 L .60829 1.37529 L 0 .789 .222 r
F
.59972 .70201 m .59697 .54069 L .59972 .70315 L 0 0 .043 r
F
.59697 .54069 m .59718 .55305 L .59972 .70315 L F
.59972 .70377 m .59972 .70378 L .60033 .738 L F
.59972 .70377 m .60033 .738 L .59972 .70377 L F
.59972 .70377 m .60033 .738 L .59972 .70376 L F
.59972 .7037 m .60033 .738 L .60033 .73799 L F
.59972 .70376 m .60033 .738 L .59972 .7037 L F
.59972 .70377 m .60033 .738 L .59972 .70377 L F
.60033 .73799 m .60033 .738 L .60041 .7429 L F
.60033 .73799 m .60041 .7429 L .60041 .74289 L F
.6004 .74158 m .59744 .56923 L .60047 .74826 L 0 .702 .227 r
F
.59744 .56923 m .59241 .27728 L .59746 .57209 L F
.59744 .56923 m .59746 .57209 L .60047 .74826 L F
.59368 .49335 m .5919 .40237 L .59369 .49212 L 0 1 .169 r
F
.59368 .49335 m .59369 .49212 L .59417 .51655 L F
.59467 .65724 m .59474 .65849 L .59369 .4943 L 0 .93 .212 r
F
.59467 .65724 m .59369 .4943 L .59369 .49433 L F
.59467 .65724 m .59368 .49335 L .59368 .49359 L F
.59367 .49139 m .59368 .49335 L .59364 .48658 L F
.5919 .40237 m .59098 .35544 L .592 .40212 L 0 1 .169 r
F
.59098 .35544 m .58942 .27567 L .59112 .35894 L F
.59098 .35544 m .59112 .35894 L .592 .40212 L F
.58723 .56896 m .58775 .54224 L .58825 .49438 L 0 1 .183 r
F
.58807 .49957 m .58825 .49438 L .58897 .42464 L F
.58723 .56896 m .58825 .49438 L .58807 .49957 L F
.58723 .56896 m .58897 .42464 L .58893 .42522 L F
.58723 .56896 m .58922 .40034 L .58918 .40077 L F
.58939 .37849 m .58951 .37194 L .58946 .37285 L F
.58723 .56896 m .58945 .3774 L .58939 .37849 L F
.58945 .3774 m .58951 .37194 L .58939 .37849 L F
.58974 .34451 m .58996 .32901 L .58992 .32806 L F
.58723 .56896 m .5898 .34318 L .58974 .34451 L F
.5898 .34318 m .58996 .32901 L .58974 .34451 L F
.59537 .44975 m .59241 .27728 L .59534 .44918 L 0 .702 .227 r
F
.59553 .44754 m .59246 .27695 L .59582 .47011 L 0 0 .043 r
F
.6004 .74125 m .59241 .27728 L .6004 .74158 L 0 .702 .227 r
F
.59548 .45264 m .59378 .35303 L .59547 .45224 L 0 0 .043 r
F
.59582 .47011 m .59438 .38718 L .59971 .69982 L F
.59438 .38718 m .59438 .38718 L .59971 .69982 L F
.59437 .38709 m .59435 .38625 L .59971 .69982 L F
.60366 1.05899 m .60056 .85561 L .6006 .8505 L 0 .789 .222 r
F
.60114 .7848 m .60065 .85377 L .60113 .7842 L F
.60144 .81505 m .60129 .80137 L .60141 .81452 L 0 .928 .09 r
F
.60273 .89444 m .602 .86441 L .60323 .9777 L 0 .646 .228 r
F
.60191 .84695 m .60147 .81571 L .60199 .86399 L 0 1 .196 r
F
.60156 .81896 m .60147 .81571 L .60191 .84695 L F
.60211 .85189 m .60199 .86294 L .602 .86441 L 0 .646 .228 r
F
.60211 .85146 m .60199 .86294 L .60211 .85189 L F
.60147 .81572 m .60113 .78398 L .60144 .81505 L 0 .928 .09 r
F
.60113 .78398 m .60114 .78446 L .60144 .81505 L F
.60113 .78398 m .60112 .7835 L .60315 .90379 L 0 .223 .192 r
F
.60233 .82754 m .602 .86441 L .60273 .89444 L 0 .646 .228 r
F
.60152 .79758 m .60159 .80537 L .60177 .82156 L 0 1 .196 r
F
.60177 .82156 m .60159 .80537 L .6016 .80584 L F
.60217 .8173 m .60085 .73912 L .60221 .81951 L 0 .727 .225 r
F
.60085 .73912 m .60085 .73907 L .60221 .81951 L F
.60113 .78357 m .60113 .78353 L .60144 .81505 L 0 .928 .09 r
F
.60112 .78345 m .60112 .78332 L .60113 .7835 L 0 1 .169 r
F
.60112 .78291 m .60112 .78321 L .60113 .78398 L 0 1 .196 r
F
.60112 .78345 m .60113 .7835 L .60113 .78354 L 0 1 .169 r
F
.60294 .96908 m .6019 .87006 L .60186 .87337 L 0 .93 .212 r
F
.60366 1.05899 m .60065 .85377 L .60114 .7848 L 0 .789 .222 r
F
.60103 .78422 m .60094 .77932 L .601 .78461 L 0 .93 .212 r
F
.60112 .78302 m .60094 .77932 L .60103 .78422 L F
.60112 .78302 m .6009 .77566 L .60094 .77932 L F
.60116 .78865 m .60084 .77351 L .60112 .78345 L 0 1 .169 r
F
.60085 .76762 m .60086 .76799 L .60109 .78146 L 0 .702 .227 r
F
.60107 .7801 m .60085 .76762 L .60109 .78146 L F
.60111 .78236 m .60084 .77003 L .60084 .77017 L F
.60088 .7606 m .59566 .27747 L .60085 .76694 L 0 .93 .212 r
F
.60085 .76735 m .60085 .76737 L .60107 .77981 L 0 0 .043 r
F
.60085 .76735 m .60107 .77981 L .60087 .76818 L F
.60093 .77195 m .60085 .76694 L .60096 .77769 L 0 .93 .212 r
F
.60088 .7606 m .60085 .76694 L .60093 .77195 L F
.60111 .78255 m .60088 .7606 L .60093 .77195 L F
.60087 .76818 m .60107 .77981 L .60111 .78236 L 0 0 .043 r
F
.60096 .77769 m .60085 .76694 L .6009 .77566 L 0 .93 .212 r
F
.60085 .76694 m .59566 .27747 L .60075 .76117 L F
.60085 .76694 m .60075 .76117 L .6009 .77566 L F
.60085 .76737 m .60106 .77958 L .60109 .78105 L 0 0 .043 r
F
.60107 .77981 m .60109 .78105 L .60111 .78236 L F
.60085 .76737 m .60109 .78105 L .60107 .77981 L F
.6006 .75247 m .59566 .27747 L .60045 .74367 L 0 .93 .212 r
F
.60075 .76117 m .59566 .27747 L .6006 .75247 L F
.60104 .77783 m .60104 .77776 L .60045 .74365 L 0 0 .043 r
F
.60104 .77776 m .6005 .74296 L .60045 .74365 L F
.60104 .77783 m .60045 .74365 L .60086 .76742 L F
.60111 .78236 m .60109 .78124 L .6011 .78198 L 0 .702 .227 r
F
.60111 .78244 m .60111 .78247 L .60111 .78255 L 0 .267 .202 r
F
.60111 .78255 m .60093 .77195 L .60096 .77769 L 0 .93 .212 r
F
.60084 .77351 m .60111 .7829 L .60112 .78345 L 0 1 .169 r
F
.60085 .76735 m .60111 .78236 L .60104 .77802 L 0 0 .043 r
F
.60116 .78885 m .60104 .77768 L .60116 .78938 L 0 .928 .09 r
F
.60104 .77768 m .59962 .64604 L .60103 .7772 L F
.60104 .77768 m .60103 .7772 L .60116 .78938 L F
.60103 .7769 m .59962 .64604 L .5996 .64553 L F
.60103 .7772 m .59962 .64604 L .60103 .7769 L F
.60228 .82322 m .60234 .8256 L .61165 1.37574 L 0 .727 .225 r
F
.60221 .81951 m .60234 .8256 L .60228 .82322 L F
.60233 .82754 m .60227 .82308 L .60199 .86294 L 0 .646 .228 r
F
.60227 .82308 m .60225 .82241 L .60199 .86294 L F
.60217 .8173 m .60221 .81951 L .60228 .82322 L 0 .727 .225 r
F
.60225 .82241 m .60166 .80184 L .60199 .86294 L 0 .646 .228 r
F
.59746 .43532 m .59569 .27755 L .59745 .4353 L 0 1 .196 r
F
.59745 .4353 m .59569 .27755 L .59745 .4353 L F
.59745 .4353 m .59569 .27755 L .59745 .4353 L F
.59819 .50234 m .59569 .27755 L .59566 .27747 L F
.6009 .74369 m .5982 .5026 L .59819 .50234 L F
.5982 .5026 m .59569 .27755 L .59819 .50234 L F
.60227 .82308 m .59575 .2775 L .59566 .27747 L 0 .646 .228 r
F
.60227 .82312 m .59575 .2775 L .60227 .82308 L F
.59821 .50274 m .59746 .43532 L .59821 .50269 L 0 1 .196 r
F
.60085 .73912 m .60077 .73421 L .60085 .73907 L 0 .727 .225 r
F
.60089 .7421 m .60085 .73857 L .6009 .74369 L 0 1 .196 r
F
.60085 .73857 m .59821 .50263 L .60085 .73923 L F
.59821 .50263 m .59745 .4353 L .59821 .50261 L F
.59821 .50263 m .59821 .50261 L .60085 .73923 L F
.60085 .73857 m .60085 .73923 L .6009 .74369 L F
.59745 .4353 m .59745 .4353 L .6009 .74369 L F
.60077 .73421 m .60085 .73893 L .60085 .73907 L 0 .727 .225 r
F
.59986 .65078 m .6011 .78121 L .60056 .72218 L 0 1 .196 r
F
.59986 .65078 m .59965 .64649 L .60112 .78321 L F
.59986 .65078 m .60112 .78321 L .60112 .78291 L F
.60077 .73421 m .60083 .73602 L .60085 .73893 L 0 .727 .225 r
F
.60085 .73929 m .59986 .65078 L .60098 .75988 L 0 1 .196 r
F
.60024 .6882 m .60056 .72218 L .60106 .77411 L F
.60024 .6882 m .60106 .77411 L .60106 .77334 L F
.60097 .75916 m .60098 .76057 L .60098 .76024 L F
.60084 .73843 m .59745 .4353 L .60085 .73857 L F
.60233 .82754 m .60227 .82312 L .60227 .82308 L 0 .646 .228 r
F
.60109 .78131 m .60112 .78284 L .60111 .78245 L 0 0 .043 r
F
.60111 .78253 m .60112 .78284 L .60109 .78131 L F
.60109 .78105 m .60111 .78245 L .60111 .78236 L F
.60109 .78131 m .60111 .78245 L .60109 .78105 L F
.60111 .78245 m .60112 .78272 L .60112 .78289 L F
.60111 .78245 m .60112 .78289 L .60111 .78261 L F
.60112 .78272 m .60112 .78284 L .60112 .78309 L F
.60112 .78301 m .60111 .78255 L .60111 .7825 L 0 .727 .225 r
F
.60112 .78302 m .60111 .78255 L .60112 .78301 L F
.60111 .7825 m .60112 .78299 L .60112 .78301 L F
.60112 .78344 m .60112 .78289 L .60104 .77804 L 0 .928 .09 r
F
.59986 .65078 m .59676 .37549 L .59965 .64649 L 0 1 .196 r
F
.59676 .37549 m .59566 .27747 L .59672 .37593 L F
.59676 .37549 m .59672 .37593 L .59965 .64649 L F
.60112 .78289 m .59672 .37597 L .60104 .77769 L 0 .928 .09 r
F
.59672 .37597 m .59672 .37601 L .60104 .77804 L F
.60084 .73843 m .60085 .73857 L .60089 .7421 L 0 1 .196 r
F
.60088 .74097 m .60112 .78299 L .60085 .73912 L 0 .727 .225 r
F
.60112 .78308 m .60112 .78299 L .60088 .74097 L F
.60088 .74176 m .60089 .7421 L .6016 .80584 L 0 1 .196 r
F
.6016 .80584 m .60089 .7421 L .6009 .74369 L F
.60113 .78354 m .60112 .78299 L .60225 .82231 L 0 .727 .225 r
F
.60112 .78332 m .60112 .78302 L .60112 .78344 L 0 .928 .09 r
F
.60112 .78302 m .59566 .27747 L .60112 .78289 L F
.60112 .78302 m .60112 .78289 L .60112 .78344 L F
.60128 .7965 m .60113 .78398 L .60147 .81571 L 0 1 .196 r
F
.60122 .78994 m .60121 .78929 L .60147 .81571 L F
.60166 .80184 m .60113 .78394 L .60199 .86294 L 0 .646 .228 r
F
.60113 .78372 m .60113 .78394 L .60166 .80184 L F
.60234 .82653 m .59575 .2775 L .60233 .82754 L F
.61156 1.37499 m .60113 .78354 L .60225 .82231 L 0 .727 .225 r
F
.60225 .82231 m .60112 .78308 L .60088 .74097 L F
.59845 .50757 m .59807 .50067 L .60113 .7835 L 0 .646 .228 r
F
.59845 .50757 m .60113 .7835 L .60113 .78353 L F
.60097 .75916 m .60105 .77219 L .60105 .77245 L 0 1 .196 r
F
.60097 .75916 m .60105 .77245 L .60098 .76057 L F
.60098 .75988 m .60097 .75916 L .60098 .76024 L F
.60097 .75916 m .60024 .6882 L .60105 .77219 L F
.60024 .6882 m .59986 .65078 L .60056 .72218 L F
.60137 .74898 m .59845 .50757 L .60113 .78353 L 0 .646 .228 r
F
.60137 .74898 m .60113 .78353 L .60113 .78372 L F
.60112 .78289 m .60112 .78309 L .60365 .92648 L 0 0 .043 r
F
.60112 .78272 m .60112 .78299 L .60112 .78289 L F
.60112 .78299 m .60112 .78309 L .60112 .78289 L F
.59438 .38718 m .59437 .38709 L .59438 .38718 L F
.59437 .38709 m .59378 .35303 L .59435 .38625 L F
.592 .40212 m .58956 .2766 L .59204 .40202 L 0 1 .169 r
F
.59311 .45298 m .58971 .27525 L .59077 .34064 L F
.5937 .48783 m .59603 .60445 L .5958 .59345 L F
.592 .40212 m .5937 .48758 L .5937 .48783 L F
.5937 .48758 m .59603 .60445 L .5937 .48783 L F
.59355 .47402 m .59255 .41378 L .59311 .45298 L F
.59352 .46994 m .59331 .43515 L .59329 .43419 L 0 .93 .212 r
F
.59355 .4742 m .59331 .43515 L .59352 .46994 L F
.59096 .35035 m .59368 .49335 L .59365 .48805 L 0 1 .169 r
F
.59366 .4922 m .59366 .49225 L .59368 .49335 L F
.5912 .36285 m .59366 .49225 L .59366 .4922 L F
.5912 .36285 m .59135 .37394 L .59366 .49225 L F
.59488 .54977 m .592 .40212 L .5958 .59345 L F
.60047 .74826 m .59537 .44975 L .60056 .75648 L 0 .702 .227 r
F
.59537 .44975 m .59534 .44918 L .60056 .75648 L F
.59563 .46132 m .59683 .53183 L .59681 .53065 L 0 0 .043 r
F
.59433 .59426 m .59623 .61391 L .59487 .54939 L 0 .93 .212 r
F
.59408 .52082 m .59445 .54704 L .59449 .53155 L F
.59408 .52082 m .59449 .53155 L .59412 .51402 L F
.59488 .54977 m .59369 .49212 L .5937 .48925 L 0 1 .169 r
F
.59417 .51655 m .59369 .49212 L .59488 .54977 L F
.59563 .46132 m .59548 .45264 L .59563 .46129 L 0 0 .043 r
F
.59477 .52618 m .59581 .46935 L .59532 .43957 L 0 .93 .212 r
F
.59483 .53027 m .59581 .46935 L .59477 .52618 L F
.59486 .54915 m .59581 .46935 L .59468 .54026 L F
.59262 .32715 m .59368 .49335 L .59344 .33604 L F
.59368 .49335 m .59404 .5102 L .59344 .33604 L F
.59487 .54939 m .59632 .61488 L .59582 .47011 L F
.59412 .51402 m .59449 .53155 L .59481 .4083 L F
.59344 .33604 m .59404 .5102 L .59481 .4083 L F
.59404 .5102 m .59412 .51402 L .59481 .4083 L F
.59449 .53155 m .59532 .43957 L .59481 .4083 L F
.59468 .54026 m .59532 .43957 L .59449 .53155 L F
.59469 .56377 m .59582 .47011 L .59581 .46935 L F
.59433 .59426 m .59469 .56397 L .59469 .56377 L F
.59469 .56397 m .59582 .47011 L .59469 .56377 L F
.60112 .78289 m .60104 .77769 L .60104 .77804 L 0 .928 .09 r
F
.60111 .78261 m .60112 .78289 L .60365 .92648 L 0 0 .043 r
F
.60113 .78357 m .60112 .78332 L .60112 .78344 L 0 .928 .09 r
F
.60137 .74898 m .60113 .78372 L .60166 .80184 L 0 .646 .228 r
F
.60113 .78353 m .60113 .7835 L .60113 .78394 L F
.60112 .78301 m .60112 .78299 L .60113 .78354 L 0 .727 .225 r
F
.60113 .78352 m .60113 .78354 L .61156 1.37499 L F
.60112 .78301 m .60113 .78354 L .60113 .78352 L F
.61157 1.37569 m .60113 .78352 L .61156 1.37499 L F
.60113 .78372 m .60113 .78353 L .60113 .78394 L 0 .646 .228 r
F
.61157 1.37569 m .60225 .82231 L .61165 1.37574 L 0 .727 .225 r
F
.60225 .82231 m .60225 .82237 L .61165 1.37574 L F
.60225 .82237 m .60228 .82322 L .61165 1.37574 L F
.60226 .82181 m .60166 .80149 L .60166 .80184 L 0 .646 .228 r
F
.60225 .82231 m .60217 .8173 L .60225 .82237 L 0 .727 .225 r
F
.60217 .8173 m .60228 .82322 L .60225 .82237 L F
.60226 .82181 m .60166 .80184 L .60225 .82241 L 0 .646 .228 r
F
.59572 .28372 m .5988 .58477 L .5988 .58476 L 0 .93 .212 r
F
.59572 .28372 m .59572 .28367 L .5988 .58477 L F
.60103 .7769 m .59561 .27734 L .59986 .70197 L 0 .928 .09 r
F
.6036 .92288 m .6005 .74292 L .60104 .77776 L 0 0 .043 r
F
.60104 .77776 m .6005 .74292 L .6005 .74296 L F
.60116 .78938 m .60103 .7772 L .60103 .7769 L 0 .928 .09 r
F
.60144 .81505 m .60116 .78885 L .60116 .78938 L F
.60141 .81452 m .60116 .78938 L .6013 .81232 L F
.60119 .7934 m .60118 .79324 L .60116 .78865 L 0 1 .169 r
F
.60118 .79324 m .60084 .77351 L .60116 .78865 L F
.60112 .78345 m .60111 .7829 L .60112 .78307 L F
.60111 .7829 m .60112 .78302 L .60112 .78307 L F
.60112 .78345 m .60112 .78307 L .60112 .78332 L F
.60113 .78398 m .60112 .78366 L .60113 .78422 L 0 .288 .209 r
F
.60113 .78418 m .60112 .78355 L .60113 .7838 L 0 .789 .222 r
F
.60113 .78353 m .60104 .77804 L .60116 .78885 L 0 .928 .09 r
F
.60113 .78418 m .60113 .7838 L .60113 .78398 L 0 .789 .222 r
F
.60113 .78429 m .60112 .78355 L .60113 .78418 L F
.60113 .78353 m .60116 .78885 L .60128 .8005 L 0 .928 .09 r
F
.60114 .78471 m .60128 .8005 L .60144 .81505 L F
.60113 .78418 m .60113 .78398 L .60113 .78409 L 0 .789 .222 r
F
.60114 .78462 m .60113 .78418 L .60113 .78436 L F
.60113 .78353 m .60128 .8005 L .60114 .78471 L 0 .928 .09 r
F
.60113 .78409 m .60113 .78398 L .60113 .78405 L 0 .789 .222 r
F
.60113 .78354 m .60113 .7835 L .60113 .78357 L 0 1 .169 r
F
.60365 .92684 m .60113 .78398 L .60315 .90379 L 0 .223 .192 r
F
.60817 1.18294 m .60113 .78357 L .61156 1.37569 L 0 1 .169 r
F
.60113 .78379 m .60112 .7835 L .60113 .78382 L 0 .223 .192 r
F
.60112 .78345 m .60113 .78354 L .60817 1.18294 L 0 1 .169 r
F
.60113 .78354 m .60113 .78357 L .60817 1.18294 L F
.60226 .82181 m .60137 .74898 L .60166 .80149 L 0 .646 .228 r
F
.60874 1.21571 m .60114 .78446 L .60115 .78523 L 0 .288 .209 r
F
.60113 .78418 m .60113 .78405 L .61156 1.37569 L 0 .789 .222 r
F
.60362 .93134 m .60353 .92635 L .60357 .92934 L 0 .646 .228 r
F
.60362 .93134 m .60357 .92934 L .60464 1.01825 L F
.60464 1.01825 m .60355 .92851 L .60345 .94425 L F
.60345 .97242 m .60325 .95916 L .60353 .97999 L 0 1 .196 r
F
.60325 .95916 m .60309 .94834 L .60353 .97999 L F
.60322 .95387 m .60309 .94834 L .60345 .97242 L F
.60355 .92851 m .60273 .89444 L .60323 .9777 L 0 .646 .228 r
F
.60464 1.01825 m .60357 .92934 L .60355 .92851 L F
.60874 1.21571 m .60115 .78523 L .60229 .86413 L 0 .288 .209 r
F
.61156 1.37569 m .60874 1.21571 L .60229 .86413 L F
.60113 .78398 m .60113 .78357 L .60114 .78446 L 0 .928 .09 r
F
.60635 1.09109 m .60634 1.09048 L .60468 1.01946 L 0 .646 .228 r
F
.60464 1.01825 m .60345 .94425 L .60443 1.01224 L F
.61156 1.37569 m .60229 .86413 L .60496 1.04915 L 0 .288 .209 r
F
.60532 1.07448 m .60527 1.07085 L .60485 1.0452 L 0 .646 .228 r
F
.60527 1.07085 m .60479 1.0375 L .60485 1.0452 L F
.60522 1.06727 m .60541 1.08061 L .6113 1.37592 L 0 .288 .209 r
F
.6113 1.37592 m .60541 1.08061 L .61032 1.37719 L F
.61032 1.37719 m .61024 1.37242 L .60898 1.37715 L 0 .646 .228 r
F
.60443 1.01224 m .60345 .94425 L .60323 .9777 L F
.60858 1.37532 m .60114 .78462 L .61156 1.37569 L 0 .789 .222 r
F
.60114 .78462 m .60113 .78436 L .61156 1.37569 L F
.60178 .8938 m .6001 .75996 L .60124 .80252 L 0 1 .169 r
F
.60166 .83896 m .60088 .8044 L .60132 .84791 L 0 .928 .09 r
F
.60166 .83896 m .60132 .84791 L .60244 .92461 L F
.60144 .81505 m .6013 .81245 L .60166 .83896 L F
.6013 .81245 m .60088 .8044 L .60166 .83896 L F
.60344 .99947 m .60188 .85543 L .60308 .99509 L F
.60188 .85543 m .60144 .81505 L .60166 .83896 L F
.60188 .85543 m .60166 .83896 L .60308 .99509 L F
.60344 .99947 m .60147 .81572 L .60144 .81505 L F
.60346 .99973 m .60147 .81572 L .60344 .99947 L F
.60829 1.37529 m .60366 1.05899 L .60114 .7848 L 0 .789 .222 r
F
.60129 .80137 m .60116 .78938 L .60141 .81452 L 0 .928 .09 r
F
.60067 .76775 m .59634 .61902 L .59662 .69863 L 0 .93 .212 r
F
.60178 .8938 m .59634 .61902 L .6001 .75996 L 0 1 .169 r
F
.60227 .82308 m .60226 .82181 L .60225 .82241 L 0 .646 .228 r
F
.60463 1.03789 m .60414 1.01288 L .6038 .97719 L 0 1 .169 r
F
.60159 .88418 m .60158 .88357 L .60178 .8938 L F
.60397 1.10434 m .6018 .89482 L .60395 1.10289 L 0 .928 .09 r
F
.6018 .89482 m .60132 .84791 L .6018 .89476 L F
.6018 .89482 m .6018 .89476 L .60395 1.10289 L F
.60395 1.10289 m .6018 .89476 L .60178 .8938 L F
.60179 .89509 m .60178 .8938 L .60179 .89505 L F
.60179 .89509 m .60179 .89505 L .60366 1.08112 L F
.60395 1.10289 m .60179 .89509 L .60366 1.08112 L F
.60496 1.20039 m .60395 1.10289 L .60605 1.32033 L F
.60395 1.10289 m .60366 1.08112 L .60605 1.32033 L F
.60605 1.31974 m .606 1.31358 L .60605 1.32033 L F
.60614 1.32888 m .60632 1.34428 L .60644 1.35629 L F
.59821 1.19011 m .59821 1.18095 L .60621 1.33514 L 0 .789 .222 r
F
.60624 1.33755 m .60621 1.33514 L .60829 1.37529 L F
.59821 1.19011 m .60621 1.33514 L .60624 1.33755 L F
.60614 1.32888 m .60366 1.08112 L .60632 1.34428 L 0 .928 .09 r
F
.60366 1.08112 m .60178 .8938 L .60366 1.08076 L F
.60366 1.08112 m .60366 1.08076 L .60644 1.35629 L F
.60232 .91632 m .6018 .89482 L .60397 1.10434 L F
.60178 .8938 m .60179 .89474 L .60366 1.08072 L F
.60366 1.08076 m .60366 1.08072 L .60644 1.35629 L F
.60178 .8938 m .60366 1.08072 L .60366 1.08076 L F
.6024 .9216 m .60232 .91632 L .60397 1.10434 L F
.60431 1.13042 m .60397 1.10434 L .60496 1.20039 L F
.6024 .9216 m .60397 1.10434 L .60431 1.13042 L F
.60496 1.20039 m .60397 1.10434 L .60395 1.10289 L F
.60829 1.37529 m .60386 1.08061 L .60366 1.05899 L 0 .789 .222 r
F
.60638 1.35019 m .60179 .89474 L .60388 1.06172 L 0 .928 .09 r
F
.60632 1.34462 m .60179 .89474 L .60638 1.35019 L F
.60232 .91632 m .60132 .84791 L .6018 .89482 L F
.60202 .90612 m .60178 .8938 L .60197 .90167 L 0 1 .169 r
F
.60829 1.37529 m .60113 .78429 L .60858 1.37532 L 0 .789 .222 r
F
.60113 .78429 m .60113 .78418 L .60858 1.37532 L F
.60202 .90612 m .60197 .90167 L .6038 .97719 L 0 1 .169 r
F
.60414 1.01288 m .60202 .90612 L .6038 .97719 L F
.6018 .89476 m .60132 .84791 L .60178 .8938 L 0 .928 .09 r
F
.6038 .97719 m .60178 .8938 L .60154 .81397 L 0 1 .169 r
F
.59634 .61902 m .59999 .74449 L .60154 .81397 L F
.60107 .79077 m .601 .78461 L .60106 .79101 L 0 .93 .212 r
F
.60154 .81397 m .60031 .75536 L .60084 .77351 L 0 1 .169 r
F
.60154 .81397 m .59999 .74449 L .60031 .75536 L F
.6013 .81232 m .60103 .7769 L .60088 .8044 L 0 .928 .09 r
F
.60116 .78938 m .60103 .7769 L .6013 .81232 L F
.60178 .8938 m .60124 .80252 L .60154 .81397 L 0 1 .169 r
F
.60041 .74127 m .6003 .73001 L .60017 .72682 L 0 0 .043 r
F
.6003 .73001 m .6002 .72397 L .60017 .72682 L F
.60041 .74127 m .60017 .72682 L .60016 .72782 L F
.60038 .73952 m .60038 .73952 L .60067 .76775 L 0 .93 .212 r
F
.60031 .75536 m .59629 .57634 L .59657 .57745 L 0 1 .169 r
F
.60067 .76775 m .6003 .73439 L .59634 .61902 L 0 .93 .212 r
F
.59681 .53065 m .59683 .53183 L .59685 .53287 L 0 0 .043 r
F
.59681 .53065 m .59685 .53287 L .59685 .53289 L F
.6003 .73439 m .59582 .47011 L .59634 .61902 L 0 .93 .212 r
F
.60022 .72256 m .59969 .69209 L .60006 .72032 L 0 0 .043 r
F
.60022 .72256 m .60006 .72032 L .60017 .72682 L F
.60067 .76775 m .60038 .73952 L .6003 .73439 L 0 .93 .212 r
F
.60081 .77253 m .6006 .75247 L .60072 .7693 L F
.6006 .75247 m .60045 .74367 L .60072 .7693 L F
.60104 .77783 m .60085 .76735 L .60104 .77802 L 0 0 .043 r
F
.60055 .74214 m .60022 .72256 L .60044 .74387 L F
.60103 .7769 m .59986 .70197 L .60088 .8044 L 0 .928 .09 r
F
.61226 1.37507 m .59987 .6878 L .61159 1.37557 L 0 0 .043 r
F
.59987 .6878 m .59986 .69767 L .61159 1.37557 L F
.59986 .69767 m .59986 .70197 L .61159 1.37557 L F
.60584 1.09998 m .60584 1.10033 L .60266 .94343 L 0 1 .169 r
F
.60584 1.09998 m .60266 .94343 L .60266 .94335 L F
.60584 1.09998 m .60266 .94335 L .60266 .9433 L F
.60384 1.05656 m .60207 .91033 L .60304 .96464 L 0 .928 .09 r
F
.60347 1.02756 m .60206 .90945 L .60384 1.05656 L F
.60206 .90945 m .60207 .91033 L .60384 1.05656 L F
.60179 .89474 m .60178 .89409 L .60388 1.06172 L F
.60178 .89409 m .60206 .90945 L .60388 1.06172 L F
.6018 .90029 m .60173 .89224 L .60196 .9041 L 0 1 .169 r
F
.60255 .93698 m .60196 .9041 L .60479 1.04657 L F
.6018 .90029 m .60196 .9041 L .60255 .93698 L F
.60177 .89327 m .60178 .8938 L .60198 .90403 L F
.60197 .90448 m .60198 .90403 L .60812 1.21381 L F
.60197 .90448 m .60812 1.21381 L .60811 1.21374 L F
.60858 1.23756 m .60887 1.25191 L .60886 1.25173 L F
.60197 .90448 m .60859 1.23772 L .60858 1.23756 L F
.60859 1.23772 m .60887 1.25191 L .60858 1.23756 L F
.60262 .94108 m .60498 1.05681 L .60508 1.06266 L F
.6026 .93982 m .60498 1.05681 L .60262 .94108 L F
.60262 .94108 m .60584 1.09998 L .60266 .9433 L F
.60644 1.35629 m .60304 .96464 L .60664 1.37508 L 0 .928 .09 r
F
.6018 .90029 m .60498 1.05681 L .6018 .90058 L 0 1 .169 r
F
.60195 .83676 m .60184 .82411 L .61156 1.37569 L F
.60154 .81397 m .60184 .82411 L .60195 .83676 L F
.60154 .81397 m .60112 .78345 L .60184 .82411 L F
.61157 1.37569 m .60113 .7835 L .60113 .78352 L 0 .727 .225 r
F
.61615 .90959 m .61344 .69714 L .61599 .78294 L 0 .593 .223 r
F
.61615 .90959 m .61613 .89606 L .61843 .88235 L F
.61568 .91524 m .62082 1.04562 L .61615 .90959 L 0 .813 .228 r
F
.61619 .92815 m .61942 1.04395 L .62082 1.04562 L F
.62095 1.24489 m .61003 .65457 L .60732 .62103 L 0 .501 .225 r
F
.62372 1.37194 m .62094 1.22592 L .62095 1.24489 L F
.62094 1.22592 m .61003 .65457 L .62095 1.24489 L F
.62071 .88503 m .62473 1.05027 L .62628 .89156 L 0 .813 .228 r
F
.61335 .71369 m .61344 .69714 L .61523 .89295 L 0 .548 .225 r
F
.61521 .8936 m .61523 .89295 L .61546 .91787 L F
.61335 .71369 m .61523 .89295 L .61521 .8936 L F
.60796 .62888 m .60674 .61384 L .60749 .55027 L F
.62372 1.37194 m .60732 .62103 L .62237 1.37247 L 0 .501 .225 r
F
.60732 .62103 m .60674 .61384 L .62237 1.37247 L F
.61619 1.09854 m .61212 1.0998 L .61694 1.37316 L F
.62393 1.37156 m .6111 1.08724 L .61927 1.37211 L 0 .654 .228 r
F
.61075 1.10025 m .60674 .61384 L .60796 .62888 L 0 .548 .225 r
F
.61694 1.37316 m .60816 1.01194 L .61523 1.37338 L 0 .501 .225 r
F
.61043 1.11181 m .60674 .61384 L .61075 1.10025 L 0 .548 .225 r
F
.59993 .57328 m .60816 1.01194 L .60042 .54784 L 0 0 .043 r
F
.59998 .57033 m .59706 .27457 L .59718 .27446 L 0 .928 .09 r
F
.59993 .57328 m .59706 .27457 L .59998 .57033 L F
.59993 .57328 m .60042 .54784 L .59952 .49387 L 0 0 .043 r
F
.60104 .77802 m .60111 .78236 L .60751 1.14542 L F
.60751 1.14542 m .60751 1.14542 L .60752 1.14574 L F
.60104 .77802 m .60751 1.14542 L .60751 1.14542 L F
.60104 .77802 m .60752 1.14574 L .60752 1.14573 L F
.60751 1.14541 m .60762 1.15182 L .60762 1.15181 L F
.60104 .77802 m .60751 1.14541 L .60751 1.14541 L F
.60751 1.14541 m .60762 1.15182 L .60751 1.14541 L F
.60752 1.14572 m .60773 1.15791 L .60773 1.1579 L F
.60104 .77802 m .60752 1.14573 L .60752 1.14572 L F
.60752 1.14573 m .60773 1.15791 L .60752 1.14572 L F
.60783 1.16354 m .60816 1.18223 L .60816 1.18217 L F
.60104 .77802 m .60783 1.16361 L .60783 1.16354 L F
.60783 1.16361 m .60816 1.18223 L .60783 1.16354 L F
.61314 .6932 m .61546 .91787 L .6154 .92008 L 0 .548 .225 r
F
.61329 .91513 m .61314 .6932 L .61501 .8808 L F
.61591 .71082 m .61716 .71778 L .61843 .88235 L 0 .593 .223 r
F
.61694 .781 m .61725 .80218 L .61746 .76283 L 0 .813 .228 r
F
.61419 .87738 m .61725 .80218 L .61694 .781 L F
.61419 .87738 m .61705 .84021 L .61725 .80218 L F
.61419 .87738 m .61606 .85994 L .61705 .84021 L F
.62487 .79794 m .62628 .89148 L .62507 .801 L 0 .529 .227 r
F
.62392 .79625 m .62628 .89148 L .62487 .79794 L F
.62226 .77687 m .62628 .89148 L .62342 .77616 L F
.60952 .43329 m .61427 .51422 L .61157 .47228 L 0 .919 .089 r
F
.60909 .42499 m .61427 .51422 L .60952 .43329 L F
.60621 .33447 m .60423 .27363 L .60585 .27296 L 0 .548 .225 r
F
.60621 .33447 m .60585 .27296 L .60756 .36456 L F
.61309 .69253 m .61312 .66195 L .61314 .6932 L F
.60677 .3808 m .61344 .69714 L .60787 .40172 L 0 .529 .227 r
F
.61156 .47213 m .62628 .89148 L .61157 .47228 L F
.60801 .40715 m .61344 .69714 L .61381 .63012 L F
.60795 .40607 m .61344 .69714 L .60801 .40715 L F
.61047 .42277 m .6112 .44594 L .61136 .44926 L 0 .537 .227 r
F
.60744 .39351 m .60887 .40381 L .61252 .46953 L 0 .919 .089 r
F
.60689 .38666 m .6069 .38681 L .60677 .3808 L 0 .501 .225 r
F
.60685 .38754 m .60677 .3808 L .60668 .37909 L F
.61273 .67314 m .60694 .38906 L .60685 .38754 L F
.60694 .38906 m .60677 .3808 L .60685 .38754 L F
.60677 .3808 m .60887 .40381 L .60744 .39351 L 0 .919 .089 r
F
.60449 .296 m .60423 .27363 L .60621 .33447 L 0 .548 .225 r
F
.60787 .40172 m .6159 .71081 L .60787 .40178 L 0 .529 .227 r
F
.6159 .71081 m .61591 .71082 L .60787 .40179 L F
.60767 .39795 m .61252 .46953 L .60787 .40179 L 0 .919 .089 r
F
.60704 .38759 m .61252 .46953 L .60714 .39022 L F
.60674 .61384 m .60423 .27363 L .60749 .55027 L 0 .548 .225 r
F
.60111 .78236 m .60365 .92648 L .60365 .92652 L 0 0 .043 r
F
.60111 .78245 m .60365 .92648 L .60111 .78236 L F
.6036 .92288 m .60055 .74214 L .6005 .74292 L F
.61132 1.37555 m .60463 1.03789 L .60154 .81397 L 0 1 .169 r
F
.61132 1.37555 m .60154 .81397 L .61156 1.37569 L F
.6018 .90029 m .60479 1.04657 L .60498 1.05681 L F
.61132 1.36008 m .61095 1.33937 L .61128 1.35902 L 0 0 .043 r
F
.61506 .93426 m .61594 .93322 L .61546 .91787 L 0 .654 .228 r
F
.61335 1.00527 m .61942 1.04395 L .61686 .96256 L F
.61329 .91513 m .61501 .8808 L .61524 .90416 L 0 .548 .225 r
F
.61419 .87738 m .62078 .98542 L .62071 .88503 L 0 .813 .228 r
F
.61758 .93127 m .61615 .90959 L .61843 .88235 L 0 .593 .223 r
F
.61405 .98584 m .61686 .96256 L .61594 .93322 L 0 .654 .228 r
F
.61335 1.00527 m .61686 .96256 L .61405 .98584 L F
.61627 1.00704 m .61617 .92234 L .61758 .93127 L 0 .593 .223 r
F
.61617 .92234 m .61615 .90959 L .61758 .93127 L F
.61335 1.00527 m .61594 .93322 L .61506 .93426 L 0 .654 .228 r
F
.61543 .92246 m .61546 .91787 L .61627 1.00704 L 0 .548 .225 r
F
.61627 1.00704 m .61546 .91787 L .61615 .90959 L 0 .593 .223 r
F
.60817 1.18182 m .60784 1.16316 L .60816 1.18215 L 0 0 .043 r
F
.60784 1.16316 m .60195 .82934 L .60783 1.16351 L F
.60784 1.16316 m .60783 1.16351 L .60816 1.18215 L F
.60989 1.10905 m .60423 .27363 L .61043 1.11181 L 0 .548 .225 r
F
.60003 .57488 m .59993 .57328 L .59998 .57033 L 0 .928 .09 r
F
.60931 1.1836 m .60816 1.01194 L .59993 .57328 L 0 0 .043 r
F
.61226 1.37507 m .60965 1.14354 L .60931 1.1836 L F
.60965 1.14354 m .60816 1.01194 L .60931 1.1836 L F
.61274 1.12353 m .61942 1.04395 L .61335 1.00527 L 0 .654 .228 r
F
.61272 1.02804 m .61309 .69253 L .61332 1.00629 L 0 .548 .225 r
F
.59991 .60307 m .59926 .52814 L .59991 .60169 L 0 .928 .09 r
F
.59926 .52814 m .59927 .52833 L .59991 .60169 L F
.59844 .43287 m .59844 .43312 L .59927 .5284 L F
.59927 .52833 m .59927 .5284 L .59991 .60169 L F
.59844 .43287 m .59927 .5284 L .59927 .52833 L F
.59991 .60169 m .59927 .5284 L .59993 .57328 L F
.59927 .5284 m .59753 .32804 L .59955 .53448 L F
.59753 .32804 m .59761 .33126 L .59955 .53448 L F
.59745 .4353 m .59745 .4353 L .59821 .50263 L 0 1 .196 r
F
.59745 .4353 m .59821 .50263 L .59821 .50263 L F
.59845 .50757 m .59566 .27747 L .59807 .50067 L 0 .646 .228 r
F
.59672 .37597 m .59566 .27747 L .59672 .37601 L 0 .928 .09 r
F
.5996 .64553 m .59566 .27747 L .59561 .27734 L F
.59962 .64604 m .59566 .27747 L .5996 .64553 L F
.59877 .59337 m .59561 .27734 L .59895 .54177 L F
.59496 .35069 m .59558 .39987 L .59515 .27728 L 0 .93 .212 r
F
.59403 .27649 m .59496 .35069 L .59515 .27728 L F
.59738 .46224 m .59797 .46912 L .59432 .27496 L 0 0 .043 r
F
.59877 .59337 m .59895 .54177 L .5999 .61708 L 0 .928 .09 r
F
.61226 1.37507 m .5999 .61709 L .59987 .6878 L 0 0 .043 r
F
.59989 .63421 m .5999 .61708 L .60031 .6494 L 0 .928 .09 r
F
.59877 .59337 m .5999 .61708 L .59989 .63421 L F
.59986 .70197 m .59877 .59337 L .60082 .74913 L F
.59485 .39379 m .59558 .39987 L .59496 .35069 L 0 .93 .212 r
F
.59501 .40615 m .59558 .39987 L .59485 .39379 L F
.59553 .44754 m .59335 .276 L .59246 .27695 L 0 0 .043 r
F
.59532 .43957 m .59536 .43383 L .59481 .4083 L 0 .93 .212 r
F
.59536 .43383 m .59558 .39987 L .59501 .40615 L F
.59536 .43383 m .59501 .40615 L .59481 .4083 L F
.59533 .43861 m .59582 .46871 L .59558 .39987 L F
.59301 .29544 m .59481 .40694 L .59496 .35069 L F
.59229 .27525 m .59496 .35069 L .59403 .27649 L F
.59987 .6878 m .59432 .27496 L .59335 .276 L 0 0 .043 r
F
.59987 .6878 m .59335 .276 L .59553 .44754 L F
.59987 .67715 m .59877 .59337 L .59989 .63421 L 0 .928 .09 r
F
.5999 .61709 m .59432 .27496 L .59987 .6878 L 0 0 .043 r
F
.59893 .55741 m .59797 .46912 L .59738 .46224 L F
.59991 .60307 m .59703 .39009 L .59844 .43287 L 0 .928 .09 r
F
.61226 1.37507 m .59993 .57328 L .5999 .61709 L 0 0 .043 r
F
.60031 .6494 m .5999 .61708 L .59991 .60307 L 0 .928 .09 r
F
.5999 .61708 m .59703 .39009 L .59991 .60307 L F
.59893 .55741 m .59993 .57328 L .59797 .46912 L 0 0 .043 r
F
.59926 .52814 m .59844 .43287 L .59927 .52833 L 0 .928 .09 r
F
.60258 .56314 m .60261 .56352 L .60276 .57906 L 0 .548 .225 r
F
.60261 .56352 m .60268 .56434 L .60276 .57906 L F
.60276 .57906 m .60268 .56434 L .60868 1.1029 L F
.60258 .56314 m .60868 1.1029 L .60865 1.10275 L F
.59844 .43287 m .59706 .27457 L .59844 .43312 L 0 .928 .09 r
F
.59844 .43287 m .59561 .27734 L .59706 .27457 L F
.59703 .39009 m .59561 .27734 L .59844 .43287 L F
.5946 .27476 m .59951 .49117 L .59635 .2735 L 0 0 .043 r
F
.59951 .49117 m .6006 .53903 L .59936 .46185 L F
.59951 .49117 m .59936 .46185 L .59635 .2735 L F
.59581 .46935 m .59582 .47011 L .59582 .46871 L 0 .93 .212 r
F
.59553 .44754 m .59582 .47011 L .59986 .70197 L 0 0 .043 r
F
.59553 .44754 m .59986 .70197 L .59986 .69767 L F
.60183 .9026 m .60648 1.13166 L .60644 1.13254 L 0 1 .169 r
F
.60182 .90157 m .60648 1.13166 L .60183 .9026 L F
.60361 .92304 m .60022 .72256 L .6036 .92288 L 0 0 .043 r
F
.60386 .93158 m .60022 .72256 L .60367 .92708 L F
.60195 .82934 m .60195 .82931 L .60816 1.18217 L F
.60816 1.18215 m .60816 1.18217 L .61157 1.37569 L F
.60195 .82934 m .60816 1.18217 L .60816 1.18215 L F
.61274 1.12353 m .61335 1.00527 L .6111 1.08724 L 0 .654 .228 r
F
.62393 1.37156 m .6211 1.16595 L .61274 1.12353 L F
.6211 1.16595 m .61942 1.04395 L .61274 1.12353 L F
.6111 1.08724 m .61043 1.11181 L .61927 1.37211 L F
.61927 1.37211 m .61043 1.11181 L .61385 1.3721 L F
.61001 1.1264 m .60989 1.10905 L .61004 1.12522 L 0 .548 .225 r
F
.61043 1.11181 m .60923 1.15295 L .61017 1.19745 L 0 .654 .228 r
F
.61043 1.11181 m .61017 1.19745 L .61385 1.3721 L F
.61385 1.3721 m .60923 1.15295 L .61221 1.3721 L F
.61004 1.12522 m .61043 1.11181 L .61235 1.3713 L 0 .548 .225 r
F
.60989 1.10905 m .61043 1.11181 L .61004 1.12522 L F
.60923 1.15295 m .60874 1.16989 L .61221 1.3721 L 0 .654 .228 r
F
.60395 1.06561 m .6031 .96758 L .60441 1.04124 L 0 .928 .09 r
F
.61122 1.37505 m .60351 .99315 L .61132 1.37555 L 0 1 .169 r
F
.61068 1.36145 m .60351 .99315 L .61122 1.37505 L F
.60304 .96464 m .6031 .96758 L .60664 1.37508 L 0 .928 .09 r
F
.60351 .99315 m .60284 .95737 L .60938 1.27985 L 0 1 .169 r
F
.60351 .99315 m .60219 .92526 L .60284 .95737 L F
.60351 .99315 m .60938 1.27985 L .60937 1.2797 L F
.60351 .99315 m .60982 1.30151 L .6098 1.30107 L F
.60284 .95737 m .60223 .92242 L .60918 1.26898 L F
.60219 .92526 m .60221 .92377 L .60284 .95737 L F
.60221 .92377 m .60223 .92242 L .60284 .95737 L F
.60914 1.26814 m .60918 1.26898 L .61132 1.37555 L F
.61221 1.3721 m .60874 1.16989 L .60742 1.13068 L F
.60937 1.2797 m .60938 1.27985 L .60982 1.30151 L F
.6098 1.30107 m .60982 1.30151 L .61132 1.37555 L F
.61091 1.37345 m .61068 1.36145 L .61122 1.37505 L F
.60886 1.25173 m .60887 1.25191 L .61132 1.37555 L F
.61095 1.33937 m .60817 1.18182 L .61094 1.34021 L 0 0 .043 r
F
.60817 1.18182 m .60816 1.18215 L .61094 1.34021 L F
.61095 1.33937 m .61094 1.34021 L .61128 1.35902 L F
.60816 1.18217 m .60816 1.18223 L .61157 1.37569 L F
.61159 1.37557 m .61132 1.36008 L .61157 1.37569 L F
.61132 1.36008 m .61128 1.35902 L .61157 1.37569 L F
.60365 .92652 m .60365 .92648 L .60948 1.25732 L F
.60948 1.25732 m .60948 1.25732 L .6107 1.32657 L F
.60365 .92652 m .60948 1.25732 L .60948 1.25732 L F
.6107 1.32657 m .6107 1.32657 L .61157 1.37569 L F
.61053 1.31662 m .6107 1.32657 L .6107 1.32657 L F
.60365 .92652 m .61033 1.30566 L .61033 1.30565 L F
.61033 1.30565 m .61053 1.31663 L .61053 1.31662 L F
.61033 1.30566 m .61053 1.31663 L .61033 1.30565 L F
.61053 1.31663 m .6107 1.32657 L .61053 1.31662 L F
.61092 1.33715 m .61055 1.31561 L .61091 1.33678 L F
.61055 1.31561 m .61035 1.30433 L .61053 1.31528 L F
.61035 1.30433 m .60386 .93158 L .61035 1.30462 L F
.61035 1.30433 m .61035 1.30462 L .61053 1.31528 L F
.61055 1.31561 m .61053 1.31528 L .61091 1.33678 L F
.6093 1.24586 m .60386 .93158 L .60367 .92708 L F
.61091 1.33678 m .60933 1.2465 L .6093 1.24586 L F
.60933 1.2465 m .60386 .93158 L .6093 1.24586 L F
.61159 1.37557 m .61092 1.33715 L .61091 1.33678 L F
.60644 1.13254 m .60648 1.13166 L .61132 1.37555 L 0 1 .169 r
F
.61221 1.3721 m .60878 1.20736 L .61091 1.37345 L F
.61221 1.3721 m .60912 1.22151 L .60914 1.22449 L F
.60912 1.22151 m .607 1.11817 L .60914 1.22449 L F
.60752 1.14573 m .60752 1.14574 L .60762 1.15182 L 0 0 .043 r
F
.60914 1.22449 m .607 1.11817 L .60682 1.11292 L 0 1 .169 r
F
.61221 1.3721 m .60742 1.13068 L .6074 1.13008 L F
.60284 .95737 m .60918 1.26898 L .60914 1.26814 L F
.61235 1.3713 m .61056 1.06884 L .61302 .75253 L 0 .548 .225 r
F
.61056 1.06884 m .60953 .89443 L .61131 .82206 L F
.61056 1.06884 m .61131 .82206 L .61302 .75253 L F
.61309 .69253 m .61314 .6932 L .61335 1.00527 L F
.61332 1.00629 m .61335 1.00527 L .61359 1.37094 L F
.61309 .69253 m .61335 1.00527 L .61332 1.00629 L F
.61034 1.17534 m .60268 .56434 L .60651 .61103 L F
.60984 1.17556 m .60268 .56434 L .61034 1.17534 L F
.6111 1.08724 m .61335 1.00527 L .60764 .96891 L 0 .654 .228 r
F
.60367 .92708 m .60361 .92304 L .6036 .92288 L 0 0 .043 r
F
.60452 1.04464 m .59998 .57033 L .60606 1.02918 L 0 .928 .09 r
F
.61091 1.37345 m .60441 1.04124 L .60387 1.01178 L 0 1 .169 r
F
.60441 1.04124 m .60388 1.01425 L .60387 1.01271 L F
.60441 1.04124 m .60387 1.01271 L .60387 1.01178 L F
.60445 1.04248 m .60441 1.04124 L .60838 1.24421 L F
.60441 1.04124 m .59993 .57328 L .60444 1.0421 L 0 .928 .09 r
F
.60442 1.04078 m .60441 1.04124 L .60445 1.04248 L 0 1 .169 r
F
.60492 1.0563 m .60454 1.04506 L .60838 1.24421 L F
.60498 1.05681 m .60574 1.09452 L .60508 1.06266 L F
.60498 1.05681 m .60479 1.04657 L .60574 1.09452 L F
.60452 1.04464 m .60606 1.02918 L .60516 1.06358 L 0 .928 .09 r
F
.60446 1.04271 m .59998 .57033 L .60452 1.04464 L F
.60444 1.0421 m .59993 .57328 L .60446 1.04271 L F
.60444 1.03981 m .60442 1.04078 L .60445 1.04248 L 0 1 .169 r
F
.60454 1.04506 m .60445 1.04248 L .60838 1.24421 L F
.60444 1.03981 m .60445 1.04248 L .60454 1.04506 L F
.60448 1.04507 m .60452 1.04464 L .60508 1.06667 L 0 .928 .09 r
F
.60762 1.15181 m .60762 1.15182 L .60773 1.15791 L 0 0 .043 r
F
.60773 1.1579 m .60773 1.15791 L .60816 1.18223 L F
.60811 1.21374 m .60812 1.21381 L .60887 1.25191 L 0 1 .169 r
F
.60878 1.20736 m .60682 1.11292 L .60838 1.24421 L F
.60516 1.06358 m .60606 1.02918 L .6074 1.13012 L 0 .928 .09 r
F
.60446 1.04271 m .60283 .87399 L .60288 .87566 L F
.60195 .82934 m .60104 .77783 L .60195 .82931 L 0 0 .043 r
F
.60104 .77783 m .60104 .77802 L .60195 .82931 L F
.60304 .96464 m .60031 .6494 L .6031 .96758 L 0 .928 .09 r
F
.60031 .6494 m .60029 .64538 L .6031 .96758 L F
.60178 .89409 m .60132 .84745 L .60206 .90945 L F
.60206 .90945 m .60132 .84745 L .60207 .91033 L F
.60113 .78352 m .60112 .78302 L .60112 .78301 L 0 .727 .225 r
F
.60113 .7835 m .60112 .78302 L .60113 .78352 L F
.60154 .81397 m .60119 .7934 L .60112 .78345 L 0 1 .169 r
F
.60304 .96464 m .60132 .84745 L .60031 .6494 L 0 .928 .09 r
F
.60207 .91033 m .60132 .84745 L .60304 .96464 L F
.6031 .96758 m .59991 .60169 L .60441 1.04124 L F
.59991 .60169 m .59993 .57328 L .60441 1.04124 L F
.60178 .8938 m .60132 .84745 L .60179 .89474 L F
.60682 1.11292 m .59916 .744 L .60492 1.0563 L 0 1 .169 r
F
.60508 1.06266 m .60574 1.09452 L .60584 1.09998 L F
.60584 1.09998 m .60574 1.09452 L .60648 1.13166 L F
.60584 1.09998 m .60648 1.13166 L .60584 1.10033 L F
.60682 1.11292 m .60492 1.0563 L .60838 1.24421 L F
.60508 1.06667 m .60516 1.06358 L .60791 1.16876 L 0 .928 .09 r
F
.59358 .4795 m .59331 .43515 L .59355 .4742 L 0 .93 .212 r
F
.59358 .4795 m .59333 .43861 L .59333 .43854 L F
.59359 .47972 m .59333 .43861 L .59358 .4795 L F
.59352 .46994 m .59329 .43419 L .59352 .46983 L F
.59311 .45298 m .59351 .48085 L .59365 .48805 L 0 1 .169 r
F
.59311 .45298 m .59365 .48805 L .59356 .47658 L F
.59368 .49486 m .59359 .48017 L .59368 .49493 L 0 .93 .212 r
F
.59359 .48017 m .59333 .43861 L .59359 .47972 L F
.59359 .48017 m .59359 .47972 L .59368 .49493 L F
.5994 .77501 m .60177 .89327 L .60166 .88871 L 0 1 .169 r
F
.59468 .54026 m .59483 .53027 L .59477 .52618 L 0 .93 .212 r
F
.59549 .57755 m .59634 .61902 L .59603 .60445 L 0 1 .169 r
F
.59623 .61391 m .59632 .61488 L .59487 .54939 L 0 .93 .212 r
F
.59433 .59426 m .5981 1.18492 L .59632 .61488 L F
.5981 1.18492 m .59812 1.17911 L .59632 .61488 L F
.59633 .61951 m .59635 .61944 L .59943 .77522 L 0 1 .169 r
F
.59621 .61343 m .59634 .61902 L .59635 .61944 L F
.59621 .61343 m .59635 .61944 L .59633 .61951 L F
.59622 .61338 m .59634 .61902 L .59621 .61343 L F
.59896 .75967 m .59592 .60314 L .59912 .76101 L F
.59592 .60314 m .5956 .58683 L .59593 .60305 L F
.59592 .60314 m .59593 .60305 L .59912 .76101 L F
.5956 .58683 m .59561 .5866 L .59912 .76101 L F
.59494 .55326 m .59495 .55323 L .59538 .57463 L F
.59542 .57702 m .59542 .577 L .59548 .57976 L F
.59548 .57978 m .59548 .57976 L .59912 .76101 L F
.59542 .57702 m .59548 .57976 L .59548 .57978 L F
.59538 .57463 m .5958 .59345 L .59912 .76101 L F
.59488 .54977 m .59539 .57433 L .59538 .57463 L F
.59539 .57433 m .5958 .59345 L .59538 .57463 L F
.5958 .59345 m .59943 .77522 L .5994 .77501 L F
.59603 .60445 m .59943 .77522 L .5958 .59345 L F
.5994 .77501 m .59943 .77522 L .60158 .88357 L F
.5994 .77501 m .60158 .88357 L .60159 .88418 L F
.59896 .75967 m .59912 .76101 L .60031 .82096 L F
.59896 .75967 m .60031 .82096 L .60019 .8209 L F
.59916 .744 m .59567 .57621 L .60012 .81613 L F
.59567 .57621 m .59551 .57605 L .60012 .81613 L F
.59467 .65724 m .59368 .49493 L .59368 .49587 L 0 .93 .212 r
F
.59467 .65724 m .59368 .49587 L .59368 .49589 L F
.59467 .65724 m .59368 .49486 L .59368 .49493 L F
.59814 1.20354 m .59764 1.17319 L .59815 1.19915 L 0 .789 .222 r
F
.59764 1.17319 m .59771 1.17134 L .59816 1.19466 L F
.59764 1.17319 m .59816 1.19466 L .59815 1.19915 L F
.59831 1.22536 m .5983 1.21699 L .59803 1.17474 L 0 .93 .212 r
F
.59809 1.1906 m .59803 1.17474 L .59443 .61984 L F
.59831 1.22536 m .59803 1.17474 L .59809 1.1906 L F
.59831 1.22536 m .59855 1.25604 L .5983 1.21699 L F
.59801 1.20591 m .59695 1.1311 L .59814 1.20354 L 0 .789 .222 r
F
.6003 .73001 m .60022 .72256 L .6002 .72397 L 0 0 .043 r
F
.60132 .84745 m .59986 .70197 L .60082 .74913 L 0 .928 .09 r
F
.59329 .43417 m .59293 .37454 L .59293 .3745 L 0 .93 .212 r
F
.59329 .43419 m .59293 .37454 L .59329 .43417 L F
.59329 .43419 m .59331 .43515 L .59293 .37454 L F
.59282 .3706 m .59297 .39344 L .59291 .37277 L F
.59308 .40927 m .59087 .29621 L .59096 .30282 L 0 1 .169 r
F
.59308 .40904 m .59087 .29621 L .59308 .40927 L F
.59299 .40315 m .59087 .29621 L .59299 .40477 L F
.59312 .41314 m .59333 .44439 L .59322 .42551 L 0 .93 .212 r
F
.59311 .41343 m .59333 .44439 L .59312 .41314 L F
.59297 .39344 m .59311 .41343 L .59312 .41314 L F
.59297 .39344 m .59322 .42551 L .59291 .37277 L F
.59299 .40315 m .59299 .40477 L .59308 .40904 L 0 1 .169 r
F
.59333 .44439 m .59351 .46971 L .59331 .43588 L 0 .93 .212 r
F
.59322 .42551 m .59331 .43588 L .59291 .37277 L F
.59333 .44439 m .59331 .43588 L .59322 .42551 L F
.59087 .29621 m .59297 .39344 L .59049 .27398 L 0 1 .169 r
F
.59255 .36564 m .59297 .39344 L .59219 .27347 L 0 .93 .212 r
F
.59297 .39344 m .59657 .56091 L .59293 .3889 L 0 1 .169 r
F
.59297 .39344 m .59282 .38385 L .59049 .27398 L F
.59152 .32224 m .59282 .38385 L .59219 .34151 L F
.6074 1.13012 m .60701 1.10033 L .60761 1.13641 L 0 .928 .09 r
F
.60701 1.10033 m .59998 .57033 L .60706 1.09535 L F
.60701 1.10033 m .60706 1.09535 L .60761 1.13641 L F
.60761 1.13641 m .59998 .57033 L .60786 1.12553 L F
.60788 1.14436 m .60786 1.12553 L .6083 1.15676 L F
.60761 1.13641 m .60786 1.12553 L .60788 1.14436 L F
.61017 1.23665 m .60268 .56434 L .61103 1.27698 L 0 .548 .225 r
F
.6111 1.08724 m .6077 1.01188 L .61043 1.11181 L 0 .654 .228 r
F
.60959 1.20953 m .60258 .56314 L .61014 1.23524 L 0 .548 .225 r
F
.59998 .57033 m .6006 .53903 L .60782 1.09855 L 0 .928 .09 r
F
.59362 .48581 m .59364 .48658 L .59333 .43861 L 0 .93 .212 r
F
.60706 1.11986 m .60081 .79858 L .59337 .44996 L 0 1 .169 r
F
.61221 1.3721 m .6074 1.13008 L .60706 1.11986 L F
.6074 1.13008 m .60081 .79858 L .60706 1.11986 L F
.60786 1.12553 m .60782 1.09855 L .60874 1.16989 L 0 .928 .09 r
F
.61221 1.3721 m .59337 .44996 L .59342 .45607 L 0 1 .169 r
F
.6083 1.15676 m .60874 1.16989 L .61134 1.37139 L 0 .928 .09 r
F
.60786 1.12553 m .60874 1.16989 L .6083 1.15676 L F
.59998 .57033 m .60782 1.09855 L .60786 1.12553 L F
.61134 1.37139 m .60117 .58392 L .60323 .62355 L 0 .548 .225 r
F
.6077 1.01188 m .605 .95207 L .60773 1.03232 L 0 .654 .228 r
F
.6077 1.01188 m .60773 1.03232 L .61043 1.11181 L F
.605 .95207 m .60892 .92019 L .60564 .63882 L F
.60953 .89443 m .60749 .55027 L .61302 .75253 L 0 .548 .225 r
F
.60892 .92019 m .61419 .87738 L .61048 .7739 L 0 .654 .228 r
F
.60892 .92019 m .61048 .7739 L .60564 .63882 L F
.60742 1.13068 m .59087 .29621 L .6074 1.13008 L 0 1 .169 r
F
.60283 .87399 m .59993 .57328 L .60288 .87566 L 0 .928 .09 r
F
.60288 .87566 m .59993 .57328 L .60003 .57488 L F
.60109 .8116 m .605 .95207 L .59087 .29621 L 0 1 .169 r
F
.59049 .27398 m .59152 .32224 L .59137 .28686 L F
.59115 .27213 m .59251 .35528 L .59152 .27261 L 0 .93 .212 r
F
.59206 .33277 m .59251 .35528 L .59115 .27213 L F
.59115 .27213 m .59137 .28686 L .59131 .27169 L 0 1 .169 r
F
.59049 .27398 m .59137 .28686 L .59115 .27213 L F
.59206 .33277 m .59255 .36564 L .59251 .35528 L 0 .93 .212 r
F
.59152 .27261 m .59251 .35528 L .59219 .27347 L F
.59219 .27347 m .59282 .3706 L .59229 .27525 L F
.59282 .3706 m .59291 .37277 L .59229 .27525 L F
.59152 .32224 m .59301 .36496 L .59131 .27169 L 0 1 .169 r
F
.59084 .27173 m .59206 .33277 L .59115 .27213 L 0 .93 .212 r
F
.59342 .45607 m .59255 .41378 L .59355 .47402 L 0 1 .169 r
F
.59255 .41378 m .58971 .27525 L .59311 .45298 L F
.592 .40212 m .59112 .35894 L .5912 .36098 L F
.59308 .40927 m .5904 .27425 L .59337 .44996 L F
.59342 .45607 m .59337 .44996 L .59128 .3521 L F
.59311 .45298 m .59077 .34064 L .59351 .48085 L F
.59106 .28407 m .59353 .61509 L .59255 .36564 L 0 .93 .212 r
F
.59094 .28522 m .59353 .61509 L .59106 .28407 L F
.59297 .39344 m .59293 .3889 L .59282 .38385 L 0 1 .169 r
F
.59355 .47402 m .59311 .45298 L .59356 .47658 L F
.59353 .61509 m .59297 .39344 L .59255 .36564 L 0 .93 .212 r
F
.59219 .34151 m .59293 .3889 L .59266 .35492 L 0 1 .169 r
F
.59282 .38385 m .59293 .3889 L .59219 .34151 L F
.59266 .35492 m .59657 .56091 L .59301 .36496 L F
.59293 .3745 m .59293 .37454 L .59291 .37277 L 0 .93 .212 r
F
.59293 .3889 m .59657 .56091 L .59266 .35492 L 0 1 .169 r
F
.59096 .30282 m .59087 .29621 L .5904 .27425 L F
.59071 .27174 m .59814 1.20364 L .59084 .27173 L 0 .93 .212 r
F
.59814 1.20364 m .59814 1.20354 L .59084 .27173 L F
.58946 .37285 m .58951 .37194 L .58996 .32901 L 0 1 .183 r
F
.58976 .3239 m .58723 .56896 L .58992 .32806 L F
.5895 .33087 m .58723 .56896 L .58976 .3239 L F
.58929 .32896 m .58723 .56896 L .5896 .31993 L F
.5904 .27425 m .59087 .29621 L .59049 .27398 L 0 1 .169 r
F
.59128 .3521 m .5904 .27425 L .58971 .27525 L F
.59077 .34064 m .58971 .27525 L .58942 .27567 L F
.59077 .34064 m .58942 .27567 L .59117 .3647 L F
.59056 .28121 m .58775 .54224 L .59071 .53307 L 0 1 .183 r
F
.59055 .27163 m .59045 .28102 L .59056 .28121 L F
.59045 .28102 m .58775 .54224 L .59056 .28121 L F
.58743 .26969 m .58762 .27602 L .58584 .26844 L 0 .824 .212 r
F
.5896 .31993 m .5895 .33087 L .58976 .3239 L 0 1 .183 r
F
.58941 .3149 m .58929 .32896 L .5896 .31993 L F
.58946 .30834 m .58941 .3149 L .5899 .29641 L F
.59084 .27173 m .59094 .28522 L .59106 .28407 L 0 .93 .212 r
F
.59084 .27173 m .59255 .36564 L .59206 .33277 L F
.58992 .32806 m .58996 .32901 L .59055 .27163 L 0 1 .183 r
F
.58941 .3149 m .58992 .32806 L .59055 .27163 L F
.59657 .56091 m .59713 .56102 L .59343 .37711 L 0 1 .169 r
F
.59657 .56091 m .59343 .37711 L .59304 .36595 L F
.59301 .36496 m .59156 .28392 L .59149 .28169 L F
.59657 .56091 m .59304 .36595 L .59301 .36496 L F
.59304 .36595 m .59156 .28392 L .59301 .36496 L F
.59299 .40315 m .59308 .40904 L .59307 .40742 L F
.59304 .42292 m .59317 .42515 L .59297 .39344 L 0 .93 .212 r
F
.59353 .61509 m .59317 .42515 L .59304 .42292 L F
.59353 .61509 m .59443 .61984 L .59317 .42515 L F
.59322 .41479 m .59299 .40315 L .59327 .4188 L 0 1 .169 r
F
.59311 .41343 m .59366 .50075 L .59333 .44439 L 0 .93 .212 r
F
.5931 .4137 m .59366 .50075 L .59311 .41343 L F
.59262 .41962 m .59273 .42159 L .59257 .41879 L 0 1 .156 r
F
.6074 1.13008 m .59322 .41479 L .59327 .4188 L 0 1 .169 r
F
.59333 .43854 m .59333 .43861 L .59331 .43515 L 0 .93 .212 r
F
.60081 .79858 m .59308 .40927 L .59337 .44996 L 0 1 .169 r
F
.59987 .6878 m .59553 .44754 L .59986 .69767 L 0 0 .043 r
F
.59969 .69209 m .59582 .47011 L .59971 .69982 L F
.58936 .37755 m .58906 .40764 L .58902 .36064 L 0 1 .183 r
F
.59567 .57621 m .59355 .47402 L .59551 .57605 L 0 1 .169 r
F
.59494 .55326 m .59538 .57463 L .59537 .57465 L F
.5956 .58683 m .59494 .55326 L .59561 .5866 L F
.59494 .55326 m .59488 .54977 L .59495 .55323 L F
.59603 .60445 m .59622 .61338 L .59621 .61343 L F
.59355 .47402 m .59356 .47658 L .60012 .81613 L F
.59537 .57465 m .59538 .57463 L .59542 .577 L F
.59537 .57465 m .59542 .577 L .59542 .57702 L F
.60067 .84752 m .59896 .75967 L .601 .86109 L F
.59433 .59426 m .59486 .54915 L .59468 .54026 L 0 .93 .212 r
F
.59677 .64719 m .59417 .51655 L .59488 .54977 L 0 1 .169 r
F
.59368 .49335 m .59433 .59426 L .59404 .5102 L 0 .93 .212 r
F
.59404 .5102 m .59408 .52082 L .59412 .51402 L F
.59653 .63871 m .59368 .49335 L .59677 .64719 L 0 1 .169 r
F
.59368 .49335 m .59417 .51655 L .59677 .64719 L F
.6008 .85381 m .5999 .81013 L .59995 .81055 L F
.59679 .64813 m .59653 .63871 L .59677 .64719 L F
.59995 .81055 m .59672 .64814 L .59679 .64813 L F
.59672 .64814 m .59653 .63871 L .59679 .64813 L F
.59503 .55255 m .59487 .55091 L .59677 .64809 L F
.5999 .81013 m .59653 .63871 L .59995 .81055 L F
.59685 .64801 m .59677 .64809 L .60029 .82893 L F
.59503 .55255 m .59677 .64809 L .59685 .64801 L F
.59814 1.20199 m .59815 1.19963 L .59443 .61984 L 0 .93 .212 r
F
.59353 .61509 m .59814 1.20354 L .59443 .61984 L F
.59814 1.20354 m .59814 1.20199 L .59443 .61984 L F
.59503 .55255 m .60029 .82893 L .60016 .81956 L 0 1 .169 r
F
.6022 .92411 m .60141 .88299 L .60223 .92242 L F
.60219 .92526 m .60141 .88299 L .6022 .92411 L F
.60219 .92526 m .60067 .84752 L .60141 .88299 L F
.60067 .84752 m .601 .86109 L .60223 .92242 L F
.60387 1.01178 m .60062 .84665 L .6008 .85381 L F
.60057 .84459 m .60062 .84665 L .60387 1.01178 L F
.60328 .98349 m .60325 .98068 L .60387 1.01178 L F
.60388 1.01425 m .60328 .98349 L .60387 1.01178 L F
.60212 .92408 m .60208 .92124 L .60387 1.01178 L F
.60019 .8209 m .60163 .88793 L .60117 .86909 L F
.60019 .8209 m .60031 .82096 L .60162 .88681 L F
.60019 .8209 m .60162 .88681 L .60163 .88793 L F
.60051 .84211 m .60057 .84459 L .60387 1.01178 L F
.60019 .8209 m .60117 .86909 L .60112 .86713 L F
.59503 .55255 m .60442 1.04078 L .60444 1.03981 L F
.59916 .744 m .59342 .45607 L .59355 .47402 L F
.59884 .72068 m .59342 .45607 L .59916 .744 L F
.59366 .49164 m .59364 .48658 L .59362 .48581 L 0 .93 .212 r
F
.59467 .65724 m .59367 .49085 L .59366 .49164 L F
.59367 .49085 m .59364 .48658 L .59366 .49164 L F
.59913 .77137 m .59914 .77148 L .60062 .84665 L 0 1 .169 r
F
.59913 .77137 m .60062 .84665 L .60057 .84459 L F
.59913 .77137 m .59653 .63871 L .59914 .77148 L F
.59544 .58081 m .59539 .58062 L .60037 .83472 L F
.5999 .61709 m .59993 .57328 L .59893 .55741 L 0 0 .043 r
F
.60082 .74913 m .59987 .67715 L .60031 .6494 L 0 .928 .09 r
F
.59657 .56091 m .605 .95207 L .59713 .56102 L 0 1 .169 r
F
.59639 .57348 m .60037 .60018 L .60058 .60615 L 0 .858 .083 r
F
.59365 .48805 m .59368 .49335 L .59539 .58062 L 0 1 .169 r
F
.59365 .48805 m .59539 .58062 L .59544 .58081 L F
.60051 .84211 m .59913 .77137 L .60057 .84459 L F
.59365 .48805 m .60037 .83472 L .60031 .83071 L F
.60062 .84665 m .5999 .81013 L .6008 .85381 L F
.60325 .98089 m .60318 .97723 L .60325 .98068 L F
.60328 .98349 m .60318 .97723 L .60325 .98089 L F
.60328 .98349 m .60212 .92408 L .60318 .97723 L F
.60212 .92408 m .60051 .84211 L .60208 .92124 L F
.59365 .48805 m .60441 1.04124 L .60442 1.04078 L F
.59477 .56086 m .59625 .57127 L .59639 .57348 L 0 .858 .083 r
F
.59625 .57127 m .60037 .60018 L .59639 .57348 L F
.59366 .50075 m .59467 .65724 L .59368 .49589 L 0 .93 .212 r
F
.59096 .35035 m .59103 .35448 L .5912 .36285 L 0 1 .169 r
F
.59103 .35448 m .59135 .37394 L .5912 .36285 L F
.59077 .34064 m .59117 .3647 L .59135 .37394 L F
.59077 .34064 m .59135 .37394 L .59096 .35035 L F
.59771 1.17134 m .59695 1.1311 L .59788 1.17452 L 0 .789 .222 r
F
.59764 1.17319 m .59695 1.1311 L .59771 1.17134 L F
.59071 .27174 m .59071 .53307 L .59855 1.25604 L 0 .93 .212 r
F
.59295 .61029 m .59636 .59629 L .59655 .60528 L 0 .248 .155 r
F
.59655 .60528 m .59859 .59895 L .59832 .61425 L 0 .849 .145 r
F
.59636 .59629 m .59674 .59473 L .59655 .60528 L 0 .248 .155 r
F
.58896 .41698 m .58841 .47213 L .58862 .40669 L 0 1 .183 r
F
.58723 .56896 m .58709 .58501 L .58775 .54224 L F
.58709 .58501 m .58688 .61017 L .58731 .58501 L F
.58688 .61017 m .58604 .70724 L .58706 .60913 L F
.58688 .61017 m .58706 .60913 L .58731 .58501 L F
.58709 .58501 m .58604 .70724 L .58709 .58501 L F
.5797 .70334 m .58567 .58499 L .58509 .58498 L 0 1 .167 r
F
.58709 .58501 m .58709 .58501 L .58709 .58501 L 0 1 .183 r
F
.58709 .58501 m .58731 .58501 L .58775 .54224 L F
.58841 .47213 m .58833 .47959 L .5881 .46708 L F
.60031 .6494 m .59991 .60307 L .60029 .64538 L 0 .928 .09 r
F
.59991 .60307 m .59991 .60169 L .60029 .64538 L F
.5968 .58113 m .60058 .60615 L .59859 .59895 L 0 .858 .083 r
F
.59477 .56086 m .59639 .57348 L .5968 .58113 L F
.59639 .57348 m .60058 .60615 L .5968 .58113 L F
.59679 .59218 m .59859 .59895 L .59655 .60528 L 0 .849 .145 r
F
.58824 .48846 m .58748 .56426 L .58796 .48406 L 0 1 .183 r
F
.58748 .56426 m .58604 .70724 L .58728 .56332 L F
.58748 .56426 m .58728 .56332 L .58796 .48406 L F
.59753 .32804 m .59706 .27457 L .59761 .33126 L 0 .928 .09 r
F
.60167 .55783 m .59754 .27329 L .59635 .2735 L 0 .501 .225 r
F
.60262 .5613 m .59754 .27329 L .60167 .55783 L F
.60153 .55043 m .59635 .2735 L .6006 .53903 L F
.60196 .59896 m .6006 .53903 L .60323 .62355 L 0 .548 .225 r
F
.60117 .58392 m .6006 .53903 L .60196 .59896 L F
.59432 .27496 m .6006 .53903 L .5946 .27476 L 0 0 .043 r
F
.60323 .62355 m .6006 .53903 L .60258 .56314 L 0 .548 .225 r
F
.60199 .69577 m .60564 .63882 L .59954 .48738 L 0 .654 .228 r
F
.605 .95207 m .6055 .70806 L .60199 .69577 L F
.6055 .70806 m .60564 .63882 L .60199 .69577 L F
.59927 .5284 m .59955 .53448 L .59993 .57328 L 0 .928 .09 r
F
.59432 .27496 m .59993 .57328 L .59952 .49387 L 0 0 .043 r
F
.59906 .5434 m .6006 .57305 L .59927 .55098 L 0 1 .156 r
F
.6008 .5769 m .60136 .5876 L .60085 .5808 L F
.60136 .5876 m .6072 .7 L .60137 .59046 L F
.60136 .5876 m .60137 .59046 L .60085 .5808 L F
.60121 .62522 m .60147 .62592 L .60137 .62976 L 0 .771 .083 r
F
.6072 .7 m .60724 .70086 L .60112 .58577 L 0 1 .156 r
F
.60112 .58577 m .60112 .58577 L .60085 .58083 L F
.6072 .7 m .60112 .58577 L .60112 .58577 L F
.60112 .58576 m .60085 .58083 L .60085 .58082 L F
.6072 .7 m .60112 .58577 L .60112 .58576 L F
.60112 .58577 m .60085 .58083 L .60112 .58576 L F
.60037 .60018 m .60129 .60665 L .60058 .60615 L 0 .858 .083 r
F
.60072 .57838 m .6006 .57609 L .6006 .57607 L 0 1 .156 r
F
.60058 .60615 m .60133 .61205 L .6008 .61293 L 0 .858 .083 r
F
.6072 .7 m .60091 .5819 L .60091 .58188 L 0 1 .156 r
F
.60022 .59531 m .60119 .60141 L .60037 .60018 L 0 .858 .083 r
F
.60077 .58067 m .60724 .70086 L .60356 .6358 L 0 1 .156 r
F
.60075 .57986 m .60724 .70086 L .60077 .58067 L F
.60023 .56917 m .60724 .70086 L .6003 .57134 L F
.60462 .62125 m .60414 .60151 L .60564 .63882 L F
.59904 .54284 m .6072 .69993 L .59904 .54286 L F
.60612 .67914 m .60612 .67914 L .60109 .58224 L F
.60489 .65554 m .60109 .58224 L .60109 .58224 L F
.60553 .66776 m .60489 .65554 L .60489 .65554 L F
.60489 .65554 m .60109 .58224 L .60489 .65554 L F
.60553 .66776 m .60109 .58224 L .60553 .66776 L F
.60612 .67914 m .60489 .65554 L .60612 .67914 L F
.60489 .65554 m .60109 .58224 L .60489 .65554 L F
.60489 .65554 m .60489 .65554 L .60612 .67914 L F
.6072 .69993 m .60085 .57771 L .60085 .57771 L F
.60109 .58224 m .60062 .57329 L .60062 .57329 L F
.6072 .69993 m .60136 .5874 L .60136 .5874 L F
.6072 .69993 m .60564 .63882 L .60746 .70495 L F
.59904 .54284 m .60478 .62633 L .6072 .69993 L F
.60478 .62633 m .60564 .63882 L .6072 .69993 L F
.60749 .55027 m .60843 .47047 L .61302 .75253 L 0 .548 .225 r
F
.60557 .35062 m .61314 .6932 L .60665 .3778 L 0 .501 .225 r
F
.6032 .29109 m .60382 .31631 L .60557 .35062 L F
.60382 .31631 m .61314 .6932 L .60557 .35062 L F
.6159 .71081 m .60787 .40179 L .60787 .40178 L 0 .529 .227 r
F
.61144 .46866 m .61053 .45244 L .61156 .47213 L F
.60614 .27222 m .60845 .38374 L .60451 .27144 L 0 .974 .197 r
F
.60845 .38374 m .60887 .40381 L .60451 .27144 L F
.60451 .27144 m .60887 .40381 L .60388 .27114 L F
.60787 .40179 m .61252 .46953 L .61308 .48482 L 0 .919 .089 r
F
.6044 .26816 m .61053 .45244 L .61144 .46866 L 0 .529 .227 r
F
.60388 .27114 m .60887 .40381 L .60677 .3808 L 0 .974 .197 r
F
.60388 .27114 m .60677 .3808 L .6051 .32771 L F
.6032 .29109 m .60665 .3778 L .6066 .3755 L 0 .501 .225 r
F
.60388 .27114 m .6051 .32771 L .60329 .2702 L 0 .974 .197 r
F
.60367 .28214 m .6066 .3755 L .60439 .26816 L 0 .501 .225 r
F
.6032 .29109 m .6066 .3755 L .60367 .28214 L F
.60271 .27127 m .6032 .29109 L .60367 .28214 L F
.60271 .27127 m .60367 .28214 L .60329 .2702 L F
.60732 .62103 m .60271 .27127 L .59972 .2729 L F
.61003 .65457 m .60271 .27127 L .60732 .62103 L F
.61309 .69253 m .61303 .68938 L .61309 .69144 L 0 .548 .225 r
F
.61003 .65457 m .61314 .6932 L .60271 .27127 L 0 .501 .225 r
F
.60329 .2702 m .60608 .37326 L .60252 .26898 L 0 .974 .197 r
F
.6051 .32771 m .60608 .37326 L .60329 .2702 L F
.60668 .37909 m .60677 .3808 L .60665 .3778 L 0 .501 .225 r
F
.60665 .3778 m .60677 .3808 L .60439 .26816 L F
.6051 .32771 m .60677 .3808 L .60608 .37326 L 0 .974 .197 r
F
.60329 .2702 m .60367 .28214 L .60439 .26816 L 0 .501 .225 r
F
.6044 .26816 m .60787 .40179 L .61053 .45244 L 0 .529 .227 r
F
.60787 .40179 m .61495 .67422 L .61156 .47213 L F
.6044 .26816 m .61156 .47213 L .6044 .26816 L F
.61156 .47213 m .61157 .47228 L .6044 .26816 L F
.61156 .47213 m .61495 .67422 L .61648 .61229 L F
.60746 .39818 m .60952 .43329 L .61157 .47228 L 0 .919 .089 r
F
.61427 .51422 m .61876 .59149 L .61589 .55037 L F
.61308 .48482 m .61252 .46953 L .61568 .52628 L F
.6105 .42957 m .61068 .43511 L .61047 .42277 L 0 .537 .227 r
F
.61068 .43511 m .61065 .42862 L .61047 .42277 L F
.60808 .27108 m .61568 .52618 L .60885 .27047 L 0 .196 .185 r
F
.61541 .28294 m .61431 .29222 L .61435 .28238 L 0 .978 .185 r
F
.61435 .28238 m .61431 .29222 L .614 .28196 L 0 1 .122 r
F
.614 .28196 m .61431 .29222 L .61396 .28187 L F
.62029 .27738 m .61 .28687 L .61288 .27574 L 0 .819 .215 r
F
.62132 .28604 m .61431 .29222 L .61541 .28294 L 0 .978 .185 r
F
.62196 .2884 m .62502 .34285 L .62137 .28695 L 0 0 .064 r
F
.62137 .28695 m .62502 .34285 L .62132 .28604 L F
.62132 .28604 m .62502 .34285 L .61431 .29222 L 0 .978 .185 r
F
.61431 .29222 m .62421 .49575 L .61837 .40533 L F
.62029 .27738 m .62563 .4857 L .61 .28687 L 0 .819 .215 r
F
.61288 .27574 m .61 .28687 L .61017 .27511 L F
.61017 .27511 m .61 .28687 L .60992 .27506 L F
.60992 .27506 m .61 .28687 L .60968 .27492 L 0 1 .188 r
F
.60968 .27492 m .61 .28687 L .60948 .2748 L F
.61 .28687 m .6222 .6643 L .61568 .52623 L 0 .819 .215 r
F
.61 .28687 m .62657 .64594 L .6222 .6643 L F
.61 .28687 m .62563 .4857 L .62657 .64594 L F
.60885 .27047 m .6222 .66427 L .61028 .26934 L 0 .196 .185 r
F
.60885 .27047 m .61568 .52618 L .6222 .66427 L F
.61494 .33842 m .62723 .61233 L .63197 .63653 L 0 .36 .222 r
F
.61493 .33823 m .61495 .33854 L .61494 .33842 L F
.61495 .33854 m .62723 .61233 L .61494 .33842 L F
.61146 .2675 m .61304 .31507 L .61492 .33785 L 0 .196 .185 r
F
.61304 .31507 m .615 .34522 L .61492 .33785 L F
.63703 .63408 m .63893 .67203 L .63961 .65021 L 0 .385 .231 r
F
.61494 .33836 m .63197 .63653 L .62716 .5019 L 0 .36 .222 r
F
.63197 .63653 m .63228 .63638 L .62716 .5019 L F
.61494 .33842 m .63293 .65322 L .61494 .33836 L F
.63767 .69662 m .6445 .76875 L .6443 .76884 L 0 .556 .212 r
F
.6399 .75538 m .6443 .76884 L .64047 .77039 L F
.63889 .73251 m .64 .72734 L .64058 .73127 L 0 .659 .2 r
F
.63767 .69662 m .6443 .76884 L .6399 .75538 L 0 .556 .212 r
F
.63947 .7122 m .64538 .75515 L .64504 .76041 L F
.63767 .69662 m .64538 .75515 L .63947 .7122 L F
.64173 .73949 m .64504 .76041 L .6445 .76875 L F
.63767 .69662 m .64504 .76041 L .64173 .73949 L F
.64063 .70926 m .64013 .76364 L .6445 .76874 L 0 .376 .227 r
F
.62716 .5019 m .635 .66005 L .64063 .70926 L F
.63841 .73286 m .63872 .73149 L .63889 .73251 L 0 .659 .2 r
F
.62784 .71132 m .63841 .73286 L .62784 .71169 L 0 .625 .212 r
F
.62658 .64684 m .63767 .69662 L .63441 .77221 L 0 .658 .219 r
F
.635 .66005 m .64013 .76364 L .64063 .70926 L 0 .376 .227 r
F
.63841 .73286 m .63857 .73382 L .63853 .73507 L 0 .659 .2 r
F
.62716 .5019 m .63293 .65322 L .64046 .77038 L 0 .376 .227 r
F
.6287 .58202 m .63474 .63519 L .63703 .63408 L 0 .385 .231 r
F
.63474 .63519 m .63893 .67203 L .63703 .63408 L F
.63197 .63653 m .63293 .65322 L .63228 .63638 L 0 .36 .222 r
F
.61493 .33823 m .61494 .33842 L .61494 .33836 L F
.6154 .38627 m .61575 .38955 L .61492 .33785 L 0 .196 .185 r
F
.61575 .38955 m .61619 .39381 L .61496 .33933 L F
.61575 .38955 m .61496 .33933 L .61492 .33785 L F
.61619 .39381 m .61636 .39547 L .61499 .3406 L F
.61619 .39381 m .61499 .3406 L .61492 .33785 L F
.61494 .33821 m .61654 .35963 L .61903 .32398 L 0 .36 .222 r
F
.61654 .35963 m .62238 .39735 L .61903 .32398 L F
.61415 .26165 m .61903 .32398 L .61536 .26028 L F
.61832 .47406 m .61837 .47226 L .61642 .39602 L 0 .196 .185 r
F
.61636 .39547 m .61642 .39602 L .61492 .33785 L F
.61832 .47406 m .61642 .39602 L .61636 .39547 L F
.6214 .44404 m .62149 .45729 L .62159 .44694 L 0 0 .114 r
F
.61304 .31507 m .6154 .38627 L .615 .34522 L 0 .196 .185 r
F
.62716 .5019 m .6306 .45697 L .62624 .42024 L 0 .376 .227 r
F
.62716 .5019 m .63788 .56712 L .6306 .45697 L F
.62752 .47865 m .63104 .49752 L .62713 .46513 L 0 .036 .14 r
F
.62779 .48811 m .63013 .49489 L .62752 .47865 L F
.63013 .49489 m .63104 .49752 L .62752 .47865 L F
.61837 .47225 m .61855 .46647 L .61563 .36296 L 0 .196 .185 r
F
.61558 .36251 m .61563 .36296 L .61523 .34871 L F
.61837 .47225 m .61563 .36296 L .61558 .36251 L F
.62693 .46468 m .62713 .46513 L .63085 .49588 L 0 .545 0 r
F
.62693 .46468 m .63085 .49588 L .63079 .49552 L F
.61837 .47225 m .61523 .34871 L .6152 .34842 L 0 .196 .185 r
F
.61837 .47225 m .61499 .34016 L .61499 .34014 L F
.62129 .56355 m .62127 .56044 L .61564 .36305 L F
.61563 .36296 m .61564 .36305 L .61497 .33943 L F
.62129 .56355 m .61564 .36305 L .61563 .36296 L F
.61877 .4876 m .61497 .33943 L .61492 .33785 L F
.63438 .77378 m .63443 .77275 L .6344 .77276 L 0 .689 .233 r
F
.6344 .77276 m .63443 .77288 L .63441 .77282 L 0 .625 .212 r
F
.62784 .71169 m .63442 .77281 L .6344 .77276 L F
.63442 .77281 m .63443 .77288 L .6344 .77276 L F
.6344 .77276 m .63432 .77298 L .63033 .77314 L F
.63037 .77422 m .63419 .77239 L .63037 .77308 L 0 .689 .233 r
F
.63419 .77239 m .63441 .77228 L .63416 .77233 L F
.63033 .77314 m .63435 .7723 L .63036 .77304 L 0 1 .491 r
F
.63419 .77239 m .63416 .77233 L .63037 .77308 L 0 .689 .233 r
F
.62658 .64684 m .63441 .77221 L .63432 .77223 L 0 .658 .219 r
F
.62961 .74777 m .63432 .77223 L .63036 .77299 L F
.62658 .64684 m .63432 .77223 L .62961 .74777 L F
.62578 .57999 m .63006 .76436 L .63441 .77219 L 0 .36 .222 r
F
.62059 .49778 m .63006 .76436 L .62578 .57999 L F
.61877 .4876 m .62129 .56355 L .61855 .46647 L 0 .196 .185 r
F
.63197 .63653 m .62996 .67313 L .63293 .65322 L 0 .36 .222 r
F
.62723 .61233 m .62996 .67313 L .63197 .63653 L F
.62996 .67313 m .63298 .74048 L .63317 .67274 L F
.63298 .74048 m .63441 .77219 L .63399 .73847 L F
.63298 .74048 m .63399 .73847 L .63317 .67274 L F
.62996 .67313 m .63317 .67274 L .63293 .65322 L F
.61028 .26934 m .61958 .57725 L .62124 .56392 L 0 .196 .185 r
F
.61028 .26934 m .62178 .57852 L .61146 .2675 L F
.61499 .34014 m .61499 .34016 L .61497 .33943 L F
.62129 .56355 m .62178 .57852 L .62127 .56044 L F
.62124 .56392 m .621 .62445 L .62178 .57852 L F
.621 .62445 m .62189 .60131 L .62178 .57852 L F
.62779 .71123 m .62784 .71132 L .62784 .71169 L 0 .625 .212 r
F
.62779 .71123 m .62783 .71081 L .62783 .71112 L F
.62674 .73908 m .62641 .72296 L .62781 .71212 L 0 .586 .223 r
F
.61493 .33823 m .6218 .5794 L .63036 .77297 L 0 .36 .222 r
F
.61731 .47273 m .63236 .73675 L .63363 .68903 L 0 .371 .225 r
F
.63236 .73675 m .63434 .77151 L .63404 .73353 L F
.63434 .77151 m .63439 .77153 L .63404 .73353 L F
.6344 .77276 m .63444 .77265 L .63441 .77228 L 0 .689 .233 r
F
.6344 .77262 m .63442 .77271 L .63442 .77248 L 0 .371 .225 r
F
.63441 .77248 m .63441 .77226 L .63442 .77248 L 0 .306 .198 r
F
.63006 .76436 m .63036 .77297 L .63411 .77225 L 0 .36 .222 r
F
.63006 .76436 m .63411 .77225 L .63441 .77219 L F
.63428 .77151 m .63383 .77149 L .63433 .77213 L 0 .389 .233 r
F
.63434 .77151 m .63433 .77213 L .63441 .77223 L F
.61731 .47273 m .63025 .77133 L .63434 .77151 L 0 .371 .225 r
F
.63309 .75835 m .63433 .77213 L .63434 .77151 L 0 .389 .233 r
F
.62982 .90761 m .6322 .98609 L .63155 .9121 L 0 .644 .229 r
F
.63077 .96879 m .6322 .98609 L .62982 .90761 L F
.62559 1.20354 m .63175 1.01449 L .62964 .89581 L 0 1 .192 r
F
.62869 1.31524 m .62871 1.31958 L .63052 1.37585 L 0 .646 .228 r
F
.63052 1.37585 m .62871 1.31958 L .62879 1.33773 L F
.62822 1.21732 m .62838 1.24245 L .62891 1.19747 L 0 1 .192 r
F
.62769 1.23277 m .62838 1.24245 L .62811 1.19894 L F
.62891 1.19747 m .62769 1.23277 L .63065 1.3758 L 0 .644 .229 r
F
.62811 1.19894 m .62822 1.21732 L .62891 1.19747 L 0 1 .192 r
F
.62869 1.10838 m .63113 1.11109 L .63175 1.01449 L F
.63065 1.3758 m .6285 1.27211 L .62869 1.31524 L 0 .646 .228 r
F
.63027 1.17811 m .63145 1.18457 L .63096 1.13832 L 0 1 .192 r
F
.63145 1.18457 m .63258 1.19075 L .63096 1.13832 L F
.62969 1.17495 m .63027 1.17811 L .63096 1.13832 L F
.62811 1.19894 m .63258 1.19075 L .62849 1.16837 L F
.63313 1.27188 m .63105 1.24481 L .63291 1.22224 L 0 .629 .179 r
F
.63096 1.13832 m .62891 1.19747 L .63349 1.37577 L 0 .644 .229 r
F
.62849 1.16837 m .62969 1.17495 L .63096 1.13832 L 0 1 .192 r
F
.62849 1.16837 m .63096 1.13832 L .62869 1.10838 L F
.63096 1.13832 m .63113 1.11109 L .62869 1.10838 L F
.62559 1.20354 m .62811 1.19894 L .62849 1.16837 L F
.62559 1.20354 m .62849 1.16837 L .62869 1.10838 L F
.62559 1.20354 m .62964 .89581 L .62629 .8916 L F
.63178 1.37266 m .62629 .89168 L .63001 1.37253 L 0 .759 .227 r
F
.63113 1.11109 m .63303 1.1132 L .63175 1.01449 L 0 1 .192 r
F
.63303 1.1132 m .6353 1.08553 L .63175 1.01449 L F
.63885 1.20264 m .63622 1.18425 L .63734 1.16832 L 0 .565 .151 r
F
.63682 1.20972 m .6375 1.10807 L .63175 1.01449 L 0 .644 .229 r
F
.63885 1.20264 m .63734 1.16832 L .64144 1.16535 L 0 .565 .151 r
F
.64111 1.37542 m .63752 1.10938 L .63682 1.20972 L 0 .644 .229 r
F
.63752 1.10938 m .6375 1.10807 L .63682 1.20972 L F
.63175 1.01449 m .6375 1.10807 L .63172 1.01219 L F
.6322 .98609 m .63473 1.01661 L .63164 .91513 L F
.6322 .98609 m .63164 .91513 L .63155 .9121 L F
.63157 .91304 m .63751 1.10847 L .63753 1.10865 L 0 .689 .233 r
F
.65476 1.07171 m .64202 1.07288 L .65086 1.07369 L 0 .781 .321 r
F
.64357 1.0758 m .6382 1.068 L .64481 1.0713 L 0 .097 0 r
F
.64086 1.09358 m .638 1.08052 L .64404 1.08499 L 0 .298 .053 r
F
.64291 1.11829 m .6385 1.10087 L .64188 1.09983 L 0 .386 .089 r
F
.64291 1.11829 m .63893 1.10876 L .6385 1.10087 L F
.64204 1.15331 m .64304 1.12701 L .64852 1.13368 L 0 .49 .115 r
F
.64204 1.15331 m .63921 1.12906 L .64304 1.12701 L F
.64204 1.15331 m .63877 1.1403 L .63921 1.12906 L F
.64204 1.15331 m .64852 1.13368 L .65202 1.14468 L F
.64204 1.15331 m .65202 1.14468 L .65162 1.15601 L F
.64204 1.15331 m .65162 1.15601 L .64756 1.16007 L F
.63885 1.20264 m .64144 1.16535 L .64661 1.17472 L 0 .565 .151 r
F
.63885 1.20264 m .64661 1.17472 L .64942 1.19029 L F
.63885 1.20264 m .64942 1.19029 L .64834 1.20638 L F
.6379 1.05528 m .63753 1.10865 L .64442 1.20161 L 0 .689 .233 r
F
.63157 .91304 m .63753 1.10865 L .6379 1.05528 L F
.64111 1.37542 m .63175 1.01449 L .63112 1.11295 L 0 .644 .229 r
F
.63959 1.3757 m .63096 1.13832 L .63349 1.37577 L F
.63123 1.1224 m .63109 1.11858 L .63096 1.13832 L F
.64111 1.37542 m .63123 1.1224 L .63959 1.3757 L F
.63123 1.1224 m .63096 1.13832 L .63959 1.3757 L F
.63175 1.01449 m .63172 1.01219 L .63171 1.01192 L F
.63178 1.37266 m .6329 .98426 L .62629 .89168 L 0 .759 .227 r
F
.62559 1.20354 m .62769 1.23277 L .62811 1.19894 L 0 1 .192 r
F
.62895 1.3759 m .62871 1.31958 L .62559 1.20354 L 0 .581 .001 r
F
.62871 1.31958 m .62769 1.23277 L .62559 1.20354 L F
.63163 .91272 m .64093 .8565 L .63161 .91104 L 0 .689 .233 r
F
.63161 .91104 m .63441 .77405 L .63438 .77378 L F
.63039 .77654 m .6343 .77312 L .6304 .7748 L 0 .722 .24 r
F
.63028 .84428 m .63438 .77378 L .63401 .77404 L F
.63038 .78766 m .63401 .77404 L .63039 .77654 L F
.63028 .84428 m .63401 .77404 L .63038 .78766 L F
.6343 .77312 m .6343 .77307 L .6304 .7748 L F
.63438 .77378 m .63442 .77301 L .63424 .77317 L F
.63401 .77404 m .63424 .77317 L .63039 .77654 L F
.63438 .77378 m .63424 .77317 L .63401 .77404 L F
.6344 .77262 m .63442 .77248 L .6344 .77249 L 0 .371 .225 r
F
.6344 .77276 m .63441 .77228 L .63037 .77422 L 0 .689 .233 r
F
.63439 .77249 m .63441 .77244 L .63441 .77255 L 0 .306 .198 r
F
.63157 .91304 m .63438 .77378 L .63039 .77654 L 0 .689 .233 r
F
.64429 .96991 m .64649 .96357 L .65077 .95287 L 0 0 0 r
F
.64429 .96991 m .65441 .94178 L .65499 .93764 L F
.64429 .96991 m .65077 .95287 L .65441 .94178 L F
.64429 .96991 m .65499 .93764 L .65223 .94489 L F
.64957 .95281 m .64775 .95463 L .64947 .95179 L F
.64468 .96348 m .65223 .94489 L .65535 .92929 L 0 1 .123 r
F
.6434 .94526 m .65374 .89606 L .65006 .90242 L 0 1 .199 r
F
.6434 .94526 m .65456 .90806 L .65374 .89606 L F
.64429 .96991 m .65223 .94489 L .64795 .95875 L 0 0 0 r
F
.64468 .96348 m .64795 .95875 L .65223 .94489 L 0 1 .123 r
F
.6434 .94526 m .65006 .90242 L .64595 .92299 L 0 1 .199 r
F
.64468 .96348 m .64471 .96674 L .64795 .95875 L 0 1 .123 r
F
.64365 .95753 m .65503 .92906 L .65465 .9369 L 0 .29 .138 r
F
.64365 .95753 m .65465 .9369 L .6511 .95071 L F
.64365 .95753 m .6511 .95071 L .64676 .96126 L F
.66395 .97131 m .64815 .97794 L .65019 .98018 L 0 1 .538 r
F
.66395 .97131 m .65404 .97414 L .64815 .97794 L F
.65815 .96563 m .65404 .97414 L .66395 .97131 L 0 1 .536 r
F
.65827 .97115 m .64515 .97792 L .6541 .97688 L 0 1 .52 r
F
.65827 .97115 m .64312 .97655 L .64515 .97792 L F
.65827 .97115 m .64873 .97365 L .64312 .97655 L F
.64673 .96622 m .65251 .9685 L .65757 .96618 L 0 1 .475 r
F
.64673 .96622 m .65757 .96618 L .65515 .96534 L F
.64215 .99901 m .64676 .96126 L .6511 .95071 L 0 .126 .114 r
F
.64215 .99901 m .64292 .98192 L .64676 .96126 L F
.63858 1.00966 m .64781 .92237 L .64356 .93952 L 0 1 .135 r
F
.63858 1.00966 m .64996 .93852 L .64781 .92237 L F
.66099 .958 m .64907 .96352 L .6515 .9642 L 0 1 .45 r
F
.66099 .958 m .65313 .96087 L .64907 .96352 L F
.65306 .94685 m .66243 .93027 L .66372 .92578 L 0 .853 .12 r
F
.65306 .94685 m .65832 .93895 L .66243 .93027 L F
.65306 .94685 m .6541 .94608 L .65832 .93895 L F
.65306 .94685 m .66372 .92578 L .66148 .92914 L F
.65306 .94685 m .66148 .92914 L .65719 .93812 L F
.65257 .94968 m .6511 .95071 L .65352 .94516 L 0 .126 .114 r
F
.64215 .99901 m .64996 .95688 L .65257 .94968 L F
.64996 .95688 m .6511 .95071 L .65257 .94968 L F
.65499 .93764 m .66148 .92914 L .66512 .91772 L 0 1 .154 r
F
.65499 .93764 m .65719 .93812 L .66148 .92914 L F
.65499 .93764 m .65441 .94178 L .65719 .93812 L F
.65465 .9369 m .66619 .91753 L .66569 .92098 L 0 .126 .085 r
F
.65465 .9369 m .66569 .92098 L .66203 .92934 L F
.65465 .9369 m .66203 .92934 L .65765 .93703 L F
.65547 .94165 m .66203 .92934 L .66435 .92245 L 0 0 0 r
F
.64215 .99901 m .65352 .94516 L .65241 .94829 L 0 .126 .114 r
F
.65241 .94829 m .65765 .93703 L .66203 .92934 L 0 0 0 r
F
.65241 .94829 m .65472 .94373 L .65547 .94165 L F
.65472 .94373 m .66203 .92934 L .65547 .94165 L F
.64215 .99901 m .65241 .94829 L .64859 .96891 L 0 .126 .114 r
F
.63858 1.00966 m .64859 .96891 L .64996 .93852 L 0 1 .135 r
F
.63858 1.00966 m .64356 .93952 L .63999 .97888 L F
.63157 .91304 m .64572 .97298 L .64093 .8565 L 0 .689 .233 r
F
.65033 1.08111 m .64327 1.084 L .65509 1.08364 L 0 1 .401 r
F
.64554 1.07862 m .65033 1.08111 L .65739 1.0802 L 0 1 .391 r
F
.64554 1.07862 m .65739 1.0802 L .65535 1.07924 L F
.6606 1.07374 m .64511 1.07439 L .64717 1.07537 L 0 .84 .334 r
F
.6606 1.07374 m .65086 1.07369 L .64511 1.07439 L F
.6489 1.06961 m .64541 1.07136 L .65476 1.07171 L 0 .719 .311 r
F
.643 1.06738 m .6489 1.06961 L .65379 1.06957 L 0 .65 .3 r
F
.643 1.06738 m .65379 1.06957 L .65132 1.0688 L F
.65674 1.06924 m .64511 1.0668 L .6476 1.06762 L 0 .479 .215 r
F
.65674 1.06924 m .64902 1.06749 L .64511 1.0668 L F
.6418 1.06668 m .641 1.06533 L .64828 1.06784 L 0 0 0 r
F
.6418 1.06668 m .64828 1.06784 L .65173 1.06953 L F
.6418 1.06668 m .65173 1.06953 L .64903 1.06926 L F
.6606 1.07374 m .64717 1.07537 L .65628 1.07594 L 0 .84 .334 r
F
.65476 1.07171 m .65086 1.07369 L .6606 1.07374 L 0 .781 .321 r
F
.65093 1.07533 m .64498 1.06883 L .65182 1.0715 L 0 0 0 r
F
.65093 1.07533 m .64227 1.06852 L .64498 1.06883 L F
.65093 1.07533 m .64481 1.0713 L .64227 1.06852 L F
.64357 1.0758 m .64481 1.0713 L .65093 1.07533 L 0 .097 0 r
F
.66642 1.07573 m .65229 1.07779 L .66169 1.07817 L 0 .898 .347 r
F
.66642 1.07573 m .65024 1.07683 L .65229 1.07779 L F
.66642 1.07573 m .65628 1.07594 L .65024 1.07683 L F
.64357 1.0758 m .65093 1.07533 L .65326 1.07869 L 0 .097 0 r
F
.64357 1.0758 m .65326 1.07869 L .65022 1.07912 L F
.64905 1.09119 m .64565 1.07972 L .65189 1.08332 L 0 .236 .038 r
F
.64905 1.09119 m .64259 1.08008 L .64565 1.07972 L F
.64905 1.09119 m .64404 1.08499 L .64259 1.08008 L F
.64086 1.09358 m .64404 1.08499 L .64905 1.09119 L 0 .298 .053 r
F
.64086 1.09358 m .64905 1.09119 L .6503 1.09681 L F
.64086 1.09358 m .6503 1.09681 L .64694 1.09809 L F
.65182 1.11325 m .64694 1.09809 L .6503 1.09681 L 0 .308 .079 r
F
.65182 1.11325 m .64758 1.10512 L .64694 1.09809 L F
.64291 1.11829 m .64188 1.09983 L .64758 1.10512 L 0 .386 .089 r
F
.64291 1.11829 m .64758 1.10512 L .65182 1.11325 L F
.64291 1.11829 m .65182 1.11325 L .65228 1.12121 L F
.64291 1.11829 m .65228 1.12121 L .64864 1.12364 L F
.64215 .99901 m .64859 .96891 L .64459 .99342 L 0 .126 .114 r
F
.63858 1.00966 m .64459 .99342 L .64859 .96891 L 0 1 .135 r
F
.63858 1.00966 m .64029 1.01095 L .64459 .99342 L F
.63157 .91304 m .6473 1.12171 L .64572 .97298 L 0 .689 .233 r
F
.63157 .91304 m .64442 1.20161 L .6473 1.12171 L F
.63289 .98325 m .63442 .77305 L .63426 .77312 L 0 .69 .231 r
F
.63289 .98325 m .63426 .77312 L .63059 .7911 L F
.63438 .77378 m .63452 .77367 L .63442 .77301 L 0 .722 .24 r
F
.63289 .98325 m .64171 .89467 L .63442 .77305 L 0 .69 .231 r
F
.63153 1.00224 m .63311 .85649 L .63679 .84885 L 0 .321 .207 r
F
.63311 .85649 m .63346 .82398 L .63589 .84209 L F
.63311 .85649 m .63589 .84209 L .63679 .84885 L F
.63289 .98325 m .64766 1.06601 L .64171 .89467 L 0 .69 .231 r
F
.65674 1.06924 m .6476 1.06762 L .65551 1.06912 L 0 .479 .215 r
F
.64828 1.06784 m .64865 1.06767 L .65674 1.06924 L 0 .362 .189 r
F
.64865 1.06767 m .64902 1.06749 L .65674 1.06924 L F
.64865 1.06767 m .65674 1.06924 L .65674 1.06924 L F
.65202 1.14467 m .64852 1.13368 L .64864 1.12364 L 0 .38 .104 r
F
.64942 1.19029 m .64756 1.16007 L .65162 1.15601 L 0 .455 .14 r
F
.64942 1.19029 m .64661 1.17472 L .64756 1.16007 L F
.63885 1.20264 m .64834 1.20638 L .64406 1.21218 L 0 .565 .151 r
F
.65129 1.28071 m .64938 1.24892 L .65332 1.23653 L 0 .257 .143 r
F
.64472 1.25685 m .64834 1.20638 L .65328 1.21596 L 0 .513 .171 r
F
.64472 1.25685 m .64406 1.21218 L .64834 1.20638 L F
.65129 1.28071 m .6485 1.26785 L .64938 1.24892 L 0 .257 .143 r
F
.65129 1.28071 m .65332 1.23653 L .65844 1.23393 L F
.64472 1.25685 m .65328 1.21596 L .65561 1.23465 L 0 .513 .171 r
F
.64472 1.25685 m .65561 1.23465 L .65409 1.25642 L F
.64472 1.25685 m .65409 1.25642 L .6497 1.26664 L F
.65129 1.28071 m .65844 1.23393 L .66137 1.24286 L 0 .257 .143 r
F
.65129 1.28071 m .66137 1.24286 L .66054 1.26177 L F
.65129 1.28071 m .66054 1.26177 L .65647 1.27811 L F
.64957 1.32565 m .6497 1.26664 L .65409 1.25642 L 0 .438 .183 r
F
.64957 1.32565 m .64775 1.2962 L .6497 1.26664 L F
.64538 1.35788 m .6473 1.12171 L .64442 1.20161 L 0 .958 .219 r
F
.65202 1.14467 m .65228 1.12121 L .65778 1.12619 L 0 .38 .104 r
F
.65202 1.14467 m .64864 1.12364 L .65228 1.12121 L F
.64942 1.19029 m .65162 1.15601 L .65688 1.16244 L 0 .455 .14 r
F
.64942 1.19029 m .65688 1.16244 L .65986 1.17513 L F
.64942 1.19029 m .65986 1.17513 L .65895 1.1899 L F
.64942 1.19029 m .65895 1.1899 L .65473 1.19683 L F
.64538 1.35788 m .65227 1.13192 L .6473 1.12171 L 0 .958 .219 r
F
.65202 1.14467 m .65778 1.12619 L .66149 1.13532 L 0 .38 .104 r
F
.65202 1.14467 m .66149 1.13532 L .66141 1.14543 L F
.65202 1.14467 m .66141 1.14543 L .65755 1.14973 L F
.65561 1.23465 m .65473 1.19683 L .65895 1.1899 L 0 .392 .157 r
F
.65561 1.23465 m .65328 1.21596 L .65473 1.19683 L F
.64538 1.35788 m .65615 1.22589 L .65227 1.13192 L 0 .958 .219 r
F
.65561 1.23465 m .65895 1.1899 L .66393 1.19549 L 0 .392 .157 r
F
.65561 1.23465 m .66393 1.19549 L .66636 1.20995 L F
.65561 1.23465 m .66636 1.20995 L .66496 1.22921 L F
.65561 1.23465 m .66496 1.22921 L .66063 1.24037 L F
.65735 1.31555 m .65647 1.27811 L .66054 1.26177 L 0 .21 .142 r
F
.65735 1.31555 m .65508 1.30115 L .65647 1.27811 L F
.64957 1.32565 m .65409 1.25642 L .65873 1.26529 L 0 .438 .183 r
F
.65735 1.31555 m .66054 1.26177 L .66531 1.25628 L 0 .21 .142 r
F
.64694 1.36932 m .65508 1.30115 L .65735 1.31555 L 0 .287 .169 r
F
.64957 1.32565 m .65873 1.26529 L .66056 1.28751 L 0 .438 .183 r
F
.65735 1.31555 m .66531 1.25628 L .66764 1.26524 L 0 .21 .142 r
F
.65735 1.31555 m .66764 1.26524 L .66631 1.28823 L F
.65735 1.31555 m .66631 1.28823 L .66218 1.30999 L F
.64694 1.36932 m .65735 1.31555 L .65594 1.34388 L 0 .287 .169 r
F
.64957 1.32565 m .66056 1.28751 L .65866 1.31734 L 0 .438 .183 r
F
.64957 1.32565 m .65866 1.31734 L .65426 1.33481 L F
.66201 1.35332 m .66218 1.30999 L .66631 1.28823 L 0 .133 .127 r
F
.66201 1.35332 m .66032 1.3379 L .66218 1.30999 L F
.65241 1.41338 m .65594 1.34388 L .66032 1.3379 L 0 .242 .166 r
F
.65311 1.41302 m .66032 1.3379 L .66201 1.35332 L F
.65241 1.41338 m .66032 1.3379 L .65311 1.41302 L F
.65383 1.40577 m .65866 1.31734 L .66289 1.32313 L 0 .338 .187 r
F
.65349 1.40584 m .65866 1.31734 L .65383 1.40577 L F
.64694 1.36932 m .65594 1.34388 L .65176 1.3673 L 0 .287 .169 r
F
.65167 1.41362 m .65594 1.34388 L .65241 1.41338 L 0 .242 .166 r
F
.65167 1.41362 m .65176 1.3673 L .65594 1.34388 L F
.65349 1.40584 m .65426 1.33481 L .65866 1.31734 L 0 .338 .187 r
F
.66201 1.35332 m .67062 1.27791 L .67228 1.28582 L 0 .133 .127 r
F
.66201 1.35332 m .66631 1.28823 L .67062 1.27791 L F
.66201 1.35332 m .67228 1.28582 L .67048 1.31356 L F
.66201 1.35332 m .67048 1.31356 L .66638 1.34283 L F
.65383 1.41256 m .66201 1.35332 L .66022 1.3894 L 0 .242 .166 r
F
.65311 1.41302 m .66201 1.35332 L .65383 1.41256 L F
.65424 1.40563 m .66289 1.32313 L .66417 1.34846 L 0 .338 .187 r
F
.65383 1.40577 m .66289 1.32313 L .65424 1.40563 L F
.65312 1.40591 m .65426 1.33481 L .65349 1.40584 L F
.65312 1.40591 m .65199 1.37586 L .65426 1.33481 L F
.65064 1.41396 m .65176 1.3673 L .65167 1.41362 L 0 .242 .166 r
F
.65064 1.41396 m .6499 1.40347 L .65176 1.3673 L F
.6372 1.41783 m .64694 1.36933 L .64529 1.40301 L 0 .403 .187 r
F
.63663 1.418 m .64694 1.36933 L .6372 1.41783 L F
.639 1.41735 m .64529 1.40301 L .64281 1.41647 L F
.6372 1.41783 m .64529 1.40301 L .639 1.41735 L F
.6447 1.4161 m .64529 1.40301 L .6499 1.40348 L 0 .342 .191 r
F
.64281 1.41647 m .64529 1.40301 L .6447 1.4161 L F
.64498 1.40784 m .64741 1.35862 L .65199 1.37586 L 0 .494 .203 r
F
.64237 1.40804 m .64741 1.35862 L .64498 1.40784 L F
.64237 1.40804 m .64268 1.37288 L .64741 1.35862 L F
.65736 1.38078 m .65615 1.22589 L .64538 1.35788 L 0 .958 .219 r
F
.63289 .98325 m .65085 1.29405 L .64766 1.06601 L 0 .69 .231 r
F
.64472 1.25685 m .6425 1.23373 L .64406 1.21218 L 0 .513 .171 r
F
.65736 1.38078 m .64538 1.35788 L .65617 1.38046 L 0 .958 .219 r
F
.6489 1.41472 m .6499 1.40348 L .65064 1.41396 L 0 .342 .191 r
F
.6447 1.4161 m .6499 1.40348 L .6489 1.41472 L F
.64869 1.40713 m .65199 1.37586 L .65312 1.40591 L 0 .494 .203 r
F
.64498 1.40784 m .65199 1.37586 L .64869 1.40713 L F
.65617 1.38046 m .64538 1.35788 L .64674 1.37786 L 0 .958 .219 r
F
.64958 1.37416 m .63289 .98325 L .64704 1.3741 L 0 .69 .231 r
F
.64958 1.37416 m .65085 1.29405 L .63289 .98325 L F
.64704 1.3741 m .63289 .98325 L .64081 1.28118 L F
.63743 1.37333 m .6329 .98426 L .63178 1.37266 L 0 .759 .227 r
F
.63743 1.37333 m .64082 1.2817 L .6329 .98426 L F
.62835 1.0951 m .63679 .84885 L .6359 .95505 L 0 .321 .207 r
F
.62835 1.09504 m .63679 .84885 L .62835 1.0951 L F
.63346 .82398 m .63587 .81929 L .63679 .84885 L F
.64093 .8565 m .6547 .89101 L .65057 .81995 L 0 .724 .238 r
F
.66395 .97131 m .65019 .98018 L .65943 .97969 L 0 1 .538 r
F
.66973 .97679 m .65943 .97969 L .65325 .9835 L 0 1 .539 r
F
.66395 .97131 m .65943 .97969 L .66973 .97679 L 0 1 .538 r
F
.66402 .97411 m .65022 .98152 L .65945 .98036 L 0 1 .53 r
F
.66402 .97411 m .64819 .98005 L .65022 .98152 L F
.66402 .97411 m .6541 .97688 L .64819 .98005 L F
.65827 .97115 m .6541 .97688 L .66402 .97411 L 0 1 .52 r
F
.65251 .9685 m .64873 .97365 L .65827 .97115 L 0 1 .503 r
F
.65815 .96563 m .66395 .97131 L .66957 .9675 L 0 1 .536 r
F
.65251 .9685 m .65827 .97115 L .66363 .96853 L 0 1 .503 r
F
.65251 .9685 m .66363 .96853 L .66121 .96755 L F
.65815 .96563 m .66957 .9675 L .66713 .96525 L 0 1 .536 r
F
.6742 .95303 m .66347 .96181 L .67201 .96143 L 0 1 .535 r
F
.6742 .95303 m .66102 .95947 L .66347 .96181 L F
.66771 .9593 m .65515 .96534 L .65757 .96618 L 0 1 .482 r
F
.66771 .9593 m .65948 .96239 L .65515 .96534 L F
.66099 .958 m .6515 .9642 L .65948 .96239 L 0 1 .45 r
F
.65426 .95715 m .65313 .96087 L .66099 .958 L 0 1 .404 r
F
.66741 .94724 m .65734 .95588 L .66561 .95571 L 0 1 .532 r
F
.65426 .95715 m .66099 .958 L .6648 .95564 L 0 1 .404 r
F
.65426 .95715 m .6648 .95564 L .662 .95537 L F
.66262 .94936 m .65385 .95502 L .65731 .9551 L 0 1 .379 r
F
.66262 .94936 m .65612 .95257 L .65385 .95502 L F
.6606 .94117 m .65919 .94973 L .66741 .94724 L 0 1 .529 r
F
.66198 .9438 m .65494 .94911 L .6579 .94848 L 0 1 .289 r
F
.66198 .9438 m .65668 .94711 L .65494 .94911 L F
.65405 .94663 m .65668 .94711 L .66198 .9438 L 0 .969 .239 r
F
.6606 .94117 m .66741 .94724 L .67147 .94359 L 0 1 .529 r
F
.65405 .94663 m .66198 .9438 L .66352 .94225 L 0 .969 .239 r
F
.65405 .94663 m .66352 .94225 L .66026 .9435 L F
.65374 .89606 m .65456 .90806 L .65838 .90711 L 0 1 .259 r
F
.65465 .9369 m .6632 .91742 L .66619 .91753 L 0 .126 .085 r
F
.65525 .92231 m .65535 .92929 L .65866 .92616 L 0 1 .216 r
F
.65465 .9369 m .6587 .92073 L .6632 .91742 L 0 .126 .085 r
F
.65465 .9369 m .65503 .92906 L .6587 .92073 L F
.65241 .94829 m .65352 .94516 L .65765 .93703 L 0 0 0 r
F
.65241 .94829 m .66435 .92245 L .66305 .92095 L F
.65241 .94829 m .66305 .92095 L .65894 .92904 L F
.64872 .91767 m .65818 .8961 L .65342 .89324 L 0 1 .286 r
F
.64781 .92237 m .64857 .92047 L .64872 .91767 L F
.64857 .92047 m .65818 .8961 L .64872 .91767 L F
.67549 .98212 m .65833 .98891 L .66036 .99104 L 0 1 .54 r
F
.67549 .98212 m .66481 .98509 L .65833 .98891 L F
.66975 .97733 m .65945 .98036 L .65326 .98379 L 0 1 .536 r
F
.66402 .97411 m .65945 .98036 L .66975 .97733 L 0 1 .53 r
F
.66395 .97131 m .66973 .97679 L .67565 .97298 L 0 1 .538 r
F
.66402 .97411 m .66975 .97733 L .67568 .97415 L 0 1 .53 r
F
.66395 .97131 m .67565 .97298 L .67323 .97081 L 0 1 .538 r
F
.66402 .97411 m .67568 .97415 L .67328 .97294 L 0 1 .53 r
F
.65827 .97115 m .66402 .97411 L .66966 .97121 L 0 1 .52 r
F
.65827 .97115 m .66966 .97121 L .66725 .9701 L F
.6742 .95303 m .66561 .95571 L .66102 .95947 L 0 1 .535 r
F
.68097 .95859 m .66957 .9675 L .67838 .96694 L 0 1 .537 r
F
.68097 .95859 m .66713 .96525 L .66957 .9675 L F
.68097 .95859 m .67201 .96143 L .66713 .96525 L F
.6744 .96098 m .66363 .96853 L .67214 .96659 L 0 1 .504 r
F
.6744 .96098 m .66121 .96755 L .66363 .96853 L F
.6744 .96098 m .66582 .96432 L .66121 .96755 L F
.66771 .9593 m .65757 .96618 L .66582 .96432 L 0 1 .482 r
F
.66099 .958 m .65948 .96239 L .66771 .9593 L 0 1 .45 r
F
.6606 .94117 m .67147 .94359 L .66863 .94122 L 0 1 .529 r
F
.66099 .958 m .66771 .9593 L .6718 .95663 L 0 1 .45 r
F
.66099 .958 m .6718 .95663 L .669 .95619 L F
.66741 .94724 m .66561 .95571 L .6742 .95303 L 0 1 .532 r
F
.66741 .94724 m .6742 .95303 L .67854 .94932 L F
.67198 .94897 m .6648 .95564 L .67233 .953 L 0 1 .433 r
F
.67198 .94897 m .662 .95537 L .6648 .95564 L F
.67198 .94897 m .66507 .95251 L .662 .95537 L F
.66262 .94936 m .65731 .9551 L .66507 .95251 L 0 1 .379 r
F
.66262 .94936 m .66507 .95251 L .67198 .94897 L F
.66741 .94724 m .67854 .94932 L .67572 .94706 L 0 1 .532 r
F
.66262 .94936 m .67198 .94897 L .67428 .9465 L 0 1 .379 r
F
.66262 .94936 m .67428 .9465 L .67041 .94676 L F
.65547 .95021 m .66262 .94936 L .66529 .94727 L 0 1 .314 r
F
.65547 .95021 m .66529 .94727 L .66234 .94769 L F
.67922 .9354 m .66863 .94122 L .67147 .94359 L 0 1 .532 r
F
.66989 .9416 m .66234 .94769 L .66529 .94727 L 0 1 .355 r
F
.66989 .9416 m .6643 .94526 L .66234 .94769 L F
.66198 .9438 m .6579 .94848 L .6643 .94526 L 0 1 .289 r
F
.66198 .9438 m .6643 .94526 L .66989 .9416 L F
.67922 .9354 m .67194 .93771 L .66863 .94122 L 0 1 .532 r
F
.66198 .9438 m .66989 .9416 L .67165 .93958 L 0 1 .289 r
F
.66198 .9438 m .67165 .93958 L .6684 .94057 L F
.66554 .93824 m .66352 .94225 L .66946 .93831 L 0 1 .255 r
F
.66554 .93824 m .66026 .9435 L .66352 .94225 L F
.66554 .93824 m .66112 .94179 L .66026 .9435 L F
.65694 .943 m .66112 .94179 L .66554 .93824 L 0 .924 .219 r
F
.6715 .92963 m .66437 .93758 L .67194 .93771 L 0 1 .528 r
F
.65694 .943 m .66554 .93824 L .66623 .93712 L 0 .924 .219 r
F
.65694 .943 m .66623 .93712 L .66271 .93918 L F
.66628 .93433 m .66271 .93918 L .66623 .93712 L 0 1 .223 r
F
.66628 .93433 m .66273 .93799 L .66271 .93918 L F
.66437 .93312 m .66242 .93708 L .66615 .93394 L 0 1 .199 r
F
.66437 .93312 m .66165 .93674 L .66242 .93708 L F
.66002 .93614 m .66795 .92702 L .67001 .92249 L 0 .932 .166 r
F
.66002 .93614 m .66348 .93388 L .66795 .92702 L F
.66002 .93614 m .65957 .93851 L .66348 .93388 L F
.66002 .93614 m .67001 .92249 L .66854 .92344 L F
.66002 .93614 m .66854 .92344 L .6645 .92925 L F
.66372 .92578 m .66243 .93026 L .6645 .92925 L 0 1 .181 r
F
.64857 .92047 m .66041 .90965 L .65818 .8961 L 0 1 .286 r
F
.64781 .92237 m .64849 .92169 L .64857 .92047 L F
.64849 .92169 m .66041 .90965 L .64857 .92047 L F
.64781 .92237 m .65894 .92904 L .66041 .90965 L F
.65492 .87946 m .66724 .98552 L .66305 .92564 L 0 .58 .239 r
F
.65385 .87751 m .66724 .98552 L .65492 .87946 L F
.65207 .864 m .66724 .98552 L .65211 .86348 L F
.65175 .8621 m .66724 .98552 L .65177 .86159 L F
.66643 .91163 m .66624 .90722 L .66934 .90336 L 0 .08 .041 r
F
.64093 .8565 m .64429 .88528 L .6476 .87321 L 0 .724 .238 r
F
.65333 .96278 m .65536 .98013 L .65532 .9744 L F
.64781 .92237 m .65342 .89324 L .6493 .90297 L 0 1 .286 r
F
.65241 .94829 m .65894 .92904 L .65473 .94137 L 0 0 0 r
F
.64781 .92237 m .65473 .94137 L .65894 .92904 L 0 1 .286 r
F
.65258 .88569 m .65509 .94398 L .6547 .89101 L 0 .724 .238 r
F
.64838 .98929 m .65315 .99461 L .66036 .99104 L 0 1 .541 r
F
.64838 .98929 m .66036 .99104 L .65833 .98891 L F
.64781 .92237 m .64996 .93852 L .65473 .94137 L 0 1 .286 r
F
.64093 .8565 m .65199 1.02723 L .65536 .98013 L 0 .724 .238 r
F
.64093 .8565 m .64572 .97298 L .65199 1.02723 L F
.65146 .85979 m .65191 .86504 L .66724 .98552 L 0 .58 .239 r
F
.67549 .98212 m .66036 .99104 L .67016 .99036 L 0 1 .54 r
F
.65547 .95021 m .65612 .95257 L .66262 .94936 L 0 1 .314 r
F
.65694 .943 m .65537 .94559 L .66112 .94179 L 0 .924 .219 r
F
.66002 .93614 m .65808 .93949 L .65957 .93851 L 0 .932 .166 r
F
.65191 .86504 m .66758 1.04526 L .66744 1.0211 L 0 .58 .239 r
F
.65191 .86504 m .66744 1.0211 L .66724 .98552 L F
.64171 .89467 m .65677 .98292 L .65152 .86113 L 0 .639 .235 r
F
.65136 .85952 m .65152 .86113 L .65144 .85924 L F
.64171 .89467 m .65152 .86113 L .65136 .85952 L F
.65818 .8961 m .66381 .8878 L .65964 .88674 L 0 1 .333 r
F
.65818 .8961 m .67082 .90119 L .66861 .894 L F
.66643 .91163 m .67367 .9026 L .67704 .90394 L 0 .08 .041 r
F
.66643 .91163 m .66934 .90336 L .67367 .9026 L F
.66643 .91163 m .67704 .90394 L .67722 .90648 L F
.6821 .90888 m .67586 .91286 L .67917 .91493 L 0 1 .501 r
F
.67392 .90892 m .67458 .9154 L .67861 .91048 L 0 1 .282 r
F
.67392 .90892 m .67257 .91474 L .67458 .9154 L F
.66372 .92578 m .67257 .91474 L .67392 .90892 L 0 1 .181 r
F
.66372 .92578 m .67392 .90892 L .67187 .9099 L F
.66372 .92578 m .67187 .9099 L .66777 .91704 L F
.66643 .91163 m .67722 .90648 L .67412 .91036 L 0 .08 .041 r
F
.65818 .8961 m .66936 .91054 L .67082 .90119 L 0 1 .333 r
F
.66643 .91163 m .67412 .91036 L .66981 .91298 L 0 .08 .041 r
F
.65818 .8961 m .66521 .91584 L .66936 .91054 L 0 1 .333 r
F
.65818 .8961 m .66041 .90964 L .66521 .91584 L F
.65146 .85979 m .66305 .92564 L .65836 .8722 L 0 .58 .239 r
F
.65278 .85636 m .65836 .8722 L .65619 .84751 L F
.65146 .85979 m .65836 .8722 L .65278 .85636 L F
.65033 1.08111 m .65509 1.08364 L .66246 1.08264 L 0 1 .401 r
F
.65033 1.08111 m .66246 1.08264 L .66044 1.08166 L F
.67221 1.07772 m .65535 1.07924 L .65739 1.0802 L 0 .956 .363 r
F
.67221 1.07772 m .66169 1.07817 L .65535 1.07924 L F
.65476 1.07171 m .6606 1.07374 L .6661 1.07324 L 0 .781 .321 r
F
.65476 1.07171 m .6661 1.07324 L .66365 1.07252 L F
.6489 1.06961 m .65476 1.07171 L .65996 1.07143 L 0 .719 .311 r
F
.6489 1.06961 m .65996 1.07143 L .6575 1.0707 L F
.6636 1.07031 m .65379 1.06957 L .66197 1.07067 L 0 .556 .231 r
F
.6636 1.07031 m .65132 1.0688 L .65379 1.06957 L F
.6636 1.07031 m .65551 1.06912 L .65132 1.0688 L F
.65674 1.06924 m .65551 1.06912 L .6636 1.07031 L 0 .479 .215 r
F
.64828 1.06784 m .65674 1.06924 L .65992 1.07031 L 0 .362 .189 r
F
.64828 1.06784 m .65992 1.07031 L .6564 1.06998 L F
.65826 1.07477 m .65173 1.06953 L .6588 1.07165 L 0 0 0 r
F
.65826 1.07477 m .64903 1.06926 L .65173 1.06953 L F
.65826 1.07477 m .65182 1.0715 L .64903 1.06926 L F
.65093 1.07533 m .65182 1.0715 L .65826 1.07477 L F
.6606 1.07374 m .65628 1.07594 L .66642 1.07573 L 0 .84 .334 r
F
.65093 1.07533 m .65826 1.07477 L .66084 1.07757 L 0 0 0 r
F
.65093 1.07533 m .66084 1.07757 L .65781 1.07802 L F
.6572 1.0885 m .65326 1.07869 L .65971 1.08153 L 0 .163 .019 r
F
.6572 1.0885 m .65022 1.07912 L .65326 1.07869 L F
.6572 1.0885 m .65189 1.08332 L .65022 1.07912 L F
.64905 1.09119 m .65189 1.08332 L .6572 1.0885 L 0 .236 .038 r
F
.64905 1.09119 m .6572 1.0885 L .65868 1.09344 L F
.64905 1.09119 m .65868 1.09344 L .65534 1.09482 L F
.65182 1.11325 m .6503 1.09681 L .65618 1.10092 L 0 .308 .079 r
F
.65182 1.11325 m .65618 1.10092 L .66067 1.10772 L F
.65182 1.11325 m .66067 1.10772 L .66134 1.11479 L F
.65182 1.11325 m .66134 1.11479 L .65773 1.11741 L F
.65227 1.13192 m .66057 .99994 L .65536 .98013 L 0 .933 .228 r
F
.67797 1.07974 m .66246 1.08264 L .67243 1.08271 L 0 1 .379 r
F
.67797 1.07974 m .66044 1.08166 L .66246 1.08264 L F
.67797 1.07974 m .66707 1.08042 L .66044 1.08166 L F
.67221 1.07772 m .65739 1.0802 L .66707 1.08042 L 0 .956 .363 r
F
.66642 1.07573 m .66169 1.07817 L .67221 1.07772 L 0 .898 .347 r
F
.6606 1.07374 m .66642 1.07573 L .67221 1.07503 L 0 .84 .334 r
F
.6606 1.07374 m .67221 1.07503 L .66977 1.07431 L F
.67723 1.07243 m .66365 1.07252 L .6661 1.07324 L 0 .667 .252 r
F
.67723 1.07243 m .6684 1.07217 L .66365 1.07252 L F
.67043 1.07136 m .65996 1.07143 L .6684 1.07217 L 0 .618 .243 r
F
.67043 1.07136 m .6575 1.0707 L .65996 1.07143 L F
.67043 1.07136 m .66197 1.07067 L .6575 1.0707 L F
.6636 1.07031 m .66197 1.07067 L .67043 1.07136 L 0 .556 .231 r
F
.6636 1.07031 m .67043 1.07136 L .67466 1.07168 L F
.6636 1.07031 m .67466 1.07168 L .67182 1.07141 L F
.65674 1.06924 m .6636 1.07031 L .66755 1.07101 L 0 .479 .215 r
F
.65674 1.06924 m .66755 1.07101 L .6647 1.07075 L F
.67723 1.07243 m .6661 1.07324 L .67481 1.07367 L 0 .667 .252 r
F
.66556 1.07421 m .65992 1.07031 L .66792 1.07183 L 0 0 0 r
F
.66556 1.07421 m .6564 1.06998 L .65992 1.07031 L F
.66556 1.07421 m .6588 1.07165 L .6564 1.06998 L F
.65826 1.07477 m .6588 1.07165 L .66556 1.07421 L F
.66642 1.07573 m .67221 1.07772 L .6783 1.07683 L 0 .898 .347 r
F
.66642 1.07573 m .6783 1.07683 L .67587 1.07611 L F
.65826 1.07477 m .66556 1.07421 L .66839 1.07646 L 0 0 0 r
F
.65826 1.07477 m .66839 1.07646 L .66537 1.0769 L F
.67221 1.07772 m .66707 1.08042 L .67797 1.07974 L 0 .956 .363 r
F
.6653 1.08576 m .66084 1.07757 L .6675 1.07973 L 0 .079 0 r
F
.6653 1.08576 m .65781 1.07802 L .66084 1.07757 L F
.6653 1.08576 m .65971 1.08153 L .65781 1.07802 L F
.6572 1.0885 m .65971 1.08153 L .6653 1.08576 L 0 .163 .019 r
F
.6572 1.0885 m .6653 1.08576 L .66702 1.08998 L F
.6572 1.0885 m .66702 1.08998 L .66369 1.09137 L F
.66067 1.10772 m .65868 1.09344 L .66473 1.09654 L 0 .251 .066 r
F
.66067 1.10772 m .65534 1.09482 L .65868 1.09344 L F
.66067 1.10772 m .65618 1.10092 L .65534 1.09482 L F
.65227 1.13192 m .66424 1.07417 L .66057 .99994 L 0 .933 .228 r
F
.65146 .85979 m .66377 1.06431 L .66758 1.04526 L 0 .58 .239 r
F
.65227 1.13192 m .65536 .98013 L .65199 1.02723 L 0 .933 .228 r
F
.64171 .89467 m .6514 1.0228 L .65677 .98292 L 0 .639 .235 r
F
.6514 1.0228 m .65679 .98448 L .65677 .98292 L F
.65146 .85979 m .65678 .98316 L .65685 .98403 L 0 .58 .239 r
F
.65831 .97366 m .65685 .98403 L .66377 1.06431 L F
.65146 .85979 m .65685 .98403 L .65831 .97366 L F
.66948 1.10208 m .66369 1.09137 L .66702 1.08998 L 0 .184 .05 r
F
.66948 1.10208 m .66473 1.09654 L .66369 1.09137 L F
.66067 1.10772 m .66473 1.09654 L .66948 1.10208 L 0 .251 .066 r
F
.66067 1.10772 m .66948 1.10208 L .67036 1.10822 L F
.66067 1.10772 m .67036 1.10822 L .66676 1.11086 L F
.66149 1.13532 m .66134 1.11479 L .66698 1.11835 L 0 .299 .095 r
F
.66149 1.13532 m .65773 1.11741 L .66134 1.11479 L F
.66149 1.13532 m .65778 1.12619 L .65773 1.11741 L F
.66149 1.13532 m .66698 1.11835 L .6709 1.12574 L F
.66149 1.13532 m .6709 1.12574 L .671 1.13457 L F
.66149 1.13532 m .671 1.13457 L .66717 1.13893 L F
.65987 1.17513 m .66141 1.14543 L .66663 1.14976 L 0 .341 .122 r
F
.65987 1.17513 m .65755 1.14973 L .66141 1.14543 L F
.65987 1.17513 m .65688 1.16243 L .65755 1.14973 L F
.65987 1.17513 m .66663 1.14976 L .66978 1.1599 L F
.65987 1.17513 m .66978 1.1599 L .66914 1.17268 L F
.65987 1.17513 m .66914 1.17268 L .66513 1.17955 L F
.65227 1.13192 m .66471 1.18012 L .66424 1.07417 L 0 .933 .228 r
F
.6514 1.0228 m .65835 1.11475 L .65679 .98448 L 0 .639 .235 r
F
.66372 .92578 m .66854 .92344 L .67257 .91474 L 0 1 .181 r
F
.66569 .92098 m .67412 .91036 L .67692 .9094 L 0 0 .004 r
F
.66569 .92098 m .66981 .91298 L .67412 .91036 L F
.66569 .92098 m .6662 .91753 L .66981 .91298 L F
.66569 .92098 m .67692 .9094 L .67635 .91076 L F
.66569 .92098 m .67635 .91076 L .67274 .91531 L F
.66306 .92095 m .67274 .91531 L .67489 .91022 L 0 1 .308 r
F
.66569 .92098 m .67274 .91531 L .6685 .92003 L 0 0 .004 r
F
.66306 .92095 m .6685 .92003 L .67274 .91531 L 0 1 .308 r
F
.66306 .92095 m .66435 .92245 L .6685 .92003 L F
.66306 .92095 m .67489 .91022 L .67351 .90814 L F
.66306 .92095 m .67351 .90814 L .66936 .91054 L F
.66306 .92095 m .66936 .91054 L .66521 .91584 L F
.66305 .92564 m .66719 .8923 L .66305 .88602 L 0 .659 .256 r
F
.65494 .92333 m .66305 .88601 L .66342 .88658 L 0 .402 .159 r
F
.66626 .89464 m .66342 .88658 L .66719 .89229 L F
.65494 .92333 m .66342 .88658 L .66626 .89464 L F
.6772 .91779 m .66983 .923 L .67376 .9259 L 0 1 .522 r
F
.6772 .91779 m .67129 .91952 L .66983 .923 L F
.6715 .92963 m .67194 .93771 L .67922 .9354 L 0 1 .528 r
F
.6715 .92963 m .67922 .9354 L .68229 .93198 L F
.6715 .92963 m .68229 .93198 L .6791 .92975 L F
.66628 .93433 m .67545 .9281 L .67548 .92689 L 0 1 .223 r
F
.66628 .93433 m .67548 .92689 L .67175 .92957 L F
.6772 .91779 m .67376 .9259 L .68142 .92651 L 0 1 .522 r
F
.67401 .92381 m .67175 .92957 L .67548 .92689 L 0 1 .264 r
F
.67401 .92381 m .67112 .92825 L .67175 .92957 L F
.66437 .93312 m .67112 .92825 L .67401 .92381 L 0 1 .199 r
F
.66437 .93312 m .67401 .92381 L .67325 .92344 L F
.67001 .92249 m .67781 .91637 L .67999 .91091 L 0 1 .222 r
F
.67001 .92249 m .67325 .92344 L .67781 .91637 L F
.66437 .93312 m .67325 .92344 L .66935 .92742 L 0 1 .199 r
F
.67001 .92249 m .66935 .92742 L .67325 .92344 L 0 1 .222 r
F
.67001 .92249 m .67999 .91091 L .67861 .91048 L F
.67001 .92249 m .66795 .92702 L .66935 .92742 L F
.67001 .92249 m .67861 .91048 L .67458 .9154 L F
.66372 .92578 m .6645 .92925 L .66854 .92344 L 0 1 .181 r
F
.66305 .92564 m .67329 .92874 L .66719 .8923 L 0 .659 .256 r
F
.65494 .92333 m .66501 .89781 L .66783 .90654 L 0 .402 .159 r
F
.66501 .89781 m .66719 .89229 L .66765 .90261 L F
.66501 .89781 m .66765 .90261 L .66783 .90654 L F
.65211 .86348 m .65385 .87751 L .65492 .87946 L 0 .58 .239 r
F
.65177 .86159 m .65207 .864 L .65211 .86348 L F
.65146 .85979 m .65175 .8621 L .65177 .86159 L F
.64171 .89467 m .64453 .77004 L .64048 .77099 L 0 .639 .235 r
F
.6568 .85704 m .65619 .84748 L .65685 .85734 L 0 .996 .115 r
F
.64329 .79646 m .64048 .77097 L .64349 .77027 L 0 .307 .199 r
F
.64329 .79646 m .64349 .77027 L .64428 .77539 L F
.64171 .89467 m .65144 .85924 L .64453 .77004 L 0 .639 .235 r
F
.65023 .80448 m .65619 .84749 L .65124 .803 L 0 .484 .258 r
F
.65146 .85979 m .65619 .84751 L .65125 .80302 L 0 .58 .239 r
F
.64493 .90485 m .65124 .80301 L .65619 .8475 L 0 .703 .206 r
F
.64493 .90485 m .64646 .82704 L .65124 .80301 L F
.64493 .90485 m .65348 .86131 L .65781 .89923 L F
.65348 .86131 m .65619 .8475 L .65685 .86867 L F
.65348 .86131 m .65685 .86867 L .65781 .89923 L F
.65201 .82582 m .65619 .84748 L .6568 .85704 L 0 .996 .115 r
F
.65413 .82304 m .65146 .80497 L .65619 .84747 L 0 0 .119 r
F
.65413 .82304 m .65619 .84747 L .65607 .83455 L F
.64093 .8565 m .64103 .85403 L .6409 .85105 L 0 .724 .238 r
F
.64093 .8565 m .641 .85488 L .64103 .85403 L F
.6359 .95505 m .64453 .77003 L .64645 .8265 L 0 .307 .199 r
F
.64442 .79558 m .64505 .79137 L .64485 .79551 L 0 .283 .182 r
F
.64505 .79137 m .64553 .78809 L .64519 .79178 L F
.64505 .79137 m .64519 .79178 L .64485 .79551 L F
.64553 .78809 m .64562 .78753 L .64554 .7883 L F
.64553 .78809 m .64554 .7883 L .64483 .79575 L F
.64428 .77539 m .64349 .77027 L .64453 .77003 L 0 .307 .199 r
F
.64019 .78253 m .64048 .77097 L .64329 .79646 L F
.64295 .8055 m .64426 .77098 L .64326 .8034 L 0 .283 .182 r
F
.6359 .95505 m .64019 .78253 L .64329 .79646 L 0 .307 .199 r
F
.63991 .81142 m .64426 .77098 L .64295 .8055 L 0 .283 .182 r
F
.6359 .95505 m .63679 .84885 L .64048 .77097 L 0 .307 .199 r
F
.63416 .86471 m .64385 .77005 L .64426 .77097 L 0 .283 .182 r
F
.64316 .77005 m .6442 .77008 L .6442 .77008 L 0 1 .486 r
F
.64427 .77001 m .6442 .77008 L .64453 .77 L F
.64316 .77005 m .6442 .77008 L .64427 .77001 L F
.64426 .77098 m .64438 .76992 L .64326 .8034 L 0 .283 .182 r
F
.64423 .76928 m .6442 .77006 L .64453 .76998 L 0 .385 .231 r
F
.64438 .76992 m .64427 .77001 L .64453 .77 L 0 1 .486 r
F
.64438 .76992 m .64442 .76988 L .64326 .8034 L 0 .283 .182 r
F
.64326 .8034 m .64442 .76996 L .64562 .78753 L F
.64442 .76996 m .64442 .76988 L .64442 .76997 L F
.64442 .76996 m .64442 .76997 L .64562 .78753 L F
.63309 .75835 m .63174 .76884 L .63383 .77149 L 0 .389 .233 r
F
.63309 .75835 m .63383 .77149 L .63428 .77151 L F
.63436 .76829 m .63437 .76738 L .63418 .74779 L 0 .371 .225 r
F
.63417 .74783 m .63418 .74779 L .63363 .68903 L F
.63436 .76829 m .63418 .74779 L .63417 .74783 L F
.63771 .66434 m .6445 .76874 L .64396 .7279 L 0 .376 .227 r
F
.63893 .67203 m .6415 .71921 L .64267 .70544 L 0 .385 .231 r
F
.63893 .67203 m .64412 .71841 L .64388 .71559 L F
.63893 .67203 m .64269 .70516 L .64218 .68861 L F
.64269 .70516 m .64412 .71776 L .64284 .69857 L F
.64269 .70516 m .64284 .69857 L .64218 .68861 L F
.63893 .67203 m .64218 .68861 L .63961 .65021 L F
.64278 .69199 m .64769 .75739 L .64771 .75661 L 0 0 .119 r
F
.63962 .65044 m .64086 .66689 L .64087 .66681 L F
.6287 .58202 m .63631 .67235 L .63893 .67203 L 0 .385 .231 r
F
.62428 .53959 m .63198 .66264 L .6287 .58202 L 0 .371 .225 r
F
.63198 .66264 m .63233 .6621 L .6287 .58202 L F
.63335 .68442 m .63341 .68415 L .6287 .58202 L F
.6287 .58202 m .63363 .68903 L .63406 .69409 L 0 .385 .231 r
F
.64013 .76364 m .64046 .77038 L .64394 .76897 L 0 .376 .227 r
F
.64322 .7683 m .64054 .77035 L .64394 .76897 L 0 .44 .248 r
F
.64054 .77035 m .64047 .7704 L .64394 .76897 L F
.64394 .76897 m .64047 .7704 L .64395 .76899 L F
.63026 .60697 m .63406 .69409 L .64039 .76993 L 0 .385 .231 r
F
.63026 .60697 m .64039 .76993 L .64041 .76993 L F
.64041 .76992 m .64045 .77059 L .64046 .77059 L F
.63026 .60697 m .64041 .76993 L .64041 .76992 L F
.64041 .76993 m .64045 .77059 L .64041 .76992 L F
.63236 .73675 m .63404 .73353 L .63363 .68903 L 0 .371 .225 r
F
.64433 .76765 m .64361 .76807 L .6445 .76876 L 0 .44 .248 r
F
.64041 .76992 m .64047 .7704 L .64322 .7683 L F
.64047 .77078 m .6445 .7688 L .64047 .77044 L 0 .724 .238 r
F
.64046 .77059 m .64047 .77043 L .64111 .77036 L 0 .283 .182 r
F
.64447 .76963 m .6445 .7688 L .644 .76904 L 0 .724 .238 r
F
.64399 .76899 m .6443 .76886 L .64397 .76899 L 0 1 .317 r
F
.6443 .76886 m .6445 .76877 L .6443 .76886 L F
.6443 .76886 m .6443 .76886 L .64397 .76899 L F
.64399 .76899 m .64397 .76899 L .64047 .77042 L F
.64392 .76936 m .64047 .77043 L .64396 .769 L 0 .283 .182 r
F
.64111 .77036 m .64047 .77043 L .64392 .76936 L F
.64013 .76364 m .64394 .76897 L .6445 .76874 L 0 .376 .227 r
F
.64361 .76807 m .64395 .76899 L .6445 .76876 L 0 .44 .248 r
F
.63972 .75875 m .64041 .76992 L .64433 .76765 L 0 .385 .231 r
F
.63991 .76518 m .64322 .7683 L .64361 .76807 L 0 .44 .248 r
F
.64322 .7683 m .64395 .76899 L .64361 .76807 L F
.64041 .76992 m .64046 .77059 L .64433 .76765 L 0 .385 .231 r
F
.64433 .76765 m .64046 .77059 L .64446 .76918 L F
.6287 .58202 m .63972 .75875 L .64433 .76765 L F
.64267 .70544 m .64379 .76126 L .64412 .71841 L F
.6415 .71921 m .64379 .76126 L .64267 .70544 L F
.63631 .67235 m .64379 .76126 L .63893 .67203 L F
.64379 .76126 m .64442 .76873 L .64442 .76785 L F
.64379 .76126 m .64437 .76733 L .64412 .71776 L F
.64433 .76765 m .64444 .76786 L .64439 .76715 L 0 .44 .248 r
F
.64437 .76733 m .64442 .76785 L .64441 .76696 L 0 .385 .231 r
F
.64437 .76733 m .64441 .76696 L .64412 .71776 L F
.64433 .76765 m .64439 .76715 L .64111 .72002 L 0 .44 .248 r
F
.63858 .73018 m .64433 .76765 L .64111 .72002 L F
.64433 .76765 m .6445 .76876 L .64444 .76786 L F
.63055 .6779 m .63991 .76518 L .64361 .76807 L F
.63055 .6779 m .64361 .76807 L .64433 .76765 L F
.63991 .76518 m .64041 .76992 L .64322 .7683 L F
.64041 .76993 m .64039 .76993 L .64045 .77059 L 0 .385 .231 r
F
.64046 .77059 m .64045 .77059 L .64048 .77092 L F
.64043 .7709 m .64046 .77059 L .64385 .77005 L 0 .283 .182 r
F
.64046 .77059 m .64111 .77036 L .64385 .77005 L F
.6287 .58202 m .63406 .69409 L .63026 .60697 L 0 .385 .231 r
F
.62779 .48811 m .64359 .64771 L .64288 .62377 L 0 .036 .14 r
F
.62779 .48811 m .6394 .62058 L .64359 .64771 L F
.6287 .58202 m .63961 .65021 L .63289 .57111 L 0 .385 .231 r
F
.63962 .65044 m .64359 .64771 L .6394 .62058 L 0 0 .119 r
F
.63061 .63305 m .64209 .64701 L .64326 .64143 L 0 .84 .347 r
F
.64209 .64701 m .64361 .64886 L .64343 .64495 L F
.64209 .64701 m .64343 .64495 L .64326 .64143 L F
.63198 .66264 m .63335 .68442 L .63233 .6621 L 0 .371 .225 r
F
.63335 .68442 m .63363 .68903 L .63341 .68415 L F
.63962 .65044 m .64253 .67168 L .64219 .64867 L 0 0 .119 r
F
.63962 .65044 m .64276 .68786 L .64263 .68108 L F
.64276 .68786 m .65252 .68709 L .64263 .68138 L 0 .968 .234 r
F
.64268 .68518 m .64263 .68138 L .64255 .68133 L F
.64276 .68786 m .64263 .68138 L .64268 .68518 L F
.64253 .67168 m .64298 .67654 L .64306 .67553 L 0 0 .119 r
F
.64298 .67648 m .64299 .67647 L .64306 .67553 L 0 .968 .234 r
F
.64299 .67647 m .64806 .66411 L .64306 .67553 L F
.64219 .64867 m .64341 .66054 L .64359 .64771 L 0 0 .119 r
F
.64318 .67014 m .6434 .6739 L .64357 .65361 L 0 .968 .234 r
F
.64306 .67553 m .64806 .66411 L .64879 .64848 L F
.64306 .67553 m .6434 .6739 L .6432 .67044 L F
.64253 .67168 m .64306 .67553 L .64219 .64867 L 0 0 .119 r
F
.64306 .67553 m .6432 .67044 L .64318 .67014 L 0 .968 .234 r
F
.6434 .6739 m .64664 .65863 L .64394 .64993 L F
.6434 .6739 m .64394 .64993 L .64368 .64907 L F
.64364 .65095 m .64368 .64886 L .64359 .64771 L 0 0 .119 r
F
.64341 .66054 m .64364 .65095 L .64359 .64771 L F
.64357 .65361 m .64368 .64907 L .64361 .64886 L 0 .968 .234 r
F
.6434 .6739 m .64368 .64907 L .64357 .65361 L F
.64664 .65863 m .64749 .64858 L .64368 .64885 L F
.64368 .64907 m .64368 .64885 L .64361 .64886 L F
.64664 .65863 m .64368 .64885 L .64368 .64907 L F
.6495 .7503 m .65252 .6871 L .64967 .73239 L 0 1 .145 r
F
.64263 .68108 m .64267 .6814 L .64266 .68098 L 0 .968 .234 r
F
.64266 .68098 m .64635 .68326 L .64556 .6719 L F
.64267 .6814 m .65252 .68709 L .64266 .68098 L F
.64263 .68108 m .64297 .67671 L .64253 .67168 L 0 0 .119 r
F
.64255 .68133 m .64263 .68108 L .64272 .67714 L 0 .968 .234 r
F
.64266 .68098 m .64806 .66411 L .64299 .67647 L F
.64635 .68326 m .65252 .68709 L .64556 .6719 L F
.64721 .69055 m .64721 .69044 L .64438 .65708 L 0 0 .119 r
F
.64438 .65709 m .64438 .65708 L .64368 .64885 L F
.64721 .69055 m .64438 .65708 L .64438 .65709 L F
.64263 .68108 m .64266 .68098 L .64298 .67648 L 0 .968 .234 r
F
.64266 .68098 m .64299 .67647 L .64298 .67648 L F
.64771 .75661 m .64967 .7324 L .64785 .75115 L 0 .729 .063 r
F
.64876 .74337 m .64882 .74265 L .64876 .74336 L F
.64952 .73402 m .64967 .7324 L .64977 .7309 L F
.64952 .73402 m .64977 .7309 L .65151 .70313 L F
.64785 .75115 m .64952 .73402 L .65151 .70313 L F
.64882 .74265 m .65303 .69054 L .64882 .74264 L F
.64789 .74943 m .65151 .70313 L .6479 .74897 L F
.64695 .74612 m .64772 .75614 L .64763 .74574 L 0 0 .119 r
F
.64785 .75115 m .65151 .70313 L .64789 .74943 L 0 .729 .063 r
F
.64527 .76948 m .64815 .76657 L .64639 .76744 L 0 1 .317 r
F
.64815 .76657 m .64937 .76534 L .648 .76631 L F
.64815 .76657 m .648 .76631 L .64639 .76744 L F
.64772 .75614 m .64788 .75006 L .64763 .74574 L 0 0 .119 r
F
.64279 .69242 m .64769 .75739 L .64278 .69199 L F
.64385 .70677 m .64768 .7576 L .64385 .70662 L F
.64751 .7584 m .64751 .75843 L .64763 .75987 L F
.64322 .70457 m .64751 .75843 L .64751 .7584 L F
.64322 .70457 m .64618 .74268 L .64751 .75843 L F
.64322 .70457 m .64763 .75987 L .64763 .7597 L F
.64564 .73026 m .64768 .75757 L .64769 .75739 L F
.63962 .65044 m .64566 .7307 L .64564 .73026 L F
.64566 .7307 m .64768 .75757 L .64564 .73026 L F
.64306 .67553 m .64341 .66054 L .64219 .64867 L F
.63962 .65044 m .64263 .68108 L .64253 .67168 L F
.64087 .66681 m .64279 .69242 L .64278 .69199 L F
.64086 .66689 m .64279 .69242 L .64087 .66681 L F
.63962 .65044 m .64234 .68665 L .64234 .68662 L F
.64763 .75958 m .64776 .75808 L .64768 .75757 L 0 .729 .063 r
F
.64763 .75958 m .64763 .75987 L .64776 .75808 L F
.63962 .65044 m .64322 .70457 L .64801 .76449 L 0 0 .119 r
F
.63962 .65044 m .64801 .76449 L .64817 .7642 L F
.63962 .65044 m .64695 .74612 L .64763 .74574 L F
.63962 .65044 m .64771 .75661 L .64772 .75614 L F
.6404 .68805 m .64264 .66075 L .64006 .65226 L 0 .968 .234 r
F
.64264 .66075 m .64361 .64886 L .64218 .65023 L F
.64264 .66075 m .64218 .65023 L .64006 .65226 L F
.64684 .76439 m .64771 .75661 L .64785 .75115 L 0 .729 .063 r
F
.64478 .79141 m .64501 .78994 L .64494 .78926 L F
.64295 .8055 m .64442 .79558 L .64483 .79575 L 0 .283 .182 r
F
.64442 .79558 m .64485 .79551 L .64483 .79575 L F
.64295 .8055 m .64483 .79575 L .64304 .81445 L F
.64304 .8142 m .64479 .79258 L .64478 .79141 L 0 .729 .063 r
F
.64479 .79258 m .64501 .78994 L .64478 .79141 L F
.64496 .78895 m .64541 .78492 L .64503 .78807 L F
.64498 .78893 m .64541 .78492 L .64496 .78895 L F
.64501 .78994 m .64541 .78492 L .64494 .78926 L F
.64442 .76988 m .64446 .76984 L .64562 .78753 L 0 .283 .182 r
F
.64445 .77009 m .6446 .76965 L .64447 .76963 L 0 .724 .238 r
F
.64458 .77009 m .6446 .76965 L .64445 .77009 L F
.64449 .76964 m .6445 .76964 L .64451 .76976 L 0 .659 .2 r
F
.64447 .76937 m .64453 .76998 L .64452 .76952 L 0 .385 .231 r
F
.6445 .76965 m .64456 .76983 L .64453 .77 L 0 .659 .2 r
F
.64448 .76972 m .64451 .76976 L .64453 .77 L F
.64447 .7693 m .64452 .76914 L .64562 .78753 L 0 .283 .182 r
F
.64438 .76992 m .64453 .77 L .64458 .77012 L 0 1 .486 r
F
.64447 .76963 m .64451 .76976 L .64448 .76972 L 0 .659 .2 r
F
.64449 .76966 m .64451 .76976 L .64447 .76963 L F
.64447 .76963 m .64453 .77 L .64447 .76963 L F
.64443 .76939 m .64447 .7693 L .64562 .78753 L 0 .283 .182 r
F
.6348 .85876 m .64059 .80502 L .6342 .86445 L F
.64059 .80502 m .64443 .76939 L .6406 .80503 L F
.64059 .80502 m .6406 .80503 L .6342 .86445 L F
.64283 .77031 m .64048 .77095 L .64293 .77038 L 0 1 .486 r
F
.64043 .7709 m .64048 .77095 L .64283 .77031 L F
.63123 .73883 m .63434 .77151 L .63445 .74272 L 0 .389 .233 r
F
.63439 .77249 m .63441 .77226 L .63441 .77244 L 0 .306 .198 r
F
.6344 .77249 m .63442 .77248 L .63437 .76738 L 0 .371 .225 r
F
.6344 .77249 m .63437 .76738 L .63436 .76829 L F
.63434 .77151 m .63441 .77153 L .63445 .74272 L 0 .389 .233 r
F
.621 .62445 m .62129 .63418 L .62189 .60131 L 0 .196 .185 r
F
.62129 .63418 m .6222 .66427 L .62206 .63491 L F
.62129 .63418 m .62206 .63491 L .62189 .60131 L F
.61493 .33823 m .62059 .49778 L .62578 .57999 L 0 .36 .222 r
F
.62308 .54918 m .63363 .68903 L .62428 .53959 L 0 .371 .225 r
F
.61958 .57725 m .621 .62445 L .62124 .56392 L 0 .196 .185 r
F
.6044 .26816 m .61157 .47228 L .62227 .63297 L 0 .529 .227 r
F
.62247 .63339 m .62227 .63297 L .62296 .64335 L F
.6044 .26816 m .62227 .63297 L .62247 .63339 L F
.61157 .47228 m .61462 .52744 L .61478 .5312 L 0 .919 .089 r
F
.61157 .47228 m .62092 .73868 L .62234 .67209 L 0 .529 .227 r
F
.61157 .47228 m .61478 .5312 L .61495 .535 L 0 .919 .089 r
F
.61157 .47228 m .61495 .535 L .6154 .54545 L F
.61734 .57927 m .6222 .66434 L .61734 .5793 L F
.61581 .55248 m .61588 .55384 L .61581 .55248 L F
.61588 .55384 m .6222 .66434 L .61588 .55384 L F
.61588 .55384 m .61588 .55384 L .61581 .55248 L F
.61196 .60743 m .61575 .6042 L .61642 .6047 L 0 .507 .099 r
F
.62836 .77311 m .62842 .77401 L .6287 .77339 L 0 1 .479 r
F
.62092 .73868 m .62342 .77616 L .62448 .7565 L 0 .529 .227 r
F
.62342 .77616 m .62473 .77535 L .62448 .7565 L F
.62092 .73868 m .62448 .7565 L .62492 .77451 L 0 .593 .223 r
F
.62342 .77616 m .62507 .801 L .62473 .77535 L 0 .529 .227 r
F
.62363 .82167 m .62628 .89156 L .62554 .7995 L 0 .813 .228 r
F
.62342 .77616 m .62392 .79625 L .62487 .79794 L 0 .529 .227 r
F
.62092 .73868 m .62226 .77687 L .62342 .77616 L F
.62295 .77523 m .62492 .77451 L .62554 .7995 L 0 .593 .223 r
F
.62479 .8082 m .62554 .7995 L .62651 .83918 L F
.62295 .77523 m .62554 .7995 L .62479 .8082 L F
.62092 .73868 m .62492 .77451 L .62295 .77523 L F
.61843 .88235 m .62027 .77623 L .62334 .78214 L F
.62027 .77623 m .62092 .73868 L .62295 .77523 L F
.62027 .77623 m .62295 .77523 L .62334 .78214 L F
.62255 .76835 m .62531 .77279 L .62738 .7736 L 0 1 .479 r
F
.62743 .77358 m .62738 .7736 L .62749 .77364 L F
.62255 .76835 m .62738 .7736 L .62743 .77358 L F
.62255 .76835 m .62782 .77343 L .62836 .77311 L F
.62782 .77343 m .62783 .77344 L .62785 .77342 L F
.62782 .77343 m .62785 .77342 L .62836 .77311 L F
.62783 .77344 m .62842 .77401 L .62836 .77311 L F
.62092 .73868 m .62353 .71798 L .62448 .7565 L 0 .593 .223 r
F
.62092 .73868 m .62152 .74168 L .62368 .69675 L 0 .529 .227 r
F
.62152 .74168 m .62414 .73125 L .62368 .69675 L F
.62092 .73868 m .62368 .69675 L .62234 .67209 L F
.61868 .60602 m .61961 .62135 L .6241 .70607 L 0 .919 .089 r
F
.61961 .62135 m .6222 .66437 L .62368 .69675 L F
.61961 .62135 m .62368 .69675 L .6241 .70607 L F
.62674 .73908 m .6271 .74479 L .62618 .72967 L 0 .459 .231 r
F
.62619 .73005 m .62618 .72967 L .62221 .66438 L F
.62674 .73908 m .62618 .72967 L .62619 .73005 L F
.62234 .67209 m .62351 .69367 L .62296 .64335 L 0 .529 .227 r
F
.62351 .69367 m .62368 .69675 L .62364 .69415 L F
.62351 .69367 m .62364 .69415 L .62296 .64335 L F
.6165 .56567 m .6222 .66437 L .61868 .60602 L 0 .919 .089 r
F
.6154 .54545 m .61652 .56504 L .6165 .56567 L F
.61652 .56504 m .6222 .66437 L .6165 .56567 L F
.6158 .55059 m .61586 .55167 L .61581 .55248 L F
.61586 .55167 m .6222 .66434 L .61588 .55384 L F
.61586 .55167 m .61588 .55384 L .61581 .55248 L F
.61496 .53365 m .6222 .66434 L .61504 .53713 L F
.6158 .55059 m .61581 .55248 L .6154 .54545 L F
.61462 .52744 m .61496 .53365 L .61504 .53713 L F
.61157 .47228 m .61586 .55194 L .61704 .55443 L 0 .529 .227 r
F
.61544 .54415 m .61577 .55022 L .61552 .54149 L 0 .919 .089 r
F
.61504 .53713 m .6158 .55059 L .6154 .54545 L F
.6154 .54545 m .61577 .55022 L .61544 .54415 L F
.6154 .54545 m .61581 .55248 L .61581 .55248 L F
.6154 .54545 m .61589 .55443 L .61577 .55022 L F
.61586 .55194 m .62234 .67209 L .61704 .55443 L 0 .529 .227 r
F
.61581 .55248 m .61734 .57927 L .61734 .5793 L 0 .919 .089 r
F
.61773 .58842 m .6241 .70607 L .61808 .59055 L F
.6194 .58994 m .62234 .67209 L .62296 .64335 L 0 .529 .227 r
F
.61704 .55443 m .61858 .58869 L .6194 .58994 L F
.61976 .61457 m .61876 .59149 L .62004 .61865 L 0 .919 .089 r
F
.61858 .58869 m .62234 .67209 L .6194 .58994 L 0 .529 .227 r
F
.6044 .26816 m .62296 .64335 L .60441 .26816 L F
.60441 .26816 m .62296 .64335 L .61732 .47306 L F
.61731 .47273 m .62295 .64248 L .6302 .77133 L 0 .371 .225 r
F
.63025 .77133 m .6302 .77133 L .63036 .77301 L 0 .389 .233 r
F
.63439 .77249 m .63036 .77306 L .63441 .77226 L 0 .306 .198 r
F
.63035 .77361 m .63033 .77361 L .6304 .77474 L 0 .371 .225 r
F
.63059 .7911 m .63426 .77312 L .6304 .77485 L 0 .69 .231 r
F
.63035 .77361 m .63036 .77306 L .63439 .77249 L 0 .306 .198 r
F
.63037 .77422 m .63442 .77298 L .6304 .77476 L 0 .625 .212 r
F
.63372 .773 m .63442 .77298 L .63037 .77422 L F
.63435 .7723 m .63441 .77224 L .63414 .7723 L 0 1 .491 r
F
.63435 .7723 m .63414 .7723 L .63036 .77304 L F
.61731 .47273 m .6302 .77133 L .63025 .77133 L 0 .371 .225 r
F
.62992 .76651 m .63036 .77301 L .63412 .77228 L 0 .389 .233 r
F
.62992 .76651 m .63412 .77228 L .63441 .77223 L F
.63434 .77151 m .6304 .77474 L .63428 .77302 L 0 .371 .225 r
F
.6344 .77276 m .63439 .77298 L .63432 .77298 L 0 .625 .212 r
F
.6344 .77276 m .63442 .77298 L .63439 .77298 L F
.63439 .77249 m .63428 .77302 L .63442 .77296 L 0 .371 .225 r
F
.63025 .77133 m .6304 .77474 L .63434 .77151 L F
.6343 .77312 m .63442 .77301 L .6343 .77307 L 0 .722 .24 r
F
.63437 .77297 m .63035 .77361 L .63439 .77249 L 0 .306 .198 r
F
.63168 .76803 m .63174 .76884 L .63185 .76802 L 0 .389 .233 r
F
.63168 .76803 m .63185 .76802 L .63309 .75835 L F
.61994 .62014 m .62087 .62518 L .62438 .61361 L F
.62087 .62518 m .62636 .63424 L .62438 .61361 L F
.61735 .57402 m .6207 .64015 L .61992 .61977 L 0 .919 .089 r
F
.6207 .64015 m .62137 .65321 L .61999 .62149 L F
.6207 .64015 m .61999 .62149 L .61992 .61977 L F
.61995 .62026 m .63447 .73117 L .63055 .6779 L 0 .389 .233 r
F
.62219 .66941 m .62 .62147 L .61992 .61977 L 0 .919 .089 r
F
.61993 .62016 m .61995 .62032 L .61995 .62026 L 0 .389 .233 r
F
.61995 .62032 m .63447 .73117 L .61995 .62026 L F
.62137 .65321 m .62003 .62224 L .61992 .61977 L 0 .919 .089 r
F
.61993 .62016 m .62438 .61361 L .62006 .58083 L 0 .389 .233 r
F
.62016 .60157 m .62493 .62744 L .62072 .60707 L 0 .953 .114 r
F
.62016 .60157 m .62438 .61361 L .62493 .62744 L F
.61552 .54149 m .61735 .57402 L .61593 .54778 L 0 .919 .089 r
F
.61735 .57402 m .61992 .61977 L .61751 .5764 L F
.61735 .57402 m .61751 .5764 L .61593 .54778 L F
.61716 .57215 m .61749 .57856 L .61735 .57402 L F
.61749 .57856 m .62219 .66941 L .61764 .57966 L F
.61749 .57856 m .61764 .57966 L .61735 .57402 L F
.61926 .60063 m .62493 .62744 L .6213 .61277 L 0 .953 .114 r
F
.61865 .59701 m .61923 .59985 L .61926 .60063 L F
.61923 .59985 m .62493 .62744 L .61926 .60063 L F
.6238 .61896 m .63251 .64437 L .63448 .64548 L 0 .153 .226 r
F
.6213 .61277 m .62332 .61846 L .6238 .61896 L F
.62332 .61846 m .63251 .64437 L .6238 .61896 L F
.6213 .61277 m .6306 .63305 L .62495 .61713 L F
.62458 .61992 m .63448 .64548 L .6306 .63305 L F
.6213 .61277 m .6238 .61896 L .62458 .61992 L F
.6238 .61896 m .63448 .64548 L .62458 .61992 L F
.6213 .61277 m .63057 .64335 L .63447 .64989 L F
.6213 .61277 m .62493 .62744 L .63057 .64335 L F
.62039 .62213 m .62457 .62306 L .62863 .62489 L 0 .03 0 r
F
.6288 .6251 m .62863 .62489 L .63013 .62557 L F
.62039 .62213 m .62863 .62489 L .6288 .6251 L F
.63014 .62559 m .63013 .62557 L .63025 .62562 L F
.62039 .62213 m .63013 .62557 L .63014 .62559 L F
.62315 .62129 m .62495 .61713 L .62457 .62305 L 0 .507 .099 r
F
.61603 .55121 m .62219 .66941 L .61615 .55273 L 0 .919 .089 r
F
.61495 .67422 m .61591 .71082 L .61648 .61229 L 0 .529 .227 r
F
.61196 .60743 m .62234 .61518 L .62315 .62129 L 0 .507 .099 r
F
.62234 .61518 m .62495 .61713 L .62315 .62129 L F
.61815 .59064 m .61871 .59369 L .61865 .59701 L 0 .953 .114 r
F
.61871 .59369 m .62016 .60157 L .61902 .59812 L F
.61871 .59369 m .61902 .59812 L .61865 .59701 L F
.63251 .64437 m .63282 .64524 L .63306 .64527 L 0 .153 .226 r
F
.63251 .64437 m .63306 .64527 L .63448 .64548 L F
.62087 .62518 m .63055 .6779 L .62636 .63424 L 0 .389 .233 r
F
.61993 .62016 m .61995 .62026 L .61994 .62014 L F
.61995 .62026 m .63055 .6779 L .61994 .62014 L F
.62137 .65321 m .62219 .66941 L .62003 .62224 L 0 .919 .089 r
F
.61615 .55273 m .61716 .57215 L .61735 .57402 L F
.62016 .60157 m .62072 .60707 L .61865 .59701 L 0 .953 .114 r
F
.61993 .62016 m .63168 .76803 L .63309 .75835 L 0 .389 .233 r
F
.63439 .77259 m .63441 .77255 L .6344 .77294 L 0 .306 .198 r
F
.63439 .77295 m .6344 .77296 L .6344 .77294 L 0 1 .479 r
F
.63346 .82398 m .63442 .77303 L .63587 .81929 L 0 .321 .207 r
F
.62679 .72069 m .62579 .72467 L .6302 .77133 L 0 .389 .233 r
F
.62679 .72069 m .6302 .77133 L .63025 .77133 L F
.62974 .77116 m .63437 .77297 L .63114 .76805 L 0 1 .479 r
F
.63437 .77297 m .63442 .77299 L .63439 .77295 L F
.63439 .77261 m .63439 .77259 L .63439 .77295 L 0 .306 .198 r
F
.62766 .97661 m .62834 1.09381 L .62835 1.09437 L 0 .01 .121 r
F
.62833 1.09313 m .62835 1.09437 L .62835 1.09574 L F
.62766 .97661 m .62835 1.09437 L .62833 1.09313 L F
.63068 1.0964 m .63395 1.06269 L .63332 1.09768 L 0 .321 .207 r
F
.66636 1.20994 m .66393 1.19548 L .66513 1.17955 L 0 .291 .135 r
F
.66056 1.28751 m .66063 1.24037 L .66496 1.22921 L 0 .306 .164 r
F
.65227 1.13192 m .66155 1.24697 L .66471 1.18012 L 0 .933 .228 r
F
.64171 .89467 m .65492 1.16344 L .65835 1.11475 L 0 .639 .235 r
F
.64171 .89467 m .64766 1.06601 L .65492 1.16344 L F
.63956 1.01762 m .65007 .94849 L .65007 .95818 L 0 .066 .113 r
F
.63878 1.02025 m .64043 .99702 L .64007 1.00559 L 0 0 .076 r
F
.62835 1.09527 m .63395 1.06269 L .63068 1.0964 L 0 .321 .207 r
F
.62889 1.11434 m .63332 1.09768 L .63075 1.17987 L F
.62834 1.09527 m .63068 1.0964 L .62889 1.11434 L F
.63068 1.0964 m .63332 1.09768 L .62889 1.11434 L F
.63943 1.0088 m .64015 .99893 L .64043 .99702 L 0 0 .076 r
F
.63063 1.13488 m .63332 1.09768 L .63314 1.07092 L 0 .995 .099 r
F
.62869 1.31524 m .62818 1.25671 L .62813 1.27078 L 0 .646 .228 r
F
.6285 1.27211 m .62818 1.25671 L .62869 1.31524 L F
.62559 1.20354 m .62629 .8916 L .62473 1.05033 L 0 1 .192 r
F
.63001 1.37253 m .62629 .89168 L .62474 1.05045 L 0 .759 .227 r
F
.62988 1.37595 m .62885 1.35252 L .62895 1.3761 L 0 .646 .228 r
F
.62895 1.3761 m .62886 1.35401 L .62895 1.3759 L 0 .581 .001 r
F
.62886 1.35401 m .62871 1.31958 L .62895 1.3759 L F
.62869 1.31524 m .62813 1.27078 L .62864 1.31368 L 0 .646 .228 r
F
.63001 1.37253 m .62474 1.05045 L .62906 1.37259 L 0 .759 .227 r
F
.6273 1.29002 m .62753 1.04246 L .62835 1.09574 L 0 .01 .121 r
F
.62895 1.3759 m .62559 1.20354 L .62667 1.37391 L 0 .581 .001 r
F
.62725 1.29885 m .62726 1.2914 L .6273 1.29002 L 0 .01 .121 r
F
.62726 1.2914 m .62753 1.04246 L .6273 1.29002 L F
.63063 1.13488 m .63314 1.07092 L .63134 1.10027 L 0 .995 .099 r
F
.62715 1.30366 m .62753 1.04246 L .62725 1.29885 L 0 .01 .121 r
F
.63063 1.13488 m .63134 1.10027 L .63035 1.1164 L 0 .995 .099 r
F
.63035 1.1164 m .63878 1.01534 L .63943 1.0088 L 0 0 .076 r
F
.62695 1.33136 m .62753 1.04246 L .62712 1.32212 L 0 .01 .121 r
F
.63225 1.09474 m .63834 1.02174 L .63878 1.02025 L 0 0 .076 r
F
.63221 1.09514 m .63834 1.02174 L .63225 1.09474 L F
.63173 1.09998 m .63834 1.02174 L .63206 1.09693 L F
.62835 1.09527 m .6359 .95505 L .63395 1.06269 L 0 .321 .207 r
F
.62834 1.09527 m .62835 1.0951 L .62835 1.09527 L F
.62835 1.0951 m .6359 .95505 L .62835 1.09527 L F
.62834 1.09527 m .62836 1.09217 L .62841 1.09179 L F
.62964 .89581 m .62907 .85946 L .62629 .8916 L 0 1 .192 r
F
.62836 1.09217 m .6304 .77482 L .62841 1.09179 L 0 .321 .207 r
F
.63157 .91304 m .63163 .91272 L .63161 .91104 L 0 .689 .233 r
F
.62841 1.09179 m .6304 .77482 L .63442 .77303 L 0 .321 .207 r
F
.62834 1.09527 m .62835 1.09504 L .62835 1.0951 L F
.62753 1.04246 m .62766 .97661 L .62834 1.09448 L 0 .01 .121 r
F
.62753 1.04246 m .62834 1.09448 L .62835 1.09574 L F
.63585 .90294 m .63881 .88665 L .63582 .91289 L 0 0 .072 r
F
.62835 1.09504 m .63084 .96313 L .63153 1.00224 L 0 .321 .207 r
F
.62835 1.09489 m .63084 .96313 L .62835 1.09504 L F
.63084 .96313 m .63346 .82398 L .63153 1.00224 L F
.62766 .97661 m .62773 .94436 L .6281 1.01159 L 0 .01 .121 r
F
.62773 .94436 m .6278 .90981 L .6279 .94407 L F
.62773 .94436 m .6279 .94407 L .6281 1.01159 L F
.62952 .91167 m .62778 .90884 L .6304 .77482 L 0 .321 .207 r
F
.62802 1.01271 m .6281 1.01159 L .62814 1.02448 L 0 .01 .121 r
F
.62766 .97661 m .6281 1.01159 L .62802 1.01271 L F
.62796 1.02739 m .62814 1.02448 L .62834 1.09381 L F
.62766 .97661 m .62814 1.02448 L .62796 1.02739 L F
.62834 1.09527 m .62789 .94439 L .62952 .91167 L 0 .321 .207 r
F
.62667 1.37391 m .62559 1.20354 L .62624 1.37308 L 0 .581 .001 r
F
.62632 1.36834 m .62629 .89164 L .6278 .90981 L 0 .01 .121 r
F
.62632 1.36834 m .6278 .90981 L .62689 1.36025 L F
.62674 1.36764 m .62689 1.36025 L .62688 1.36741 L F
.62632 1.36834 m .62689 1.36025 L .62674 1.36764 L F
.6316 1.13568 m .63075 1.17987 L .63332 1.09768 L 0 .995 .099 r
F
.62561 1.36904 m .62629 .89164 L .62632 1.36834 L 0 .01 .121 r
F
.62561 1.36904 m .62473 1.05039 L .62629 .89164 L F
.62472 1.36993 m .62473 1.05039 L .62561 1.36904 L F
.62473 1.36999 m .62468 1.36366 L .62472 1.36993 L 0 .671 .04 r
F
.62475 1.37006 m .62468 1.36366 L .62473 1.36999 L F
.62472 1.36993 m .62468 1.36366 L .62473 1.05039 L 0 .01 .121 r
F
.62734 1.36609 m .62751 1.3223 L .62846 1.36363 L F
.62751 1.3223 m .62835 1.09574 L .62842 1.27194 L F
.62751 1.3223 m .62842 1.27194 L .62846 1.36363 L F
.63042 1.16194 m .63063 1.1822 L .6316 1.13568 L 0 .995 .099 r
F
.62688 1.36741 m .62693 1.35797 L .62734 1.36609 L 0 .01 .121 r
F
.62705 1.3353 m .62835 1.09574 L .62753 1.31591 L F
.62755 1.19872 m .63063 1.13488 L .63035 1.1164 L 0 .995 .099 r
F
.62387 1.30666 m .62722 1.2214 L .62755 1.19872 L F
.62722 1.2214 m .63063 1.13488 L .62755 1.19872 L F
.63206 1.09693 m .63221 1.09514 L .63225 1.09474 L 0 0 .076 r
F
.63035 1.1164 m .63173 1.09998 L .63206 1.09693 L F
.63035 1.1164 m .63779 1.01536 L .6412 .9863 L F
.63834 1.02174 m .64043 .99702 L .63878 1.02025 L F
.64007 1.00559 m .64043 .99702 L .6414 .9904 L F
.63784 1.02963 m .6414 .9904 L .63823 1.02514 L F
.63694 1.04006 m .63767 1.03197 L .63784 1.02963 L F
.63767 1.03197 m .6414 .9904 L .63784 1.02963 L F
.63633 1.04787 m .63729 1.03706 L .63694 1.04006 L F
.63729 1.03706 m .6414 .9904 L .63767 1.03197 L F
.63729 1.03706 m .63767 1.03197 L .63694 1.04006 L F
.63225 1.09474 m .63552 1.05744 L .63291 1.08675 L F
.63552 1.05744 m .6414 .9904 L .63575 1.05447 L F
.63552 1.05744 m .63575 1.05447 L .63291 1.08675 L F
.63962 1.01612 m .65007 .94849 L .63956 1.01762 L 0 .066 .113 r
F
.6359 .95505 m .64492 .90461 L .6412 .9863 L 0 .307 .199 r
F
.63823 1.02513 m .64646 .95772 L .65007 .94849 L 0 .066 .113 r
F
.63823 1.02513 m .6414 .99039 L .64646 .95772 L F
.6413 .98393 m .64824 .96773 L .64334 .97388 L 0 1 .165 r
F
.6359 .95505 m .6412 .9863 L .63779 1.01536 L 0 .307 .199 r
F
.6357 1.01149 m .64043 .99497 L .6413 .98393 L 0 1 .165 r
F
.64015 .99893 m .6412 .9863 L .64126 .9875 L 0 0 .076 r
F
.64015 .99893 m .64126 .9875 L .6414 .9904 L F
.64043 .99497 m .64824 .96773 L .6413 .98393 L 0 1 .165 r
F
.63878 1.01534 m .64015 .99893 L .63943 1.0088 L 0 0 .076 r
F
.68771 .96395 m .67323 .97081 L .67565 .97298 L 0 1 .538 r
F
.69439 .96793 m .68472 .97201 L .67929 .97602 L 0 1 .533 r
F
.68771 .96395 m .67565 .97298 L .68304 .9724 L 0 1 .538 r
F
.6852 .97094 m .68304 .9724 L .68472 .97201 L 0 1 .527 r
F
.6852 .97094 m .68304 .9724 L .68473 .97227 L 0 1 .538 r
F
.68771 .96395 m .68304 .9724 L .6852 .97094 L F
.69439 .96793 m .68169 .97732 L .69099 .97506 L 0 1 .533 r
F
.69439 .96793 m .67929 .97602 L .68169 .97732 L F
.69439 .96793 m .69099 .97506 L .70102 .97075 L F
.69131 .96673 m .68472 .97201 L .69439 .96793 L 0 1 .527 r
F
.69667 .96322 m .69959 .96415 L .69682 .96319 L F
.68771 .96395 m .68545 .97025 L .6912 .96665 L 0 1 .538 r
F
.69435 .96468 m .69439 .96793 L .69959 .96415 L 0 1 .527 r
F
.69439 .96793 m .70102 .97075 L .70649 .96671 L 0 1 .533 r
F
.69439 .96793 m .70649 .96671 L .70373 .96566 L F
.69433 .96468 m .69442 .96914 L .69962 .96526 L 0 1 .538 r
F
.68771 .96395 m .6912 .96665 L .69433 .96468 L F
.69131 .96673 m .69439 .96793 L .69435 .96468 L 0 1 .527 r
F
.6912 .96665 m .69442 .96914 L .69433 .96468 L 0 1 .538 r
F
.69663 .96323 m .69435 .96468 L .69667 .96322 L 0 1 .527 r
F
.69435 .96468 m .69959 .96415 L .69667 .96322 L F
.69658 .96325 m .69962 .96526 L .69682 .96323 L 0 1 .538 r
F
.68771 .96395 m .69433 .96468 L .69658 .96325 L F
.69658 .96325 m .69433 .96468 L .69663 .96323 L 0 1 .527 r
F
.69433 .96468 m .69435 .96468 L .69663 .96323 L F
.69433 .96468 m .69962 .96526 L .69658 .96325 L 0 1 .538 r
F
.68775 .96534 m .69433 .96468 L .69658 .96325 L 0 1 .527 r
F
.6912 .96665 m .68525 .97082 L .69131 .96673 L 0 1 .538 r
F
.68545 .97025 m .68525 .97082 L .6912 .96665 L F
.68525 .97082 m .6852 .97094 L .69131 .96673 L F
.68775 .96534 m .69131 .96673 L .69435 .96468 L 0 1 .527 r
F
.68775 .96534 m .6852 .97094 L .69131 .96673 L F
.6852 .97094 m .68472 .97201 L .69131 .96673 L F
.69131 .96673 m .6852 .97094 L .69138 .96679 L 0 1 .538 r
F
.69138 .96679 m .68473 .97227 L .69442 .96914 L F
.6852 .97094 m .68473 .97227 L .69138 .96679 L F
.68775 .96534 m .67568 .97415 L .68302 .97241 L 0 1 .527 r
F
.68305 .97239 m .68302 .97241 L .68304 .9724 L F
.68775 .96534 m .68302 .97241 L .68305 .97239 L F
.68775 .96534 m .68304 .9724 L .6852 .97094 L F
.68775 .96534 m .67328 .97294 L .67568 .97415 L F
.68771 .96395 m .67838 .96694 L .67323 .97081 L 0 1 .538 r
F
.68775 .96534 m .67844 .96917 L .67328 .97294 L 0 1 .527 r
F
.68097 .95859 m .67838 .96694 L .68771 .96395 L 0 1 .537 r
F
.68108 .96301 m .66966 .97121 L .67844 .96917 L 0 1 .518 r
F
.68108 .96301 m .66725 .9701 L .66966 .97121 L F
.68108 .96301 m .67214 .96659 L .66725 .9701 L F
.6742 .95303 m .67201 .96143 L .68097 .95859 L 0 1 .535 r
F
.6744 .96098 m .67214 .96659 L .68108 .96301 L 0 1 .504 r
F
.6742 .95303 m .68097 .95859 L .68559 .95482 L 0 1 .535 r
F
.68097 .95859 m .68771 .96395 L .69262 .96013 L 0 1 .537 r
F
.6744 .96098 m .68108 .96301 L .68573 .95977 L 0 1 .504 r
F
.6742 .95303 m .68559 .95482 L .68278 .95265 L 0 1 .535 r
F
.66771 .9593 m .66582 .96432 L .6744 .96098 L 0 1 .482 r
F
.6744 .96098 m .68573 .95977 L .68295 .95903 L 0 1 .504 r
F
.66771 .9593 m .6744 .96098 L .67877 .95802 L 0 1 .482 r
F
.67922 .9354 m .67147 .94359 L .67929 .94345 L 0 1 .532 r
F
.66771 .9593 m .67877 .95802 L .67598 .95742 L 0 1 .482 r
F
.69458 .94617 m .68278 .95265 L .68559 .95482 L 0 1 .536 r
F
.69458 .94617 m .68662 .94894 L .68278 .95265 L F
.68715 .94986 m .67598 .95742 L .67877 .95802 L 0 1 .492 r
F
.68715 .94986 m .67957 .95393 L .67598 .95742 L F
.68691 .9409 m .67854 .94932 L .68662 .94894 L 0 1 .534 r
F
.67958 .94919 m .6718 .95663 L .67957 .95393 L 0 1 .468 r
F
.67958 .94919 m .669 .95619 L .6718 .95663 L F
.67958 .94919 m .67233 .953 L .669 .95619 L F
.68691 .9409 m .67572 .94706 L .67854 .94932 L 0 1 .534 r
F
.67198 .94897 m .67233 .953 L .67958 .94919 L 0 1 .433 r
F
.67198 .94897 m .67958 .94919 L .68268 .94633 L F
.67198 .94897 m .68268 .94633 L .67954 .94632 L F
.68691 .9409 m .67929 .94345 L .67572 .94706 L 0 1 .534 r
F
.67922 .9354 m .67929 .94345 L .68691 .9409 L 0 1 .532 r
F
.67778 .93997 m .67428 .9465 L .68185 .94302 L 0 1 .413 r
F
.67778 .93997 m .67041 .94676 L .67428 .9465 L F
.67778 .93997 m .6719 .94397 L .67041 .94676 L F
.66989 .9416 m .66529 .94727 L .6719 .94397 L 0 1 .355 r
F
.66989 .9416 m .6719 .94397 L .67777 .93997 L F
.66989 .9416 m .67777 .93997 L .67976 .93753 L F
.66989 .9416 m .67976 .93753 L .67652 .93828 L F
.67413 .93429 m .67165 .93958 L .67777 .93552 L 0 1 .331 r
F
.67413 .93429 m .6684 .94057 L .67165 .93958 L F
.67413 .93429 m .66946 .93831 L .6684 .94057 L F
.66554 .93824 m .66946 .93831 L .67413 .93429 L 0 1 .255 r
F
.66554 .93824 m .67413 .93429 L .67501 .93256 L F
.66554 .93824 m .67501 .93256 L .6715 .93428 L F
.67545 .9281 m .6715 .93428 L .67501 .93256 L 0 1 .301 r
F
.67545 .9281 m .67168 .93238 L .6715 .93428 L F
.66628 .93433 m .66623 .93712 L .67168 .93238 L 0 1 .223 r
F
.66628 .93433 m .67168 .93238 L .67545 .9281 L F
.66437 .93312 m .66615 .93394 L .67112 .92825 L 0 1 .199 r
F
.66305 .92564 m .67731 .97141 L .67329 .92874 L 0 .659 .256 r
F
.67549 .98212 m .67016 .99036 L .68123 .98733 L 0 1 .54 r
F
.67549 .98212 m .68123 .98733 L .68775 .98351 L F
.67549 .98212 m .68775 .98351 L .68534 .98144 L F
.66305 .92564 m .67737 1.01188 L .67731 .97141 L 0 .659 .256 r
F
.66305 .92564 m .67341 1.02282 L .67737 1.01188 L F
.66305 .92564 m .66724 .98552 L .67341 1.02282 L F
.66475 .93113 m .66848 .92112 L .66797 .924 L 0 0 .058 r
F
.65495 .95282 m .66245 .93524 L .66475 .93113 L F
.66245 .93524 m .66848 .92112 L .66475 .93113 L F
.67999 .91091 m .68869 .89955 L .68466 .90369 L 0 1 .317 r
F
.67999 .91091 m .68998 .90113 L .68869 .89955 L F
.67722 .90648 m .68785 .90108 L .68802 .90236 L 0 0 0 r
F
.67722 .90648 m .68802 .90236 L .68492 .90485 L F
.67722 .90648 m .68492 .90485 L .68059 .90687 L F
.6821 .90888 m .67917 .91493 L .68557 .91521 L 0 1 .501 r
F
.6821 .90888 m .68557 .91521 L .69082 .91351 L F
.6821 .90888 m .69082 .91351 L .69209 .91092 L F
.6821 .90888 m .69209 .91092 L .68852 .90916 L F
.67999 .91091 m .68766 .90736 L .68998 .90113 L 0 1 .317 r
F
.68641 .90438 m .68492 .90485 L .68769 .90357 L 0 0 0 r
F
.67635 .91076 m .6837 .90569 L .68641 .90438 L F
.6837 .90569 m .68492 .90485 L .68641 .90438 L F
.69336 .9056 m .68852 .90916 L .69209 .91092 L 0 .997 .465 r
F
.69336 .9056 m .68906 .90688 L .68852 .90916 L F
.68998 .90113 m .69276 .90704 L .69751 .89977 L 0 1 .377 r
F
.68998 .90113 m .68886 .90988 L .69276 .90704 L F
.68998 .90113 m .68766 .90736 L .68886 .90988 L F
.68802 .90236 m .69884 .89909 L .69573 .90057 L 0 0 0 r
F
.68802 .90236 m .69573 .90057 L .6914 .90215 L F
.68949 .9029 m .69573 .90057 L .6985 .89921 L F
.67635 .91076 m .68769 .90357 L .68708 .90389 L F
.68708 .90389 m .6914 .90215 L .69573 .90057 L F
.68708 .90389 m .68883 .90322 L .68949 .9029 L F
.68883 .90322 m .69573 .90057 L .68949 .9029 L F
.67635 .91076 m .68059 .90687 L .68492 .90485 L F
.67635 .91076 m .67692 .9094 L .68059 .90687 L F
.67635 .91076 m .68708 .90389 L .68341 .90643 L F
.67351 .90814 m .68341 .90643 L .68554 .90293 L 0 1 .419 r
F
.67635 .91076 m .68341 .90643 L .67913 .90948 L 0 0 0 r
F
.67351 .90814 m .67913 .90948 L .68341 .90643 L 0 1 .419 r
F
.67351 .90814 m .67489 .91022 L .67913 .90948 L F
.67722 .90648 m .68448 .9007 L .68785 .90108 L 0 0 0 r
F
.67351 .90814 m .68554 .90293 L .68411 .90131 L 0 1 .419 r
F
.67351 .90814 m .68411 .90131 L .67986 .90204 L F
.67351 .90814 m .67986 .90204 L .67564 .90463 L F
.66861 .894 m .67564 .90463 L .67986 .90204 L 0 1 .432 r
F
.66861 .894 m .67082 .90119 L .67564 .90463 L F
.67332 .90067 m .67735 .89814 L .67333 .8975 L 0 .72 .27 r
F
.67329 .92874 m .67657 .90407 L .67332 .90639 L F
.68702 .89907 m .6861 .89767 L .68861 .89675 L 0 0 0 r
F
.68702 .89907 m .69681 .89744 L .69779 .89799 L F
.68702 .89907 m .69779 .89799 L .69529 .89892 L F
.68702 .89907 m .69529 .89892 L .69096 .89961 L F
.68802 .90236 m .69529 .89892 L .69866 .8987 L F
.68802 .90236 m .69096 .89961 L .69529 .89892 L F
.68802 .90236 m .68785 .90108 L .69096 .89961 L F
.68802 .90236 m .69866 .8987 L .69884 .89909 L F
.68411 .90131 m .69414 .90038 L .69625 .89788 L 0 1 .399 r
F
.68708 .90389 m .69785 .89896 L .69414 .90038 L 0 0 0 r
F
.68708 .90389 m .69414 .90038 L .68984 .90253 L F
.68411 .90131 m .68984 .90253 L .69414 .90038 L 0 1 .399 r
F
.68411 .90131 m .68554 .90293 L .68984 .90253 L F
.68417 .89581 m .69301 .89637 L .69476 .89675 L 0 0 0 r
F
.68417 .89581 m .69476 .89675 L .69287 .89691 L F
.68702 .89907 m .69287 .89691 L .69681 .89744 L F
.68411 .90131 m .69625 .89788 L .69475 .89669 L 0 1 .399 r
F
.68702 .89907 m .68861 .89675 L .69287 .89691 L 0 0 0 r
F
.68411 .90131 m .69045 .89709 L .68621 .8988 L 0 1 .399 r
F
.68411 .90131 m .69475 .89669 L .69045 .89709 L F
.67912 .89483 m .68621 .8988 L .69045 .89709 L 0 1 .524 r
F
.67912 .89483 m .68136 .89784 L .68621 .8988 L F
.6772 .91779 m .68142 .92651 L .68771 .92442 L 0 1 .522 r
F
.6772 .91779 m .68771 .92442 L .68921 .92094 L F
.6772 .91779 m .68921 .92094 L .68489 .9184 L F
.68771 .92442 m .68142 .92651 L .6791 .92975 L 0 1 .527 r
F
.67545 .9281 m .68062 .92767 L .6846 .92286 L 0 1 .301 r
F
.67545 .9281 m .6846 .92286 L .6848 .92094 L F
.67545 .9281 m .6848 .92094 L .68107 .92319 L F
.68363 .91589 m .68107 .92319 L .6848 .92094 L 0 1 .348 r
F
.68363 .91589 m .68057 .92104 L .68107 .92319 L F
.67401 .92381 m .67548 .92689 L .68057 .92104 L 0 1 .264 r
F
.67401 .92381 m .68057 .92104 L .68363 .91589 L F
.67401 .92381 m .68363 .91589 L .68301 .91455 L F
.67401 .92381 m .68301 .91455 L .67911 .91793 L F
.67999 .91091 m .68301 .91455 L .68766 .90736 L 0 1 .317 r
F
.67999 .91091 m .67911 .91793 L .68301 .91455 L F
.67999 .91091 m .67781 .91637 L .67911 .91793 L F
.67329 .92874 m .68336 .92378 L .67735 .89814 L 0 .72 .27 r
F
.69082 .91351 m .68489 .9184 L .68921 .92094 L 0 1 .51 r
F
.69082 .91351 m .68557 .91521 L .68489 .9184 L F
.68363 .91589 m .6848 .92094 L .69001 .91495 L 0 1 .348 r
F
.68363 .91589 m .69001 .91495 L .69325 .90921 L F
.68363 .91589 m .69325 .90921 L .69276 .90704 L F
.68363 .91589 m .69276 .90704 L .68886 .90988 L F
.68417 .89581 m .69287 .89691 L .68861 .89675 L 0 0 0 r
F
.67912 .89483 m .69045 .89709 L .69191 .89495 L 0 1 .524 r
F
.68336 .89899 m .68734 .89615 L .68336 .89757 L 0 .781 .284 r
F
.68336 .92378 m .68679 .89997 L .68336 .90287 L F
.69808 .87101 m .6851 .88655 L .69451 .88373 L 0 1 .503 r
F
.69808 .87101 m .69451 .88373 L .70469 .87736 L F
.69818 .87435 m .68518 .88929 L .69463 .88782 L 0 1 .487 r
F
.69818 .87435 m .69463 .88782 L .70484 .88258 L F
.69437 .88313 m .69474 .89384 L .69877 .89037 L 0 1 .383 r
F
.69437 .88313 m .69285 .89075 L .69474 .89384 L F
.69996 .89292 m .70251 .90072 L .70736 .89341 L 0 1 .413 r
F
.68962 .8938 m .69682 .89465 L .70107 .89313 L 0 1 .364 r
F
.68962 .8938 m .69191 .89495 L .69682 .89465 L F
.69996 .89292 m .70736 .89341 L .70994 .88604 L 0 1 .413 r
F
.69996 .89292 m .70994 .88604 L .70886 .88268 L F
.69996 .89292 m .70886 .88268 L .70482 .88559 L F
.68962 .8938 m .70107 .89313 L .70247 .89158 L 0 1 .364 r
F
.68962 .8938 m .70247 .89158 L .70007 .89105 L F
.68962 .8938 m .70007 .89105 L .69515 .89134 L F
.70007 .89105 m .70552 .88796 L .70138 .8895 L 0 1 .259 r
F
.69272 .89375 m .70138 .8895 L .70552 .88796 L 0 0 0 r
F
.69272 .89375 m .6959 .89198 L .70138 .8895 L F
.69272 .89375 m .70552 .88796 L .70612 .88759 L F
.69272 .89375 m .70612 .88759 L .70277 .88862 L F
.69272 .89375 m .70277 .88862 L .69727 .89111 L F
.69082 .91351 m .68921 .92094 L .69663 .92128 L 0 1 .51 r
F
.69082 .91351 m .69663 .92128 L .70223 .91919 L F
.69082 .91351 m .70223 .91919 L .70294 .916 L F
.69082 .91351 m .70294 .916 L .69827 .91385 L F
.6846 .92286 m .6941 .91595 L .69038 .91783 L 0 1 .372 r
F
.69325 .90921 m .69038 .91783 L .6941 .91595 L 0 1 .402 r
F
.69325 .90921 m .69001 .91495 L .69038 .91783 L F
.68708 .90389 m .68769 .90357 L .6914 .90215 L 0 0 0 r
F
.68708 .90389 m .6985 .89921 L .69785 .89896 L F
.68336 .92378 m .69336 .91617 L .68734 .89615 L 0 .781 .284 r
F
.70269 .90938 m .69816 .91102 L .69827 .91385 L 0 1 .482 r
F
.69325 .90921 m .6941 .91595 L .69944 .90987 L 0 1 .402 r
F
.69325 .90921 m .69944 .90987 L .70286 .90362 L F
.69476 .89675 m .69482 .89663 L .69898 .89735 L 0 0 0 r
F
.69476 .89675 m .69898 .89735 L .70348 .8977 L F
.69476 .89675 m .69301 .89637 L .69482 .89663 L F
.69476 .89675 m .70348 .8977 L .70534 .89745 L F
.69476 .89675 m .70093 .89716 L .70354 .89719 L F
.70093 .89716 m .70534 .89745 L .70354 .89719 L F
.70654 .89723 m .70354 .89719 L .70751 .89715 L F
.69779 .89799 m .70354 .89719 L .70654 .89723 L F
.69476 .89675 m .70354 .89719 L .69927 .8971 L F
.69475 .89669 m .7049 .89581 L .70697 .89378 L 0 1 .329 r
F
.69779 .89799 m .69927 .8971 L .70354 .89719 L 0 0 0 r
F
.69475 .89669 m .70059 .8975 L .7049 .89581 L 0 1 .329 r
F
.69779 .89799 m .69681 .89744 L .69927 .8971 L 0 0 0 r
F
.69475 .89669 m .69625 .89788 L .70059 .8975 L 0 1 .329 r
F
.69475 .89669 m .70697 .89378 L .70542 .89275 L F
.69475 .89669 m .70107 .89313 L .69682 .89465 L F
.69475 .89669 m .70542 .89275 L .70107 .89313 L F
.68414 .89485 m .69285 .89075 L .69437 .88313 L 0 1 .346 r
F
.68414 .89485 m .69437 .88313 L .69242 .8811 L F
.68414 .89485 m .69242 .8811 L .68831 .88602 L F
.67912 .89483 m .69191 .89495 L .68962 .8938 L 0 1 .524 r
F
.68264 .89691 m .6959 .89198 L .69272 .89375 L 0 0 0 r
F
.69272 .89375 m .69727 .89111 L .6933 .89338 L F
.69331 .89402 m .69727 .89112 L .6933 .89339 L 0 .839 .298 r
F
.69336 .91617 m .69722 .89142 L .69331 .89402 L F
.69722 .89142 m .69727 .89112 L .69331 .89402 L F
.70701 .88491 m .70321 .88744 L .70716 .8848 L 0 .806 .167 r
F
.68347 .90328 m .69604 .89219 L .69712 .89145 L 0 0 0 r
F
.69604 .89219 m .69698 .89137 L .69712 .89145 L F
.69437 .88313 m .69877 .89037 L .703 .88161 L 0 1 .383 r
F
.69808 .87101 m .70469 .87736 L .71027 .87069 L 0 1 .503 r
F
.69818 .87435 m .70484 .88258 L .71044 .87616 L 0 1 .487 r
F
.69808 .87101 m .71027 .87069 L .70752 .86818 L 0 1 .503 r
F
.69145 .86464 m .69808 .87101 L .70338 .8644 L 0 1 .502 r
F
.69818 .87435 m .71044 .87616 L .70766 .87287 L 0 1 .487 r
F
.69808 .87101 m .68271 .88395 L .6851 .88655 L 0 1 .503 r
F
.69808 .87101 m .68826 .87729 L .68271 .88395 L F
.69149 .86581 m .69818 .87435 L .70349 .86783 L 0 1 .481 r
F
.69145 .86464 m .70338 .8644 L .70063 .86188 L 0 1 .502 r
F
.7138 .84782 m .70063 .86188 L .70338 .8644 L 0 1 .497 r
F
.69149 .86581 m .70349 .86783 L .7007 .86441 L 0 1 .481 r
F
.7138 .84782 m .70508 .85478 L .70063 .86188 L 0 1 .497 r
F
.72129 .854 m .70752 .86818 L .71027 .87069 L 0 1 .499 r
F
.72129 .854 m .71223 .86103 L .70752 .86818 L F
.7138 .84782 m .70338 .8644 L .71223 .86103 L 0 1 .497 r
F
.7138 .84782 m .71223 .86103 L .72129 .854 L F
.71396 .85256 m .70349 .86783 L .7124 .86642 L 0 1 .481 r
F
.71396 .85256 m .7007 .86441 L .70349 .86783 L F
.71396 .85256 m .70518 .85787 L .7007 .86441 L F
.7063 .84161 m .69648 .8581 L .70508 .85478 L 0 1 .495 r
F
.7063 .84161 m .69372 .85557 L .69648 .8581 L F
.7063 .84161 m .70508 .85478 L .7138 .84782 L F
.70636 .84365 m .69651 .85917 L .70518 .85787 L 0 1 .475 r
F
.69254 .85816 m .69145 .86464 L .69648 .8581 L 0 1 .501 r
F
.69326 .85589 m .69648 .8581 L .69348 .85564 L F
.68478 .85693 m .69131 .85818 L .69348 .85564 L 0 1 .475 r
F
.69131 .85818 m .69648 .8581 L .69307 .85577 L 0 1 .501 r
F
.69348 .85564 m .69651 .85917 L .69372 .85561 L 0 1 .475 r
F
.69131 .85818 m .69006 .86331 L .69254 .85816 L 0 1 .501 r
F
.68478 .85693 m .68837 .86169 L .69131 .85818 L 0 1 .475 r
F
.68837 .86169 m .69006 .86331 L .69131 .85818 L 0 1 .501 r
F
.68837 .86169 m .68855 .86193 L .69131 .85818 L 0 1 .475 r
F
.68814 .86147 m .68837 .86169 L .69131 .85818 L 0 1 .501 r
F
.68481 .85828 m .68814 .86147 L .69131 .85818 L F
.69006 .86331 m .69145 .86464 L .69254 .85816 L F
.69131 .85818 m .69651 .85917 L .6936 .85579 L 0 1 .475 r
F
.69131 .85818 m .6936 .85579 L .69348 .85564 L F
.69348 .85564 m .69648 .8581 L .69372 .85557 L 0 1 .501 r
F
.69307 .85577 m .69326 .85589 L .69348 .85564 L F
.68481 .85828 m .69131 .85818 L .69307 .85577 L F
.69131 .85818 m .69149 .86581 L .69651 .85917 L 0 1 .475 r
F
.68855 .86193 m .69149 .86581 L .69131 .85818 L F
.70636 .84365 m .69379 .85554 L .69651 .85917 L F
.69379 .85554 m .69372 .85561 L .69374 .85564 L F
.69379 .85554 m .69374 .85564 L .69651 .85917 L F
.7063 .84161 m .69792 .84851 L .69372 .85557 L 0 1 .495 r
F
.70636 .84365 m .69793 .84896 L .69372 .85561 L 0 1 .475 r
F
.69874 .83433 m .68952 .85014 L .6961 .84922 L 0 1 .468 r
F
.69818 .8445 m .6961 .84922 L .69792 .84851 L 0 1 .492 r
F
.69818 .8445 m .6961 .84922 L .69793 .84896 L 0 1 .468 r
F
.69874 .83433 m .6961 .84922 L .69818 .8445 L F
.7013 .83746 m .69792 .84851 L .7063 .84161 L 0 1 .492 r
F
.7013 .83746 m .69793 .84896 L .70636 .84365 L 0 1 .468 r
F
.69874 .83433 m .69818 .8445 L .7013 .83746 L F
.69818 .8445 m .69792 .84851 L .7013 .83746 L 0 1 .492 r
F
.69818 .8445 m .69793 .84896 L .7013 .83746 L 0 1 .468 r
F
.69877 .83536 m .69818 .8445 L .7013 .83746 L 0 1 .492 r
F
.69877 .83536 m .68956 .85178 L .6961 .84922 L F
.69877 .83536 m .6961 .84922 L .69818 .8445 L F
.69874 .83433 m .68671 .84642 L .68952 .85014 L 0 1 .468 r
F
.67804 .84766 m .68478 .85693 L .68952 .85014 L F
.67804 .84766 m .68952 .85014 L .68671 .84642 L F
.69877 .83536 m .68679 .84926 L .68956 .85178 L 0 1 .492 r
F
.69874 .83433 m .69066 .83965 L .68671 .84642 L 0 1 .468 r
F
.69877 .83536 m .69073 .84223 L .68679 .84926 L 0 1 .492 r
F
.6911 .82455 m .69066 .83965 L .69874 .83433 L 0 1 .46 r
F
.69123 .82911 m .69073 .84223 L .69877 .83536 L 0 1 .489 r
F
.6911 .82455 m .69874 .83433 L .70245 .82739 L 0 1 .46 r
F
.7063 .84161 m .7138 .84782 L .71803 .84074 L 0 1 .495 r
F
.7063 .84161 m .71803 .84074 L .71493 .83827 L F
.70233 .83512 m .7063 .84161 L .71026 .83456 L 0 1 .492 r
F
.7013 .83746 m .7063 .84161 L .70233 .83512 L F
.70233 .83512 m .70636 .84365 L .71034 .83687 L 0 1 .468 r
F
.69874 .83433 m .7013 .83746 L .70233 .83512 L F
.7013 .83746 m .70636 .84365 L .70233 .83512 L F
.69877 .83536 m .7013 .83746 L .70233 .83512 L 0 1 .492 r
F
.70291 .83374 m .71026 .83456 L .70715 .83207 L F
.70233 .83512 m .71026 .83456 L .70291 .83374 L F
.70291 .83374 m .71034 .83687 L .70718 .83313 L 0 1 .468 r
F
.69874 .83433 m .70233 .83512 L .70291 .83374 L F
.70233 .83512 m .71034 .83687 L .70291 .83374 L F
.69877 .83536 m .70233 .83512 L .70291 .83374 L 0 1 .492 r
F
.69123 .82911 m .69877 .83536 L .70248 .82834 L 0 1 .489 r
F
.6911 .82455 m .70245 .82739 L .69929 .82347 L 0 1 .46 r
F
.68344 .81426 m .6911 .82455 L .69454 .81744 L 0 1 .453 r
F
.68344 .81426 m .69454 .81744 L .69137 .81331 L F
.69123 .82911 m .70248 .82834 L .69936 .82584 L 0 1 .489 r
F
.6911 .82455 m .6825 .84071 L .69066 .83965 L 0 1 .46 r
F
.6911 .82455 m .67969 .83682 L .6825 .84071 L F
.6911 .82455 m .68337 .8299 L .67969 .83682 L F
.68344 .81426 m .68337 .8299 L .6911 .82455 L 0 1 .453 r
F
.68368 .82287 m .69123 .82911 L .69468 .8221 L 0 1 .486 r
F
.70072 .80104 m .69137 .81331 L .69454 .81744 L 0 1 .453 r
F
.70072 .80104 m .69401 .80628 L .69137 .81331 L F
.69523 .77435 m .68261 .79515 L .69186 .79192 L 0 1 .448 r
F
.69523 .77435 m .69186 .79192 L .70184 .78384 L F
.69221 .79003 m .68661 .80695 L .69401 .80628 L 0 1 .444 r
F
.68368 .82287 m .69468 .8221 L .69155 .8196 L 0 1 .486 r
F
.70072 .80104 m .69454 .81744 L .70218 .81663 L 0 1 .453 r
F
.70083 .80458 m .69155 .8196 L .69468 .8221 L 0 1 .477 r
F
.70083 .80458 m .69418 .81209 L .69155 .8196 L F
.69245 .79825 m .68686 .81585 L .69418 .81209 L 0 1 .472 r
F
.72129 .854 m .71027 .87069 L .71937 .86725 L 0 1 .499 r
F
.72129 .854 m .71937 .86725 L .72877 .86014 L F
.72153 .8611 m .71044 .87616 L .71961 .87463 L 0 1 .486 r
F
.72153 .8611 m .70766 .87287 L .71044 .87616 L F
.7046 .87338 m .70886 .88268 L .71315 .87398 L 0 1 .406 r
F
.7046 .87338 m .70482 .88559 L .70886 .88268 L F
.72153 .8611 m .7124 .86642 L .70766 .87287 L 0 1 .486 r
F
.7046 .87338 m .71315 .87398 L .71485 .86526 L 0 1 .406 r
F
.7046 .87338 m .703 .88161 L .70482 .88559 L F
.71396 .85256 m .7124 .86642 L .72153 .8611 L 0 1 .481 r
F
.7046 .87338 m .71485 .86526 L .71304 .86126 L 0 1 .406 r
F
.69437 .88313 m .703 .88161 L .7046 .87338 L 0 1 .383 r
F
.7046 .87338 m .71304 .86126 L .70891 .86466 L 0 1 .406 r
F
.69437 .88313 m .7046 .87338 L .70272 .87026 L 0 1 .383 r
F
.70636 .84365 m .70518 .85787 L .71396 .85256 L 0 1 .475 r
F
.69671 .86099 m .70636 .85977 L .70709 .84985 L 0 1 .372 r
F
.69671 .86099 m .70272 .87026 L .70636 .85977 L F
.69437 .88313 m .70272 .87026 L .6986 .87435 L 0 1 .383 r
F
.69671 .86099 m .6986 .87435 L .70272 .87026 L 0 1 .372 r
F
.69671 .86099 m .70709 .84985 L .70452 .84586 L F
.69671 .86099 m .70452 .84586 L .70035 .85047 L F
.69692 .8336 m .69709 .84522 L .70035 .85047 L 0 1 .356 r
F
.69221 .79003 m .69401 .80628 L .70072 .80104 L 0 1 .444 r
F
.67576 .80342 m .68344 .81426 L .68661 .80695 L F
.67611 .81665 m .68686 .81585 L .68373 .81335 L 0 1 .482 r
F
.69245 .79825 m .68373 .81335 L .68686 .81585 L 0 1 .472 r
F
.69245 .79825 m .69418 .81209 L .70083 .80458 L F
.67576 .80342 m .68661 .80695 L .68343 .80259 L 0 1 .444 r
F
.69221 .79003 m .68343 .80259 L .68661 .80695 L F
.69245 .79825 m .68612 .80581 L .68373 .81335 L 0 1 .472 r
F
.70072 .80104 m .70218 .81663 L .70734 .8128 L 0 1 .453 r
F
.70919 .81085 m .70667 .81741 L .71026 .82459 L 0 1 .482 r
F
.70667 .81741 m .70245 .82739 L .70491 .8271 L 0 1 .461 r
F
.70667 .81741 m .70491 .8271 L .7051 .82707 L F
.70919 .81085 m .70736 .81365 L .70667 .81741 L 0 1 .482 r
F
.70667 .81741 m .69929 .82347 L .70245 .82739 L 0 1 .461 r
F
.70736 .81365 m .70729 .81375 L .70667 .81741 L 0 1 .482 r
F
.7092 .81142 m .70729 .81375 L .70667 .81741 L 0 1 .461 r
F
.70729 .81375 m .69929 .82347 L .70667 .81741 L F
.70729 .81375 m .69936 .82584 L .70667 .81741 L 0 1 .482 r
F
.70667 .81741 m .69936 .82584 L .70248 .82834 L F
.70667 .81741 m .70471 .82252 L .70578 .82292 L F
.70667 .81741 m .70578 .82292 L .71026 .82459 L F
.70471 .82252 m .70323 .82797 L .71026 .82459 L F
.71753 .81708 m .71026 .82459 L .70715 .83207 L 0 1 .486 r
F
.7092 .81142 m .70667 .81741 L .71032 .82644 L 0 1 .461 r
F
.70667 .81741 m .7051 .82707 L .71032 .82644 L F
.70729 .81375 m .70218 .81663 L .69929 .82347 L F
.70919 .81085 m .70746 .81271 L .70729 .81375 L 0 1 .482 r
F
.7092 .81142 m .70746 .81271 L .70729 .81375 L 0 1 .461 r
F
.70746 .81271 m .70218 .81663 L .70729 .81375 L F
.70729 .81375 m .70746 .81271 L .70708 .81406 L 0 1 .482 r
F
.70708 .81406 m .70223 .81835 L .69936 .82584 L F
.70746 .81271 m .70223 .81835 L .70708 .81406 L F
.70072 .80104 m .70734 .8128 L .70788 .81082 L 0 1 .453 r
F
.70803 .80999 m .70746 .81271 L .70919 .81085 L 0 1 .477 r
F
.70803 .80999 m .70788 .81082 L .70809 .81005 L 0 1 .453 r
F
.70072 .80104 m .70788 .81082 L .70803 .80999 L F
.70932 .80362 m .70919 .81085 L .71184 .80333 L 0 1 .477 r
F
.70919 .81085 m .71026 .82459 L .71753 .81708 L 0 1 .482 r
F
.70919 .81085 m .71753 .81708 L .72042 .80957 L F
.70919 .81085 m .72042 .80957 L .71699 .80708 L F
.70932 .80362 m .7092 .81142 L .71187 .80438 L 0 1 .453 r
F
.70072 .80104 m .70803 .80999 L .70932 .80362 L F
.70922 .80414 m .70919 .81085 L .70932 .80362 L 0 1 .477 r
F
.70803 .80999 m .70919 .81085 L .70922 .80363 L F
.70803 .80999 m .7092 .81142 L .70932 .80362 L 0 1 .453 r
F
.70922 .80363 m .70922 .80414 L .70932 .80362 L 0 1 .477 r
F
.70083 .80458 m .70803 .80999 L .70922 .80363 L F
.70083 .80458 m .70223 .81835 L .70746 .81271 L F
.70779 .81114 m .70734 .8128 L .70746 .81271 L 0 1 .453 r
F
.70083 .80458 m .70746 .81271 L .70803 .80999 L 0 1 .477 r
F
.70809 .81005 m .70779 .81114 L .70746 .81271 L 0 1 .453 r
F
.70818 .81016 m .70746 .81271 L .7092 .81142 L F
.70809 .81005 m .70746 .81271 L .70818 .81016 L F
.70471 .82252 m .70248 .82834 L .70323 .82797 L 0 1 .482 r
F
.71606 .78488 m .71091 .7956 L .71184 .80333 L 0 1 .47 r
F
.70932 .80362 m .70965 .80174 L .70838 .80021 L 0 1 .453 r
F
.71091 .7956 m .70951 .7985 L .70965 .80174 L 0 1 .47 r
F
.71091 .7956 m .70965 .80174 L .71184 .80333 L F
.70932 .80362 m .71184 .80333 L .70965 .80174 L 0 1 .477 r
F
.71606 .78488 m .71184 .80333 L .71901 .79922 L 0 1 .47 r
F
.71618 .78841 m .70951 .7985 L .71187 .80438 L 0 .977 .454 r
F
.70951 .7985 m .70838 .80021 L .70965 .80174 L F
.70951 .7985 m .70965 .80174 L .71187 .80438 L F
.70951 .7985 m .7084 .80082 L .70965 .80174 L 0 1 .47 r
F
.70072 .80104 m .70927 .8036 L .70838 .80021 L 0 1 .453 r
F
.70927 .8036 m .70932 .80362 L .70929 .80351 L F
.70927 .8036 m .70929 .80351 L .70838 .80021 L F
.70932 .80362 m .71187 .80438 L .70965 .80174 L F
.70083 .80458 m .70932 .80362 L .7084 .80082 L 0 1 .477 r
F
.70932 .80362 m .70965 .80174 L .7084 .80082 L F
.69221 .79003 m .70072 .80104 L .70314 .79377 L 0 1 .444 r
F
.69245 .79825 m .70083 .80458 L .70324 .79702 L 0 1 .472 r
F
.69523 .77435 m .68022 .79138 L .68261 .79515 L 0 1 .448 r
F
.69221 .79003 m .68583 .79535 L .68343 .80259 L 0 1 .444 r
F
.69523 .77435 m .68562 .78247 L .68022 .79138 L 0 1 .448 r
F
.68369 .77835 m .67866 .79587 L .68583 .79535 L 0 1 .435 r
F
.68861 .76465 m .68562 .78247 L .69523 .77435 L 0 1 .443 r
F
.68369 .77835 m .68583 .79535 L .69221 .79003 L 0 1 .435 r
F
.68406 .7919 m .68612 .80581 L .69245 .79825 L 0 1 .466 r
F
.69245 .79825 m .70324 .79702 L .69979 .79448 L 0 1 .472 r
F
.69221 .79003 m .70314 .79377 L .69964 .78935 L 0 1 .444 r
F
.68406 .7919 m .69245 .79825 L .69462 .79065 L 0 1 .466 r
F
.68465 .81562 m .69494 .79983 L .69108 .79388 L 0 1 .326 r
F
.68465 .81562 m .696 .81414 L .69494 .79983 L F
.68653 .84862 m .69709 .84522 L .69692 .8336 L 0 1 .339 r
F
.67804 .84766 m .67567 .86225 L .68478 .85693 L 0 1 .468 r
F
.67816 .85193 m .68481 .85828 L .68956 .85178 L 0 1 .499 r
F
.67816 .85193 m .68956 .85178 L .68679 .84926 L F
.68653 .84862 m .69411 .85816 L .69709 .84522 L 0 1 .339 r
F
.70083 .80458 m .69468 .8221 L .70223 .81835 L 0 1 .477 r
F
.67611 .81665 m .68368 .82287 L .68686 .81585 L 0 1 .482 r
F
.68465 .81562 m .69368 .82949 L .696 .81414 L 0 1 .326 r
F
.69123 .82911 m .68263 .84548 L .69073 .84223 L 0 1 .489 r
F
.68653 .84862 m .69692 .8336 L .69368 .82949 L 0 1 .339 r
F
.68369 .77835 m .69221 .79003 L .69438 .78251 L 0 1 .435 r
F
.68406 .7919 m .69462 .79065 L .69117 .78809 L 0 1 .466 r
F
.68198 .75475 m .67936 .77284 L .68861 .76465 L 0 1 .439 r
F
.67319 .76299 m .67762 .78376 L .68369 .77835 L 0 .993 .424 r
F
.67319 .76299 m .68369 .77835 L .685 .76963 L F
.68369 .77835 m .69438 .78251 L .69087 .77781 L 0 1 .435 r
F
.69523 .77435 m .70184 .78384 L .70726 .77492 L 0 1 .448 r
F
.69523 .77435 m .70726 .77492 L .70451 .77111 L F
.68861 .76465 m .69523 .77435 L .70038 .76532 L 0 1 .443 r
F
.69763 .76527 m .69087 .77781 L .69438 .78251 L 0 .922 .434 r
F
.69763 .76527 m .69226 .77043 L .69087 .77781 L F
.69763 .76527 m .69438 .78251 L .70125 .78227 L F
.69783 .77185 m .69117 .78809 L .69462 .79065 L 0 1 .456 r
F
.69783 .77185 m .69254 .78004 L .69117 .78809 L F
.68861 .76465 m .70038 .76532 L .69762 .76143 L 0 1 .443 r
F
.68198 .75475 m .68861 .76465 L .69348 .75551 L 0 1 .439 r
F
.68198 .75475 m .69348 .75551 L .69072 .75153 L F
.68621 .74938 m .685 .76963 L .69226 .77042 L 0 .897 .421 r
F
.68661 .76364 m .68539 .78379 L .69254 .78003 L 0 1 .446 r
F
.67319 .76299 m .685 .76963 L .68068 .76343 L 0 .993 .424 r
F
.68621 .74938 m .68068 .76343 L .685 .76963 L 0 .897 .421 r
F
.68661 .76364 m .68115 .78063 L .68539 .78379 L 0 1 .446 r
F
.68621 .74938 m .69226 .77042 L .69763 .76527 L 0 .897 .421 r
F
.68661 .76364 m .69254 .78003 L .69783 .77185 L 0 1 .446 r
F
.68661 .76364 m .68166 .772 L .68115 .78063 L F
.68067 .77441 m .69108 .79388 L .69271 .776 L 0 1 .314 r
F
.67373 .78409 m .68406 .7919 L .68539 .78379 L 0 1 .457 r
F
.67373 .78409 m .68539 .78379 L .68115 .78063 L F
.68067 .77441 m .68698 .80026 L .69108 .79388 L 0 1 .314 r
F
.68465 .81562 m .69108 .79388 L .68698 .80026 L 0 1 .326 r
F
.68656 .78482 m .69291 .8138 L .68865 .80901 L 0 .565 .16 r
F
.67816 .85193 m .67572 .8644 L .68481 .85828 L 0 1 .499 r
F
.69123 .82911 m .67985 .84297 L .68263 .84548 L 0 1 .489 r
F
.69123 .82911 m .68353 .83596 L .67985 .84297 L F
.68368 .82287 m .68353 .83596 L .69123 .82911 L 0 1 .486 r
F
.68465 .81562 m .68953 .83566 L .69368 .82949 L 0 1 .326 r
F
.68465 .81562 m .68565 .82971 L .68953 .83566 L F
.6762 .86732 m .6867 .85971 L .68653 .84862 L 0 1 .316 r
F
.69149 .86581 m .67673 .8776 L .67915 .881 L 0 1 .481 r
F
.69149 .86581 m .68201 .8711 L .67673 .8776 L F
.6762 .86732 m .68373 .87322 L .6867 .85971 L 0 1 .316 r
F
.6762 .86732 m .68653 .84862 L .68332 .84607 L F
.68192 .87027 m .68865 .80901 L .69291 .8138 L 0 .415 .173 r
F
.68653 .84862 m .68995 .8638 L .69411 .85816 L 0 1 .339 r
F
.68653 .84862 m .69368 .82949 L .68953 .83566 L F
.68653 .84862 m .6867 .85971 L .68995 .8638 L F
.68192 .87027 m .69291 .8138 L .6944 .84042 L 0 .415 .173 r
F
.69149 .86581 m .68833 .87961 L .69818 .87435 L 0 1 .481 r
F
.71753 .81708 m .70715 .83207 L .71026 .83456 L 0 1 .486 r
F
.71753 .81708 m .71026 .83456 L .71827 .83078 L F
.71767 .82125 m .70718 .83313 L .71034 .83687 L 0 1 .469 r
F
.71767 .82125 m .71032 .82644 L .70718 .83313 L F
.69692 .8336 m .70751 .83343 L .70734 .82146 L 0 1 .356 r
F
.69692 .8336 m .70452 .84586 L .70751 .83343 L F
.69692 .8336 m .70734 .82146 L .70408 .81619 L F
.69692 .8336 m .70035 .85047 L .70452 .84586 L F
.69149 .86581 m .67915 .881 L .68833 .87961 L 0 1 .481 r
F
.68635 .87455 m .69602 .87038 L .69671 .86099 L 0 1 .349 r
F
.69692 .8336 m .70408 .81619 L .69992 .82115 L 0 1 .356 r
F
.69494 .79983 m .69992 .82115 L .70408 .81619 L 0 1 .34 r
F
.68635 .87455 m .69671 .86099 L .69411 .85816 L 0 1 .349 r
F
.69494 .79983 m .696 .81414 L .69992 .82115 L 0 1 .34 r
F
.68635 .87455 m .69411 .85816 L .68995 .8638 L 0 1 .349 r
F
.69209 .87149 m .69928 .81944 L .70351 .82216 L 0 .347 .158 r
F
.69209 .87149 m .6944 .84042 L .69928 .81944 L F
.69671 .86099 m .69602 .87038 L .6986 .87435 L 0 1 .372 r
F
.69209 .87149 m .70351 .82216 L .70477 .84355 L 0 .347 .158 r
F
.7138 .84782 m .72129 .854 L .72578 .84689 L 0 1 .497 r
F
.7138 .84782 m .72578 .84689 L .72268 .84444 L F
.70636 .84365 m .71396 .85256 L .7182 .8459 L 0 1 .475 r
F
.70636 .84365 m .7182 .8459 L .71506 .84234 L F
.72586 .82323 m .71493 .83827 L .71803 .84074 L 0 1 .489 r
F
.72586 .82323 m .71827 .83078 L .71493 .83827 L F
.71767 .82125 m .71034 .83687 L .71844 .83577 L 0 1 .469 r
F
.7092 .81142 m .71032 .82644 L .71767 .82125 L 0 1 .461 r
F
.72586 .82323 m .71803 .84074 L .72627 .83691 L 0 1 .489 r
F
.72586 .82323 m .72627 .83691 L .73417 .82932 L F
.72611 .83057 m .71506 .84234 L .7182 .8459 L 0 1 .476 r
F
.70709 .84985 m .71671 .85099 L .71749 .84068 L 0 1 .389 r
F
.72129 .854 m .72877 .86014 L .73351 .85298 L 0 1 .499 r
F
.72129 .854 m .73351 .85298 L .73042 .85055 L F
.71396 .85256 m .72153 .8611 L .72604 .85454 L 0 1 .481 r
F
.71396 .85256 m .72604 .85454 L .72291 .85113 L F
.70709 .84985 m .71304 .86126 L .71671 .85099 L 0 1 .389 r
F
.70709 .84985 m .70891 .86466 L .71304 .86126 L F
.72611 .83057 m .71844 .83577 L .71506 .84234 L 0 1 .476 r
F
.70709 .84985 m .71749 .84068 L .71495 .83577 L 0 1 .389 r
F
.70709 .84985 m .70636 .85977 L .70891 .86466 L F
.71753 .81708 m .71827 .83078 L .72586 .82323 L 0 1 .486 r
F
.71767 .82125 m .71844 .83577 L .72611 .83057 L 0 1 .469 r
F
.70734 .82146 m .71495 .83577 L .71796 .82379 L 0 1 .37 r
F
.70709 .84985 m .71495 .83577 L .71077 .83956 L 0 1 .389 r
F
.70734 .82146 m .71077 .83956 L .71495 .83577 L 0 1 .37 r
F
.70734 .82146 m .70751 .83343 L .71077 .83956 L F
.7022 .86963 m .70983 .82526 L .71403 .82666 L 0 .296 .14 r
F
.7022 .86963 m .70477 .84355 L .70983 .82526 L F
.7022 .86963 m .71403 .82666 L .71509 .84408 L F
.69818 .87435 m .68277 .88601 L .68518 .88929 L 0 1 .487 r
F
.69818 .87435 m .68833 .87961 L .68277 .88601 L F
.68635 .87455 m .69242 .8811 L .69602 .87038 L 0 1 .349 r
F
.69209 .87149 m .70477 .84355 L .7022 .86963 L 0 .347 .158 r
F
.7022 .86963 m .71509 .84408 L .71227 .86613 L 0 .296 .14 r
F
.69209 .87149 m .7022 .86963 L .69727 .8911 L 0 .347 .158 r
F
.7022 .86963 m .70717 .8848 L .70321 .88743 L 0 .296 .14 r
F
.7022 .86963 m .71227 .86613 L .70717 .8848 L F
.69042 .8059 m .70321 .88742 L .70716 .88479 L 0 .536 .27 r
F
.69042 .8059 m .69601 .85341 L .70321 .88742 L F
.68192 .87027 m .6944 .84042 L .69209 .87149 L 0 .415 .173 r
F
.68406 .7919 m .67903 .80961 L .68612 .80581 L 0 1 .466 r
F
.68406 .7919 m .67589 .80712 L .67903 .80961 L F
.68406 .7919 m .67804 .79953 L .67589 .80712 L F
.67373 .78409 m .67804 .79953 L .68406 .7919 L 0 1 .457 r
F
.67064 .7949 m .68084 .81113 L .68251 .79191 L 0 1 .302 r
F
.68368 .82287 m .67289 .83672 L .67568 .83922 L 0 1 .486 r
F
.68368 .82287 m .67632 .82972 L .67289 .83672 L F
.67611 .81665 m .67632 .82972 L .68368 .82287 L 0 1 .482 r
F
.67441 .83561 m .68465 .81562 L .68084 .81113 L 0 1 .309 r
F
.68368 .82287 m .67568 .83922 L .68353 .83596 L 0 1 .486 r
F
.67441 .83561 m .68565 .82971 L .68465 .81562 L 0 1 .309 r
F
.67804 .84766 m .66702 .86347 L .67567 .86225 L 0 1 .468 r
F
.67816 .85193 m .66711 .86706 L .67572 .8644 L 0 1 .499 r
F
.67816 .85193 m .6647 .86449 L .66711 .86706 L F
.67816 .85193 m .66943 .858 L .6647 .86449 L F
.67148 .84562 m .66943 .858 L .67816 .85193 L 0 1 .498 r
F
.67148 .84562 m .67816 .85193 L .68263 .84548 L F
.67148 .84562 m .68263 .84548 L .67985 .84297 L F
.67064 .7949 m .68251 .79191 L .68067 .77441 L 0 1 .302 r
F
.67441 .83561 m .68332 .84607 L .68565 .82971 L 0 1 .309 r
F
.67441 .83561 m .68084 .81113 L .67676 .81924 L F
.67064 .7949 m .67676 .81924 L .68084 .81113 L 0 1 .302 r
F
.67064 .7949 m .67238 .81228 L .67676 .81924 L F
.67441 .83561 m .67919 .85379 L .68332 .84607 L 0 1 .309 r
F
.67441 .83561 m .67537 .84931 L .67919 .85379 L F
.66425 .86107 m .67441 .83561 L .67067 .83309 L 0 1 .289 r
F
.66425 .86107 m .67537 .84931 L .67441 .83561 L F
.66425 .86107 m .67301 .86689 L .67537 .84931 L F
.67163 .86293 m .67788 .79126 L .6822 .79934 L 0 .483 .186 r
F
.67163 .86293 m .6822 .79934 L .68395 .833 L F
.6762 .86732 m .68332 .84607 L .67919 .85379 L 0 1 .316 r
F
.68192 .87027 m .68395 .833 L .68865 .80901 L 0 .415 .173 r
F
.68068 .79994 m .69626 .88554 L .69601 .85341 L 0 .494 .261 r
F
.69626 .88554 m .69727 .8911 L .69705 .88473 L F
.69626 .88554 m .69705 .88473 L .69601 .85341 L F
.70691 .77724 m .70314 .79377 L .70928 .79343 L 0 .949 .444 r
F
.70928 .79307 m .70928 .79343 L .70934 .79343 L F
.70691 .77724 m .70928 .79343 L .70928 .79307 L F
.70932 .78011 m .7102 .79291 L .71606 .78488 L 0 1 .464 r
F
.70691 .77724 m .70934 .79343 L .70933 .7934 L 0 .949 .444 r
F
.7093 .78887 m .70934 .79343 L .7102 .79291 L 0 1 .464 r
F
.70691 .77724 m .70934 .79343 L .70951 .79125 L 0 .949 .444 r
F
.70949 .78982 m .70951 .79125 L .70959 .79031 L F
.70691 .77724 m .70951 .79125 L .70949 .78982 L F
.70929 .77809 m .71606 .78488 L .71766 .7769 L 0 1 .464 r
F
.70925 .78006 m .7093 .78887 L .70932 .78011 L F
.70691 .77724 m .7093 .78887 L .70925 .78006 L 0 .949 .444 r
F
.70695 .77843 m .7093 .78887 L .70925 .78006 L 0 1 .464 r
F
.7093 .78887 m .7102 .79291 L .70932 .78011 L F
.7093 .78887 m .70949 .78982 L .70925 .78006 L 0 .949 .444 r
F
.71606 .78488 m .7102 .79291 L .70942 .79635 L 0 1 .47 r
F
.71606 .78488 m .70942 .79635 L .70946 .7972 L F
.70951 .7985 m .70942 .79635 L .70838 .80021 L 0 .977 .454 r
F
.71606 .78488 m .70905 .79795 L .70903 .79829 L 0 1 .47 r
F
.71606 .78488 m .70893 .79847 L .70881 .79995 L F
.71618 .78841 m .71022 .79338 L .70942 .79635 L 0 .977 .454 r
F
.71618 .78841 m .70942 .79635 L .70951 .7985 L F
.70946 .7972 m .70942 .79635 L .70905 .79795 L 0 1 .47 r
F
.70903 .79829 m .70905 .79795 L .70893 .79847 L F
.71023 .78123 m .71022 .79338 L .71618 .78841 L 0 .949 .444 r
F
.70925 .78006 m .70979 .78747 L .71023 .78123 L F
.70979 .78747 m .71022 .79338 L .71023 .78123 L F
.70949 .78982 m .71022 .79338 L .70925 .78006 L F
.70919 .7771 m .71766 .7769 L .71394 .7743 L 0 1 .464 r
F
.70932 .78011 m .71606 .78488 L .70929 .77809 L F
.71606 .78488 m .71901 .79922 L .72515 .79121 L 0 1 .47 r
F
.71606 .78488 m .72515 .79121 L .72698 .78329 L F
.71606 .78488 m .72698 .78329 L .72325 .78075 L F
.70923 .7781 m .71618 .78841 L .71781 .78131 L 0 .949 .444 r
F
.70923 .7781 m .70932 .78011 L .70929 .77809 L 0 1 .464 r
F
.70691 .77724 m .70925 .78006 L .70923 .7781 L 0 .949 .444 r
F
.70922 .77835 m .70923 .77863 L .70923 .7781 L 0 1 .464 r
F
.70923 .77863 m .70932 .78011 L .70923 .7781 L F
.70925 .78006 m .70932 .78011 L .7092 .7781 L F
.70925 .78006 m .70942 .78026 L .70923 .7781 L 0 .949 .444 r
F
.70942 .78026 m .71618 .78841 L .70923 .7781 L F
.70691 .77724 m .70923 .7781 L .70919 .7771 L F
.70914 .77713 m .70923 .7781 L .70919 .7771 L 0 1 .464 r
F
.70695 .77843 m .70923 .7781 L .70914 .77713 L F
.70923 .7781 m .71766 .7769 L .70919 .7771 L F
.70919 .7771 m .70923 .7781 L .70927 .7771 L 0 .949 .444 r
F
.70927 .7771 m .71781 .78131 L .71402 .77682 L F
.70923 .7781 m .71781 .78131 L .70927 .7771 L F
.7092 .7781 m .70922 .77835 L .70923 .7781 L 0 1 .464 r
F
.70695 .77843 m .70925 .78006 L .7092 .7781 L F
.70695 .77843 m .70324 .79702 L .70934 .79343 L F
.70695 .77843 m .70934 .79343 L .7093 .78887 L F
.70933 .7934 m .70934 .79343 L .70934 .79343 L 0 .949 .444 r
F
.70959 .79031 m .70934 .79343 L .71022 .79338 L F
.70881 .79995 m .70893 .79847 L .7084 .80082 L 0 1 .47 r
F
.70691 .77724 m .69964 .78935 L .70314 .79377 L 0 .949 .444 r
F
.70691 .77724 m .70125 .78227 L .69964 .78935 L F
.70695 .77843 m .69979 .79448 L .70324 .79702 L 0 1 .464 r
F
.70695 .77843 m .70138 .78652 L .69979 .79448 L F
.69763 .76527 m .70125 .78227 L .70691 .77724 L 0 .922 .434 r
F
.69783 .77185 m .69462 .79065 L .70138 .78652 L 0 1 .456 r
F
.69783 .77185 m .70138 .78652 L .70695 .77843 L F
.69494 .79983 m .7053 .78731 L .70139 .78029 L 0 1 .34 r
F
.69494 .79983 m .70639 .80169 L .7053 .78731 L F
.69494 .79983 m .70408 .81619 L .70639 .80169 L F
.69494 .79983 m .70139 .78029 L .69726 .78532 L F
.68656 .78482 m .69735 .79929 L .69291 .8138 L 0 .565 .16 r
F
.69042 .8059 m .70595 .87906 L .70581 .85079 L 0 .536 .27 r
F
.70595 .87906 m .70716 .88479 L .7069 .87812 L F
.70595 .87906 m .7069 .87812 L .70581 .85079 L F
.72153 .8611 m .71961 .87463 L .72908 .86929 L 0 1 .486 r
F
.71485 .86526 m .71894 .87625 L .72331 .86761 L 0 1 .422 r
F
.71485 .86526 m .71491 .87868 L .71894 .87625 L F
.72153 .8611 m .72908 .86929 L .73386 .86282 L 0 1 .486 r
F
.72153 .8611 m .73386 .86282 L .73074 .85955 L F
.71485 .86526 m .72331 .86761 L .72511 .8585 L 0 1 .422 r
F
.71485 .86526 m .71315 .87398 L .71491 .87868 L F
.71485 .86526 m .72511 .8585 L .72336 .85378 L F
.71485 .86526 m .72336 .85378 L .71923 .8566 L F
.73417 .82932 m .72268 .84444 L .72578 .84689 L 0 1 .492 r
F
.73417 .82932 m .72627 .83691 L .72268 .84444 L F
.72611 .83057 m .7182 .8459 L .72653 .84466 L 0 1 .476 r
F
.72586 .82323 m .73417 .82932 L .73754 .8218 L 0 1 .489 r
F
.72586 .82323 m .73754 .8218 L .73413 .81938 L F
.71753 .81708 m .72586 .82323 L .72899 .81572 L 0 1 .486 r
F
.71767 .82125 m .72611 .83057 L .72927 .82386 L 0 1 .469 r
F
.73417 .82932 m .72578 .84689 L .73425 .84299 L 0 1 .492 r
F
.73417 .82932 m .73425 .84299 L .74246 .83533 L F
.73453 .83943 m .72291 .85113 L .72604 .85454 L 0 1 .482 r
F
.73453 .83943 m .72653 .84466 L .72291 .85113 L F
.72611 .83057 m .72653 .84466 L .73453 .83943 L 0 1 .476 r
F
.71749 .84068 m .72336 .85378 L .72708 .84371 L 0 1 .403 r
F
.71749 .84068 m .71923 .8566 L .72336 .85378 L F
.71749 .84068 m .72708 .84371 L .72792 .83309 L F
.71749 .84068 m .71671 .85099 L .71923 .8566 L F
.72611 .83057 m .73453 .83943 L .73794 .83284 L 0 1 .476 r
F
.73417 .82932 m .74246 .83533 L .74608 .82778 L 0 1 .492 r
F
.72611 .83057 m .73794 .83284 L .73448 .8293 L 0 1 .476 r
F
.71749 .84068 m .72792 .83309 L .72541 .82746 L 0 1 .403 r
F
.71749 .84068 m .72541 .82746 L .72122 .83059 L F
.71753 .81708 m .72899 .81572 L .72557 .81327 L 0 1 .486 r
F
.71767 .82125 m .72927 .82386 L .7258 .82013 L 0 1 .469 r
F
.7092 .81142 m .71767 .82125 L .72058 .81439 L 0 1 .461 r
F
.7092 .81142 m .72058 .81439 L .7171 .81045 L F
.71779 .8116 m .72122 .83059 L .72541 .82746 L 0 1 .383 r
F
.71779 .8116 m .71796 .82379 L .72122 .83059 L F
.71227 .86612 m .7213 .82815 L .72679 .82874 L 0 .259 .12 r
F
.71227 .86612 m .71509 .84408 L .7213 .82815 L F
.74246 .83533 m .73351 .85298 L .74221 .84901 L 0 1 .495 r
F
.74246 .83533 m .73042 .85055 L .73351 .85298 L F
.74246 .83533 m .73425 .84299 L .73042 .85055 L F
.73453 .83943 m .72604 .85454 L .73461 .85315 L 0 1 .482 r
F
.72792 .83309 m .72709 .84371 L .73054 .84941 L 0 1 .415 r
F
.71227 .86612 m .72679 .82874 L .72859 .84242 L 0 .259 .12 r
F
.69735 .79929 m .70351 .82216 L .69928 .81944 L 0 .495 .147 r
F
.69735 .79929 m .70804 .80843 L .70351 .82216 L F
.69042 .8059 m .70581 .85079 L .7001 .80842 L 0 .536 .27 r
F
.74246 .83533 m .74221 .84901 L .75074 .84126 L 0 1 .495 r
F
.74292 .84787 m .73386 .86282 L .74266 .86128 L 0 1 .488 r
F
.74292 .84787 m .73074 .85955 L .73386 .86282 L F
.72511 .8585 m .73124 .86992 L .73665 .86085 L 0 1 .436 r
F
.72511 .8585 m .72594 .87249 L .73124 .86992 L F
.74292 .84787 m .73461 .85315 L .73074 .85955 L 0 1 .488 r
F
.72511 .8585 m .73665 .86085 L .73858 .85132 L 0 1 .436 r
F
.72511 .8585 m .72331 .86761 L .72594 .87249 L F
.73453 .83943 m .73461 .85315 L .74292 .84787 L 0 1 .482 r
F
.72511 .8585 m .73858 .85132 L .73597 .84641 L 0 1 .436 r
F
.72511 .8585 m .73597 .84641 L .73054 .84941 L F
.71227 .86612 m .72859 .84242 L .72548 .86025 L 0 .259 .12 r
F
.71227 .86612 m .72548 .86025 L .71922 .87647 L F
.7001 .80842 m .71797 .87203 L .71866 .84567 L 0 .575 .28 r
F
.71797 .87203 m .71922 .87646 L .71912 .87097 L F
.71797 .87203 m .71912 .87097 L .71866 .84567 L F
.73417 .82932 m .74608 .82778 L .74267 .8254 L 0 1 .492 r
F
.74329 .8035 m .73754 .8218 L .74534 .81755 L 0 1 .485 r
F
.74383 .81797 m .73448 .8293 L .73794 .83284 L 0 1 .478 r
F
.74383 .81797 m .73699 .82294 L .73448 .8293 L F
.73453 .83943 m .74292 .84787 L .74659 .84138 L 0 1 .482 r
F
.73453 .83943 m .74659 .84138 L .74313 .83802 L F
.72792 .83309 m .73597 .84641 L .74072 .83598 L 0 1 .415 r
F
.72792 .83309 m .73054 .84941 L .73597 .84641 L F
.75234 .80945 m .74267 .8254 L .74608 .82778 L 0 1 .489 r
F
.75234 .80945 m .74534 .81755 L .74267 .8254 L F
.74383 .81797 m .73794 .83284 L .74587 .83174 L 0 1 .478 r
F
.72792 .83309 m .74072 .83598 L .74163 .82506 L 0 1 .415 r
F
.74329 .8035 m .73413 .81938 L .73754 .8218 L 0 1 .485 r
F
.74329 .8035 m .73658 .81154 L .73413 .81938 L F
.73423 .79742 m .72899 .81572 L .73658 .81154 L 0 1 .48 r
F
.73463 .80871 m .72927 .82386 L .73699 .82294 L 0 1 .471 r
F
.73423 .79742 m .73658 .81154 L .74329 .8035 L 0 1 .48 r
F
.73463 .80871 m .73699 .82294 L .74383 .81797 L 0 1 .471 r
F
.72792 .83309 m .74163 .82506 L .73819 .81934 L 0 1 .415 r
F
.72548 .86025 m .73426 .82903 L .73872 .82883 L 0 .209 .101 r
F
.72548 .86025 m .7286 .84242 L .73426 .82903 L F
.72548 .86025 m .73872 .82883 L .73957 .83987 L F
.70734 .82146 m .71796 .82379 L .71779 .8116 L 0 1 .37 r
F
.72515 .79121 m .72042 .80957 L .7278 .80543 L 0 1 .476 r
F
.72515 .79121 m .71699 .80708 L .72042 .80957 L F
.72541 .79888 m .7171 .81045 L .72058 .81439 L 0 1 .462 r
F
.72541 .79888 m .71916 .80381 L .7171 .81045 L F
.70734 .82146 m .71779 .8116 L .71453 .80545 L 0 1 .37 r
F
.70734 .82146 m .71453 .80545 L .71035 .80947 L F
.72515 .79121 m .71901 .79922 L .71699 .80708 L 0 1 .476 r
F
.71618 .78841 m .71187 .80438 L .71916 .80381 L 0 .977 .454 r
F
.7053 .78731 m .71035 .80947 L .71453 .80545 L 0 1 .353 r
F
.7053 .78731 m .70639 .80169 L .71035 .80947 L F
.71618 .78841 m .71916 .80381 L .72541 .79888 L 0 .977 .454 r
F
.73423 .79742 m .72557 .81327 L .72899 .81572 L 0 1 .48 r
F
.73423 .79742 m .7278 .80543 L .72557 .81327 L F
.73463 .80871 m .72809 .81365 L .7258 .82013 L 0 1 .471 r
F
.72515 .79121 m .7278 .80543 L .73423 .79742 L 0 1 .476 r
F
.72541 .79888 m .72058 .81439 L .72809 .81365 L 0 1 .462 r
F
.72541 .79888 m .72809 .81365 L .73463 .80871 L F
.71779 .8116 m .72843 .81588 L .72828 .80354 L 0 1 .383 r
F
.73463 .80871 m .7258 .82013 L .72927 .82386 L 0 1 .471 r
F
.71779 .8116 m .72541 .82746 L .72843 .81588 L 0 1 .383 r
F
.72515 .79121 m .73423 .79742 L .73627 .78953 L 0 1 .476 r
F
.71618 .78841 m .72541 .79888 L .72728 .79202 L 0 .977 .454 r
F
.72541 .79888 m .73463 .80871 L .73672 .80205 L 0 1 .462 r
F
.72541 .79888 m .73672 .80205 L .73295 .79812 L F
.71779 .8116 m .72828 .80354 L .72502 .79673 L 0 1 .383 r
F
.71779 .8116 m .72502 .79673 L .72082 .79999 L F
.72515 .79121 m .73627 .78953 L .73256 .78705 L 0 1 .476 r
F
.71618 .78841 m .72728 .79202 L .72349 .78783 L 0 .977 .454 r
F
.71794 .75316 m .71621 .77136 L .72542 .76279 L 0 1 .443 r
F
.71946 .75756 m .71766 .7769 L .72421 .77257 L 0 1 .458 r
F
.71794 .75316 m .70726 .77492 L .71621 .77136 L 0 1 .443 r
F
.71946 .75756 m .71394 .7743 L .71766 .7769 L 0 1 .458 r
F
.71972 .76552 m .71402 .77682 L .71781 .78131 L 0 .84 .443 r
F
.7157 .77734 m .72082 .79999 L .72502 .79673 L 0 1 .365 r
F
.7157 .77734 m .71683 .79168 L .72082 .79999 L F
.7053 .78731 m .71453 .80545 L .71683 .79168 L 0 1 .353 r
F
.70804 .80843 m .72063 .79592 L .71867 .81402 L 0 .422 .132 r
F
.70804 .80843 m .71403 .82666 L .70983 .82526 L F
.70804 .80843 m .71867 .81402 L .71403 .82666 L F
.7001 .80842 m .71866 .84567 L .71276 .80848 L 0 .575 .28 r
F
.72548 .86025 m .73957 .83987 L .73622 .85493 L 0 .209 .101 r
F
.71867 .81402 m .72679 .82874 L .7213 .82815 L 0 .342 .114 r
F
.72548 .86025 m .73622 .85493 L .73052 .86855 L 0 .209 .101 r
F
.71276 .80848 m .72941 .8648 L .72912 .84074 L 0 .626 .293 r
F
.72941 .8648 m .73052 .86855 L .73029 .86403 L F
.72941 .8648 m .73029 .86403 L .72912 .84074 L F
.74292 .84787 m .74266 .86128 L .7513 .85595 L 0 1 .488 r
F
.73858 .85132 m .74276 .86505 L .74752 .85644 L 0 1 .448 r
F
.73858 .85132 m .73845 .86672 L .74276 .86505 L F
.74292 .84787 m .7513 .85595 L .75521 .84953 L 0 1 .488 r
F
.74292 .84787 m .75521 .84953 L .75177 .84632 L F
.73858 .85132 m .74752 .85644 L .74956 .84663 L 0 1 .448 r
F
.73858 .85132 m .73665 .86085 L .73845 .86672 L F
.74246 .83533 m .75074 .84126 L .7546 .83368 L 0 1 .495 r
F
.74246 .83533 m .7546 .83368 L .75119 .83133 L F
.76136 .81529 m .75119 .83133 L .7546 .83368 L 0 1 .492 r
F
.76136 .81529 m .75408 .82346 L .75119 .83133 L F
.753 .82671 m .74659 .84138 L .75473 .8401 L 0 1 .485 r
F
.73858 .85132 m .74956 .84663 L .74778 .84072 L 0 1 .448 r
F
.753 .82671 m .74313 .83802 L .74659 .84138 L 0 1 .485 r
F
.73858 .85132 m .74778 .84072 L .74336 .84269 L 0 1 .448 r
F
.753 .82671 m .74587 .83174 L .74313 .83802 L 0 1 .485 r
F
.75234 .80945 m .74608 .82778 L .75408 .82346 L 0 1 .489 r
F
.74383 .81797 m .74587 .83174 L .753 .82671 L 0 1 .478 r
F
.74163 .82506 m .74778 .84072 L .75183 .83093 L 0 1 .427 r
F
.74163 .82506 m .74336 .84269 L .74778 .84072 L F
.75234 .80945 m .75408 .82346 L .76136 .81529 L 0 1 .489 r
F
.74383 .81797 m .753 .82671 L .75555 .82033 L 0 1 .478 r
F
.74163 .82506 m .75183 .83093 L .75281 .81982 L 0 1 .427 r
F
.74163 .82506 m .74072 .83598 L .74336 .84269 L F
.73622 .85493 m .7454 .82823 L .74986 .82764 L 0 .159 .087 r
F
.73622 .85493 m .73957 .83987 L .7454 .82823 L F
.73622 .85493 m .74986 .82764 L .75054 .83667 L F
.73622 .85493 m .75054 .83667 L .74698 .84941 L F
.72922 .76418 m .72698 .78329 L .7337 .77894 L 0 1 .465 r
F
.72922 .76418 m .72325 .78075 L .72698 .78329 L F
.72966 .77686 m .72349 .78783 L .72728 .79202 L 0 .874 .453 r
F
.73896 .77058 m .73256 .78705 L .73627 .78953 L 0 1 .472 r
F
.73896 .77058 m .7337 .77894 L .73256 .78705 L F
.72966 .77686 m .72728 .79202 L .73416 .79184 L 0 .874 .453 r
F
.73896 .77058 m .73627 .78953 L .74318 .78514 L 0 1 .472 r
F
.72922 .76418 m .72421 .77257 L .72325 .78075 L 0 1 .465 r
F
.72966 .77686 m .72451 .78133 L .72349 .78783 L 0 .874 .453 r
F
.71794 .75316 m .72542 .76279 L .73001 .75345 L 0 1 .443 r
F
.71946 .75756 m .72421 .77257 L .72922 .76418 L 0 1 .458 r
F
.71972 .76552 m .72451 .78133 L .72966 .77686 L 0 .84 .443 r
F
.72966 .77686 m .73416 .79184 L .73957 .78738 L 0 .874 .453 r
F
.71972 .76552 m .72966 .77686 L .73049 .77008 L 0 .84 .443 r
F
.72922 .76418 m .7337 .77894 L .73896 .77058 L 0 1 .465 r
F
.72966 .77686 m .74061 .78086 L .73657 .77665 L 0 .874 .453 r
F
.72966 .77686 m .73957 .78738 L .74061 .78086 L F
.72615 .76934 m .73232 .79172 L .73785 .78831 L 0 1 .377 r
F
.72615 .76934 m .72731 .78359 L .73232 .79172 L F
.71972 .76552 m .71781 .78131 L .72451 .78133 L 0 .84 .443 r
F
.7157 .77734 m .72502 .79673 L .7273 .78359 L 0 1 .365 r
F
.71867 .81402 m .72635 .78523 L .73205 .78891 L 0 .342 .114 r
F
.71867 .81402 m .72063 .79593 L .72635 .78523 L F
.73423 .79742 m .74329 .8035 L .74555 .79563 L 0 1 .48 r
F
.73423 .79742 m .74555 .79563 L .74184 .79321 L F
.73957 .78738 m .73295 .79812 L .73672 .80205 L 0 .909 .463 r
F
.73957 .78738 m .73416 .79184 L .73295 .79812 L F
.74329 .8035 m .74534 .81755 L .75234 .80945 L 0 1 .485 r
F
.73463 .80871 m .74383 .81797 L .74615 .81146 L 0 1 .471 r
F
.73463 .80871 m .74615 .81146 L .74238 .80777 L F
.72828 .80354 m .73819 .81934 L .74222 .80754 L 0 1 .395 r
F
.72828 .80354 m .73269 .82264 L .73819 .81934 L F
.73957 .78738 m .73672 .80205 L .74379 .80164 L 0 .909 .463 r
F
.74869 .77678 m .74555 .79563 L .75264 .79117 L 0 1 .477 r
F
.74869 .77678 m .74184 .79321 L .74555 .79563 L F
.74869 .77678 m .74318 .78514 L .74184 .79321 L F
.73957 .78738 m .74379 .80164 L .74947 .79716 L 0 .909 .463 r
F
.72828 .80354 m .74222 .80754 L .74209 .79509 L 0 1 .395 r
F
.72828 .80354 m .72844 .81587 L .73269 .82264 L F
.72828 .80354 m .74209 .79509 L .73785 .78831 L F
.72828 .80354 m .73785 .78831 L .73232 .79172 L F
.71867 .81402 m .73205 .78891 L .73472 .80283 L 0 .342 .114 r
F
.71867 .81402 m .73472 .80283 L .73255 .81783 L F
.71867 .81402 m .73255 .81783 L .72679 .82874 L F
.71276 .80848 m .72912 .84074 L .72305 .80681 L 0 .626 .293 r
F
.72792 .83309 m .73819 .81934 L .73269 .82264 L 0 1 .415 r
F
.73255 .81783 m .73872 .82883 L .73426 .82903 L 0 .284 .099 r
F
.73622 .85493 m .74698 .84941 L .7411 .86123 L 0 .159 .087 r
F
.72305 .80681 m .74001 .85793 L .73957 .83545 L 0 .667 .303 r
F
.74001 .85793 m .7411 .86122 L .74086 .85721 L F
.74001 .85793 m .74086 .85721 L .73957 .83545 L F
.74956 .84663 m .74752 .85644 L .74923 .86277 L 0 1 .456 r
F
.76136 .81529 m .7546 .83368 L .76281 .82927 L 0 1 .492 r
F
.753 .82671 m .75473 .8401 L .76215 .835 L 0 1 .485 r
F
.76136 .81529 m .76281 .82927 L .77038 .82102 L 0 1 .492 r
F
.753 .82671 m .76215 .835 L .76493 .8287 L 0 1 .485 r
F
.753 .82671 m .76493 .8287 L .76118 .8254 L F
.76136 .81529 m .77038 .82102 L .7733 .81312 L 0 1 .492 r
F
.76919 .81483 m .76118 .8254 L .76493 .8287 L 0 1 .487 r
F
.75281 .81982 m .75885 .83643 L .76296 .82678 L 0 1 .436 r
F
.75281 .81982 m .75442 .83804 L .75885 .83643 L F
.75281 .81982 m .75183 .83093 L .75442 .83804 L F
.74698 .84941 m .75654 .82655 L .76099 .82569 L 0 .1 .071 r
F
.74698 .84941 m .75054 .83667 L .75654 .82655 L F
.76215 .835 m .75473 .8401 L .75177 .84632 L 0 1 .491 r
F
.74956 .84663 m .75885 .83643 L .75442 .83804 L 0 1 .456 r
F
.74698 .84941 m .76099 .82569 L .76152 .83305 L 0 .1 .071 r
F
.76215 .835 m .75177 .84632 L .75521 .84953 L 0 1 .491 r
F
.74956 .84663 m .75354 .8614 L .75839 .85285 L 0 1 .456 r
F
.74956 .84663 m .74923 .86277 L .75354 .8614 L F
.76215 .835 m .75521 .84953 L .76356 .84806 L 0 1 .491 r
F
.74956 .84663 m .75839 .85285 L .76055 .84278 L 0 1 .456 r
F
.74956 .84663 m .76055 .84278 L .75885 .83643 L F
.74698 .84941 m .76152 .83305 L .75774 .8438 L 0 .1 .071 r
F
.74329 .8035 m .75234 .80945 L .75482 .80159 L 0 1 .485 r
F
.74329 .8035 m .75482 .80159 L .75111 .79922 L F
.75234 .80945 m .76136 .81529 L .76407 .80742 L 0 1 .489 r
F
.75234 .80945 m .76407 .80742 L .76037 .8051 L F
.74947 .79716 m .74615 .81146 L .7534 .81083 L 0 .944 .472 r
F
.74947 .79716 m .74238 .80777 L .74615 .81146 L F
.74947 .79716 m .74379 .80164 L .74238 .80777 L F
.75841 .78278 m .75111 .79922 L .75482 .80159 L 0 1 .482 r
F
.75841 .78278 m .75264 .79117 L .75111 .79922 L F
.74947 .79716 m .7534 .81083 L .75934 .80628 L 0 .944 .472 r
F
.74209 .79509 m .75018 .81309 L .75347 .80211 L 0 1 .408 r
F
.74209 .79509 m .74569 .81525 L .75018 .81309 L F
.74869 .77678 m .75264 .79117 L .75841 .78278 L 0 1 .477 r
F
.73957 .78738 m .74947 .79716 L .75071 .79085 L 0 .909 .463 r
F
.75841 .78278 m .75482 .80159 L .76209 .79705 L 0 1 .482 r
F
.74947 .79716 m .76078 .80014 L .75676 .7965 L 0 .944 .472 r
F
.74947 .79716 m .75934 .80628 L .76078 .80014 L F
.74869 .77678 m .75841 .78278 L .75977 .77467 L 0 1 .477 r
F
.75155 .7775 m .75071 .79085 L .75728 .79094 L 0 .781 .456 r
F
.74209 .79509 m .75347 .80211 L .75336 .78961 L 0 1 .408 r
F
.74209 .79509 m .74222 .80754 L .74569 .81525 L F
.73957 .78738 m .75071 .79085 L .74667 .78695 L 0 .909 .463 r
F
.75155 .7775 m .74667 .78695 L .75071 .79085 L 0 .781 .456 r
F
.74209 .79509 m .75336 .78961 L .7499 .78188 L 0 1 .408 r
F
.75155 .7775 m .74702 .78123 L .74667 .78695 L 0 .781 .456 r
F
.74209 .79509 m .7499 .78188 L .74538 .78409 L 0 1 .408 r
F
.73255 .81783 m .7398 .79315 L .74442 .79511 L 0 .284 .099 r
F
.73255 .81783 m .73472 .80283 L .7398 .79315 L F
.73255 .81783 m .74442 .79511 L .74616 .80613 L F
.74383 .81797 m .75555 .82033 L .75179 .81684 L 0 1 .478 r
F
.73255 .81783 m .74616 .80613 L .74383 .81897 L 0 .284 .099 r
F
.73255 .81783 m .74383 .81897 L .73872 .82883 L F
.72305 .80681 m .73957 .83545 L .73333 .80414 L 0 .667 .303 r
F
.74163 .82506 m .75281 .81982 L .75018 .81309 L 0 1 .427 r
F
.74163 .82506 m .75018 .81309 L .74569 .81525 L F
.74383 .81897 m .74986 .82764 L .7454 .82823 L 0 .239 .087 r
F
.74698 .84941 m .75774 .8438 L .7517 .85407 L 0 .1 .071 r
F
.73333 .80414 m .7517 .85406 L .75004 .82997 L 0 .707 .314 r
F
.74698 .84941 m .7517 .85407 L .74746 .85691 L 0 .1 .071 r
F
.73333 .80414 m .74746 .8569 L .7517 .85406 L 0 .707 .314 r
F
.73333 .80414 m .73957 .83545 L .74746 .8569 L F
.73425 .82996 m .74901 .85036 L .75043 .84004 L 0 1 .383 r
F
.74901 .85036 m .7517 .85407 L .75119 .84852 L F
.74901 .85036 m .75119 .84852 L .75043 .84004 L F
.73622 .85493 m .7411 .86123 L .73687 .86414 L 0 .159 .087 r
F
.72305 .80681 m .73687 .86414 L .7411 .86122 L 0 .667 .303 r
F
.72305 .80681 m .72912 .84074 L .73687 .86414 L F
.72402 .83557 m .73828 .85699 L .73998 .84658 L 0 .951 .37 r
F
.73828 .85699 m .7411 .86123 L .74062 .85493 L F
.73828 .85699 m .74062 .85493 L .73998 .84658 L F
.72548 .86025 m .73052 .86855 L .72629 .87152 L 0 .209 .101 r
F
.71276 .80848 m .72629 .87151 L .73052 .86855 L 0 .626 .293 r
F
.71276 .80848 m .71866 .84567 L .72629 .87151 L F
.7138 .84087 m .72735 .86332 L .72954 .85314 L 0 .893 .356 r
F
.72735 .86332 m .73052 .86855 L .73003 .86083 L F
.72735 .86332 m .73003 .86083 L .72954 .85314 L F
.70994 .88604 m .71992 .8803 L .71894 .87625 L 0 1 .436 r
F
.70994 .88604 m .71894 .87625 L .71491 .87868 L F
.71227 .86612 m .71922 .87647 L .71403 .8801 L 0 .259 .12 r
F
.7001 .80842 m .71403 .8801 L .71922 .87646 L 0 .575 .28 r
F
.7001 .80842 m .70581 .85079 L .71403 .8801 L F
.70125 .84654 m .71527 .86989 L .71912 .85964 L 0 .816 .339 r
F
.71527 .86989 m .71922 .87647 L .71916 .86607 L F
.71527 .86989 m .71916 .86607 L .71912 .85964 L F
.69167 .84973 m .704 .87764 L .70632 .86726 L 0 .75 .325 r
F
.704 .87764 m .70716 .8848 L .70669 .8749 L F
.704 .87764 m .70669 .8749 L .70632 .86726 L F
.69167 .84973 m .70321 .88743 L .70716 .8848 L F
.69167 .84973 m .69656 .87237 L .70321 .88743 L F
.69783 .89095 m .70316 .88747 L .70701 .88491 L 0 .806 .167 r
F
.68679 .89997 m .68725 .89681 L .68336 .90287 L 0 .781 .284 r
F
.68347 .90328 m .69322 .89347 L .69698 .89137 L 0 0 0 r
F
.70269 .90938 m .70294 .916 L .71006 .91606 L 0 1 .482 r
F
.70269 .90938 m .71006 .91606 L .71174 .91533 L F
.71173 .9153 m .71174 .91533 L .71177 .91532 L F
.70269 .90938 m .71174 .91533 L .71173 .9153 L F
.71038 .91045 m .71481 .91132 L .7147 .90787 L 0 1 .457 r
F
.70269 .90938 m .71177 .91532 L .71176 .9153 L 0 1 .482 r
F
.71095 .91249 m .71177 .91532 L .71184 .91523 L 0 1 .457 r
F
.71095 .91249 m .71184 .91523 L .71481 .91132 L F
.7105 .91088 m .71481 .91132 L .71038 .91045 L F
.71095 .91249 m .71122 .91241 L .7105 .91088 L F
.71122 .91241 m .71481 .91132 L .7105 .91088 L F
.70269 .90938 m .71032 .91049 L .70983 .90943 L 0 1 .482 r
F
.70269 .90938 m .71095 .91249 L .7103 .91048 L F
.70269 .90938 m .71179 .91531 L .71043 .9123 L F
.70269 .90938 m .69827 .91385 L .70294 .916 L F
.70286 .91495 m .71032 .91049 L .70983 .90946 L 0 1 .457 r
F
.71046 .9104 m .7147 .90787 L .70988 .90945 L F
.71246 .89898 m .70984 .90942 L .7147 .90787 L 0 1 .461 r
F
.70984 .90942 m .70983 .90943 L .70988 .90945 L 0 .989 .43 r
F
.70983 .90943 m .70988 .90945 L .70983 .90943 L 0 1 .482 r
F
.70988 .90945 m .70988 .90945 L .70983 .90943 L F
.71032 .91049 m .71046 .9104 L .70988 .90945 L 0 1 .457 r
F
.71032 .91049 m .71481 .91114 L .70983 .90943 L 0 1 .482 r
F
.70984 .90942 m .70983 .90946 L .70988 .90945 L 0 1 .461 r
F
.70984 .90942 m .70988 .90945 L .7147 .90787 L F
.70985 .90941 m .70984 .90942 L .70988 .90945 L 0 .989 .43 r
F
.71267 .90548 m .70985 .90941 L .71481 .91114 L F
.70985 .90941 m .70988 .90945 L .71481 .91114 L F
.71032 .91049 m .70988 .90945 L .70983 .90946 L 0 1 .457 r
F
.70988 .90945 m .71481 .91114 L .70988 .90945 L 0 1 .482 r
F
.71481 .91132 m .71345 .91903 L .71959 .91567 L 0 1 .48 r
F
.70223 .91919 m .7115 .92353 L .71308 .92048 L 0 1 .519 r
F
.70223 .91919 m .71308 .92048 L .70929 .91884 L F
.71339 .91937 m .70929 .91884 L .71308 .92048 L 0 1 .499 r
F
.71481 .91132 m .71218 .91634 L .71339 .91937 L 0 1 .48 r
F
.7149 .91398 m .71218 .91634 L .71339 .91937 L 0 1 .499 r
F
.71218 .91634 m .70929 .91884 L .71339 .91937 L F
.71218 .91634 m .71211 .91646 L .71339 .91937 L 0 1 .48 r
F
.71339 .91937 m .70938 .92167 L .7131 .92103 L F
.71211 .91646 m .70938 .92167 L .71339 .91937 L F
.71345 .91903 m .71401 .92028 L .71959 .91567 L F
.72453 .90912 m .71868 .92025 L .72239 .91983 L 0 1 .494 r
F
.72453 .90912 m .71959 .91567 L .71868 .92025 L F
.7149 .91398 m .71339 .91937 L .71972 .9199 L 0 1 .499 r
F
.71345 .91903 m .71339 .91937 L .71401 .92028 L 0 1 .48 r
F
.71339 .91937 m .71308 .92048 L .71384 .92042 L 0 1 .499 r
F
.71339 .91937 m .7131 .92103 L .71384 .92042 L 0 1 .48 r
F
.71339 .91937 m .71384 .92042 L .71401 .92028 L F
.71339 .91937 m .71384 .92042 L .71385 .92042 L 0 1 .499 r
F
.71339 .91937 m .71385 .92042 L .71972 .9199 L F
.71218 .91634 m .71006 .91606 L .70929 .91884 L F
.71218 .91634 m .71011 .91751 L .70938 .92167 L 0 1 .48 r
F
.71481 .91132 m .71177 .91532 L .71218 .91634 L F
.71177 .91532 m .71006 .91606 L .71218 .91634 L 0 1 .499 r
F
.71177 .91532 m .71011 .91751 L .71218 .91634 L 0 1 .48 r
F
.7149 .91398 m .71177 .91532 L .71218 .91634 L 0 1 .499 r
F
.7103 .91048 m .7149 .91398 L .71481 .91114 L 0 1 .482 r
F
.71095 .91249 m .7149 .91398 L .7103 .91048 L F
.71043 .9123 m .71179 .91531 L .7149 .91398 L F
.70286 .91495 m .71095 .91249 L .71038 .91045 L 0 1 .457 r
F
.70286 .91495 m .7101 .91751 L .71177 .91532 L F
.70286 .91495 m .71177 .91532 L .71095 .91249 L F
.71176 .9153 m .71177 .91532 L .71179 .91531 L 0 1 .482 r
F
.70372 .90265 m .71225 .89544 L .70835 .89743 L 0 1 .436 r
F
.70535 .90447 m .70765 .90703 L .70887 .90566 L F
.71246 .89898 m .70887 .90566 L .70981 .90938 L 0 1 .461 r
F
.70984 .90942 m .70981 .90938 L .70983 .90943 L 0 .989 .43 r
F
.70984 .90942 m .70981 .90938 L .70983 .90946 L 0 1 .461 r
F
.71246 .89898 m .70981 .90938 L .70984 .90942 L F
.71267 .90548 m .70891 .90701 L .70981 .90938 L 0 .989 .43 r
F
.71267 .90548 m .70981 .90938 L .70984 .90942 L F
.70283 .90267 m .70531 .90444 L .70409 .90303 L 0 .862 .397 r
F
.70409 .90303 m .70887 .90566 L .71246 .89898 L 0 1 .436 r
F
.70531 .90444 m .70535 .90447 L .70409 .90303 L 0 .862 .397 r
F
.70283 .90267 m .70325 .9071 L .70746 .90703 L F
.70283 .90267 m .70746 .90703 L .70686 .90633 L F
.70283 .90267 m .70762 .90703 L .70752 .90691 L F
.70283 .90267 m .70765 .90703 L .70535 .90447 L F
.70286 .90362 m .70535 .90447 L .70409 .90303 L 0 1 .436 r
F
.70535 .90447 m .70887 .90566 L .70409 .90303 L F
.70535 .90447 m .70891 .90701 L .70409 .90303 L 0 .862 .397 r
F
.70409 .90303 m .70891 .90701 L .71267 .90548 L F
.7039 .90281 m .71246 .89898 L .70386 .90276 L 0 1 .436 r
F
.70409 .90303 m .70413 .90301 L .7039 .90281 L F
.70413 .90301 m .71246 .89898 L .7039 .90281 L F
.70283 .90267 m .70384 .90276 L .70371 .90265 L 0 .862 .397 r
F
.70383 .90278 m .70384 .90276 L .70372 .90265 L 0 1 .436 r
F
.70384 .90276 m .71225 .89544 L .70372 .90265 L F
.70384 .90276 m .71267 .90548 L .7125 .90358 L 0 .862 .397 r
F
.70283 .90267 m .70409 .90303 L .70384 .90276 L F
.70409 .90303 m .71267 .90548 L .70384 .90276 L F
.70384 .90276 m .71246 .89898 L .71225 .89544 L 0 1 .436 r
F
.70383 .90278 m .70385 .90277 L .70384 .90276 L F
.70385 .90277 m .71246 .89898 L .70384 .90276 L F
.70372 .90265 m .7125 .90358 L .70851 .90257 L 0 .862 .397 r
F
.70371 .90265 m .70372 .90265 L .70372 .90265 L F
.70372 .90265 m .7125 .90358 L .70372 .90265 L F
.70384 .90276 m .7125 .90358 L .70371 .90265 L F
.70406 .90304 m .70409 .90303 L .70383 .90278 L 0 1 .436 r
F
.70409 .90303 m .70386 .90276 L .70383 .90278 L F
.70286 .90362 m .70383 .90278 L .70372 .90265 L F
.70686 .90633 m .70746 .90703 L .70762 .90703 L 0 .862 .397 r
F
.70752 .90691 m .70762 .90703 L .70765 .90703 L F
.70286 .90362 m .70406 .90304 L .70383 .90278 L 0 1 .436 r
F
.70286 .90362 m .70339 .91183 L .70765 .90703 L F
.70286 .90362 m .70765 .90703 L .70535 .90447 L F
.70535 .90447 m .70765 .90703 L .70891 .90701 L 0 .862 .397 r
F
.70286 .90362 m .69968 .91338 L .70339 .91183 L 0 1 .436 r
F
.70286 .90362 m .69944 .90987 L .69968 .91338 L F
.70994 .88604 m .70835 .89743 L .71225 .89544 L F
.70994 .88604 m .70736 .89341 L .70835 .89743 L F
.69779 .89799 m .70751 .89715 L .70855 .89699 L 0 0 0 r
F
.69779 .89799 m .70639 .89719 L .70609 .89734 L F
.70639 .89719 m .70855 .89699 L .70609 .89734 L F
.70565 .89754 m .70609 .89734 L .70948 .89667 L F
.70011 .89824 m .70251 .90099 L .70759 .9011 L 0 .606 .252 r
F
.70011 .89824 m .70759 .9011 L .71038 .90015 L F
.70011 .89824 m .71038 .90015 L .70936 .89897 L F
.70011 .89824 m .70936 .89897 L .70521 .89835 L F
.71246 .89898 m .72122 .90129 L .72505 .89411 L 0 1 .461 r
F
.71246 .89898 m .72505 .89411 L .72411 .89028 L F
.71246 .89898 m .72411 .89028 L .719 .89238 L F
.70534 .89745 m .70936 .89897 L .71394 .89882 L 0 .586 .228 r
F
.70534 .89745 m .70521 .89835 L .70936 .89897 L F
.70534 .89745 m .70348 .8977 L .70521 .89835 L F
.70534 .89745 m .71394 .89882 L .7159 .89801 L F
.70534 .89745 m .7159 .89801 L .71419 .89736 L F
.70534 .89745 m .71419 .89736 L .70993 .8973 L F
.69884 .89909 m .70609 .89734 L .70565 .89754 L 0 0 0 r
F
.69779 .89799 m .70609 .89734 L .70177 .89794 L F
.69884 .89909 m .70177 .89794 L .70609 .89734 L F
.69884 .89909 m .69866 .8987 L .70177 .89794 L F
.69884 .89909 m .70948 .89667 L .70967 .8964 L F
.69884 .89909 m .70967 .8964 L .70657 .89715 L F
.69884 .89909 m .70657 .89715 L .70223 .89843 L F
.69785 .89896 m .70657 .89715 L .70932 .8957 L 0 .798 .217 r
F
.69785 .89896 m .70223 .89843 L .70657 .89715 L F
.69785 .89896 m .6985 .89921 L .70223 .89843 L F
.69785 .89896 m .70932 .8957 L .70864 .89504 L F
.69785 .89896 m .70864 .89504 L .7049 .89581 L F
.69785 .89896 m .7049 .89581 L .70059 .8975 L F
.69336 .91617 m .70334 .90774 L .69727 .89112 L 0 .839 .298 r
F
.69294 .89418 m .69752 .89117 L .69783 .89095 L 0 .806 .167 r
F
.69752 .89117 m .70316 .88747 L .69783 .89095 L F
.70316 .88747 m .70321 .88744 L .70701 .88491 L F
.69698 .89137 m .69727 .89111 L .69726 .89113 L 0 0 0 r
F
.69698 .89137 m .69726 .89113 L .69712 .89145 L F
.68336 .90287 m .68725 .89681 L .68336 .89899 L 0 .781 .284 r
F
.68725 .89681 m .68734 .89615 L .68336 .89899 L F
.68264 .89691 m .69515 .89134 L .6959 .89198 L 0 0 0 r
F
.69698 .89137 m .6933 .89338 L .69727 .89111 L F
.69322 .89347 m .6933 .89338 L .69698 .89137 L F
.674 .91198 m .68684 .89674 L .6874 .89859 L 0 0 .04 r
F
.68684 .89674 m .68734 .89615 L .68735 .89638 L F
.68684 .89674 m .68735 .89638 L .6874 .89859 L F
.67332 .90639 m .67717 .89955 L .67332 .90067 L 0 .72 .27 r
F
.67657 .90407 m .67717 .89955 L .67332 .90639 L F
.67717 .89955 m .67735 .89814 L .67332 .90067 L F
.68684 .89674 m .68336 .89756 L .68734 .89615 L 0 0 .04 r
F
.674 .91198 m .68321 .8978 L .68684 .89674 L F
.68321 .8978 m .68336 .89756 L .68684 .89674 L F
.67403 .91424 m .67774 .9101 L .67403 .91447 L F
.674 .91198 m .67758 .91018 L .67403 .91424 L F
.67758 .91018 m .67774 .9101 L .67403 .91424 L F
.68347 .90328 m .6874 .89859 L .6933 .89338 L 0 0 0 r
F
.68347 .90328 m .69712 .89145 L .69294 .89418 L F
.68347 .90328 m .69079 .89624 L .68701 .89941 L F
.69079 .89624 m .69294 .89418 L .68701 .89941 L F
.674 .91198 m .6874 .89859 L .68347 .90328 L 0 0 .04 r
F
.68168 .90387 m .68701 .89941 L .68604 .8984 L 0 .845 .141 r
F
.674 .91198 m .68347 .90328 L .67774 .9101 L 0 0 .04 r
F
.67227 .9157 m .68701 .89941 L .68168 .90387 L 0 .845 .141 r
F
.68347 .90328 m .68701 .89941 L .6833 .90364 L 0 0 0 r
F
.68649 .89998 m .6833 .90364 L .68701 .89941 L 0 .845 .141 r
F
.67227 .9157 m .68313 .90383 L .68649 .89998 L F
.68313 .90383 m .6833 .90364 L .68649 .89998 L F
.65495 .95282 m .66477 .92561 L .66848 .92112 L 0 0 .058 r
F
.65495 .95282 m .66797 .924 L .66357 .93239 L F
.66357 .93239 m .67403 .91447 L .67774 .9101 L 0 0 0 r
F
.66874 .92399 m .67774 .9101 L .67699 .91061 L F
.66357 .93239 m .66755 .92612 L .66874 .92399 L F
.66755 .92612 m .67774 .9101 L .66874 .92399 L F
.65495 .95282 m .65899 .93916 L .66477 .92561 L 0 0 .058 r
F
.64644 .98051 m .65923 .93276 L .65899 .93916 L 0 .05 .1 r
F
.64644 .98051 m .65554 .9378 L .65923 .93276 L F
.64644 .98051 m .65899 .93916 L .65495 .95282 L F
.65495 .95282 m .66357 .93239 L .65775 .94603 L 0 0 .058 r
F
.65495 .95282 m .65775 .94603 L .65441 .9558 L F
.64644 .98051 m .65495 .95282 L .64944 .97339 L 0 .05 .1 r
F
.65131 .95848 m .65441 .9558 L .65775 .94603 L 0 1 .195 r
F
.64478 .98955 m .65007 .95818 L .64644 .98051 L 0 .066 .113 r
F
.64381 .99419 m .65007 .95818 L .64478 .98955 L F
.64101 1.00971 m .64339 .99618 L .64173 1.00611 L F
.64339 .99618 m .65007 .95818 L .64381 .99419 L F
.64339 .99618 m .64381 .99419 L .64173 1.00611 L F
.63956 1.01762 m .65007 .95818 L .6397 1.01713 L F
.64644 .98051 m .65007 .95818 L .65554 .9378 L 0 .05 .1 r
F
.64334 .97388 m .64824 .96773 L .65014 .96406 L 0 1 .195 r
F
.65055 .96211 m .65014 .96406 L .65441 .9558 L F
.64334 .97388 m .65014 .96406 L .65055 .96211 L F
.64334 .97388 m .65055 .96211 L .65131 .95848 L F
.65055 .96211 m .65441 .9558 L .65131 .95848 L F
.64173 1.00611 m .64381 .99419 L .64478 .98955 L 0 .066 .113 r
F
.6397 1.01713 m .64101 1.00971 L .64173 1.00611 L F
.653 .95007 m .65775 .94603 L .65636 .94179 L 0 1 .195 r
F
.64334 .97388 m .65131 .95848 L .653 .95007 L F
.65131 .95848 m .65775 .94603 L .653 .95007 L F
.63823 1.02513 m .64644 .98051 L .64296 1.00311 L 0 .066 .113 r
F
.63921 1.02149 m .64296 1.00311 L .64135 1.01356 L F
.63823 1.02513 m .64296 1.00311 L .63921 1.02149 L F
.64644 .98051 m .64944 .97339 L .64616 .9871 L 0 .05 .1 r
F
.6401 .99929 m .64616 .9871 L .64658 .98536 L 0 1 .165 r
F
.64848 .97607 m .64658 .98536 L .64944 .97339 L F
.6401 .99929 m .64658 .98536 L .64848 .97607 L F
.63992 1.00164 m .64028 1.00343 L .64616 .9871 L F
.6357 1.01149 m .63972 1.00442 L .63992 1.00164 L F
.63972 1.00442 m .64028 1.00343 L .63992 1.00164 L F
.6357 1.01149 m .63992 1.00164 L .6401 .99929 L F
.63992 1.00164 m .64616 .9871 L .6401 .99929 L F
.64043 .99497 m .64944 .97339 L .64824 .96773 L F
.6357 1.01149 m .6401 .99929 L .64043 .99497 L F
.6401 .99929 m .64944 .97339 L .64043 .99497 L F
.63291 1.08675 m .63633 1.04787 L .63694 1.04006 L 0 0 .076 r
F
.63035 1.1164 m .63225 1.09474 L .63291 1.08675 L F
.63823 1.02513 m .64135 1.01356 L .6382 1.03519 L 0 .066 .113 r
F
.63035 1.1164 m .63291 1.08675 L .63356 1.08108 L 0 0 .076 r
F
.63291 1.08675 m .63823 1.02514 L .63521 1.06132 L F
.63291 1.08675 m .63521 1.06132 L .63356 1.08108 L F
.63785 1.03217 m .6382 1.03519 L .63946 1.02653 L 0 1 .179 r
F
.63724 1.0343 m .63762 1.03466 L .63785 1.03217 L F
.63762 1.03466 m .6382 1.03519 L .63785 1.03217 L F
.63035 1.1164 m .63314 1.07092 L .63779 1.01536 L 0 0 .076 r
F
.62828 1.06572 m .63682 1.03944 L .63724 1.0343 L 0 1 .179 r
F
.63682 1.03944 m .6382 1.03519 L .63724 1.0343 L F
.63035 1.1164 m .63356 1.08108 L .63052 1.12088 L 0 0 .076 r
F
.62387 1.30666 m .62755 1.19872 L .62631 1.20507 L 0 .995 .099 r
F
.62755 1.19872 m .63035 1.1164 L .62786 1.17104 L F
.62755 1.19872 m .62786 1.17104 L .62631 1.20507 L F
.62187 1.14168 m .6326 1.05759 L .62828 1.06573 L 0 1 .208 r
F
.61882 1.29647 m .62064 1.20314 L .62253 1.10661 L 0 0 0 r
F
.61881 1.2972 m .62253 1.10661 L .62254 1.10638 L F
.61881 1.2972 m .61901 1.28677 L .61881 1.29744 L F
.61901 1.28677 m .62293 1.08641 L .61919 1.2779 L F
.61901 1.28677 m .61919 1.2779 L .61881 1.29744 L F
.62254 1.10638 m .62253 1.10661 L .62293 1.08641 L F
.6297 .96363 m .63 .94054 L .63077 .94268 L 0 0 .109 r
F
.6359 .95505 m .64645 .8265 L .64492 .90461 L 0 .307 .199 r
F
.6432 .76924 m .64338 .76973 L .64358 .76946 L 0 1 .486 r
F
.63055 .6779 m .63447 .73117 L .64047 .7704 L 0 .44 .248 r
F
.63219 .7629 m .64338 .76973 L .6432 .76924 L 0 1 .486 r
F
.63219 .7629 m .64293 .77038 L .64338 .76973 L F
.63219 .7629 m .63519 .7679 L .64041 .77091 L F
.64043 .7709 m .64041 .77091 L .64048 .77095 L F
.63219 .7629 m .64041 .77091 L .64043 .7709 L F
.63416 .86471 m .63605 .81115 L .64041 .77091 L 0 .283 .182 r
F
.64043 .7709 m .64041 .77091 L .64047 .77043 L F
.63416 .86471 m .64041 .77091 L .64043 .7709 L F
.64032 .80457 m .64043 .7709 L .64385 .77005 L F
.63481 .85832 m .63847 .80149 L .64032 .80457 L F
.63847 .80149 m .64043 .7709 L .64032 .80457 L F
.64416 .77323 m .64529 .77219 L .64525 .77685 L 0 .996 .115 r
F
.64525 .77685 m .64529 .77219 L .64557 .77363 L F
.64543 .77696 m .64557 .77363 L .64631 .77749 L F
.64525 .77685 m .64557 .77363 L .64543 .77696 L F
.64222 .77503 m .64492 .78902 L .64475 .78927 L F
.64513 .78404 m .64631 .77749 L .64541 .78492 L F
.64222 .77503 m .64543 .77696 L .64513 .78404 L F
.64543 .77696 m .64631 .77749 L .64513 .78404 L F
.64222 .77503 m .64513 .78404 L .64492 .78902 L F
.64513 .78404 m .64541 .78492 L .64492 .78902 L F
.64222 .77503 m .64475 .78927 L .64472 .78705 L F
.64222 .77503 m .64472 .78705 L .64451 .78485 L F
.64222 .77503 m .64451 .78485 L .64283 .78456 L F
.64435 .7966 m .64579 .77791 L .64571 .77832 L 0 .729 .063 r
F
.64435 .79662 m .64747 .75612 L .64435 .7966 L F
.6443 .79724 m .64747 .75612 L .6443 .79723 L F
.64426 .7979 m .64747 .75612 L .64426 .79782 L F
.64397 .80166 m .64426 .7979 L .64426 .79782 L F
.64435 .7966 m .64397 .80166 L .64397 .80166 L F
.64491 .78905 m .64435 .7966 L .64435 .7966 L F
.64435 .7966 m .64397 .80166 L .64435 .7966 L F
.64571 .77832 m .64747 .75612 L .6474 .75567 L F
.64398 .8019 m .64399 .80165 L .64397 .80166 L F
.64401 .80147 m .64747 .75612 L .644 .80124 L F
.64492 .789 m .64492 .78902 L .64492 .78902 L 0 .996 .115 r
F
.64541 .78492 m .64492 .78902 L .64492 .789 L F
.64393 .80315 m .6457 .78253 L .64541 .78492 L 0 .729 .063 r
F
.64304 .8142 m .64394 .80349 L .64393 .80315 L F
.64394 .80349 m .6457 .78253 L .64393 .80315 L F
.64784 .74934 m .64962 .78086 L .6479 .74897 L 0 0 .119 r
F
.6479 .74897 m .64491 .78905 L .64491 .78905 L 0 .729 .063 r
F
.64941 .75919 m .64969 .76284 L .64958 .76307 L 0 .732 .172 r
F
.64672 .73483 m .6479 .74897 L .64737 .72927 L 0 0 .119 r
F
.65469 .74859 m .66025 .73849 L .66025 .73856 L 0 .732 .172 r
F
.65469 .74859 m .66025 .73856 L .65503 .7485 L F
.65104 .7561 m .66025 .73856 L .66052 .70689 L 0 1 .145 r
F
.65943 .70724 m .6597 .7044 L .65976 .70485 L 0 .243 .161 r
F
.6597 .7044 m .66655 .63085 L .65976 .70485 L F
.65976 .70485 m .66655 .63085 L .67031 .62787 L F
.64934 .63203 m .64935 .63216 L .64941 .63203 L 0 1 .516 r
F
.6628 .72611 m .6619 .72792 L .66387 .73359 L 0 .195 .208 r
F
.65503 .7485 m .66025 .73856 L .66062 .74697 L 0 .732 .172 r
F
.65104 .7561 m .66062 .74697 L .66253 .79034 L F
.66088 .7677 m .66387 .73359 L .66226 .72897 L 0 .397 .243 r
F
.66088 .7677 m .66226 .72897 L .66161 .73007 L F
.66006 .72957 m .66166 .72724 L .66004 .72845 L F
.66088 .7677 m .66166 .72724 L .66006 .72957 L F
.64852 .75633 m .6493 .76557 L .64923 .75564 L 0 0 .119 r
F
.6493 .76557 m .65321 .8121 L .64986 .76456 L F
.6493 .76557 m .64986 .76456 L .64923 .75564 L F
.64772 .75614 m .64962 .78086 L .64788 .75006 L F
.6479 .74897 m .64791 .74897 L .64491 .78905 L 0 .729 .063 r
F
.6479 .74897 m .64491 .78905 L .64491 .78905 L F
.64492 .78902 m .64492 .78902 L .64492 .78902 L 0 .996 .115 r
F
.64492 .78902 m .6479 .74897 L .64491 .78905 L 0 .729 .063 r
F
.64222 .77503 m .64416 .77323 L .64525 .77685 L 0 .996 .115 r
F
.64541 .78492 m .64763 .75958 L .64765 .75734 L 0 .729 .063 r
F
.6457 .78253 m .64763 .75958 L .64541 .78492 L F
.64394 .80353 m .64561 .78699 L .64763 .75987 L F
.64304 .8142 m .64395 .80452 L .64394 .80353 L F
.64395 .80452 m .64561 .78699 L .64394 .80353 L F
.64606 .77954 m .64631 .77749 L .64787 .78553 L 0 .996 .115 r
F
.64606 .77954 m .64787 .78553 L .65124 .80299 L F
.64451 .79667 m .64763 .75987 L .64763 .75958 L 0 .729 .063 r
F
.64304 .8142 m .64451 .79672 L .64451 .79667 L F
.64451 .79672 m .64763 .75987 L .64451 .79667 L F
.64876 .74337 m .65591 .81601 L .64909 .74244 L 0 0 .119 r
F
.64791 .74896 m .65168 .69834 L .64871 .74369 L 0 .729 .063 r
F
.65168 .69834 m .65151 .70313 L .65252 .68711 L F
.64876 .74337 m .65168 .69834 L .65303 .69054 L F
.64849 .74513 m .65321 .8121 L .64876 .74337 L 0 0 .119 r
F
.64861 .74519 m .64871 .74374 L .64876 .74337 L 0 .729 .063 r
F
.64871 .74374 m .65168 .69834 L .64876 .74337 L F
.6493 .74185 m .65591 .81601 L .6513 .74165 L 0 0 .119 r
F
.64916 .74224 m .65591 .81601 L .6493 .74185 L F
.64876 .74336 m .65303 .69054 L .6508 .73752 L 0 .729 .063 r
F
.65076 .73771 m .6508 .73752 L .6508 .7376 L F
.64876 .74336 m .6508 .73752 L .65076 .73771 L F
.66001 .72759 m .66166 .72724 L .66004 .72845 L 0 .243 .161 r
F
.65943 .70724 m .66166 .72724 L .66001 .72759 L F
.6628 .72611 m .66166 .72724 L .66292 .72542 L 0 0 .096 r
F
.66292 .72542 m .66166 .72724 L .66358 .72144 L F
.65943 .70724 m .66358 .72144 L .66166 .72724 L 0 .243 .161 r
F
.64935 .63216 m .65056 .63276 L .64941 .63203 L 0 1 .516 r
F
.64908 .63224 m .64885 .63268 L .64909 .63237 L 0 .195 .208 r
F
.64751 .61918 m .64883 .63244 L .64908 .63224 L F
.64883 .63244 m .64885 .63268 L .64908 .63224 L F
.65117 .63138 m .66138 .63213 L .66077 .62956 L 0 1 .516 r
F
.65099 .63168 m .66138 .63213 L .65117 .63138 L F
.64951 .6319 m .66138 .63213 L .64985 .63163 L F
.64934 .63203 m .64941 .63203 L .64951 .6319 L F
.64941 .63203 m .66138 .63213 L .64951 .6319 L F
.64966 .63146 m .6497 .63166 L .65029 .63006 L 0 .195 .208 r
F
.64985 .63163 m .65099 .63168 L .65117 .63138 L 0 1 .516 r
F
.64909 .63237 m .65056 .63276 L .64927 .63213 L F
.65943 .70724 m .6619 .66459 L .66655 .63085 L 0 .243 .161 r
F
.65943 .70724 m .67031 .62787 L .67107 .65168 L F
.65715 .67633 m .661 .63921 L .65737 .64739 L 0 .818 .278 r
F
.65318 .72472 m .661 .63921 L .6619 .66459 L 0 .201 .157 r
F
.65264 .72452 m .661 .63921 L .65318 .72472 L F
.65126 .73665 m .661 .63921 L .65145 .7366 L F
.67533 .74465 m .68198 .75475 L .68657 .74548 L 0 1 .434 r
F
.67533 .74465 m .68657 .74548 L .6838 .74141 L F
.67748 .73631 m .67167 .74993 L .67497 .75499 L 0 .872 .41 r
F
.67748 .73631 m .67274 .74192 L .67167 .74993 L F
.67748 .73631 m .67497 .75499 L .68119 .75476 L F
.67748 .73631 m .68119 .75476 L .68621 .74938 L F
.67748 .73631 m .68729 .74136 L .68372 .73606 L F
.67748 .73631 m .68621 .74938 L .68729 .74136 L F
.67932 .72811 m .67559 .73742 L .67542 .74635 L 0 1 .417 r
F
.68621 .74938 m .68119 .75476 L .68068 .76343 L 0 .897 .421 r
F
.67804 .75731 m .68661 .76364 L .68769 .75543 L 0 1 .437 r
F
.67804 .75731 m .68769 .75543 L .68418 .75284 L F
.70294 .7331 m .69348 .75551 L .70193 .75198 L 0 1 .433 r
F
.70294 .7331 m .69072 .75153 L .69348 .75551 L F
.70294 .7331 m .69477 .74192 L .69072 .75153 L F
.68621 .74938 m .69816 .75658 L .69348 .75016 L 0 .897 .421 r
F
.71045 .74327 m .69762 .76143 L .70038 .76532 L 0 1 .438 r
F
.71045 .74327 m .70193 .75198 L .69762 .76143 L F
.68621 .74938 m .69763 .76527 L .69816 .75658 L 0 .897 .421 r
F
.6885 .73513 m .68418 .75284 L .68769 .75543 L 0 1 .428 r
F
.6885 .73513 m .68453 .74415 L .68418 .75284 L F
.67932 .72811 m .67893 .74895 L .68453 .74415 L 0 1 .417 r
F
.68245 .74133 m .6823 .75656 L .68632 .75024 L 0 .968 .303 r
F
.6645 .72741 m .67693 .73185 L .6766 .73948 L 0 .703 .176 r
F
.67932 .72811 m .67542 .74635 L .67893 .74895 L 0 1 .417 r
F
.67932 .72811 m .68453 .74415 L .6885 .73513 L F
.68217 .74069 m .68124 .71777 L .68572 .72903 L 0 .633 .17 r
F
.68217 .74069 m .67849 .74008 L .67997 .74054 L 0 .968 .303 r
F
.68217 .74069 m .67997 .74054 L .68245 .74133 L F
.67849 .74008 m .6823 .75656 L .68245 .74133 L F
.67804 .75731 m .67553 .77645 L .68166 .77199 L 0 1 .437 r
F
.67804 .75731 m .67229 .77405 L .67553 .77645 L F
.67804 .75731 m .68166 .77199 L .68661 .76364 L F
.67804 .75731 m .67336 .76585 L .67229 .77405 L F
.66947 .75097 m .67336 .76585 L .67804 .75731 L 0 1 .428 r
F
.66947 .75097 m .67804 .75731 L .67893 .74895 L F
.67845 .73988 m .67728 .74497 L .6823 .75656 L 0 .968 .303 r
F
.6766 .73948 m .67693 .73185 L .67845 .73988 L 0 .633 .17 r
F
.67461 .72326 m .6766 .73948 L .67845 .73988 L 0 .968 .303 r
F
.6766 .73948 m .67728 .74497 L .67845 .73988 L F
.67848 .73964 m .67693 .73185 L .68124 .71777 L 0 .633 .17 r
F
.68217 .74069 m .68572 .72903 L .68668 .74099 L F
.67845 .73988 m .68124 .71777 L .68217 .74069 L F
.67461 .72326 m .68217 .74069 L .68722 .72947 L 0 .968 .303 r
F
.68217 .74069 m .68632 .75024 L .68668 .74197 L F
.68217 .74069 m .68668 .74099 L .68671 .7413 L 0 .633 .17 r
F
.68217 .74069 m .68668 .74197 L .68671 .7413 L 0 .968 .303 r
F
.6885 .73513 m .68769 .75543 L .69346 .75078 L 0 1 .428 r
F
.68067 .77441 m .68632 .75024 L .6823 .75656 L 0 1 .314 r
F
.71794 .75316 m .70451 .77111 L .70726 .77492 L 0 1 .443 r
F
.71794 .75316 m .70908 .76179 L .70451 .77111 L F
.71045 .74327 m .70038 .76532 L .70908 .76179 L 0 1 .438 r
F
.69763 .76527 m .70832 .76983 L .70452 .76501 L 0 .922 .434 r
F
.69763 .76527 m .70691 .77724 L .70832 .76983 L F
.68661 .76364 m .69783 .77185 L .69836 .7632 L 0 1 .446 r
F
.68661 .76364 m .69836 .7632 L .69376 .75987 L F
.68067 .77441 m .69078 .75857 L .68632 .75024 L 0 1 .314 r
F
.68217 .74069 m .68671 .7413 L .68802 .75765 L 0 .633 .17 r
F
.68217 .74069 m .68671 .7413 L .68722 .72947 L 0 .968 .303 r
F
.67845 .73988 m .6784 .73962 L .67848 .73964 L 0 .633 .17 r
F
.6784 .73962 m .67693 .73185 L .67848 .73964 L F
.66947 .75097 m .67893 .74895 L .67542 .74635 L 0 1 .428 r
F
.66494 .74549 m .67728 .74497 L .6766 .73948 L 0 1 .296 r
F
.67653 .73946 m .6766 .73948 L .67655 .73947 L 0 .703 .176 r
F
.6645 .72741 m .6766 .73948 L .67653 .73946 L F
.66494 .74549 m .6766 .73948 L .66802 .73841 L 0 1 .296 r
F
.6645 .72741 m .6766 .73952 L .6763 .73948 L 0 .703 .176 r
F
.6645 .72741 m .67659 .73978 L .66803 .73846 L F
.66802 .73841 m .6766 .73948 L .67461 .72326 L 0 1 .296 r
F
.67655 .73947 m .6766 .73948 L .6766 .73952 L 0 .703 .176 r
F
.66947 .75097 m .66743 .77046 L .67336 .76585 L 0 1 .428 r
F
.66494 .74549 m .67631 .76747 L .67728 .74497 L 0 1 .296 r
F
.67563 .76219 m .6766 .73948 L .67845 .73988 L 0 .633 .17 r
F
.67563 .76219 m .68217 .74069 L .68802 .75765 L F
.67845 .73988 m .67849 .74008 L .68217 .74069 L 0 .968 .303 r
F
.67563 .76219 m .67845 .73988 L .68217 .74069 L 0 .633 .17 r
F
.67461 .72326 m .67845 .73988 L .68217 .74069 L 0 .968 .303 r
F
.6763 .73948 m .6766 .73952 L .67659 .73978 L 0 .703 .176 r
F
.66494 .74549 m .66802 .73841 L .66604 .73826 L 0 1 .296 r
F
.66494 .74549 m .67232 .7757 L .67631 .76747 L F
.66494 .74549 m .66745 .76627 L .67232 .7757 L F
.66604 .73826 m .67563 .76219 L .67132 .7753 L 0 .703 .176 r
F
.6645 .72741 m .66802 .73841 L .66604 .73826 L F
.66802 .73841 m .67563 .76219 L .66604 .73826 L F
.66604 .73826 m .66802 .73841 L .66606 .73816 L 0 1 .296 r
F
.66606 .73816 m .67461 .72326 L .66975 .71389 L F
.66802 .73841 m .67461 .72326 L .66606 .73816 L F
.66494 .74549 m .66604 .73826 L .66526 .73837 L F
.66526 .73837 m .67132 .7753 L .66691 .76214 L 0 .703 .176 r
F
.6645 .72741 m .66604 .73826 L .66526 .73837 L F
.66604 .73826 m .67132 .7753 L .66526 .73837 L F
.66526 .73837 m .66606 .73816 L .66527 .73804 L 0 1 .296 r
F
.66604 .73826 m .66606 .73816 L .66526 .73837 L F
.66527 .73804 m .66975 .71389 L .66594 .72306 L F
.66606 .73816 m .66975 .71389 L .66527 .73804 L F
.66803 .73846 m .67659 .73978 L .67563 .76219 L 0 .703 .176 r
F
.6706 .71894 m .66876 .71812 L .67189 .71389 L 0 .006 .099 r
F
.66807 .72143 m .66824 .72248 L .6706 .71894 L 0 .245 .231 r
F
.66824 .72248 m .66966 .73082 L .6706 .71894 L F
.65126 .73665 m .65736 .6474 L .661 .63921 L 0 .201 .157 r
F
.66107 .84193 m .66691 .76214 L .67132 .7753 L 0 .553 .195 r
F
.66107 .84193 m .66253 .79034 L .66691 .76214 L F
.66425 .86107 m .67067 .83309 L .66662 .84345 L 0 1 .289 r
F
.67064 .7949 m .68067 .77441 L .67631 .76747 L 0 1 .302 r
F
.67064 .7949 m .67631 .76747 L .67232 .7757 L F
.66107 .84193 m .67132 .7753 L .67337 .81823 L 0 .553 .195 r
F
.66425 .86107 m .66891 .87666 L .67301 .86689 L 0 1 .289 r
F
.66425 .86107 m .66515 .87417 L .66891 .87666 L F
.66107 .84193 m .67337 .81823 L .67163 .86293 L 0 .553 .195 r
F
.66107 .84193 m .67163 .86293 L .66719 .89227 L F
.65149 .73685 m .6669 .88939 L .66623 .84101 L 0 .32 .232 r
F
.6669 .88939 m .66713 .88915 L .66623 .84101 L F
.6762 .86732 m .67636 .87762 L .67959 .88015 L 0 1 .316 r
F
.67602 .89112 m .6857 .88322 L .68635 .87455 L 0 1 .313 r
F
.67602 .89112 m .68214 .89416 L .6857 .88322 L F
.67602 .89112 m .68635 .87455 L .68373 .87322 L F
.67602 .89112 m .68373 .87322 L .67959 .88015 L F
.6762 .86732 m .67959 .88015 L .68373 .87322 L 0 1 .316 r
F
.67163 .86293 m .67337 .81823 L .67788 .79126 L 0 .483 .186 r
F
.67163 .86293 m .68395 .833 L .68192 .87027 L F
.67912 .89483 m .68475 .89283 L .68058 .89268 L 0 1 .524 r
F
.67246 .89567 m .68058 .89268 L .68475 .89283 L 0 0 0 r
F
.67246 .89567 m .67531 .89389 L .68058 .89268 L F
.67912 .89483 m .68962 .8938 L .68475 .89283 L 0 1 .524 r
F
.67246 .89567 m .68475 .89283 L .68564 .89464 L 0 0 0 r
F
.67246 .89567 m .68564 .89464 L .68264 .89691 L F
.67246 .89567 m .68264 .89691 L .67735 .89813 L F
.67163 .86293 m .68192 .87027 L .67735 .89813 L 0 .483 .186 r
F
.66088 .7677 m .67658 .89205 L .67626 .851 L 0 .397 .243 r
F
.67658 .89205 m .67735 .89812 L .6772 .89139 L F
.67658 .89205 m .6772 .89139 L .67626 .851 L F
.68635 .87455 m .68831 .88602 L .69242 .8811 L 0 1 .349 r
F
.68635 .87455 m .6857 .88322 L .68831 .88602 L F
.68962 .8938 m .69515 .89134 L .691 .89225 L 0 1 .364 r
F
.68264 .89691 m .691 .89225 L .69515 .89134 L 0 0 0 r
F
.68264 .89691 m .68564 .89464 L .691 .89225 L F
.68264 .89691 m .69272 .89375 L .68734 .89615 L F
.68192 .87027 m .69209 .87149 L .68734 .89614 L 0 .415 .173 r
F
.67086 .78844 m .6864 .88999 L .68617 .85402 L 0 .45 .252 r
F
.6864 .88999 m .68734 .89613 L .68715 .8892 L F
.6864 .88999 m .68715 .8892 L .68617 .85402 L F
.69209 .87149 m .69727 .8911 L .6933 .89338 L 0 .347 .158 r
F
.68068 .79994 m .6933 .89337 L .69727 .8911 L 0 .494 .261 r
F
.68068 .79994 m .68617 .85402 L .6933 .89337 L F
.68207 .85118 m .69385 .88214 L .69656 .87237 L 0 .677 .311 r
F
.69385 .88214 m .69727 .89111 L .69681 .87903 L F
.69385 .88214 m .69681 .87903 L .69656 .87237 L F
.68264 .89691 m .68734 .89615 L .68336 .89756 L 0 0 0 r
F
.68192 .87027 m .68734 .89614 L .68336 .89755 L 0 .415 .173 r
F
.67086 .78844 m .68336 .89755 L .68734 .89613 L 0 .45 .252 r
F
.67086 .78844 m .67626 .851 L .68336 .89755 L F
.67242 .8496 m .68363 .88456 L .68678 .87623 L 0 .591 .297 r
F
.68363 .88456 m .68734 .89614 L .68692 .88106 L F
.68363 .88456 m .68692 .88106 L .68678 .87623 L F
.67246 .89567 m .67735 .89813 L .67333 .89749 L 0 0 0 r
F
.67163 .86293 m .67735 .89813 L .67333 .89748 L 0 .483 .186 r
F
.66088 .7677 m .67332 .89747 L .67735 .89812 L 0 .397 .243 r
F
.66088 .7677 m .66623 .84101 L .67332 .89747 L F
.66267 .84259 m .67327 .88268 L .67696 .87755 L 0 .475 .282 r
F
.67327 .88268 m .67735 .89813 L .67698 .87878 L F
.67327 .88268 m .67698 .87878 L .67696 .87755 L F
.6669 .88939 m .66719 .89226 L .66713 .88915 L 0 .32 .232 r
F
.65117 .73657 m .65736 .6474 L .65126 .73665 L 0 .201 .157 r
F
.6508 .7376 m .65303 .69054 L .65103 .73663 L 0 .729 .063 r
F
.6508 .7376 m .65103 .73663 L .65093 .73708 L F
.6508 .7376 m .65103 .73674 L .65094 .73721 L F
.65114 .73722 m .65591 .81601 L .66305 .88599 L 0 .32 .232 r
F
.65113 .73703 m .65114 .73722 L .65114 .73722 L F
.65114 .73722 m .65591 .81601 L .65114 .73722 L F
.66266 .72508 m .66181 .72721 L .6628 .72611 L 0 .195 .208 r
F
.65691 .7171 m .6619 .66459 L .65943 .70724 L 0 .201 .157 r
F
.65612 .71689 m .6619 .66459 L .65691 .7171 L F
.65445 .72226 m .6619 .66459 L .65549 .72262 L F
.65317 .73125 m .65436 .72223 L .6533 .73117 L F
.65436 .72223 m .6619 .66459 L .65445 .72226 L F
.65436 .72223 m .65445 .72226 L .6533 .73117 L F
.6515 .73627 m .65213 .73193 L .65307 .73208 L F
.65213 .73193 m .6619 .66459 L .65317 .73125 L F
.65213 .73193 m .65317 .73125 L .65307 .73208 L F
.65112 .7369 m .65736 .6474 L .65115 .73688 L F
.65101 .73699 m .65104 .73733 L .65112 .7369 L 0 .32 .232 r
F
.65104 .73733 m .65591 .81601 L .65113 .73709 L F
.65104 .73733 m .65113 .73709 L .65112 .7369 L F
.65113 .73704 m .65591 .81601 L .65113 .73703 L F
.65124 .73679 m .66305 .88599 L .66719 .89226 L F
.65112 .7369 m .66305 .88599 L .65124 .73679 L F
.65207 .73598 m .6515 .73627 L .65307 .73208 L 0 .201 .157 r
F
.6493 .74185 m .6513 .74165 L .65104 .73748 L 0 0 .119 r
F
.65088 .73738 m .65104 .73748 L .65101 .73699 L F
.6493 .74185 m .65104 .73748 L .65088 .73738 L F
.65149 .73685 m .66623 .84101 L .65199 .7373 L 0 .32 .232 r
F
.65149 .73685 m .65199 .7373 L .65184 .73621 L F
.65145 .7366 m .6515 .73627 L .65207 .73598 L 0 .201 .157 r
F
.65149 .73655 m .65184 .73621 L .65155 .73413 L 0 .32 .232 r
F
.65149 .73685 m .65184 .73621 L .65149 .73655 L F
.65143 .73671 m .65145 .7366 L .65207 .73598 L 0 .201 .157 r
F
.65159 .73783 m .65143 .73671 L .65207 .73598 L F
.65124 .73679 m .66719 .89226 L .65149 .73685 L 0 .32 .232 r
F
.65085 .74071 m .6513 .73764 L .65159 .73783 L 0 .201 .157 r
F
.6513 .73764 m .65143 .73671 L .65159 .73783 L F
.65207 .73598 m .65307 .73208 L .65334 .73472 L F
.65207 .73598 m .66088 .7677 L .65708 .731 L 0 .32 .232 r
F
.65292 .73903 m .66623 .84101 L .66088 .7677 L F
.65307 .73208 m .65832 .71848 L .65505 .75147 L 0 .201 .157 r
F
.65207 .73598 m .65708 .731 L .657 .73026 L 0 .32 .232 r
F
.65345 .7311 m .65943 .70724 L .65832 .71848 L 0 .201 .157 r
F
.65307 .73208 m .6533 .73117 L .65345 .7311 L F
.6533 .73117 m .65943 .70724 L .65345 .7311 L F
.66178 .72703 m .66166 .72724 L .66179 .72711 L 0 .195 .208 r
F
.65148 .73168 m .65303 .69054 L .65736 .6474 L 0 .201 .157 r
F
.65085 .74071 m .65125 .73145 L .65148 .73168 L F
.65125 .73145 m .65303 .69054 L .65148 .73168 L F
.64879 .64848 m .65247 .63951 L .64893 .6434 L 0 1 .332 r
F
.63866 .57159 m .64723 .63269 L .63851 .56932 L 0 .122 .176 r
F
.64667 .63749 m .64893 .6434 L .65247 .63951 L 0 1 .414 r
F
.64661 .63792 m .64893 .6434 L .64667 .63749 L F
.64581 .64067 m .64893 .6434 L .64639 .6374 L F
.63887 .50195 m .6462 .5686 L .6416 .54596 L 0 .838 .18 r
F
.63787 .56691 m .6406 .50885 L .63677 .49512 L 0 .689 .238 r
F
.63787 .56691 m .64678 .55898 L .6406 .50885 L F
.63787 .56691 m .65124 .6127 L .64678 .55898 L F
.64811 .63472 m .65247 .63951 L .65199 .63464 L 0 1 .414 r
F
.63778 .56531 m .64288 .62377 L .6448 .63988 L 0 .122 .176 r
F
.63778 .56531 m .6448 .63988 L .64484 .63981 L F
.63778 .56531 m .64506 .64205 L .64553 .64042 L F
.63778 .56531 m .64639 .6374 L .64694 .63065 L F
.64752 .63473 m .64639 .6374 L .64697 .63649 L 0 1 .414 r
F
.64752 .63473 m .64697 .63649 L .64811 .63472 L F
.64723 .63269 m .64752 .63473 L .64726 .63244 L 0 .122 .176 r
F
.64697 .63649 m .65247 .63951 L .64811 .63472 L 0 1 .414 r
F
.64639 .6374 m .64667 .63749 L .64697 .63649 L F
.64667 .63749 m .65247 .63951 L .64697 .63649 L F
.63851 .56932 m .64756 .6346 L .64751 .61918 L 0 .122 .176 r
F
.64756 .6346 m .64771 .6341 L .64751 .61918 L F
.64752 .63473 m .64756 .6346 L .64726 .63244 L F
.64639 .6374 m .64706 .63583 L .64701 .6339 L F
.64639 .6374 m .64701 .6339 L .64694 .63065 L F
.64723 .63269 m .64726 .63244 L .63851 .56932 L F
.64581 .64067 m .64554 .64222 L .64893 .6434 L 0 1 .414 r
F
.65168 .69834 m .65252 .68711 L .65278 .68888 L 0 .729 .063 r
F
.65168 .69834 m .65278 .68888 L .65303 .69054 L F
.64723 .63269 m .65387 .69996 L .65287 .67288 L 0 .122 .176 r
F
.64694 .63065 m .64718 .63298 L .64723 .63269 L F
.64664 .65863 m .64879 .64848 L .64749 .64858 L 0 .968 .234 r
F
.64718 .63298 m .65387 .69996 L .64723 .63269 L 0 .122 .176 r
F
.64724 .6445 m .65387 .69996 L .64694 .63065 L F
.64752 .63473 m .65199 .63464 L .64899 .63277 L 0 1 .414 r
F
.64834 .63348 m .64899 .63277 L .64885 .63268 L F
.64752 .63473 m .64899 .63277 L .64834 .63348 L F
.67217 .49078 m .67418 .52938 L .67911 .52517 L 0 .729 .326 r
F
.67217 .49078 m .67043 .52185 L .67418 .52938 L F
.67217 .49078 m .66957 .50531 L .67043 .52185 L F
.66486 .59487 m .67053 .51464 L .67469 .52355 L 0 .496 .192 r
F
.66486 .59487 m .66633 .54484 L .67053 .51464 L F
.67436 .54498 m .68356 .54748 L .6798 .54036 L 0 .86 .344 r
F
.67436 .54498 m .68356 .56208 L .68356 .54748 L F
.67436 .54498 m .6798 .57441 L .68356 .56208 L F
.66486 .59487 m .67469 .52355 L .67644 .55845 L 0 .496 .192 r
F
.68356 .56208 m .68312 .59401 L .68875 .58979 L 0 .86 .355 r
F
.68356 .56208 m .67961 .5881 L .68312 .59401 L F
.68356 .56208 m .6798 .57441 L .67961 .5881 L F
.67793 .57205 m .68241 .58365 L .68679 .59143 L 0 0 .152 r
F
.67793 .57205 m .67862 .57536 L .68241 .58365 L F
.69275 .57825 m .68875 .58979 L .6892 .60396 L 0 .868 .365 r
F
.67793 .57205 m .68679 .59143 L .68956 .59501 L 0 0 .152 r
F
.67793 .57205 m .68505 .58364 L .68068 .57558 L F
.67793 .57205 m .68886 .59198 L .68505 .58364 L F
.67793 .57205 m .68956 .59501 L .68886 .59198 L F
.67529 .57598 m .68068 .57558 L .68505 .58364 L 0 .475 .048 r
F
.67529 .57598 m .67651 .5723 L .68068 .57558 L F
.67919 .58378 m .68679 .59143 L .68241 .58365 L 0 .317 .328 r
F
.67529 .57598 m .68505 .58364 L .68734 .59116 L 0 .475 .048 r
F
.67919 .58378 m .67928 .59169 L .68259 .60261 L 0 .317 .328 r
F
.68221 .6071 m .6938 .6113 L .6892 .60396 L 0 .987 .372 r
F
.68221 .6071 m .69344 .62494 L .6938 .6113 L F
.67919 .58378 m .68259 .60261 L .68692 .60928 L 0 .317 .328 r
F
.69275 .57825 m .6892 .60396 L .6938 .6113 L 0 .868 .365 r
F
.67919 .58378 m .69015 .6092 L .69011 .60239 L 0 .317 .328 r
F
.67919 .58378 m .68692 .60928 L .69015 .6092 L F
.67529 .57598 m .68181 .58982 L .67755 .58349 L 0 .475 .048 r
F
.67919 .58378 m .69011 .60239 L .68679 .59143 L 0 .317 .328 r
F
.67529 .57598 m .68601 .59311 L .68181 .58982 L 0 .475 .048 r
F
.67529 .57598 m .68734 .59116 L .68601 .59311 L F
.6713 .59768 m .67755 .58349 L .68181 .58982 L 0 .511 .105 r
F
.6713 .59768 m .67306 .58683 L .67755 .58349 L F
.6713 .59768 m .68181 .58982 L .68353 .59922 L F
.66486 .59487 m .67644 .55845 L .67456 .59659 L 0 .496 .192 r
F
.67892 .60535 m .68692 .60928 L .68259 .60261 L 0 .613 .358 r
F
.6713 .59768 m .68353 .59922 L .68154 .60544 L 0 .511 .105 r
F
.6713 .59768 m .67702 .60885 L .67299 .60714 L F
.67892 .60535 m .67836 .61565 L .68111 .62745 L 0 .613 .358 r
F
.68221 .6071 m .68836 .63576 L .69344 .62494 L 0 .987 .372 r
F
.67892 .60535 m .68968 .62111 L .68692 .60928 L 0 .613 .358 r
F
.67892 .60535 m .68902 .63018 L .68968 .62111 L F
.67892 .60535 m .68535 .63289 L .68902 .63018 L F
.67892 .60535 m .68111 .62745 L .68535 .63289 L F
.6713 .59768 m .68154 .60544 L .67702 .60885 L 0 .511 .105 r
F
.66486 .59487 m .67456 .59659 L .67031 .62785 L 0 .496 .192 r
F
.65604 .56549 m .67031 .62786 L .66979 .60252 L 0 .548 .271 r
F
.65772 .63554 m .67031 .62786 L .67043 .627 L 0 1 .217 r
F
.65772 .63554 m .67043 .627 L .6668 .62884 L F
.65772 .63554 m .6668 .62884 L .66138 .63213 L F
.67588 .64552 m .67982 .62373 L .676 .62482 L 0 .76 .299 r
F
.66827 .68687 m .676 .62482 L .67684 .62458 L 0 .251 .153 r
F
.67975 .62407 m .67684 .62458 L .67981 .62373 L F
.66827 .68687 m .67684 .62458 L .67975 .62407 L F
.68056 .63305 m .68352 .63549 L .68801 .64686 L 0 .46 0 r
F
.68056 .63305 m .68033 .62959 L .68352 .63549 L F
.69068 .65532 m .69232 .66168 L .69669 .67046 L 0 0 .132 r
F
.69068 .65532 m .68975 .6552 L .69232 .66168 L F
.68056 .63305 m .68801 .64686 L .6916 .65869 L 0 .46 0 r
F
.68056 .63305 m .68869 .65716 L .68413 .64486 L F
.68786 .65718 m .69669 .67046 L .69232 .66168 L 0 .193 .257 r
F
.68056 .63305 m .69189 .6631 L .68869 .65716 L 0 .46 0 r
F
.68056 .63305 m .6916 .65869 L .69189 .6631 L F
.67588 .64552 m .68551 .64078 L .67982 .62373 L 0 .76 .299 r
F
.68651 .66705 m .69226 .66943 L .68816 .66537 L 0 .971 .388 r
F
.68337 .6654 m .68719 .66983 L .68651 .66705 L 0 .353 .341 r
F
.6835 .67012 m .68719 .66983 L .68651 .66705 L 0 .971 .388 r
F
.68719 .66983 m .69226 .66943 L .68651 .66705 L F
.68651 .66705 m .69245 .67593 L .68823 .66795 L 0 .353 .341 r
F
.68719 .66983 m .69245 .67593 L .68651 .66705 L F
.68786 .65718 m .68823 .66795 L .69245 .67593 L 0 .193 .257 r
F
.68786 .65718 m .68626 .65993 L .68823 .66795 L F
.69696 .67658 m .69857 .69785 L .70532 .6883 L 0 1 .407 r
F
.69696 .67658 m .70781 .67755 L .70437 .67278 L F
.69696 .67658 m .70532 .6883 L .70781 .67755 L F
.69364 .67982 m .70252 .67905 L .69842 .6753 L 0 .991 .403 r
F
.69364 .67982 m .70377 .68884 L .70252 .67905 L F
.68786 .65718 m .69245 .67593 L .69692 .68047 L 0 .193 .257 r
F
.68786 .65718 m .69866 .67852 L .69669 .67046 L F
.68786 .65718 m .69692 .68047 L .69866 .67852 L F
.68018 .6535 m .68413 .64486 L .68869 .65716 L 0 .733 .087 r
F
.68018 .6535 m .6805 .64328 L .68413 .64486 L F
.68018 .6535 m .68869 .65716 L .69188 .67415 L F
.67588 .64552 m .68931 .66469 L .68551 .64078 L 0 .76 .299 r
F
.68018 .6535 m .6879 .68298 L .68334 .67052 L 0 .733 .087 r
F
.68018 .6535 m .69157 .68453 L .6879 .68298 L F
.68018 .6535 m .69188 .67415 L .69157 .68453 L F
.67588 .64552 m .68921 .68554 L .68931 .66469 L 0 .76 .299 r
F
.67588 .64552 m .68527 .68935 L .68921 .68554 L F
.67588 .64552 m .67955 .67215 L .68527 .68935 L F
.66827 .68687 m .67975 .62407 L .68038 .64452 L 0 .251 .153 r
F
.67975 .62407 m .67981 .62373 L .67982 .62406 L F
.67975 .62407 m .67982 .62406 L .68038 .64452 L F
.68551 .64078 m .68941 .62236 L .68556 .62268 L 0 .766 .313 r
F
.68925 .62302 m .68556 .62268 L .68941 .62237 L 0 .246 .141 r
F
.67728 .67367 m .68545 .62336 L .68925 .62302 L F
.68545 .62336 m .68556 .62268 L .68925 .62302 L F
.68609 .62326 m .68715 .62285 L .68927 .62263 L 0 0 0 r
F
.67728 .67367 m .68038 .64452 L .68556 .62268 L 0 .246 .141 r
F
.67755 .62496 m .68464 .62341 L .68609 .62326 L 0 0 0 r
F
.68464 .62341 m .68715 .62285 L .68609 .62326 L F
.69344 .62494 m .7038 .62669 L .70006 .62105 L 0 .991 .383 r
F
.68968 .62111 m .68902 .63018 L .6917 .6406 L 0 .643 .379 r
F
.68968 .62111 m .6917 .6406 L .69593 .64543 L F
.68968 .62111 m .69773 .62413 L .69341 .61851 L F
.69344 .62494 m .70257 .63869 L .7038 .62669 L 0 .991 .383 r
F
.69344 .62494 m .6972 .64904 L .70257 .63869 L F
.68968 .62111 m .70042 .63457 L .69773 .62413 L 0 .643 .379 r
F
.68968 .62111 m .69967 .64285 L .70042 .63457 L F
.68968 .62111 m .69593 .64543 L .69967 .64285 L F
.69011 .60239 m .69341 .61851 L .69773 .62413 L 0 .349 .351 r
F
.69275 .57825 m .6938 .6113 L .70049 .60879 L 0 .868 .365 r
F
.69011 .60239 m .69773 .62413 L .70098 .62368 L 0 .349 .351 r
F
.68551 .64078 m .69523 .63837 L .68941 .62236 L 0 .766 .313 r
F
.68749 .64458 m .69593 .64543 L .6917 .6406 L 0 .828 .383 r
F
.70257 .63869 m .69576 .66052 L .6992 .66548 L 0 .999 .393 r
F
.70257 .63869 m .6972 .64904 L .69576 .66052 L F
.68749 .64458 m .69798 .65609 L .69593 .64543 L 0 .828 .383 r
F
.68749 .64458 m .69647 .66546 L .69798 .65609 L F
.70257 .63869 m .6992 .66548 L .70603 .66174 L 0 .999 .393 r
F
.69798 .65609 m .69842 .6753 L .70252 .67905 L 0 .857 .401 r
F
.69798 .65609 m .69647 .66546 L .69842 .6753 L F
.7117 .65178 m .70437 .67278 L .70781 .67755 L 0 1 .401 r
F
.7117 .65178 m .70603 .66174 L .70437 .67278 L F
.69798 .65609 m .70252 .67905 L .70682 .67524 L 0 .857 .401 r
F
.70257 .63869 m .70603 .66174 L .7117 .65178 L 0 .999 .393 r
F
.69798 .65609 m .70651 .65654 L .70228 .65226 L 0 .857 .401 r
F
.69798 .65609 m .70846 .6664 L .70651 .65654 L F
.69798 .65609 m .70682 .67524 L .70846 .6664 L F
.68551 .64078 m .69915 .66007 L .69523 .63837 L 0 .766 .313 r
F
.69068 .65532 m .69669 .67046 L .70074 .67768 L 0 0 .132 r
F
.69068 .65532 m .6992 .672 L .69473 .66251 L F
.69068 .65532 m .70178 .67851 L .6992 .672 L F
.69068 .65532 m .70074 .67768 L .70178 .67851 L F
.69189 .6631 m .69473 .66251 L .6992 .672 L 0 .449 .006 r
F
.69189 .6631 m .6916 .65869 L .69473 .66251 L F
.70532 .6883 m .71367 .69958 L .71641 .68914 L 0 1 .414 r
F
.70532 .6883 m .71641 .68914 L .71297 .68456 L F
.70532 .6883 m .69896 .71263 L .7066 .70891 L F
.70532 .6883 m .7066 .70891 L .71367 .69958 L F
.70377 .68884 m .71277 .68789 L .70867 .68444 L 0 1 .417 r
F
.70377 .68884 m .7139 .6972 L .71277 .68789 L F
.69866 .67852 m .70758 .69031 L .70323 .68273 L 0 .187 .249 r
F
.70178 .67851 m .70074 .67768 L .70323 .68273 L 0 0 .125 r
F
.69189 .6631 m .6992 .672 L .70282 .68272 L 0 .449 .006 r
F
.71367 .69958 m .70364 .71907 L .70675 .7233 L 0 1 .421 r
F
.71367 .69958 m .7066 .70891 L .70364 .71907 L F
.70377 .68884 m .7113 .70615 L .7139 .6972 L 0 1 .417 r
F
.69866 .67852 m .70944 .6971 L .70758 .69031 L 0 .187 .249 r
F
.70377 .68884 m .70247 .70742 L .7064 .71052 L 0 1 .417 r
F
.70377 .68884 m .70134 .69813 L .70247 .70742 L F
.70377 .68884 m .7064 .71052 L .7113 .70615 L F
.69364 .67982 m .70134 .69813 L .70377 .68884 L 0 .991 .403 r
F
.69866 .67852 m .70756 .69853 L .70944 .6971 L 0 .187 .249 r
F
.69189 .6631 m .70282 .68272 L .70316 .68752 L 0 .449 .006 r
F
.68551 .64078 m .69911 .67828 L .69915 .66007 L 0 .766 .313 r
F
.69866 .67852 m .69878 .68722 L .70299 .6943 L 0 .187 .249 r
F
.69866 .67852 m .70299 .6943 L .70756 .69853 L F
.69866 .67852 m .69692 .68047 L .69878 .68722 L F
.69189 .6631 m .70002 .6837 L .6955 .67381 L 0 .449 .006 r
F
.69189 .6631 m .70316 .68752 L .70002 .6837 L F
.69364 .67982 m .69656 .70263 L .70134 .69813 L 0 .991 .403 r
F
.69157 .68453 m .6955 .67381 L .70002 .6837 L 0 .67 .087 r
F
.69157 .68453 m .69188 .67415 L .6955 .67381 L F
.68551 .64078 m .69514 .68079 L .69911 .67828 L 0 .766 .313 r
F
.68551 .64078 m .68931 .66469 L .69514 .68079 L F
.67728 .67367 m .68925 .62302 L .68978 .64022 L 0 .246 .141 r
F
.68925 .62302 m .68941 .62237 L .68942 .62301 L F
.68925 .62302 m .68942 .62301 L .68978 .64022 L F
.69523 .63837 m .69907 .62216 L .6952 .62214 L 0 .781 .328 r
F
.69881 .62302 m .6952 .62214 L .69907 .62216 L 0 .234 .126 r
F
.68639 .66459 m .69498 .62319 L .69881 .62302 L F
.69498 .62319 m .6952 .62214 L .69881 .62302 L F
.68639 .66459 m .68978 .64022 L .6952 .62214 L F
.69139 .62279 m .6952 .62214 L .69907 .62216 L 0 0 0 r
F
.66827 .68687 m .67107 .65168 L .676 .62482 L 0 .251 .153 r
F
.6668 .62884 m .67793 .62446 L .67775 .6247 L 0 0 0 r
F
.67597 .62528 m .67757 .62493 L .67755 .62496 L F
.6668 .62884 m .67981 .62392 L .67597 .62528 L F
.67597 .62528 m .68927 .62263 L .68521 .62331 L F
.68521 .62331 m .68918 .62284 L .69139 .62279 L F
.68918 .62284 m .6952 .62214 L .69139 .62279 L F
.69373 .62258 m .69708 .62232 L .69877 .62215 L F
.68845 .62303 m .69198 .62274 L .69373 .62258 L F
.69198 .62274 m .69708 .62232 L .69373 .62258 L F
.70481 .59808 m .70006 .62105 L .7038 .62669 L 0 .876 .378 r
F
.70481 .59808 m .7038 .62669 L .71004 .62329 L F
.70481 .59808 m .71004 .62329 L .71462 .61311 L F
.71462 .61311 m .71004 .62329 L .70941 .63493 L 0 .888 .388 r
F
.70481 .59808 m .70049 .60879 L .70006 .62105 L 0 .876 .378 r
F
.69011 .60239 m .70098 .62368 L .70098 .61744 L 0 .349 .351 r
F
.70257 .63869 m .71315 .64028 L .70941 .63493 L 0 .999 .393 r
F
.70098 .61744 m .70421 .63193 L .70852 .6367 L 0 .418 .376 r
F
.70098 .61744 m .70098 .62368 L .70421 .63193 L F
.71462 .61311 m .70941 .63493 L .71315 .64028 L 0 .888 .388 r
F
.70098 .61744 m .70852 .6367 L .71178 .6358 L 0 .418 .376 r
F
.70098 .61744 m .71181 .6298 L .70857 .62152 L F
.70098 .61744 m .71178 .6358 L .71181 .6298 L F
.69275 .57825 m .70049 .60879 L .70481 .59807 L 0 .868 .365 r
F
.69971 .60719 m .70857 .62152 L .71127 .62266 L 0 .16 .196 r
F
.71462 .61311 m .71315 .64028 L .71958 .63698 L 0 .888 .388 r
F
.71052 .61915 m .71127 .62266 L .71508 .62839 L 0 .271 .256 r
F
.69971 .60719 m .71127 .62266 L .71052 .61915 L 0 .16 .196 r
F
.71462 .61311 m .71958 .63698 L .72442 .62722 L 0 .888 .388 r
F
.71052 .61915 m .71508 .62839 L .71941 .63253 L 0 .271 .256 r
F
.72442 .62722 m .71958 .63698 L .71875 .6481 L 0 .903 .398 r
F
.71052 .61915 m .71941 .63253 L .72208 .63272 L 0 .271 .256 r
F
.71052 .61915 m .7213 .62881 L .71748 .62306 L F
.71052 .61915 m .72208 .63272 L .7213 .62881 L F
.69971 .60719 m .71052 .61915 L .70671 .61299 L 0 .16 .196 r
F
.71052 .61915 m .71748 .62306 L .71318 .61931 L 0 .271 .256 r
F
.70728 .61518 m .71318 .61931 L .71748 .62306 L 0 .001 0 r
F
.70728 .61518 m .71748 .62306 L .7195 .62457 L F
.72442 .62722 m .71875 .6481 L .72248 .65317 L 0 .903 .398 r
F
.72442 .62722 m .72248 .65317 L .7291 .64992 L F
.72442 .62722 m .7291 .64992 L .7342 .64048 L F
.72442 .62722 m .7342 .64048 L .73504 .62933 L F
.71788 .62283 m .72494 .62881 L .73058 .63273 L 0 .21 .188 r
F
.71788 .62283 m .7195 .62458 L .72494 .62881 L F
.70728 .61518 m .7195 .62457 L .71788 .62283 L 0 .001 0 r
F
.71788 .62283 m .73058 .63273 L .73352 .63359 L 0 .21 .188 r
F
.71462 .61311 m .72442 .62722 L .72506 .61555 L 0 .888 .388 r
F
.72442 .62722 m .73504 .62933 L .73105 .62393 L 0 .903 .398 r
F
.71788 .62283 m .73178 .63081 L .72632 .62655 L 0 .21 .188 r
F
.71788 .62283 m .73352 .63359 L .73178 .63081 L F
.71788 .62283 m .72632 .62655 L .72079 .62368 L F
.7123 .6213 m .72079 .62368 L .72632 .62655 L 0 0 0 r
F
.7123 .6213 m .72632 .62655 L .72847 .62758 L F
.7123 .6213 m .72847 .62758 L .72579 .62607 L F
.7123 .6213 m .72579 .62607 L .71977 .62381 L F
.70452 .62188 m .71443 .62232 L .71977 .62381 L F
.70452 .62188 m .7079 .62149 L .71443 .62232 L F
.70452 .62188 m .71803 .62359 L .72107 .62425 L F
.71803 .62359 m .71977 .62381 L .72107 .62424 L F
.71803 .62359 m .72107 .62424 L .72107 .62425 L F
.72284 .62462 m .72705 .62569 L .7314 .62669 L 0 .443 .197 r
F
.71745 .62332 m .722 .62444 L .72284 .62462 L F
.722 .62444 m .72705 .62569 L .72284 .62462 L F
.70098 .61744 m .70857 .62152 L .70423 .6165 L 0 .418 .376 r
F
.69971 .60719 m .70423 .6165 L .70857 .62152 L 0 .16 .196 r
F
.69971 .60719 m .70671 .61299 L .7024 .6083 L F
.68886 .59198 m .6977 .6081 L .70043 .61037 L 0 .046 .172 r
F
.68886 .59198 m .69971 .60719 L .69591 .60025 L F
.68886 .59198 m .70043 .61037 L .69971 .60719 L F
.69971 .60719 m .70043 .61037 L .70423 .6165 L 0 .16 .196 r
F
.69666 .60559 m .7024 .6083 L .70671 .61299 L 0 .196 0 r
F
.69666 .60559 m .70671 .61299 L .70881 .61594 L F
.70728 .61518 m .70881 .61594 L .71318 .61931 L 0 .001 0 r
F
.69666 .60559 m .70728 .61518 L .70295 .61201 L 0 .196 0 r
F
.69666 .60559 m .70881 .61594 L .70728 .61518 L F
.70728 .61518 m .71788 .62283 L .71349 .61945 L 0 .001 0 r
F
.70728 .61518 m .71349 .61945 L .70928 .61668 L F
.70204 .6169 m .70928 .61668 L .71349 .61945 L 0 .092 0 r
F
.70204 .6169 m .70437 .61559 L .70928 .61668 L F
.70204 .6169 m .71349 .61945 L .71479 .62143 L F
.70204 .6169 m .71479 .62143 L .7123 .6213 L F
.70204 .6169 m .70738 .62021 L .70332 .61888 L F
.70204 .6169 m .7123 .6213 L .70738 .62021 L F
.6947 .62085 m .70332 .61888 L .70738 .62021 L 0 0 0 r
F
.6947 .62085 m .70738 .62021 L .7079 .62149 L F
.6947 .62085 m .7079 .62149 L .70452 .62188 L F
.70452 .62188 m .72107 .62425 L .71745 .62332 L F
.70452 .62188 m .71089 .62249 L .70579 .62231 L F
.70452 .62188 m .71745 .62332 L .71089 .62249 L F
.70404 .60672 m .71089 .62249 L .70579 .6223 L 0 .343 .127 r
F
.70481 .59808 m .71462 .61311 L .71506 .60083 L 0 .876 .378 r
F
.71462 .61311 m .72506 .61555 L .72106 .60978 L 0 .888 .388 r
F
.70404 .60672 m .71701 .61043 L .71089 .62249 L 0 .343 .127 r
F
.69275 .57825 m .70436 .58389 L .69944 .57571 L 0 .868 .365 r
F
.69275 .57825 m .70481 .59807 L .70436 .58389 L F
.70144 .55019 m .69819 .56128 L .69944 .57571 L 0 .734 .359 r
F
.70144 .55019 m .69944 .57571 L .70436 .58389 L F
.70144 .55019 m .70436 .58389 L .7107 .58243 L F
.69011 .60239 m .6977 .6081 L .69334 .60191 L 0 .349 .351 r
F
.68886 .59198 m .69334 .60191 L .6977 .6081 L 0 .046 .172 r
F
.68886 .59198 m .69591 .60025 L .69157 .59422 L F
.68886 .59198 m .68956 .59501 L .69334 .60191 L F
.68601 .59311 m .69157 .59422 L .69591 .60025 L 0 .346 .006 r
F
.68601 .59311 m .69591 .60025 L .6981 .60513 L F
.68601 .59311 m .69666 .60559 L .6924 .60252 L F
.68601 .59311 m .6981 .60513 L .69666 .60559 L F
.69418 .60343 m .70157 .5637 L .70569 .56798 L 0 .394 .146 r
F
.69418 .60343 m .69665 .57878 L .70157 .5637 L F
.69418 .60343 m .70569 .56798 L .70676 .58634 L F
.70144 .55019 m .7107 .58243 L .71423 .57228 L 0 .734 .359 r
F
.70481 .59808 m .71506 .60083 L .71106 .59466 L 0 .876 .378 r
F
.71423 .57228 m .71106 .59466 L .71506 .60083 L 0 .744 .373 r
F
.71423 .57228 m .7107 .58243 L .71106 .59466 L F
.71423 .57228 m .71506 .60083 L .72088 .59829 L F
.71423 .57228 m .72088 .59829 L .72463 .58871 L F
.70404 .60672 m .71283 .57453 L .71823 .57898 L 0 .343 .127 r
F
.70404 .60672 m .70677 .58634 L .71283 .57453 L F
.68601 .59311 m .68734 .59116 L .69157 .59422 L 0 .346 .006 r
F
.68601 .59311 m .6924 .60252 L .68817 .59798 L F
.69011 .60239 m .69015 .6092 L .69341 .61851 L 0 .349 .351 r
F
.69011 .60239 m .70098 .61744 L .6977 .6081 L F
.68154 .60544 m .68817 .59798 L .6924 .60252 L 0 .347 .074 r
F
.68154 .60544 m .68353 .59922 L .68817 .59798 L F
.68154 .60544 m .6924 .60252 L .69396 .60839 L F
.68435 .59989 m .69665 .57878 L .69418 .60343 L 0 .434 .163 r
F
.70404 .60672 m .71823 .57898 L .72004 .59431 L 0 .343 .127 r
F
.69418 .60343 m .70676 .58634 L .70404 .60672 L 0 .394 .146 r
F
.70404 .60672 m .72004 .59431 L .71701 .61043 L 0 .343 .127 r
F
.69666 .60559 m .6981 .60513 L .7024 .6083 L 0 .196 0 r
F
.69666 .60559 m .70295 .61201 L .69874 .60853 L F
.69178 .61168 m .69874 .60853 L .70295 .61201 L 0 .244 .027 r
F
.69178 .61168 m .69396 .60839 L .69874 .60853 L F
.69178 .61168 m .70295 .61201 L .70437 .61559 L F
.69178 .61168 m .70437 .61559 L .70204 .6169 L F
.69178 .61168 m .70204 .6169 L .69723 .61676 L F
.6947 .62085 m .69789 .61915 L .70332 .61888 L 0 0 0 r
F
.6947 .62085 m .70452 .62188 L .69907 .62216 L F
.69418 .60343 m .70404 .60672 L .69907 .62215 L 0 .394 .146 r
F
.69343 .58668 m .71089 .62249 L .71088 .60902 L 0 .628 .339 r
F
.69343 .58668 m .70579 .6223 L .71089 .62249 L F
.69343 .58668 m .69831 .60694 L .70579 .6223 L F
.70042 .63457 m .70852 .6367 L .70421 .63193 L 0 .686 .399 r
F
.70257 .63869 m .7117 .65178 L .71315 .64028 L 0 .999 .393 r
F
.70042 .63457 m .71113 .64614 L .70852 .6367 L 0 .686 .399 r
F
.705 .63711 m .71089 .6225 L .70579 .62231 L 0 .801 .343 r
F
.70042 .63457 m .70228 .65226 L .70651 .65654 L 0 .686 .399 r
F
.70042 .63457 m .69967 .64285 L .70228 .65226 L F
.70042 .63457 m .70651 .65654 L .7103 .65392 L F
.70042 .63457 m .7103 .65392 L .71113 .64614 L F
.69523 .63837 m .705 .63711 L .69907 .62216 L 0 .781 .328 r
F
.69523 .63837 m .70905 .65707 L .705 .63711 L F
.7117 .65178 m .70781 .67755 L .71485 .67389 L 0 1 .401 r
F
.70846 .6664 m .70867 .68444 L .71277 .68789 L 0 .892 .417 r
F
.70846 .6664 m .70682 .67524 L .70867 .68444 L F
.72081 .66424 m .71297 .68456 L .71641 .68914 L 0 1 .41 r
F
.72081 .66424 m .71485 .67389 L .71297 .68456 L F
.70846 .6664 m .71277 .68789 L .71716 .68413 L 0 .892 .417 r
F
.7117 .65178 m .71485 .67389 L .72081 .66424 L 0 1 .401 r
F
.70846 .6664 m .71707 .66641 L .71285 .66261 L 0 .892 .417 r
F
.72081 .66424 m .71641 .68914 L .72366 .68552 L 0 1 .41 r
F
.70846 .6664 m .71892 .67564 L .71707 .66641 L 0 .892 .417 r
F
.70846 .6664 m .71716 .68413 L .71892 .67564 L F
.69523 .63837 m .70909 .67336 L .70905 .65707 L 0 .781 .328 r
F
.69523 .63837 m .70509 .67509 L .70909 .67336 L F
.69523 .63837 m .69915 .66007 L .70509 .67509 L F
.69557 .65797 m .70579 .62231 L .71089 .6225 L 0 .216 .109 r
F
.69557 .65797 m .69924 .63743 L .70579 .62231 L F
.69921 .62207 m .70793 .62242 L .71131 .62196 L 0 0 0 r
F
.69178 .61168 m .69723 .61676 L .69318 .61528 L 0 .244 .027 r
F
.68493 .62027 m .69318 .61528 L .69723 .61676 L 0 .083 .013 r
F
.68493 .62027 m .69723 .61676 L .69789 .61915 L F
.68493 .62027 m .69789 .61915 L .6947 .62085 L F
.6947 .62085 m .69907 .62216 L .6952 .62214 L 0 0 0 r
F
.69418 .60343 m .69907 .62215 L .6952 .62213 L 0 .394 .146 r
F
.68356 .56208 m .69294 .56455 L .68918 .55785 L 0 .86 .355 r
F
.68356 .56208 m .69275 .57824 L .69294 .56455 L F
.68356 .56208 m .68875 .58979 L .69275 .57824 L F
.69168 .53182 m .69294 .56455 L .69819 .56127 L 0 .722 .347 r
F
.69168 .53182 m .68918 .55785 L .69294 .56455 L F
.68435 .59989 m .69126 .55115 L .69539 .55648 L 0 .434 .163 r
F
.68435 .59989 m .68655 .5696 L .69126 .55115 L F
.68435 .59989 m .69539 .55648 L .69665 .57878 L F
.67456 .59659 m .68655 .5696 L .68435 .59989 L 0 .468 .178 r
F
.68154 .60544 m .69396 .60839 L .69178 .61168 L 0 .347 .074 r
F
.68154 .60544 m .69178 .61168 L .68711 .61295 L F
.68493 .62027 m .68792 .61677 L .69318 .61528 L 0 .083 .013 r
F
.68493 .62027 m .6947 .62085 L .68941 .62236 L F
.68435 .59989 m .69418 .60343 L .68941 .62235 L 0 .434 .163 r
F
.68405 .58258 m .69907 .62215 L .6983 .60694 L 0 .593 .321 r
F
.68405 .58258 m .6952 .62213 L .69907 .62215 L F
.68405 .58258 m .68876 .60515 L .6952 .62213 L F
.6945 .62212 m .69789 .62219 L .69921 .62207 L 0 0 0 r
F
.69892 .62217 m .69907 .62216 L .69906 .62216 L F
.69892 .62217 m .69906 .62216 L .69877 .62215 L F
.68639 .66459 m .69907 .62216 L .69924 .63743 L 0 .234 .126 r
F
.68795 .62308 m .69892 .62217 L .68845 .62303 L 0 0 0 r
F
.68521 .62331 m .69877 .62215 L .69449 .62212 L F
.6945 .62212 m .70579 .62231 L .71089 .62249 L F
.6945 .62212 m .69877 .62215 L .70579 .62231 L F
.69789 .62219 m .70793 .62242 L .69921 .62207 L F
.70793 .62242 m .71079 .62249 L .71092 .62236 L F
.70793 .62242 m .71092 .62236 L .71131 .62196 L F
.71079 .62249 m .71089 .62249 L .7109 .62248 L F
.71079 .62249 m .7109 .62248 L .71131 .62196 L F
.69708 .62232 m .69892 .62217 L .69886 .62216 L F
.69708 .62232 m .69886 .62216 L .69877 .62215 L F
.68521 .62331 m .68795 .62308 L .68845 .62303 L F
.68715 .62285 m .68912 .62242 L .68919 .62252 L F
.68715 .62285 m .68919 .62252 L .68927 .62263 L F
.67775 .6247 m .67981 .62372 L .67981 .62392 L F
.67793 .62446 m .67981 .62372 L .67775 .6247 L F
.67757 .62493 m .68912 .62242 L .67755 .62496 L F
.68912 .62242 m .68941 .62236 L .6894 .62237 L F
.68912 .62242 m .6894 .62237 L .68927 .62263 L F
.6668 .62884 m .676 .62481 L .67981 .62372 L F
.6668 .62884 m .67043 .627 L .676 .62481 L F
.6668 .62884 m .67037 .62748 L .66677 .62904 L F
.6668 .62884 m .67597 .62528 L .67037 .62748 L F
.65637 .62869 m .66677 .62904 L .67037 .62748 L 0 1 .441 r
F
.65637 .62869 m .66077 .62956 L .66677 .62904 L F
.65637 .62869 m .67037 .62748 L .66961 .62608 L F
.65637 .62869 m .66961 .62608 L .66497 .62579 L F
.65637 .62869 m .66497 .62579 L .65895 .62631 L F
.64678 .55898 m .65808 .6227 L .66028 .6035 L 0 .571 .256 r
F
.66028 .62377 m .6674 .62387 L .66573 .6229 L 0 .992 .294 r
F
.65889 .62295 m .65925 .6245 L .65978 .62192 L 0 .1 .186 r
F
.65925 .6245 m .65945 .62449 L .66028 .62377 L 0 .992 .294 r
F
.65945 .62449 m .6674 .62387 L .66028 .62377 L F
.65945 .62449 m .66402 .62484 L .6674 .62387 L F
.65925 .6245 m .65942 .62452 L .65945 .62449 L F
.65942 .62452 m .66402 .62484 L .65945 .62449 L F
.65865 .62494 m .66402 .62484 L .65925 .6245 L F
.65265 .63013 m .66077 .62956 L .65637 .62869 L 0 1 .516 r
F
.65213 .63074 m .66077 .62956 L .65265 .63013 L F
.64774 .63589 m .64885 .63268 L .64751 .61918 L 0 .122 .176 r
F
.64898 .63233 m .65199 .63464 L .65781 .63468 L 0 1 .516 r
F
.64779 .63202 m .64885 .63268 L .64898 .63233 L F
.64885 .63268 m .65199 .63464 L .64898 .63233 L F
.65943 .70724 m .67107 .65168 L .66827 .68687 L 0 .243 .161 r
F
.65943 .70724 m .66827 .68687 L .66365 .72086 L F
.66338 .72076 m .66365 .72086 L .66358 .72144 L F
.65943 .70724 m .66365 .72086 L .66338 .72076 L F
.66876 .71812 m .67229 .70113 L .67192 .71282 L 0 .006 .099 r
F
.66827 .68687 m .68038 .64452 L .67728 .67367 L 0 .251 .153 r
F
.67461 .72326 m .67941 .69664 L .67552 .70257 L 0 .968 .303 r
F
.67461 .72326 m .68442 .70815 L .67941 .69664 L F
.67461 .72326 m .68722 .72947 L .68442 .70815 L F
.66827 .68687 m .67728 .67367 L .67229 .70113 L 0 .251 .153 r
F
.66827 .68687 m .67229 .70113 L .66878 .70826 L F
.68442 .70815 m .68921 .68554 L .68527 .68935 L 0 .948 .313 r
F
.67861 .71231 m .68651 .6802 L .6901 .67639 L 0 .024 .09 r
F
.67855 .71232 m .68651 .6802 L .67861 .71231 L F
.69751 .73673 m .69348 .75016 L .69816 .75658 L 0 .779 .418 r
F
.69751 .73673 m .6932 .74166 L .69348 .75016 L F
.69767 .74199 m .69376 .75987 L .69836 .7632 L 0 1 .438 r
F
.69767 .74199 m .69347 .75078 L .69376 .75987 L F
.6885 .73513 m .69346 .75078 L .69766 .74199 L 0 1 .428 r
F
.70294 .7331 m .70193 .75198 L .71045 .74327 L 0 1 .433 r
F
.69751 .73673 m .69816 .75658 L .70513 .75791 L 0 .779 .418 r
F
.71045 .74327 m .70908 .76179 L .71794 .75316 L 0 1 .438 r
F
.70969 .75072 m .70857 .76699 L .7147 .76602 L 0 1 .449 r
F
.70857 .76699 m .70911 .76983 L .7147 .76602 L F
.71946 .75756 m .7147 .76602 L .71394 .7743 L 0 1 .458 r
F
.70977 .75324 m .70857 .76699 L .71483 .77006 L 0 .808 .431 r
F
.70857 .76699 m .70832 .76983 L .70907 .76986 L F
.70857 .76699 m .70907 .76986 L .70911 .76983 L 0 1 .449 r
F
.70857 .76699 m .70907 .76986 L .71483 .77006 L 0 .808 .431 r
F
.70857 .76699 m .70834 .77036 L .70907 .76986 L 0 1 .449 r
F
.70857 .76699 m .70452 .76501 L .70832 .76983 L 0 .808 .431 r
F
.70857 .76699 m .7046 .7677 L .70834 .77036 L 0 1 .449 r
F
.70969 .75072 m .70722 .75895 L .70857 .76699 L F
.70722 .75895 m .70709 .75926 L .70857 .76699 L 0 .808 .431 r
F
.70709 .75926 m .70452 .76501 L .70857 .76699 L F
.70722 .75895 m .7046 .7677 L .70857 .76699 L 0 1 .449 r
F
.70977 .75324 m .70722 .75895 L .70857 .76699 L 0 .808 .431 r
F
.69751 .73673 m .70513 .75791 L .70677 .75626 L 0 .779 .418 r
F
.70722 .75895 m .70514 .75791 L .70452 .76501 L 0 .808 .431 r
F
.70715 .75852 m .70514 .75791 L .70722 .75895 L F
.70969 .75072 m .70677 .75626 L .70722 .75895 L 0 1 .449 r
F
.70677 .75626 m .70514 .75791 L .70738 .75859 L 0 .808 .431 r
F
.70722 .75895 m .70677 .75626 L .70694 .7599 L 0 1 .449 r
F
.70677 .75626 m .70677 .75626 L .70722 .75895 L F
.70738 .75859 m .70715 .75852 L .70722 .75895 L 0 .808 .431 r
F
.70977 .75324 m .70677 .75626 L .70738 .75859 L F
.69767 .74199 m .70518 .75929 L .70677 .75626 L 0 1 .438 r
F
.7058 .74789 m .70677 .75626 L .70968 .75072 L F
.69751 .73673 m .70677 .75626 L .70668 .75425 L 0 .779 .418 r
F
.7058 .74789 m .70668 .75425 L .70642 .74874 L F
.69751 .73673 m .70668 .75425 L .7058 .74789 L F
.70294 .7331 m .71045 .74327 L .71452 .73365 L 0 1 .433 r
F
.69751 .73673 m .70505 .74175 L .70449 .73803 L 0 .779 .418 r
F
.70505 .74175 m .70968 .75072 L .7094 .74161 L 0 1 .438 r
F
.70506 .74198 m .70968 .75072 L .70505 .74175 L F
.7058 .74789 m .70968 .75072 L .70508 .74201 L F
.69751 .73673 m .7058 .74789 L .70505 .74175 L 0 .779 .418 r
F
.7058 .74789 m .70508 .74201 L .70495 .74176 L 0 1 .438 r
F
.7058 .74789 m .70647 .7488 L .70505 .74175 L 0 .779 .418 r
F
.70505 .74175 m .70977 .75324 L .70949 .74471 L F
.70647 .7488 m .70977 .75324 L .70505 .74175 L F
.70433 .73816 m .70505 .74175 L .7045 .73806 L 0 1 .438 r
F
.69767 .74199 m .70505 .74175 L .70433 .73816 L F
.70569 .74173 m .7094 .74161 L .70454 .73809 L F
.70294 .7331 m .71452 .73365 L .71141 .72955 L 0 1 .433 r
F
.71367 .69958 m .70675 .7233 L .71462 .71961 L 0 1 .421 r
F
.70679 .71963 m .70451 .73797 L .7094 .74161 L 0 1 .432 r
F
.70451 .73797 m .70451 .73798 L .70451 .73799 L 0 .621 .408 r
F
.70451 .73798 m .70449 .73803 L .70454 .73809 L F
.70451 .73797 m .7045 .73806 L .70454 .73809 L 0 1 .432 r
F
.70451 .73797 m .70454 .73809 L .7094 .74161 L F
.70699 .72577 m .70451 .73797 L .70949 .74471 L 0 .621 .408 r
F
.70451 .73797 m .70451 .73799 L .70949 .74471 L F
.70451 .73798 m .70454 .73809 L .70949 .74471 L F
.70505 .74175 m .70569 .74173 L .70454 .73809 L 0 1 .438 r
F
.70505 .74175 m .70454 .73809 L .70449 .73803 L 0 .779 .418 r
F
.70505 .74175 m .70454 .73809 L .7045 .73806 L 0 1 .438 r
F
.70505 .74175 m .70487 .73853 L .70454 .73809 L 0 .779 .418 r
F
.70505 .74175 m .70949 .74471 L .70487 .73853 L F
.70495 .74176 m .70506 .74198 L .70505 .74175 L 0 1 .438 r
F
.69767 .74199 m .7058 .74789 L .70495 .74176 L F
.69767 .74199 m .70677 .75626 L .7058 .74789 L F
.70642 .74874 m .70677 .75626 L .70977 .75324 L 0 .779 .418 r
F
.70694 .7599 m .70518 .75929 L .7046 .7677 L 0 1 .449 r
F
.70677 .75626 m .70518 .75929 L .70694 .7599 L F
.6885 .73513 m .69766 .74199 L .69802 .73328 L 0 1 .428 r
F
.6885 .73513 m .69802 .73328 L .69428 .73047 L F
.68978 .72384 m .69477 .74344 L .6923 .74267 L 0 .67 .125 r
F
.69767 .74199 m .69836 .7632 L .70518 .75929 L 0 1 .438 r
F
.69078 .75857 m .70096 .74649 L .70057 .7457 L 0 1 .326 r
F
.68978 .72384 m .70092 .74516 L .70057 .7457 L 0 .67 .125 r
F
.68978 .72384 m .70057 .7457 L .70012 .74552 L F
.69078 .75857 m .70057 .7457 L .69477 .74344 L 0 1 .326 r
F
.68978 .72384 m .70036 .74604 L .69477 .74344 L 0 .67 .125 r
F
.69477 .74344 m .70057 .7457 L .69642 .7372 L 0 1 .326 r
F
.70012 .74552 m .70057 .7457 L .70036 .74604 L 0 .67 .125 r
F
.69078 .75857 m .70297 .76364 L .70096 .74649 L 0 1 .326 r
F
.69477 .74344 m .70036 .74604 L .69685 .75161 L 0 .67 .125 r
F
.69233 .74231 m .69642 .7372 L .69237 .74194 L 0 1 .326 r
F
.6923 .74267 m .69251 .74239 L .69233 .74231 L F
.69251 .74239 m .69642 .7372 L .69233 .74231 L F
.69078 .75857 m .69477 .74344 L .6923 .74267 L F
.69477 .74344 m .69642 .7372 L .6923 .74267 L F
.6923 .74267 m .69685 .75161 L .69242 .74353 L 0 .67 .125 r
F
.69477 .74344 m .69685 .75161 L .6923 .74267 L F
.69783 .77185 m .70695 .77843 L .70834 .77036 L 0 1 .456 r
F
.69783 .77185 m .70834 .77036 L .7046 .7677 L F
.69078 .75857 m .70139 .78029 L .70297 .76364 L 0 1 .326 r
F
.69078 .75857 m .69726 .78532 L .70139 .78029 L F
.69078 .75857 m .69271 .776 L .69726 .78532 L F
.68067 .77441 m .69271 .776 L .69078 .75857 L 0 1 .314 r
F
.68656 .78482 m .69242 .74353 L .69685 .75161 L 0 .565 .16 r
F
.68656 .78482 m .68802 .75765 L .69242 .74353 L F
.68656 .78482 m .69685 .75161 L .69898 .77541 L F
.67563 .76219 m .68802 .75765 L .68656 .78482 L 0 .633 .17 r
F
.6786 .7127 m .68914 .7725 L .69297 .77502 L 0 .315 .263 r
F
.67859 .71272 m .68914 .7725 L .6786 .7127 L F
.67804 .71277 m .67808 .71299 L .67856 .7125 L F
.67808 .71299 m .68914 .7725 L .67856 .7125 L F
.68442 .70815 m .69434 .69794 L .68921 .68554 L 0 .948 .313 r
F
.6821 .70515 m .6901 .67639 L .68932 .68715 L 0 .024 .09 r
F
.6814 .70537 m .6901 .67639 L .6821 .70515 L F
.67923 .71102 m .6901 .67639 L .67981 .71069 L F
.67861 .71231 m .6901 .67639 L .67887 .71217 L F
.69379 .68478 m .69657 .70289 L .70156 .70536 L 0 .351 .35 r
F
.69157 .68453 m .69922 .70909 L .69471 .69952 L 0 .67 .087 r
F
.69839 .71308 m .70338 .72864 L .70679 .71962 L 0 1 .421 r
F
.69707 .71118 m .69788 .72882 L .7021 .72965 L 0 .588 .393 r
F
.69707 .71118 m .7021 .72965 L .70174 .72806 L F
.69707 .71118 m .70219 .72967 L .6997 .71893 L F
.69834 .71304 m .6997 .71893 L .69839 .71308 L 0 1 .421 r
F
.6997 .71893 m .70338 .72864 L .69839 .71308 L F
.6997 .71893 m .70219 .72967 L .70338 .72864 L F
.70679 .71963 m .70338 .72864 L .70447 .73785 L 0 1 .432 r
F
.70451 .73797 m .70447 .73785 L .70449 .73803 L 0 .621 .408 r
F
.70451 .73797 m .70447 .73785 L .7045 .73806 L 0 1 .432 r
F
.70679 .71963 m .70447 .73785 L .70451 .73797 L F
.70699 .72577 m .70342 .72992 L .70447 .73785 L 0 .621 .408 r
F
.70699 .72577 m .70447 .73785 L .70451 .73797 L F
.69834 .71304 m .70342 .72991 L .70699 .72576 L 0 .588 .393 r
F
.69707 .71118 m .6997 .71893 L .69834 .71304 L F
.6997 .71893 m .70342 .72991 L .69834 .71304 L F
.6971 .71208 m .6997 .71893 L .69834 .71304 L 0 1 .421 r
F
.70174 .72806 m .7021 .72965 L .70219 .72967 L 0 .588 .393 r
F
.6997 .71893 m .70219 .72967 L .70342 .72991 L F
.6971 .71208 m .69802 .73328 L .70219 .72967 L 0 1 .421 r
F
.6971 .71208 m .70219 .72967 L .6997 .71893 L F
.6971 .71208 m .69428 .73047 L .69802 .73328 L F
.6971 .71208 m .69389 .72138 L .69428 .73047 L F
.69808 .71192 m .7064 .71052 L .69794 .71135 L F
.69808 .71192 m .70679 .71962 L .7064 .71052 L F
.69834 .71304 m .70679 .71962 L .69808 .71192 L F
.69808 .71192 m .70699 .72576 L .70665 .71819 L 0 .588 .393 r
F
.69707 .71118 m .69834 .71304 L .69808 .71192 L F
.69834 .71304 m .70699 .72576 L .69808 .71192 L F
.69827 .71299 m .69834 .71304 L .69808 .71192 L 0 1 .421 r
F
.6971 .71208 m .69827 .71299 L .69808 .71192 L F
.69798 .71136 m .70665 .71819 L .70262 .71225 L 0 .588 .393 r
F
.69794 .71135 m .69798 .71138 L .69798 .71136 L F
.69798 .71138 m .70665 .71819 L .69798 .71136 L F
.69707 .71118 m .69808 .71192 L .69794 .71135 L F
.69808 .71192 m .70665 .71819 L .69794 .71135 L F
.69794 .71135 m .7064 .71052 L .70247 .70742 L 0 1 .421 r
F
.6971 .71208 m .69808 .71192 L .69794 .71135 L F
.68978 .72384 m .69471 .69952 L .69922 .70909 L 0 .67 .125 r
F
.69379 .68478 m .70299 .6943 L .69878 .68722 L 0 .351 .35 r
F
.69379 .68478 m .70419 .70208 L .70299 .6943 L F
.69379 .68478 m .70156 .70536 L .70419 .70208 L F
.69157 .68453 m .70002 .6837 L .70318 .69863 L 0 .67 .087 r
F
.70419 .70208 m .70156 .70536 L .70262 .71225 L 0 .362 .359 r
F
.69157 .68453 m .70286 .70869 L .69922 .70909 L 0 .67 .087 r
F
.69157 .68453 m .70318 .69863 L .70286 .70869 L F
.69434 .69794 m .69911 .67828 L .69514 .68079 L 0 .944 .325 r
F
.69434 .69794 m .70435 .69086 L .69911 .67828 L F
.70419 .70208 m .70262 .71225 L .70665 .71819 L 0 .362 .359 r
F
.72201 .71045 m .71141 .72955 L .71452 .73365 L 0 1 .428 r
F
.72201 .71045 m .71462 .71961 L .71141 .72955 L F
.71367 .69958 m .71462 .71961 L .72201 .71045 L 0 1 .421 r
F
.70679 .71963 m .71839 .71954 L .71323 .71572 L 0 1 .432 r
F
.72201 .71045 m .71452 .73365 L .72262 .72997 L 0 1 .428 r
F
.70679 .71963 m .7195 .72898 L .71839 .71954 L 0 1 .432 r
F
.70419 .70208 m .70665 .71819 L .71177 .72045 L 0 .362 .359 r
F
.71367 .69958 m .72201 .71045 L .72499 .70028 L 0 1 .421 r
F
.71367 .69958 m .72499 .70028 L .72156 .69587 L F
.7139 .6972 m .71323 .71572 L .71839 .71954 L 0 1 .43 r
F
.7139 .6972 m .7113 .70615 L .71323 .71572 L F
.70419 .70208 m .71177 .72045 L .71457 .71752 L 0 .362 .359 r
F
.70419 .70208 m .71352 .71059 L .70931 .70431 L F
.70419 .70208 m .71457 .71752 L .71352 .71059 L F
.70944 .6971 m .70931 .70431 L .71352 .71059 L 0 .194 .245 r
F
.70944 .6971 m .70756 .69853 L .70931 .70431 L F
.70286 .70869 m .70679 .69712 L .71128 .70512 L 0 .594 .083 r
F
.70286 .70869 m .70318 .69863 L .70679 .69712 L F
.70679 .71963 m .71582 .73773 L .7195 .72898 L 0 1 .432 r
F
.71457 .71752 m .71177 .72045 L .71363 .72786 L 0 .393 .372 r
F
.70286 .70869 m .71128 .70512 L .71441 .71817 L 0 .594 .083 r
F
.69434 .69794 m .70738 .71019 L .70435 .69086 L 0 .944 .325 r
F
.70679 .71963 m .7094 .74161 L .71582 .73773 L 0 1 .432 r
F
.71045 .74327 m .71794 .75316 L .72227 .74369 L 0 1 .438 r
F
.71045 .74327 m .72227 .74369 L .71917 .73971 L F
.73033 .72094 m .71917 .73971 L .72227 .74369 L 0 1 .434 r
F
.73033 .72094 m .72262 .72997 L .71917 .73971 L F
.7195 .72898 m .71606 .74636 L .72004 .74913 L 0 1 .445 r
F
.7195 .72898 m .71583 .73773 L .71606 .74636 L F
.71457 .71752 m .71363 .72786 L .7189 .73482 L 0 .393 .372 r
F
.70286 .70869 m .71441 .71817 L .71407 .72763 L 0 .594 .083 r
F
.70699 .72577 m .7189 .73482 L .71363 .72786 L 0 .621 .408 r
F
.73033 .72094 m .72227 .74369 L .73061 .73999 L 0 1 .434 r
F
.7195 .72898 m .72004 .74913 L .72594 .74476 L 0 1 .445 r
F
.70699 .72577 m .71997 .74296 L .7189 .73482 L 0 .621 .408 r
F
.70286 .70869 m .71045 .72922 L .70597 .72182 L 0 .594 .083 r
F
.70286 .70869 m .71407 .72763 L .71045 .72922 L F
.68978 .72384 m .69922 .70909 L .70189 .7286 L 0 .67 .125 r
F
.70969 .75072 m .72004 .74913 L .71606 .74636 L 0 1 .449 r
F
.70699 .72577 m .70949 .74471 L .71612 .74683 L 0 .621 .408 r
F
.70699 .72577 m .71612 .74683 L .71997 .74296 L F
.70092 .74516 m .70597 .72182 L .71045 .72922 L 0 .593 .115 r
F
.70092 .74516 m .70189 .7286 L .70597 .72182 L F
.69434 .69794 m .70659 .72739 L .70738 .71019 L 0 .944 .325 r
F
.69434 .69794 m .70251 .73096 L .70659 .72739 L F
.68978 .72384 m .69067 .70579 L .69471 .69952 L 0 .67 .125 r
F
.68978 .72384 m .70189 .7286 L .70092 .74516 L F
.69434 .69794 m .69726 .71832 L .70251 .73096 L 0 .944 .325 r
F
.68442 .70815 m .69726 .71832 L .69434 .69794 L 0 .948 .313 r
F
.67728 .67367 m .68978 .64022 L .68639 .66459 L 0 .246 .141 r
F
.67728 .67367 m .68639 .66459 L .68115 .68688 L F
.68639 .66459 m .6901 .67639 L .68651 .6802 L 0 .234 .126 r
F
.68466 .70548 m .69636 .67069 L .70111 .66689 L 0 .015 .082 r
F
.68466 .70548 m .68933 .68715 L .69636 .67069 L F
.68466 .70548 m .70111 .66689 L .70093 .67537 L F
.68667 .70281 m .70093 .67537 L .69589 .69058 L F
.68466 .70548 m .68587 .70324 L .68667 .70281 L F
.68587 .70324 m .70093 .67537 L .68667 .70281 L F
.68639 .66459 m .69924 .63743 L .69557 .65797 L 0 .234 .126 r
F
.68639 .66459 m .69557 .65797 L .6901 .67639 L F
.70178 .67851 m .70323 .68273 L .70758 .69031 L 0 0 .125 r
F
.70178 .67851 m .70758 .69031 L .7117 .69692 L F
.70178 .67851 m .71034 .69307 L .70589 .6851 L F
.70178 .67851 m .71283 .69814 L .71034 .69307 L F
.70178 .67851 m .7117 .69692 L .71283 .69814 L F
.7117 .65178 m .72248 .65317 L .71875 .6481 L 0 1 .401 r
F
.7117 .65178 m .72081 .66424 L .72248 .65317 L F
.71113 .64614 m .71285 .66261 L .71707 .66641 L 0 .739 .417 r
F
.71113 .64614 m .7103 .65392 L .71285 .66261 L F
.705 .63711 m .70905 .65707 L .71605 .67089 L 0 .801 .343 r
F
.71113 .64614 m .71707 .66641 L .72092 .66365 L 0 .739 .417 r
F
.71113 .64614 m .71928 .64744 L .71498 .64335 L F
.71113 .64614 m .72183 .65615 L .71928 .64744 L F
.71113 .64614 m .72092 .66365 L .72183 .65615 L F
.71181 .6298 m .71498 .64335 L .71928 .64744 L 0 .508 .401 r
F
.71181 .6298 m .71178 .6358 L .71498 .64335 L F
.71181 .6298 m .71928 .64744 L .72256 .64606 L F
.71181 .6298 m .71941 .63253 L .71508 .62839 L F
.71181 .6298 m .72262 .64011 L .71941 .63253 L F
.71181 .6298 m .72256 .64606 L .72262 .64011 L F
.7123 .6213 m .71479 .62143 L .72079 .62368 L 0 0 0 r
F
.7123 .6213 m .71977 .62381 L .71443 .62232 L F
.71745 .62332 m .72107 .62425 L .72705 .62569 L 0 .443 .197 r
F
.71745 .62332 m .7314 .62669 L .73183 .62612 L F
.71745 .62332 m .73183 .62612 L .72801 .62435 L F
.71745 .62332 m .72201 .62291 L .71784 .62275 L F
.71745 .62332 m .72801 .62435 L .72201 .62291 L F
.705 .63711 m .71789 .63628 L .71089 .6225 L 0 .801 .343 r
F
.705 .63711 m .72212 .65448 L .71789 .63628 L F
.72081 .66424 m .72366 .68552 L .72991 .67611 L 0 1 .41 r
F
.72081 .66424 m .7318 .66542 L .72808 .6606 L F
.72081 .66424 m .72991 .67611 L .7318 .66542 L F
.72991 .67611 m .72156 .69587 L .72499 .70028 L 0 1 .418 r
F
.72991 .67611 m .72366 .68552 L .72156 .69587 L F
.72991 .67611 m .72499 .70028 L .73245 .69666 L F
.72183 .65615 m .72439 .67256 L .72993 .67695 L 0 .806 .436 r
F
.72183 .65615 m .72092 .66365 L .72439 .67256 L F
.72991 .67611 m .73245 .69666 L .73899 .68743 L 0 1 .418 r
F
.72991 .67611 m .74111 .67706 L .73739 .67247 L F
.72991 .67611 m .73899 .68743 L .74111 .67706 L F
.72183 .65615 m .72993 .67695 L .73484 .67475 L 0 .806 .436 r
F
.7342 .64048 m .72808 .6606 L .7318 .66542 L 0 .92 .407 r
F
.7342 .64048 m .7291 .64992 L .72808 .6606 L F
.72183 .65615 m .73238 .65847 L .72674 .65392 L 0 .806 .436 r
F
.7342 .64048 m .7318 .66542 L .73861 .66215 L 0 .92 .407 r
F
.72183 .65615 m .73585 .66741 L .73238 .65847 L 0 .806 .436 r
F
.72183 .65615 m .73484 .67475 L .73585 .66741 L F
.705 .63711 m .72133 .66933 L .72212 .65448 L 0 .801 .343 r
F
.705 .63711 m .71605 .67089 L .72133 .66933 L F
.70316 .68752 m .70589 .6851 L .71034 .69307 L 0 .42 .009 r
F
.72201 .71045 m .72262 .72997 L .73033 .72094 L 0 1 .428 r
F
.7139 .6972 m .71839 .71954 L .72437 .71592 L 0 1 .43 r
F
.70944 .6971 m .71845 .70751 L .71411 .70094 L 0 .194 .245 r
F
.70944 .6971 m .7202 .71332 L .71845 .70751 L F
.71283 .69814 m .7117 .69692 L .71411 .70094 L 0 0 .124 r
F
.70316 .68752 m .71034 .69307 L .71398 .70265 L 0 .42 .009 r
F
.70316 .68752 m .71128 .70512 L .70679 .69712 L F
.70944 .6971 m .71352 .71059 L .71818 .71446 L 0 .194 .245 r
F
.70316 .68752 m .71437 .70749 L .71128 .70512 L 0 .42 .009 r
F
.70944 .6971 m .71818 .71446 L .7202 .71332 L 0 .194 .245 r
F
.70316 .68752 m .71398 .70265 L .71437 .70749 L 0 .42 .009 r
F
.70435 .69086 m .71443 .6858 L .70909 .67336 L 0 .95 .337 r
F
.70871 .68228 m .71216 .648 L .71784 .62276 L 0 .254 .142 r
F
.69589 .69057 m .7076 .66222 L .7115 .65978 L 0 0 .067 r
F
.69589 .69057 m .70093 .67536 L .7076 .66222 L F
.70316 .68752 m .70282 .68272 L .70589 .6851 L 0 .42 .009 r
F
.70435 .69086 m .70909 .67336 L .70509 .67509 L 0 .95 .337 r
F
.69589 .69057 m .7115 .65978 L .71045 .66767 L 0 0 .067 r
F
.69589 .69057 m .71045 .66767 L .70511 .68074 L F
.68466 .70548 m .69589 .69058 L .69094 .70221 L 0 .015 .082 r
F
.68466 .70548 m .69094 .70221 L .68553 .70585 L F
.68305 .7098 m .67955 .7123 L .68485 .7122 L 0 .315 .263 r
F
.68253 .7091 m .67959 .71142 L .68466 .70548 L 0 .024 .09 r
F
.68253 .7091 m .67941 .71186 L .68305 .7098 L 0 .315 .263 r
F
.67941 .71186 m .67955 .7123 L .68305 .7098 L F
.68149 .71847 m .69297 .77502 L .69111 .74906 L F
.68107 .71907 m .69297 .77502 L .68149 .71847 L F
.67973 .71316 m .69297 .77502 L .6798 .71309 L F
.69585 .69891 m .69481 .6998 L .69527 .70013 L 0 .279 .283 r
F
.69597 .69927 m .69527 .70013 L .69655 .70104 L F
.69585 .69891 m .69527 .70013 L .69597 .69927 L F
.70509 .68816 m .7074 .68375 L .70512 .68811 L 0 0 0 r
F
.6968 .69744 m .69783 .7003 L .69743 .6971 L 0 .279 .283 r
F
.69668 .69709 m .69655 .70104 L .69783 .7003 L F
.69618 .69749 m .69491 .69848 L .69731 .69541 L 0 0 0 r
F
.69558 .6981 m .6957 .69845 L .69668 .69709 L 0 .279 .283 r
F
.6957 .69845 m .69655 .70104 L .69668 .69709 L F
.69668 .69709 m .69731 .69541 L .69802 .6947 L 0 0 0 r
F
.69558 .6981 m .69476 .69964 L .69585 .69891 L 0 .279 .283 r
F
.69476 .69964 m .69481 .6998 L .69585 .69891 L F
.67856 .7125 m .69297 .77502 L .67955 .7123 L 0 .315 .263 r
F
.68442 .70815 m .68722 .72947 L .69237 .74194 L 0 .948 .313 r
F
.68216 .71753 m .69111 .74906 L .68506 .71347 L 0 .315 .263 r
F
.6798 .71309 m .69111 .74906 L .68067 .71228 L F
.68442 .70815 m .69642 .7372 L .69726 .71832 L 0 .948 .313 r
F
.68442 .70815 m .69237 .74194 L .69642 .7372 L F
.68485 .7122 m .69685 .72253 L .6909 .70231 L 0 .376 .277 r
F
.68553 .70585 m .69094 .70221 L .6909 .70231 L 0 .015 .082 r
F
.68553 .70585 m .6909 .70231 L .68898 .7038 L F
.68485 .7122 m .6909 .70231 L .68604 .70607 L 0 .376 .277 r
F
.68553 .70585 m .6907 .70277 L .68604 .70607 L 0 .015 .082 r
F
.68604 .70607 m .6909 .70231 L .68841 .69385 L 0 .376 .277 r
F
.68898 .7038 m .6909 .70231 L .6907 .70277 L 0 .015 .082 r
F
.7011 .74517 m .71045 .72922 L .71303 .74589 L 0 .593 .115 r
F
.70092 .74516 m .70095 .74511 L .7011 .74517 L F
.70095 .74511 m .71045 .72922 L .7011 .74517 L F
.71794 .75316 m .73001 .75345 L .72692 .74958 L 0 1 .443 r
F
.70969 .75072 m .71946 .75756 L .72004 .74913 L 0 1 .449 r
F
.71946 .75756 m .72922 .76418 L .72999 .75588 L 0 1 .458 r
F
.71946 .75756 m .72999 .75588 L .72602 .75321 L F
.71997 .74296 m .71629 .75344 L .72035 .75839 L 0 .655 .422 r
F
.71997 .74296 m .71613 .74684 L .71629 .75344 L F
.71997 .74296 m .72035 .75839 L .72645 .75929 L F
.73863 .73106 m .73001 .75345 L .73858 .74971 L 0 1 .44 r
F
.73863 .73106 m .72692 .74958 L .73001 .75345 L F
.73863 .73106 m .73061 .73999 L .72692 .74958 L F
.73033 .72094 m .73061 .73999 L .73863 .73106 L 0 1 .434 r
F
.72983 .73615 m .72999 .75588 L .73605 .75149 L 0 1 .455 r
F
.72983 .73615 m .72602 .75321 L .72999 .75588 L F
.72983 .73615 m .72594 .74476 L .72602 .75321 L F
.71997 .74296 m .72645 .75929 L .73052 .75554 L 0 .655 .422 r
F
.71997 .74296 m .73052 .75554 L .73037 .74891 L F
.7195 .72898 m .72594 .74476 L .72983 .73615 L 0 1 .445 r
F
.71997 .74296 m .73037 .74891 L .72608 .74385 L 0 .655 .422 r
F
.71769 .75133 m .71715 .73907 L .72161 .74482 L 0 .513 .106 r
F
.70969 .75072 m .7147 .76602 L .71946 .75756 L 0 1 .449 r
F
.70977 .75324 m .71483 .77006 L .71972 .76552 L 0 .808 .431 r
F
.70977 .75324 m .72035 .75839 L .71629 .75344 L F
.70977 .75324 m .71972 .76552 L .72035 .75839 L F
.71769 .75133 m .71799 .7642 L .72216 .76103 L 0 1 .35 r
F
.71449 .75027 m .71452 .75013 L .71769 .75133 L 0 .513 .106 r
F
.71452 .75013 m .71715 .73907 L .71769 .75133 L F
.71449 .75027 m .71303 .74589 L .71715 .73907 L F
.71457 .75061 m .7133 .75401 L .71799 .7642 L 0 1 .35 r
F
.71449 .75027 m .71439 .75056 L .71457 .75061 L F
.71439 .75056 m .7133 .75401 L .71457 .75061 L F
.71449 .75027 m .71799 .7642 L .71769 .75133 L F
.71779 .75154 m .72216 .76103 L .72294 .75351 L F
.71769 .75133 m .72161 .74482 L .72296 .75255 L 0 .513 .106 r
F
.71779 .75154 m .72294 .75351 L .72301 .75281 L 0 1 .35 r
F
.71769 .75133 m .72296 .75255 L .72301 .75281 L 0 .513 .106 r
F
.71795 .7514 m .72301 .75281 L .72367 .74642 L 0 1 .35 r
F
.71779 .75154 m .72301 .75281 L .71795 .7514 L F
.71769 .75133 m .71779 .75154 L .71793 .75142 L F
.71769 .75133 m .72301 .75281 L .7241 .75906 L 0 .513 .106 r
F
.70096 .74649 m .71175 .76956 L .7133 .75401 L 0 1 .338 r
F
.71197 .76083 m .71769 .75133 L .7241 .75906 L 0 .513 .106 r
F
.71276 .74971 m .7133 .75401 L .71449 .75027 L 0 1 .35 r
F
.70096 .74649 m .7133 .75401 L .71276 .74971 L 0 1 .338 r
F
.70092 .74516 m .71303 .74589 L .71276 .74971 L 0 .593 .115 r
F
.70096 .74649 m .71276 .74971 L .70151 .74599 L 0 1 .338 r
F
.70151 .74599 m .71276 .74971 L .71197 .76083 L 0 .593 .115 r
F
.70092 .74516 m .71276 .74971 L .70151 .74599 L F
.70151 .74599 m .71276 .74971 L .70157 .74594 L 0 1 .338 r
F
.70157 .74594 m .71276 .74971 L .71121 .73726 L F
.71448 .75029 m .71276 .74971 L .71449 .75027 L 0 .513 .106 r
F
.71197 .76083 m .71276 .74971 L .71448 .75029 L F
.71276 .74971 m .71303 .74589 L .71449 .75027 L F
.71121 .73726 m .71276 .74971 L .71449 .75027 L 0 1 .35 r
F
.71121 .73726 m .71449 .75027 L .71769 .75133 L F
.71197 .76083 m .71449 .75027 L .71769 .75133 L 0 .513 .106 r
F
.71121 .73726 m .71769 .75133 L .72367 .74642 L 0 1 .35 r
F
.71769 .75133 m .71793 .75142 L .72367 .74642 L F
.70114 .74588 m .71121 .73726 L .70659 .72739 L 0 1 .338 r
F
.70096 .74649 m .70151 .74599 L .70114 .74588 L F
.70151 .74599 m .71121 .73726 L .70114 .74588 L F
.70092 .74516 m .70151 .74599 L .70114 .74588 L 0 .593 .115 r
F
.70151 .74599 m .70154 .74603 L .70114 .74588 L F
.70096 .74649 m .7076 .77353 L .71175 .76956 L 0 1 .338 r
F
.70114 .74588 m .71197 .76083 L .70787 .76778 L 0 .593 .115 r
F
.70154 .74603 m .71197 .76083 L .70114 .74588 L F
.70103 .74583 m .70659 .72739 L .70251 .73096 L 0 1 .338 r
F
.70092 .74516 m .70114 .74588 L .70102 .74585 L 0 .593 .115 r
F
.70102 .74585 m .70103 .74583 L .70103 .74583 L 0 1 .338 r
F
.70103 .74583 m .70659 .72739 L .70103 .74583 L F
.70096 .74649 m .70114 .74588 L .70102 .74585 L F
.70114 .74588 m .70659 .72739 L .70102 .74585 L F
.70096 .74649 m .70297 .76364 L .7076 .77353 L F
.70102 .74585 m .70787 .76778 L .70347 .762 L 0 .593 .115 r
F
.70114 .74588 m .70787 .76778 L .70102 .74585 L F
.68485 .7122 m .69829 .74372 L .69685 .72253 L 0 .376 .277 r
F
.7195 .72898 m .72961 .72749 L .72541 .72458 L 0 1 .445 r
F
.71457 .71752 m .72631 .72793 L .7208 .72072 L 0 .393 .372 r
F
.7195 .72898 m .72983 .73615 L .72961 .72749 L 0 1 .445 r
F
.71457 .71752 m .72816 .73536 L .72631 .72793 L 0 .393 .372 r
F
.71283 .69814 m .71411 .70094 L .71845 .70751 L 0 0 .124 r
F
.71283 .69814 m .71845 .70751 L .72263 .71346 L F
.72201 .71045 m .73033 .72094 L .73355 .71099 L 0 1 .428 r
F
.72201 .71045 m .73355 .71099 L .73013 .70675 L F
.7139 .6972 m .72437 .71592 L .72718 .70727 L 0 1 .43 r
F
.71283 .69814 m .72263 .71346 L .72385 .71481 L 0 0 .124 r
F
.71283 .69814 m .72144 .71079 L .717 .70407 L F
.71283 .69814 m .72385 .71481 L .72144 .71079 L F
.71437 .70749 m .717 .70407 L .72144 .71079 L 0 .381 .006 r
F
.71437 .70749 m .71398 .70265 L .717 .70407 L F
.72718 .70727 m .72437 .71592 L .72541 .72458 L 0 1 .445 r
F
.7202 .71332 m .7208 .72072 L .72631 .72793 L 0 .218 .248 r
F
.7202 .71332 m .71818 .71446 L .7208 .72072 L F
.72718 .70727 m .72541 .72458 L .72961 .72749 L 0 1 .445 r
F
.7202 .71332 m .72631 .72793 L .73208 .73261 L 0 .218 .248 r
F
.73033 .72094 m .73863 .73106 L .7421 .72129 L 0 1 .434 r
F
.73033 .72094 m .7421 .72129 L .73868 .71722 L F
.72718 .70727 m .72961 .72749 L .73499 .7233 L 0 1 .445 r
F
.7202 .71332 m .73165 .72533 L .72597 .71797 L 0 .218 .248 r
F
.7202 .71332 m .73427 .73161 L .73165 .72533 L F
.7202 .71332 m .73208 .73261 L .73427 .73161 L F
.71437 .70749 m .72144 .71079 L .72509 .71928 L 0 .381 .006 r
F
.71437 .70749 m .72509 .71928 L .72552 .72391 L F
.71437 .70749 m .72249 .72251 L .71801 .716 L F
.71437 .70749 m .72552 .72391 L .72249 .72251 L F
.71457 .71752 m .7189 .73482 L .72513 .73804 L 0 .393 .372 r
F
.71457 .71752 m .72513 .73804 L .72816 .73536 L F
.71407 .72763 m .71801 .716 L .72249 .72251 L 0 .51 .077 r
F
.71407 .72763 m .71441 .71817 L .71801 .716 L F
.70435 .69086 m .71683 .71995 L .71756 .70414 L 0 .95 .337 r
F
.70435 .69086 m .71273 .72267 L .71683 .71995 L F
.70435 .69086 m .70738 .71019 L .71273 .72267 L F
.70499 .74085 m .71283 .70057 L .70524 .74068 L 0 .09 .106 r
F
.71972 .76552 m .71483 .77006 L .71402 .77682 L 0 .84 .443 r
F
.7053 .78731 m .7157 .77734 L .71175 .76956 L 0 1 .353 r
F
.7053 .78731 m .71683 .79168 L .7157 .77734 L F
.7157 .77734 m .7273 .78359 L .72615 .76934 L 0 1 .365 r
F
.71972 .76552 m .73049 .77008 L .72644 .76552 L 0 .84 .443 r
F
.7157 .77734 m .72615 .76934 L .72216 .76103 L 0 1 .365 r
F
.7157 .77734 m .72216 .76103 L .71799 .7642 L F
.70804 .80843 m .71444 .77523 L .7188 .77937 L 0 .422 .132 r
F
.70804 .80843 m .70984 .7876 L .71444 .77523 L F
.70315 .74241 m .70329 .74286 L .70524 .74068 L 0 .444 .294 r
F
.70329 .74286 m .71547 .78128 L .70524 .74068 L F
.71197 .76083 m .7241 .75906 L .72295 .77239 L 0 .513 .106 r
F
.71197 .76083 m .7188 .77937 L .71444 .77523 L F
.71197 .76083 m .72295 .77239 L .7188 .77937 L F
.70542 .74106 m .71547 .78128 L .71339 .7583 L 0 .444 .294 r
F
.70524 .74068 m .70535 .74112 L .70542 .74106 L F
.70535 .74112 m .71547 .78128 L .70542 .74106 L F
.70816 .7387 m .71339 .7583 L .70894 .73817 L F
.70524 .74068 m .70542 .74106 L .70816 .7387 L F
.70542 .74106 m .71339 .7583 L .70816 .7387 L F
.71407 .72763 m .72161 .74482 L .71715 .73907 L 0 .51 .077 r
F
.71407 .72763 m .72523 .74257 L .72161 .74482 L F
.71407 .72763 m .72249 .72251 L .72558 .73388 L F
.72816 .73537 m .72513 .73805 L .72608 .74385 L 0 .429 .385 r
F
.71407 .72763 m .72558 .73388 L .72523 .74257 L 0 .51 .077 r
F
.71121 .73726 m .71683 .71995 L .71273 .72267 L 0 1 .35 r
F
.71121 .73726 m .72152 .73013 L .71683 .71995 L F
.7139 .6972 m .72526 .69768 L .71988 .69356 L 0 1 .43 r
F
.7139 .6972 m .72718 .70727 L .72526 .69768 L F
.72385 .71481 m .72597 .71797 L .73165 .72533 L 0 0 .129 r
F
.72385 .71481 m .72263 .71347 L .72597 .71797 L F
.73863 .73106 m .73858 .74971 L .74692 .74084 L 0 1 .44 r
F
.73863 .73106 m .74692 .74084 L .75064 .73123 L F
.73863 .73106 m .75064 .73123 L .74722 .7273 L F
.73798 .71479 m .7359 .73173 L .7401 .73448 L 0 1 .455 r
F
.73798 .71479 m .73499 .7233 L .7359 .73173 L F
.72385 .71481 m .73165 .72533 L .73692 .73181 L 0 0 .129 r
F
.72385 .71481 m .73692 .73181 L .73826 .73308 L F
.72385 .71481 m .73491 .72857 L .72911 .72128 L F
.72385 .71481 m .73826 .73308 L .73491 .72857 L F
.71443 .6858 m .72397 .7159 L .72938 .71323 L 0 .959 .351 r
F
.71443 .6858 m .71756 .70414 L .72397 .7159 L F
.71105 .73549 m .72156 .70638 L .71656 .73004 L 0 .074 .1 r
F
.71105 .73549 m .71656 .73004 L .7164 .73078 L F
.71121 .73726 m .72367 .74642 L .72152 .73013 L 0 1 .35 r
F
.72718 .70727 m .73499 .7233 L .73798 .71479 L 0 1 .445 r
F
.73899 .68743 m .73355 .71099 L .74123 .70735 L 0 1 .425 r
F
.73899 .68743 m .73013 .70675 L .73355 .71099 L F
.73899 .68743 m .73245 .69666 L .73013 .70675 L F
.72718 .70727 m .73694 .7061 L .73257 .70305 L 0 1 .445 r
F
.72718 .70727 m .73798 .71479 L .73694 .7061 L F
.71892 .67564 m .71988 .69356 L .72526 .69768 L 0 .935 .432 r
F
.71892 .67564 m .71717 .68413 L .71988 .69356 L F
.71892 .67564 m .72526 .69768 L .73072 .69462 L F
.71892 .67564 m .73072 .69462 L .73264 .68641 L F
.71892 .67564 m .73264 .68641 L .72993 .67695 L F
.71443 .6858 m .73099 .6983 L .72773 .68107 L 0 .959 .351 r
F
.71443 .6858 m .72938 .71323 L .73099 .6983 L F
.73264 .68642 m .73257 .70305 L .73694 .7061 L 0 .98 .448 r
F
.73264 .68642 m .73073 .69462 L .73257 .70305 L F
.72773 .68107 m .73099 .69829 L .73676 .70998 L 0 .987 .368 r
F
.72553 .72391 m .7251 .71928 L .72911 .72128 L 0 .33 0 r
F
.72152 .73013 m .72938 .71323 L .72397 .7159 L 0 1 .362 r
F
.71684 .73044 m .73109 .69638 L .72554 .7183 L 0 .053 .092 r
F
.72922 .76418 m .73896 .77058 L .73993 .76238 L 0 1 .465 r
F
.72922 .76418 m .73993 .76238 L .73596 .75981 L F
.73052 .75554 m .73675 .77072 L .74104 .767 L 0 .694 .434 r
F
.74016 .74296 m .73993 .76238 L .74614 .75794 L 0 1 .463 r
F
.74016 .74296 m .73596 .75981 L .73993 .76238 L F
.74016 .74296 m .73605 .75149 L .73596 .75981 L F
.73052 .75554 m .74107 .76076 L .73679 .75616 L 0 .694 .434 r
F
.73052 .75554 m .74104 .767 L .74107 .76076 L F
.72523 .74257 m .73329 .756 L .72931 .75339 L 0 .413 .069 r
F
.73052 .75554 m .72644 .76552 L .73049 .77008 L 0 .694 .434 r
F
.73052 .75554 m .73049 .77008 L .73675 .77072 L F
.72615 .76934 m .73739 .75783 L .73329 .756 L 0 1 .377 r
F
.72816 .73537 m .72608 .74385 L .73037 .74891 L 0 .429 .385 r
F
.72983 .73615 m .73605 .75149 L .74016 .74296 L 0 1 .455 r
F
.72816 .73537 m .73037 .74891 L .73599 .75077 L 0 .429 .385 r
F
.7392 .74816 m .73679 .75616 L .74107 .76076 L 0 .476 .397 r
F
.7392 .74816 m .73599 .75077 L .73679 .75616 L F
.72523 .74257 m .73979 .75762 L .73809 .75815 L 0 .413 .069 r
F
.72523 .74257 m .73809 .75815 L .73329 .756 L F
.73739 .75783 m .7377 .75751 L .73329 .756 L 0 1 .377 r
F
.72615 .76934 m .73992 .76112 L .7377 .75751 L F
.73329 .756 m .73809 .75815 L .73513 .75907 L 0 .413 .069 r
F
.73052 .75554 m .72645 .75929 L .72644 .76552 L 0 .694 .434 r
F
.72615 .76934 m .73329 .756 L .72941 .75622 L 0 1 .377 r
F
.73329 .756 m .73116 .75519 L .72931 .75339 L 0 .413 .069 r
F
.73329 .756 m .73491 .75298 L .73116 .75519 L 0 1 .377 r
F
.73329 .756 m .73116 .75519 L .72941 .75622 L F
.73329 .756 m .73129 .75532 L .73116 .75519 L 0 .413 .069 r
F
.73329 .756 m .73513 .75907 L .73129 .75532 L F
.73329 .756 m .7377 .75751 L .73491 .75298 L 0 1 .377 r
F
.72891 .75458 m .72941 .75622 L .73116 .75519 L 0 1 .362 r
F
.72983 .73615 m .7401 .73448 L .7359 .73173 L 0 1 .455 r
F
.72983 .73615 m .74016 .74296 L .7401 .73448 L F
.72816 .73537 m .73599 .75077 L .7392 .74816 L 0 .429 .385 r
F
.72816 .73537 m .73827 .74234 L .73379 .7372 L F
.72816 .73537 m .7392 .74816 L .73827 .74234 L F
.73427 .73161 m .73379 .7372 L .73827 .74234 L 0 .251 .255 r
F
.73427 .73161 m .73208 .73261 L .73379 .7372 L F
.72523 .74257 m .73023 .7325 L .73607 .73929 L 0 .413 .069 r
F
.72523 .74257 m .72559 .73388 L .73023 .7325 L F
.75046 .74943 m .74614 .75794 L .74589 .76616 L 0 1 .47 r
F
.7392 .74816 m .74107 .76076 L .74682 .76225 L 0 .476 .397 r
F
.75046 .74943 m .74986 .76864 L .75622 .76412 L 0 1 .47 r
F
.75046 .74943 m .74589 .76616 L .74986 .76864 L F
.74016 .74296 m .74614 .75794 L .75046 .74943 L 0 1 .463 r
F
.7392 .74816 m .74682 .76225 L .75022 .75963 L 0 .476 .397 r
F
.7392 .74816 m .74943 .75422 L .74497 .74963 L F
.7392 .74816 m .75022 .75963 L .74943 .75422 L F
.72523 .74257 m .73607 .73929 L .74018 .75005 L 0 .413 .069 r
F
.72523 .74257 m .74018 .75005 L .73979 .75762 L F
.72152 .73013 m .72367 .74642 L .72836 .75442 L 0 1 .362 r
F
.72891 .75458 m .72836 .75442 L .72941 .75622 L F
.72891 .75458 m .72836 .75442 L .72931 .75339 L 0 .422 .098 r
F
.72152 .73013 m .72836 .75442 L .72891 .75458 L 0 1 .362 r
F
.72296 .77239 m .7241 .75906 L .72836 .75442 L 0 .422 .098 r
F
.72296 .77239 m .72836 .75442 L .72891 .75458 L F
.72296 .77239 m .72891 .75458 L .73513 .75907 L F
.72891 .75458 m .72931 .75339 L .73116 .75519 L F
.72891 .75458 m .73116 .75519 L .73513 .75907 L F
.72152 .73013 m .72891 .75458 L .73491 .75298 L 0 1 .362 r
F
.72891 .75458 m .73116 .75519 L .73491 .75298 L F
.71651 .73073 m .73331 .75864 L .71684 .73044 L 0 .554 .319 r
F
.71681 .73047 m .71681 .73047 L .71684 .73044 L 0 .053 .092 r
F
.71681 .73047 m .73109 .69638 L .71684 .73044 L F
.74016 .74296 m .75046 .74943 L .75057 .74108 L 0 1 .463 r
F
.74016 .74296 m .75057 .74108 L .74638 .73849 L F
.73427 .73161 m .73827 .74234 L .74337 .74544 L 0 .251 .255 r
F
.73427 .73161 m .74337 .74544 L .7457 .74442 L F
.73427 .73161 m .74399 .73981 L .73938 .7347 L F
.73427 .73161 m .7457 .74442 L .74399 .73981 L F
.72553 .72391 m .72911 .72128 L .73491 .72857 L 0 .33 0 r
F
.72553 .72391 m .73491 .72857 L .73963 .73713 L F
.72553 .72391 m .73963 .73713 L .74011 .74128 L F
.72553 .72391 m .73607 .73929 L .73023 .7325 L F
.72553 .72391 m .74011 .74128 L .73607 .73929 L F
.72152 .73013 m .73735 .73875 L .73512 .72302 L 0 1 .362 r
F
.72152 .73013 m .73491 .75298 L .73735 .73875 L F
.71684 .73044 m .73331 .75864 L .72601 .7316 L 0 .554 .319 r
F
.73899 .68743 m .74123 .70735 L .74806 .69825 L 0 1 .425 r
F
.73899 .68743 m .7504 .68814 L .74669 .68377 L F
.73899 .68743 m .74806 .69825 L .7504 .68814 L F
.73264 .68642 m .74175 .70232 L .7438 .69422 L 0 .98 .448 r
F
.73264 .68642 m .74196 .68577 L .73746 .68261 L F
.73264 .68642 m .7438 .69422 L .74196 .68577 L F
.74397 .65296 m .73739 .67247 L .74111 .67706 L 0 .939 .416 r
F
.74397 .65296 m .73861 .66215 L .73739 .67247 L F
.73585 .66741 m .73746 .68261 L .74196 .68577 L 0 .872 .453 r
F
.73585 .66741 m .73484 .67475 L .73746 .68261 L F
.72773 .68107 m .74198 .69471 L .73861 .67822 L 0 .987 .368 r
F
.74806 .69825 m .74123 .70735 L .73868 .71722 L 0 1 .432 r
F
.73264 .68642 m .73694 .7061 L .74175 .70232 L 0 .98 .448 r
F
.72773 .68107 m .74119 .70832 L .74198 .69471 L 0 .987 .368 r
F
.72773 .68107 m .73676 .70998 L .74119 .70832 L F
.73896 .77058 m .74318 .78514 L .74869 .77678 L 0 1 .472 r
F
.73896 .77058 m .74869 .77678 L .74986 .76864 L F
.73896 .77058 m .74986 .76864 L .74589 .76616 L F
.74104 .767 m .73657 .77665 L .74061 .78086 L 0 .737 .446 r
F
.74104 .767 m .73675 .77072 L .73657 .77665 L F
.74104 .767 m .74061 .78086 L .74702 .78123 L F
.72615 .76934 m .74111 .7752 L .73992 .76112 L 0 1 .377 r
F
.72615 .76934 m .73785 .78831 L .74111 .7752 L F
.72296 .77239 m .73513 .75907 L .73856 .77177 L 0 .422 .098 r
F
.72296 .77239 m .73856 .77177 L .73729 .78311 L F
.71645 .73077 m .73577 .77952 L .71651 .73073 L 0 .554 .319 r
F
.71645 .73079 m .71645 .73077 L .7165 .73076 L 0 .053 .092 r
F
.71645 .73077 m .73228 .68248 L .71651 .73073 L F
.71645 .73077 m .71651 .73073 L .7165 .73076 L F
.71651 .73073 m .73577 .77952 L .73331 .75864 L 0 .554 .319 r
F
.7163 .73037 m .71645 .73077 L .71651 .73073 L F
.71095 .73576 m .72335 .75911 L .71641 .73083 L 0 .5 .307 r
F
.71645 .73077 m .72837 .68564 L .73228 .68248 L 0 .053 .092 r
F
.71632 .73117 m .71642 .73078 L .71645 .73077 L F
.71642 .73078 m .72837 .68564 L .71645 .73077 L F
.72296 .77239 m .73729 .78311 L .73205 .78891 L 0 .422 .098 r
F
.71645 .73077 m .73171 .78023 L .73577 .77952 L 0 .554 .319 r
F
.7163 .73037 m .71642 .73078 L .71645 .73077 L F
.71643 .7308 m .73171 .78023 L .71645 .73077 L F
.72152 .73013 m .73512 .72302 L .72938 .71323 L 0 1 .362 r
F
.72221 .72593 m .72601 .7316 L .72337 .72496 L 0 .554 .319 r
F
.71739 .73051 m .72601 .7316 L .72221 .72593 L F
.72554 .7183 m .72655 .72181 L .72495 .72332 L 0 .027 .083 r
F
.71716 .73 m .72554 .7183 L .72424 .72228 L 0 .053 .092 r
F
.7165 .73076 m .73109 .69638 L .71679 .73052 L F
.7165 .73076 m .73228 .68248 L .73109 .69638 L F
.74397 .65296 m .74111 .67706 L .74811 .67375 L 0 .939 .416 r
F
.73585 .66741 m .74196 .68577 L .74616 .68265 L 0 .872 .453 r
F
.73585 .66741 m .74616 .68265 L .74725 .67532 L F
.71892 .67564 m .72993 .67695 L .72439 .67256 L 0 .935 .432 r
F
.72773 .68107 m .73861 .67822 L .73285 .66655 L 0 .987 .368 r
F
.73585 .66741 m .74463 .66743 L .74005 .66426 L 0 .872 .453 r
F
.73585 .66741 m .74725 .67532 L .74463 .66743 L F
.7342 .64048 m .73861 .66215 L .74397 .65296 L 0 .92 .407 r
F
.73679 .65132 m .74005 .66426 L .74463 .66743 L 0 .731 .45 r
F
.74397 .65296 m .74811 .67375 L .75373 .66474 L 0 .939 .416 r
F
.73679 .65132 m .74463 .66743 L .74817 .66516 L 0 .731 .45 r
F
.73861 .67822 m .74366 .66458 L .73933 .66531 L 0 1 .381 r
F
.75373 .66474 m .74811 .67375 L .74669 .68377 L 0 .958 .424 r
F
.75373 .66474 m .74669 .68377 L .7504 .68814 L F
.75373 .66474 m .7504 .68814 L .75759 .68477 L F
.74725 .67532 m .74871 .69027 L .75321 .69311 L 0 .929 .465 r
F
.74725 .67532 m .74616 .68265 L .74871 .69027 L F
.76347 .67588 m .75759 .68477 L .75597 .69454 L 0 .978 .432 r
F
.74725 .67532 m .75321 .69311 L .75746 .68972 L 0 .929 .465 r
F
.75373 .66474 m .75759 .68477 L .76347 .67588 L 0 .958 .424 r
F
.74725 .67532 m .75746 .68972 L .75864 .68233 L 0 .929 .465 r
F
.74725 .67532 m .75609 .67468 L .75151 .67189 L F
.74725 .67532 m .75864 .68233 L .75609 .67468 L F
.73861 .67822 m .74952 .67594 L .74366 .66458 L 0 1 .381 r
F
.73861 .67822 m .753 .69183 L .74952 .67594 L F
.74806 .69825 m .74999 .71761 L .75711 .70861 L 0 1 .432 r
F
.74806 .69825 m .75968 .69871 L .75597 .69454 L F
.74806 .69825 m .75711 .70861 L .75968 .69871 L F
.74806 .69825 m .7421 .72129 L .74999 .71761 L F
.74806 .69825 m .73868 .71722 L .7421 .72129 L F
.7438 .69422 m .75277 .70938 L .75495 .70131 L 0 1 .459 r
F
.7438 .69422 m .75321 .69311 L .74871 .69027 L F
.7438 .69422 m .75495 .70131 L .75321 .69311 L F
.73861 .67822 m .75228 .70474 L .753 .69183 L 0 1 .381 r
F
.7438 .69422 m .74786 .71331 L .75277 .70938 L 0 1 .459 r
F
.73861 .67822 m .74784 .70608 L .75228 .70474 L 0 1 .381 r
F
.7438 .69422 m .74349 .7105 L .74786 .71331 L 0 1 .459 r
F
.7438 .69422 m .74175 .70232 L .74349 .7105 L F
.73861 .67822 m .74198 .69471 L .74784 .70608 L 0 1 .381 r
F
.72554 .7183 m .73815 .67804 L .74208 .67527 L 0 .027 .083 r
F
.72554 .7183 m .73109 .69638 L .73815 .67804 L F
.72554 .7183 m .74208 .67527 L .74068 .68763 L F
.72554 .7183 m .74068 .68763 L .73482 .70707 L F
.72601 .7316 m .73571 .7316 L .73023 .71906 L 0 .606 .331 r
F
.72554 .7183 m .73482 .70707 L .73023 .71906 L 0 .027 .083 r
F
.72554 .7183 m .73023 .71906 L .72988 .71934 L F
.72601 .7316 m .73023 .71906 L .72659 .72197 L 0 .606 .331 r
F
.72554 .7183 m .7301 .71939 L .72659 .72197 L 0 .027 .083 r
F
.72659 .72197 m .73023 .71906 L .7272 .71213 L 0 .606 .331 r
F
.72988 .71934 m .73023 .71906 L .7301 .71939 L 0 .027 .083 r
F
.72659 .72197 m .7301 .71939 L .72767 .72574 L F
.7249 .72321 m .7272 .71213 L .72339 .7117 L 0 .606 .331 r
F
.72494 .72346 m .725 .72314 L .7249 .72321 L F
.725 .72314 m .7272 .71213 L .7249 .72321 L F
.72601 .7316 m .72659 .72197 L .72494 .72346 L F
.72495 .72332 m .72502 .72339 L .72494 .72346 L 0 .027 .083 r
F
.72659 .72197 m .7272 .71213 L .72494 .72346 L 0 .606 .331 r
F
.72494 .72346 m .72767 .72574 L .72405 .73098 L 0 .027 .083 r
F
.72502 .72339 m .72767 .72574 L .72494 .72346 L F
.72655 .72181 m .72767 .72574 L .72495 .72332 L F
.71684 .73044 m .71739 .73051 L .72221 .72593 L 0 .554 .319 r
F
.71642 .73078 m .72156 .70638 L .72837 .68564 L 0 .053 .092 r
F
.71632 .73117 m .7164 .7308 L .71642 .73078 L F
.7164 .7308 m .72156 .70638 L .71642 .73078 L F
.71642 .73078 m .72335 .75911 L .73171 .78023 L 0 .554 .319 r
F
.71642 .73077 m .71642 .73078 L .71642 .73078 L F
.71642 .73078 m .72335 .75911 L .71642 .73078 L F
.7163 .73037 m .7164 .7308 L .71642 .73077 L F
.7164 .7308 m .72335 .75911 L .71642 .73077 L F
.71095 .73576 m .71641 .73083 L .71617 .73103 L 0 .5 .307 r
F
.71412 .73298 m .7164 .73078 L .7164 .7308 L 0 .074 .1 r
F
.71617 .73103 m .71641 .73083 L .71641 .73081 L 0 .5 .307 r
F
.71634 .73085 m .71641 .73081 L .7164 .7308 L F
.71566 .73171 m .7164 .7308 L .71632 .73117 L 0 .074 .1 r
F
.71412 .73298 m .7164 .7308 L .71566 .73171 L F
.71716 .73 m .72424 .72228 L .71864 .73943 L 0 .053 .092 r
F
.71684 .73044 m .72337 .72496 L .72331 .72482 L 0 .554 .319 r
F
.71632 .73117 m .71684 .73044 L .71864 .73943 L 0 .053 .092 r
F
.71684 .73044 m .71716 .73 L .71719 .73015 L F
.71684 .73044 m .71719 .73015 L .71864 .73943 L F
.71642 .73078 m .71643 .7308 L .71645 .73077 L 0 .554 .319 r
F
.7163 .73037 m .71651 .73073 L .71684 .73044 L F
.71677 .73043 m .71684 .73044 L .72312 .72434 L F
.71684 .73044 m .72331 .72482 L .72312 .72434 L F
.71679 .73052 m .71681 .73047 L .71684 .73044 L 0 .053 .092 r
F
.71632 .73117 m .7165 .73076 L .71679 .73052 L F
.71095 .73576 m .71641 .73081 L .71634 .73085 L 0 .5 .307 r
F
.71632 .73117 m .71645 .73079 L .7165 .73076 L 0 .053 .092 r
F
.71105 .73549 m .7164 .73078 L .71412 .73298 L 0 .074 .1 r
F
.71095 .73576 m .72252 .69077 L .72156 .70638 L F
.70983 .73664 m .7099 .73684 L .71095 .73576 L 0 .5 .307 r
F
.72296 .77239 m .73205 .78891 L .72635 .78523 L 0 .422 .098 r
F
.7099 .73684 m .72562 .78098 L .71095 .73576 L 0 .5 .307 r
F
.71095 .73576 m .72562 .78098 L .72335 .75911 L F
.71067 .73654 m .71095 .73576 L .71569 .73222 L 0 .074 .1 r
F
.71095 .73576 m .71105 .73549 L .71158 .73512 L F
.71095 .73576 m .71158 .73512 L .71569 .73222 L F
.70802 .73756 m .71208 .71809 L .70885 .73662 L 0 .09 .106 r
F
.70524 .74068 m .70536 .74028 L .70802 .73756 L F
.70536 .74028 m .71208 .71809 L .70802 .73756 L F
.7153 .73008 m .71095 .73576 L .7163 .73037 L 0 .5 .307 r
F
.70983 .73664 m .72252 .69077 L .71095 .73576 L 0 .074 .1 r
F
.70315 .74241 m .71283 .70057 L .70498 .74089 L 0 .09 .106 r
F
.70524 .74068 m .71283 .70057 L .71208 .71809 L F
.70315 .74241 m .70897 .70502 L .71283 .70057 L F
.7053 .78731 m .71175 .76956 L .7076 .77353 L 0 1 .353 r
F
.70198 .74312 m .71141 .78099 L .70315 .74241 L 0 .444 .294 r
F
.70286 .74367 m .70305 .74247 L .70315 .74241 L 0 .09 .106 r
F
.70305 .74247 m .70897 .70502 L .70315 .74241 L F
.70315 .74241 m .71141 .78099 L .71547 .78128 L 0 .444 .294 r
F
.69735 .79929 m .70347 .762 L .70787 .76778 L 0 .495 .147 r
F
.69735 .79929 m .70787 .76778 L .70984 .7876 L F
.70198 .74312 m .70341 .75573 L .71141 .78099 L 0 .444 .294 r
F
.70187 .74368 m .70198 .74312 L .70286 .74367 L 0 .09 .106 r
F
.70198 .74312 m .70897 .70502 L .70305 .74247 L F
.70198 .74312 m .70305 .74247 L .70286 .74367 L F
.70103 .74369 m .70341 .75573 L .70198 .74312 L 0 .444 .294 r
F
.69915 .74574 m .6997 .74702 L .70121 .74459 L 0 .376 .277 r
F
.6997 .74702 m .70341 .75573 L .70139 .74553 L F
.6997 .74702 m .70139 .74553 L .70121 .74459 L F
.702 .74301 m .70268 .73213 L .70897 .70502 L 0 .09 .106 r
F
.69735 .79929 m .69898 .77541 L .70347 .762 L 0 .495 .147 r
F
.69829 .74372 m .7046 .77961 L .70341 .75573 L 0 .376 .277 r
F
.69431 .7445 m .7046 .77961 L .69829 .74372 L F
.69915 .74574 m .70121 .74459 L .70103 .74369 L F
.68485 .7122 m .69959 .77807 L .7046 .77961 L F
.6981 .76424 m .70111 .74318 L .702 .74301 L 0 .09 .106 r
F
.70111 .74318 m .70268 .73213 L .702 .74301 L F
.68485 .7122 m .69431 .7445 L .69829 .74372 L 0 .376 .277 r
F
.6981 .76424 m .70463 .74268 L .70717 .74622 L 0 .09 .106 r
F
.70463 .74268 m .70524 .74068 L .70563 .74181 L F
.70463 .74268 m .70563 .74181 L .70717 .74622 L F
.69685 .72253 m .70103 .74369 L .70198 .74312 L 0 .444 .294 r
F
.69685 .72253 m .70198 .74312 L .70315 .74241 L F
.70983 .73664 m .72156 .78127 L .72562 .78098 L 0 .5 .307 r
F
.70435 .69086 m .71756 .70414 L .71443 .6858 L 0 .95 .337 r
F
.70922 .73699 m .71864 .69447 L .70983 .73664 L 0 .074 .1 r
F
.70922 .73699 m .71339 .7583 L .72156 .78127 L 0 .5 .307 r
F
.7092 .737 m .71208 .71809 L .70922 .73699 L 0 .074 .1 r
F
.70874 .73727 m .71208 .71809 L .70917 .7372 L F
.70524 .74068 m .70885 .73662 L .70874 .73727 L 0 .09 .106 r
F
.70524 .74068 m .70894 .73817 L .70874 .73727 L 0 .444 .294 r
F
.70559 .74168 m .70874 .73727 L .70717 .74622 L 0 .09 .106 r
F
.70524 .74068 m .70874 .73727 L .70559 .74168 L F
.70914 .7367 m .70874 .73727 L .70922 .73699 L 0 .5 .307 r
F
.70658 .72753 m .70874 .73727 L .70914 .7367 L F
.70874 .73727 m .71339 .7583 L .70922 .73699 L F
.70922 .73699 m .71208 .71809 L .71864 .69447 L 0 .074 .1 r
F
.70917 .7372 m .7092 .737 L .70922 .73699 L F
.70717 .74622 m .70874 .73727 L .70917 .7372 L F
.70554 .73773 m .70874 .73727 L .70658 .72753 L 0 .444 .294 r
F
.70524 .74068 m .70874 .73727 L .70554 .73773 L F
.70658 .72753 m .70922 .73699 L .70983 .73664 L 0 .5 .307 r
F
.70922 .73699 m .72156 .78127 L .70983 .73664 L F
.70983 .73664 m .71864 .69447 L .72252 .69077 L 0 .074 .1 r
F
.70717 .74622 m .70922 .73699 L .70983 .73664 L F
.70658 .72753 m .71053 .73497 L .7153 .73008 L 0 .5 .307 r
F
.71053 .73497 m .71095 .73576 L .7153 .73008 L F
.70717 .74622 m .70983 .73664 L .71095 .73576 L 0 .074 .1 r
F
.70658 .72753 m .70983 .73664 L .71095 .73576 L 0 .5 .307 r
F
.7163 .73037 m .71677 .73043 L .71768 .71064 L 0 .554 .319 r
F
.71677 .73043 m .72312 .72434 L .71768 .71064 L F
.71192 .73488 m .71105 .73549 L .71302 .73388 L 0 .074 .1 r
F
.71095 .73576 m .7164 .7308 L .7163 .73037 L 0 .5 .307 r
F
.71569 .73222 m .71192 .73488 L .71632 .73117 L 0 .074 .1 r
F
.71192 .73488 m .71302 .73388 L .71632 .73117 L F
.70717 .74622 m .71067 .73654 L .71569 .73222 L F
.70286 .74367 m .70315 .74241 L .70463 .74268 L 0 .09 .106 r
F
.70315 .74241 m .70498 .74089 L .70463 .74268 L F
.69685 .72253 m .70315 .74241 L .70524 .74068 L 0 .444 .294 r
F
.69685 .72253 m .70524 .74068 L .70658 .72753 L F
.70463 .74268 m .70499 .74085 L .70524 .74068 L 0 .09 .106 r
F
.6981 .76424 m .70286 .74367 L .70463 .74268 L F
.69829 .74372 m .69915 .74574 L .70103 .74369 L 0 .376 .277 r
F
.69829 .74372 m .70103 .74369 L .69685 .72253 L F
.6981 .76424 m .70187 .74368 L .70286 .74367 L 0 .09 .106 r
F
.68656 .78482 m .69898 .77541 L .69735 .79929 L 0 .565 .16 r
F
.68485 .7122 m .69112 .74906 L .69959 .77807 L 0 .376 .277 r
F
.69685 .72253 m .69863 .70252 L .69481 .6998 L 0 .444 .294 r
F
.68153 .72433 m .69635 .6977 L .69632 .69896 L 0 0 0 r
F
.69635 .6977 m .69668 .69709 L .69665 .69728 L F
.69635 .6977 m .69665 .69728 L .69632 .69896 L F
.68067 .71228 m .68216 .71753 L .68485 .71222 L 0 .315 .263 r
F
.68216 .71753 m .68506 .71347 L .68485 .71222 L F
.67955 .7123 m .6798 .71309 L .68067 .71228 L F
.69635 .6977 m .6961 .69763 L .69668 .69709 L 0 0 0 r
F
.68153 .72433 m .69577 .69824 L .69635 .6977 L F
.69577 .69824 m .6961 .69763 L .69635 .6977 L F
.6968 .69744 m .69743 .6971 L .69737 .69656 L 0 .279 .283 r
F
.69618 .69749 m .69731 .69541 L .69668 .69709 L 0 0 0 r
F
.69668 .69709 m .69802 .6947 L .69753 .69593 L F
.69802 .6947 m .69824 .69438 L .69761 .69589 L F
.69802 .6947 m .69761 .69589 L .69747 .69606 L F
.69783 .7003 m .69827 .70017 L .69761 .69589 L 0 .279 .283 r
F
.69802 .6947 m .69731 .69541 L .69837 .69406 L 0 0 0 r
F
.69589 .69057 m .69837 .69406 L .69478 .69864 L 0 0 .067 r
F
.69589 .69057 m .70511 .68074 L .69837 .69406 L F
.69733 .69625 m .69761 .69589 L .69589 .6848 L 0 .279 .283 r
F
.69783 .7003 m .69761 .69589 L .69733 .69625 L F
.69668 .69709 m .69753 .69593 L .69747 .69606 L 0 0 0 r
F
.69677 .69702 m .69737 .69656 L .69733 .69625 L 0 .279 .283 r
F
.69677 .69702 m .69733 .69625 L .69677 .69698 L F
.6968 .69744 m .69737 .69656 L .69677 .69702 L F
.69668 .69709 m .6968 .69744 L .69677 .69702 L F
.69668 .69709 m .69747 .69606 L .69632 .69896 L 0 0 0 r
F
.69747 .69606 m .69761 .69589 L .69632 .69896 L F
.69677 .69698 m .69733 .69625 L .69589 .6848 L 0 .279 .283 r
F
.6961 .69763 m .69618 .69749 L .69668 .69709 L 0 0 0 r
F
.6961 .69763 m .69478 .69864 L .69491 .69848 L F
.6961 .69763 m .69491 .69848 L .69618 .69749 L F
.69458 .69903 m .69478 .69864 L .6961 .69763 L F
.68153 .72433 m .68758 .71157 L .69454 .69906 L F
.69458 .69903 m .69454 .69906 L .69478 .69864 L F
.68153 .72433 m .69454 .69906 L .69458 .69903 L F
.67946 .64912 m .68659 .67686 L .69454 .69906 L 0 .279 .283 r
F
.69458 .69903 m .69454 .69906 L .69481 .6998 L F
.67946 .64912 m .69454 .69906 L .69458 .69903 L F
.67946 .64912 m .69458 .69903 L .69558 .6981 L F
.69458 .69903 m .69476 .69964 L .69558 .6981 L F
.67946 .64912 m .69668 .69709 L .69589 .6848 L F
.69668 .69709 m .69677 .69702 L .69589 .6848 L F
.68153 .72433 m .69458 .69903 L .6961 .69763 L 0 0 0 r
F
.67946 .64912 m .69558 .6981 L .69668 .69709 L 0 .279 .283 r
F
.70455 .68894 m .70264 .69114 L .70509 .68816 L 0 0 0 r
F
.70247 .69135 m .7074 .68375 L .70509 .68816 L F
.70202 .6919 m .70205 .69185 L .70247 .69135 L F
.70205 .69185 m .7074 .68375 L .70247 .69135 L F
.70871 .68228 m .71283 .70057 L .70897 .70502 L 0 .254 .142 r
F
.71443 .6858 m .72133 .66933 L .71605 .67089 L 0 .959 .351 r
F
.71443 .6858 m .72773 .68107 L .72133 .66933 L F
.70871 .68228 m .71859 .67469 L .71283 .70057 L 0 .254 .142 r
F
.72262 .64011 m .72674 .65392 L .73238 .65847 L 0 .622 .427 r
F
.72262 .64011 m .72256 .64606 L .72674 .65392 L F
.72262 .64011 m .73238 .65847 L .73669 .65736 L F
.71789 .63628 m .73285 .66655 L .7328 .653 L 0 .841 .362 r
F
.71789 .63628 m .72853 .66746 L .73285 .66655 L F
.71789 .63628 m .72212 .65448 L .72853 .66746 L F
.70871 .68228 m .72235 .64501 L .71859 .67469 L 0 .254 .142 r
F
.70722 .68664 m .71284 .67823 L .71648 .67479 L 0 0 0 r
F
.70718 .68667 m .71284 .67823 L .70722 .68664 L F
.70594 .68765 m .71284 .67823 L .70707 .68683 L F
.71789 .63628 m .72201 .62291 L .71784 .62275 L 0 .841 .362 r
F
.72131 .62882 m .72692 .63897 L .7326 .64342 L 0 .374 .33 r
F
.72131 .62882 m .72209 .63272 L .72692 .63897 L F
.72131 .62882 m .7326 .64342 L .73625 .64345 L F
.72131 .62882 m .73058 .63273 L .72494 .62881 L F
.72131 .62882 m .73543 .63901 L .73058 .63273 L F
.7342 .64048 m .74501 .64225 L .74103 .63718 L 0 .92 .407 r
F
.7342 .64048 m .74397 .65296 L .74501 .64225 L F
.72131 .62882 m .73625 .64345 L .73543 .63901 L 0 .374 .33 r
F
.71789 .63628 m .72842 .63587 L .72201 .62291 L 0 .841 .362 r
F
.72262 .64011 m .7326 .64342 L .72692 .63897 L 0 .622 .427 r
F
.72262 .64011 m .73678 .65131 L .7326 .64342 L F
.72262 .64011 m .73669 .65736 L .73678 .65131 L F
.71789 .63628 m .7328 .653 L .72842 .63587 L 0 .841 .362 r
F
.70871 .68228 m .71784 .62276 L .72201 .62291 L 0 .254 .142 r
F
.70871 .68228 m .72073 .62863 L .72235 .64501 L F
.72073 .62863 m .72209 .62854 L .72235 .64501 L F
.722 .62297 m .72201 .62297 L .72235 .64501 L F
.7258 .62607 m .72847 .62759 L .73384 .63012 L 0 .353 .2 r
F
.73502 .60389 m .73105 .62393 L .73504 .62933 L 0 .782 .395 r
F
.73502 .60389 m .73104 .61304 L .73105 .62393 L F
.7258 .62607 m .73384 .63012 L .73834 .632 L 0 .353 .2 r
F
.7258 .62607 m .73834 .632 L .73961 .63163 L F
.73502 .60389 m .73504 .62933 L .74119 .62678 L 0 .782 .395 r
F
.7258 .62607 m .73961 .63163 L .7368 .62924 L 0 .353 .2 r
F
.7258 .62607 m .7314 .62669 L .72705 .62569 L F
.7258 .62607 m .7368 .62924 L .7314 .62669 L F
.7454 .61796 m .74119 .62678 L .74103 .63718 L 0 .806 .405 r
F
.72801 .62435 m .73795 .62806 L .74231 .62889 L 0 .56 .237 r
F
.72801 .62435 m .73183 .62612 L .73795 .62806 L F
.72801 .62435 m .74231 .62889 L .7426 .62766 L F
.72801 .62435 m .7426 .62766 L .7386 .62517 L F
.72801 .62435 m .73245 .62321 L .72827 .6231 L F
.72801 .62435 m .7386 .62517 L .73245 .62321 L F
.72842 .63587 m .73245 .62322 L .72827 .62311 L 0 .875 .377 r
F
.73178 .63081 m .73825 .63761 L .74284 .64019 L 0 .391 .236 r
F
.73178 .63081 m .73352 .6336 L .73825 .63761 L F
.7454 .61796 m .74103 .63718 L .74501 .64225 L 0 .806 .405 r
F
.73178 .63081 m .74284 .64019 L .74492 .63953 L 0 .391 .236 r
F
.73178 .63081 m .74492 .63953 L .74309 .63604 L F
.73178 .63081 m .73834 .632 L .73384 .63012 L F
.73178 .63081 m .74309 .63604 L .73834 .632 L F
.72842 .63587 m .73898 .63552 L .73245 .62322 L 0 .875 .377 r
F
.73679 .65132 m .74493 .65202 L .74032 .64901 L 0 .731 .45 r
F
.73543 .63901 m .74032 .64901 L .74493 .65202 L 0 .516 .394 r
F
.73543 .63901 m .73625 .64345 L .74032 .64901 L F
.73543 .63901 m .74493 .65202 L .74776 .65064 L F
.73543 .63901 m .74776 .65064 L .74692 .64578 L F
.73543 .63901 m .74284 .64019 L .73825 .63761 L F
.73543 .63901 m .74692 .64578 L .74284 .64019 L F
.72842 .63587 m .74352 .65181 L .73898 .63552 L 0 .875 .377 r
F
.73679 .65132 m .73669 .65737 L .74005 .66426 L 0 .731 .45 r
F
.73679 .65132 m .74817 .66516 L .7483 .65895 L F
.74397 .65296 m .75497 .65439 L .75099 .64963 L 0 .939 .416 r
F
.74397 .65296 m .75373 .66474 L .75497 .65439 L F
.73679 .65132 m .7483 .65895 L .74493 .65202 L 0 .731 .45 r
F
.72842 .63587 m .74366 .66458 L .74352 .65181 L 0 .875 .377 r
F
.72842 .63587 m .73933 .66531 L .74366 .66458 L F
.72842 .63587 m .7328 .653 L .73933 .66531 L F
.71859 .67469 m .72827 .62311 L .73245 .62322 L 0 .238 .128 r
F
.71859 .67469 m .72235 .64501 L .72827 .62311 L F
.71859 .67469 m .73115 .62801 L .73258 .64248 L F
.73115 .62801 m .73246 .62789 L .73258 .64248 L F
.73242 .6233 m .73245 .62331 L .73258 .64248 L F
.7454 .61796 m .74501 .64225 L .75132 .63963 L 0 .806 .405 r
F
.7368 .62924 m .74509 .63459 L .74959 .63615 L 0 .49 .24 r
F
.7368 .62924 m .73961 .63163 L .74509 .63459 L F
.7454 .61796 m .75132 .63963 L .75575 .63104 L 0 .806 .405 r
F
.7368 .62924 m .74959 .63615 L .75077 .63499 L 0 .49 .24 r
F
.7368 .62924 m .75077 .63499 L .74781 .63187 L F
.7368 .62924 m .74231 .62889 L .73795 .62806 L F
.7368 .62924 m .74781 .63187 L .74231 .62889 L F
.73502 .60389 m .74119 .62678 L .7454 .61796 L 0 .782 .395 r
F
.7386 .62517 m .74886 .63002 L .75324 .63069 L 0 .632 .276 r
F
.7386 .62517 m .7426 .62766 L .74886 .63002 L F
.7386 .62517 m .75324 .63069 L .75339 .62886 L F
.7386 .62517 m .75339 .62886 L .74921 .62574 L F
.7386 .62517 m .74291 .62336 L .73872 .62332 L F
.7386 .62517 m .74921 .62574 L .74291 .62336 L F
.73898 .63552 m .74291 .62337 L .73872 .62333 L 0 .91 .392 r
F
.74309 .63604 m .74959 .63615 L .74509 .63459 L 0 .489 .326 r
F
.73898 .63552 m .74957 .63512 L .74291 .62337 L 0 .91 .392 r
F
.72773 .68107 m .73285 .66655 L .72853 .66746 L 0 .987 .368 r
F
.75575 .63104 m .75099 .64963 L .75497 .65439 L 0 .831 .415 r
F
.75575 .63104 m .75132 .63963 L .75099 .64963 L F
.75575 .63104 m .75497 .65439 L .76144 .65166 L F
.74692 .64578 m .75927 .65678 L .7584 .65152 L 0 .667 .433 r
F
.74692 .64578 m .7543 .64593 L .74972 .64376 L F
.74692 .64578 m .7584 .65152 L .7543 .64593 L F
.74309 .63604 m .74972 .64376 L .7543 .64593 L 0 .489 .326 r
F
.74309 .63604 m .74492 .63953 L .74972 .64376 L F
.74309 .63604 m .7543 .64593 L .75632 .6445 L F
.74309 .63604 m .75632 .6445 L .75441 .64041 L F
.74309 .63604 m .75441 .64041 L .74959 .63615 L F
.73898 .63552 m .75426 .65076 L .74957 .63512 L 0 .91 .392 r
F
.75373 .66474 m .76491 .66583 L .76094 .66134 L 0 .958 .424 r
F
.75373 .66474 m .76347 .67588 L .76491 .66583 L F
.7483 .65895 m .75964 .67197 L .7598 .66555 L 0 .82 .466 r
F
.7483 .65895 m .75646 .65878 L .75185 .6562 L F
.7483 .65895 m .7598 .66555 L .75646 .65878 L F
.74692 .64578 m .75185 .6562 L .75646 .65878 L 0 .667 .433 r
F
.74692 .64578 m .74776 .65064 L .75185 .6562 L F
.74692 .64578 m .75646 .65878 L .75927 .65678 L F
.73898 .63552 m .75452 .66294 L .75426 .65076 L 0 .91 .392 r
F
.7483 .65895 m .75151 .67189 L .75609 .67468 L 0 .82 .466 r
F
.7483 .65895 m .75609 .67468 L .75964 .67197 L F
.73898 .63552 m .75017 .66356 L .75452 .66294 L 0 .91 .392 r
F
.7483 .65895 m .74817 .66516 L .75151 .67189 L 0 .82 .466 r
F
.73898 .63552 m .74352 .65181 L .75017 .66356 L 0 .91 .392 r
F
.72852 .66836 m .73872 .62333 L .74291 .62337 L 0 .22 .113 r
F
.72852 .66836 m .73258 .64248 L .73872 .62333 L F
.72852 .66836 m .74161 .62741 L .74284 .64022 L F
.74161 .62741 m .74287 .62727 L .74284 .64022 L F
.74288 .62346 m .74291 .62347 L .74284 .64022 L F
.75575 .63104 m .76144 .65166 L .7661 .64323 L 0 .831 .415 r
F
.74781 .63187 m .75635 .6383 L .76085 .63961 L 0 .577 .31 r
F
.74781 .63187 m .75077 .63499 L .75635 .6383 L F
.75575 .63104 m .7661 .64323 L .76644 .63319 L 0 .831 .415 r
F
.74781 .63187 m .76085 .63961 L .76193 .63778 L 0 .577 .31 r
F
.74781 .63187 m .76193 .63778 L .75884 .63403 L F
.74781 .63187 m .75324 .63069 L .74886 .63002 L F
.74781 .63187 m .75884 .63403 L .75324 .63069 L F
.7454 .61796 m .75575 .63104 L .75593 .6206 L 0 .806 .405 r
F
.75575 .63104 m .76644 .63319 L .76224 .62827 L 0 .831 .415 r
F
.74921 .62574 m .7598 .63159 L .76418 .63212 L 0 .789 .351 r
F
.74921 .62574 m .75339 .62886 L .7598 .63159 L F
.76515 .61138 m .76224 .62827 L .76644 .63319 L 0 .699 .413 r
F
.74921 .62574 m .76418 .63212 L .7642 .62976 L 0 .789 .351 r
F
.76515 .61138 m .76168 .61893 L .76224 .62827 L 0 .699 .413 r
F
.74921 .62574 m .7642 .62976 L .75984 .62607 L 0 .789 .351 r
F
.74921 .62574 m .7534 .62332 L .7492 .62336 L F
.74921 .62574 m .75984 .62607 L .7534 .62332 L F
.74957 .63512 m .7534 .62333 L .7492 .62337 L 0 .946 .405 r
F
.7661 .64323 m .77694 .64491 L .77275 .64032 L 0 .858 .425 r
F
.75884 .63403 m .76761 .64141 L .77212 .64251 L 0 .757 .383 r
F
.75884 .63403 m .76193 .63778 L .76761 .64141 L F
.77598 .62385 m .77275 .64032 L .77694 .64491 L 0 .736 .424 r
F
.77598 .62385 m .77233 .63131 L .77275 .64032 L F
.75884 .63403 m .77212 .64251 L .77311 .6401 L 0 .757 .383 r
F
.75884 .63403 m .77311 .6401 L .76989 .63578 L F
.75884 .63403 m .76418 .63212 L .7598 .63159 L F
.75884 .63403 m .76989 .63578 L .76418 .63212 L F
.74957 .63512 m .76019 .63465 L .7534 .62333 L 0 .946 .405 r
F
.7385 .66291 m .7492 .62337 L .7534 .62333 L 0 .197 .104 r
F
.7385 .66291 m .74284 .64022 L .7492 .62337 L F
.74957 .63512 m .75426 .65076 L .76104 .66207 L 0 .946 .405 r
F
.7661 .64323 m .76094 .66134 L .76491 .66583 L 0 .858 .425 r
F
.7661 .64323 m .76144 .65166 L .76094 .66134 L F
.7661 .64323 m .76491 .66583 L .77154 .66296 L F
.7584 .65152 m .76337 .66239 L .76798 .66463 L 0 .792 .46 r
F
.7584 .65152 m .75927 .65678 L .76337 .66239 L F
.7584 .65152 m .76798 .66463 L .77077 .66209 L F
.7661 .64323 m .77154 .66296 L .77642 .65462 L 0 .858 .425 r
F
.7584 .65152 m .77077 .66209 L .76988 .65643 L 0 .792 .46 r
F
.7584 .65152 m .76576 .65079 L .76118 .64894 L F
.7584 .65152 m .76988 .65643 L .76576 .65079 L F
.74957 .63512 m .76104 .66207 L .7654 .66151 L 0 .946 .405 r
F
.75441 .64041 m .76576 .65079 L .76772 .64872 L 0 .661 .395 r
F
.75441 .64041 m .76772 .64872 L .76573 .64408 L F
.75441 .64041 m .76085 .63961 L .75635 .6383 L F
.75441 .64041 m .76573 .64408 L .76085 .63961 L F
.74957 .63512 m .76504 .64977 L .76019 .63465 L 0 .946 .405 r
F
.75441 .64041 m .76118 .64894 L .76576 .65079 L 0 .661 .395 r
F
.75441 .64041 m .75632 .6445 L .76118 .64894 L F
.74957 .63512 m .7654 .66151 L .76504 .64977 L 0 .946 .405 r
F
.7385 .66291 m .75211 .62676 L .75313 .63811 L 0 .197 .104 r
F
.75211 .62676 m .75331 .6266 L .75313 .63811 L F
.75336 .62342 m .7534 .62342 L .75313 .63811 L F
.76515 .61138 m .76644 .63319 L .77233 .63131 L 0 .699 .413 r
F
.75984 .62607 m .77075 .63282 L .77514 .63322 L 0 .939 .408 r
F
.75984 .62607 m .7642 .62976 L .77075 .63282 L F
.76515 .61138 m .77233 .63131 L .77598 .62385 L 0 .699 .413 r
F
.75984 .62607 m .77514 .63322 L .77504 .63038 L 0 .939 .408 r
F
.75984 .62607 m .77504 .63038 L .77049 .62617 L F
.75984 .62607 m .77049 .62617 L .76391 .62309 L F
.75984 .62607 m .76391 .62309 L .7597 .62321 L F
.76019 .63465 m .76391 .62309 L .7597 .62321 L 0 .98 .418 r
F
.76989 .63578 m .77514 .63322 L .77075 .63282 L 0 .905 .433 r
F
.76019 .63465 m .77083 .63406 L .76391 .62309 L 0 .98 .418 r
F
.74852 .65807 m .7597 .62321 L .76391 .62309 L 0 .171 .095 r
F
.74852 .65807 m .75313 .63811 L .7597 .62321 L F
.77642 .65462 m .77087 .67239 L .77483 .67663 L 0 .885 .433 r
F
.77642 .65462 m .77154 .66296 L .77087 .67239 L F
.77642 .65462 m .77483 .67663 L .78163 .67361 L F
.76988 .65643 m .77489 .66778 L .7795 .66974 L 0 .894 .48 r
F
.77642 .65462 m .78163 .67361 L .78673 .66531 L 0 .885 .433 r
F
.76988 .65643 m .7795 .66974 L .78227 .66671 L 0 .894 .48 r
F
.76988 .65643 m .78227 .66671 L .78136 .66068 L F
.77642 .65462 m .78673 .66531 L .78743 .65585 L 0 .885 .433 r
F
.76988 .65643 m .77723 .65495 L .77264 .65337 L 0 .894 .48 r
F
.76988 .65643 m .78136 .66068 L .77723 .65495 L F
.7661 .64323 m .77642 .65462 L .77694 .64491 L 0 .858 .425 r
F
.77642 .65462 m .78743 .65585 L .78324 .65156 L 0 .885 .433 r
F
.76573 .64408 m .77264 .65337 L .77723 .65495 L 0 .813 .441 r
F
.76573 .64408 m .76772 .64872 L .77264 .65337 L F
.76573 .64408 m .77723 .65495 L .77913 .65232 L F
.76573 .64408 m .77913 .65232 L .77706 .64719 L F
.76573 .64408 m .77212 .64251 L .76761 .64141 L F
.76573 .64408 m .77706 .64719 L .77212 .64251 L F
.76019 .63465 m .77194 .66071 L .77631 .6602 L 0 .98 .418 r
F
.76988 .65643 m .77077 .66209 L .77489 .66778 L 0 .894 .48 r
F
.76019 .63465 m .76504 .64977 L .77194 .66071 L 0 .98 .418 r
F
.76019 .63465 m .77631 .6602 L .77584 .64878 L F
.77598 .62385 m .77694 .64491 L .78296 .6428 L 0 .736 .424 r
F
.7868 .63537 m .78296 .6428 L .78324 .65156 L 0 .774 .434 r
F
.76989 .63578 m .77889 .64402 L .7834 .64493 L 0 .905 .433 r
F
.76989 .63578 m .77311 .6401 L .77889 .64402 L F
.77598 .62385 m .78296 .6428 L .7868 .63537 L 0 .736 .424 r
F
.76989 .63578 m .7834 .64493 L .78429 .64201 L 0 .905 .433 r
F
.76989 .63578 m .78429 .64201 L .78095 .63717 L F
.76989 .63578 m .78095 .63717 L .77514 .63322 L F
.76019 .63465 m .77584 .64878 L .77083 .63406 L 0 .98 .418 r
F
.74852 .65807 m .76263 .62601 L .76345 .63607 L 0 .171 .095 r
F
.76263 .62601 m .76379 .62584 L .76345 .63607 L F
.76387 .62318 m .76391 .62318 L .76345 .63607 L F
.77598 .62385 m .7868 .63537 L .7864 .62631 L 0 .736 .424 r
F
.77049 .62617 m .78172 .63374 L .78612 .63403 L 0 1 .447 r
F
.77049 .62617 m .77504 .63038 L .78172 .63374 L F
.77049 .62617 m .78612 .63403 L .78589 .63075 L F
.77049 .62617 m .78589 .63075 L .78117 .62605 L F
.77049 .62617 m .77445 .62266 L .77023 .62286 L F
.76515 .61138 m .77598 .62385 L .77544 .61447 L 0 .699 .413 r
F
.77598 .62385 m .7864 .62631 L .78202 .62169 L 0 .736 .424 r
F
.77049 .62617 m .78117 .62605 L .77445 .62266 L 0 1 .447 r
F
.77083 .63406 m .77445 .62267 L .77023 .62286 L 0 1 .429 r
F
.77083 .63406 m .78149 .63335 L .77445 .62267 L F
.75858 .65367 m .77023 .62286 L .77445 .62267 L 0 .141 .085 r
F
.75858 .65367 m .76345 .63607 L .77023 .62286 L F
.78136 .66068 m .78869 .65855 L .7841 .65718 L 0 .975 .493 r
F
.77706 .64719 m .7841 .65718 L .78869 .65855 L 0 .929 .47 r
F
.77706 .64719 m .77913 .65232 L .7841 .65718 L F
.7868 .63537 m .78324 .65156 L .78743 .65585 L 0 .774 .434 r
F
.7868 .63537 m .78743 .65585 L .79358 .6535 L F
.77706 .64719 m .78869 .65855 L .79054 .65541 L 0 .929 .47 r
F
.77706 .64719 m .79054 .65541 L .7884 .64982 L F
.77706 .64719 m .7834 .64493 L .77889 .64402 L F
.77706 .64719 m .7884 .64982 L .7834 .64493 L F
.77083 .63406 m .78287 .65943 L .78724 .65893 L 0 1 .429 r
F
.77083 .63406 m .77584 .64878 L .78287 .65943 L F
.77083 .63406 m .78724 .65893 L .78666 .64776 L F
.7868 .63537 m .79358 .6535 L .7976 .64605 L 0 .774 .434 r
F
.78095 .63717 m .79018 .64619 L .79469 .64696 L 0 1 .466 r
F
.78095 .63717 m .78429 .64201 L .79018 .64619 L F
.7868 .63537 m .7976 .64605 L .79734 .63724 L 0 .774 .434 r
F
.78095 .63717 m .79469 .64696 L .79549 .64356 L 0 1 .466 r
F
.78095 .63717 m .79549 .64356 L .79203 .63825 L F
.78095 .63717 m .78612 .63403 L .78172 .63374 L F
.7868 .63537 m .79734 .63724 L .79297 .63297 L 0 .774 .434 r
F
.78095 .63717 m .79203 .63825 L .78612 .63403 L 0 1 .466 r
F
.77083 .63406 m .78666 .64776 L .78149 .63335 L 0 1 .429 r
F
.75858 .65367 m .77317 .62516 L .7738 .63406 L 0 .141 .085 r
F
.77317 .62516 m .77429 .62497 L .7738 .63406 L F
.77441 .62274 m .77444 .62275 L .7738 .63406 L F
.79451 .61908 m .79297 .63297 L .79734 .63724 L 0 .626 .426 r
F
.79451 .61908 m .79175 .6252 L .79297 .63297 L F
.79451 .61908 m .79734 .63724 L .80279 .63578 L F
.78117 .62605 m .79271 .63439 L .79711 .63458 L 0 1 .474 r
F
.78117 .62605 m .78589 .63075 L .79271 .63439 L F
.78117 .62605 m .79711 .63458 L .79676 .63088 L F
.78331 .60767 m .78202 .62169 L .7864 .62631 L 0 .572 .413 r
F
.78331 .60767 m .7864 .62631 L .79175 .6252 L F
.78117 .62605 m .79676 .63088 L .79187 .62573 L 0 1 .474 r
F
.78117 .62605 m .78501 .62205 L .78078 .62232 L F
.78117 .62605 m .79187 .62573 L .78501 .62205 L F
.78149 .63335 m .78501 .62205 L .78078 .62232 L 0 1 .44 r
F
.76867 .64959 m .78078 .62232 L .78501 .62205 L 0 .107 .074 r
F
.76867 .64959 m .7738 .63406 L .78078 .62232 L F
.7976 .64605 m .79371 .66209 L .7979 .66611 L 0 .811 .444 r
F
.7976 .64605 m .79358 .6535 L .79371 .66209 L F
.7976 .64605 m .7979 .66611 L .80418 .66351 L F
.7884 .64982 m .79557 .66047 L .80016 .66167 L 0 1 .49 r
F
.7884 .64982 m .79054 .65541 L .79557 .66047 L F
.7884 .64982 m .80016 .66167 L .80195 .65807 L F
.7884 .64982 m .80195 .65807 L .79975 .65206 L F
.7884 .64982 m .79469 .64696 L .79018 .64619 L F
.7884 .64982 m .79975 .65206 L .79469 .64696 L F
.78149 .63335 m .79381 .65819 L .7982 .65769 L 0 1 .44 r
F
.78149 .63335 m .78666 .64776 L .79381 .65819 L F
.78149 .63335 m .7982 .65769 L .7975 .6467 L F
.78149 .63335 m .79218 .63251 L .78501 .62205 L F
.7976 .64605 m .80827 .64737 L .8039 .64341 L 0 .811 .444 r
F
.7976 .64605 m .80839 .656 L .80827 .64737 L F
.79203 .63825 m .80147 .64801 L .80599 .64864 L 0 1 .488 r
F
.79203 .63825 m .79549 .64356 L .80147 .64801 L F
.80569 .62953 m .8039 .64341 L .80827 .64737 L 0 .68 .438 r
F
.79203 .63825 m .80599 .64864 L .80671 .64482 L 0 1 .488 r
F
.80569 .62953 m .80279 .63578 L .8039 .64341 L 0 .68 .438 r
F
.79203 .63825 m .80671 .64482 L .80312 .63906 L 0 1 .488 r
F
.79203 .63825 m .79711 .63458 L .79271 .63439 L F
.79203 .63825 m .80312 .63906 L .79711 .63458 L F
.78149 .63335 m .7975 .6467 L .79218 .63251 L 0 1 .44 r
F
.76867 .64959 m .78374 .62419 L .78418 .63204 L 0 .107 .074 r
F
.78374 .62419 m .78482 .62399 L .78418 .63204 L F
.78496 .62212 m .785 .62212 L .78418 .63204 L F
.78331 .60767 m .79175 .6252 L .79451 .61908 L 0 .572 .413 r
F
.79187 .62573 m .79559 .62127 L .79135 .6216 L 0 1 .493 r
F
.79451 .61908 m .80279 .63578 L .80569 .62953 L 0 .626 .426 r
F
.79451 .61908 m .80569 .62953 L .80449 .62172 L F
.79187 .62573 m .80258 .62522 L .79559 .62127 L 0 1 .493 r
F
.80569 .62953 m .80827 .64737 L .81382 .64556 L 0 .68 .438 r
F
.79187 .62573 m .80372 .6348 L .80813 .63489 L 0 1 .493 r
F
.79187 .62573 m .79676 .63088 L .80372 .6348 L F
.80569 .62953 m .81382 .64556 L .81686 .63916 L 0 .68 .438 r
F
.80569 .62953 m .81686 .63916 L .81577 .63148 L F
.79187 .62573 m .80813 .63489 L .80765 .6308 L 0 1 .493 r
F
.80569 .62953 m .81577 .63148 L .81126 .62768 L 0 .68 .438 r
F
.79187 .62573 m .80765 .6308 L .80258 .62522 L 0 1 .493 r
F
.79218 .63251 m .79559 .62127 L .79135 .6216 L 0 1 .449 r
F
.77879 .64574 m .79135 .6216 L .79559 .62127 L 0 .067 .061 r
F
.77879 .64574 m .78418 .63204 L .79135 .6216 L F
.79218 .63251 m .80289 .63155 L .79559 .62127 L 0 1 .449 r
F
.77879 .64574 m .79559 .62127 L .79458 .62999 L 0 .067 .061 r
F
.77809 .62975 m .7931 .62247 L .79428 .62363 L 0 0 0 r
F
.7931 .62247 m .79559 .62127 L .79513 .6221 L F
.7931 .62247 m .79513 .6221 L .79428 .62363 L F
.78374 .62419 m .78496 .62212 L .78482 .62399 L 0 .107 .074 r
F
.78496 .62212 m .78501 .62205 L .785 .62212 L F
.7931 .62247 m .79135 .6216 L .79559 .62127 L 0 0 0 r
F
.77809 .62975 m .79014 .62234 L .7931 .62247 L F
.79014 .62234 m .79135 .6216 L .7931 .62247 L F
.76794 .63238 m .78246 .62359 L .78387 .62522 L F
.78246 .62359 m .785 .62205 L .78458 .62323 L F
.78246 .62359 m .78458 .62323 L .78387 .62522 L F
.77317 .62516 m .77441 .62274 L .77429 .62497 L 0 .141 .085 r
F
.77441 .62274 m .77445 .62267 L .77444 .62275 L F
.78246 .62359 m .78078 .62232 L .785 .62205 L 0 0 0 r
F
.76794 .63238 m .77955 .62328 L .78246 .62359 L F
.77955 .62328 m .78078 .62232 L .78246 .62359 L F
.75782 .63505 m .77184 .62461 L .77348 .62673 L 0 0 .004 r
F
.77184 .62461 m .77445 .62266 L .77407 .62427 L F
.77184 .62461 m .77407 .62427 L .77348 .62673 L F
.76263 .62601 m .76387 .62318 L .76379 .62584 L 0 .171 .095 r
F
.76387 .62318 m .76391 .62309 L .76391 .62318 L F
.77184 .62461 m .77023 .62286 L .77445 .62266 L 0 0 .004 r
F
.75782 .63505 m .76897 .62409 L .77184 .62461 L F
.76897 .62409 m .77023 .62286 L .77184 .62461 L F
.74773 .63781 m .76123 .62553 L .76312 .62815 L 0 0 .029 r
F
.76123 .62553 m .76391 .62309 L .76358 .62521 L F
.76123 .62553 m .76358 .62521 L .76312 .62815 L F
.75211 .62676 m .75336 .62342 L .75331 .6266 L 0 .197 .104 r
F
.75336 .62342 m .7534 .62333 L .7534 .62342 L F
.76123 .62553 m .7597 .62321 L .76391 .62309 L 0 0 .029 r
F
.74773 .63781 m .75842 .62477 L .76123 .62553 L F
.75842 .62477 m .7597 .62321 L .76123 .62553 L F
.73767 .64071 m .75064 .62638 L .75279 .62949 L 0 .052 .051 r
F
.75064 .62638 m .7534 .62333 L .75312 .62609 L F
.75064 .62638 m .75312 .62609 L .75279 .62949 L F
.74161 .62741 m .74288 .62346 L .74287 .62727 L 0 .22 .113 r
F
.74288 .62346 m .74291 .62337 L .74291 .62347 L F
.75064 .62638 m .7492 .62336 L .7534 .62333 L 0 .052 .051 r
F
.73767 .64071 m .74789 .62534 L .75064 .62638 L F
.74789 .62534 m .7492 .62336 L .75064 .62638 L F
.72765 .64386 m .74006 .62719 L .74248 .63079 L 0 .105 .069 r
F
.74006 .62719 m .74291 .62336 L .7427 .62694 L F
.74006 .62719 m .7427 .62694 L .74248 .63079 L F
.73115 .62801 m .73242 .6233 L .73246 .62789 L 0 .238 .128 r
F
.73242 .6233 m .73245 .62322 L .73245 .62331 L F
.74006 .62719 m .73872 .62333 L .74291 .62336 L 0 .105 .069 r
F
.72765 .64386 m .73738 .62582 L .74006 .62719 L F
.73738 .62582 m .73872 .62333 L .74006 .62719 L F
.71766 .64738 m .7295 .62803 L .7322 .63207 L 0 .148 .084 r
F
.7295 .62803 m .73245 .62322 L .73232 .62783 L F
.7295 .62803 m .73232 .62783 L .7322 .63207 L F
.72073 .62863 m .722 .62297 L .72209 .62854 L 0 .254 .142 r
F
.722 .62297 m .72201 .62291 L .72201 .62297 L F
.7295 .62803 m .72827 .62311 L .73245 .62322 L 0 .148 .084 r
F
.71766 .64738 m .72689 .62626 L .7295 .62803 L F
.72689 .62626 m .72827 .62311 L .7295 .62803 L F
.69557 .65797 m .70111 .66689 L .69636 .67069 L 0 .216 .109 r
F
.70511 .68074 m .71736 .65639 L .72127 .65432 L 0 0 .052 r
F
.70511 .68074 m .71045 .66767 L .71736 .65639 L F
.70511 .68074 m .72127 .65432 L .72001 .66112 L F
.70511 .68074 m .72001 .66112 L .71438 .67233 L F
.70511 .68074 m .71438 .67233 L .7074 .68375 L F
.70594 .68765 m .70512 .68811 L .71284 .67823 L 0 0 0 r
F
.70455 .68894 m .70478 .68938 L .70474 .68872 L 0 .316 .303 r
F
.70478 .68938 m .70518 .69014 L .70491 .68925 L F
.70478 .68938 m .70491 .68925 L .70474 .68872 L F
.70707 .68683 m .7078 .6863 L .70897 .68475 L 0 .384 .321 r
F
.70818 .68577 m .70879 .68495 L .70911 .68461 L 0 0 0 r
F
.70896 .68547 m .71768 .71064 L .70917 .68532 L 0 .384 .321 r
F
.70707 .68683 m .70733 .68743 L .70896 .68547 L F
.70733 .68743 m .71768 .71064 L .70896 .68547 L F
.70452 .68897 m .70452 .68898 L .70455 .68894 L 0 .316 .303 r
F
.70452 .68898 m .70816 .7076 L .70455 .68894 L F
.70246 .69141 m .70264 .69114 L .70455 .68894 L 0 0 0 r
F
.70192 .69205 m .70378 .68768 L .7074 .68375 L F
.7002 .6935 m .70435 .70586 L .70192 .69205 L 0 .316 .303 r
F
.68845 .65855 m .69589 .6848 L .69959 .69401 L F
.7002 .6935 m .69959 .69401 L .70435 .70586 L F
.7002 .6935 m .69959 .69401 L .70378 .68768 L 0 0 0 r
F
.68845 .65855 m .69959 .69401 L .7002 .6935 L 0 .316 .303 r
F
.68994 .71016 m .69632 .69896 L .69959 .69401 L 0 0 0 r
F
.68994 .71016 m .69959 .69401 L .7002 .6935 L F
.68994 .71016 m .7002 .6935 L .70192 .69205 L F
.7002 .6935 m .70378 .68768 L .70192 .69205 L F
.70192 .69205 m .70435 .70586 L .70816 .7076 L 0 .316 .303 r
F
.68845 .65855 m .7002 .6935 L .70192 .69205 L F
.70146 .69093 m .70192 .69205 L .70449 .68883 L F
.70192 .69205 m .70816 .7076 L .70452 .68897 L F
.70246 .69141 m .70202 .6919 L .70264 .69114 L 0 0 0 r
F
.70192 .69205 m .70202 .6919 L .70246 .69141 L F
.70192 .69205 m .70452 .68897 L .70449 .68883 L 0 .316 .303 r
F
.68994 .71016 m .70192 .69205 L .70246 .69141 L 0 0 0 r
F
.68994 .71016 m .70455 .68894 L .69841 .6979 L F
.70455 .68894 m .70512 .68811 L .70474 .68866 L F
.70455 .68894 m .70474 .68872 L .70473 .68868 L 0 .316 .303 r
F
.70455 .68894 m .70474 .68866 L .70473 .68868 L 0 0 0 r
F
.70511 .68074 m .7074 .68375 L .70378 .68768 L 0 0 .052 r
F
.70455 .68894 m .70473 .68868 L .69742 .6652 L 0 .316 .303 r
F
.70455 .68894 m .70473 .68868 L .69841 .6979 L 0 0 0 r
F
.68994 .71016 m .70246 .69141 L .70455 .68894 L F
.70455 .68894 m .70816 .7076 L .70518 .69014 L 0 .316 .303 r
F
.70449 .68883 m .70452 .68897 L .70455 .68894 L F
.68845 .65855 m .70146 .69093 L .70449 .68883 L F
.70707 .68683 m .71388 .70964 L .71768 .71064 L 0 .384 .321 r
F
.69742 .6652 m .7058 .68783 L .70707 .68683 L F
.70591 .68813 m .71388 .70964 L .70707 .68683 L F
.70654 .68751 m .70707 .68683 L .70818 .68577 L 0 0 0 r
F
.70783 .68599 m .71648 .67479 L .70901 .68467 L F
.70722 .68664 m .71648 .67479 L .70783 .68599 L F
.70879 .68495 m .70881 .68493 L .70911 .68461 L F
.709 .68467 m .71648 .67479 L .7093 .68435 L F
.70911 .68461 m .71648 .67479 L .71397 .67856 L F
.70911 .68461 m .70941 .68423 L .71084 .68236 L F
.70941 .68423 m .71397 .67856 L .71098 .68219 L F
.70941 .68423 m .71098 .68219 L .71084 .68236 L F
.71859 .67469 m .73258 .64248 L .72852 .66836 L 0 .238 .128 r
F
.71438 .67233 m .72716 .6514 L .73109 .64958 L 0 0 .033 r
F
.71438 .67233 m .72001 .66112 L .72716 .6514 L F
.71438 .67233 m .73109 .64958 L .72963 .65536 L F
.71438 .67233 m .72963 .65536 L .72369 .66496 L F
.71438 .67233 m .71648 .67479 L .71284 .67823 L F
.71438 .67233 m .72369 .66496 L .71648 .67479 L F
.70638 .66971 m .71303 .67951 L .71534 .67254 L 0 .454 .337 r
F
.71662 .67658 m .72195 .6699 L .72561 .66682 L 0 0 0 r
F
.71494 .67815 m .72195 .6699 L .71662 .67658 L F
.71156 .6818 m .72195 .6699 L .71223 .68134 L F
.7181 .67512 m .72561 .66682 L .72287 .67001 L F
.71223 .68134 m .71662 .67658 L .71344 .68012 L F
.71223 .68134 m .71494 .67815 L .71662 .67658 L F
.71334 .67997 m .71344 .68012 L .7155 .67763 L 0 .454 .337 r
F
.71334 .67997 m .7155 .67763 L .71568 .67741 L F
.70881 .68493 m .709 .68467 L .70911 .68461 L 0 0 0 r
F
.709 .68467 m .7093 .68435 L .70911 .68461 L F
.71859 .67469 m .72252 .69077 L .71864 .69447 L 0 .238 .128 r
F
.71363 .6804 m .7272 .71213 L .72374 .69532 L 0 .454 .337 r
F
.71145 .68193 m .71397 .67856 L .72195 .6699 L 0 0 0 r
F
.71139 .68197 m .71397 .67856 L .71145 .68193 L F
.71073 .68249 m .71397 .67856 L .71133 .68204 L F
.71143 .68217 m .71446 .69349 L .72339 .7117 L 0 .454 .337 r
F
.71141 .68219 m .71446 .69349 L .71143 .68217 L F
.71073 .68249 m .71446 .69349 L .71137 .68202 L F
.71214 .68144 m .72339 .7117 L .7272 .71213 L F
.71137 .68202 m .72339 .7117 L .71214 .68144 L F
.71214 .68144 m .7272 .71213 L .71363 .6804 L F
.70943 .68513 m .71121 .68392 L .71082 .68277 L 0 .384 .321 r
F
.7058 .68783 m .70495 .68836 L .70594 .68765 L 0 0 0 r
F
.70541 .68814 m .70495 .68836 L .7058 .68783 L F
.7058 .68783 m .70518 .69014 L .71388 .70964 L 0 .384 .321 r
F
.70473 .68868 m .70474 .68866 L .70484 .68859 L 0 0 0 r
F
.70474 .68866 m .70495 .68836 L .70566 .68802 L F
.70495 .68836 m .70512 .68811 L .70594 .68765 L F
.69742 .6652 m .70473 .68868 L .7058 .68783 L 0 .384 .321 r
F
.70473 .68868 m .70518 .69014 L .7058 .68783 L F
.69841 .6979 m .70473 .68868 L .70566 .68802 L 0 0 0 r
F
.70473 .68868 m .70484 .68859 L .70566 .68802 L F
.69841 .6979 m .70911 .68461 L .70694 .68709 L F
.70869 .68391 m .70917 .68532 L .70943 .68513 L 0 .384 .321 r
F
.70694 .68709 m .71214 .68144 L .71344 .68012 L 0 0 0 r
F
.71214 .68144 m .71223 .68134 L .71261 .68095 L F
.71214 .68144 m .71261 .68095 L .71344 .68012 L F
.71137 .68202 m .71141 .68219 L .71143 .68217 L 0 .454 .337 r
F
.71133 .68204 m .71139 .68197 L .71137 .68202 L 0 0 0 r
F
.70638 .66971 m .71073 .68249 L .71137 .68202 L 0 .454 .337 r
F
.71137 .68202 m .71139 .68197 L .71145 .68193 L 0 0 0 r
F
.71125 .68215 m .71133 .68204 L .71137 .68202 L F
.71073 .68249 m .71133 .68204 L .71125 .68215 L F
.70638 .66971 m .71137 .68202 L .71214 .68144 L 0 .454 .337 r
F
.70638 .66971 m .71214 .68144 L .71363 .6804 L F
.70929 .68442 m .71082 .68277 L .71073 .68249 L 0 .384 .321 r
F
.70929 .68442 m .71073 .68249 L .70912 .68355 L F
.69742 .6652 m .70911 .68461 L .70638 .66971 L F
.70911 .68461 m .70929 .68442 L .70928 .68438 L F
.70911 .68461 m .70928 .68438 L .70638 .66971 L F
.70911 .68461 m .71084 .68236 L .71073 .68249 L 0 0 0 r
F
.70707 .68683 m .70901 .68467 L .70818 .68577 L F
.70707 .68683 m .70722 .68664 L .70783 .68599 L F
.70707 .68683 m .70718 .68667 L .70722 .68664 L F
.70707 .68683 m .70897 .68475 L .70869 .68391 L 0 .384 .321 r
F
.70911 .68461 m .71073 .68249 L .70694 .68709 L 0 0 0 r
F
.70694 .68709 m .71073 .68249 L .71125 .68215 L F
.70912 .68355 m .71073 .68249 L .70638 .66971 L 0 .384 .321 r
F
.71334 .67997 m .71672 .67627 L .7135 .67939 L 0 .454 .337 r
F
.7133 .68027 m .71618 .6768 L .7155 .67738 L 0 0 0 r
F
.71618 .6768 m .71671 .67617 L .71669 .67619 L F
.7135 .67939 m .71672 .67627 L .71669 .67619 L 0 .454 .337 r
F
.71386 .67806 m .71669 .67619 L .71534 .67254 L F
.7135 .67939 m .71669 .67619 L .71386 .67806 L F
.71662 .67658 m .72561 .66682 L .7181 .67512 L 0 0 0 r
F
.71344 .68012 m .71662 .67658 L .7181 .67512 L F
.71344 .68012 m .72287 .67001 L .71622 .67677 L F
.71532 .67785 m .71622 .67677 L .71618 .6768 L F
.71344 .68012 m .71622 .67677 L .71532 .67785 L F
.71534 .67254 m .71921 .67318 L .71516 .65698 L 0 .52 .351 r
F
.72852 .66836 m .74284 .64022 L .7385 .66291 L 0 .22 .113 r
F
.72507 .66856 m .73111 .66241 L .73478 .65961 L 0 0 0 r
F
.71859 .67469 m .72852 .66836 L .72252 .69077 L 0 .238 .128 r
F
.72852 .66836 m .73228 .68248 L .72837 .68564 L 0 .22 .113 r
F
.72077 .67344 m .73302 .69594 L .72431 .67403 L 0 .52 .351 r
F
.71716 .67585 m .72255 .67065 L .72507 .66856 L 0 0 0 r
F
.71714 .67586 m .72255 .67065 L .71716 .67585 L F
.71625 .67673 m .72287 .67001 L .71677 .67611 L F
.71691 .67603 m .73111 .66241 L .71712 .67588 L F
.71756 .67547 m .72034 .6729 L .72084 .67241 L F
.71752 .6755 m .71752 .6755 L .71756 .67547 L F
.71756 .67547 m .71713 .67588 L .71762 .67555 L 0 .52 .351 r
F
.71625 .67673 m .71677 .67611 L .71673 .67615 L 0 0 0 r
F
.71631 .67665 m .71673 .67615 L .71671 .67617 L F
.71689 .67605 m .72287 .67001 L .73111 .66241 L F
.71618 .6768 m .71669 .67619 L .7155 .67738 L F
.71669 .67619 m .72287 .67001 L .71689 .67605 L F
.71618 .6768 m .71625 .67673 L .71673 .67615 L F
.71618 .6768 m .71673 .67615 L .71631 .67665 L F
.72255 .67065 m .73111 .66241 L .72507 .66856 L F
.72141 .67131 m .73181 .66221 L .72412 .66853 L F
.71534 .67254 m .71669 .67619 L .71689 .67605 L 0 .52 .351 r
F
.71669 .67619 m .72374 .69532 L .71689 .67605 L F
.71689 .67605 m .73291 .71243 L .71713 .67588 L F
.71686 .67608 m .71689 .67605 L .71705 .67596 L 0 0 0 r
F
.71689 .67605 m .71691 .67603 L .71695 .67601 L F
.71689 .67605 m .71695 .67601 L .71705 .67596 L F
.7155 .67738 m .71669 .67619 L .71689 .67605 L F
.71534 .67254 m .71689 .67605 L .71713 .67588 L 0 .52 .351 r
F
.71744 .67531 m .71713 .67588 L .71756 .67547 L F
.71954 .67323 m .71764 .67539 L .72141 .67131 L 0 0 0 r
F
.71764 .67539 m .73181 .66221 L .72141 .67131 L F
.71954 .67323 m .71788 .67516 L .71982 .67328 L 0 .52 .351 r
F
.71921 .67318 m .71813 .67478 L .71954 .67323 L F
.71534 .67254 m .71744 .67531 L .71921 .67318 L F
.71744 .67531 m .71756 .67547 L .71921 .67318 L F
.71756 .67547 m .71762 .67555 L .71788 .67516 L F
.71756 .67547 m .71788 .67516 L .71921 .67318 L F
.71705 .67596 m .71714 .67586 L .71716 .67585 L 0 0 0 r
F
.71705 .67596 m .71716 .67585 L .7174 .67561 L F
.72163 .67168 m .73175 .6624 L .73181 .66221 L F
.72084 .67241 m .72132 .67198 L .72163 .67168 L F
.72132 .67198 m .73175 .6624 L .72163 .67168 L F
.73306 .65835 m .73478 .65961 L .73111 .66241 L F
.72412 .66853 m .72983 .6639 L .73277 .66036 L F
.73175 .6624 m .73478 .65961 L .73404 .66026 L F
.73175 .6624 m .73404 .66026 L .73181 .66221 L F
.73306 .65835 m .74246 .6523 L .73478 .65961 L F
.72983 .6639 m .74079 .655 L .73541 .65859 L F
.72983 .6639 m .73541 .65859 L .73277 .66036 L F
.72507 .66856 m .73175 .6624 L .72519 .66844 L F
.72034 .6729 m .73175 .6624 L .72084 .67241 L F
.72412 .66853 m .74031 .65556 L .74399 .65296 L F
.72412 .66853 m .73181 .66221 L .74031 .65556 L F
.7385 .66291 m .75313 .63811 L .74852 .65807 L 0 .197 .104 r
F
.74246 .6523 m .74399 .65296 L .74031 .65556 L 0 0 0 r
F
.74246 .6523 m .7519 .64668 L .74399 .65296 L F
.7519 .64668 m .75324 .64676 L .74954 .64919 L F
.73883 .65605 m .75324 .64676 L .7498 .64826 L F
.73277 .66036 m .7379 .65695 L .73883 .65605 L F
.73532 .65944 m .74124 .65512 L .74079 .655 L F
.73277 .66036 m .74954 .64919 L .75324 .64676 L F
.74124 .65512 m .74331 .6534 L .74079 .655 L F
.73277 .66036 m .74079 .655 L .74954 .64919 L F
.7379 .65695 m .75324 .64676 L .73883 .65605 L F
.72983 .6639 m .73413 .66058 L .73532 .65944 L F
.73413 .66058 m .74124 .65512 L .73532 .65944 L F
.72412 .66853 m .72901 .6647 L .72983 .6639 L F
.72901 .6647 m .74124 .65512 L .72983 .6639 L F
.71716 .67585 m .72507 .66856 L .71752 .6755 L F
.72507 .66856 m .72519 .66844 L .71752 .6755 L F
.71716 .67585 m .71752 .6755 L .7174 .67561 L F
.71534 .67254 m .71707 .67575 L .71744 .67531 L 0 .52 .351 r
F
.7155 .67738 m .71954 .67323 L .7158 .67619 L 0 0 0 r
F
.71921 .67318 m .71954 .67323 L .72203 .66979 L 0 .52 .351 r
F
.71954 .67323 m .72412 .66853 L .72227 .67023 L 0 0 0 r
F
.71752 .6755 m .72034 .6729 L .71756 .67547 L F
.71954 .67323 m .72431 .67403 L .72227 .67023 L 0 .52 .351 r
F
.71954 .67323 m .72227 .67023 L .72203 .66979 L F
.71954 .67323 m .72227 .67023 L .72224 .67026 L 0 0 0 r
F
.72369 .66496 m .72561 .66682 L .72195 .6699 L 0 0 .011 r
F
.71921 .67318 m .72203 .66979 L .71516 .65698 L 0 .52 .351 r
F
.71954 .67323 m .72224 .67026 L .7158 .67619 L 0 0 0 r
F
.71813 .67478 m .71802 .67494 L .71954 .67323 L 0 .52 .351 r
F
.71756 .67547 m .71764 .67539 L .71954 .67323 L 0 0 0 r
F
.71802 .67494 m .71788 .67516 L .71954 .67323 L 0 .52 .351 r
F
.71707 .67575 m .71713 .67588 L .71744 .67531 L F
.71691 .67603 m .71712 .67588 L .71705 .67596 L 0 0 0 r
F
.7155 .67738 m .71686 .67608 L .71705 .67596 L F
.7155 .67738 m .71756 .67547 L .71954 .67323 L F
.71694 .67615 m .72374 .69532 L .73291 .71243 L 0 .52 .351 r
F
.71689 .67605 m .71693 .67616 L .71694 .67615 L F
.71693 .67616 m .72374 .69532 L .71694 .67615 L F
.73798 .71479 m .7401 .73448 L .7456 .73022 L 0 1 .455 r
F
.73798 .71479 m .7456 .73022 L .74876 .72177 L F
.73798 .71479 m .74786 .71331 L .74349 .7105 L F
.73798 .71479 m .74876 .72177 L .74786 .71331 L F
.73512 .72302 m .74119 .70832 L .73676 .70998 L 0 1 .378 r
F
.75711 .70861 m .74722 .7273 L .75064 .73123 L 0 1 .439 r
F
.75711 .70861 m .74999 .71761 L .74722 .7273 L F
.74876 .72177 m .74638 .73849 L .75057 .74108 L 0 1 .464 r
F
.74876 .72177 m .7456 .73022 L .74638 .73849 L F
.7457 .74442 m .74497 .74963 L .74943 .75422 L 0 .29 .268 r
F
.7457 .74442 m .74337 .74544 L .74497 .74963 L F
.75046 .74943 m .75622 .76412 L .76076 .7556 L 0 1 .47 r
F
.7457 .74442 m .74943 .75422 L .75462 .75681 L 0 .29 .268 r
F
.75046 .74943 m .76076 .7556 L .76103 .74735 L 0 1 .47 r
F
.75046 .74943 m .76103 .74735 L .75685 .74488 L F
.7457 .74442 m .75462 .75681 L .7571 .75567 L 0 .29 .268 r
F
.7457 .74442 m .75551 .75146 L .7509 .747 L F
.7457 .74442 m .7571 .75567 L .75551 .75146 L F
.73826 .73308 m .73938 .7347 L .74399 .73981 L 0 0 .14 r
F
.73826 .73308 m .74399 .73981 L .74852 .74445 L F
.73826 .73308 m .74852 .74445 L .74995 .74551 L F
.73826 .73308 m .7475 .74262 L .74279 .73772 L F
.73826 .73308 m .74995 .74551 L .7475 .74262 L F
.74011 .74128 m .74279 .73772 L .7475 .74262 L 0 .262 0 r
F
.74011 .74128 m .73963 .73713 L .74279 .73772 L F
.74011 .74128 m .7475 .74262 L .75142 .74902 L F
.74011 .74128 m .75142 .74902 L .75193 .75266 L F
.73512 .72302 m .74689 .74693 L .74854 .7339 L 0 1 .378 r
F
.73826 .73308 m .73692 .73181 L .73938 .7347 L 0 0 .14 r
F
.74011 .74128 m .74876 .7521 L .74402 .7477 L 0 .262 0 r
F
.74011 .74128 m .75193 .75266 L .74876 .7521 L F
.73979 .75762 m .74402 .7477 L .74876 .7521 L 0 .332 .054 r
F
.73979 .75762 m .74018 .75005 L .74402 .7477 L F
.73512 .72302 m .7424 .749 L .74689 .74693 L 0 1 .378 r
F
.73512 .72302 m .74854 .7339 L .74623 .71857 L F
.73512 .72302 m .73735 .73875 L .7424 .749 L F
.73512 .72302 m .74623 .71857 L .74119 .70832 L F
.73571 .7316 m .73666 .71335 L .73345 .71614 L 0 .656 .343 r
F
.73482 .70707 m .74415 .69711 L .73745 .71212 L 0 0 .072 r
F
.74952 .67594 m .75452 .66294 L .75017 .66356 L 0 1 .394 r
F
.73482 .70707 m .74798 .67134 L .75192 .66887 L 0 0 .072 r
F
.73482 .70707 m .74068 .68763 L .74798 .67134 L F
.76347 .67588 m .75597 .69454 L .75968 .69871 L 0 .978 .432 r
F
.76347 .67588 m .75968 .69871 L .76705 .69525 L F
.75495 .70131 m .76445 .69976 L .75995 .69718 L 0 1 .469 r
F
.75711 .70861 m .76894 .70881 L .76524 .70483 L 0 1 .439 r
F
.77319 .68644 m .76524 .70483 L .76894 .70881 L 0 .998 .439 r
F
.77319 .68644 m .76705 .69525 L .76524 .70483 L F
.75495 .70131 m .76608 .70779 L .76445 .69976 L 0 1 .469 r
F
.74952 .67594 m .753 .69183 L .75895 .70291 L 0 1 .394 r
F
.75864 .68233 m .75995 .69718 L .76445 .69976 L 0 .981 .476 r
F
.75864 .68233 m .75746 .68972 L .75995 .69718 L F
.74952 .67594 m .75895 .70291 L .7634 .7018 L 0 1 .394 r
F
.74952 .67594 m .76047 .67403 L .75452 .66294 L F
.76347 .67588 m .76705 .69525 L .77319 .68644 L 0 .978 .432 r
F
.75864 .68233 m .76445 .69976 L .76876 .69609 L 0 .981 .476 r
F
.75864 .68233 m .76876 .69609 L .77002 .68859 L F
.75864 .68233 m .76753 .68109 L .76295 .67862 L F
.75864 .68233 m .77002 .68859 L .76753 .68109 L F
.74952 .67594 m .76406 .68943 L .76047 .67403 L 0 1 .394 r
F
.74952 .67594 m .7634 .7018 L .76406 .68943 L F
.73482 .70707 m .75192 .66887 L .75031 .67984 L 0 0 .072 r
F
.73482 .70707 m .75031 .67984 L .74415 .69711 L F
.74415 .69711 m .7459 .70289 L .74223 .70707 L 0 0 .06 r
F
.74353 .70713 m .74223 .70707 L .7459 .70289 L 0 0 0 r
F
.73571 .7316 m .74542 .73067 L .73799 .71509 L 0 .656 .343 r
F
.73571 .7316 m .73799 .71509 L .73754 .71562 L F
.73571 .7316 m .73768 .71445 L .73685 .71551 L F
.7448 .70772 m .74623 .71178 L .74519 .70749 L 0 .583 .365 r
F
.74412 .70813 m .74423 .70833 L .7448 .70772 L F
.74423 .70833 m .74623 .71178 L .7448 .70772 L F
.77319 .68644 m .76894 .70881 L .7765 .70525 L 0 .998 .439 r
F
.77002 .68859 m .77118 .70347 L .77567 .70583 L 0 1 .484 r
F
.77002 .68859 m .76876 .69609 L .77118 .70347 L F
.77319 .68644 m .7765 .70525 L .7829 .69648 L 0 .998 .439 r
F
.77002 .68859 m .77567 .70583 L .78004 .70188 L 0 1 .484 r
F
.76347 .67588 m .77483 .67663 L .77087 .67239 L 0 .978 .432 r
F
.76347 .67588 m .77319 .68644 L .77483 .67663 L F
.7598 .66555 m .76295 .67862 L .76753 .68109 L 0 .898 .479 r
F
.7598 .66555 m .75964 .67197 L .76295 .67862 L F
.76047 .67403 m .77009 .70027 L .77456 .69932 L 0 1 .407 r
F
.76047 .67403 m .76406 .68943 L .77009 .70027 L F
.75904 .69213 m .76431 .68413 L .75963 .69149 L 0 0 0 r
F
.75711 .70861 m .76614 .71853 L .76894 .70881 L 0 1 .439 r
F
.75495 .70131 m .76377 .71589 L .76608 .70779 L 0 1 .469 r
F
.75711 .70861 m .75064 .73123 L .75874 .72748 L 0 1 .439 r
F
.75711 .70861 m .75874 .72748 L .76614 .71853 L F
.75495 .70131 m .75441 .71738 L .75877 .71999 L 0 1 .469 r
F
.75495 .70131 m .75877 .71999 L .76377 .71589 L F
.75738 .71497 m .7634 .7018 L .75895 .70291 L 0 1 .402 r
F
.76608 .70779 m .76531 .72377 L .76967 .72621 L 0 1 .477 r
F
.76608 .70779 m .76377 .71589 L .76531 .72377 L F
.76608 .70779 m .76967 .72621 L .77476 .72192 L F
.76608 .70779 m .77476 .72192 L .7772 .71375 L F
.76608 .70779 m .77567 .70583 L .77118 .70347 L F
.76608 .70779 m .7772 .71375 L .77567 .70583 L F
.75738 .71497 m .76857 .71199 L .7634 .7018 L 0 1 .402 r
F
.75635 .69504 m .75655 .69534 L .75963 .69149 L 0 .697 .388 r
F
.75655 .69534 m .76531 .7084 L .75963 .69149 L F
.74623 .71857 m .75228 .70474 L .74784 .70608 L 0 1 .39 r
F
.74353 .70713 m .74242 .71214 L .74623 .71178 L 0 .583 .365 r
F
.74108 .70931 m .74135 .70987 L .74353 .70713 L F
.74135 .70987 m .74242 .71214 L .74353 .70713 L F
.73571 .7316 m .73703 .71308 L .737 .71309 L 0 .656 .343 r
F
.73571 .7316 m .73701 .71304 L .73666 .71335 L F
.75022 .75963 m .74748 .76735 L .75175 .77154 L 0 .53 .41 r
F
.75022 .75963 m .74682 .76225 L .74748 .76735 L F
.76076 .7556 m .75581 .77229 L .75977 .77467 L 0 1 .477 r
F
.76076 .7556 m .75622 .76412 L .75581 .77229 L F
.75022 .75963 m .75175 .77154 L .75763 .77267 L 0 .53 .41 r
F
.76076 .7556 m .75977 .77467 L .76629 .77006 L 0 1 .477 r
F
.75022 .75963 m .75763 .77267 L .76121 .76997 L 0 .53 .41 r
F
.75022 .75963 m .76057 .76485 L .75612 .76074 L F
.75022 .75963 m .76121 .76997 L .76057 .76485 L F
.73979 .75762 m .74876 .7521 L .75201 .76035 L 0 .332 .054 r
F
.73979 .75762 m .75201 .76035 L .75182 .76339 L F
.73992 .76112 m .75238 .76978 L .75184 .76363 L 0 1 .391 r
F
.74869 .77678 m .75977 .77467 L .75581 .77229 L 0 1 .477 r
F
.75841 .78278 m .76966 .78051 L .76571 .7782 L 0 1 .482 r
F
.75155 .7775 m .7624 .7814 L .75814 .77756 L 0 .781 .456 r
F
.75309 .76388 m .75238 .76978 L .75668 .77886 L 0 1 .402 r
F
.73992 .76112 m .75184 .76363 L .7502 .76308 L 0 1 .391 r
F
.7571 .75567 m .75462 .75681 L .75612 .76074 L 0 .333 .285 r
F
.75311 .76384 m .75201 .76035 L .75586 .75811 L 0 .278 .038 r
F
.7571 .75567 m .75612 .76074 L .76057 .76485 L 0 .333 .285 r
F
.76076 .7556 m .76629 .77006 L .77104 .7615 L 0 1 .477 r
F
.7571 .75567 m .76057 .76485 L .76586 .76694 L 0 .333 .285 r
F
.75539 .76477 m .75586 .75811 L .76059 .76172 L 0 .278 .038 r
F
.75309 .76388 m .75586 .75811 L .75539 .76477 L F
.76121 .76997 m .75814 .77756 L .7624 .7814 L 0 .589 .423 r
F
.76121 .76997 m .75763 .77267 L .75814 .77756 L F
.75841 .78278 m .76811 .7886 L .76966 .78051 L 0 1 .482 r
F
.77104 .7615 m .76571 .7782 L .76966 .78051 L F
.77104 .7615 m .76629 .77006 L .76571 .7782 L F
.76121 .76997 m .7624 .7814 L .76841 .78216 L 0 .589 .423 r
F
.77104 .7615 m .76966 .78051 L .77634 .77579 L 0 1 .482 r
F
.76121 .76997 m .76841 .78216 L .77218 .77932 L 0 .589 .423 r
F
.76121 .76997 m .77168 .77441 L .76724 .77071 L F
.76121 .76997 m .77218 .77932 L .77168 .77441 L F
.75539 .76477 m .7612 .77704 L .76313 .76791 L 0 1 .402 r
F
.76017 .7664 m .76059 .76172 L .76322 .76741 L 0 .278 .038 r
F
.75539 .76477 m .76313 .76791 L .76323 .76744 L 0 1 .402 r
F
.75309 .76388 m .75308 .76383 L .75311 .76384 L 0 .278 .038 r
F
.75117 .75585 m .75668 .77886 L .7612 .77704 L 0 1 .402 r
F
.75535 .76479 m .75539 .76477 L .76017 .7664 L 0 .278 .038 r
F
.75539 .76477 m .76059 .76172 L .76017 .7664 L F
.75539 .76477 m .76323 .76744 L .76368 .76534 L 0 1 .402 r
F
.75117 .75585 m .75539 .76477 L .76368 .76534 L F
.75308 .76383 m .75201 .76035 L .75311 .76384 L 0 .278 .038 r
F
.75182 .76339 m .75238 .76978 L .75309 .76388 L 0 1 .402 r
F
.7516 .76699 m .75182 .76339 L .75309 .76388 L 0 .278 .038 r
F
.75182 .76339 m .75201 .76035 L .75309 .76388 L F
.75182 .76339 m .75309 .76388 L .75309 .76386 L 0 1 .402 r
F
.75309 .76386 m .75309 .76388 L .75309 .76388 L F
.75309 .76388 m .75238 .76978 L .75309 .76388 L F
.7516 .76699 m .75309 .76388 L .75539 .76477 L 0 .278 .038 r
F
.7516 .76699 m .75535 .76479 L .76381 .76869 L F
.75535 .76479 m .76322 .76741 L .76381 .76869 L F
.7502 .76308 m .75184 .76363 L .75182 .76339 L 0 1 .391 r
F
.73979 .75762 m .75182 .76339 L .75139 .76322 L 0 .332 .054 r
F
.73992 .76112 m .75182 .76339 L .74261 .75986 L 0 1 .391 r
F
.73979 .75762 m .75182 .76343 L .74261 .75986 L 0 .332 .054 r
F
.74261 .75986 m .75182 .76339 L .75117 .75585 L 0 1 .391 r
F
.75139 .76322 m .75182 .76339 L .75143 .76324 L 0 .332 .054 r
F
.75143 .76324 m .75182 .76339 L .75182 .76343 L F
.75117 .75585 m .75182 .76339 L .75309 .76386 L 0 1 .402 r
F
.73992 .76112 m .74261 .75986 L .74086 .7592 L 0 1 .391 r
F
.74104 .767 m .75175 .77154 L .74748 .76735 L 0 .737 .446 r
F
.74104 .767 m .74702 .78123 L .75155 .7775 L F
.74104 .767 m .75155 .7775 L .75175 .77154 L F
.73992 .76112 m .7499 .78188 L .75238 .76978 L 0 1 .391 r
F
.74086 .7592 m .7516 .76699 L .74775 .7694 L 0 .332 .054 r
F
.73979 .75762 m .74261 .75986 L .74086 .7592 L F
.74261 .75986 m .7516 .76699 L .74086 .7592 L F
.74086 .7592 m .74261 .75986 L .74087 .75918 L 0 1 .391 r
F
.74087 .75918 m .75117 .75585 L .74689 .74693 L F
.74261 .75986 m .75117 .75585 L .74087 .75918 L F
.74261 .75986 m .75182 .76343 L .7516 .76699 L 0 .332 .054 r
F
.73979 .75762 m .74086 .7592 L .74035 .75904 L F
.74035 .75904 m .74689 .74693 L .7424 .749 L 0 1 .391 r
F
.73992 .76112 m .74086 .7592 L .74035 .75904 L F
.74086 .7592 m .74689 .74693 L .74035 .75904 L F
.74035 .75904 m .74775 .7694 L .74303 .76593 L 0 .332 .054 r
F
.74086 .7592 m .74775 .7694 L .74035 .75904 L F
.72601 .7316 m .74327 .75722 L .73571 .7316 L 0 .606 .331 r
F
.73992 .76112 m .74538 .78409 L .7499 .78188 L 0 1 .391 r
F
.73992 .76112 m .74111 .77519 L .74538 .78409 L F
.73729 .78311 m .74303 .76593 L .74775 .7694 L 0 .325 .086 r
F
.73729 .78311 m .73856 .77178 L .74303 .76593 L F
.73729 .78311 m .74775 .7694 L .75028 .77932 L F
.72601 .7316 m .74592 .77723 L .74327 .75722 L 0 .606 .331 r
F
.72601 .7316 m .74186 .77824 L .74592 .77723 L F
.72601 .7316 m .73331 .75864 L .74186 .77824 L F
.72431 .67403 m .73302 .69594 L .74089 .70949 L 0 .583 .365 r
F
.74108 .70931 m .74089 .70949 L .74242 .71214 L F
.74108 .70931 m .74089 .70949 L .74223 .70707 L 0 0 0 r
F
.72431 .67403 m .74089 .70949 L .74108 .70931 L 0 .583 .365 r
F
.73754 .71562 m .73799 .71509 L .73768 .71445 L 0 .656 .343 r
F
.72652 .73767 m .73396 .72191 L .74089 .70949 L 0 0 0 r
F
.72652 .73767 m .74089 .70949 L .74108 .70931 L F
.72652 .73767 m .74108 .70931 L .74353 .70713 L F
.74108 .70931 m .74126 .70897 L .74353 .70713 L F
.74126 .70897 m .74223 .70707 L .74353 .70713 L F
.72431 .67403 m .74108 .70931 L .74353 .70713 L 0 .583 .365 r
F
.72652 .73767 m .74353 .70713 L .74286 .71028 L 0 0 0 r
F
.74353 .70713 m .74394 .7064 L .74385 .70674 L F
.74353 .70713 m .74385 .70674 L .74286 .71028 L F
.72852 .66836 m .7385 .66291 L .73228 .68248 L 0 .22 .113 r
F
.7598 .66555 m .76753 .68109 L .77111 .67797 L 0 .898 .479 r
F
.7598 .66555 m .77111 .67797 L .7713 .67132 L F
.7598 .66555 m .76798 .66463 L .76337 .66239 L F
.7598 .66555 m .7713 .67132 L .76798 .66463 L F
.76047 .67403 m .7654 .66151 L .76104 .66207 L 0 1 .407 r
F
.74415 .69711 m .75785 .66531 L .76181 .66305 L 0 0 .06 r
F
.74415 .69711 m .75031 .67984 L .75785 .66531 L F
.74415 .69711 m .76181 .66305 L .75999 .67277 L F
.74415 .69711 m .75999 .67277 L .75353 .68813 L F
.74415 .69711 m .75353 .68813 L .7459 .70289 L F
.75495 .70131 m .75277 .70938 L .75441 .71738 L 0 1 .469 r
F
.74623 .71857 m .75738 .71497 L .75228 .70474 L 0 1 .39 r
F
.74997 .70112 m .75195 .71103 L .75577 .71039 L 0 .642 .377 r
F
.74969 .70136 m .7514 .69691 L .74997 .70112 L 0 0 0 r
F
.74782 .70294 m .75195 .71103 L .74997 .70112 L 0 .642 .377 r
F
.74782 .70294 m .74722 .70346 L .75195 .71103 L F
.74759 .70333 m .74782 .70294 L .74949 .70186 L 0 0 0 r
F
.74782 .70294 m .7514 .69691 L .74969 .70136 L F
.74782 .70294 m .74969 .70136 L .74949 .70186 L F
.73328 .67445 m .74231 .69561 L .74722 .70346 L 0 .642 .377 r
F
.74412 .70813 m .74519 .70749 L .74472 .70555 L 0 .583 .365 r
F
.73509 .72443 m .74286 .71028 L .7514 .69691 L 0 0 0 r
F
.73328 .67445 m .74722 .70346 L .74782 .70294 L 0 .642 .377 r
F
.73328 .67445 m .74782 .70294 L .74997 .70112 L F
.74997 .70112 m .7514 .69691 L .75508 .69311 L 0 0 0 r
F
.74949 .70186 m .74969 .70136 L .74997 .70112 L F
.74542 .73067 m .74623 .71178 L .74242 .71214 L 0 .704 .355 r
F
.73509 .72443 m .74759 .70333 L .74949 .70186 L 0 0 0 r
F
.74394 .7064 m .7459 .70289 L .74503 .705 L F
.74384 .70624 m .74472 .70555 L .74231 .69561 L 0 .583 .365 r
F
.74394 .7064 m .74503 .705 L .74475 .70567 L 0 0 0 r
F
.74412 .70813 m .74467 .70577 L .74391 .70668 L 0 .583 .365 r
F
.74353 .70713 m .74412 .70813 L .74393 .70681 L F
.74384 .70677 m .74475 .70567 L .74286 .71028 L 0 0 0 r
F
.74394 .7064 m .74475 .70567 L .74384 .70677 L F
.74391 .70668 m .74472 .70555 L .74384 .70624 L 0 .583 .365 r
F
.74467 .70577 m .74472 .70555 L .74391 .70668 L F
.73328 .67445 m .74997 .70112 L .75161 .69451 L 0 .642 .377 r
F
.74997 .70112 m .75577 .71039 L .75257 .69817 L F
.74997 .70112 m .75089 .69968 L .75123 .69969 L 0 0 0 r
F
.75089 .69968 m .75508 .69311 L .75318 .69694 L F
.75089 .69968 m .75318 .69694 L .75181 .6997 L F
.75353 .68813 m .75508 .69311 L .7514 .69691 L 0 0 .046 r
F
.74997 .70112 m .75257 .69817 L .75161 .69451 L 0 .642 .377 r
F
.73509 .72443 m .74997 .70112 L .75181 .6997 L 0 0 0 r
F
.74997 .70112 m .75123 .69969 L .75181 .6997 L F
.7385 .66291 m .74852 .65807 L .74208 .67527 L 0 .197 .104 r
F
.75635 .69504 m .76149 .70926 L .76531 .7084 L 0 .697 .388 r
F
.75454 .69652 m .76061 .68763 L .75635 .69504 L 0 0 0 r
F
.7437 .71239 m .75181 .6997 L .75352 .69736 L F
.75454 .69652 m .75352 .69736 L .76061 .68763 L F
.75454 .69652 m .75352 .69736 L .76149 .70926 L 0 .697 .388 r
F
.7437 .71239 m .75352 .69736 L .75454 .69652 L 0 0 0 r
F
.74226 .674 m .75161 .69451 L .75352 .69736 L 0 .697 .388 r
F
.74226 .674 m .75352 .69736 L .75454 .69652 L F
.74226 .674 m .75454 .69652 L .75635 .69504 L F
.75454 .69652 m .76149 .70926 L .75635 .69504 L F
.75635 .69504 m .76061 .68763 L .76431 .68413 L 0 0 0 r
F
.7437 .71239 m .75454 .69652 L .75635 .69504 L F
.7437 .71239 m .75963 .69149 L .75236 .70132 L F
.75963 .69149 m .7608 .68995 L .76006 .69096 L F
.75963 .69149 m .76531 .7084 L .76092 .69279 L 0 .697 .388 r
F
.75963 .69149 m .76092 .69279 L .76007 .69103 L F
.75963 .69149 m .76007 .69103 L .76004 .69098 L F
.75963 .69149 m .76006 .69096 L .76004 .69098 L 0 0 0 r
F
.75635 .69504 m .76431 .68413 L .75902 .69215 L F
.75963 .69149 m .76431 .68413 L .7608 .68995 L F
.77319 .68644 m .78474 .68686 L .78078 .68284 L 0 .998 .439 r
F
.77319 .68644 m .7829 .69648 L .78474 .68686 L F
.77002 .68859 m .78004 .70188 L .78139 .69423 L 0 1 .484 r
F
.77002 .68859 m .77897 .68682 L .77439 .68461 L F
.77002 .68859 m .78139 .69423 L .77897 .68682 L F
.76047 .67403 m .77456 .69932 L .77514 .68737 L 0 1 .407 r
F
.7713 .67132 m .77111 .67797 L .77439 .68461 L 0 .965 .489 r
F
.76047 .67403 m .77144 .67237 L .7654 .66151 L 0 1 .407 r
F
.7713 .67132 m .77439 .68461 L .77897 .68682 L 0 .965 .489 r
F
.76047 .67403 m .77514 .68737 L .77144 .67237 L 0 1 .407 r
F
.75353 .68813 m .76776 .65979 L .77174 .65769 L 0 0 .046 r
F
.75353 .68813 m .75999 .67277 L .76776 .65979 L F
.75353 .68813 m .77174 .65769 L .7697 .66627 L F
.75353 .68813 m .7697 .66627 L .76295 .67992 L F
.75353 .68813 m .76295 .67992 L .75508 .69311 L F
.75963 .69149 m .76004 .69098 L .75125 .67284 L 0 .697 .388 r
F
.75963 .69149 m .76004 .69098 L .75236 .70132 L 0 0 0 r
F
.75541 .69634 m .75635 .69504 L .75833 .6932 L F
.75635 .69504 m .75902 .69215 L .75833 .6932 L F
.74226 .674 m .75635 .69504 L .75963 .69149 L 0 .697 .388 r
F
.74226 .674 m .75963 .69149 L .75125 .67284 L F
.75833 .6932 m .75904 .69213 L .75963 .69149 L 0 0 0 r
F
.7437 .71239 m .75541 .69634 L .75833 .6932 L F
.73685 .71551 m .73768 .71445 L .73703 .71308 L 0 .656 .343 r
F
.72431 .67403 m .74353 .70713 L .74231 .69561 L 0 .583 .365 r
F
.74353 .70713 m .74393 .70681 L .74231 .69561 L F
.73682 .7125 m .73745 .71212 L .73703 .71308 L 0 0 .072 r
F
.73482 .70707 m .73745 .71212 L .73682 .7125 L F
.73666 .71335 m .73703 .71308 L .73676 .71368 L F
.73482 .70707 m .73703 .71308 L .73666 .71335 L F
.737 .71309 m .73703 .71308 L .73701 .71304 L 0 .656 .343 r
F
.73666 .71335 m .73701 .71304 L .73671 .71242 L F
.73342 .71634 m .73676 .71368 L .73312 .71832 L 0 0 .072 r
F
.73345 .71614 m .73444 .7154 L .73342 .71634 L F
.73444 .7154 m .73676 .71368 L .73342 .71634 L F
.73482 .70707 m .73666 .71335 L .73345 .71614 L F
.73666 .71335 m .73676 .71368 L .73345 .71614 L F
.73345 .71614 m .73671 .71242 L .73291 .71243 L 0 .656 .343 r
F
.73666 .71335 m .73671 .71242 L .73345 .71614 L F
.71713 .67588 m .73291 .71243 L .73671 .71242 L 0 .52 .351 r
F
.7174 .67561 m .71752 .6755 L .71756 .67547 L 0 0 0 r
F
.71982 .67328 m .71762 .67555 L .72077 .67344 L 0 .52 .351 r
F
.71788 .67516 m .71762 .67555 L .71982 .67328 L F
.71762 .67555 m .73671 .71242 L .73302 .69594 L F
.71713 .67588 m .73671 .71242 L .71762 .67555 L F
.71762 .67555 m .73302 .69594 L .72077 .67344 L F
.74124 .65512 m .74399 .65296 L .74331 .6534 L 0 0 0 r
F
.7155 .67763 m .71344 .68012 L .71673 .67629 L 0 .454 .337 r
F
.71344 .68012 m .71363 .6804 L .71517 .67836 L F
.71344 .68012 m .71517 .67836 L .71673 .67629 L F
.7133 .68027 m .71344 .68012 L .71618 .6768 L 0 0 0 r
F
.71568 .67741 m .71673 .67629 L .71672 .67627 L 0 .454 .337 r
F
.7155 .67763 m .71673 .67629 L .71568 .67741 L F
.7155 .67738 m .71705 .67596 L .7174 .67561 L 0 0 0 r
F
.70943 .68513 m .71082 .68277 L .70929 .68442 L 0 .384 .321 r
F
.7078 .6863 m .70898 .68477 L .70897 .68475 L F
.70694 .68709 m .71156 .6818 L .71223 .68134 L 0 0 0 r
F
.71363 .6804 m .72374 .69532 L .71732 .6779 L 0 .454 .337 r
F
.71363 .6804 m .71732 .6779 L .71673 .67629 L F
.71303 .67951 m .71334 .67997 L .7137 .67865 L F
.71303 .67951 m .7137 .67865 L .71534 .67254 L F
.70911 .68461 m .70943 .68513 L .70929 .68442 L 0 .384 .321 r
F
.7058 .68783 m .70591 .68813 L .70707 .68683 L F
.70566 .68802 m .70541 .68814 L .7058 .68783 L 0 0 0 r
F
.69841 .6979 m .70654 .68751 L .70693 .68709 L F
.70694 .68709 m .7133 .68027 L .7155 .67738 L F
.7078 .6863 m .70917 .68532 L .70898 .68477 L 0 .384 .321 r
F
.70678 .68619 m .70707 .68683 L .70869 .68391 L F
.70943 .68513 m .71446 .69349 L .71121 .68392 L F
.69841 .6979 m .70594 .68765 L .70707 .68683 L 0 0 0 r
F
.70943 .68513 m .71768 .71064 L .71446 .69349 L 0 .384 .321 r
F
.70917 .68532 m .71768 .71064 L .70943 .68513 L F
.69742 .6652 m .70678 .68619 L .70869 .68391 L F
.68845 .65855 m .70455 .68894 L .69742 .6652 L 0 .316 .303 r
F
.69802 .6947 m .69837 .69406 L .69824 .69438 L 0 0 0 r
F
.6798 .71309 m .68107 .71907 L .68149 .71847 L 0 .315 .263 r
F
.67955 .7123 m .67973 .71316 L .6798 .71309 L F
.67955 .7123 m .68485 .71222 L .68485 .7122 L F
.67518 .71544 m .68115 .68688 L .68056 .69876 L 0 .024 .096 r
F
.67109 .72098 m .67221 .72635 L .67152 .7211 L 0 .245 .231 r
F
.67104 .72097 m .67105 .721 L .67109 .72098 L F
.67105 .721 m .67221 .72635 L .67109 .72098 L F
.67592 .71824 m .68337 .76738 L .6817 .74017 L 0 .282 .248 r
F
.66808 .72134 m .66878 .70826 L .67229 .70113 L 0 .006 .099 r
F
.67386 .71494 m .67759 .69197 L .68115 .68688 L 0 .024 .096 r
F
.67333 .71697 m .67262 .71548 L .67386 .71494 L F
.66667 .72246 m .66978 .74747 L .67051 .7488 L 0 .245 .231 r
F
.6666 .72251 m .66978 .74747 L .66667 .72246 L F
.66631 .72272 m .66878 .70826 L .66807 .72143 L 0 .006 .099 r
F
.66631 .72272 m .66567 .72319 L .66878 .70826 L F
.66573 .71851 m .66631 .72272 L .66607 .71836 L 0 .245 .231 r
F
.66631 .72272 m .66978 .74747 L .6666 .72251 L F
.66631 .72272 m .6666 .72251 L .66607 .71836 L F
.6628 .72611 m .66387 .73359 L .6635 .72523 L 0 .195 .208 r
F
.66088 .7677 m .67086 .78844 L .66387 .73359 L 0 .397 .243 r
F
.65954 .76238 m .66333 .73438 L .66567 .72319 L 0 .006 .099 r
F
.65702 .65638 m .66262 .70518 L .66494 .71885 L 0 .245 .231 r
F
.66573 .71851 m .66494 .71885 L .66978 .74747 L F
.65702 .65638 m .66494 .71885 L .66573 .71851 L F
.67262 .71548 m .67189 .71389 L .67759 .69197 L 0 .024 .096 r
F
.66807 .72135 m .66878 .70826 L .66808 .72134 L 0 .006 .099 r
F
.66876 .71812 m .67192 .71282 L .67189 .71389 L F
.65702 .65638 m .6704 .71799 L .66639 .6821 L 0 .245 .231 r
F
.6706 .71894 m .67119 .71805 L .67115 .71829 L 0 .006 .099 r
F
.6706 .71894 m .67104 .72097 L .67078 .71873 L 0 .245 .231 r
F
.67104 .72097 m .67152 .7211 L .67115 .71829 L F
.6706 .71894 m .67189 .71389 L .67119 .71805 L 0 .006 .099 r
F
.6707 .71811 m .67115 .71829 L .66639 .6821 L 0 .245 .231 r
F
.67104 .72097 m .67115 .71829 L .6707 .71811 L F
.67333 .71697 m .67951 .76307 L .68337 .76738 L 0 .282 .248 r
F
.67239 .71754 m .67227 .71714 L .67333 .71697 L 0 .024 .096 r
F
.67215 .71768 m .67154 .71596 L .67262 .71548 L F
.67115 .71829 m .67131 .71947 L .67215 .71768 L 0 .282 .248 r
F
.67131 .71947 m .67221 .72635 L .67216 .71842 L F
.67131 .71947 m .67216 .71842 L .67215 .71768 L F
.67215 .71768 m .67221 .72635 L .67951 .76307 L F
.67215 .71768 m .67951 .76307 L .67333 .71697 L F
.67549 .71663 m .67376 .7191 L .67592 .71824 L F
.67333 .71697 m .67347 .71644 L .67403 .71611 L 0 .024 .096 r
F
.67333 .71697 m .67403 .71611 L .67518 .71544 L F
.67262 .71548 m .67759 .69197 L .67386 .71494 L F
.67347 .71644 m .68115 .68688 L .67518 .71544 L F
.66639 .6821 m .67333 .71697 L .67401 .71686 L 0 .282 .248 r
F
.67518 .71544 m .67401 .71686 L .67549 .71663 L F
.66639 .6821 m .67401 .71686 L .67518 .71544 L F
.67333 .71697 m .67376 .7191 L .67549 .71663 L F
.67526 .71573 m .67801 .72618 L .67696 .71443 L F
.6742 .71846 m .67518 .71544 L .67695 .71624 L 0 .024 .096 r
F
.67941 .71186 m .67959 .71142 L .68253 .7091 L 0 .024 .09 r
F
.67959 .71142 m .68932 .68715 L .68491 .70451 L F
.67959 .71142 m .68491 .70451 L .68466 .70548 L F
.68165 .70793 m .67941 .71186 L .68253 .7091 L 0 .315 .263 r
F
.6773 .71284 m .68056 .69876 L .67777 .71227 L 0 .024 .096 r
F
.67528 .71512 m .68056 .69876 L .6773 .71284 L F
.67959 .71142 m .6814 .70537 L .6821 .70515 L 0 .024 .09 r
F
.67809 .71259 m .68651 .6802 L .67851 .7125 L F
.67804 .71277 m .6817 .74017 L .68914 .7725 L 0 .315 .263 r
F
.67802 .71278 m .68056 .69876 L .67804 .71277 L 0 .024 .09 r
F
.67762 .71299 m .68056 .69876 L .67797 .71305 L F
.67518 .71544 m .67777 .71227 L .67762 .71299 L 0 .024 .096 r
F
.67518 .71544 m .67528 .71512 L .6773 .71284 L F
.67689 .71374 m .67762 .71299 L .67681 .71285 L 0 .282 .248 r
F
.67801 .72618 m .67763 .71343 L .67689 .71374 L F
.67763 .71343 m .67762 .71299 L .67689 .71374 L F
.67941 .71186 m .67856 .7125 L .67955 .7123 L 0 .315 .263 r
F
.67941 .71186 m .67856 .7125 L .67959 .71142 L 0 .024 .09 r
F
.67804 .71277 m .68056 .69876 L .68651 .6802 L F
.67887 .71217 m .67923 .71102 L .67959 .71142 L F
.67856 .7125 m .67861 .71231 L .67887 .71217 L F
.67565 .69991 m .67856 .7125 L .67941 .71186 L 0 .315 .263 r
F
.67902 .71284 m .67856 .7125 L .67941 .71186 L 0 .024 .09 r
F
.67762 .71299 m .6817 .74017 L .67804 .71277 L 0 .315 .263 r
F
.67801 .72618 m .67969 .7268 L .6777 .71357 L 0 .282 .248 r
F
.67764 .71362 m .6777 .71357 L .67762 .71299 L F
.67801 .72618 m .6777 .71357 L .67764 .71362 L F
.67619 .7199 m .68142 .711 L .67865 .72432 L 0 .024 .09 r
F
.67728 .67367 m .68115 .68688 L .67759 .69197 L 0 .246 .141 r
F
.67565 .69991 m .68253 .7091 L .67747 .68029 L 0 .315 .263 r
F
.68253 .7091 m .68485 .7122 L .68387 .70796 L F
.68253 .7091 m .68466 .70548 L .68387 .70796 L 0 .024 .09 r
F
.68253 .7091 m .68387 .70796 L .67747 .68029 L 0 .315 .263 r
F
.68142 .711 m .68253 .7091 L .68332 .70968 L 0 .024 .09 r
F
.68253 .7091 m .68387 .70796 L .68332 .70968 L F
.68142 .711 m .68332 .70968 L .67865 .72432 L F
.67619 .7199 m .67836 .71312 L .67902 .71284 L F
.67856 .7125 m .67859 .71272 L .6786 .7127 L 0 .315 .263 r
F
.67836 .71312 m .67856 .7125 L .67902 .71284 L 0 .024 .09 r
F
.67591 .71577 m .67762 .71299 L .67695 .71624 L 0 .024 .096 r
F
.67518 .71544 m .67526 .71573 L .67553 .71523 L 0 .282 .248 r
F
.67526 .71573 m .67696 .71443 L .67681 .71285 L F
.67518 .71544 m .67762 .71299 L .67591 .71577 L 0 .024 .096 r
F
.67798 .71241 m .67762 .71299 L .67804 .71277 L 0 .315 .263 r
F
.67565 .69991 m .67762 .71299 L .67798 .71241 L F
.67797 .71305 m .67802 .71278 L .67804 .71277 L 0 .024 .09 r
F
.67619 .7199 m .67762 .71299 L .67797 .71305 L F
.67681 .71285 m .67762 .71299 L .67565 .69991 L 0 .282 .248 r
F
.67565 .69991 m .67909 .71083 L .68165 .70793 L 0 .315 .263 r
F
.67923 .71102 m .67981 .71069 L .67959 .71142 L 0 .024 .09 r
F
.67909 .71083 m .67941 .71186 L .68165 .70793 L 0 .315 .263 r
F
.67376 .7191 m .68337 .76738 L .67592 .71824 L 0 .282 .248 r
F
.65702 .65638 m .67051 .7488 L .6729 .74989 L 0 .245 .231 r
F
.67076 .71966 m .66966 .73082 L .67221 .72635 L F
.6706 .71894 m .67053 .71981 L .67076 .71966 L F
.67053 .71981 m .66966 .73082 L .67076 .71966 L F
.67462 .71715 m .67333 .71697 L .67518 .71544 L 0 .024 .096 r
F
.66966 .73082 m .67368 .75453 L .6725 .73187 L 0 .245 .231 r
F
.66966 .73082 m .6725 .73187 L .67221 .72635 L F
.6678 .73826 m .67301 .7182 L .67462 .71715 L 0 .024 .096 r
F
.67301 .7182 m .67333 .71697 L .67462 .71715 L F
.67196 .7186 m .67184 .71787 L .67215 .71768 L F
.67184 .71787 m .67154 .71596 L .67215 .71768 L F
.67115 .71829 m .67154 .71596 L .67196 .7186 L F
.67154 .71596 m .67189 .71389 L .67262 .71548 L F
.66639 .6821 m .67115 .71829 L .67215 .71768 L 0 .282 .248 r
F
.67227 .71714 m .67262 .71548 L .67333 .71697 L 0 .024 .096 r
F
.66639 .6821 m .67215 .71768 L .67333 .71697 L 0 .282 .248 r
F
.67282 .71894 m .67239 .71754 L .67333 .71697 L 0 .024 .096 r
F
.6678 .73826 m .67196 .7186 L .67282 .71894 L F
.67196 .7186 m .67227 .71714 L .67282 .71894 L F
.6706 .71894 m .67115 .71829 L .6678 .73826 L 0 .006 .099 r
F
.6704 .71799 m .6706 .71894 L .6707 .71811 L 0 .245 .231 r
F
.6706 .71894 m .67078 .71873 L .6707 .71811 L F
.6704 .71799 m .6707 .71811 L .66639 .6821 L F
.6678 .73826 m .67115 .71829 L .67196 .7186 L 0 .024 .096 r
F
.65954 .76238 m .66567 .72319 L .66631 .72272 L 0 .006 .099 r
F
.66807 .72143 m .66807 .72135 L .66808 .72134 L F
.65954 .76238 m .66631 .72272 L .66807 .72143 L F
.66607 .71836 m .6666 .72251 L .66667 .72246 L 0 .245 .231 r
F
.65702 .65638 m .66573 .71851 L .66607 .71836 L F
.6678 .73826 m .6742 .71846 L .67619 .7199 L 0 .024 .096 r
F
.6742 .71846 m .67695 .71624 L .67619 .7199 L F
.67438 .71242 m .67518 .71544 L .67681 .71285 L 0 .282 .248 r
F
.67518 .71544 m .67553 .71523 L .67681 .71285 L F
.68142 .711 m .67941 .71186 L .68253 .7091 L 0 .024 .09 r
F
.67619 .7199 m .67902 .71284 L .68142 .711 L F
.67902 .71284 m .67941 .71186 L .68142 .711 L F
.68485 .7122 m .68604 .70607 L .68461 .70728 L 0 .376 .277 r
F
.68461 .70728 m .6888 .70726 L .68442 .71417 L 0 .015 .082 r
F
.68466 .70548 m .68604 .70607 L .68461 .70728 L F
.68604 .70607 m .6888 .70726 L .68461 .70728 L F
.68461 .70728 m .68604 .70607 L .6846 .70709 L 0 .376 .277 r
F
.6846 .70709 m .68841 .69385 L .6837 .68864 L F
.68604 .70607 m .68841 .69385 L .6846 .70709 L F
.68604 .70607 m .6907 .70277 L .6888 .70726 L 0 .015 .082 r
F
.69783 .7003 m .69655 .70104 L .69863 .70252 L 0 .279 .283 r
F
.69783 .7003 m .69863 .70252 L .69827 .70017 L F
.67804 .71277 m .67809 .71259 L .67815 .71271 L 0 .024 .09 r
F
.67565 .69991 m .67804 .71277 L .67856 .7125 L 0 .315 .263 r
F
.67797 .71305 m .67804 .71277 L .67836 .71312 L 0 .024 .09 r
F
.67804 .71277 m .67815 .71271 L .67836 .71312 L F
.67809 .71259 m .67851 .7125 L .67836 .71312 L F
.67836 .71312 m .67855 .71232 L .67861 .71231 L F
.67619 .7199 m .67797 .71305 L .67836 .71312 L F
.66639 .6821 m .67438 .71242 L .67565 .69991 L 0 .282 .248 r
F
.67438 .71242 m .67681 .71285 L .67565 .69991 L F
.67801 .72618 m .6817 .74017 L .67969 .7268 L F
.66266 .72508 m .66266 .72508 L .64969 .63167 L 0 .195 .208 r
F
.6497 .63166 m .64934 .63203 L .64985 .63163 L 0 1 .516 r
F
.64934 .63203 m .64969 .63166 L .64945 .63184 L 0 .195 .208 r
F
.64966 .63146 m .66266 .72508 L .66262 .70518 L F
.64751 .61918 m .64909 .63237 L .64934 .63203 L F
.64751 .61918 m .64934 .63203 L .64966 .63146 L F
.64779 .63202 m .64934 .63203 L .6497 .63166 L 0 1 .516 r
F
.6497 .63166 m .66077 .62956 L .6507 .63094 L F
.6497 .63166 m .6507 .63094 L .65052 .63096 L F
.6497 .63166 m .64971 .63174 L .6504 .63076 L 0 .195 .208 r
F
.64971 .63174 m .66262 .70518 L .65045 .63103 L F
.64971 .63174 m .65045 .63103 L .6504 .63076 L F
.64751 .61918 m .65052 .63096 L .65005 .60788 L F
.65052 .63096 m .65055 .63094 L .65005 .60788 L F
.65055 .63093 m .65301 .62844 L .65005 .60788 L F
.65052 .63096 m .65217 .63032 L .65304 .62866 L 0 1 .516 r
F
.65217 .63032 m .65637 .62869 L .6535 .62867 L F
.65217 .63032 m .6535 .62867 L .65304 .62866 L F
.64272 .55863 m .6485 .59369 L .65516 .62661 L 0 .002 .141 r
F
.65546 .6152 m .65692 .62597 L .65746 .62404 L F
.65646 .62646 m .65569 .62727 L .65895 .62631 L 0 1 .328 r
F
.65637 .62869 m .65895 .62631 L .65569 .62727 L 0 1 .441 r
F
.65561 .62735 m .65569 .62727 L .65558 .6273 L F
.65637 .62869 m .65569 .62727 L .65561 .62735 L F
.65488 .61866 m .65644 .6264 L .65546 .6152 L 0 .002 .141 r
F
.65644 .6264 m .65646 .62646 L .65691 .62587 L F
.65646 .62646 m .65693 .62604 L .65691 .62587 L F
.65644 .6264 m .65691 .62587 L .65546 .6152 L F
.65692 .62597 m .65753 .62533 L .65746 .62404 L F
.64272 .55863 m .65516 .62661 L .6552 .62657 L F
.65646 .62646 m .65558 .6273 L .65569 .62727 L 0 1 .328 r
F
.65533 .62729 m .65558 .6273 L .65646 .62646 L F
.65732 .63455 m .65781 .63468 L .65769 .6321 L 0 1 .516 r
F
.65687 .63677 m .66116 .63413 L .65772 .63554 L 0 1 .332 r
F
.65772 .63554 m .66138 .63213 L .65781 .63468 L 0 1 .217 r
F
.65647 .62651 m .65784 .63589 L .65805 .63433 L 0 .002 .141 r
F
.65585 .62345 m .65635 .62659 L .65647 .62651 L F
.65635 .62659 m .65784 .63589 L .65647 .62651 L F
.65552 .62401 m .65784 .63589 L .65585 .62345 L F
.65606 .62676 m .65562 .62886 L .65784 .63589 L F
.65463 .61947 m .65544 .62721 L .65606 .62676 L F
.65544 .62721 m .65562 .62886 L .65606 .62676 L F
.64751 .61918 m .64966 .63146 L .65029 .63006 L 0 .195 .208 r
F
.64639 .6374 m .64979 .68179 L .65387 .69996 L 0 .122 .176 r
F
.63778 .56531 m .64553 .64042 L .64639 .6374 L F
.64553 .64042 m .64554 .64222 L .64581 .64067 L 0 1 .414 r
F
.64553 .64042 m .64979 .68179 L .64639 .6374 L 0 .122 .176 r
F
.64484 .63981 m .6448 .63988 L .64506 .64205 L F
.63923 .63491 m .64514 .64176 L .64553 .64042 L 0 1 .414 r
F
.64514 .64176 m .64554 .64222 L .64553 .64042 L F
.64421 .62719 m .64927 .62767 L .6553 .62731 L 0 1 .328 r
F
.65533 .62729 m .6553 .62731 L .65558 .6273 L F
.64421 .62719 m .6553 .62731 L .65533 .62729 L F
.65417 .62097 m .65562 .62886 L .65463 .61947 L 0 .002 .141 r
F
.65646 .62646 m .65895 .62631 L .65761 .62543 L 0 1 .328 r
F
.65805 .63433 m .65837 .63218 L .65761 .62543 L 0 .002 .141 r
F
.65754 .6255 m .65761 .62543 L .65746 .62404 L F
.65805 .63433 m .65761 .62543 L .65754 .6255 L F
.65214 .62506 m .65749 .62535 L .65772 .62534 L 0 .992 .294 r
F
.65135 .59069 m .65746 .62404 L .65776 .62533 L 0 .1 .186 r
F
.65786 .62528 m .65776 .62533 L .65826 .62529 L 0 .992 .294 r
F
.65879 .62494 m .65826 .62529 L .66402 .62484 L F
.6564 .63964 m .66116 .63413 L .65687 .63677 L 0 1 .332 r
F
.65594 .64305 m .65736 .64738 L .661 .6392 L F
.6564 .63964 m .661 .6392 L .66116 .63413 L F
.65594 .64305 m .661 .6392 L .6564 .63964 L F
.65846 .62494 m .65776 .62533 L .66478 .65543 L 0 .1 .186 r
F
.65135 .59069 m .65776 .62533 L .65846 .62494 L F
.65778 .62527 m .65772 .62534 L .65776 .62533 L 0 .992 .294 r
F
.65778 .62527 m .65776 .62533 L .65786 .62528 L F
.65214 .62506 m .65772 .62534 L .65778 .62527 L F
.65925 .6245 m .66478 .65543 L .66842 .66372 L 0 .1 .186 r
F
.65135 .59069 m .65846 .62494 L .65925 .6245 L F
.65846 .62494 m .65826 .62529 L .65879 .62494 L 0 .992 .294 r
F
.65846 .62494 m .66478 .65543 L .65925 .6245 L 0 .1 .186 r
F
.65214 .62506 m .65786 .62528 L .65846 .62494 L 0 .992 .294 r
F
.65786 .62528 m .65826 .62529 L .65846 .62494 L F
.64421 .62719 m .65646 .62646 L .65749 .62535 L 0 1 .328 r
F
.65692 .62597 m .65805 .63433 L .65753 .62533 L 0 .002 .141 r
F
.65646 .62646 m .65761 .62543 L .65749 .62535 L 0 1 .328 r
F
.65646 .62646 m .65805 .63433 L .65693 .62604 L 0 .002 .141 r
F
.6552 .62657 m .65516 .62661 L .6553 .62731 L F
.6552 .62657 m .6553 .62731 L .65533 .62729 L F
.64421 .62719 m .65533 .62729 L .65646 .62646 L 0 1 .328 r
F
.65533 .62729 m .6553 .62731 L .65562 .62886 L 0 .002 .141 r
F
.65055 .63109 m .65149 .63007 L .65055 .63093 L 0 .195 .208 r
F
.65149 .63007 m .65301 .62844 L .65055 .63093 L F
.65052 .63096 m .65213 .63074 L .65265 .63013 L 0 1 .516 r
F
.6525 .6327 m .65732 .63455 L .65261 .63206 L F
.65536 .64764 m .65736 .64738 L .65594 .64305 L 0 1 .332 r
F
.65055 .63109 m .65702 .65638 L .65301 .62844 L 0 .195 .208 r
F
.65052 .63096 m .65304 .62866 L .65291 .62866 L 0 1 .516 r
F
.6497 .63166 m .6504 .63076 L .65029 .63006 L 0 .195 .208 r
F
.65029 .63006 m .66262 .70518 L .65702 .65638 L F
.64779 .63202 m .65052 .63096 L .65053 .62864 L 0 1 .516 r
F
.65052 .63096 m .65291 .62866 L .65053 .62864 L F
.64965 .63167 m .6497 .63166 L .65052 .63096 L F
.64934 .63203 m .66266 .72508 L .64969 .63166 L 0 .195 .208 r
F
.64945 .63184 m .64969 .63166 L .64966 .63146 L F
.65925 .6245 m .66842 .66372 L .66017 .62384 L 0 .1 .186 r
F
.65925 .6245 m .66017 .62384 L .65978 .62192 L F
.65214 .62506 m .65925 .6245 L .66028 .62377 L 0 .992 .294 r
F
.67522 .62096 m .68307 .61134 L .68711 .61295 L 0 .188 .063 r
F
.67522 .62096 m .67798 .61476 L .68307 .61134 L F
.67522 .62096 m .68711 .61295 L .68792 .61677 L F
.67522 .62096 m .68792 .61677 L .68493 .62027 L F
.67522 .62096 m .67982 .62372 L .676 .62481 L F
.67522 .62096 m .68493 .62027 L .67982 .62372 L F
.67456 .59659 m .67982 .62371 L .676 .6248 L 0 .468 .178 r
F
.66535 .5719 m .676 .62481 L .67981 .62372 L 0 .548 .287 r
F
.66535 .5719 m .66979 .60252 L .676 .62481 L F
.64678 .55898 m .66042 .60397 L .65604 .56549 L 0 .571 .256 r
F
.66806 .61995 m .67074 .61689 L .66828 .61781 L 0 .974 .297 r
F
.65084 .57045 m .66659 .61562 L .66795 .61794 L 0 .033 .163 r
F
.66544 .62222 m .67248 .62244 L .67588 .62151 L 0 .957 .285 r
F
.66524 .62246 m .67248 .62244 L .66544 .62222 L F
.66183 .62256 m .66188 .62256 L .66198 .62246 L F
.66188 .62256 m .67248 .62244 L .66202 .62246 L F
.66188 .62256 m .66202 .62246 L .66198 .62246 L F
.662 .62245 m .66524 .62246 L .66544 .62222 L F
.65989 .61458 m .66176 .62256 L .662 .62245 L 0 .17 .223 r
F
.66177 .62246 m .66197 .62246 L .662 .62245 L 0 .957 .285 r
F
.66197 .62246 m .66524 .62246 L .662 .62245 L F
.65135 .59069 m .66026 .62371 L .65989 .61458 L 0 .1 .186 r
F
.66026 .62371 m .66027 .6237 L .65989 .61458 L F
.66174 .62257 m .66573 .6229 L .66176 .62256 L 0 .957 .285 r
F
.66154 .62266 m .66573 .6229 L .66166 .62256 L F
.65978 .62192 m .66018 .62384 L .66028 .62377 L 0 .1 .186 r
F
.64272 .55863 m .65552 .62401 L .65585 .62345 L 0 .002 .141 r
F
.64272 .55863 m .65746 .62404 L .65135 .59069 L F
.65214 .62506 m .66028 .62377 L .66009 .62258 L 0 .992 .294 r
F
.66028 .62377 m .66573 .6229 L .66154 .62266 L F
.66028 .62377 m .66028 .62376 L .66027 .6237 L 0 .1 .186 r
F
.66027 .6237 m .66027 .6237 L .65989 .61458 L F
.66028 .62377 m .66027 .6237 L .66027 .6237 L F
.66026 .62371 m .66028 .62377 L .66027 .6237 L F
.66028 .62377 m .66154 .62267 L .65989 .61458 L F
.66028 .62377 m .66154 .62266 L .66009 .62258 L 0 .992 .294 r
F
.66176 .62256 m .66631 .64614 L .67386 .67438 L 0 .17 .223 r
F
.65989 .61458 m .66154 .62266 L .66176 .62256 L F
.66154 .62266 m .66631 .64614 L .66176 .62256 L F
.66176 .62256 m .66573 .6229 L .67248 .62244 L 0 .957 .285 r
F
.66166 .62256 m .66174 .62257 L .66176 .62256 L F
.66009 .62258 m .66154 .62266 L .66166 .62256 L F
.66234 .62223 m .67588 .62151 L .67399 .62044 L F
.66009 .62258 m .662 .62245 L .66234 .62223 L F
.662 .62245 m .67588 .62151 L .66234 .62223 L F
.66234 .62223 m .662 .62245 L .66234 .62225 L 0 .17 .223 r
F
.65989 .61458 m .662 .62245 L .66234 .62223 L F
.66234 .62225 m .67747 .68029 L .67511 .66225 L F
.662 .62245 m .67747 .68029 L .66234 .62225 L F
.67597 .62528 m .68556 .62267 L .68941 .62236 L 0 0 0 r
F
.67597 .62528 m .67981 .62392 L .68556 .62267 L F
.67597 .62528 m .67943 .62456 L .6758 .62556 L F
.66497 .62579 m .6758 .62556 L .67943 .62456 L 0 .953 .275 r
F
.66497 .62579 m .66961 .62608 L .6758 .62556 L F
.66497 .62579 m .67943 .62456 L .6785 .62361 L F
.66497 .62579 m .6785 .62361 L .67362 .62334 L F
.66497 .62579 m .6674 .62387 L .66402 .62484 L F
.66497 .62579 m .67362 .62334 L .6674 .62387 L F
.66321 .62155 m .67399 .62044 L .66806 .61995 L 0 .957 .285 r
F
.65989 .61458 m .66233 .62222 L .66321 .62155 L 0 .17 .223 r
F
.66233 .62222 m .66234 .62223 L .66321 .62155 L F
.66009 .62258 m .66321 .62155 L .66127 .6204 L 0 .957 .285 r
F
.65989 .61458 m .66321 .62155 L .66088 .60442 L 0 .17 .223 r
F
.66234 .62223 m .67399 .62044 L .66321 .62155 L 0 .957 .285 r
F
.66321 .62155 m .66325 .62164 L .66324 .62153 L 0 .17 .223 r
F
.66321 .62155 m .66324 .62153 L .66088 .60442 L F
.66321 .62155 m .66806 .61995 L .66509 .62015 L 0 .957 .285 r
F
.66325 .62164 m .66516 .62041 L .66088 .60442 L 0 .17 .223 r
F
.66321 .62155 m .66509 .62015 L .66501 .62015 L 0 .957 .285 r
F
.66321 .62155 m .66501 .62015 L .66127 .6204 L F
.66009 .62258 m .66234 .62223 L .66321 .62155 L F
.66321 .62155 m .66234 .62225 L .66325 .62164 L 0 .17 .223 r
F
.66234 .62223 m .66234 .62225 L .66321 .62155 L F
.66325 .62164 m .67511 .66225 L .66838 .63242 L F
.66234 .62225 m .67511 .66225 L .66325 .62164 L F
.662 .62245 m .67386 .67438 L .67747 .68029 L F
.66176 .62256 m .66183 .62256 L .66181 .62253 L 0 .957 .285 r
F
.66176 .62256 m .67386 .67438 L .662 .62245 L 0 .17 .223 r
F
.66166 .62256 m .66176 .62256 L .66177 .62246 L 0 .957 .285 r
F
.66176 .62256 m .66181 .62253 L .66177 .62246 L F
.66183 .62256 m .66198 .62246 L .66177 .62246 L F
.66325 .62164 m .66838 .63242 L .66516 .62041 L 0 .17 .223 r
F
.68154 .60544 m .68711 .61295 L .68307 .61134 L 0 .347 .074 r
F
.67456 .59659 m .68435 .59989 L .67982 .62371 L 0 .468 .178 r
F
.68192 .51203 m .68356 .54748 L .68865 .54382 L 0 .722 .337 r
F
.68192 .51203 m .6798 .54036 L .68356 .54748 L F
.67456 .59659 m .68092 .53531 L .68506 .54208 L 0 .468 .178 r
F
.67456 .59659 m .67644 .55845 L .68092 .53531 L F
.67456 .59659 m .68506 .54208 L .68655 .5696 L F
.66535 .5719 m .67981 .62372 L .67924 .60346 L 0 .548 .287 r
F
.68493 .62027 m .68941 .62236 L .68556 .62267 L 0 .083 .013 r
F
.68435 .59989 m .68941 .62235 L .68556 .62266 L 0 .434 .163 r
F
.67469 .57765 m .68556 .62266 L .68941 .62235 L 0 .565 .304 r
F
.67469 .57765 m .67924 .60346 L .68556 .62266 L F
.66806 .61995 m .68178 .61994 L .68625 .61877 L 0 .974 .297 r
F
.66806 .61995 m .67399 .62044 L .68178 .61994 L F
.66806 .61995 m .68625 .61877 L .68489 .61725 L F
.66806 .61995 m .67856 .61639 L .67074 .61689 L F
.66806 .61995 m .68489 .61725 L .67856 .61639 L F
.65135 .59069 m .65889 .62295 L .65978 .62192 L 0 .1 .186 r
F
.64272 .55863 m .65417 .62097 L .65463 .61947 L 0 .002 .141 r
F
.66742 .61925 m .66828 .61781 L .66795 .61794 L 0 .974 .297 r
F
.67003 .62803 m .66904 .62887 L .67031 .62786 L 0 1 .217 r
F
.66838 .63243 m .6709 .62291 L .66795 .61794 L 0 .231 .255 r
F
.66691 .6187 m .66795 .61794 L .66659 .61562 L F
.66708 .61889 m .66795 .61794 L .66691 .6187 L 0 .974 .297 r
F
.66742 .61925 m .66795 .61794 L .66708 .61889 L F
.66806 .61995 m .66828 .61781 L .66742 .61925 L F
.66838 .63243 m .66795 .61794 L .66691 .6187 L 0 .231 .255 r
F
.66691 .6187 m .66795 .61794 L .66666 .61842 L 0 .974 .297 r
F
.65197 .61946 m .66666 .61842 L .66795 .61794 L 0 1 .322 r
F
.65084 .57045 m .66795 .61794 L .66869 .61714 L 0 .033 .163 r
F
.65084 .57045 m .66869 .61714 L .66841 .61193 L F
.65197 .61946 m .6687 .61717 L .6685 .61539 L 0 1 .322 r
F
.6687 .61717 m .67074 .61689 L .66932 .61594 L F
.66869 .61714 m .6687 .61717 L .66887 .61684 L 0 .033 .163 r
F
.6687 .61717 m .66828 .61781 L .67074 .61689 L 0 1 .322 r
F
.669 .61795 m .66961 .61723 L .66932 .61595 L 0 .033 .163 r
F
.66888 .61678 m .66932 .61595 L .66841 .61193 L F
.669 .61795 m .66932 .61595 L .66888 .61678 L F
.67192 .61283 m .67964 .61348 L .67657 .61191 L 0 1 .372 r
F
.66869 .61714 m .66875 .61704 L .66841 .61193 L 0 .033 .163 r
F
.66875 .61704 m .66889 .6168 L .66888 .61678 L F
.66875 .61704 m .66888 .61678 L .66841 .61193 L F
.65084 .57045 m .65799 .59311 L .66659 .61562 L F
.6614 .61492 m .6685 .61539 L .66967 .6153 L 0 1 .372 r
F
.67053 .61483 m .67019 .61526 L .67631 .61477 L F
.67126 .61414 m .67964 .61348 L .67192 .61283 L F
.67126 .61414 m .67631 .61477 L .67964 .61348 L F
.67115 .61431 m .67631 .61477 L .67126 .61414 L F
.66079 .59003 m .66841 .61193 L .66984 .61528 L 0 .137 .222 r
F
.67007 .61507 m .66984 .61528 L .67019 .61526 L 0 1 .372 r
F
.66991 .61484 m .67019 .61526 L .67053 .61483 L F
.67362 .62334 m .67588 .62151 L .67248 .62244 L 0 .791 .249 r
F
.67033 .61483 m .66984 .61528 L .67676 .63156 L 0 .137 .222 r
F
.66079 .59003 m .66984 .61528 L .67033 .61483 L F
.66991 .61484 m .66967 .6153 L .66984 .61528 L 0 1 .372 r
F
.66991 .61484 m .66984 .61528 L .67007 .61507 L F
.66991 .61484 m .67033 .61483 L .67023 .61422 L F
.67033 .61483 m .67631 .61477 L .67092 .61429 L F
.66079 .59003 m .67033 .61483 L .67106 .61416 L 0 .137 .222 r
F
.67033 .61483 m .67092 .61429 L .67023 .61422 L 0 1 .372 r
F
.67362 .62334 m .68489 .6233 L .68853 .62261 L 0 .791 .249 r
F
.67362 .62334 m .6785 .62361 L .68489 .6233 L F
.67362 .62334 m .68853 .62261 L .68743 .62171 L F
.67362 .62334 m .68743 .62171 L .68229 .6212 L F
.67362 .62334 m .68229 .6212 L .67588 .62151 L F
.67106 .61416 m .67676 .63156 L .68026 .63577 L 0 .137 .222 r
F
.67033 .61483 m .67676 .63156 L .67106 .61416 L F
.67597 .62528 m .68521 .62331 L .67943 .62456 L 0 0 0 r
F
.67199 .61298 m .68026 .63577 L .67687 .62297 L 0 .137 .222 r
F
.67186 .6127 m .67106 .61416 L .67192 .61283 L F
.66079 .59003 m .67097 .61396 L .67186 .6127 L F
.67097 .61396 m .67106 .61416 L .67186 .6127 L F
.67469 .57765 m .68941 .62235 L .68876 .60515 L 0 .565 .304 r
F
.67329 .6109 m .68466 .61153 L .688 .61021 L 0 1 .406 r
F
.67327 .61092 m .68466 .61153 L .67329 .6109 L F
.67293 .6112 m .68466 .61153 L .67319 .61091 L F
.67282 .61122 m .67657 .61191 L .67285 .6112 L F
.67253 .61147 m .67657 .61191 L .67268 .6112 L F
.66079 .59003 m .67186 .6127 L .66886 .60174 L 0 .137 .222 r
F
.67186 .6127 m .67192 .61283 L .67187 .61267 L F
.67186 .6127 m .67187 .61267 L .66886 .60174 L F
.65084 .57045 m .66841 .61193 L .66078 .59003 L 0 .033 .163 r
F
.6614 .61492 m .67192 .61283 L .6691 .6111 L 0 1 .372 r
F
.67192 .61283 m .67657 .61191 L .67253 .61147 L F
.67192 .61283 m .67194 .61279 L .66886 .60174 L 0 .137 .222 r
F
.67199 .61298 m .67269 .61188 L .67256 .61154 L F
.67196 .61288 m .67256 .61154 L .66886 .60174 L F
.67199 .61298 m .67256 .61154 L .67196 .61288 L F
.66886 .60174 m .67285 .6112 L .6732 .6109 L 0 .208 .266 r
F
.67283 .61092 m .6732 .6109 L .67306 .6104 L 0 1 .406 r
F
.6732 .6109 m .688 .61021 L .67353 .61039 L F
.67364 .61027 m .6732 .6109 L .67366 .61029 L 0 .208 .266 r
F
.66886 .60174 m .6732 .6109 L .67364 .61027 L F
.65604 .56549 m .66979 .60252 L .66535 .5719 L 0 .548 .271 r
F
.66886 .60174 m .67481 .60821 L .66832 .59234 L 0 .208 .266 r
F
.67481 .60821 m .68467 .60835 L .67684 .60719 L 0 1 .406 r
F
.66886 .60174 m .67253 .61147 L .67285 .6112 L 0 .208 .266 r
F
.67366 .61029 m .68467 .60835 L .67481 .60821 L 0 1 .406 r
F
.67481 .60821 m .67369 .61035 L .67507 .60849 L 0 .208 .266 r
F
.67483 .60817 m .67538 .60724 L .66832 .59234 L F
.67481 .60821 m .67495 .60798 L .67494 .60798 L 0 1 .406 r
F
.66886 .60174 m .67364 .61027 L .67481 .60821 L 0 .208 .266 r
F
.67481 .60821 m .67483 .60817 L .66832 .59234 L F
.67481 .60821 m .67494 .60798 L .66871 .60757 L 0 1 .406 r
F
.67364 .61027 m .67366 .61029 L .67481 .60821 L 0 .208 .266 r
F
.67366 .61029 m .67369 .61035 L .67481 .60821 L F
.67358 .6103 m .67366 .61029 L .67481 .60821 L 0 1 .406 r
F
.6691 .6111 m .67358 .6103 L .67481 .60821 L F
.67481 .60821 m .67522 .608 L .67495 .60798 L F
.67522 .608 m .67576 .60724 L .67538 .60725 L F
.67533 .60734 m .67538 .60725 L .67538 .60724 L 0 .208 .266 r
F
.67495 .60798 m .67538 .60725 L .66871 .60757 L 0 1 .406 r
F
.67522 .608 m .67538 .60725 L .67495 .60798 L F
.67488 .60829 m .67545 .6074 L .67538 .60725 L 0 .208 .266 r
F
.67488 .60829 m .67538 .60725 L .67533 .60734 L F
.67488 .60829 m .67538 .60724 L .67483 .60817 L F
.67481 .60821 m .67488 .60829 L .67483 .60817 L F
.6691 .6111 m .67481 .60821 L .66871 .60757 L 0 1 .406 r
F
.67522 .608 m .67684 .60719 L .67576 .60724 L F
.6732 .6109 m .67353 .61039 L .67306 .6104 L F
.67366 .61029 m .688 .61021 L .68467 .60835 L F
.67358 .61039 m .688 .61021 L .67366 .61029 L F
.67488 .60829 m .67693 .61052 L .67545 .6074 L 0 .208 .266 r
F
.67366 .61029 m .6732 .6109 L .67369 .61035 L F
.67306 .6104 m .67358 .61039 L .67366 .61029 L 0 1 .406 r
F
.6691 .6111 m .67283 .61092 L .67306 .6104 L F
.67192 .61283 m .67253 .61147 L .6691 .6111 L 0 1 .372 r
F
.67192 .61283 m .67194 .61279 L .67194 .61279 L 0 .137 .222 r
F
.67285 .6112 m .67687 .62297 L .6855 .64122 L 0 .208 .266 r
F
.67253 .61147 m .67687 .62297 L .67285 .6112 L F
.67285 .6112 m .67657 .61191 L .68466 .61153 L 0 1 .406 r
F
.67268 .6112 m .67282 .61122 L .67285 .6112 L F
.6691 .6111 m .67253 .61147 L .67268 .6112 L F
.6732 .6109 m .6855 .64122 L .68899 .64427 L 0 .208 .266 r
F
.67291 .6112 m .67293 .6112 L .67303 .61105 L 0 1 .406 r
F
.67291 .6112 m .67303 .61105 L .67299 .61108 L F
.67293 .6112 m .67319 .61091 L .67311 .61091 L F
.67285 .6112 m .6855 .64122 L .6732 .6109 L 0 .208 .266 r
F
.67299 .61108 m .67303 .61105 L .67311 .61091 L 0 1 .406 r
F
.67369 .61035 m .68899 .64427 L .68531 .63109 L 0 .208 .266 r
F
.67311 .61091 m .67327 .61092 L .67329 .6109 L 0 1 .406 r
F
.6732 .6109 m .68899 .64427 L .67369 .61035 L 0 .208 .266 r
F
.67856 .61639 m .69235 .61719 L .69601 .61626 L 0 1 .332 r
F
.67856 .61639 m .68489 .61725 L .69235 .61719 L F
.67856 .61639 m .69601 .61626 L .69379 .61464 L F
.67856 .61639 m .69379 .61464 L .68715 .61343 L F
.67856 .61639 m .67964 .61348 L .67631 .61477 L F
.67856 .61639 m .68715 .61343 L .67964 .61348 L F
.67507 .60849 m .68531 .63109 L .67693 .61052 L 0 .208 .266 r
F
.67369 .61035 m .68531 .63109 L .67507 .60849 L F
.6691 .6111 m .67291 .6112 L .67311 .61091 L 0 1 .406 r
F
.6614 .61492 m .67106 .61416 L .67192 .61283 L 0 1 .372 r
F
.67106 .61416 m .67126 .61414 L .67192 .61283 L F
.67192 .61283 m .67106 .61416 L .67199 .61298 L 0 .137 .222 r
F
.67106 .61416 m .68026 .63577 L .67199 .61298 L F
.6614 .61492 m .66967 .6153 L .66991 .61484 L 0 1 .372 r
F
.67192 .61283 m .67199 .61298 L .67194 .61279 L 0 .137 .222 r
F
.67199 .61298 m .67687 .62297 L .67269 .61188 L F
.67023 .61422 m .67115 .61431 L .67126 .61414 L 0 1 .372 r
F
.6614 .61492 m .66991 .61484 L .67023 .61422 L F
.6687 .61717 m .66932 .61594 L .6685 .61539 L 0 1 .322 r
F
.66887 .61684 m .6687 .61717 L .66889 .6168 L 0 .033 .163 r
F
.6687 .61717 m .669 .61795 L .66889 .61687 L F
.6687 .61717 m .66889 .61687 L .66889 .6168 L F
.6687 .61717 m .66795 .61794 L .66828 .61781 L 0 1 .322 r
F
.66869 .61714 m .66795 .61794 L .6687 .61717 L 0 .033 .163 r
F
.65197 .61946 m .66795 .61794 L .6687 .61717 L 0 1 .322 r
F
.6687 .61717 m .66795 .61794 L .6709 .62291 L 0 .033 .163 r
F
.669 .61795 m .6709 .62291 L .66961 .61723 L F
.66009 .62258 m .66166 .62256 L .66177 .62246 L 0 .957 .285 r
F
.66028 .62377 m .66028 .62377 L .66028 .62376 L 0 .1 .186 r
F
.66028 .62377 m .66631 .64614 L .66154 .62267 L F
.65214 .62506 m .65865 .62494 L .65925 .6245 L 0 .992 .294 r
F
.66028 .62377 m .66842 .66372 L .66631 .64614 L 0 .1 .186 r
F
.66018 .62384 m .66842 .66372 L .66028 .62377 L F
.64779 .63202 m .64965 .63167 L .65052 .63096 L 0 1 .516 r
F
.65052 .63096 m .65055 .63109 L .65055 .63094 L 0 .195 .208 r
F
.63923 .63491 m .64752 .63473 L .64779 .63202 L 0 1 .414 r
F
.64756 .6346 m .64757 .63466 L .64771 .6341 L 0 .122 .176 r
F
.64757 .63466 m .64772 .63443 L .64771 .6341 L F
.64752 .63473 m .64885 .63268 L .64779 .63202 L 0 1 .414 r
F
.64757 .63466 m .64774 .63589 L .64772 .63443 L 0 .122 .176 r
F
.64752 .63473 m .65287 .67288 L .64756 .6346 L F
.64639 .6374 m .64661 .63792 L .64667 .63749 L 0 1 .414 r
F
.64639 .6374 m .64724 .6445 L .64706 .63583 L 0 .122 .176 r
F
.63923 .63491 m .64639 .6374 L .64752 .63473 L 0 1 .414 r
F
.64514 .64176 m .64506 .64205 L .64554 .64222 L F
.64553 .64042 m .64506 .64205 L .64979 .68179 L 0 .122 .176 r
F
.63923 .63491 m .64326 .64143 L .64506 .64205 L 0 1 .414 r
F
.63923 .63491 m .64506 .64205 L .64514 .64176 L F
.63923 .63491 m .64581 .64067 L .64639 .6374 L F
.64934 .63203 m .66164 .7271 L .66178 .72703 L 0 .195 .208 r
F
.66164 .7271 m .66166 .72724 L .66178 .72703 L F
.65549 .72262 m .65612 .71689 L .65691 .7171 L 0 .201 .157 r
F
.6533 .73117 m .65445 .72226 L .65549 .72262 L F
.65307 .73208 m .65317 .73125 L .6533 .73117 L F
.65207 .73598 m .657 .73026 L .65547 .71543 L 0 .32 .232 r
F
.65145 .7366 m .65264 .72452 L .65318 .72472 L 0 .201 .157 r
F
.65155 .73413 m .65207 .73598 L .65547 .71543 L 0 .32 .232 r
F
.65218 .73638 m .65233 .73978 L .65292 .73903 L F
.65187 .73647 m .65233 .73978 L .65218 .73638 L F
.65233 .73978 m .66623 .84101 L .65292 .73903 L F
.65085 .74071 m .65207 .73598 L .65505 .75147 L 0 .201 .157 r
F
.65207 .73598 m .65334 .73472 L .65505 .75147 L F
.64934 .63203 m .6599 .72219 L .66123 .726 L 0 .195 .208 r
F
.66148 .72584 m .66123 .726 L .66166 .72724 L F
.64934 .63203 m .66123 .726 L .66148 .72584 L F
.66266 .72508 m .6628 .72611 L .66266 .72508 L F
.66266 .72508 m .6628 .72611 L .66279 .72513 L F
.66266 .72508 m .66279 .72513 L .66262 .70518 L F
.64934 .63203 m .66162 .72576 L .66266 .72508 L F
.66162 .72576 m .66181 .72721 L .66266 .72508 L F
.65085 .74071 m .65124 .73679 L .65145 .7366 L 0 .201 .157 r
F
.65124 .73679 m .65126 .73665 L .65132 .73663 L F
.65124 .73679 m .65132 .73663 L .65145 .7366 L F
.65112 .7369 m .65113 .73704 L .65113 .73703 L 0 .32 .232 r
F
.65063 .73081 m .65101 .73699 L .65112 .7369 L F
.65094 .73981 m .65115 .73688 L .65124 .73679 L 0 .201 .157 r
F
.65115 .73688 m .65115 .73677 L .65124 .73679 L F
.6511 .73723 m .65112 .7369 L .65112 .73729 L F
.65112 .7369 m .65115 .73688 L .65112 .73729 L F
.65124 .73679 m .65117 .73657 L .65126 .73665 L F
.65115 .73677 m .65117 .73657 L .65124 .73679 L F
.65063 .73081 m .65112 .7369 L .65124 .73679 L 0 .32 .232 r
F
.65063 .73081 m .65155 .73413 L .65387 .69996 L F
.65155 .73413 m .65547 .71543 L .65387 .69996 L F
.65093 .73708 m .65103 .73663 L .65103 .73674 L 0 .729 .063 r
F
.65094 .73721 m .65103 .73674 L .65101 .73699 L F
.65128 .73537 m .65124 .73679 L .65149 .73685 L 0 .32 .232 r
F
.65063 .73081 m .65116 .73599 L .65128 .73537 L F
.65116 .73599 m .65124 .73679 L .65128 .73537 L F
.64912 .74187 m .6493 .74185 L .65101 .73699 L 0 0 .119 r
F
.65049 .74414 m .6508 .7376 L .65085 .74071 L 0 .729 .063 r
F
.6508 .7376 m .65101 .73699 L .65085 .74071 L F
.65092 .73979 m .6511 .73723 L .65094 .73981 L 0 .201 .157 r
F
.6511 .73723 m .65112 .73729 L .65094 .73981 L F
.65013 .73448 m .65101 .73699 L .65063 .73081 L 0 0 .119 r
F
.64912 .74187 m .65101 .73699 L .65013 .73448 L F
.65128 .73537 m .65149 .73685 L .65155 .73413 L 0 .32 .232 r
F
.6729 .74989 m .67051 .7488 L .67368 .75453 L 0 .245 .231 r
F
.65085 .74071 m .65092 .73979 L .65094 .73981 L 0 .201 .157 r
F
.65954 .76238 m .6706 .71894 L .6678 .73826 L 0 .006 .099 r
F
.65954 .76238 m .66807 .72143 L .6706 .71894 L F
.66807 .72143 m .66876 .71812 L .6706 .71894 L F
.65702 .65638 m .66807 .72143 L .6706 .71894 L 0 .245 .231 r
F
.65155 .73413 m .65187 .73647 L .65218 .73638 L 0 .32 .232 r
F
.64898 .63233 m .64909 .63237 L .64908 .63203 L 0 1 .516 r
F
.64909 .63237 m .64927 .63213 L .64908 .63203 L F
.64909 .63237 m .65287 .67288 L .6599 .72219 L 0 .195 .208 r
F
.64885 .63268 m .65287 .67288 L .64909 .63237 L F
.66181 .72721 m .6619 .72792 L .6623 .72711 L F
.66181 .72721 m .6623 .72711 L .6628 .72611 L F
.66179 .72711 m .66166 .72724 L .6619 .72792 L F
.66275 .72643 m .66166 .72724 L .6628 .72611 L 0 0 .096 r
F
.64302 .67694 m .64903 .74187 L .64306 .67553 L 0 0 .119 r
F
.64903 .74187 m .65591 .81601 L .64912 .74187 L F
.64903 .74187 m .64912 .74187 L .64306 .67553 L F
.66161 .73007 m .66226 .72897 L .66166 .72724 L 0 .397 .243 r
F
.66039 .74076 m .66155 .72797 L .66275 .72643 L 0 0 .096 r
F
.64876 .74337 m .65321 .8121 L .65591 .81601 L 0 0 .119 r
F
.66088 .7677 m .67626 .851 L .67086 .78844 L 0 .397 .243 r
F
.65392 .79582 m .65365 .79303 L .65245 .78756 L 0 .161 .225 r
F
.65192 .78826 m .65392 .79582 L .65245 .78756 L F
.65284 .78649 m .65961 .74084 L .66039 .74076 L 0 0 .096 r
F
.65283 .78655 m .65284 .78649 L .65284 .78649 L F
.65284 .78649 m .65961 .74084 L .65284 .78649 L F
.66415 .7632 m .67043 .74215 L .6689 .7483 L 0 0 .006 r
F
.65656 .78737 m .66525 .81267 L .66022 .79131 L 0 .285 .282 r
F
.65529 .78599 m .65621 .78847 L .65656 .78737 L F
.65621 .78847 m .66525 .81267 L .65656 .78737 L F
.65516 .78632 m .66525 .81267 L .65529 .78599 L F
.65329 .78628 m .65409 .78805 L .65486 .78553 L F
.65409 .78805 m .66525 .81267 L .65499 .78588 L F
.65409 .78805 m .65499 .78588 L .65486 .78553 L F
.65996 .77392 m .65912 .77717 L .66266 .7796 L 0 .289 .306 r
F
.65997 .77388 m .65908 .77553 L .6623 .76478 L 0 0 0 r
F
.65996 .77392 m .65993 .77398 L .65997 .77388 L F
.65993 .77398 m .65908 .77553 L .65997 .77388 L F
.67086 .78844 m .67368 .75453 L .66978 .74747 L 0 .45 .252 r
F
.67563 .76219 m .6822 .79934 L .67788 .79126 L 0 .633 .17 r
F
.67086 .78844 m .68068 .79994 L .67368 .75453 L 0 .45 .252 r
F
.66392 .76487 m .67149 .78358 L .66951 .77252 L 0 .384 .336 r
F
.66371 .76457 m .66298 .76621 L .66415 .7632 L 0 0 .006 r
F
.66271 .76708 m .66284 .76733 L .66371 .76457 L 0 .384 .336 r
F
.65885 .77648 m .65912 .77717 L .65996 .77392 L 0 .289 .306 r
F
.65521 .78536 m .66022 .79131 L .65777 .78408 L 0 .285 .282 r
F
.65486 .78553 m .65505 .78574 L .65521 .78536 L F
.65505 .78574 m .66022 .79131 L .65521 .78536 L F
.65282 .78656 m .65961 .74084 L .65283 .78655 L 0 0 .096 r
F
.65283 .78655 m .6623 .82224 L .66614 .82595 L 0 .285 .282 r
F
.65269 .78667 m .6527 .78663 L .6527 .78666 L 0 0 .096 r
F
.6527 .78663 m .65961 .74084 L .65282 .78656 L F
.65257 .78677 m .65261 .78691 L .65283 .78655 L 0 .285 .282 r
F
.65262 .78696 m .6623 .82224 L .65283 .78655 L F
.65329 .78628 m .66614 .82595 L .66525 .81267 L F
.65283 .78655 m .66614 .82595 L .65329 .78628 L F
.65402 .78462 m .65329 .78628 L .65486 .78553 L F
.65322 .78594 m .6596 .74555 L .66151 .74369 L 0 0 .096 r
F
.65283 .78655 m .6596 .74555 L .65322 .78594 L F
.65271 .78655 m .65889 .74091 L .65961 .74084 L F
.64541 .78492 m .64606 .77954 L .65124 .80299 L 0 .996 .115 r
F
.64503 .78807 m .64705 .76474 L .64684 .76439 L 0 .729 .063 r
F
.64541 .78492 m .64705 .76474 L .64503 .78807 L F
.65035 .79132 m .65012 .78964 L .65124 .80297 L 0 0 .119 r
F
.65142 .79075 m .65146 .80497 L .65413 .82304 L F
.64962 .78086 m .65146 .80497 L .65142 .79075 L F
.64821 .76256 m .65124 .80297 L .65146 .80497 L F
.64772 .75614 m .6482 .76257 L .64821 .76256 L F
.6482 .76257 m .65124 .80297 L .64821 .76256 L F
.64771 .75661 m .65124 .80297 L .64772 .75614 L F
.65019 .79324 m .65261 .80716 L .6565 .81418 L 0 .161 .225 r
F
.6498 .79194 m .64938 .79436 L .65019 .79324 L F
.6479 .74897 m .64852 .75633 L .64849 .74513 L 0 0 .119 r
F
.64852 .75633 m .64923 .75564 L .64849 .74513 L F
.64494 .78926 m .64498 .78893 L .64496 .78895 L 0 .729 .063 r
F
.64541 .78492 m .65124 .80299 L .64492 .78902 L 0 .996 .115 r
F
.64492 .78902 m .65124 .80299 L .64492 .78902 L F
.64557 .79242 m .65124 .80299 L .65619 .84748 L F
.64492 .78902 m .64569 .79074 L .64557 .79242 L F
.64569 .79074 m .65124 .80299 L .64557 .79242 L F
.64304 .8142 m .64453 .80681 L .64353 .81799 L 0 .729 .063 r
F
.64743 .79804 m .65275 .82558 L .64745 .7981 L 0 .996 .115 r
F
.64643 .79525 m .64664 .79626 L .64743 .79804 L F
.64664 .79626 m .65275 .82558 L .64743 .79804 L F
.64882 .81218 m .65201 .82582 L .6568 .85704 L F
.64609 .79681 m .64898 .81099 L .64882 .81218 L F
.64898 .81099 m .65201 .82582 L .64882 .81218 L F
.64938 .79436 m .65261 .80716 L .65019 .79324 L 0 .161 .225 r
F
.64819 .75232 m .64962 .78086 L .65142 .79075 L 0 0 .119 r
F
.6479 .74897 m .64808 .75229 L .64819 .75232 L F
.64808 .75229 m .64962 .78086 L .64819 .75232 L F
.64848 .76677 m .65012 .78964 L .65035 .79132 L F
.6484 .76684 m .65012 .78964 L .64848 .76677 L F
.64983 .78568 m .64976 .78528 L .65012 .78964 L F
.64967 .79196 m .65171 .76718 L .65449 .75413 L 0 0 .086 r
F
.64966 .79204 m .64967 .79197 L .64967 .79196 L F
.64967 .79197 m .65171 .76718 L .64967 .79196 L F
.64886 .79264 m .64887 .79256 L .64966 .79204 L F
.64768 .75757 m .64976 .78528 L .6477 .75752 L 0 0 .119 r
F
.64768 .75768 m .64976 .78528 L .64768 .75757 L F
.6477 .75752 m .64976 .78528 L .64983 .78568 L F
.64817 .7642 m .64801 .76449 L .64976 .78528 L F
.64887 .79256 m .65171 .76718 L .64966 .79203 L 0 0 .086 r
F
.64887 .79256 m .64966 .79203 L .64966 .79204 L F
.6513 .79094 m .65578 .8118 L .65586 .80317 L 0 .161 .225 r
F
.64893 .79258 m .64908 .79315 L .6498 .79194 L F
.64908 .79315 m .64938 .79436 L .6498 .79194 L F
.6498 .79194 m .65449 .75413 L .6547 .75419 L 0 0 .086 r
F
.64886 .79264 m .65261 .80716 L .64893 .79258 L 0 .161 .225 r
F
.64643 .79525 m .64745 .7981 L .64683 .79489 L 0 .996 .115 r
F
.64643 .79525 m .64683 .79489 L .64672 .79454 L F
.6466 .79616 m .64672 .79455 L .64672 .79591 L 0 .729 .063 r
F
.64672 .79455 m .65085 .74071 L .64681 .79481 L F
.64672 .79455 m .64681 .79481 L .64672 .79591 L F
.64576 .79159 m .64643 .79525 L .64672 .79454 L 0 .996 .115 r
F
.64609 .79661 m .65201 .82582 L .64609 .79681 L F
.64583 .79535 m .64609 .79661 L .64609 .79681 L F
.64575 .79334 m .65201 .82582 L .64583 .79535 L F
.64583 .79535 m .64609 .79681 L .64643 .79525 L F
.64705 .80223 m .64898 .81304 L .64749 .80155 L F
.64898 .81304 m .65012 .81949 L .64926 .81209 L F
.65012 .81949 m .65033 .81848 L .64926 .81209 L F
.64886 .79264 m .64835 .79301 L .64836 .7929 L 0 0 .086 r
F
.64887 .79256 m .64836 .7929 L .65171 .76718 L F
.64886 .79264 m .64836 .7929 L .64887 .79256 L F
.64966 .79204 m .65449 .75413 L .6498 .79194 L F
.64777 .78519 m .6498 .79194 L .6483 .78289 L 0 .161 .225 r
F
.6498 .79194 m .65578 .8118 L .65051 .79146 L F
.65097 .79007 m .6498 .79194 L .65099 .78995 L 0 0 .086 r
F
.6498 .79194 m .65051 .79146 L .65039 .79099 L 0 .161 .225 r
F
.64886 .79264 m .64835 .79301 L .65261 .80716 L F
.64898 .81304 m .64926 .81209 L .64749 .80155 L 0 .996 .115 r
F
.65022 .79124 m .6547 .75419 L .65099 .78995 L 0 0 .086 r
F
.6498 .79194 m .64981 .79188 L .65022 .79124 L F
.64981 .79188 m .6547 .75419 L .65022 .79124 L F
.6513 .79094 m .65146 .79084 L .65111 .78985 L 0 .161 .225 r
F
.65103 .78998 m .65111 .78985 L .65058 .78837 L F
.6513 .79094 m .65111 .78985 L .65103 .78998 L F
.6483 .78289 m .65051 .79146 L .6513 .79094 L F
.65051 .79146 m .65578 .8118 L .6513 .79094 L F
.64768 .80125 m .6568 .85704 L .65275 .82558 L 0 .996 .115 r
F
.64643 .79525 m .64749 .80155 L .64768 .80125 L F
.64749 .80155 m .6568 .85704 L .64768 .80125 L F
.65259 .78661 m .65889 .74091 L .65271 .78655 L 0 0 .096 r
F
.655 .78228 m .65954 .76238 L .65687 .77858 L F
.65421 .78382 m .65437 .78319 L .655 .78228 L F
.65437 .78319 m .65954 .76238 L .655 .78228 L F
.64609 .79681 m .64705 .80223 L .64661 .79629 L 0 .996 .115 r
F
.64609 .79681 m .64661 .79629 L .64643 .79525 L F
.64504 .79093 m .64575 .79334 L .64583 .79535 L F
.64404 .80181 m .64496 .79043 L .64404 .8018 L 0 .729 .063 r
F
.64552 .79087 m .64583 .79535 L .64643 .79525 L 0 .996 .115 r
F
.64491 .78905 m .64397 .80166 L .64491 .78905 L 0 .729 .063 r
F
.64491 .78905 m .64491 .78905 L .64397 .80166 L F
.6443 .79723 m .64435 .79662 L .64435 .7966 L F
.64426 .79782 m .6443 .79724 L .6443 .79723 L F
.64492 .78902 m .64491 .78905 L .64306 .81398 L F
.64492 .78902 m .64575 .79334 L .64495 .79007 L 0 .996 .115 r
F
.64579 .77791 m .64747 .75612 L .64571 .77832 L 0 .729 .063 r
F
.64705 .76474 m .64771 .75661 L .64684 .76439 L F
.64781 .75167 m .64785 .75115 L .64788 .74953 L F
.64785 .75115 m .64789 .74943 L .64788 .74953 L F
.64773 .7527 m .64781 .75167 L .64781 .75045 L F
.64781 .75167 m .64788 .74953 L .64781 .75045 L F
.64747 .75612 m .64773 .7527 L .6474 .75567 L F
.64773 .7527 m .64781 .75045 L .6474 .75567 L F
.64505 .78925 m .64791 .74897 L .64861 .74519 L F
.64504 .78923 m .64791 .74897 L .64505 .78925 L F
.64492 .78994 m .645 .7903 L .64496 .79043 L 0 .996 .115 r
F
.6474 .75567 m .64789 .74943 L .6479 .74897 L 0 .729 .063 r
F
.64492 .78903 m .64791 .74897 L .64496 .79043 L F
.64861 .74519 m .64861 .74519 L .64496 .79045 L F
.64861 .74519 m .64496 .79045 L .64496 .79045 L F
.64496 .79043 m .64505 .78925 L .64496 .79043 L F
.64505 .78925 m .64861 .74519 L .64505 .78926 L F
.64505 .78925 m .64505 .78926 L .64496 .79043 L F
.64771 .75661 m .6484 .76684 L .64848 .76677 L 0 0 .119 r
F
.64768 .75757 m .64776 .75808 L .64771 .75661 L 0 .729 .063 r
F
.64769 .75739 m .6484 .76684 L .64771 .75661 L 0 0 .119 r
F
.64763 .7597 m .64763 .75987 L .64801 .76449 L F
.64552 .79087 m .64861 .74519 L .65049 .74414 L 0 .729 .063 r
F
.6452 .79062 m .64583 .79535 L .64552 .79087 L 0 .996 .115 r
F
.64496 .79043 m .645 .7903 L .64504 .79093 L F
.645 .7903 m .64575 .79334 L .64504 .79093 L F
.64504 .79093 m .64583 .79535 L .64524 .7909 L F
.64504 .79093 m .64524 .7909 L .64512 .78998 L F
.64305 .81404 m .64496 .79043 L .64552 .79087 L 0 .729 .063 r
F
.64496 .79043 m .64506 .78926 L .64552 .79087 L F
.64765 .75734 m .64768 .75757 L .64771 .75661 L F
.64763 .75958 m .64768 .75757 L .64765 .75734 L F
.64769 .75739 m .64768 .75757 L .6477 .75752 L 0 0 .119 r
F
.64506 .78926 m .64861 .74519 L .64552 .79087 L 0 .729 .063 r
F
.64525 .78959 m .64552 .79087 L .64545 .78992 L 0 .996 .115 r
F
.64552 .79087 m .64643 .79525 L .6458 .79186 L F
.64552 .79087 m .64702 .79068 L .64672 .79455 L 0 .729 .063 r
F
.64552 .79087 m .6458 .79186 L .64576 .79159 L 0 .996 .115 r
F
.64552 .79087 m .64672 .79455 L .6466 .79616 L 0 .729 .063 r
F
.64552 .79087 m .65085 .74071 L .64702 .79068 L F
.64552 .79087 m .64576 .79159 L .64545 .78992 L 0 .996 .115 r
F
.64472 .78705 m .64525 .78959 L .64451 .78485 L F
.64525 .78959 m .64545 .78992 L .64451 .78485 L F
.64496 .79043 m .64504 .78923 L .64505 .78925 L 0 .729 .063 r
F
.64399 .80165 m .64401 .80147 L .64399 .80142 L F
.64401 .80147 m .644 .80124 L .64399 .80142 L F
.64399 .80165 m .64399 .80142 L .64397 .80166 L F
.64304 .8142 m .64398 .8019 L .64397 .80166 L F
.64306 .81398 m .64492 .78903 L .64496 .79043 L F
.64492 .78902 m .64495 .79007 L .64492 .78994 L 0 .996 .115 r
F
.64485 .78912 m .64492 .78994 L .64475 .78927 L F
.64492 .78902 m .64492 .78994 L .64485 .78912 L F
.64496 .79045 m .64496 .79045 L .64305 .81404 L 0 .729 .063 r
F
.64472 .78705 m .6452 .79062 L .64552 .79087 L 0 .996 .115 r
F
.64496 .79043 m .64504 .79093 L .64512 .78998 L F
.64496 .79043 m .64496 .79043 L .64496 .79045 L 0 .729 .063 r
F
.64496 .79043 m .64496 .79045 L .64404 .8018 L F
.64475 .78927 m .64492 .78994 L .64496 .79043 L 0 .996 .115 r
F
.64554 .79823 m .64552 .79087 L .6466 .79616 L 0 .729 .063 r
F
.64452 .80022 m .64523 .79361 L .64554 .79823 L F
.64523 .79361 m .64552 .79087 L .64554 .79823 L F
.64681 .79481 m .65085 .74071 L .64683 .79489 L F
.65099 .78995 m .6547 .75419 L .65494 .76328 L 0 0 .086 r
F
.65097 .79007 m .65494 .76328 L .65128 .78936 L F
.65128 .78936 m .65148 .78791 L .65232 .78698 L F
.65148 .78791 m .65494 .76328 L .6525 .78537 L F
.65148 .78791 m .6525 .78537 L .65232 .78698 L F
.65437 .78319 m .66151 .74369 L .65954 .76238 L 0 0 .096 r
F
.65306 .78675 m .65318 .78611 L .6537 .78589 L F
.6513 .79094 m .65586 .80317 L .65146 .79084 L 0 .161 .225 r
F
.65109 .7898 m .65586 .80317 L .65186 .78803 L F
.65257 .78677 m .65586 .80317 L .6623 .82224 L 0 .285 .282 r
F
.65232 .78698 m .65494 .76328 L .65254 .78698 L 0 0 .096 r
F
.65113 .78151 m .65232 .78698 L .65257 .78677 L 0 .285 .282 r
F
.65232 .78698 m .65586 .80317 L .65257 .78677 L F
.65257 .78677 m .65494 .76328 L .66014 .73188 L 0 0 .096 r
F
.65254 .78698 m .65256 .78678 L .65257 .78677 L F
.65256 .78678 m .65494 .76328 L .65257 .78677 L F
.65143 .79505 m .65232 .78698 L .65254 .78698 L F
.65113 .78151 m .65283 .78655 L .65298 .78646 L 0 .285 .282 r
F
.65319 .78607 m .65298 .78646 L .65329 .78628 L F
.65113 .78151 m .65298 .78646 L .65319 .78607 L F
.65319 .78607 m .65392 .78468 L .6539 .78483 L 0 0 .096 r
F
.65319 .78607 m .65347 .78465 L .65392 .78468 L F
.65347 .78465 m .66151 .74369 L .65413 .78359 L F
.65347 .78465 m .65413 .78359 L .65392 .78468 L F
.65413 .78359 m .66151 .74369 L .65437 .78319 L F
.6479 .74897 m .64849 .74513 L .64737 .72927 L 0 0 .119 r
F
.64791 .74897 m .64791 .74896 L .64861 .74519 L 0 .729 .063 r
F
.64791 .74896 m .64871 .74369 L .64861 .74519 L F
.6479 .74897 m .64791 .74896 L .64791 .74897 L F
.64763 .74574 m .64784 .74934 L .6479 .74897 L 0 0 .119 r
F
.65085 .74071 m .65505 .75147 L .65171 .76718 L 0 .201 .157 r
F
.65954 .76238 m .6623 .76478 L .65908 .77553 L 0 .006 .099 r
F
.6468 .74619 m .65872 .77617 L .65996 .77392 L 0 .289 .306 r
F
.65882 .77659 m .65879 .77666 L .65908 .77553 L 0 0 0 r
F
.65877 .7768 m .65908 .77553 L .65995 .77395 L F
.65872 .77617 m .65885 .77648 L .65958 .77479 L 0 .289 .306 r
F
.65992 .774 m .65908 .77553 L .65996 .77392 L 0 0 0 r
F
.65872 .77617 m .65958 .77479 L .65996 .77392 L 0 .289 .306 r
F
.65316 .78599 m .65319 .78607 L .65402 .78462 L 0 .285 .282 r
F
.65319 .78607 m .65329 .78628 L .65402 .78462 L F
.65319 .78607 m .6539 .78483 L .6539 .78484 L 0 0 .096 r
F
.65318 .78611 m .65319 .78607 L .6539 .78484 L F
.65318 .78611 m .6539 .78484 L .6537 .78589 L F
.65421 .78382 m .65687 .77858 L .65656 .78049 L F
.65486 .78553 m .65521 .78536 L .65496 .78309 L 0 .285 .282 r
F
.65486 .78553 m .65496 .78309 L .65494 .78312 L F
.65486 .78553 m .65495 .78296 L .65469 .78342 L F
.65402 .78462 m .65486 .78553 L .65469 .78342 L F
.65521 .78536 m .65777 .78408 L .65685 .78136 L F
.65421 .78382 m .65656 .78049 L .65422 .78429 L 0 0 .096 r
F
.65521 .78536 m .65685 .78136 L .6538 .77233 L 0 .285 .282 r
F
.65486 .78553 m .65516 .78632 L .65529 .78599 L F
.65422 .78429 m .65656 .78049 L .6543 .79424 L 0 0 .096 r
F
.65494 .78312 m .65496 .78309 L .65495 .78296 L 0 .285 .282 r
F
.65469 .78342 m .65495 .78296 L .6538 .77233 L F
.65113 .78151 m .65402 .78462 L .6538 .77233 L F
.65402 .78462 m .65413 .78359 L .65437 .78319 L 0 0 .096 r
F
.6539 .78484 m .65413 .78359 L .65402 .78462 L F
.65402 .78462 m .65421 .78382 L .65422 .7843 L F
.65402 .78462 m .65469 .78342 L .6538 .77233 L 0 .285 .282 r
F
.6537 .78589 m .6539 .78484 L .65402 .78462 L 0 0 .096 r
F
.65872 .77617 m .65886 .77663 L .65889 .77659 L 0 .289 .306 r
F
.6468 .74619 m .6587 .77621 L .65872 .77617 L F
.6587 .77621 m .65886 .77663 L .65872 .77617 L F
.6468 .74619 m .65232 .76284 L .6573 .77334 L F
.65743 .77302 m .6573 .77334 L .65886 .77663 L F
.6468 .74619 m .6573 .77334 L .65743 .77302 L F
.65889 .77659 m .65886 .77663 L .65912 .77717 L F
.65588 .78856 m .65879 .77666 L .65882 .77659 L 0 0 0 r
F
.65525 .79259 m .65643 .78772 L .65709 .78545 L F
.64984 .81525 m .65114 .80846 L .65284 .8008 L F
.64352 .84032 m .65143 .79505 L .6478 .82305 L 0 0 .086 r
F
.64411 .83894 m .6478 .82305 L .64645 .83348 L F
.64352 .84032 m .6478 .82305 L .64411 .83894 L F
.64574 .83504 m .64927 .81764 L .64984 .81525 L 0 0 0 r
F
.64927 .81764 m .65114 .80846 L .64984 .81525 L F
.64574 .83504 m .65284 .8008 L .65312 .79983 L F
.64589 .8339 m .65114 .80846 L .64574 .83504 L F
.65392 .79582 m .65586 .80317 L .65408 .79504 L 0 .161 .225 r
F
.65017 .81351 m .65289 .80081 L .65011 .81341 L 0 0 0 r
F
.65392 .79582 m .65408 .79504 L .65391 .79568 L 0 .161 .225 r
F
.65994 .77401 m .65877 .7768 L .65995 .77395 L 0 0 0 r
F
.65391 .79568 m .65408 .79504 L .65365 .79303 L 0 .161 .225 r
F
.65134 .7992 m .6543 .79424 L .65114 .80846 L 0 0 .096 r
F
.65159 .80623 m .6543 .79424 L .65313 .79877 L 0 0 0 r
F
.65082 .80999 m .65289 .80081 L .65159 .80623 L F
.65101 .80935 m .65289 .80081 L .65082 .80999 L F
.64835 .82259 m .6543 .79424 L .6481 .82315 L F
.66022 .79131 m .66266 .7796 L .65912 .77717 L 0 .406 .308 r
F
.6435 .84152 m .64645 .83348 L .64337 .85265 L 0 0 .086 r
F
.64352 .84032 m .64411 .83894 L .6435 .84152 L F
.64411 .83894 m .64645 .83348 L .6435 .84152 L F
.6443 .84266 m .64635 .8337 L .64544 .83561 L 0 .717 .051 r
F
.64325 .84254 m .64678 .80509 L .64352 .84032 L 0 0 .072 r
F
.63899 .8773 m .64218 .84632 L .64325 .84254 L F
.63815 .88234 m .64218 .84632 L .63899 .8773 L F
.63899 .8773 m .64079 .86263 L .64086 .86633 L F
.64079 .86263 m .64325 .84254 L .64174 .85751 L F
.64079 .86263 m .64174 .85751 L .64086 .86633 L F
.64325 .84254 m .64332 .84226 L .64181 .85715 L F
.64466 .84331 m .64645 .83348 L .64635 .8337 L 0 .717 .051 r
F
.64174 .85751 m .64181 .85715 L .64023 .87266 L 0 0 .072 r
F
.6402 .87287 m .64023 .87266 L .63934 .88146 L F
.64174 .85751 m .64023 .87266 L .6402 .87287 L F
.64412 .84716 m .64337 .85265 L .64645 .83348 L 0 .717 .051 r
F
.64019 .87294 m .63934 .88146 L .63932 .8816 L 0 0 .072 r
F
.64174 .85751 m .6402 .87287 L .64019 .87294 L F
.6402 .87287 m .63934 .88146 L .64019 .87294 L F
.63585 .90294 m .63899 .8773 L .63881 .88665 L F
.63899 .8773 m .64086 .86633 L .63881 .88665 L F
.63682 .89508 m .63815 .88234 L .63899 .8773 L F
.63585 .90294 m .63649 .89723 L .63682 .89508 L F
.63649 .89723 m .63815 .88234 L .63682 .89508 L F
.63477 .91552 m .63589 .90144 L .63585 .90295 L 0 0 .09 r
F
.63589 .90144 m .63886 .86381 L .6361 .89968 L F
.63589 .90144 m .6361 .89968 L .63585 .90295 L F
.63411 .92176 m .63556 .90406 L .63477 .91552 L F
.63556 .90406 m .63886 .86381 L .63589 .90144 L F
.63556 .90406 m .63589 .90144 L .63477 .91552 L F
.63828 .88203 m .6421 .86012 L .64216 .85967 L 0 .717 .051 r
F
.63063 .9629 m .63542 .90526 L .63152 .95339 L 0 0 .09 r
F
.63542 .90526 m .63886 .86381 L .63556 .90406 L F
.63542 .90526 m .63556 .90406 L .63152 .95339 L F
.6383 .88188 m .64259 .8572 L .6427 .8565 L 0 .717 .051 r
F
.63542 .90526 m .63859 .85593 L .63886 .86381 L 0 0 .09 r
F
.63063 .9629 m .63441 .91204 L .63542 .90526 L F
.63441 .91204 m .63859 .85593 L .63542 .90526 L F
.64326 .85224 m .6427 .8565 L .64412 .84716 L 0 .717 .051 r
F
.63041 .96307 m .6318 .94489 L .63063 .9629 L 0 0 .09 r
F
.6318 .94489 m .63859 .85593 L .63222 .94154 L F
.6318 .94489 m .63222 .94154 L .63063 .9629 L F
.64325 .84254 m .64181 .85715 L .64174 .85751 L 0 0 .072 r
F
.64705 .80223 m .64749 .80155 L .64661 .79629 L 0 .996 .115 r
F
.63585 .90294 m .64678 .79566 L .64678 .80509 L 0 0 .072 r
F
.63585 .90294 m .64353 .81799 L .64678 .79566 L F
.63585 .90294 m .63886 .8638 L .64353 .81799 L F
.61746 1.06055 m .62293 1.08641 L .62064 1.20314 L 0 .593 .223 r
F
.61627 1.00704 m .61941 1.04443 L .61746 1.06055 L F
.61941 1.04443 m .62293 1.08641 L .61746 1.06055 L F
.62879 .96657 m .62705 .97239 L .6303 .93407 L 0 0 .109 r
F
.62078 .98542 m .62473 1.05027 L .62071 .88503 L 0 .813 .228 r
F
.62078 .98542 m .62082 1.04562 L .62473 1.05027 L F
.61627 1.00704 m .62543 .93078 L .62293 1.08641 L 0 .593 .223 r
F
.61949 1.23125 m .62308 1.05735 L .62101 1.13361 L 0 0 0 r
F
.61457 1.37006 m .61627 1.00704 L .61931 1.36741 L 0 .548 .225 r
F
.61745 1.36198 m .61942 1.25515 L .61949 1.23125 L 0 0 0 r
F
.61942 1.25515 m .62308 1.05735 L .61949 1.23125 L F
.61753 1.36262 m .61934 1.26303 L .61745 1.36198 L F
.61934 1.26303 m .62203 1.11516 L .61942 1.25515 L F
.62203 1.11516 m .6223 1.10015 L .62201 1.11543 L F
.6223 1.10015 m .62229 1.10046 L .62201 1.11543 L F
.62203 1.11516 m .62201 1.11543 L .61942 1.25515 L F
.62255 1.08638 m .62252 1.08727 L .61942 1.25515 L F
.6194 1.25982 m .62293 1.08641 L .62308 1.05735 L F
.61934 1.26303 m .6194 1.26022 L .6194 1.25982 L F
.6194 1.26022 m .62293 1.08641 L .6194 1.25982 L F
.61882 1.29656 m .62064 1.20314 L .61882 1.29647 L F
.61882 1.29655 m .61882 1.29653 L .62064 1.20314 L F
.61882 1.29655 m .62064 1.20314 L .61882 1.29688 L F
.61882 1.29688 m .62064 1.20314 L .61881 1.2972 L F
.61919 1.2779 m .62293 1.08641 L .61934 1.26303 L F
.62143 1.12544 m .62443 1.06051 L .62478 1.05988 L 0 0 .109 r
F
.62443 1.06051 m .62734 .99776 L .62478 1.05988 L F
.62478 1.05988 m .62734 .99776 L .62868 .98348 L F
.62868 .98348 m .6289 .96425 L .6297 .96363 L F
.62734 .99776 m .6289 .96425 L .62868 .98348 L F
.6289 .96425 m .63 .94054 L .6297 .96363 L F
.62369 1.08077 m .62821 .9926 L .62813 .99292 L F
.62339 1.08676 m .62821 .9926 L .62369 1.08077 L F
.62821 .9926 m .63077 .94268 L .62854 .98503 L F
.62821 .9926 m .62854 .98503 L .62813 .99292 L F
.62149 1.12338 m .62734 .99776 L .62143 1.12544 L F
.62243 1.10328 m .62658 .98486 L .62879 .96657 L F
.62102 1.13358 m .62191 1.10972 L .62243 1.10328 L F
.6223 1.10015 m .62255 1.08638 L .62229 1.10046 L 0 0 0 r
F
.62191 1.10972 m .62658 .98486 L .62243 1.10328 L 0 0 .109 r
F
.62255 1.08638 m .62308 1.05735 L .62252 1.08727 L 0 0 0 r
F
.62102 1.13358 m .62308 1.05732 L .62705 .97239 L 0 0 .109 r
F
.61963 1.07428 m .62335 1.04958 L .62688 1.01572 L 0 1 .109 r
F
.62303 1.09418 m .62744 1.00777 L .62337 1.08724 L 0 0 .109 r
F
.62744 1.00777 m .6275 1.00655 L .62264 1.10139 L F
.62391 1.07681 m .62813 .99292 L .62581 1.04284 L F
.62263 1.10193 m .62303 1.09418 L .62264 1.10139 L F
.62303 1.09418 m .62337 1.08724 L .62264 1.10139 L F
.62264 1.10139 m .62339 1.08676 L .62369 1.08077 L F
.6214 1.126 m .62263 1.10193 L .62264 1.10139 L F
.62143 1.12544 m .62263 1.10193 L .6214 1.126 L F
.6214 1.126 m .62369 1.08077 L .62132 1.1282 L F
.62369 1.08077 m .62813 .99292 L .62391 1.07681 L F
.62369 1.08077 m .62391 1.07681 L .62132 1.1282 L F
.62704 1.01253 m .62688 1.01572 L .62786 1.00636 L 0 1 .109 r
F
.62792 1.00514 m .62786 1.00636 L .62837 1.00138 L F
.62704 1.01253 m .62786 1.00636 L .62792 1.00514 L F
.61963 1.07428 m .62688 1.01572 L .62704 1.01253 L F
.62818 .99331 m .63077 .94268 L .62821 .9926 L 0 0 .109 r
F
.62909 .98037 m .63524 .88423 L .63859 .85593 L 0 0 .09 r
F
.62813 .99292 m .62878 .98304 L .62909 .98037 L F
.62878 .98304 m .63524 .88423 L .62909 .98037 L F
.63152 .95339 m .63411 .92176 L .63477 .91552 L F
.63006 .97041 m .63585 .90295 L .633 .94031 L F
.62813 .99292 m .63077 .94268 L .63524 .88423 L F
.62993 .95336 m .63063 .95104 L .63582 .91289 L 0 .772 .081 r
F
.62658 .98486 m .62705 .97239 L .62879 .96657 L 0 0 .109 r
F
.62668 .97572 m .62981 .95615 L .62993 .95336 L 0 .772 .081 r
F
.62981 .95615 m .63063 .95104 L .62993 .95336 L F
.62744 1.00777 m .62818 .99331 L .6275 1.00655 L 0 0 .109 r
F
.62818 .99331 m .62821 .9926 L .6275 1.00655 L F
.63 .94054 m .6306 .93954 L .63077 .94268 L F
.63022 .94706 m .63482 .91593 L .63559 .90354 L 0 .772 .081 r
F
.62668 .97572 m .63003 .95111 L .63022 .94706 L F
.63003 .95111 m .63482 .91593 L .63022 .94706 L F
.62132 1.1282 m .62391 1.07681 L .62415 1.07871 L 0 0 .109 r
F
.62391 1.07681 m .62581 1.04284 L .62415 1.07871 L F
.62813 .99292 m .63135 .96198 L .62837 1.00138 L 0 0 .09 r
F
.62917 .98287 m .62837 1.00138 L .63135 .96198 L 0 1 .109 r
F
.62789 .99514 m .62824 .99959 L .62917 .98287 L F
.62824 .99959 m .62837 1.00138 L .62917 .98287 L F
.61963 1.07428 m .62704 1.01253 L .62789 .99514 L F
.62704 1.01253 m .62837 1.00138 L .62789 .99514 L F
.63003 .95111 m .63431 .92331 L .63482 .91593 L 0 .772 .081 r
F
.62668 .97572 m .62993 .95336 L .63003 .95111 L F
.62993 .95336 m .63431 .92331 L .63003 .95111 L F
.62117 1.08646 m .62273 1.09714 L .62335 1.04958 L 0 1 .149 r
F
.62273 1.09714 m .62415 1.07871 L .62353 1.05623 L F
.62273 1.09714 m .62353 1.05623 L .62335 1.04958 L F
.61965 1.07405 m .63063 .95105 L .62668 .97573 L 0 1 .109 r
F
.61963 1.07428 m .61965 1.07408 L .61965 1.07405 L F
.61965 1.07408 m .63063 .95105 L .61965 1.07405 L F
.61488 1.00707 m .61543 .92246 L .61627 1.00704 L 0 .548 .225 r
F
.61627 1.00704 m .62115 .92703 L .62543 .93078 L 0 .593 .223 r
F
.61627 1.00704 m .61758 .93127 L .61984 .92859 L F
.61843 .88235 m .62334 .78214 L .62479 .8082 L F
.62071 .88503 m .62628 .89156 L .62363 .82167 L 0 .813 .228 r
F
.62164 .84494 m .62363 .82167 L .62273 .79786 L F
.62071 .88503 m .62363 .82167 L .62164 .84494 L F
.61627 1.00704 m .62307 .85755 L .62458 .87081 L 0 .593 .223 r
F
.62789 .94439 m .62778 .90884 L .62952 .91167 L 0 .321 .207 r
F
.62544 .93118 m .6303 .93407 L .62705 .97239 L 0 .306 .198 r
F
.63 .94054 m .6303 .93407 L .6306 .93954 L 0 0 .109 r
F
.62668 .97572 m .63792 .88462 L .63372 .90821 L 0 .772 .081 r
F
.62544 .93118 m .63416 .86471 L .6303 .93407 L 0 .306 .198 r
F
.62668 .97572 m .63372 .90821 L .6285 .94645 L 0 .772 .081 r
F
.61359 1.37094 m .61335 1.0071 L .61627 1.00704 L 0 .548 .225 r
F
.61535 1.01248 m .6268 .93549 L .62177 .94812 L 0 1 .195 r
F
.61359 1.37094 m .61627 1.00704 L .61457 1.37006 L 0 .548 .225 r
F
.61535 1.01248 m .6285 .94645 L .6268 .93549 L 0 1 .195 r
F
.62668 .97572 m .6285 .94645 L .62576 .97378 L 0 .772 .081 r
F
.61535 1.01248 m .62576 .97378 L .6285 .94645 L 0 1 .195 r
F
.61535 1.01248 m .62177 .94812 L .61612 .97634 L F
.61523 .96186 m .63023 .95467 L .62729 .94229 L 0 1 .322 r
F
.61335 1.0071 m .61543 .92246 L .61488 1.00707 L 0 .548 .225 r
F
.61453 .96299 m .61526 .96261 L .61523 .96186 L 0 1 .322 r
F
.61526 .96261 m .63023 .95467 L .61523 .96186 L F
.62813 .99292 m .63063 .9629 L .63152 .95339 L 0 0 .09 r
F
.62813 .99292 m .63041 .96307 L .63063 .9629 L F
.62813 .99292 m .63006 .97041 L .63135 .96198 L F
.63006 .97041 m .633 .94031 L .63135 .96198 L F
.61963 1.07428 m .63135 .96198 L .63063 .95105 L 0 1 .109 r
F
.61963 1.07428 m .62668 .97573 L .62165 1.02371 L F
.61963 1.07428 m .62165 1.02371 L .6189 1.06313 L F
.61235 1.3713 m .61272 1.02804 L .61359 1.37094 L 0 .548 .225 r
F
.61272 1.02804 m .61332 1.00629 L .61359 1.37094 L F
.61426 1.19637 m .62335 1.04958 L .61963 1.07428 L 0 1 .149 r
F
.61311 1.22261 m .61439 1.20098 L .61426 1.19637 L F
.61439 1.20098 m .62335 1.04958 L .61426 1.19637 L F
.6111 1.08724 m .60764 .96891 L .6077 1.01188 L 0 .654 .228 r
F
.60865 1.10275 m .60868 1.1029 L .61017 1.23665 L 0 .548 .225 r
F
.60865 1.10275 m .61017 1.23665 L .61014 1.23524 L F
.61043 1.11181 m .60773 1.03232 L .60923 1.15295 L 0 .654 .228 r
F
.60882 1.10084 m .6189 1.06313 L .62165 1.02371 L 0 1 .215 r
F
.60882 1.10084 m .6134 1.09634 L .6189 1.06313 L F
.60516 1.06358 m .6074 1.13012 L .60791 1.16876 L 0 .928 .09 r
F
.60448 1.04507 m .60791 1.16876 L .60798 1.21928 L F
.60878 1.20736 m .60838 1.24421 L .61091 1.37345 L 0 1 .169 r
F
.60448 1.04507 m .60975 1.30723 L .60998 1.33834 L 0 .928 .09 r
F
.60773 1.03232 m .60829 1.10794 L .60923 1.15295 L 0 .654 .228 r
F
.6094 1.28082 m .6074 1.13012 L .60955 1.28 L 0 .928 .09 r
F
.6074 1.13012 m .60761 1.13641 L .60955 1.28 L F
.60955 1.28 m .60761 1.13641 L .60901 1.20728 L F
.60761 1.13641 m .6083 1.15676 L .60901 1.20728 L F
.60923 1.15295 m .60829 1.10794 L .60874 1.16989 L 0 .654 .228 r
F
.60829 1.10794 m .605 .95207 L .60874 1.16989 L F
.6076 1.37379 m .60448 1.04507 L .6106 1.37186 L 0 .928 .09 r
F
.60742 1.13068 m .60874 1.16989 L .60109 .8116 L 0 1 .169 r
F
.60874 1.16989 m .605 .95207 L .60109 .8116 L F
.61167 1.37136 m .61001 1.1264 L .61235 1.3713 L 0 .548 .225 r
F
.61001 1.1264 m .61004 1.12522 L .61235 1.3713 L F
.6076 1.37379 m .60536 1.14025 L .60538 1.14014 L 0 .928 .09 r
F
.61235 1.3713 m .61043 1.11181 L .61075 1.10025 L 0 .548 .225 r
F
.60667 1.37504 m .60395 1.06561 L .6076 1.37379 L 0 .928 .09 r
F
.60655 1.36467 m .60395 1.06561 L .60667 1.37504 L F
.60395 1.06561 m .60441 1.04124 L .6076 1.37379 L F
.60485 1.17565 m .6134 1.09634 L .60882 1.10084 L 0 1 .228 r
F
.60505 1.19089 m .6134 1.09634 L .60485 1.17565 L F
.60798 1.21928 m .60791 1.16876 L .60975 1.30723 L 0 .928 .09 r
F
.60505 1.19089 m .61491 1.13524 L .6134 1.09634 L 0 1 .228 r
F
.60235 1.20585 m .60504 1.2023 L .60505 1.19089 L 0 .797 .246 r
F
.61311 1.22261 m .61976 1.13591 L .61983 1.10902 L 0 1 .149 r
F
.60975 1.30723 m .60901 1.20728 L .61134 1.37139 L 0 .928 .09 r
F
.61134 1.37139 m .60959 1.20953 L .61167 1.37136 L 0 .548 .225 r
F
.60959 1.20953 m .61014 1.23524 L .61167 1.37136 L F
.61103 1.27698 m .60984 1.17556 L .61034 1.17534 L F
.62113 1.13596 m .62415 1.07871 L .62147 1.14305 L 0 0 .109 r
F
.62102 1.13358 m .62132 1.1282 L .62113 1.13596 L F
.62132 1.1282 m .62415 1.07871 L .62113 1.13596 L F
.62102 1.13358 m .62149 1.12338 L .62143 1.12544 L F
.62102 1.13358 m .62143 1.12544 L .6214 1.126 L F
.62102 1.13358 m .6214 1.126 L .62132 1.1282 L F
.61909 1.25063 m .62101 1.13361 L .61937 1.21716 L 0 0 0 r
F
.61745 1.36198 m .61904 1.26032 L .61728 1.36124 L F
.61904 1.26032 m .62101 1.13361 L .61909 1.25063 L F
.61904 1.26032 m .61909 1.25063 L .61728 1.36124 L F
.61311 1.22261 m .61673 1.20512 L .61957 1.16792 L 0 1 .149 r
F
.61961 1.16072 m .61957 1.16792 L .62147 1.14305 L F
.61311 1.22261 m .61957 1.16792 L .61961 1.16072 L F
.62008 1.13176 m .62147 1.14305 L .62415 1.07871 L F
.61311 1.22261 m .61986 1.15842 L .62008 1.13176 L F
.61986 1.15842 m .62147 1.14305 L .62008 1.13176 L F
.61728 1.36124 m .61909 1.25063 L .61797 1.28817 L 0 0 0 r
F
.61909 1.25063 m .61937 1.21716 L .61797 1.28817 L F
.61311 1.22261 m .61963 1.07428 L .61491 1.13524 L 0 1 .149 r
F
.61311 1.22261 m .61491 1.13524 L .61233 1.19238 L F
.60491 1.21284 m .61233 1.19238 L .60504 1.2023 L 0 1 .228 r
F
.61014 1.23524 m .61017 1.23665 L .61167 1.37136 L 0 .548 .225 r
F
.61167 1.37136 m .61017 1.23665 L .61103 1.27698 L F
.61143 1.35635 m .61673 1.20515 L .61311 1.22265 L 0 1 .21 r
F
.60491 1.21284 m .60701 1.22878 L .61233 1.19238 L 0 1 .228 r
F
.60235 1.20585 m .60476 1.22408 L .60491 1.21284 L 0 .797 .246 r
F
.60444 1.19771 m .60504 1.2023 L .60505 1.19089 L 0 1 .228 r
F
.59814 1.20364 m .59855 1.25604 L .59814 1.20354 L 0 .93 .212 r
F
.60039 1.37409 m .59821 1.21988 L .60094 1.374 L 0 .789 .222 r
F
.59821 1.21196 m .59821 1.20902 L .59815 1.19963 L 0 .93 .212 r
F
.59821 1.21196 m .59815 1.19963 L .59814 1.20199 L F
.59814 1.20354 m .59821 1.21196 L .59814 1.20199 L F
.59821 1.21196 m .59831 1.22536 L .59821 1.20902 L F
.59821 1.21988 m .59814 1.20354 L .60094 1.374 L 0 .789 .222 r
F
.59815 1.19915 m .59816 1.19466 L .60155 1.37411 L F
.60094 1.374 m .59814 1.20354 L .60155 1.37411 L F
.59814 1.20354 m .59815 1.19915 L .60155 1.37411 L F
.60214 1.37435 m .59821 1.19011 L .60624 1.33755 L F
.59812 1.17926 m .60614 1.32888 L .60619 1.3347 L F
.59515 1.29699 m .60287 1.26206 L .60234 1.20586 L 0 .627 .24 r
F
.60287 1.26206 m .60395 1.25716 L .60341 1.2399 L F
.60287 1.26206 m .60341 1.2399 L .60234 1.20586 L F
.60395 1.25716 m .60416 1.23265 L .60392 1.22912 L F
.60359 1.24543 m .60392 1.22912 L .60234 1.20586 L F
.60395 1.25716 m .60392 1.22912 L .60359 1.24543 L F
.60538 1.25072 m .60477 1.22411 L .60234 1.20586 L F
.60235 1.20585 m .60491 1.21284 L .60504 1.2023 L 0 .797 .246 r
F
.60235 1.20585 m .60505 1.19089 L .60485 1.17565 L F
.60235 1.20585 m .60485 1.17565 L .60346 1.13112 L F
.60485 1.17565 m .6051 1.17102 L .60476 1.16363 L 0 1 .228 r
F
.60485 1.17565 m .60452 1.12975 L .60346 1.13112 L 0 .797 .246 r
F
.60538 1.14014 m .60445 1.0435 L .60448 1.04507 L 0 .928 .09 r
F
.60536 1.14025 m .60441 1.04124 L .60538 1.14014 L F
.60441 1.04124 m .60445 1.0435 L .60538 1.14014 L F
.6051 1.17102 m .60616 1.11873 L .60353 1.13635 L 0 1 .228 r
F
.60485 1.17565 m .60497 1.12916 L .60452 1.12975 L 0 .797 .246 r
F
.60253 1.2194 m .60485 1.17565 L .60353 1.13635 L 0 1 .228 r
F
.60485 1.17565 m .60476 1.16363 L .60353 1.13635 L F
.60773 1.03232 m .605 .95207 L .60829 1.10794 L 0 .654 .228 r
F
.607 1.11817 m .59884 .72068 L .60682 1.11292 L 0 1 .169 r
F
.6051 1.17102 m .60882 1.10084 L .60616 1.11873 L 0 1 .228 r
F
.60253 1.2194 m .60444 1.19771 L .60485 1.17565 L F
.60444 1.19771 m .60481 1.19362 L .60483 1.1817 L F
.60444 1.19771 m .60483 1.1817 L .60485 1.17565 L F
.60253 1.2194 m .60437 1.20689 L .60444 1.19771 L F
.60437 1.20689 m .60504 1.2023 L .60444 1.19771 L F
.60395 1.25716 m .60538 1.25072 L .60416 1.23265 L 0 .627 .24 r
F
.60538 1.25072 m .6055 1.25019 L .60477 1.22411 L F
.60561 1.25569 m .60701 1.22881 L .6055 1.25019 L 0 .861 .234 r
F
.59515 1.29699 m .60682 1.31161 L .6055 1.25019 L 0 .627 .24 r
F
.60664 1.37508 m .60655 1.36467 L .60667 1.37504 L 0 .928 .09 r
F
.6066 1.37514 m .60644 1.35629 L .60664 1.37508 L F
.60644 1.35629 m .60632 1.34462 L .60638 1.35019 L F
.60214 1.37435 m .60624 1.33755 L .60667 1.37504 L 0 .789 .222 r
F
.60593 1.35396 m .59515 1.29699 L .6032 1.3541 L 0 .627 .24 r
F
.60601 1.34983 m .59515 1.29699 L .60593 1.35396 L F
.60619 1.3347 m .60614 1.32888 L .60621 1.33514 L 0 .789 .222 r
F
.60685 1.35391 m .60734 1.34379 L .59515 1.29699 L 0 .627 .24 r
F
.60816 1.35414 m .60826 1.34087 L .60734 1.34379 L 0 1 .21 r
F
.60826 1.34087 m .60857 1.30006 L .60782 1.32649 L F
.60826 1.34087 m .60782 1.32649 L .60734 1.34379 L F
.60734 1.34379 m .60857 1.30006 L .60682 1.31161 L 0 .861 .234 r
F
.60734 1.34379 m .60739 1.31233 L .60682 1.31161 L 0 .627 .24 r
F
.60734 1.34379 m .60682 1.31161 L .59515 1.29699 L F
.60685 1.35391 m .60601 1.34983 L .60593 1.35396 L F
.6032 1.3541 m .59515 1.29699 L .59921 1.35431 L F
.61004 1.35527 m .60857 1.30006 L .60826 1.34087 L 0 1 .21 r
F
.60844 1.3543 m .60826 1.34087 L .60816 1.35414 L F
.61004 1.35527 m .60826 1.34087 L .60844 1.3543 L F
.60561 1.25569 m .60682 1.31161 L .60701 1.22881 L 0 .861 .234 r
F
.60058 1.35279 m .60682 1.31161 L .60561 1.25569 L F
.60682 1.31161 m .60857 1.30006 L .6078 1.26496 L F
.60682 1.31161 m .6078 1.26496 L .60701 1.22881 L F
.60697 1.24353 m .60877 1.31405 L .6072 1.24247 L 0 .627 .24 r
F
.6055 1.25019 m .6076 1.29135 L .60697 1.24353 L F
.6076 1.29135 m .60877 1.31405 L .60697 1.24353 L F
.60848 1.35373 m .60877 1.31405 L .60734 1.34379 L 0 .846 .233 r
F
.60725 1.35386 m .60734 1.34379 L .60685 1.35391 L F
.60732 1.35388 m .60734 1.34379 L .60725 1.35386 L 0 1 .21 r
F
.60816 1.35414 m .60734 1.34379 L .60732 1.35388 L F
.60848 1.35373 m .60734 1.34379 L .60725 1.35386 L 0 .846 .233 r
F
.60725 1.35386 m .60734 1.34379 L .60706 1.3538 L 0 1 .21 r
F
.60706 1.3538 m .60734 1.34379 L .60058 1.35279 L 0 .861 .234 r
F
.60734 1.34379 m .60682 1.31161 L .60058 1.35279 L F
.6055 1.25019 m .6055 1.25025 L .6055 1.25019 L 0 .627 .24 r
F
.6055 1.25025 m .60877 1.31405 L .6055 1.25019 L F
.60734 1.34379 m .60877 1.31405 L .60739 1.31233 L F
.60682 1.31161 m .60877 1.31405 L .6055 1.25019 L F
.59051 1.37427 m .58828 1.14686 L .59281 1.37509 L 0 .992 .198 r
F
.59921 1.35431 m .59515 1.29699 L .58724 1.33996 L 0 .377 .228 r
F
.60058 1.35279 m .60561 1.25569 L .59827 1.35228 L 0 .861 .234 r
F
.60561 1.25569 m .6055 1.25019 L .59827 1.35228 L F
.59827 1.35228 m .6055 1.25019 L .60253 1.21942 L F
.6055 1.25019 m .60701 1.22881 L .60477 1.22411 L F
.6055 1.25019 m .60477 1.22411 L .60477 1.22411 L 0 .627 .24 r
F
.6055 1.25019 m .60477 1.22411 L .60253 1.21942 L 0 .861 .234 r
F
.6055 1.25019 m .6072 1.24247 L .60477 1.22411 L 0 .627 .24 r
F
.60453 1.21388 m .60476 1.22408 L .60491 1.21284 L 0 1 .228 r
F
.60253 1.2194 m .60476 1.22408 L .60453 1.21388 L F
.60476 1.22408 m .60476 1.22408 L .60453 1.21388 L F
.60476 1.22408 m .60701 1.22878 L .60491 1.21284 L F
.60998 1.33834 m .60975 1.30723 L .6106 1.37186 L 0 .928 .09 r
F
.60975 1.30723 m .6094 1.28082 L .60955 1.28 L F
.61089 1.37168 m .6104 1.33348 L .61134 1.37139 L F
.6106 1.37186 m .6104 1.33348 L .61089 1.37168 L F
.6106 1.37186 m .60975 1.30723 L .6104 1.33348 L F
.61004 1.35527 m .61311 1.22265 L .60857 1.30006 L 0 1 .21 r
F
.61143 1.35635 m .61311 1.22265 L .61004 1.35527 L F
.60491 1.21284 m .6072 1.24245 L .61297 1.23483 L 0 .797 .246 r
F
.60476 1.22408 m .6072 1.24245 L .60491 1.21284 L F
.60504 1.2023 m .61297 1.23483 L .61574 1.18826 L F
.60491 1.21284 m .61297 1.23483 L .60504 1.2023 L F
.60504 1.2023 m .61233 1.19238 L .61491 1.13524 L 0 1 .228 r
F
.60253 1.2194 m .60491 1.21284 L .60504 1.2023 L F
.60504 1.2023 m .61491 1.13524 L .60505 1.19089 L F
.60505 1.19089 m .61574 1.18826 L .61408 1.14084 L 0 .797 .246 r
F
.60504 1.2023 m .61574 1.18826 L .60505 1.19089 L F
.60485 1.17565 m .61408 1.14084 L .60916 1.12372 L F
.60505 1.19089 m .61408 1.14084 L .60485 1.17565 L F
.60481 1.19362 m .60505 1.19089 L .60485 1.17565 L 0 1 .228 r
F
.60485 1.17565 m .60916 1.12372 L .60497 1.12916 L 0 .797 .246 r
F
.61163 1.10063 m .6212 1.06638 L .61609 1.05906 L 0 .952 .255 r
F
.60916 1.12372 m .61191 1.11063 L .61163 1.10063 L F
.61191 1.11063 m .6212 1.06638 L .61163 1.10063 L F
.61999 1.0578 m .6212 1.06636 L .6272 1.05549 L 0 1 .268 r
F
.61609 1.05905 m .61997 1.06461 L .61999 1.0578 L F
.61997 1.06461 m .6212 1.06636 L .61999 1.0578 L F
.61881 1.2972 m .61882 1.29656 L .61882 1.29647 L 0 0 0 r
F
.61829 1.32372 m .61829 1.32372 L .61882 1.29653 L F
.6175 1.36436 m .61829 1.32372 L .61829 1.32372 L F
.6175 1.36436 m .61757 1.36052 L .61829 1.32372 L F
.6175 1.36436 m .61882 1.29653 L .61882 1.29655 L F
.6175 1.36436 m .61882 1.29655 L .61752 1.36325 L F
.61882 1.29655 m .61882 1.29688 L .61752 1.36325 L F
.61752 1.36325 m .61882 1.29688 L .61881 1.2972 L F
.61752 1.36325 m .61881 1.2972 L .61753 1.36262 L F
.61881 1.2972 m .61881 1.29744 L .61753 1.36262 L F
.61753 1.36262 m .61919 1.2779 L .61934 1.26303 L F
.61976 1.13591 m .6208 1.12235 L .61983 1.10902 L 0 1 .149 r
F
.6208 1.12235 m .62273 1.09714 L .62099 1.1043 L F
.6208 1.12235 m .62099 1.1043 L .61983 1.10902 L F
.61934 1.26303 m .61942 1.25515 L .61745 1.36198 L 0 0 0 r
F
.61983 1.10902 m .62099 1.1043 L .62117 1.08646 L 0 1 .149 r
F
.62099 1.1043 m .62273 1.09714 L .62117 1.08646 L F
.63372 .90821 m .64538 .83601 L .64097 .85775 L 0 .717 .051 r
F
.64538 .83601 m .64544 .83561 L .6454 .8358 L F
.64538 .83601 m .6454 .8358 L .64097 .85775 L F
.63372 .90821 m .64222 .85926 L .64326 .85224 L F
.64222 .85926 m .6427 .8565 L .64326 .85224 L F
.63372 .90821 m .63828 .88203 L .6383 .88188 L F
.63828 .88203 m .64259 .8572 L .6383 .88188 L F
.63372 .90821 m .63826 .88214 L .63828 .88203 L F
.63826 .88214 m .6421 .86012 L .63828 .88203 L F
.63372 .90821 m .63792 .88462 L .63805 .88389 L F
.63826 .88214 m .63805 .88389 L .6421 .86012 L F
.63372 .90821 m .63805 .88389 L .63826 .88214 L F
.64216 .85967 m .6421 .86012 L .64259 .8572 L F
.6427 .8565 m .64259 .8572 L .64337 .85265 L F
.6427 .8565 m .64337 .85265 L .64412 .84716 L F
.63899 .87556 m .64447 .84465 L .64466 .84331 L F
.64447 .84465 m .64645 .83348 L .64466 .84331 L F
.63932 .8816 m .63934 .88146 L .63881 .88665 L 0 0 .072 r
F
.64097 .85775 m .64589 .8339 L .64574 .83504 L 0 0 0 r
F
.64229 .85145 m .64752 .82656 L .64206 .85249 L F
.64752 .82656 m .64835 .82259 L .64754 .82645 L F
.64752 .82656 m .64754 .82645 L .64206 .85249 L F
.64206 .85249 m .64754 .82645 L .6481 .82315 L F
.64754 .82645 m .64835 .82259 L .64819 .82296 L F
.64754 .82645 m .64819 .82296 L .6481 .82315 L F
.64097 .85775 m .64697 .82861 L .64703 .8284 L F
.64097 .85775 m .64607 .83259 L .64635 .83161 L F
.64206 .85249 m .64861 .82068 L .6419 .8529 L F
.64703 .8284 m .65 .81388 L .65016 .81319 L F
.65016 .81319 m .65 .81388 L .65114 .80846 L F
.64861 .82068 m .65313 .79877 L .64874 .81994 L F
.64697 .82861 m .65 .81388 L .64703 .8284 L F
.64635 .83161 m .64607 .83259 L .65 .81388 L F
.64861 .82068 m .64874 .81994 L .6419 .8529 L F
.64325 .84254 m .64352 .84032 L .64332 .84226 L 0 0 .072 r
F
.64097 .85775 m .64544 .83561 L .64607 .83259 L 0 0 0 r
F
.6419 .8529 m .64774 .82478 L .64838 .81915 L F
.64774 .82478 m .65313 .79877 L .6494 .81479 L F
.64774 .82478 m .6494 .81479 L .64838 .81915 L F
.64218 .84632 m .64678 .80509 L .64325 .84254 L 0 0 .072 r
F
.64097 .85775 m .64206 .85249 L .6419 .8529 L 0 0 0 r
F
.65017 .81218 m .65822 .77905 L .65994 .77401 L F
.64838 .81915 m .65085 .8091 L .65017 .81218 L F
.65085 .8091 m .65822 .77905 L .65017 .81218 L F
.65822 .77905 m .65877 .7768 L .65994 .77401 L F
.65143 .79505 m .6529 .79464 L .65134 .7992 L 0 0 .096 r
F
.6529 .79464 m .6543 .79424 L .65134 .7992 L F
.65312 .79983 m .65284 .8008 L .6543 .79424 L 0 0 0 r
F
.65289 .80081 m .6543 .79424 L .65159 .80623 L F
.64838 .81915 m .65587 .78858 L .65588 .78856 L F
.64838 .81915 m .65313 .79877 L .65565 .78892 L F
.64838 .81915 m .65565 .78892 L .65587 .78858 L F
.65525 .79259 m .65709 .78545 L .65658 .787 L F
.65471 .79441 m .65643 .78772 L .65525 .79259 L F
.65525 .79259 m .65658 .787 L .65592 .78901 L F
.65996 .77392 m .66266 .7796 L .66107 .77001 L 0 .289 .306 r
F
.66284 .76734 m .66796 .78235 L .67149 .78358 L 0 .384 .336 r
F
.66277 .76689 m .66716 .75048 L .67043 .74215 L 0 0 .006 r
F
.66275 .76691 m .66716 .75048 L .66277 .76689 L F
.66192 .76846 m .66716 .75048 L .66271 .76708 L F
.66192 .76846 m .66225 .76923 L .66271 .76708 L 0 .384 .336 r
F
.66271 .76708 m .66225 .76923 L .66284 .76734 L F
.6608 .77098 m .66085 .77076 L .66107 .77001 L 0 0 0 r
F
.66085 .77076 m .6623 .76478 L .66113 .76977 L F
.66085 .77076 m .66113 .76977 L .66107 .77001 L F
.66271 .76708 m .66275 .76691 L .66277 .76689 L 0 0 .006 r
F
.66271 .76708 m .66298 .76621 L .66371 .76457 L F
.66298 .76621 m .67043 .74215 L .66415 .7632 L F
.66575 .75928 m .67865 .72432 L .67693 .73043 L F
.66385 .76415 m .66415 .7632 L .66388 .76405 L F
.66388 .76405 m .66415 .7632 L .66408 .7634 L F
.66415 .7632 m .6689 .7483 L .66549 .75893 L F
.68067 .77441 m .68251 .79191 L .68698 .80026 L 0 1 .314 r
F
.67563 .76219 m .68656 .78482 L .6822 .79934 L 0 .633 .17 r
F
.66573 .75934 m .67808 .77378 L .66659 .75725 L 0 .502 .357 r
F
.66649 .75747 m .6665 .75747 L .66659 .75725 L 0 0 .006 r
F
.6665 .75747 m .67693 .73043 L .66659 .75725 L F
.66659 .75725 m .67808 .77378 L .67162 .75831 L 0 .502 .357 r
F
.66559 .75969 m .66573 .75934 L .66631 .75794 L 0 0 .006 r
F
.66573 .75934 m .67693 .73043 L .66655 .75732 L F
.66573 .75934 m .66655 .75732 L .66631 .75794 L F
.68068 .79994 m .68337 .76738 L .67951 .76307 L 0 .494 .261 r
F
.66573 .75934 m .6803 .78513 L .67808 .77378 L 0 .502 .357 r
F
.66415 .7632 m .66549 .75893 L .66496 .76057 L 0 0 .006 r
F
.66489 .76081 m .66496 .76057 L .66493 .76066 L F
.66415 .7632 m .66496 .76057 L .66489 .76081 L F
.66539 .76001 m .67535 .73094 L .67865 .72432 L F
.66465 .76198 m .66506 .76099 L .66493 .76066 L 0 .384 .336 r
F
.66375 .76446 m .66388 .76405 L .66385 .76412 L 0 0 .006 r
F
.65954 .76238 m .6678 .73826 L .6623 .76478 L 0 .006 .099 r
F
.65713 .78532 m .659 .77766 L .65949 .77592 L 0 0 0 r
F
.65709 .78545 m .65712 .78534 L .65713 .78532 L F
.65712 .78534 m .659 .77766 L .65713 .78532 L F
.65901 .77803 m .65949 .77592 L .66024 .77327 L F
.65709 .78545 m .65949 .77592 L .65901 .77803 L F
.65643 .78772 m .659 .77766 L .65709 .78545 L F
.65709 .78545 m .66046 .77243 L .65769 .78255 L F
.66024 .77327 m .6608 .77098 L .66096 .7705 L F
.65592 .78901 m .66096 .7705 L .66122 .76967 L 0 0 .006 r
F
.66192 .76846 m .66122 .76967 L .66716 .75048 L F
.66132 .76949 m .66122 .76967 L .66178 .77073 L 0 .384 .336 r
F
.66167 .76789 m .66178 .77073 L .66225 .76923 L F
.65969 .77497 m .6623 .76478 L .66075 .77117 L 0 0 0 r
F
.65508 .75274 m .66126 .76934 L .66167 .76789 L 0 .384 .336 r
F
.66126 .76934 m .66178 .77073 L .66167 .76789 L F
.659 .77766 m .65969 .77497 L .66024 .77327 L 0 0 0 r
F
.65969 .77497 m .66075 .77117 L .66024 .77327 L F
.65592 .78901 m .66122 .76967 L .66192 .76846 L 0 0 .006 r
F
.65508 .75274 m .66093 .76912 L .66122 .76967 L 0 .384 .336 r
F
.65508 .75274 m .66122 .76967 L .66132 .76949 L F
.66371 .76457 m .66393 .76388 L .66378 .76199 L F
.6636 .76219 m .66378 .76199 L .66335 .75657 L F
.66371 .76457 m .66378 .76199 L .6636 .76219 L F
.66539 .76001 m .67677 .78477 L .6803 .78513 L 0 .502 .357 r
F
.66515 .76035 m .6689 .7483 L .67535 .73094 L 0 0 .006 r
F
.66515 .76036 m .6689 .7483 L .66515 .76035 L F
.66493 .76066 m .6689 .7483 L .66515 .76036 L F
.66493 .76066 m .665 .76082 L .66515 .76035 L 0 .502 .357 r
F
.66502 .76089 m .66951 .77252 L .6652 .76047 L F
.66515 .76035 m .66951 .77252 L .67677 .78477 L F
.66515 .76035 m .67677 .78477 L .66539 .76001 L F
.66543 .76007 m .6803 .78513 L .66573 .75934 L F
.66659 .75725 m .67162 .75831 L .66844 .75296 L F
.66402 .76499 m .66565 .76251 L .66506 .76099 L 0 .384 .336 r
F
.66696 .75629 m .66896 .75156 L .66616 .75909 L 0 0 .006 r
F
.66537 .76103 m .66616 .75909 L .66477 .76283 L F
.66696 .75629 m .66616 .75909 L .66537 .76103 L F
.67128 .7453 m .67398 .74073 L .67142 .74655 L 0 0 .004 r
F
.67128 .7453 m .67142 .74655 L .67034 .74857 L F
.66747 .75509 m .67128 .7453 L .66896 .75156 L 0 0 .006 r
F
.66696 .75629 m .66713 .75587 L .66747 .75509 L F
.66713 .75587 m .67128 .7453 L .66747 .75509 L F
.66517 .7603 m .67535 .73094 L .66539 .76001 L F
.66659 .75725 m .67693 .73043 L .67128 .7453 L F
.66544 .75989 m .67865 .72432 L .66575 .75928 L F
.65961 .74084 m .66155 .72797 L .66039 .74076 L 0 0 .096 r
F
.65961 .74084 m .66014 .73188 L .66166 .72724 L F
.65889 .74091 m .66014 .73188 L .65961 .74084 L F
.66151 .74369 m .66333 .73438 L .66225 .74235 L F
.6596 .74555 m .6628 .72611 L .66151 .74369 L F
.6628 .72611 m .66322 .72529 L .66151 .74369 L F
.66151 .74369 m .66319 .72563 L .66333 .73438 L F
.6678 .73826 m .67043 .74215 L .66716 .75048 L 0 .024 .096 r
F
.67128 .7453 m .6888 .70726 L .68758 .71157 L 0 0 .004 r
F
.67128 .7453 m .68442 .71417 L .6888 .70726 L F
.67128 .7453 m .67693 .73042 L .68442 .71417 L F
.67128 .7453 m .68758 .71157 L .68153 .72433 L F
.68153 .72433 m .68268 .72322 L .67941 .72936 L 0 0 0 r
F
.67128 .7453 m .68153 .72433 L .67588 .73659 L 0 0 .004 r
F
.67284 .74267 m .67588 .73659 L .67398 .74073 L F
.67128 .7453 m .67588 .73659 L .67284 .74267 L F
.67439 .73614 m .67941 .72936 L .68116 .72608 L 0 .925 .15 r
F
.68227 .72386 m .68116 .72608 L .68268 .72322 L F
.67439 .73614 m .68116 .72608 L .68227 .72386 L F
.65438 .72432 m .66993 .74684 L .6701 .74685 L 0 .528 .39 r
F
.65438 .72432 m .6701 .74685 L .67043 .74603 L F
.67049 .74586 m .67106 .74688 L .67113 .74671 L F
.65438 .72432 m .67043 .74603 L .67049 .74586 L F
.67043 .74603 m .67106 .74688 L .67049 .74586 L F
.67171 .74544 m .67127 .74689 L .67142 .74655 L 0 .922 .139 r
F
.67176 .74533 m .67142 .74655 L .67398 .74073 L F
.67171 .74544 m .67142 .74655 L .67176 .74533 L F
.66004 .72845 m .66166 .72724 L .66014 .73188 L 0 .243 .161 r
F
.66319 .72563 m .6635 .72523 L .66333 .73438 L 0 0 .096 r
F
.6678 .73826 m .67619 .7199 L .67043 .74215 L 0 .024 .096 r
F
.65438 .72432 m .67199 .74453 L .67165 .73771 L 0 .528 .39 r
F
.67232 .7439 m .67171 .74544 L .67398 .74073 L 0 .922 .139 r
F
.65438 .72432 m .67127 .74689 L .67199 .74453 L 0 .528 .39 r
F
.67043 .74603 m .6701 .74685 L .67106 .74688 L F
.66335 .75657 m .66493 .76066 L .66515 .76035 L 0 .502 .357 r
F
.66335 .75657 m .66515 .76035 L .66539 .76001 L F
.66335 .75657 m .66523 .75973 L .66545 .75902 L F
.66335 .75657 m .66573 .75934 L .66659 .75725 L F
.66335 .75657 m .66659 .75725 L .66436 .74609 L F
.66659 .75725 m .66696 .75629 L .66683 .75667 L 0 0 .006 r
F
.66659 .75725 m .66838 .75286 L .66436 .74609 L 0 .502 .357 r
F
.66393 .76388 m .66493 .76066 L .66335 .75657 L 0 .384 .336 r
F
.66151 .74369 m .66225 .74235 L .65954 .76238 L 0 0 .096 r
F
.65508 .75274 m .66217 .76607 L .66291 .76347 L 0 .384 .336 r
F
.65508 .75274 m .66371 .76457 L .66335 .75657 L F
.65508 .75274 m .66192 .76846 L .66271 .76708 L F
.6547 .75419 m .65503 .75376 L .65494 .76328 L 0 0 .086 r
F
.6468 .74619 m .65996 .77392 L .66093 .76912 L 0 .289 .306 r
F
.6547 .75419 m .65449 .75413 L .65505 .75147 L 0 0 .086 r
F
.6547 .75419 m .65505 .75147 L .65503 .75376 L F
.6468 .74619 m .66093 .76912 L .65508 .75274 L 0 .289 .306 r
F
.65438 .72432 m .66146 .73711 L .66993 .74684 L 0 .528 .39 r
F
.67034 .74857 m .67142 .74655 L .67127 .74689 L 0 0 .004 r
F
.67162 .75831 m .67414 .747 L .67127 .74689 L 0 .611 .374 r
F
.67027 .74882 m .67127 .74689 L .67024 .74894 L 0 0 .004 r
F
.67034 .74857 m .67127 .74689 L .67027 .74882 L F
.67024 .74894 m .67127 .74689 L .66993 .74684 L 0 .611 .374 r
F
.67162 .75831 m .67127 .74689 L .67024 .74894 L F
.67024 .74894 m .67127 .74689 L .67 .74976 L 0 0 .004 r
F
.65557 .7759 m .67199 .74453 L .67174 .74132 L 0 .922 .139 r
F
.67199 .74453 m .67398 .74073 L .67256 .7411 L F
.67199 .74453 m .67217 .74345 L .67165 .73771 L 0 .528 .39 r
F
.6723 .74489 m .67315 .74329 L .67276 .74183 L F
.68153 .72433 m .69632 .69896 L .68994 .71016 L 0 0 0 r
F
.68153 .72433 m .68994 .71016 L .68268 .72322 L F
.67619 .7199 m .67865 .72432 L .67535 .73094 L 0 .024 .09 r
F
.68994 .71016 m .69088 .7093 L .68759 .71463 L 0 0 0 r
F
.67637 .72869 m .68759 .71463 L .69088 .7093 L 0 .938 .161 r
F
.67635 .72872 m .68759 .71463 L .67637 .72869 L F
.67602 .72938 m .68759 .71463 L .67632 .72877 L F
.67509 .73318 m .68268 .72322 L .67965 .72525 L 0 .925 .15 r
F
.67503 .73344 m .68268 .72322 L .67509 .73318 L F
.67445 .73271 m .67426 .73635 L .67509 .73318 L 0 .654 .412 r
F
.66411 .72516 m .67325 .73523 L .67445 .73271 L F
.67325 .73523 m .67426 .73635 L .67445 .73271 L F
.67602 .72938 m .67965 .72525 L .68759 .71463 L 0 .938 .161 r
F
.66411 .72516 m .67445 .73271 L .67204 .72439 L 0 .654 .412 r
F
.67445 .73271 m .67472 .73211 L .67204 .72439 L F
.67472 .73211 m .67567 .73005 L .67204 .72439 L F
.67509 .73318 m .67567 .73005 L .67472 .73211 L F
.67445 .73271 m .67509 .73318 L .67472 .73211 L F
.6722 .74379 m .67252 .74264 L .67165 .73771 L 0 .528 .39 r
F
.67252 .74264 m .67274 .74177 L .67165 .73771 L F
.66155 .72797 m .66166 .72724 L .66275 .72643 L 0 0 .096 r
F
.66004 .72845 m .66166 .72724 L .6599 .72219 L 0 .397 .243 r
F
.6628 .72611 m .66358 .72144 L .66322 .72529 L 0 0 .096 r
F
.66319 .72563 m .66358 .72144 L .6635 .72523 L F
.6628 .72611 m .6635 .72523 L .66262 .70518 L 0 .195 .208 r
F
.65438 .72432 m .67165 .73771 L .66411 .72516 L 0 .528 .39 r
F
.67371 .73784 m .67328 .73893 L .67941 .72936 L 0 .925 .15 r
F
.67426 .73635 m .67392 .7386 L .67441 .73651 L 0 .654 .412 r
F
.66411 .72516 m .67354 .73809 L .67426 .73635 L F
.67354 .73809 m .67392 .7386 L .67426 .73635 L F
.67354 .73809 m .67328 .73893 L .67371 .73784 L 0 .925 .15 r
F
.67309 .7392 m .67328 .73893 L .67354 .73809 L F
.66411 .72516 m .67165 .73771 L .67306 .73926 L 0 .654 .412 r
F
.67309 .7392 m .67306 .73926 L .67328 .73893 L 0 .925 .15 r
F
.67354 .73809 m .67306 .73926 L .67988 .74678 L 0 .654 .412 r
F
.66411 .72516 m .67306 .73926 L .67354 .73809 L F
.66475 .75119 m .67175 .74132 L .67306 .73926 L 0 .925 .15 r
F
.66475 .75119 m .67306 .73926 L .67309 .7392 L F
.66475 .75119 m .67309 .7392 L .67354 .73809 L F
.66475 .75119 m .67527 .73286 L .67229 .73413 L F
.67527 .73286 m .67965 .72525 L .67605 .7296 L F
.67575 .72996 m .67965 .72525 L .67602 .72938 L 0 .938 .161 r
F
.67426 .73635 m .68268 .72322 L .67502 .73345 L 0 .925 .15 r
F
.67371 .73784 m .67941 .72936 L .67439 .73614 L F
.68994 .71016 m .69841 .6979 L .69088 .7093 L 0 0 0 r
F
.67686 .72729 m .69088 .7093 L .6876 .71122 L 0 .938 .161 r
F
.67204 .72439 m .67567 .73005 L .67586 .72927 L 0 .745 .426 r
F
.67527 .73286 m .67605 .7296 L .67567 .73005 L 0 .925 .15 r
F
.67599 .72942 m .67575 .72996 L .67602 .72938 L 0 .938 .161 r
F
.67585 .7297 m .67575 .72996 L .67599 .72942 L F
.67567 .73005 m .67575 .72996 L .67592 .72951 L F
.67567 .73005 m .67996 .73673 L .67597 .72946 L 0 .745 .426 r
F
.67567 .73005 m .67597 .72946 L .67586 .72927 L F
.67592 .72951 m .67585 .7297 L .67599 .72942 L 0 .938 .161 r
F
.67204 .72439 m .67599 .72942 L .67633 .72874 L 0 .745 .426 r
F
.67678 .72742 m .67633 .72874 L .67686 .72729 L 0 .938 .161 r
F
.67651 .72826 m .69088 .7093 L .67686 .72729 L F
.67633 .72874 m .67637 .72869 L .67651 .72826 L F
.67637 .72869 m .69088 .7093 L .67651 .72826 L F
.6779 .72308 m .6876 .71122 L .67989 .71916 L F
.67204 .72439 m .67673 .72738 L .6779 .72308 L 0 .745 .426 r
F
.67673 .72738 m .67678 .72742 L .6779 .72308 L F
.67204 .72439 m .67633 .72874 L .67678 .72742 L F
.67229 .73413 m .6779 .72308 L .67187 .72986 L 0 .938 .161 r
F
.67204 .72439 m .6779 .72308 L .67146 .71401 L 0 .745 .426 r
F
.6779 .72308 m .67989 .71916 L .67845 .72107 L 0 .938 .161 r
F
.67678 .72742 m .6876 .71122 L .6779 .72308 L F
.6779 .72308 m .67998 .72262 L .67845 .72107 L 0 .745 .426 r
F
.67782 .72298 m .67841 .72103 L .67146 .71401 L F
.67881 .71969 m .67913 .71182 L .67606 .71279 L 0 .823 .437 r
F
.67882 .71969 m .67883 .71964 L .67881 .71969 L 0 .974 .175 r
F
.67989 .71916 m .67956 .71727 L .67882 .71969 L F
.67998 .72262 m .67956 .71726 L .67881 .71969 L 0 .823 .437 r
F
.67989 .71916 m .68753 .70581 L .68087 .71345 L 0 .974 .175 r
F
.69841 .6979 m .69914 .69706 L .69583 .70177 L 0 0 0 r
F
.67989 .71916 m .69583 .70177 L .69914 .69706 L 0 .974 .175 r
F
.67989 .71916 m .6876 .71122 L .69583 .70177 L F
.69841 .6979 m .70694 .68709 L .69914 .69706 L 0 0 0 r
F
.67989 .71916 m .69914 .69706 L .6956 .69877 L 0 .974 .175 r
F
.67989 .71916 m .6956 .69877 L .68753 .70581 L F
.67998 .72262 m .68793 .72006 L .68087 .71345 L 0 .823 .437 r
F
.67956 .71726 m .68087 .71345 L .67913 .71182 L F
.67989 .71916 m .68087 .71345 L .68079 .71368 L 0 .974 .175 r
F
.67989 .71916 m .68082 .71351 L .67956 .71726 L F
.67998 .72262 m .68087 .71345 L .67956 .71726 L 0 .823 .437 r
F
.68079 .71368 m .68087 .71345 L .68082 .71351 L 0 .974 .175 r
F
.67956 .71726 m .67913 .71182 L .67882 .71946 L 0 .823 .437 r
F
.67956 .71726 m .68082 .71351 L .67923 .71533 L 0 .974 .175 r
F
.67956 .71726 m .67882 .71946 L .67881 .71969 L 0 .823 .437 r
F
.67881 .71969 m .67923 .71533 L .67628 .72094 L 0 .974 .175 r
F
.67883 .71964 m .67923 .71533 L .67881 .71969 L F
.67956 .71727 m .67923 .71533 L .67882 .71969 L F
.6779 .72308 m .67845 .72107 L .67841 .72103 L 0 .745 .426 r
F
.6779 .72308 m .67841 .72103 L .67782 .72298 L F
.6779 .72308 m .67845 .72107 L .67844 .72109 L 0 .938 .161 r
F
.6779 .72308 m .67844 .72109 L .67187 .72986 L F
.67229 .73413 m .67678 .72742 L .6779 .72308 L F
.6779 .72308 m .67678 .72742 L .6782 .72302 L 0 .745 .426 r
F
.6782 .72302 m .67693 .72751 L .67915 .72281 L F
.67678 .72742 m .67693 .72751 L .6782 .72302 L F
.67678 .72742 m .67633 .72874 L .67693 .72751 L F
.67229 .73413 m .67633 .72874 L .67678 .72742 L 0 .938 .161 r
F
.67605 .72951 m .67996 .73673 L .68847 .74535 L 0 .745 .426 r
F
.67586 .72927 m .67603 .72957 L .67605 .72951 L F
.67603 .72957 m .67996 .73673 L .67605 .72951 L F
.67495 .733 m .67567 .73005 L .67229 .73413 L 0 .925 .15 r
F
.67527 .73286 m .67567 .73005 L .67495 .733 L F
.67441 .73651 m .67988 .74678 L .68332 .74633 L 0 .654 .412 r
F
.67392 .7386 m .67988 .74678 L .67441 .73651 L F
.67509 .73318 m .67581 .73026 L .67567 .73005 L F
.67229 .73413 m .67567 .73005 L .67592 .72951 L 0 .938 .161 r
F
.67395 .73684 m .67426 .73635 L .67466 .73393 L 0 .925 .15 r
F
.67426 .73635 m .67502 .73345 L .67466 .73393 L F
.67509 .73318 m .68332 .74633 L .67996 .73673 L 0 .654 .412 r
F
.67426 .73635 m .68332 .74633 L .67509 .73318 L F
.67633 .72874 m .68847 .74535 L .69191 .7445 L 0 .745 .426 r
F
.67599 .72942 m .67602 .72938 L .67606 .72928 L 0 .938 .161 r
F
.67599 .72942 m .68847 .74535 L .67633 .72874 L 0 .745 .426 r
F
.67592 .72951 m .67599 .72942 L .67619 .72893 L 0 .938 .161 r
F
.67599 .72942 m .67606 .72928 L .67619 .72893 L F
.67602 .72938 m .67632 .72877 L .67619 .72893 L F
.67693 .72751 m .69191 .7445 L .68827 .73475 L 0 .745 .426 r
F
.67633 .72874 m .69191 .7445 L .67693 .72751 L F
.67915 .72281 m .68827 .73475 L .67998 .72262 L F
.67693 .72751 m .68827 .73475 L .67915 .72281 L F
.67619 .72893 m .67635 .72872 L .67637 .72869 L 0 .938 .161 r
F
.67229 .73413 m .67592 .72951 L .67619 .72893 L F
.67509 .73318 m .67996 .73673 L .67581 .73026 L 0 .654 .412 r
F
.67466 .73393 m .67503 .73344 L .67509 .73318 L 0 .925 .15 r
F
.66475 .75119 m .67395 .73684 L .67466 .73393 L F
.67252 .74264 m .67276 .74183 L .67274 .74177 L 0 .528 .39 r
F
.6723 .74489 m .67276 .74183 L .6722 .74379 L F
.65557 .7759 m .66978 .75017 L .67182 .74514 L 0 .922 .139 r
F
.67199 .74453 m .67182 .74514 L .67232 .7439 L F
.65557 .7759 m .67182 .74514 L .67199 .74453 L F
.67199 .74453 m .67256 .7411 L .67174 .74132 L F
.67199 .74453 m .6722 .74379 L .67217 .74345 L 0 .528 .39 r
F
.67199 .74453 m .6723 .74489 L .6722 .74379 L F
.67199 .74453 m .67127 .74689 L .6723 .74489 L F
.67171 .74544 m .67 .74976 L .67127 .74689 L 0 .922 .139 r
F
.66475 .75119 m .67371 .73784 L .67439 .73614 L 0 .925 .15 r
F
.67113 .74671 m .67106 .74688 L .67127 .74689 L 0 .528 .39 r
F
.6723 .74489 m .67127 .74689 L .67414 .747 L F
.6723 .74489 m .67414 .747 L .67315 .74329 L F
.66978 .75017 m .67 .74976 L .67232 .7439 L 0 .922 .139 r
F
.66659 .75725 m .66844 .75296 L .66838 .75286 L 0 .502 .357 r
F
.66402 .76499 m .66506 .76099 L .66465 .76198 L 0 .384 .336 r
F
.66415 .7632 m .66493 .76066 L .66403 .76354 L 0 0 .006 r
F
.66402 .76499 m .66493 .76066 L .66393 .76388 L 0 .384 .336 r
F
.66331 .76402 m .66271 .76708 L .66371 .76457 L F
.66371 .76458 m .66375 .76446 L .66355 .76498 L 0 0 .006 r
F
.66356 .76495 m .66659 .75725 L .66477 .76283 L F
.66659 .75725 m .66683 .75667 L .66477 .76283 L F
.665 .76082 m .66502 .76089 L .66518 .76044 L 0 .502 .357 r
F
.66502 .76089 m .6652 .76047 L .66518 .76044 L F
.665 .76082 m .66518 .76044 L .66515 .76035 L F
.66543 .75995 m .66543 .76007 L .66553 .75983 L F
.66543 .75995 m .66553 .75983 L .66573 .75934 L F
.66356 .76495 m .66539 .76001 L .66575 .75928 L 0 0 .006 r
F
.66539 .76001 m .66544 .75989 L .66567 .75944 L F
.66539 .76001 m .66567 .75944 L .66575 .75928 L F
.66493 .76066 m .66515 .76036 L .66512 .76044 L F
.66512 .76044 m .66515 .76036 L .66515 .76035 L F
.66403 .76354 m .66493 .76066 L .66356 .76495 L F
.66388 .76405 m .66408 .7634 L .66356 .76495 L F
.66356 .76495 m .66493 .76066 L .66512 .76044 L F
.66375 .76446 m .66385 .76412 L .66356 .76495 L F
.66356 .76495 m .66517 .7603 L .66539 .76001 L F
.66545 .75902 m .66543 .75995 L .66573 .75934 L 0 .502 .357 r
F
.66523 .75973 m .66543 .76007 L .66545 .75902 L F
.66631 .75794 m .66649 .75747 L .66659 .75725 L 0 0 .006 r
F
.66355 .76498 m .66375 .76446 L .66356 .76495 L F
.66356 .76495 m .66559 .75969 L .66631 .75794 L F
.66291 .76347 m .66283 .76495 L .66331 .76402 L 0 .384 .336 r
F
.66283 .76495 m .66271 .76708 L .66331 .76402 L F
.66217 .76607 m .66271 .76708 L .66291 .76347 L F
.66225 .76923 m .66178 .77073 L .66796 .78235 L F
.65799 .78251 m .66271 .76708 L .66371 .76457 L 0 0 .006 r
F
.65799 .78251 m .66385 .76415 L .65826 .78163 L F
.66385 .76415 m .66388 .76405 L .65826 .78163 L F
.65826 .78163 m .66371 .76458 L .66355 .76498 L F
.66371 .76457 m .66402 .76499 L .66393 .76388 L 0 .384 .336 r
F
.66402 .76499 m .66951 .77252 L .66565 .76251 L F
.65709 .78545 m .65772 .7824 L .65592 .78901 L 0 0 0 r
F
.65592 .78901 m .66192 .76846 L .66271 .76708 L 0 0 .006 r
F
.66225 .76923 m .66796 .78235 L .66284 .76734 L 0 .384 .336 r
F
.65592 .78901 m .65816 .78178 L .65799 .78251 L 0 0 .006 r
F
.65592 .78901 m .65799 .78251 L .65826 .78163 L F
.65816 .78178 m .66271 .76708 L .65799 .78251 L F
.65592 .78901 m .6573 .78516 L .65433 .79535 L F
.6556 .78956 m .65433 .79535 L .6573 .78516 L 0 1 .139 r
F
.64352 .84032 m .6498 .79194 L .65097 .79007 L 0 0 .086 r
F
.64352 .84032 m .64678 .80509 L .64835 .79301 L F
.64352 .84032 m .64835 .79301 L .64886 .79264 L F
.65069 .79218 m .65092 .79195 L .64659 .82275 L F
.64352 .84032 m .64966 .79204 L .6498 .79194 L F
.64352 .84032 m .64886 .79264 L .64966 .79204 L F
.64654 .81999 m .6492 .80203 L .64659 .82275 L F
.6492 .80203 m .64933 .80233 L .64659 .82275 L F
.65143 .79505 m .6537 .78589 L .6543 .79424 L 0 0 .096 r
F
.6537 .78589 m .65404 .7855 L .6543 .79424 L F
.65402 .78462 m .65422 .7843 L .6543 .79424 L F
.6513 .79094 m .65058 .78837 L .65047 .78858 L 0 .161 .225 r
F
.65044 .78864 m .6513 .79094 L .65047 .78858 L F
.64659 .82275 m .65128 .78936 L .65143 .79505 L 0 0 .086 r
F
.63416 .86471 m .64304 .81445 L .63859 .85593 L 0 .283 .182 r
F
.64179 .82527 m .65395 .79627 L .6556 .78956 L 0 1 .139 r
F
.65395 .79627 m .65433 .79535 L .6556 .78956 L F
.64935 .81493 m .6498 .81314 L .64992 .81246 L 0 0 0 r
F
.6498 .81314 m .65592 .78901 L .65129 .80711 L F
.6498 .81314 m .65129 .80711 L .64992 .81246 L F
.64838 .81915 m .64991 .81306 L .64935 .81493 L F
.64179 .82527 m .6477 .81251 L .6539 .79649 L 0 1 .139 r
F
.65395 .79627 m .6539 .79649 L .65433 .79535 L F
.64179 .82527 m .6539 .79649 L .65395 .79627 L F
.64991 .81306 m .65592 .78901 L .6498 .81314 L 0 0 0 r
F
.64943 .81466 m .6498 .81314 L .64935 .81493 L F
.64991 .81306 m .6498 .81314 L .64943 .81466 L F
.65011 .81341 m .65101 .80935 L .65082 .80999 L F
.6481 .82315 m .65017 .81351 L .65011 .81341 L F
.64994 .81312 m .65471 .79441 L .65525 .79259 L F
.64991 .81306 m .65525 .79259 L .65592 .78901 L F
.64838 .81915 m .65017 .81218 L .64994 .81312 L F
.64838 .81915 m .64994 .81312 L .64991 .81306 L F
.65017 .81218 m .65471 .79441 L .64994 .81312 L F
.64994 .81312 m .65525 .79259 L .64991 .81306 L F
.65587 .78858 m .65879 .77666 L .65588 .78856 L F
.6498 .79194 m .65039 .79099 L .6483 .78289 L 0 .161 .225 r
F
.64873 .79215 m .64834 .79298 L .64835 .79301 L F
.64873 .79215 m .64835 .79301 L .64886 .79264 L F
.65012 .81949 m .6568 .85704 L .65033 .81848 L 0 .996 .115 r
F
.65587 .78858 m .65565 .78892 L .65879 .77666 L 0 0 0 r
F
.65097 .79007 m .65128 .78936 L .65092 .79195 L 0 0 .086 r
F
.65097 .79007 m .65092 .79195 L .65069 .79218 L F
.64441 .80129 m .64452 .80022 L .64655 .79676 L 0 .729 .063 r
F
.64452 .80022 m .6466 .79616 L .64655 .79676 L F
.64414 .76998 m .64396 .77002 L .6442 .77002 L 0 1 .486 r
F
.64385 .77005 m .64411 .76999 L .64426 .77097 L 0 .283 .182 r
F
.64347 .76961 m .64316 .77005 L .64396 .77002 L 0 1 .486 r
F
.64347 .76961 m .64396 .77002 L .64414 .76998 L F
.64385 .77005 m .64396 .769 L .64411 .76999 L 0 .283 .182 r
F
.64347 .76961 m .6442 .77002 L .64427 .77001 L 0 1 .486 r
F
.64358 .76946 m .64347 .76961 L .64427 .77001 L F
.64358 .76946 m .64427 .77001 L .64438 .76992 L F
.64426 .77097 m .64396 .769 L .64431 .76886 L 0 .283 .182 r
F
.64446 .76918 m .64431 .76886 L .6445 .76878 L F
.64446 .76918 m .64423 .76928 L .64453 .76998 L 0 .385 .231 r
F
.64426 .77097 m .64431 .76886 L .64446 .76918 L 0 .283 .182 r
F
.64436 .76896 m .64485 .76853 L .6445 .76877 L 0 1 .317 r
F
.64447 .76921 m .64452 .76864 L .64447 .76868 L 0 .385 .231 r
F
.64447 .76937 m .64448 .76923 L .64447 .76921 L F
.64446 .76918 m .6445 .76878 L .64452 .7691 L 0 .283 .182 r
F
.64448 .76923 m .64452 .76864 L .64447 .76921 L 0 .385 .231 r
F
.63219 .7629 m .64438 .76992 L .64528 .77165 L 0 1 .486 r
F
.633 .76346 m .64043 .7709 L .64283 .77031 L F
.63219 .7629 m .63325 .76393 L .633 .76346 L F
.63325 .76393 m .64043 .7709 L .633 .76346 L F
.635 .85213 m .64043 .7709 L .63481 .85832 L 0 .283 .182 r
F
.63219 .7629 m .64528 .77165 L .64221 .7748 L 0 1 .486 r
F
.65047 .78858 m .65058 .78837 L .64349 .76853 L 0 .161 .225 r
F
.64451 .78485 m .64576 .79159 L .64675 .79446 L 0 .996 .115 r
F
.64576 .79159 m .64672 .79454 L .64675 .79446 L F
.64672 .79454 m .64683 .79489 L .64675 .79446 L F
.64672 .79591 m .64681 .79481 L .64678 .79566 L 0 .729 .063 r
F
.64681 .79481 m .64683 .79489 L .64678 .79566 L F
.64655 .79676 m .6466 .79616 L .64672 .79591 L F
.64352 .77009 m .65044 .78864 L .64349 .76853 L 0 .161 .225 r
F
.65044 .78864 m .65047 .78858 L .64349 .76853 L F
.64738 .78691 m .64701 .78856 L .64834 .79298 L F
.64738 .78691 m .64834 .79298 L .64873 .79215 L F
.64304 .8142 m .64441 .80129 L .64655 .79676 L 0 .729 .063 r
F
.64355 .77205 m .64886 .79264 L .64353 .77114 L 0 .161 .225 r
F
.64886 .79264 m .64893 .79258 L .64353 .77114 L F
.64353 .77114 m .64893 .79258 L .6498 .79194 L F
.6492 .80203 m .65097 .79007 L .64933 .80233 L 0 0 .086 r
F
.64453 .80681 m .64678 .79566 L .6439 .81548 L 0 .729 .063 r
F
.64453 .80681 m .6439 .81548 L .64353 .81799 L F
.64306 .81398 m .64404 .80181 L .64305 .81404 L F
.64404 .80181 m .64404 .8018 L .64305 .81404 L F
.65086 .78917 m .65109 .7898 L .65186 .78802 L 0 .161 .225 r
F
.65109 .7898 m .65186 .78803 L .65186 .78802 L F
.65008 .78698 m .65086 .78917 L .65158 .78698 L F
.65086 .78917 m .65186 .78802 L .65158 .78698 L F
.6537 .78589 m .65402 .78462 L .65404 .7855 L 0 0 .096 r
F
.65143 .79505 m .65259 .78661 L .65271 .78655 L F
.65113 .78151 m .65316 .78599 L .65402 .78462 L 0 .285 .282 r
F
.65261 .78691 m .65262 .78696 L .65283 .78655 L F
.65143 .79505 m .65283 .78655 L .65322 .78594 L 0 0 .096 r
F
.65113 .78151 m .65257 .78677 L .65283 .78655 L 0 .285 .282 r
F
.65265 .78698 m .65269 .78667 L .65276 .78698 L 0 0 .096 r
F
.65269 .78667 m .6527 .78666 L .65276 .78698 L F
.6527 .78663 m .65282 .78656 L .65276 .78698 L F
.66371 .76457 m .66284 .76733 L .66392 .76487 L 0 .384 .336 r
F
.66284 .76733 m .67149 .78358 L .66392 .76487 L F
.65995 .77395 m .65992 .774 L .65996 .77392 L 0 0 0 r
F
.65276 .78698 m .65282 .78656 L .65283 .78655 L 0 0 .096 r
F
.65143 .79505 m .65265 .78698 L .65276 .78698 L F
.64842 .78234 m .65008 .78698 L .64933 .77846 L 0 .161 .225 r
F
.65008 .78698 m .65158 .78698 L .64933 .77846 L F
.65996 .77392 m .66107 .77001 L .66093 .76912 L 0 .289 .306 r
F
.6608 .77098 m .66107 .77001 L .66096 .7705 L 0 0 0 r
F
.65063 .73081 m .65128 .73537 L .65155 .73413 L 0 .32 .232 r
F
.64861 .74519 m .64876 .74336 L .65049 .74414 L 0 .729 .063 r
F
.64876 .74336 m .6508 .7376 L .65049 .74414 L F
.64912 .74187 m .64916 .74224 L .6493 .74185 L 0 0 .119 r
F
.65058 .73044 m .64912 .74187 L .65063 .73081 L F
.64306 .67553 m .64906 .74121 L .65058 .73044 L F
.64906 .74121 m .64912 .74187 L .65058 .73044 L F
.64446 .76657 m .6445 .76621 L .64412 .71776 L 0 .385 .231 r
F
.64442 .76873 m .64447 .76868 L .64412 .71776 L F
.64111 .72002 m .64439 .76715 L .64446 .73336 L 0 .44 .248 r
F
.64439 .76715 m .6445 .76876 L .6445 .76621 L F
.64439 .76715 m .6445 .76621 L .64446 .73336 L F
.64447 .76868 m .64452 .76864 L .6445 .76621 L 0 .385 .231 r
F
.64447 .76868 m .6445 .76621 L .64446 .76657 L F
.64271 .74611 m .65024 .76832 L .6538 .77233 L 0 .205 .26 r
F
.63849 .73615 m .64277 .74785 L .64271 .74611 L F
.64277 .74785 m .65024 .76832 L .64271 .74611 L F
.64197 .76594 m .64355 .77205 L .64353 .77114 L 0 .161 .225 r
F
.64355 .77205 m .64638 .78646 L .64701 .78856 L F
.64355 .77205 m .64701 .78856 L .64738 .78691 L F
.65186 .78803 m .65192 .78826 L .65189 .78797 L F
.65128 .78936 m .65232 .78698 L .65143 .79505 L 0 0 .086 r
F
.64933 .77846 m .65186 .78803 L .65113 .78151 L 0 .161 .225 r
F
.65186 .78803 m .65189 .78797 L .65113 .78151 L F
.65192 .78826 m .65245 .78756 L .65113 .78151 L F
.65143 .79505 m .65306 .78675 L .6537 .78589 L 0 0 .096 r
F
.64927 .63213 m .64929 .63213 L .64934 .63203 L 0 1 .516 r
F
.64929 .63213 m .64935 .63216 L .64934 .63203 L F
.64909 .63237 m .6599 .72219 L .64934 .63203 L 0 .195 .208 r
F
.64908 .63203 m .64927 .63213 L .64934 .63203 L 0 1 .516 r
F
.64197 .76594 m .64356 .77335 L .64355 .77205 L 0 .161 .225 r
F
.64356 .77335 m .64638 .78646 L .64355 .77205 L F
.64349 .76853 m .64842 .78234 L .64933 .77846 L F
.64197 .76594 m .64352 .77009 L .64349 .76853 L F
.64527 .76948 m .64639 .76744 L .64485 .76853 L 0 1 .317 r
F
.64342 .76344 m .65113 .78151 L .6449 .76089 L 0 .161 .225 r
F
.64197 .76594 m .64349 .76853 L .64342 .76344 L F
.64438 .76992 m .64458 .77012 L .64528 .77165 L 0 1 .486 r
F
.64438 .76992 m .64443 .76939 L .64442 .76988 L 0 .283 .182 r
F
.64442 .76988 m .64443 .76939 L .64446 .76984 L F
.64446 .76918 m .64452 .76914 L .64447 .7693 L F
.64443 .76939 m .64446 .76918 L .64447 .7693 L F
.64449 .76914 m .64452 .7691 L .64452 .76864 L 0 .385 .231 r
F
.64442 .76873 m .64447 .76937 L .64447 .76868 L F
.64349 .76853 m .65113 .78151 L .64342 .76344 L 0 .161 .225 r
F
.64475 .78927 m .64496 .79043 L .64472 .78705 L 0 .996 .115 r
F
.64496 .79043 m .64512 .78998 L .64472 .78705 L F
.64477 .79096 m .64492 .78902 L .64477 .79096 L 0 .729 .063 r
F
.64451 .78485 m .64675 .79446 L .64401 .78754 L 0 .996 .115 r
F
.64451 .78485 m .64401 .78754 L .64283 .78456 L F
.64389 .78433 m .64401 .78754 L .64587 .79223 L 0 .001 .148 r
F
.64601 .79183 m .64587 .79223 L .64675 .79446 L F
.64389 .78433 m .64587 .79223 L .64601 .79183 L F
.63439 .77261 m .63439 .77295 L .63438 .77295 L 0 .306 .198 r
F
.63437 .77297 m .63439 .77261 L .63438 .77295 L F
.63439 .77259 m .6344 .77294 L .63439 .77295 L F
.63434 .77151 m .63441 .77223 L .63441 .77153 L 0 .389 .233 r
F
.63434 .77151 m .6344 .77262 L .63439 .77153 L 0 .371 .225 r
F
.63439 .77249 m .63441 .77255 L .63439 .77259 L 0 .306 .198 r
F
.63439 .77261 m .63439 .77249 L .63439 .77259 L F
.63434 .77151 m .63428 .77302 L .63439 .77249 L 0 .371 .225 r
F
.6344 .77296 m .63442 .77299 L .63443 .77294 L 0 1 .479 r
F
.63402 .83406 m .6344 .77294 L .63605 .81115 L 0 .306 .198 r
F
.6344 .77262 m .63442 .77296 L .63442 .77271 L 0 .371 .225 r
F
.63441 .77282 m .63443 .77288 L .63442 .77298 L 0 .625 .212 r
F
.6344 .77294 m .63441 .77248 L .63442 .77292 L 0 .306 .198 r
F
.6344 .77296 m .63443 .77294 L .63443 .77291 L 0 1 .479 r
F
.6344 .77296 m .63443 .77291 L .6344 .77294 L F
.6344 .77294 m .63442 .77292 L .63605 .81115 L 0 .306 .198 r
F
.63441 .77267 m .63444 .77275 L .63442 .77275 L 0 .625 .212 r
F
.63443 .77275 m .63444 .77265 L .6344 .77276 L 0 .689 .233 r
F
.63441 .77248 m .63442 .77248 L .63605 .81115 L 0 .306 .198 r
F
.63442 .77275 m .63444 .77275 L .63443 .77288 L 0 .625 .212 r
F
.6344 .77294 m .63443 .77291 L .63519 .7679 L 0 1 .479 r
F
.61993 .62016 m .62992 .76651 L .63174 .76884 L 0 .389 .233 r
F
.63114 .76805 m .63439 .77295 L .63519 .7679 L 0 1 .479 r
F
.63439 .77295 m .6344 .77294 L .63519 .7679 L F
.63114 .76805 m .63519 .7679 L .6329 .76408 L F
.63219 .7629 m .64221 .7748 L .6376 .77214 L 0 1 .486 r
F
.63293 .76429 m .6376 .77214 L .63691 .77174 L F
.63219 .7629 m .6376 .77214 L .63293 .76429 L F
.64183 .77924 m .64283 .78456 L .64401 .78754 L 0 .001 .148 r
F
.63278 .74492 m .64123 .77824 L .64183 .77924 L F
.64123 .77824 m .64283 .78456 L .64183 .77924 L F
.63278 .74492 m .64401 .78754 L .64389 .78433 L F
.6437 .77829 m .64675 .79446 L .64638 .78646 L F
.63278 .74492 m .64389 .78433 L .6437 .77829 L F
.64389 .78433 m .64675 .79446 L .6437 .77829 L F
.63278 .74492 m .6437 .77829 L .64197 .76594 L F
.6437 .77829 m .64638 .78646 L .64356 .77335 L F
.6437 .77829 m .64356 .77335 L .64197 .76594 L F
.64352 .77009 m .64777 .78519 L .6483 .78289 L 0 .161 .225 r
F
.64197 .76594 m .64353 .77114 L .64352 .77009 L F
.64353 .77114 m .64777 .78519 L .64352 .77009 L F
.64397 .80166 m .64397 .80166 L .64306 .81398 L 0 .729 .063 r
F
.64306 .81391 m .64477 .79096 L .64306 .81398 L F
.64477 .79096 m .64477 .79096 L .64306 .81398 L F
.64097 .85775 m .64229 .85145 L .64206 .85249 L 0 0 0 r
F
.63899 .87556 m .64635 .8337 L .6443 .84266 L 0 .717 .051 r
F
.63372 .90821 m .63852 .88008 L .63899 .87556 L F
.63852 .88008 m .64645 .83348 L .63899 .87556 L F
.62093 1.1529 m .62179 1.14584 L .62187 1.14168 L 0 1 .208 r
F
.62179 1.14584 m .6326 1.05759 L .62187 1.14168 L F
.62093 1.1529 m .6251 1.15182 L .62828 1.13366 L F
.62834 1.12815 m .62828 1.13366 L .63052 1.12088 L F
.62093 1.1529 m .62828 1.13366 L .62834 1.12815 L F
.6288 1.10997 m .63052 1.12088 L .63317 1.08616 L F
.62093 1.1529 m .62856 1.12744 L .6288 1.10997 L F
.62856 1.12744 m .63052 1.12088 L .6288 1.10997 L F
.63326 1.08282 m .63317 1.08616 L .63356 1.08108 L F
.62093 1.1529 m .63317 1.08616 L .63326 1.08282 L F
.62693 1.35797 m .62705 1.3353 L .62751 1.3223 L 0 .01 .121 r
F
.62705 1.3353 m .62753 1.31591 L .62751 1.3223 L F
.62693 1.35797 m .62751 1.3223 L .62734 1.36609 L F
.62991 1.17306 m .62976 1.19824 L .63042 1.16194 L 0 .995 .099 r
F
.62387 1.30666 m .6294 1.2048 L .62991 1.17306 L F
.6294 1.2048 m .62976 1.19824 L .62991 1.17306 L F
.62976 1.19824 m .63063 1.1822 L .63042 1.16194 L F
.63063 1.1822 m .63075 1.17987 L .6316 1.13568 L F
.63681 .90135 m .63582 .91289 L .63881 .88665 L 0 .772 .081 r
F
.63482 .91593 m .63562 .91349 L .63681 .90135 L F
.63562 .91349 m .63582 .91289 L .63681 .90135 L F
.63431 .92331 m .63582 .91289 L .63482 .91593 L F
.63559 .90354 m .63881 .88665 L .63792 .88462 L F
.63482 .91593 m .63881 .88665 L .63559 .90354 L F
.62834 1.09527 m .62835 1.09489 L .62835 1.09504 L 0 .321 .207 r
F
.62093 1.1529 m .63326 1.08282 L .6326 1.05759 L 0 1 .208 r
F
.63326 1.08282 m .63356 1.08108 L .63341 1.07742 L F
.63326 1.08282 m .63341 1.07742 L .6326 1.05759 L F
.62712 1.32212 m .62715 1.30366 L .62725 1.29885 L 0 .01 .121 r
F
.62387 1.30666 m .62991 1.17306 L .63063 1.13488 L 0 .995 .099 r
F
.62991 1.17306 m .63332 1.09768 L .63063 1.13488 L F
.62688 1.36741 m .62695 1.33136 L .62712 1.32212 L 0 .01 .121 r
F
.64045 1.01714 m .63946 1.02653 L .64135 1.01356 L 0 1 .179 r
F
.62828 1.06572 m .63946 1.02653 L .64045 1.01714 L F
.63823 1.02513 m .63956 1.01762 L .6397 1.01713 L 0 .066 .113 r
F
.63823 1.02513 m .63962 1.01612 L .63956 1.01762 L F
.62828 1.06572 m .64045 1.01714 L .64028 1.00343 L 0 1 .179 r
F
.64045 1.01714 m .64135 1.01356 L .64109 1.01109 L F
.64045 1.01714 m .64109 1.01109 L .64028 1.00343 L F
.63438 .77295 m .63439 .77295 L .63406 .82843 L 0 .306 .198 r
F
.63038 .77468 m .6304 .77478 L .63422 .77304 L 0 1 .479 r
F
.63031 .77479 m .63031 .77471 L .63437 .77297 L 0 .306 .198 r
F
.63031 .77471 m .63035 .77361 L .63437 .77297 L F
.63422 .77304 m .6304 .77478 L .63427 .77306 L 0 1 .479 r
F
.63025 .77133 m .6302 .77133 L .63033 .77361 L 0 .371 .225 r
F
.63025 .77133 m .63033 .77361 L .63035 .77361 L F
.62934 .80588 m .62857 .8045 L .63027 .77473 L 0 .306 .198 r
F
.63031 .77471 m .63027 .77473 L .63036 .77306 L F
.62934 .80588 m .63027 .77473 L .63031 .77471 L F
.6287 .77339 m .62842 .77401 L .63027 .77473 L 0 1 .479 r
F
.63031 .77471 m .63027 .77473 L .6304 .77478 L F
.6287 .77339 m .63027 .77473 L .63031 .77471 L F
.62974 .77116 m .63038 .77468 L .63422 .77304 L F
.63437 .77297 m .63427 .77306 L .63442 .77299 L F
.62974 .77116 m .63427 .77306 L .63437 .77297 L F
.63437 .77297 m .63439 .77295 L .63114 .76805 L F
.63432 .77387 m .63437 .77297 L .63406 .82843 L 0 .306 .198 r
F
.63437 .77297 m .63438 .77295 L .63406 .82843 L F
.63439 .77295 m .6344 .77294 L .63402 .83406 L F
.62544 .93118 m .63031 .77479 L .63437 .77297 L F
.61815 .59064 m .61975 .59655 L .62016 .60157 L 0 .953 .114 r
F
.61975 .59655 m .62438 .61361 L .62016 .60157 L F
.61552 .54149 m .61603 .55121 L .61615 .55273 L 0 .919 .089 r
F
.61993 .62016 m .61999 .62143 L .62 .62145 L 0 .389 .233 r
F
.62219 .66941 m .6241 .70607 L .62 .62147 L 0 .919 .089 r
F
.61999 .62143 m .62412 .70698 L .62 .62145 L 0 .389 .233 r
F
.62 .62145 m .62412 .70698 L .62579 .72467 L F
.61995 .62032 m .62876 .71288 L .63447 .73117 L F
.61993 .62016 m .62579 .72467 L .62679 .72069 L F
.61993 .62016 m .61995 .62044 L .61995 .62032 L F
.61995 .62044 m .63123 .73883 L .61995 .62032 L F
.61196 .60743 m .62315 .62129 L .62039 .62213 L 0 .507 .099 r
F
.62315 .62129 m .62457 .62305 L .62339 .62279 L F
.62315 .62129 m .62339 .62279 L .62039 .62213 L F
.61589 .55443 m .61773 .58842 L .6165 .56015 L 0 .919 .089 r
F
.61773 .58842 m .61808 .59055 L .6165 .56015 L F
.61589 .55443 m .6165 .56015 L .61552 .54149 L F
.61865 .59701 m .6213 .61277 L .61899 .60216 L 0 .953 .114 r
F
.6213 .61277 m .62495 .61713 L .62131 .60835 L 0 .153 .226 r
F
.61648 .61081 m .62131 .60835 L .62172 .60933 L 0 .507 .099 r
F
.62234 .61518 m .62172 .60933 L .62495 .61713 L F
.61648 .61081 m .62172 .60933 L .62234 .61518 L F
.61196 .60743 m .61645 .60787 L .61648 .61081 L F
.61645 .60787 m .62131 .60835 L .61648 .61081 L F
.61865 .59701 m .61899 .60216 L .61591 .58798 L 0 .953 .114 r
F
.61591 .58776 m .61591 .58798 L .61573 .58718 L F
.61865 .59701 m .61591 .58798 L .61591 .58776 L F
.61596 .57877 m .6177 .58299 L .61815 .59064 L F
.61146 .55437 m .61587 .57457 L .61596 .57877 L F
.61587 .57457 m .6177 .58299 L .61596 .57877 L F
.61589 .58062 m .61774 .58842 L .61809 .5937 L F
.61146 .55437 m .61596 .57877 L .61589 .58062 L F
.61596 .57877 m .61774 .58842 L .61589 .58062 L F
.61273 .67314 m .61344 .69714 L .60702 .39285 L 0 .501 .225 r
F
.61314 .6932 m .61344 .69714 L .61335 .71369 L 0 .548 .225 r
F
.61314 .6932 m .61344 .69714 L .61273 .67314 L 0 .501 .225 r
F
.61302 .75253 m .61178 .67633 L .61309 .69253 L 0 .548 .225 r
F
.6 .56133 m .60746 .70495 L .60002 .56186 L 0 1 .156 r
F
.60521 .64131 m .60979 .66109 L .60901 .65402 L 0 .297 .226 r
F
.60356 .6358 m .60901 .65402 L .60605 .64036 L F
.62182 .70237 m .6241 .70365 L .62086 .69589 L 0 0 .148 r
F
.62013 .69418 m .62086 .69589 L .6241 .70365 L 0 .313 0 r
F
.61597 .68411 m .62573 .71678 L .62182 .70237 L 0 0 .133 r
F
.61579 .68368 m .62573 .71678 L .61597 .68411 L F
.61505 .68133 m .61568 .6834 L .61519 .68168 L F
.61568 .6834 m .62573 .71678 L .61579 .68368 L F
.61568 .6834 m .61579 .68368 L .61519 .68168 L F
.61461 .67989 m .62573 .71678 L .61464 .67994 L F
.61465 .68025 m .62573 .71678 L .61455 .67967 L F
.60605 .64036 m .60901 .65402 L .60788 .64373 L 0 .297 .226 r
F
.59973 .56013 m .60113 .58784 L .59979 .56212 L 0 1 .156 r
F
.60113 .58784 m .60356 .6358 L .60111 .58784 L F
.60113 .58784 m .60111 .58784 L .59979 .56212 L F
.60462 .62125 m .60564 .63882 L .60478 .62633 L F
.59979 .56212 m .60356 .6358 L .59982 .56307 L F
.60013 .57314 m .60356 .6358 L .60036 .58066 L F
.60026 .5717 m .60356 .6358 L .60013 .57314 L F
.59532 .43957 m .59582 .46871 L .59533 .43861 L 0 .93 .212 r
F
.59581 .46935 m .59582 .46871 L .59532 .43957 L F
.59371 .43447 m .60414 .60151 L .60462 .62125 L 0 1 .156 r
F
.59104 .38862 m .59376 .43279 L .59371 .43447 L F
.59376 .43279 m .60414 .60151 L .59371 .43447 L F
.59109 .53934 m .59324 .51386 L .59362 .52661 L 0 .265 .185 r
F
.59408 .52082 m .59433 .59426 L .59445 .54704 L 0 .93 .212 r
F
.59356 .47658 m .59487 .55091 L .59503 .55255 L 0 1 .169 r
F
.59356 .47658 m .59365 .48805 L .59487 .55091 L F
.59362 .52661 m .59718 .52585 L .59815 .57456 L 0 .875 .195 r
F
.59366 .50075 m .59368 .49589 L .59351 .46971 L 0 .93 .212 r
F
.59366 .50075 m .59351 .46971 L .59333 .44439 L F
.59163 .51758 m .59299 .50576 L .59109 .53934 L 0 .265 .185 r
F
.59299 .50576 m .59368 .49974 L .59309 .50886 L F
.59299 .50576 m .59309 .50886 L .59109 .53934 L F
.59368 .49974 m .59367 .50703 L .59109 .53934 L F
.59368 .50028 m .59422 .50418 L .59365 .51495 L 0 .875 .195 r
F
.59422 .50418 m .59718 .52585 L .59391 .51575 L F
.59422 .50418 m .59391 .51575 L .59365 .51495 L F
.59362 .52661 m .59815 .57456 L .59364 .52722 L F
.59365 .51495 m .59391 .51575 L .59362 .52661 L F
.59391 .51575 m .59718 .52585 L .59362 .52661 L F
.59185 .53554 m .59362 .52661 L .59283 .55116 L 0 .265 .185 r
F
.59362 .52661 m .59364 .52722 L .59363 .52708 L 0 .875 .195 r
F
.59362 .52661 m .59379 .54185 L .59302 .54925 L 0 .265 .185 r
F
.59362 .52661 m .59302 .54925 L .59283 .55116 L F
.59367 .50703 m .59366 .5088 L .59109 .53934 L F
.58833 .47959 m .58804 .47485 L .5881 .46708 L 0 1 .183 r
F
.59368 .49493 m .59358 .4795 L .59368 .49587 L 0 .93 .212 r
F
.59358 .4795 m .59355 .4742 L .59368 .49587 L F
.59368 .49587 m .59355 .4742 L .59352 .46994 L F
.59117 .51392 m .5929 .47037 L .59306 .4706 L 0 .265 .185 r
F
.59368 .49493 m .59359 .47972 L .59358 .4795 L 0 .93 .212 r
F
.59368 .49587 m .59352 .46994 L .59368 .49589 L F
.59352 .46994 m .59352 .46983 L .59368 .49589 L F
.59368 .49589 m .59352 .46983 L .59351 .46971 L F
.59364 .52722 m .59815 .57456 L .59424 .54688 L 0 .875 .195 r
F
.59364 .52722 m .59424 .54688 L .59381 .54385 L F
.59298 .55089 m .59379 .54274 L .59386 .5493 L 0 .265 .185 r
F
.59364 .52722 m .59381 .54385 L .59363 .52739 L 0 .875 .195 r
F
.59524 .48241 m .5993 .55302 L .59718 .52585 L 0 1 .156 r
F
.59513 .47475 m .5993 .55302 L .59524 .48241 L F
.59386 .5493 m .59815 .57456 L .59477 .56086 L 0 .875 .195 r
F
.59302 .54925 m .59379 .54185 L .59298 .55089 L 0 .265 .185 r
F
.59379 .54185 m .59379 .54263 L .59298 .55089 L F
.5958 .52228 m .59581 .52264 L .59393 .54141 L F
.59393 .54126 m .59393 .54141 L .59298 .55089 L F
.5958 .52228 m .59393 .54141 L .59393 .54126 L F
.58775 .54224 m .58604 .70724 L .5902 .55203 L 0 1 .183 r
F
.58775 .54224 m .5902 .55203 L .59071 .53307 L F
.58604 .70724 m .5887 .73677 L .59071 .53307 L F
.5893 .61223 m .59453 .58466 L .59528 .59621 L 0 .248 .155 r
F
.58928 .60802 m .59453 .58466 L .5893 .61223 L F
.58821 .54615 m .58854 .49604 L .58842 .53056 L 0 1 .183 r
F
.58915 .60039 m .59026 .58602 L .59015 .59538 L 0 0 .088 r
F
.58779 .57789 m .58776 .56545 L .5879 .56907 L 0 1 .183 r
F
.58678 .65284 m .58765 .57559 L .58779 .57789 L F
.58765 .57559 m .58776 .56545 L .58779 .57789 L F
.58429 .60776 m .58509 .58498 L .58431 .60736 L 0 1 .167 r
F
.58668 .65377 m .58789 .55087 L .58678 .65284 L 0 1 .183 r
F
.58789 .55087 m .58791 .55187 L .58678 .65284 L F
.58863 .48826 m .58863 .48827 L .58857 .49356 L F
.58857 .49354 m .58857 .49356 L .58678 .65284 L F
.58863 .48826 m .58857 .49356 L .58857 .49354 L F
.58928 .60802 m .59015 .59538 L .59509 .58216 L 0 .248 .155 r
F
.58849 .46422 m .58883 .47105 L .58604 .70724 L 0 1 .183 r
F
.5879 .56907 m .58807 .53765 L .58821 .54615 L F
.58776 .56545 m .58807 .53765 L .5879 .56907 L F
.58789 .55087 m .58863 .48826 L .58791 .55187 L F
.58807 .53765 m .58854 .49604 L .58821 .54615 L F
.58567 .58499 m .58842 .53056 L .58509 .58498 L 0 1 .167 r
F
.58646 .56261 m .58684 .56193 L .58672 .56423 L 0 .265 .185 r
F
.58604 .70724 m .58668 .65377 L .58678 .65284 L 0 1 .183 r
F
.58604 .70724 m .58842 .53056 L .58596 .61803 L F
.5797 .70334 m .58596 .61803 L .58842 .53056 L 0 1 .167 r
F
.58684 .56193 m .59283 .55116 L .58672 .56423 L 0 .265 .185 r
F
.58672 .56423 m .59283 .55116 L .59026 .58602 L F
.59386 .5493 m .59388 .55421 L .59325 .55973 L F
.59386 .54953 m .59387 .54957 L .59383 .5538 L 0 .875 .195 r
F
.59387 .54957 m .59477 .56086 L .59388 .55421 L F
.59387 .54957 m .59388 .55421 L .59383 .5538 L F
.59283 .55116 m .59386 .5493 L .59325 .55973 L 0 .265 .185 r
F
.59381 .54385 m .59815 .57456 L .59386 .5493 L 0 .875 .195 r
F
.59055 .27163 m .59071 .53307 L .59071 .27174 L 0 1 .183 r
F
.58646 .56261 m .59163 .51758 L .59109 .53934 L 0 .265 .185 r
F
.58833 .47959 m .58824 .48846 L .58804 .47485 L 0 1 .183 r
F
.58824 .48846 m .58796 .48406 L .58804 .47485 L F
.58646 .56261 m .59088 .49932 L .59117 .51392 L 0 .265 .185 r
F
.59507 .47085 m .59513 .47475 L .59367 .44738 L 0 1 .156 r
F
.59367 .44738 m .59513 .47475 L .59524 .48241 L F
.59368 .49359 m .59368 .49335 L .59367 .49139 L 0 .93 .212 r
F
.59369 .49433 m .59369 .4943 L .59368 .49335 L F
.59367 .44738 m .59447 .46521 L .59397 .47191 L 0 1 .156 r
F
.59447 .46521 m .59718 .52585 L .59437 .47862 L F
.59447 .46521 m .59437 .47862 L .59397 .47191 L F
.59304 .36595 m .59343 .37711 L .59156 .28392 L 0 1 .169 r
F
.59124 .27063 m .5934 .38302 L .58946 .30834 L 0 .824 .212 r
F
.59016 .27036 m .58946 .30834 L .59055 .27163 L 0 1 .183 r
F
.58946 .30834 m .5899 .29641 L .59055 .27163 L F
.59124 .27063 m .58946 .30834 L .59016 .27036 L 0 .824 .212 r
F
.58946 .30834 m .5934 .38302 L .58963 .32409 L F
.58977 .33725 m .58936 .37755 L .58946 .30834 L 0 1 .183 r
F
.58936 .37755 m .58902 .36064 L .58946 .30834 L F
.58946 .30834 m .58963 .32409 L .58916 .31677 L 0 .824 .212 r
F
.58893 .42522 m .58897 .42464 L .58922 .40034 L 0 1 .183 r
F
.58918 .40077 m .58922 .40034 L .58951 .37194 L F
.58936 .37755 m .58883 .47105 L .58849 .46422 L F
.58945 .38205 m .58883 .47105 L .58936 .37755 L F
.58984 .34485 m .58952 .38534 L .58977 .33725 L F
.58952 .38534 m .58883 .47105 L .58945 .38205 L F
.58952 .38534 m .58945 .38205 L .58977 .33725 L F
.58646 .56261 m .59382 .48645 L .59368 .49974 L 0 .265 .185 r
F
.59117 .51392 m .59306 .4706 L .59348 .49001 L F
.59088 .49932 m .5929 .47037 L .59117 .51392 L F
.58854 .49604 m .58855 .4969 L .58842 .53056 L 0 1 .183 r
F
.58857 .49356 m .58859 .49699 L .58842 .53056 L F
.58864 .48745 m .58896 .47787 L .58842 .53056 L F
.58509 .58498 m .58842 .53056 L .58863 .50728 L 0 1 .167 r
F
.58928 .44597 m .58928 .44684 L .58842 .53056 L 0 1 .183 r
F
.58646 .56261 m .58863 .50728 L .58902 .50389 L 0 .265 .185 r
F
.58891 .52744 m .58902 .50389 L .5929 .47037 L F
.58646 .56261 m .58902 .50389 L .58891 .52744 L F
.5901 .35785 m .5934 .38302 L .59104 .38862 L 0 .824 .212 r
F
.58977 .33725 m .58945 .38205 L .58936 .37755 L 0 1 .183 r
F
.58992 .35164 m .59022 .33326 L .5901 .35785 L 0 .824 .212 r
F
.58963 .32409 m .59022 .33326 L .58992 .35164 L F
.59022 .33326 m .5934 .38302 L .5901 .35785 L F
.58992 .35164 m .5901 .35785 L .59007 .36614 L F
.5901 .35785 m .59104 .38862 L .59007 .36614 L F
.58984 .34485 m .59007 .36614 L .58883 .47105 L 0 1 .183 r
F
.58584 .26844 m .59007 .36614 L .58601 .34056 L 0 .824 .212 r
F
.59007 .36614 m .59104 .38862 L .58998 .3785 L F
.59 .37575 m .58928 .44684 L .58928 .44597 L 0 1 .183 r
F
.59 .37584 m .58928 .44684 L .59 .37575 L F
.59004 .3719 m .58928 .44684 L .59004 .37168 L F
.59004 .3719 m .59003 .37332 L .58928 .44684 L F
.58906 .40764 m .58875 .392 L .58902 .36064 L F
.58864 .48745 m .58934 .42815 L .58896 .47787 L F
.58934 .42815 m .58954 .41042 L .58935 .43245 L F
.58934 .42815 m .58935 .43245 L .58896 .47787 L F
.59362 .52661 m .59363 .52708 L .58957 .4845 L 0 .875 .195 r
F
.58957 .48427 m .58957 .4845 L .58541 .44081 L F
.59362 .52661 m .58957 .4845 L .58957 .48427 L F
.58541 .44081 m .58961 .49476 L .58532 .44235 L F
.58961 .49476 m .59459 .55859 L .58961 .49623 L F
.58961 .49476 m .58961 .49623 L .58532 .44235 L F
.58954 .41042 m .58972 .39533 L .58955 .41423 L 0 1 .183 r
F
.58935 .43245 m .58936 .43437 L .58896 .47787 L F
.58972 .39533 m .58971 .40456 L .58896 .47787 L F
.58841 .47213 m .5881 .46708 L .58862 .40669 L F
.58546 .44022 m .58957 .48366 L .58541 .44081 L 0 .875 .195 r
F
.58957 .48366 m .59362 .52661 L .58957 .48427 L F
.58957 .48366 m .58957 .48427 L .58541 .44081 L F
.58954 .41042 m .58955 .41423 L .58936 .43437 L 0 1 .183 r
F
.58954 .41042 m .58936 .43437 L .58935 .43245 L F
.58972 .39533 m .5903 .34659 L .58971 .40456 L F
.59153 .48415 m .59154 .48462 L .58959 .47037 L 0 .875 .195 r
F
.58959 .4701 m .58959 .47037 L .58546 .44022 L F
.59153 .48415 m .58959 .47037 L .58959 .4701 L F
.59007 .36614 m .58998 .3785 L .58601 .34056 L 0 .824 .212 r
F
.59004 .37168 m .59 .37584 L .59 .37575 L 0 1 .183 r
F
.5903 .34659 m .59004 .3719 L .59004 .37168 L F
.5899 .33777 m .59014 .35958 L .59007 .36614 L F
.5899 .33777 m .59007 .36614 L .58984 .34485 L F
.58858 .30777 m .58963 .32409 L .58992 .35164 L 0 .824 .212 r
F
.5903 .34659 m .59032 .34581 L .59003 .37332 L 0 1 .183 r
F
.5903 .34659 m .59003 .37332 L .59004 .3719 L F
.59368 .49974 m .5937 .50039 L .59154 .48462 L 0 .875 .195 r
F
.59368 .49974 m .59154 .48462 L .59153 .48415 L F
.58552 .43885 m .59152 .48359 L .58546 .44022 L F
.59152 .48359 m .59368 .49974 L .59153 .48415 L F
.59152 .48359 m .59153 .48415 L .58546 .44022 L F
.59047 .26749 m .58984 .34485 L .58977 .33725 L 0 1 .183 r
F
.59047 .26749 m .59038 .33957 L .59014 .35958 L F
.59047 .26749 m .59014 .35958 L .5899 .33777 L F
.59104 .38862 m .59367 .44738 L .59292 .44856 L 0 1 .156 r
F
.59214 .43104 m .59397 .47191 L .5929 .47037 L 0 .623 .221 r
F
.59367 .44738 m .59397 .47191 L .59261 .44906 L 0 1 .156 r
F
.59331 .43652 m .59507 .47085 L .59367 .44738 L F
.59507 .47085 m .5993 .55302 L .59513 .47475 L F
.59236 .41808 m .59331 .43652 L .59367 .44738 L F
.59285 .42396 m .59384 .44306 L .59292 .42564 L F
.59384 .44306 m .59878 .53806 L .59388 .44401 L F
.59384 .44306 m .59388 .44401 L .59292 .42564 L F
.59273 .42159 m .59285 .42396 L .59272 .42172 L F
.59285 .42396 m .59292 .42564 L .59272 .42172 L F
.59273 .42159 m .59272 .42172 L .59257 .41879 L F
.59502 .46724 m .59878 .53806 L .59927 .55098 L F
.59272 .42176 m .59485 .46271 L .59502 .46724 L F
.59485 .46271 m .59878 .53806 L .59502 .46724 L F
.59368 .49974 m .59397 .47191 L .59718 .52585 L 0 .875 .195 r
F
.59368 .49974 m .59718 .52585 L .5937 .50039 L F
.5958 .52228 m .59674 .51312 L .59581 .52264 L 0 .265 .185 r
F
.59505 .46924 m .59243 .41832 L .59243 .41833 L 0 1 .156 r
F
.59933 .55237 m .59505 .46928 L .59505 .46924 L F
.59505 .46928 m .59243 .41832 L .59505 .46924 L F
.59386 .5493 m .59584 .52524 L .59459 .54799 L 0 .265 .185 r
F
.59933 .55238 m .59505 .46928 L .59933 .55237 L 0 1 .156 r
F
.59505 .46928 m .59243 .41832 L .59505 .46928 L F
.59505 .46928 m .59505 .46928 L .59933 .55237 L F
.59379 .54274 m .59581 .52264 L .59386 .5493 L 0 .265 .185 r
F
.59933 .55238 m .59938 .55418 L .59506 .46967 L 0 1 .156 r
F
.59505 .46928 m .59506 .46967 L .59243 .41832 L F
.59933 .55238 m .59506 .46967 L .59505 .46928 L F
.59257 .41879 m .59404 .44793 L .59243 .41833 L F
.5944 .45486 m .59973 .56013 L .59446 .45784 L F
.60062 .57329 m .60062 .57329 L .59904 .54286 L F
.59927 .55098 m .60023 .56917 L .6003 .57134 L F
.6006 .57607 m .6006 .57609 L .59927 .55098 L F
.6006 .57305 m .6006 .57607 L .59927 .55098 L F
.59766 .49625 m .59954 .48738 L .60414 .60151 L F
.60732 .62103 m .59972 .2729 L .60674 .61384 L 0 .501 .225 r
F
.59973 .56013 m .59933 .55238 L .59933 .55237 L 0 1 .156 r
F
.60085 .55675 m .60462 .62125 L .59994 .55548 L F
.60085 .55675 m .59994 .55548 L .59904 .54284 L F
.5987 .51994 m .60085 .55675 L .59904 .54284 L F
.59973 .56013 m .59979 .56212 L .59938 .55418 L F
.59973 .56013 m .59938 .55418 L .59933 .55238 L F
.59878 .53806 m .59906 .5434 L .59923 .5498 L F
.59878 .53806 m .59923 .5498 L .59927 .55098 L F
.60268 .56434 m .60108 .42116 L .60651 .61103 L 0 .548 .225 r
F
.60108 .42116 m .59944 .2742 L .60647 .60445 L F
.60467 .58855 m .59972 .2729 L .59754 .27329 L 0 .501 .225 r
F
.60674 .61384 m .59972 .2729 L .60467 .58855 L F
.60462 .62125 m .60478 .62633 L .59904 .54284 L 0 1 .156 r
F
.59243 .41832 m .59414 .45169 L .59236 .41808 L F
.59414 .45169 m .59979 .56212 L .59418 .45332 L F
.59414 .45169 m .59418 .45332 L .59236 .41808 L F
.59324 .51386 m .59511 .49159 L .59362 .52661 L 0 .265 .185 r
F
.59272 .42172 m .59388 .44401 L .59272 .42176 L 0 1 .156 r
F
.59388 .44401 m .59878 .53806 L .59389 .44433 L F
.59388 .44401 m .59389 .44433 L .59272 .42176 L F
.59511 .49159 m .59561 .48568 L .59525 .49733 L 0 .265 .185 r
F
.59375 .44096 m .59274 .42135 L .59274 .42135 L 0 1 .156 r
F
.59874 .537 m .59375 .44096 L .59375 .44096 L F
.59375 .44096 m .59274 .42135 L .59375 .44096 L F
.59254 .41435 m .59799 .50777 L .59243 .41538 L F
.59799 .50777 m .59802 .50857 L .59243 .41538 L F
.59276 .42089 m .59802 .50857 L .59273 .42121 L F
.59802 .50857 m .59803 .50879 L .59273 .42121 L F
.59297 .39344 m .5931 .4137 L .59311 .41343 L 0 .93 .212 r
F
.59307 .40742 m .59308 .40904 L .59327 .4188 L 0 1 .169 r
F
.59327 .4188 m .59308 .40904 L .59308 .40927 L F
.59104 .38862 m .59634 .45013 L .59766 .49625 L 0 1 .156 r
F
.59874 .53699 m .59874 .537 L .59375 .44096 L F
.59375 .44096 m .59375 .44096 L .59274 .42135 L F
.59874 .53699 m .59375 .44096 L .59375 .44096 L F
.59874 .537 m .59874 .53702 L .59375 .44097 L F
.59375 .44096 m .59375 .44097 L .59274 .42135 L F
.59874 .537 m .59375 .44097 L .59375 .44096 L F
.59273 .42121 m .59803 .50879 L .59904 .54284 L F
.59273 .42116 m .59375 .44097 L .59263 .41969 L F
.59375 .44097 m .59874 .53702 L .59383 .44272 L F
.59375 .44097 m .59383 .44272 L .59263 .41969 L F
.59525 .49733 m .59574 .48866 L .59571 .5161 L 0 .265 .185 r
F
.59874 .53702 m .59874 .5371 L .59263 .41969 L 0 1 .156 r
F
.59874 .5371 m .59262 .41962 L .59263 .41969 L F
.59874 .53711 m .59262 .41962 L .59874 .5371 L F
.59874 .53711 m .59878 .53806 L .59262 .41962 L F
.59273 .42121 m .59874 .53699 L .59273 .42116 L F
.59979 .56212 m .59982 .56307 L .59236 .41808 L F
.59574 .48866 m .59647 .47551 L .59607 .49678 L 0 .265 .185 r
F
.59574 .48866 m .59607 .49678 L .59571 .5161 L F
.59607 .49678 m .59647 .47551 L .59667 .51127 L F
.59667 .51127 m .59647 .47551 L .59721 .50856 L F
.59571 .5161 m .59607 .49678 L .59667 .51127 L F
.59561 .48568 m .59647 .47551 L .59574 .48866 L F
.59561 .48568 m .59574 .48866 L .59525 .49733 L F
.59511 .49159 m .59525 .49733 L .59362 .52661 L F
.5993 .55302 m .59982 .56307 L .59937 .55672 L 0 1 .156 r
F
.5993 .55302 m .59937 .55672 L .59718 .52585 L F
.59982 .56307 m .60036 .58066 L .59718 .52585 L F
.60467 .58855 m .59754 .27329 L .60268 .56434 L 0 .501 .225 r
F
.59904 .54286 m .6 .56133 L .59906 .5434 L 0 1 .156 r
F
.6 .56133 m .60002 .56186 L .59906 .5434 L F
.59662 .55083 m .60612 .53099 L .6067 .56494 L 0 .547 .201 r
F
.59459 .54799 m .59649 .54519 L .59662 .55083 L F
.59803 .50879 m .59891 .53418 L .59904 .54284 L 0 1 .156 r
F
.59904 .54284 m .59904 .54286 L .59874 .53702 L F
.59904 .54284 m .59874 .53702 L .59874 .537 L F
.59874 .53702 m .59904 .54286 L .59874 .5371 L F
.59904 .54286 m .59874 .53711 L .59874 .5371 L F
.59904 .54286 m .59906 .5434 L .59878 .53806 L F
.59904 .54286 m .59878 .53806 L .59874 .53711 L F
.59874 .53699 m .59904 .54284 L .59874 .537 L F
.59649 .54519 m .60612 .53099 L .59662 .55083 L 0 .547 .201 r
F
.59404 .44793 m .5944 .45486 L .59413 .45126 L 0 1 .156 r
F
.5944 .45486 m .59446 .45784 L .59413 .45126 L F
.59404 .44793 m .59413 .45126 L .59243 .41833 L F
.59362 .52661 m .59525 .49733 L .59571 .5161 L 0 .265 .185 r
F
.59581 .52264 m .59721 .50856 L .59584 .52524 L F
.59581 .52264 m .59584 .52524 L .59386 .5493 L F
.59584 .52524 m .59721 .50856 L .59589 .52848 L F
.59584 .52524 m .59589 .52848 L .59459 .54799 L F
.59674 .51312 m .59721 .50856 L .59675 .51322 L F
.59674 .51312 m .59675 .51322 L .59581 .52264 L F
.59257 .41879 m .59272 .42172 L .59272 .42176 L 0 1 .156 r
F
.59274 .42135 m .59273 .42116 L .59273 .42116 L F
.59274 .42135 m .59273 .42116 L .59274 .42135 L F
.59243 .41538 m .59276 .42089 L .59273 .42121 L F
.59104 .38862 m .59254 .41435 L .59243 .41538 L F
.59273 .42116 m .59273 .42116 L .59217 .41043 L F
.59208 .40917 m .59262 .41962 L .59257 .41879 L F
.59217 .41047 m .59273 .42121 L .59217 .41043 L F
.59273 .42121 m .59273 .42116 L .59217 .41043 L F
.59263 .41969 m .59262 .41962 L .59208 .40917 L F
.59208 .40917 m .59257 .41879 L .59196 .40913 L F
.59257 .41879 m .59243 .41833 L .59196 .40913 L F
.59217 .41043 m .59273 .42116 L .59208 .40917 L F
.59273 .42116 m .59263 .41969 L .59208 .40917 L F
.59464 .39777 m .59481 .4083 L .59481 .40694 L 0 .93 .212 r
F
.59229 .27525 m .59481 .4083 L .59464 .39777 L F
.59481 .4083 m .59501 .40615 L .59485 .39379 L F
.59104 .38862 m .5934 .38302 L .59954 .48738 L 0 1 .156 r
F
.59038 .33957 m .59647 .47551 L .59397 .47191 L 0 .623 .221 r
F
.59104 .38862 m .59292 .44856 L .59214 .43104 L 0 1 .156 r
F
.59243 .41833 m .59243 .41832 L .59196 .40913 L F
.59196 .40913 m .59243 .41832 L .59236 .41808 L F
.59104 .38862 m .59208 .40917 L .59196 .40913 L F
.59107 .38928 m .59217 .41047 L .59107 .38924 L F
.59217 .41047 m .59217 .41043 L .59107 .38924 L F
.59107 .38924 m .59217 .41043 L .59208 .40917 L F
.59038 .33957 m .59397 .47191 L .59214 .43104 L 0 .623 .221 r
F
.59214 .43104 m .59292 .44856 L .59261 .44906 L 0 1 .156 r
F
.59126 .46064 m .59261 .44906 L .59397 .47191 L 0 .875 .195 r
F
.58488 .43405 m .5911 .44614 L .59126 .46064 L F
.5911 .44614 m .59261 .44906 L .59126 .46064 L F
.59348 .49001 m .59306 .4706 L .59451 .47269 L 0 .265 .185 r
F
.59348 .49001 m .59451 .47269 L .59468 .47758 L F
.58488 .43405 m .59397 .47191 L .59368 .49974 L 0 .875 .195 r
F
.59368 .49974 m .59411 .48345 L .59425 .49483 L 0 .265 .185 r
F
.59382 .48645 m .59411 .48345 L .59368 .49974 L F
.59553 .48368 m .59561 .48568 L .59419 .50253 L F
.5942 .50159 m .59419 .50253 L .59366 .5088 L F
.59553 .48368 m .59419 .50253 L .5942 .50159 L F
.59425 .49483 m .59507 .4735 L .59553 .48368 L F
.59411 .48345 m .59507 .4735 L .59425 .49483 L F
.59459 .55859 m .59477 .56086 L .59459 .55866 L 0 .875 .195 r
F
.59459 .55859 m .59459 .55866 L .58532 .44235 L F
.59386 .5493 m .59459 .54799 L .59388 .55421 L 0 .265 .185 r
F
.59283 .55116 m .59325 .55973 L .59026 .58602 L F
.58685 .61879 m .58924 .60183 L .58928 .60802 L 0 .248 .155 r
F
.58924 .60183 m .59015 .59538 L .58928 .60802 L F
.58336 .62708 m .58422 .60411 L .58429 .60776 L 0 1 .167 r
F
.58276 .63966 m .58323 .62573 L .58336 .62708 L F
.5797 .70334 m .58262 .63933 L .58276 .63966 L F
.58262 .63933 m .58323 .62573 L .58276 .63966 L F
.5797 .70334 m .58336 .62708 L .58273 .6364 L F
.5797 .70334 m .5822 .69298 L .58596 .61803 L F
.57868 .66478 m .58273 .6364 L .5826 .62336 L 0 1 .186 r
F
.57287 .72612 m .58019 .6595 L .57868 .66478 L F
.58019 .6595 m .58273 .6364 L .57868 .66478 L F
.57819 .66494 m .5826 .62336 L .57964 .64826 L F
.57809 .66608 m .57822 .66486 L .57819 .66494 L F
.57822 .66486 m .5826 .62336 L .57819 .66494 L F
.57868 .66478 m .5826 .62336 L .57809 .66608 L F
.57287 .72612 m .57994 .67892 L .58273 .6364 L F
.5797 .70334 m .58273 .6364 L .57994 .67892 L 0 1 .167 r
F
.57964 .64826 m .58228 .64566 L .57949 .65789 L 0 0 .088 r
F
.57287 .72612 m .57809 .66608 L .57541 .68662 L 0 1 .186 r
F
.57141 .69026 m .57484 .67699 L .57586 .67279 L 0 .769 .072 r
F
.57819 .66494 m .57964 .64826 L .57757 .66702 L 0 1 .186 r
F
.57528 .67476 m .57586 .67279 L .57949 .65789 L 0 .769 .072 r
F
.57141 .69026 m .57586 .67279 L .57528 .67476 L F
.57809 .66608 m .57819 .66494 L .57746 .66806 L 0 1 .186 r
F
.57819 .66494 m .57757 .66702 L .57746 .66806 L F
.57809 .66608 m .57746 .66806 L .57541 .68662 L F
.57158 .68954 m .57475 .67656 L .57154 .68967 L 0 .769 .072 r
F
.57475 .67656 m .58223 .64587 L .57473 .67661 L F
.58223 .64587 m .58223 .64587 L .57473 .67661 L F
.57637 .66988 m .57949 .65789 L .58145 .64929 L F
.57637 .66988 m .58145 .64929 L .58113 .65035 L F
.57676 .66883 m .57949 .65789 L .57637 .66988 L F
.57598 .67075 m .58113 .65036 L .57959 .65536 L F
.57637 .6699 m .58113 .65036 L .57598 .67075 L F
.57141 .69026 m .58154 .64706 L .57774 .66123 L F
.57789 .66126 m .58425 .64869 L .57922 .66159 L 0 0 .073 r
F
.57778 .66124 m .57803 .66075 L .57789 .66126 L F
.57803 .66075 m .58425 .64869 L .57789 .66126 L F
.57774 .66123 m .57783 .66106 L .57778 .66124 L F
.57783 .66106 m .58425 .64869 L .57778 .66124 L F
.58223 .64587 m .58228 .64566 L .58223 .64587 L 0 .769 .072 r
F
.57475 .67656 m .57473 .67661 L .57154 .68967 L F
.57808 .66059 m .58506 .64496 L .58425 .64869 L 0 0 .073 r
F
.57783 .66106 m .57814 .66037 L .57808 .66059 L F
.57814 .66037 m .58506 .64496 L .57808 .66059 L F
.58113 .65035 m .58145 .64929 L .58228 .64566 L 0 .769 .072 r
F
.57141 .69026 m .57676 .66883 L .57637 .66988 L F
.57154 .68967 m .57637 .6699 L .57598 .67075 L F
.57287 .72612 m .57868 .66478 L .57809 .66608 L 0 1 .186 r
F
.57774 .66123 m .57786 .66098 L .57783 .66106 L 0 0 .073 r
F
.57786 .66098 m .58506 .64496 L .57783 .66106 L F
.57959 .65536 m .58228 .64566 L .58154 .64706 L 0 .769 .072 r
F
.58113 .65036 m .58228 .64566 L .57959 .65536 L F
.57141 .69026 m .57158 .68954 L .57154 .68967 L F
.58066 .65475 m .58487 .64297 L .58506 .64496 L 0 0 .073 r
F
.57801 .66064 m .58078 .6535 L .58066 .65475 L F
.58078 .6535 m .58487 .64297 L .58066 .65475 L F
.58323 .62573 m .58422 .60411 L .58336 .62708 L 0 1 .167 r
F
.58422 .60411 m .58509 .58498 L .58429 .60776 L F
.58336 .62708 m .58305 .63027 L .58273 .6364 L F
.58781 .56372 m .58983 .57118 L .58995 .57794 L 0 .849 .145 r
F
.58431 .60736 m .588 .52188 L .58646 .56261 L 0 1 .167 r
F
.588 .52188 m .58832 .51435 L .58799 .52306 L F
.588 .52188 m .58799 .52306 L .58646 .56261 L F
.58509 .58498 m .58863 .50728 L .58431 .60736 L F
.58497 .59373 m .58455 .6005 L .58273 .6364 L F
.58459 .60148 m .58497 .59373 L .58443 .60398 L F
.58497 .59373 m .58646 .56261 L .58455 .6005 L F
.58336 .62708 m .58459 .60148 L .58305 .63027 L F
.58459 .60148 m .58443 .60398 L .58305 .63027 L F
.58281 .62852 m .58715 .59678 L .58883 .59097 L 0 0 .088 r
F
.58302 .62508 m .58715 .59678 L .58281 .62852 L F
.57964 .64826 m .5826 .62336 L .58715 .59678 L F
.58333 .59563 m .58727 .5969 L .58365 .59735 L 0 .675 .152 r
F
.57666 .55938 m .58406 .58555 L .58333 .59563 L F
.58646 .56261 m .59026 .58602 L .58715 .59678 L 0 .265 .185 r
F
.58406 .58555 m .58727 .5969 L .58333 .59563 L 0 .675 .152 r
F
.57964 .64826 m .58883 .59097 L .5889 .59402 L 0 0 .088 r
F
.58727 .5969 m .58798 .5994 L .58725 .59906 L 0 .675 .152 r
F
.58727 .5969 m .58725 .59906 L .58365 .59735 L F
.58832 .51435 m .58832 .5151 L .58646 .56261 L 0 1 .167 r
F
.58855 .50902 m .58855 .50929 L .58646 .56261 L F
.58646 .56261 m .59185 .53554 L .59283 .55116 L 0 .265 .185 r
F
.58604 .55189 m .58784 .56106 L .58781 .56372 L 0 .849 .145 r
F
.58784 .56106 m .58983 .57118 L .58781 .56372 L F
.58832 .51435 m .58855 .50902 L .58832 .5151 L 0 1 .167 r
F
.58855 .50902 m .58863 .50728 L .58855 .50929 L F
.5877 .5722 m .58995 .57794 L .58885 .58629 L 0 .849 .145 r
F
.58604 .55189 m .58781 .56372 L .5877 .5722 L F
.58781 .56372 m .58995 .57794 L .5877 .5722 L F
.58244 .63416 m .5889 .59402 L .58915 .60039 L 0 0 .088 r
F
.57964 .64826 m .58269 .63039 L .58244 .63416 L F
.58269 .63039 m .5889 .59402 L .58244 .63416 L F
.57964 .64826 m .58302 .62508 L .58281 .62852 L F
.58506 .64496 m .58845 .63743 L .58537 .64567 L 0 0 .073 r
F
.58506 .64496 m .58537 .64567 L .58425 .64869 L F
.5889 .59402 m .58883 .59097 L .59026 .58602 L 0 0 .088 r
F
.58863 .48826 m .58864 .48745 L .58863 .48827 L 0 1 .183 r
F
.5889 .59402 m .59026 .58602 L .58915 .60039 L 0 0 .088 r
F
.593 .60232 m .5963 .59348 L .59295 .61029 L 0 .248 .155 r
F
.5963 .59348 m .59632 .59438 L .59295 .61029 L F
.59679 .59218 m .59657 .59545 L .59295 .61029 L F
.5928 .58626 m .59655 .60528 L .59271 .59634 L 0 .849 .145 r
F
.59655 .60528 m .59832 .61425 L .59662 .60884 L F
.59698 .61741 m .59706 .6174 L .59682 .61981 L 0 .297 .144 r
F
.5971 .61934 m .60157 .63472 L .59711 .62004 L 0 .771 .083 r
F
.59706 .6174 m .5971 .61958 L .59682 .61981 L 0 .297 .144 r
F
.59442 .61786 m .59688 .61516 L .59698 .61741 L F
.59442 .61786 m .59653 .61302 L .59688 .61516 L F
.5971 .61958 m .5971 .61967 L .59682 .61981 L F
.58685 .61879 m .59581 .60631 L .59441 .61786 L 0 .248 .155 r
F
.59581 .60631 m .59586 .60699 L .59441 .61786 L F
.59598 .60607 m .59603 .60701 L .59597 .60743 L F
.59592 .60658 m .59597 .60743 L .59441 .61786 L F
.59598 .60607 m .59597 .60743 L .59592 .60658 L F
.59622 .60575 m .59623 .60659 L .59441 .61786 L F
.59442 .61786 m .59629 .61045 L .59657 .61269 L 0 .297 .144 r
F
.59629 .61045 m .59629 .61045 L .59631 .6121 L 0 .771 .083 r
F
.59629 .61045 m .5973 .61236 L .5965 .61215 L F
.59629 .61045 m .5965 .61215 L .59631 .6121 L F
.60375 .61125 m .60788 .64373 L .60376 .60993 L 0 .297 .226 r
F
.60356 .6358 m .60788 .64373 L .60375 .61125 L F
.60119 .60141 m .60788 .64373 L .60126 .60537 L 0 .858 .083 r
F
.60119 .60141 m .60126 .60537 L .60037 .60018 L F
.60099 .59484 m .60376 .60993 L .60111 .59901 L F
.60037 .60018 m .60126 .60537 L .60129 .60665 L F
.59662 .60884 m .59832 .61425 L .59667 .61117 L 0 .849 .145 r
F
.60129 .59647 m .60114 .5934 L .60376 .60993 L 0 .858 .083 r
F
.60119 .60141 m .60376 .60993 L .60788 .64373 L F
.60022 .59531 m .60111 .59901 L .60119 .60141 L F
.60111 .59901 m .60376 .60993 L .60119 .60141 L F
.60058 .60615 m .6008 .61293 L .59859 .59895 L F
.59657 .61269 m .59816 .60304 L .60261 .59819 L 0 .297 .144 r
F
.59629 .61045 m .59816 .60304 L .59657 .61269 L F
.59655 .61298 m .59658 .61281 L .59659 .61288 L F
.59442 .61786 m .59654 .61292 L .59655 .61298 L F
.59654 .61292 m .59658 .61281 L .59655 .61298 L F
.59633 .61337 m .59688 .61516 L .5964 .61487 L 0 .771 .083 r
F
.59707 .61641 m .60137 .62976 L .5972 .61728 L F
.59708 .61581 m .60137 .62976 L .59707 .61641 L F
.59658 .61281 m .60261 .59819 L .60264 .59873 L 0 .297 .144 r
F
.59442 .61786 m .59657 .61269 L .59658 .61281 L F
.59657 .61269 m .60261 .59819 L .59658 .61281 L F
.59631 .6121 m .59659 .61284 L .59631 .61213 L 0 .771 .083 r
F
.59659 .61284 m .59717 .61439 L .59659 .61286 L F
.59659 .61284 m .59659 .61286 L .59631 .61213 L F
.59717 .61439 m .60322 .63048 L .59717 .61441 L F
.59717 .61439 m .59717 .61441 L .59631 .61213 L F
.59702 .61997 m .59711 .61993 L .59711 .62004 L 0 .297 .144 r
F
.59682 .61981 m .59703 .61971 L .59702 .61997 L F
.59442 .61786 m .59698 .61741 L .59682 .61981 L F
.59442 .61786 m .59711 .62004 L .59654 .62963 L F
.59711 .62004 m .5996 .63177 L .59745 .62723 L 0 .771 .083 r
F
.59711 .62004 m .59751 .62856 L .59654 .62963 L 0 .297 .144 r
F
.59987 .67715 m .59989 .63421 L .60031 .6494 L 0 .928 .09 r
F
.5996 .63177 m .6008 .63904 L .59647 .62518 L 0 .771 .083 r
F
.59746 .61893 m .60137 .62976 L .60157 .63472 L F
.5972 .61728 m .60137 .62976 L .59746 .61893 L F
.59706 .6174 m .60157 .63472 L .5971 .61934 L F
.59779 .62323 m .60157 .63472 L .60191 .6426 L F
.59711 .62004 m .59783 .6224 L .59779 .62323 L F
.59783 .6224 m .60157 .63472 L .59779 .62323 L F
.59148 .64021 m .59611 .63053 L .59521 .63584 L 0 .033 .084 r
F
.59611 .63053 m .59654 .62963 L .59607 .63181 L F
.59611 .63053 m .59607 .63181 L .59521 .63584 L F
.59108 .64316 m .59469 .63677 L .59482 .63709 L 0 .008 .064 r
F
.59469 .63677 m .59521 .63584 L .59482 .63709 L F
.59482 .63709 m .59521 .63584 L .59615 .63492 L F
.59108 .64316 m .59615 .63492 L .59621 .63642 L F
.5911 .64293 m .59521 .63584 L .59108 .64316 L F
.59107 .64334 m .59621 .63649 L .59629 .63825 L F
.59652 .63602 m .59661 .63447 L .59714 .63552 L 0 .592 .07 r
F
.59685 .63655 m .59714 .63552 L .60098 .64321 L F
.59652 .63602 m .59714 .63552 L .59685 .63655 L F
.5996 .63177 m .60191 .6426 L .6008 .63904 L 0 .771 .083 r
F
.60129 .60665 m .6074 .64955 L .60133 .61095 L 0 .858 .083 r
F
.60356 .6358 m .60724 .65801 L .60979 .66109 L 0 .297 .226 r
F
.60724 .65801 m .61383 .69781 L .61081 .67032 L F
.60724 .65801 m .61081 .67032 L .60979 .66109 L F
.60356 .6358 m .60979 .66109 L .60521 .64131 L F
.60749 .6502 m .60811 .65449 L .60727 .64915 L 0 .858 .083 r
F
.60749 .6502 m .60727 .64915 L .60716 .64841 L F
.6074 .64955 m .60749 .6502 L .60716 .64841 L F
.6074 .64955 m .60716 .64841 L .60133 .61095 L F
.60129 .60665 m .60788 .64373 L .60811 .65449 L F
.60197 .617 m .60811 .65449 L .60424 .63473 L F
.60133 .61205 m .60198 .61612 L .60197 .617 L F
.60198 .61612 m .60811 .65449 L .60197 .617 L F
.60153 .6303 m .60175 .63101 L .60155 .63435 L 0 .771 .083 r
F
.60133 .61095 m .60811 .65449 L .60133 .61205 L 0 .858 .083 r
F
.60425 .63474 m .61382 .68031 L .61477 .68399 L 0 0 .099 r
F
.61273 .67314 m .60702 .39285 L .60702 .39275 L 0 .501 .225 r
F
.61273 .67314 m .6069 .38681 L .60689 .38666 L F
.60425 .63474 m .61477 .68399 L .61641 .68966 L 0 0 .099 r
F
.61843 .88235 m .61716 .71778 L .62092 .73868 L 0 .593 .223 r
F
.60356 .6358 m .61761 .73607 L .61383 .69781 L 0 .297 .226 r
F
.60356 .6358 m .61518 .74198 L .61761 .73607 L F
.60724 .70086 m .6073 .70211 L .60356 .6358 L 0 1 .156 r
F
.60356 .6358 m .61344 .75993 L .61746 .76283 L 0 .297 .226 r
F
.60612 .67914 m .60553 .66776 L .60553 .66776 L 0 1 .156 r
F
.6072 .69993 m .60612 .67914 L .60612 .67914 L F
.6072 .69993 m .6072 .69993 L .60612 .67914 L F
.6072 .69993 m .60612 .67914 L .60612 .67914 L F
.6072 .7 m .60746 .70495 L .60724 .70086 L F
.60724 .70086 m .60746 .70495 L .6073 .70211 L F
.6072 .69993 m .60746 .70495 L .6072 .69993 L F
.60356 .6358 m .60746 .70495 L .61344 .75993 L 0 .297 .226 r
F
.60425 .63474 m .60811 .6545 L .61382 .68031 L 0 0 .099 r
F
.60175 .63101 m .60735 .64922 L .6017 .63472 L 0 .771 .083 r
F
.60175 .63101 m .6017 .63472 L .60155 .63435 L F
.61641 .68966 m .61477 .68399 L .61758 .69495 L 0 0 .099 r
F
.60155 .63435 m .60735 .64922 L .60157 .63472 L 0 .771 .083 r
F
.60133 .61205 m .60424 .63473 L .6014 .61672 L 0 .858 .083 r
F
.60147 .62592 m .60392 .63246 L .60153 .62993 L 0 .771 .083 r
F
.60137 .62976 m .60153 .6303 L .60155 .63435 L F
.60802 .65157 m .61563 .68615 L .61517 .68341 L 0 0 .099 r
F
.60425 .63474 m .60745 .64921 L .60802 .65157 L F
.60745 .64921 m .61563 .68615 L .60802 .65157 L F
.6021 .6435 m .61215 .67352 L .60989 .66969 L 0 .493 .007 r
F
.6088 .65554 m .61726 .69272 L .61308 .67507 L 0 0 .099 r
F
.60876 .65535 m .61726 .69272 L .6088 .65554 L F
.60802 .65157 m .61726 .69272 L .6086 .65462 L F
.61308 .67507 m .6232 .71351 L .62693 .72357 L 0 0 .133 r
F
.61308 .67507 m .61726 .69272 L .6232 .71351 L F
.61215 .67352 m .61477 .68133 L .61268 .67635 L 0 .493 .007 r
F
.61215 .67352 m .61268 .67635 L .60989 .66969 L F
.6086 .65462 m .60876 .65535 L .6088 .65554 L 0 0 .099 r
F
.60425 .63474 m .60802 .65157 L .6086 .65462 L F
.61462 .68016 m .61465 .68025 L .61458 .67983 L 0 0 .133 r
F
.61462 .68016 m .61458 .67983 L .61455 .67967 L F
.61308 .67507 m .61462 .68016 L .61455 .67967 L F
.61308 .67507 m .61588 .68157 L .61248 .67029 L F
.61308 .67507 m .62182 .70237 L .61588 .68157 L F
.61308 .67507 m .62693 .72357 L .62634 .7188 L F
.61215 .67352 m .6142 .67695 L .61477 .68133 L 0 .493 .007 r
F
.6021 .6435 m .61128 .66887 L .61215 .67352 L F
.60425 .63474 m .60831 .6533 L .60735 .64922 L 0 0 .099 r
F
.60831 .6533 m .61308 .67507 L .60963 .65952 L F
.60831 .6533 m .60963 .65952 L .60735 .64922 L F
.61211 .67117 m .61248 .67029 L .61588 .68157 L 0 .493 .007 r
F
.6021 .6435 m .61125 .66711 L .61211 .67117 L F
.61125 .66711 m .61248 .67029 L .61211 .67117 L F
.61128 .66887 m .6142 .67695 L .61215 .67352 L F
.6142 .67695 m .61588 .68157 L .6153 .68145 L F
.61464 .67994 m .61505 .68133 L .61519 .68168 L 0 0 .133 r
F
.61455 .67967 m .61461 .67989 L .61464 .67994 L F
.6142 .67695 m .6153 .68145 L .61477 .68133 L 0 .493 .007 r
F
.60425 .63474 m .60735 .64922 L .60392 .63246 L 0 0 .099 r
F
.60153 .6303 m .60392 .63246 L .60735 .64922 L 0 .771 .083 r
F
.60153 .62993 m .60392 .63246 L .60153 .6303 L F
.59639 .64089 m .5964 .64106 L .59599 .64005 L 0 .592 .07 r
F
.59585 .64005 m .59602 .63985 L .59601 .63994 L 0 .008 .064 r
F
.59105 .64347 m .59627 .63834 L .59585 .64005 L F
.59627 .63834 m .59636 .63825 L .59618 .63888 L F
.59627 .63834 m .59618 .63888 L .59585 .64005 L F
.59552 .64288 m .5964 .64106 L .59663 .64649 L 0 .592 .07 r
F
.59108 .64316 m .59633 .63626 L .59107 .64334 L 0 .008 .064 r
F
.59633 .63626 m .59633 .63628 L .59107 .64334 L F
.59663 .63865 m .60098 .64321 L .60397 .65333 L 0 .592 .07 r
F
.59671 .63851 m .60098 .64321 L .59663 .63865 L F
.59652 .63602 m .59685 .63655 L .59639 .63816 L F
.59685 .63655 m .60098 .64321 L .59639 .63816 L F
.59107 .64334 m .59639 .63816 L .59105 .64347 L 0 .008 .064 r
F
.60191 .6426 m .60192 .64292 L .59746 .62841 L 0 .771 .083 r
F
.60191 .6426 m .59746 .62841 L .59747 .62836 L F
.59601 .63994 m .60397 .65333 L .60231 .65541 L 0 .592 .07 r
F
.59639 .63816 m .59637 .63824 L .59636 .63825 L 0 .008 .064 r
F
.59639 .63816 m .59636 .63825 L .59105 .64347 L F
.59633 .63628 m .59634 .63633 L .59107 .64334 L F
.59636 .63825 m .59637 .63824 L .59585 .64005 L F
.59639 .63816 m .59663 .63865 L .59601 .63994 L 0 .592 .07 r
F
.59663 .63865 m .60397 .65333 L .59601 .63994 L F
.59518 .64164 m .59533 .64151 L .59506 .64188 L 0 .008 .064 r
F
.59519 .64182 m .59599 .64005 L .59552 .64288 L 0 .592 .07 r
F
.59599 .64005 m .5964 .64106 L .59552 .64288 L F
.59639 .64089 m .59599 .64005 L .596 .63995 L F
.59585 .63956 m .59601 .63994 L .59585 .63958 L F
.59601 .63994 m .59639 .64089 L .596 .63995 L F
.59637 .63824 m .59602 .63985 L .59585 .64005 L 0 .008 .064 r
F
.59601 .63994 m .596 .63995 L .59585 .63958 L 0 .592 .07 r
F
.59579 .64016 m .59596 .64003 L .59475 .64201 L 0 .008 .064 r
F
.59597 .64001 m .59599 .64005 L .59519 .64182 L 0 .592 .07 r
F
.596 .63995 m .59599 .64005 L .59585 .63971 L F
.59172 .6371 m .59611 .63028 L .59148 .64021 L 0 .033 .084 r
F
.59611 .63028 m .59611 .63053 L .59148 .64021 L F
.59172 .6371 m .59371 .62929 L .59654 .62963 L F
.59188 .63304 m .59371 .62929 L .59172 .6371 L F
.58685 .61879 m .59441 .61786 L .58942 .63127 L 0 .248 .155 r
F
.58425 .64869 m .58845 .63743 L .59371 .62929 L 0 .033 .084 r
F
.58425 .64869 m .59521 .63584 L .59059 .6438 L F
.59585 .63958 m .59585 .63971 L .59073 .62728 L 0 .592 .07 r
F
.596 .63995 m .59585 .63971 L .59585 .63958 L F
.59611 .63028 m .59654 .62963 L .59611 .63053 L 0 .033 .084 r
F
.60157 .63472 m .60735 .64922 L .60658 .65399 L 0 .771 .083 r
F
.60157 .63472 m .60658 .65399 L .60191 .6426 L F
.59596 .64003 m .60202 .63564 L .59533 .64151 L 0 .008 .064 r
F
.59596 .64003 m .59533 .64151 L .59475 .64201 L F
.59533 .64151 m .60202 .63564 L .59523 .64172 L F
.59533 .64151 m .59523 .64172 L .59506 .64188 L F
.59102 .64362 m .59579 .64016 L .59475 .64201 L F
.59105 .64347 m .59607 .63989 L .59102 .64362 L F
.59607 .63989 m .60202 .63564 L .59602 .63999 L F
.59607 .63989 m .59602 .63999 L .59102 .64362 L F
.59084 .64466 m .59508 .64217 L .59138 .64652 L F
.59663 .64649 m .59663 .64664 L .5951 .6421 L 0 .592 .07 r
F
.59663 .64649 m .5951 .6421 L .5951 .6421 L F
.59519 .64182 m .59508 .64217 L .59084 .64466 L 0 .008 .064 r
F
.59512 .64205 m .59509 .64205 L .59511 .64201 L 0 .592 .07 r
F
.59663 .64649 m .5951 .6421 L .59512 .64205 L F
.5951 .6421 m .59509 .64205 L .59512 .64205 L F
.59102 .64362 m .59519 .64182 L .59084 .64466 L 0 .008 .064 r
F
.59508 .64217 m .59472 .64326 L .59138 .64652 L F
.59475 .64201 m .59518 .64164 L .59506 .64188 L F
.58425 .64869 m .59172 .6371 L .59148 .64021 L 0 .033 .084 r
F
.58425 .64869 m .59188 .63304 L .59172 .6371 L F
.59059 .62872 m .59663 .64664 L .59125 .63629 L 0 .592 .07 r
F
.59639 .64089 m .60231 .65541 L .5964 .64106 L F
.5964 .64106 m .60231 .65541 L .59663 .64649 L F
.59519 .64182 m .59699 .64105 L .59508 .64217 L 0 .008 .064 r
F
.59519 .64182 m .59663 .64649 L .59511 .64201 L 0 .592 .07 r
F
.59663 .64664 m .59664 .64711 L .59125 .63629 L F
.59508 .64217 m .59699 .64105 L .59472 .64326 L 0 .008 .064 r
F
.5951 .6421 m .5951 .6421 L .59509 .64205 L 0 .592 .07 r
F
.59511 .64201 m .59509 .64205 L .59059 .62872 L F
.59073 .62728 m .59597 .64001 L .59519 .64182 L F
.59073 .62728 m .59519 .64182 L .59059 .62872 L F
.59506 .64188 m .59524 .64172 L .59519 .64182 L 0 .008 .064 r
F
.59519 .64182 m .59511 .64201 L .59059 .62872 L 0 .592 .07 r
F
.59519 .64182 m .60202 .63564 L .59699 .64105 L 0 .008 .064 r
F
.59524 .64172 m .60202 .63564 L .59519 .64182 L F
.59639 .63816 m .59671 .63851 L .59663 .63865 L 0 .592 .07 r
F
.59637 .63824 m .60364 .63109 L .59602 .63985 L 0 .008 .064 r
F
.59629 .63825 m .60079 .6304 L .60364 .63109 L F
.59621 .63649 m .60079 .6304 L .59629 .63825 L F
.59037 .62611 m .59639 .63816 L .59601 .63994 L 0 .592 .07 r
F
.59639 .63816 m .60364 .63109 L .59637 .63824 L 0 .008 .064 r
F
.59651 .63608 m .59651 .6361 L .59634 .63633 L F
.59621 .63642 m .59728 .63382 L .59722 .6351 L F
.59037 .62611 m .59652 .63602 L .59639 .63816 L 0 .592 .07 r
F
.59703 .63534 m .59703 .63541 L .59651 .6361 L 0 .008 .064 r
F
.59703 .63534 m .59651 .6361 L .59651 .63608 L F
.59703 .63534 m .59634 .63633 L .59633 .63628 L F
.59663 .64649 m .59709 .648 L .59663 .64664 L 0 .592 .07 r
F
.59663 .64664 m .59709 .648 L .59664 .64711 L F
.59633 .63626 m .59703 .63534 L .59633 .63628 L 0 .008 .064 r
F
.59703 .63534 m .60079 .6304 L .59703 .63541 L F
.59747 .62836 m .59746 .62841 L .59647 .62518 L 0 .771 .083 r
F
.59601 .63994 m .60364 .63109 L .60202 .63564 L 0 .008 .064 r
F
.59602 .63985 m .60364 .63109 L .59601 .63994 L F
.59075 .62705 m .59585 .63956 L .59073 .62728 L 0 .592 .07 r
F
.59585 .63956 m .59585 .63958 L .59073 .62728 L F
.59037 .62611 m .59515 .63156 L .59661 .63447 L F
.59621 .63642 m .59615 .63492 L .59661 .63447 L 0 .008 .064 r
F
.59621 .63642 m .59661 .63447 L .59654 .63562 L F
.59037 .62611 m .59661 .63447 L .59652 .63602 L 0 .592 .07 r
F
.59654 .63562 m .59661 .63447 L .59728 .63382 L 0 .008 .064 r
F
.59722 .6351 m .59728 .63382 L .60079 .6304 L F
.59681 .61345 m .60322 .63048 L .60323 .63061 L 0 .771 .083 r
F
.59681 .61345 m .60322 .63048 L .59681 .61345 L F
.59659 .61287 m .60322 .63048 L .59659 .61288 L F
.59717 .61439 m .59832 .61426 L .60319 .6301 L F
.59717 .61439 m .60319 .6301 L .60322 .63048 L F
.59623 .60659 m .59624 .60751 L .59441 .61786 L 0 .248 .155 r
F
.59633 .61337 m .60121 .62522 L .60137 .62976 L 0 .771 .083 r
F
.59624 .60751 m .59629 .61044 L .59441 .61786 L 0 .248 .155 r
F
.59426 .60665 m .59631 .61213 L .59633 .61337 L 0 .771 .083 r
F
.59653 .61302 m .59655 .61298 L .59688 .61516 L 0 .297 .144 r
F
.59655 .61298 m .59659 .61288 L .59688 .61516 L F
.59631 .61213 m .60121 .62522 L .59633 .61337 L 0 .771 .083 r
F
.59652 .60597 m .59629 .61044 L .59629 .61044 L 0 .248 .155 r
F
.59652 .60597 m .59629 .61044 L .59624 .60751 L F
.59711 .62004 m .60181 .62385 L .59751 .62856 L 0 .297 .144 r
F
.59711 .62004 m .59745 .62723 L .59716 .62662 L 0 .771 .083 r
F
.59659 .61759 m .59711 .62004 L .59714 .62658 L F
.59711 .62004 m .59716 .62662 L .59714 .62658 L F
.59711 .62004 m .60064 .61794 L .60064 .62291 L 0 .297 .144 r
F
.59711 .61993 m .60064 .61794 L .59711 .62004 L F
.59703 .61971 m .60064 .61794 L .59702 .61997 L F
.59688 .61516 m .59708 .61581 L .59707 .61641 L 0 .771 .083 r
F
.60133 .61205 m .6014 .61672 L .6008 .61293 L 0 .858 .083 r
F
.59706 .6174 m .60117 .61047 L .60138 .61665 L 0 .297 .144 r
F
.59698 .61741 m .59705 .61729 L .59706 .6174 L F
.59705 .61729 m .60117 .61047 L .59706 .6174 L F
.59688 .61516 m .5972 .61728 L .597 .61667 L 0 .771 .083 r
F
.59688 .61516 m .597 .61667 L .5964 .61487 L F
.59659 .61288 m .60264 .59873 L .60265 .59903 L 0 .297 .144 r
F
.59658 .61281 m .60264 .59873 L .59659 .61288 L F
.59659 .61284 m .5973 .61236 L .59717 .61439 L 0 .771 .083 r
F
.59631 .6121 m .5965 .61215 L .59659 .61284 L F
.5965 .61215 m .5973 .61236 L .59659 .61284 L F
.59426 .60665 m .59629 .61045 L .59631 .6121 L F
.59641 .60548 m .59652 .60597 L .59624 .60751 L 0 .248 .155 r
F
.59641 .60548 m .59624 .60751 L .59623 .60659 L F
.59655 .60528 m .59662 .60884 L .5964 .60814 L 0 .849 .145 r
F
.59271 .59634 m .59662 .60884 L .59426 .60665 L F
.59662 .60884 m .59667 .61117 L .59426 .60665 L F
.59652 .60597 m .59693 .60789 L .59629 .61044 L 0 .248 .155 r
F
.59581 .60631 m .59598 .60607 L .59586 .60699 L F
.59598 .60607 m .59622 .60575 L .59603 .60701 L F
.59622 .60575 m .59641 .60548 L .59623 .60659 L F
.59655 .60528 m .5964 .60814 L .59271 .59634 L 0 .849 .145 r
F
.59426 .60665 m .59659 .61759 L .59647 .62518 L 0 .771 .083 r
F
.59659 .61759 m .59714 .62658 L .59647 .62518 L F
.597 .61667 m .5972 .61728 L .59706 .6174 L F
.5973 .61236 m .59832 .61426 L .59717 .61439 L F
.59688 .61516 m .60117 .61047 L .59705 .61729 L 0 .297 .144 r
F
.59688 .61516 m .59705 .61729 L .59698 .61741 L F
.59706 .6174 m .5972 .61728 L .59746 .61893 L 0 .771 .083 r
F
.5964 .61487 m .597 .61667 L .59706 .6174 L F
.5964 .61487 m .59706 .6174 L .59659 .61759 L F
.59706 .6174 m .5971 .61934 L .59659 .61759 L F
.60064 .61678 m .60064 .61794 L .5971 .61967 L 0 .297 .144 r
F
.60064 .61678 m .5971 .61967 L .5971 .61958 L F
.59706 .6174 m .60064 .61678 L .5971 .61958 L F
.59659 .61759 m .5971 .61934 L .59711 .62004 L 0 .771 .083 r
F
.59426 .60665 m .5964 .61487 L .59659 .61759 L F
.59426 .60665 m .59633 .61337 L .5964 .61487 L F
.5963 .59348 m .59679 .59218 L .59632 .59438 L 0 .248 .155 r
F
.59679 .59218 m .5971 .5876 L .59859 .59895 L 0 .849 .145 r
F
.59477 .56086 m .5968 .58113 L .59583 .57594 L 0 .858 .083 r
F
.5968 .58113 m .59859 .59895 L .5971 .5876 L F
.59486 .56646 m .59675 .58495 L .59509 .58216 L 0 .547 .201 r
F
.5968 .58113 m .5971 .5876 L .59675 .58495 L 0 .858 .083 r
F
.59613 .57753 m .59675 .58495 L .59494 .5712 L F
.5968 .58113 m .59675 .58495 L .59613 .57753 L F
.59725 .59094 m .59675 .58495 L .59843 .58778 L 0 .248 .155 r
F
.59679 .59218 m .59675 .58495 L .5971 .5876 L 0 .849 .145 r
F
.59679 .59218 m .59675 .58495 L .59725 .59094 L 0 .248 .155 r
F
.59477 .56086 m .60002 .58768 L .60007 .58983 L 0 .858 .083 r
F
.59477 .56086 m .59815 .57456 L .59932 .58191 L F
.59477 .56086 m .59932 .58191 L .59918 .5834 L F
.59477 .56086 m .60007 .58983 L .60022 .59531 L F
.59477 .56086 m .60022 .59531 L .60037 .60018 L F
.59459 .54799 m .59843 .58778 L .59675 .58495 L 0 .547 .201 r
F
.59477 .56086 m .59583 .57594 L .59486 .56646 L 0 .858 .083 r
F
.59459 .54799 m .59675 .58495 L .59486 .56646 L 0 .547 .201 r
F
.59486 .56646 m .59583 .57594 L .59494 .5712 L 0 .858 .083 r
F
.59679 .59218 m .59725 .59094 L .59657 .59545 L 0 .248 .155 r
F
.59725 .59094 m .59843 .58778 L .59732 .59236 L F
.59725 .59094 m .59732 .59236 L .59657 .59545 L F
.58995 .57794 m .59426 .60665 L .59014 .59115 L 0 .849 .145 r
F
.58995 .57794 m .59014 .59115 L .58885 .58629 L F
.58506 .64496 m .58942 .63127 L .58845 .63743 L 0 0 .073 r
F
.58487 .64297 m .58942 .63127 L .58506 .64496 L F
.58468 .62766 m .58915 .60039 L .58685 .61879 L 0 0 .088 r
F
.57964 .64826 m .5846 .62331 L .58468 .62766 L F
.5846 .62331 m .58915 .60039 L .58468 .62766 L F
.58915 .60039 m .59015 .59538 L .58924 .60183 L F
.58915 .60039 m .58924 .60183 L .58685 .61879 L F
.58935 .61531 m .593 .60232 L .59295 .61029 L 0 .248 .155 r
F
.58685 .61879 m .5893 .61223 L .58935 .61531 L F
.5893 .61223 m .593 .60232 L .58935 .61531 L F
.58995 .57794 m .5928 .58626 L .59271 .59634 L 0 .849 .145 r
F
.58983 .57118 m .5928 .58626 L .58995 .57794 L F
.58854 .49604 m .58857 .49356 L .58855 .4969 L 0 1 .183 r
F
.58857 .49356 m .58864 .48745 L .58859 .49699 L F
.58685 .61879 m .58928 .60802 L .5893 .61223 L 0 .248 .155 r
F
.58532 .44235 m .59386 .54953 L .58942 .5206 L 0 .875 .195 r
F
.59386 .54953 m .59383 .5538 L .58942 .5206 L F
.59299 .53808 m .59381 .54385 L .59386 .5493 L F
.59379 .54185 m .5958 .52228 L .59379 .54263 L 0 .265 .185 r
F
.59363 .52739 m .59381 .54385 L .59299 .53808 L 0 .875 .195 r
F
.59362 .52661 m .59571 .5161 L .59379 .54185 L 0 .265 .185 r
F
.59571 .5161 m .59721 .50856 L .5958 .52228 L F
.59571 .5161 m .5958 .52228 L .59379 .54185 L F
.59468 .47758 m .59451 .47269 L .59507 .4735 L F
.59283 .55116 m .59302 .54925 L .59298 .55089 L F
.59553 .48368 m .59366 .5088 L .59367 .50703 L F
.59154 .48462 m .59368 .50028 L .59206 .51004 L 0 .875 .195 r
F
.59368 .50028 m .59365 .51495 L .59206 .51004 L F
.59206 .51004 m .59365 .51495 L .59362 .52661 L F
.59368 .49974 m .59553 .48368 L .59367 .50703 L 0 .265 .185 r
F
.59553 .48368 m .59647 .47551 L .59561 .48568 L F
.59209 .5109 m .59364 .52722 L .59299 .53808 L 0 .875 .195 r
F
.60989 .66969 m .61477 .68134 L .61916 .69183 L 0 .313 0 r
F
.6193 .69217 m .61916 .69183 L .62086 .69589 L F
.60989 .66969 m .61916 .69183 L .6193 .69217 L F
.60989 .66969 m .6193 .69217 L .62013 .69418 L F
.6193 .69217 m .62086 .69589 L .62013 .69418 L F
.61519 .68168 m .61579 .68368 L .61597 .68411 L 0 0 .133 r
F
.62172 .69819 m .6241 .70365 L .62258 .70028 L 0 .313 0 r
F
.61229 .67547 m .62013 .69418 L .62167 .69806 L F
.62157 .69783 m .62167 .69806 L .62172 .69819 L F
.61229 .67547 m .62167 .69806 L .62157 .69783 L F
.61214 .67509 m .62013 .69418 L .61229 .67547 L F
.61213 .67522 m .62172 .69819 L .61732 .68799 L F
.60989 .66969 m .61187 .67447 L .61213 .67522 L F
.61187 .67447 m .62172 .69819 L .61213 .67522 L F
.60989 .66969 m .61213 .67522 L .61123 .67342 L F
.61213 .67522 m .61732 .68799 L .61305 .67778 L F
.61213 .67522 m .61305 .67778 L .61123 .67342 L F
.60352 .6638 m .60916 .67236 L .61384 .67999 L 0 .279 0 r
F
.61391 .68018 m .61384 .67999 L .61552 .68272 L F
.60352 .6638 m .61384 .67999 L .61391 .68018 L F
.61732 .68799 m .61838 .68797 L .61552 .68272 L 0 0 .138 r
F
.61424 .68123 m .61552 .68272 L .61838 .68797 L 0 .279 0 r
F
.61383 .69782 m .61758 .69495 L .61382 .68031 L 0 .408 .253 r
F
.60352 .6638 m .61382 .68003 L .61424 .68123 L 0 .279 0 r
F
.61382 .68003 m .61552 .68272 L .61424 .68123 L F
.61752 .68835 m .63038 .71414 L .62475 .70143 L 0 0 .138 r
F
.61732 .68799 m .61763 .68861 L .61752 .68835 L F
.61763 .68861 m .63038 .71414 L .61752 .68835 L F
.61543 .68397 m .61838 .68797 L .61599 .68493 L 0 .279 0 r
F
.61517 .68341 m .61641 .68966 L .61726 .69272 L 0 0 .099 r
F
.61563 .68615 m .61641 .68966 L .61517 .68341 L F
.60352 .6638 m .61468 .68196 L .61543 .68397 L 0 .279 0 r
F
.61468 .68196 m .61838 .68797 L .61543 .68397 L F
.60989 .66969 m .61214 .67509 L .61229 .67547 L 0 .313 0 r
F
.62013 .69418 m .6241 .70365 L .62172 .69819 L F
.62172 .69819 m .62258 .70028 L .62198 .69887 L F
.62172 .69819 m .62198 .69887 L .61732 .68799 L F
.61641 .68966 m .61758 .69495 L .61749 .69436 L 0 0 .099 r
F
.61641 .68966 m .61749 .69436 L .61726 .69272 L F
.62573 .71678 m .62634 .7188 L .62572 .71654 L 0 0 .133 r
F
.62573 .71678 m .62572 .71654 L .62182 .70237 L F
.62876 .71288 m .63123 .73883 L .63403 .7322 L 0 .389 .233 r
F
.62876 .71288 m .63403 .7322 L .63447 .73117 L F
.62152 .74168 m .62448 .7565 L .62414 .73125 L 0 .529 .227 r
F
.61645 .60787 m .61642 .6047 L .62131 .60835 L 0 .507 .099 r
F
.61196 .60743 m .61642 .6047 L .61645 .60787 L F
.63282 .64524 m .63447 .64989 L .63448 .64683 L 0 .153 .226 r
F
.63282 .64524 m .63448 .64683 L .63448 .64548 L F
.65578 .8118 m .6565 .81418 L .65637 .81206 L 0 .161 .225 r
F
.65578 .8118 m .65637 .81206 L .65586 .80317 L F
.65058 .73044 m .65059 .73035 L .64916 .71342 L 0 0 .119 r
F
.64915 .71352 m .64916 .71342 L .64721 .69044 L F
.65058 .73044 m .64916 .71342 L .64915 .71352 L F
.64876 .74337 m .64909 .74244 L .64838 .73484 L F
.64827 .73779 m .64838 .73484 L .64253 .67168 L F
.64876 .74337 m .64838 .73484 L .64827 .73779 L F
.64263 .68108 m .64298 .67648 L .64272 .67714 L 0 .968 .234 r
F
.64263 .68108 m .64876 .74337 L .64297 .67671 L 0 0 .119 r
F
.64861 .74519 m .64876 .74337 L .64861 .74519 L 0 .729 .063 r
F
.64876 .74337 m .64876 .74336 L .64861 .74519 L F
.64882 .74265 m .64882 .74264 L .64861 .74519 L F
.65058 .73044 m .64721 .69044 L .64721 .69055 L 0 0 .119 r
F
.64368 .64886 m .64368 .64885 L .64359 .64771 L F
.65058 .73044 m .64368 .64885 L .64368 .64886 L F
.64384 .66469 m .64438 .6571 L .64368 .64886 L F
.64384 .66469 m .64368 .64886 L .64364 .65095 L F
.64306 .67553 m .65058 .73044 L .64341 .66054 L F
.64306 .67553 m .64318 .67014 L .64264 .66075 L 0 .968 .234 r
F
.64264 .66075 m .64318 .67014 L .64361 .64886 L F
.64318 .67014 m .64357 .65361 L .64361 .64886 L F
.64341 .66054 m .64384 .66469 L .64364 .65095 L 0 0 .119 r
F
.64384 .66469 m .65058 .73044 L .64438 .6571 L F
.64298 .67654 m .64302 .67694 L .64306 .67553 L F
.64272 .67714 m .64298 .67648 L .64306 .67553 L 0 .968 .234 r
F
.64272 .67714 m .64306 .67553 L .64264 .66075 L F
.64263 .68108 m .64672 .73483 L .64737 .72927 L 0 0 .119 r
F
.64264 .68138 m .64267 .6814 L .64263 .68108 L 0 .968 .234 r
F
.64276 .68786 m .64672 .73483 L .64263 .68108 L 0 0 .119 r
F
.64255 .68133 m .64264 .68138 L .64263 .68108 L 0 .968 .234 r
F
.63061 .63305 m .64006 .65226 L .6411 .65126 L 0 .84 .347 r
F
.64156 .6493 m .6411 .65126 L .64218 .65023 L F
.63061 .63305 m .6411 .65126 L .64156 .6493 L F
.64241 .6474 m .64218 .65023 L .64361 .64886 L F
.63061 .63305 m .64218 .65023 L .64241 .6474 L F
.6404 .68805 m .64272 .67714 L .64264 .66075 L 0 .968 .234 r
F
.64388 .71559 m .64412 .71841 L .64412 .71776 L 0 .385 .231 r
F
.64322 .70457 m .64414 .71829 L .64557 .73537 L 0 0 .119 r
F
.64606 .74115 m .64557 .73537 L .64618 .74268 L F
.64322 .70457 m .64557 .73537 L .64606 .74115 L F
.63055 .6779 m .63858 .73018 L .64111 .72002 L 0 .44 .248 r
F
.65275 .82558 m .65685 .85734 L .66148 .87877 L 0 .284 .256 r
F
.66201 .87991 m .66148 .87877 L .66305 .886 L F
.65275 .82558 m .66148 .87877 L .66201 .87991 L F
.64352 .84032 m .64654 .81999 L .64659 .82275 L 0 0 .086 r
F
.6568 .85704 m .65685 .85734 L .65684 .8572 L 0 .996 .115 r
F
.6568 .85704 m .65684 .8572 L .65275 .82558 L F
.63416 .86471 m .64295 .8055 L .64304 .81445 L 0 .283 .182 r
F
.63405 .82838 m .63406 .82843 L .63402 .83406 L 0 .306 .198 r
F
.63432 .77387 m .63406 .82843 L .63405 .82838 L F
.63055 .6779 m .64111 .72002 L .64041 .68827 L 0 .44 .248 r
F
.64111 .72002 m .64181 .72281 L .64166 .71898 L F
.64111 .72002 m .64166 .71898 L .64041 .68827 L F
.64181 .72281 m .64446 .73336 L .64325 .71993 L F
.64181 .72281 m .64325 .71993 L .64041 .68827 L F
.61553 .36464 m .61676 .3962 L .61959 .43266 L 0 0 .114 r
F
.60441 .26815 m .61732 .47306 L .60976 .26338 L 0 .529 .227 r
F
.6092 .25841 m .6146 .35672 L .61553 .36464 L 0 0 .114 r
F
.6146 .35672 m .61676 .3962 L .61553 .36464 L F
.6092 .25841 m .61959 .43266 L .61971 .42851 L F
.61736 .38072 m .61973 .42795 L .6214 .44404 L F
.6152 .34842 m .61523 .34871 L .61499 .34016 L 0 .196 .185 r
F
.60951 .25771 m .61634 .3715 L .61736 .38072 L 0 0 .114 r
F
.61634 .3715 m .61973 .42795 L .61736 .38072 L F
.61654 .35963 m .62716 .5019 L .62238 .39735 L 0 .36 .222 r
F
.61494 .33836 m .62716 .5019 L .61494 .33821 L F
.60974 .2583 m .61751 .3821 L .61698 .37236 L 0 0 .114 r
F
.60971 .25783 m .61751 .3821 L .60974 .2583 L F
.61751 .3821 m .62141 .44411 L .61781 .38585 L F
.61751 .3821 m .61781 .38585 L .61698 .37236 L F
.62141 .44411 m .62147 .4451 L .61782 .38588 L F
.61781 .38585 m .61782 .38588 L .61698 .37236 L F
.62141 .44411 m .61782 .38588 L .61781 .38585 L F
.61698 .37236 m .62778 .48809 L .62099 .40341 L 0 0 .128 r
F
.62235 .4299 m .63261 .55181 L .62778 .48809 L F
.62177 .42361 m .62222 .42901 L .62235 .4299 L F
.62222 .42901 m .63261 .55181 L .62235 .4299 L F
.62138 .4209 m .63261 .55181 L .62177 .42361 L F
.61906 .39624 m .63261 .55181 L .61985 .4031 L F
.61985 .4031 m .62138 .4209 L .62177 .42361 L F
.62555 .45584 m .62693 .46468 L .62843 .47951 L 0 .545 0 r
F
.61637 .36525 m .61736 .38072 L .61658 .36731 L 0 0 .114 r
F
.61736 .38072 m .6214 .44404 L .61751 .38206 L F
.61736 .38072 m .61751 .38206 L .61658 .36731 L F
.62365 .43766 m .6255 .45212 L .62566 .45352 L 0 .545 0 r
F
.62438 .44425 m .62594 .4557 L .62693 .46468 L F
.6214 .44404 m .62141 .44411 L .61751 .3821 L 0 0 .114 r
F
.6214 .44404 m .61751 .3821 L .61751 .38209 L F
.6214 .44404 m .61659 .36736 L .61658 .36731 L F
.6092 .25841 m .61971 .42851 L .60951 .25771 L F
.61971 .42851 m .61973 .42795 L .60951 .25771 L F
.61698 .37236 m .63289 .57111 L .63261 .55181 L 0 0 .128 r
F
.61698 .37236 m .62842 .53256 L .63289 .57111 L F
.61698 .37236 m .62159 .44694 L .62842 .53256 L F
.61604 .37765 m .62365 .43766 L .62438 .44425 L 0 .545 0 r
F
.62365 .43766 m .62594 .4557 L .62438 .44425 L F
.61751 .38209 m .61751 .3821 L .61659 .36736 L 0 0 .114 r
F
.61658 .36731 m .61659 .36736 L .60964 .2568 L F
.62565 .45678 m .62843 .47951 L .62829 .47858 L 0 .545 0 r
F
.61604 .37765 m .62555 .45584 L .62565 .45678 L F
.62555 .45584 m .62843 .47951 L .62565 .45678 L F
.61604 .37765 m .62356 .43687 L .62365 .43766 L F
.62356 .43687 m .6255 .45212 L .62365 .43766 L F
.61604 .37765 m .62438 .44425 L .62555 .45584 L F
.62438 .44425 m .62693 .46468 L .62555 .45584 L F
.60951 .25771 m .61637 .36525 L .60964 .2568 L 0 0 .114 r
F
.61637 .36525 m .61658 .36731 L .60964 .2568 L F
.62693 .46468 m .63104 .49752 L .62855 .48071 L 0 .545 0 r
F
.61908 .40423 m .62855 .48071 L .62511 .45713 L F
.61604 .37765 m .61849 .39783 L .61908 .40423 L F
.61849 .39783 m .62855 .48071 L .61908 .40423 L F
.62511 .45713 m .62782 .47506 L .62741 .47224 L 0 0 .074 r
F
.63399 .51549 m .64272 .55863 L .63756 .52898 L 0 0 .117 r
F
.63447 .51645 m .63756 .52898 L .63586 .51921 L F
.63399 .51549 m .63756 .52898 L .63447 .51645 L F
.64147 .5474 m .64427 .55579 L .64092 .54247 L 0 .002 .141 r
F
.64272 .55863 m .64418 .55597 L .64147 .5474 L F
.64418 .55597 m .64427 .55579 L .64147 .5474 L F
.64176 .54601 m .64092 .54247 L .64253 .54887 L 0 .436 0 r
F
.63688 .527 m .64034 .54024 L .64176 .54601 L F
.64034 .54024 m .64092 .54247 L .64176 .54601 L F
.63952 .53844 m .64427 .55579 L .64198 .54826 L F
.63769 .53114 m .64105 .5437 L .63952 .53844 L F
.64105 .5437 m .64427 .55579 L .63952 .53844 L F
.63769 .53114 m .64198 .54826 L .63859 .53589 L F
.63892 .53983 m .6485 .59369 L .64272 .55863 L 0 0 .117 r
F
.63399 .51549 m .63807 .53748 L .63892 .53983 L F
.63807 .53748 m .6485 .59369 L .63892 .53983 L F
.64496 .55661 m .64965 .57328 L .65001 .57364 L 0 0 .095 r
F
.64074 .55187 m .65005 .60788 L .6485 .59369 L 0 0 .117 r
F
.63399 .51549 m .64008 .55053 L .64074 .55187 L F
.64008 .55053 m .65005 .60788 L .64074 .55187 L F
.64728 .56514 m .64928 .57337 L .65261 .58345 L 0 0 .095 r
F
.63399 .51549 m .64632 .59158 L .65005 .60788 L 0 0 .117 r
F
.63769 .53114 m .63845 .53511 L .63559 .52493 L 0 .436 0 r
F
.64214 .54749 m .64253 .54887 L .64374 .55366 L F
.64355 .55297 m .64374 .55366 L .64427 .55579 L F
.64176 .54601 m .64374 .55366 L .64355 .55297 L F
.63688 .527 m .64427 .55579 L .63769 .53114 L F
.63559 .52493 m .64652 .56359 L .64728 .56514 L 0 0 .095 r
F
.64652 .56359 m .64928 .57337 L .64728 .56514 L F
.63845 .53511 m .63859 .53589 L .63559 .52493 L 0 .436 0 r
F
.64176 .54601 m .64253 .54887 L .64214 .54749 L F
.63559 .52493 m .64411 .55423 L .64496 .55661 L 0 0 .095 r
F
.64411 .55423 m .64965 .57328 L .64496 .55661 L F
.63632 .52737 m .63971 .53886 L .6391 .53667 L F
.63559 .52493 m .63661 .52838 L .63632 .52737 L F
.63661 .52838 m .63971 .53886 L .63632 .52737 L F
.64678 .55898 m .64999 .53155 L .64626 .52448 L 0 .571 .256 r
F
.64678 .55898 m .65604 .56549 L .64999 .53155 L F
.64235 .54706 m .64329 .5474 L .64036 .5393 L 0 0 .132 r
F
.64323 .55052 m .64326 .54893 L .64235 .54706 L F
.64326 .54893 m .64329 .5474 L .64235 .54706 L F
.64791 .55844 m .64836 .55953 L .6522 .56758 L 0 0 .089 r
F
.64201 .54644 m .65001 .57364 L .64323 .55052 L 0 0 .095 r
F
.64 .5397 m .64199 .54646 L .64201 .54644 L F
.64199 .54646 m .65001 .57364 L .64201 .54644 L F
.64348 .54939 m .64489 .55229 L .64367 .54856 L 0 0 .132 r
F
.64323 .55052 m .64367 .54856 L .64328 .54768 L F
.63991 .53942 m .64199 .54647 L .64 .5397 L 0 0 .095 r
F
.64199 .54647 m .65001 .57364 L .64199 .54646 L F
.64199 .54647 m .64199 .54646 L .64 .5397 L F
.63971 .53886 m .64197 .5465 L .6391 .53667 L F
.64197 .5465 m .65001 .57364 L .64199 .54647 L F
.64197 .5465 m .64199 .54647 L .6391 .53667 L F
.64214 .54621 m .64717 .55698 L .64728 .5572 L 0 0 .089 r
F
.6391 .53667 m .64323 .55052 L .63746 .53068 L 0 0 .095 r
F
.63743 .53059 m .63746 .53068 L .63741 .53049 L F
.6391 .53667 m .63746 .53068 L .63743 .53059 L F
.64082 .54152 m .64036 .5393 L .64329 .5474 L 0 .416 0 r
F
.6391 .53667 m .63991 .53942 L .64 .5397 L 0 0 .095 r
F
.63559 .52493 m .6391 .53667 L .63691 .5289 L F
.63327 .51114 m .6372 .53877 L .63943 .55189 L 0 0 .074 r
F
.63309 .51035 m .6372 .53877 L .63327 .51114 L F
.63157 .5001 m .6372 .53877 L .6317 .50077 L F
.63027 .4919 m .6372 .53877 L .63074 .4944 L F
.62561 .4605 m .6372 .53877 L .62572 .46113 L F
.63457 .51801 m .63652 .52543 L .63688 .527 L 0 .436 0 r
F
.63357 .51272 m .63943 .55189 L .63399 .51549 L 0 0 .074 r
F
.63344 .51201 m .63943 .55189 L .63357 .51272 L F
.63091 .49542 m .63182 .50145 L .63138 .49832 L F
.63331 .51136 m .63943 .55189 L .63344 .51201 L F
.62782 .47506 m .63943 .55189 L .62741 .47224 L F
.62779 .48811 m .62843 .4931 L .63104 .49752 L 0 .036 .14 r
F
.62843 .4931 m .63778 .56531 L .63307 .51793 L F
.62843 .4931 m .63307 .51793 L .63104 .49752 L F
.63811 .54489 m .63685 .53915 L .64066 .56208 L 0 0 .074 r
F
.62829 .47858 m .62843 .47951 L .62855 .48071 L 0 .545 0 r
F
.63079 .49552 m .63085 .49588 L .63104 .49752 L F
.62855 .48071 m .63104 .49752 L .63018 .49411 L F
.62855 .48071 m .63018 .49411 L .62905 .48588 L F
.62855 .48071 m .62905 .48588 L .62511 .45713 L F
.62511 .45713 m .63622 .53478 L .63811 .54489 L 0 0 .074 r
F
.63622 .53478 m .63685 .53915 L .63811 .54489 L F
.62779 .48811 m .64288 .62377 L .63778 .56531 L 0 .036 .14 r
F
.62779 .48811 m .63261 .55183 L .6394 .62058 L F
.62511 .45713 m .63018 .49411 L .63685 .53915 L 0 0 .074 r
F
.63399 .51549 m .63943 .55189 L .64632 .59158 L 0 0 .117 r
F
.6279 .49204 m .6339 .51514 L .63437 .51699 L 0 .436 0 r
F
.63447 .51749 m .63437 .51699 L .64092 .54247 L F
.6279 .49204 m .63437 .51699 L .63447 .51749 L F
.63182 .50145 m .63331 .51136 L .63215 .50343 L 0 0 .074 r
F
.63331 .51136 m .63344 .51201 L .63215 .50343 L F
.63182 .50145 m .63215 .50343 L .63138 .49832 L F
.63489 .51995 m .63688 .527 L .63769 .53114 L 0 .436 0 r
F
.6279 .49204 m .63457 .51801 L .63489 .51995 L F
.63457 .51801 m .63688 .527 L .63489 .51995 L F
.6279 .49204 m .63447 .51749 L .63457 .51801 L F
.63447 .51749 m .63652 .52543 L .63457 .51801 L F
.63138 .49832 m .63344 .51201 L .63357 .51272 L 0 0 .074 r
F
.62741 .47224 m .63091 .49542 L .63138 .49832 L F
.6279 .49204 m .63489 .51995 L .63559 .52493 L 0 .436 0 r
F
.63489 .51995 m .63769 .53114 L .6358 .52555 L F
.63489 .51995 m .6358 .52555 L .63559 .52493 L F
.63577 .5252 m .63691 .5289 L .63595 .52548 L 0 0 .095 r
F
.63559 .52493 m .63691 .5289 L .63577 .5252 L F
.6391 .53667 m .63741 .53049 L .63595 .52548 L F
.6435 .55721 m .64588 .56372 L .64427 .55579 L 0 .002 .141 r
F
.63559 .52493 m .64198 .54826 L .64879 .57168 L 0 0 .095 r
F
.64885 .57185 m .64879 .57168 L .64928 .57337 L F
.63559 .52493 m .64879 .57168 L .64885 .57185 L F
.64272 .55863 m .65135 .59069 L .64588 .56372 L 0 .002 .141 r
F
.64272 .55863 m .64588 .56372 L .6435 .55721 L F
.62568 .50552 m .63281 .52135 L .63949 .53723 L 0 .416 0 r
F
.63956 .53746 m .63949 .53723 L .64036 .5393 L F
.62568 .50552 m .63949 .53723 L .63956 .53746 L F
.63652 .52543 m .64092 .54247 L .63688 .527 L 0 .436 0 r
F
.62568 .50552 m .63956 .53746 L .64082 .54152 L 0 .416 0 r
F
.63956 .53746 m .64036 .5393 L .64082 .54152 L F
.62568 .50552 m .63982 .54132 L .63228 .5251 L F
.62568 .50552 m .64329 .5474 L .64181 .54481 L F
.63854 .53808 m .64181 .54481 L .63982 .54132 L F
.62568 .50552 m .64181 .54481 L .63854 .53808 L F
.63228 .5251 m .64214 .54621 L .64214 .54621 L 0 0 .089 r
F
.63228 .5251 m .63983 .54132 L .64213 .54623 L F
.63228 .5251 m .64213 .54623 L .64214 .54621 L F
.63228 .5251 m .64214 .54621 L .64216 .54618 L F
.63292 .5265 m .64216 .54618 L .64255 .54736 L F
.63228 .5251 m .63322 .5271 L .63292 .5265 L F
.63322 .5271 m .64216 .54618 L .63292 .5265 L F
.64214 .54621 m .64717 .55698 L .64214 .54621 L F
.64214 .54621 m .64213 .54623 L .64717 .55698 L F
.64728 .5572 m .64717 .55698 L .64836 .55953 L F
.64323 .55052 m .65084 .57044 L .64489 .55229 L 0 0 .132 r
F
.64323 .55052 m .64489 .55229 L .64348 .54939 L F
.64328 .54768 m .64367 .54856 L .64329 .5474 L F
.64216 .54618 m .64667 .55591 L .64791 .55844 L 0 0 .089 r
F
.64214 .54621 m .64667 .55591 L .64216 .54618 L F
.64216 .54618 m .64881 .56037 L .64255 .54736 L F
.64881 .56037 m .6522 .56758 L .64942 .56176 L F
.64667 .55591 m .64836 .55953 L .64791 .55844 L F
.64881 .56037 m .64942 .56176 L .64255 .54736 L F
.65037 .56839 m .6522 .56758 L .64836 .55953 L 0 .033 .163 r
F
.65084 .57045 m .65131 .56944 L .65037 .56839 L F
.65131 .56944 m .6522 .56758 L .65037 .56839 L F
.6574 .57624 m .65742 .57731 L .66053 .58219 L 0 0 .138 r
F
.64708 .55717 m .6522 .56758 L .64901 .56135 L 0 0 .089 r
F
.64255 .54736 m .64931 .56153 L .64641 .55572 L F
.63228 .5251 m .64901 .56135 L .64093 .54497 L F
.6419 .54666 m .65648 .57359 L .64796 .55726 L 0 0 .138 r
F
.64093 .54497 m .64245 .54777 L .6419 .54666 L F
.64245 .54777 m .65648 .57359 L .6419 .54666 L F
.64641 .55572 m .65146 .56603 L .64708 .55717 L 0 0 .089 r
F
.64931 .56153 m .65146 .56603 L .64641 .55572 L F
.65146 .56603 m .6522 .56758 L .64708 .55717 L F
.64052 .54387 m .64796 .55726 L .64105 .54414 L 0 0 .138 r
F
.6403 .54299 m .64105 .54414 L .64018 .54248 L F
.64052 .54387 m .64105 .54414 L .6403 .54299 L F
.64796 .55726 m .64628 .55174 L .6436 .5479 L 0 .034 .169 r
F
.644 .54866 m .6436 .5479 L .64628 .55174 L 0 .154 0 r
F
.64052 .54387 m .64018 .54248 L .63973 .54176 L 0 0 .138 r
F
.64093 .54497 m .6419 .54666 L .64052 .54387 L F
.6419 .54666 m .64796 .55726 L .64052 .54387 L F
.6372 .53877 m .64066 .56208 L .63975 .55458 L 0 0 .074 r
F
.6372 .53877 m .63975 .55458 L .63943 .55189 L F
.63228 .5251 m .64093 .54497 L .63451 .53128 L 0 0 .089 r
F
.64093 .54497 m .63957 .54132 L .63688 .5364 L 0 0 .138 r
F
.63652 .53683 m .63688 .5364 L .63957 .54132 L 0 .281 0 r
F
.62095 .50764 m .62308 .54918 L .62428 .53959 L 0 .371 .225 r
F
.61877 .4876 m .61855 .46647 L .61837 .47225 L 0 .196 .185 r
F
.61832 .47406 m .61877 .4876 L .61837 .47226 L F
.61731 .47273 m .62104 .52209 L .62095 .50764 L 0 .371 .225 r
F
.62104 .52209 m .62308 .54918 L .62095 .50764 L F
.6154 .38627 m .61832 .47406 L .61636 .39547 L 0 .196 .185 r
F
.61731 .47273 m .62428 .53959 L .62149 .45729 L 0 .371 .225 r
F
.62428 .53959 m .6287 .58202 L .62507 .51919 L F
.62428 .53959 m .62507 .51919 L .62149 .45729 L F
.61999 .51249 m .63581 .53488 L .63652 .53683 L 0 .281 0 r
F
.63581 .53488 m .63688 .5364 L .63652 .53683 L F
.6323 .52518 m .63451 .53128 L .63397 .53013 L 0 0 .089 r
F
.63228 .5251 m .63451 .53128 L .6323 .52518 L F
.63233 .5258 m .63397 .53013 L .63239 .52676 L F
.63228 .5251 m .63397 .53013 L .63233 .5258 L F
.61999 .51249 m .63652 .53683 L .63485 .53609 L 0 .281 0 r
F
.63652 .53683 m .63957 .54132 L .63724 .53874 L F
.63652 .53683 m .63724 .53874 L .63485 .53609 L F
.62588 .52417 m .64288 .54694 L .644 .54866 L 0 .154 0 r
F
.64288 .54694 m .6436 .5479 L .644 .54866 L F
.64093 .54497 m .65617 .57488 L .6574 .57624 L 0 0 .138 r
F
.63778 .56531 m .64066 .56208 L .63685 .53915 L 0 .122 .176 r
F
.64093 .54497 m .66053 .58219 L .65648 .57359 L 0 0 .138 r
F
.64093 .54497 m .64901 .56135 L .65742 .57731 L F
.62588 .52417 m .64319 .54774 L .6392 .54271 L 0 .154 0 r
F
.62588 .52417 m .63178 .53339 L .62304 .52157 L F
.62588 .52417 m .64122 .54552 L .63178 .53339 L F
.63112 .53253 m .63769 .54053 L .62997 .53093 L 0 0 .149 r
F
.6297 .53063 m .62997 .53093 L .62939 .53021 L F
.63112 .53253 m .62997 .53093 L .6297 .53063 L F
.62588 .52417 m .644 .54866 L .64319 .54774 L 0 .154 0 r
F
.62588 .52417 m .63485 .53609 L .6436 .5479 L F
.63769 .54053 m .63416 .53508 L .63193 .53294 L 0 .106 .183 r
F
.63183 .53305 m .63193 .53294 L .63416 .53508 L 0 0 0 r
F
.63112 .53253 m .62939 .53021 L .62904 .52981 L 0 0 .149 r
F
.60834 .41353 m .61552 .54149 L .61219 .48063 L 0 .919 .089 r
F
.60781 .40513 m .61157 .47228 L .6154 .54545 L F
.60064 .44004 m .61177 .48822 L .61454 .55557 L 0 .825 .204 r
F
.60746 .39818 m .61157 .47228 L .60781 .40513 L 0 .919 .089 r
F
.60834 .41353 m .6154 .54545 L .61552 .54149 L F
.60781 .40513 m .6154 .54545 L .60834 .41353 L F
.61177 .48822 m .61279 .49262 L .61383 .52979 L 0 .825 .204 r
F
.61177 .48822 m .61383 .52979 L .61454 .55557 L F
.61279 .49262 m .61299 .49648 L .61454 .55557 L F
.61219 .48063 m .61552 .54149 L .6129 .49308 L 0 .919 .089 r
F
.61552 .54149 m .61593 .54778 L .6129 .49308 L F
.63178 .53339 m .62859 .52922 L .62637 .5264 L 0 0 .149 r
F
.61214 .51581 m .63113 .53224 L .63183 .53305 L 0 0 0 r
F
.63113 .53224 m .63193 .53294 L .63183 .53305 L F
.61214 .51581 m .63183 .53305 L .63069 .53217 L F
.61214 .51581 m .63069 .53217 L .62551 .52787 L F
.61214 .51581 m .6277 .52985 L .61685 .52073 L F
.61214 .51581 m .6225 .52468 L .63193 .53294 L F
.61718 .52098 m .63291 .53363 L .62157 .52433 L 0 .137 .174 r
F
.61685 .52073 m .61773 .52144 L .61718 .52098 L F
.61773 .52144 m .63291 .53363 L .61718 .52098 L F
.62551 .52787 m .63069 .53217 L .6277 .52985 L 0 0 0 r
F
.63183 .53305 m .63416 .53508 L .63227 .53355 L F
.63183 .53305 m .63227 .53355 L .6277 .52985 L F
.62904 .52981 m .62939 .53021 L .62859 .52922 L 0 0 .149 r
F
.63178 .53339 m .63238 .53411 L .63112 .53253 L F
.63238 .53411 m .63769 .54053 L .63112 .53253 L F
.6392 .54271 m .64319 .54774 L .64122 .54552 L 0 .154 0 r
F
.644 .54866 m .64628 .55174 L .64472 .54983 L F
.644 .54866 m .64472 .54983 L .64122 .54552 L F
.63973 .54176 m .64018 .54248 L .63957 .54132 L 0 0 .138 r
F
.65617 .57488 m .65742 .57731 L .6574 .57624 L F
.64965 .57328 m .65261 .58345 L .65128 .57844 L 0 0 .095 r
F
.64965 .57328 m .65128 .57844 L .65001 .57364 L F
.6317 .50077 m .63309 .51035 L .63327 .51114 L 0 0 .074 r
F
.63074 .4944 m .63157 .5001 L .6317 .50077 L F
.62572 .46113 m .63027 .4919 L .63074 .4944 L F
.62511 .45713 m .62561 .4605 L .62572 .46113 L F
.63399 .51549 m .63586 .51921 L .63247 .50156 L 0 0 .117 r
F
.63331 .50672 m .63247 .50156 L .6342 .51056 L 0 .566 .019 r
F
.61971 .42851 m .61959 .43266 L .62149 .45729 L 0 0 .114 r
F
.61973 .42795 m .62149 .45729 L .6214 .44404 L F
.61971 .42851 m .62149 .45729 L .61973 .42795 L F
.61731 .47273 m .62149 .45729 L .61676 .3962 L 0 .371 .225 r
F
.62511 .45713 m .62594 .4626 L .62734 .47062 L 0 0 .074 r
F
.62594 .4626 m .63399 .51549 L .62915 .48281 L F
.62594 .4626 m .62915 .48281 L .62734 .47062 L F
.63212 .50156 m .63241 .5013 L .63331 .50672 L 0 .566 .019 r
F
.62015 .44971 m .63142 .49714 L .63212 .50156 L F
.63142 .49714 m .63241 .5013 L .63212 .50156 L F
.63241 .5013 m .63247 .50156 L .63331 .50672 L F
.62469 .46582 m .62734 .47062 L .62574 .47178 L 0 .771 .071 r
F
.62141 .44411 m .62159 .44694 L .62147 .4451 L 0 0 .114 r
F
.6214 .44404 m .62159 .44694 L .62141 .44411 L F
.60441 .26816 m .61732 .47306 L .60441 .26815 L 0 .529 .227 r
F
.61232 .3951 m .62326 .45009 L .62469 .46582 L 0 .771 .071 r
F
.62326 .45009 m .62734 .47062 L .62469 .46582 L F
.63475 .51428 m .6342 .51056 L .63586 .51921 L 0 .566 .019 r
F
.62015 .44971 m .6342 .51056 L .63475 .51428 L F
.62015 .44971 m .63475 .51428 L .6339 .51514 L F
.63475 .51428 m .63586 .51921 L .63528 .518 L F
.63475 .51428 m .63528 .518 L .6339 .51514 L F
.61698 .37236 m .61906 .39624 L .61985 .4031 L 0 0 .128 r
F
.62566 .45352 m .62582 .45463 L .62594 .4557 L 0 .545 0 r
F
.6255 .45212 m .62582 .45463 L .62566 .45352 L F
.61907 .4015 m .62332 .43469 L .62356 .43687 L F
.61604 .37765 m .61905 .40118 L .61907 .4015 L F
.61905 .40118 m .62332 .43469 L .61907 .4015 L F
.60934 .26109 m .60988 .28117 L .60901 .26001 L 0 .693 .059 r
F
.60901 .26001 m .60988 .28117 L .60881 .25928 L F
.60881 .25928 m .61676 .3962 L .6092 .25841 L 0 0 .114 r
F
.60881 .25928 m .60988 .28121 L .61676 .3962 L F
.60629 .26213 m .61801 .38546 L .61604 .37764 L 0 .765 .068 r
F
.61801 .38546 m .6207 .41375 L .61899 .40049 L F
.61801 .38546 m .61899 .40049 L .61604 .37764 L F
.60964 .2568 m .60971 .25783 L .60974 .2583 L 0 0 .114 r
F
.61905 .40118 m .6207 .41377 L .62332 .43469 L 0 .545 0 r
F
.61604 .37765 m .61899 .4005 L .61905 .40118 L F
.61899 .4005 m .6207 .41377 L .61905 .40118 L F
.62356 .43687 m .62332 .43469 L .62582 .45463 L F
.62594 .4557 m .62582 .45463 L .62713 .46513 L F
.62594 .4557 m .62713 .46513 L .62693 .46468 L F
.61415 .26165 m .61493 .33823 L .61903 .32398 L 0 .36 .222 r
F
.61536 .26028 m .61903 .32398 L .61504 .25865 L 0 .633 .026 r
F
.61504 .25865 m .61964 .34201 L .61455 .25615 L F
.61504 .25865 m .61903 .32398 L .61964 .34201 L F
.61455 .25615 m .61964 .34201 L .61524 .27524 L F
.61524 .27524 m .62624 .42024 L .62727 .42889 L 0 0 .125 r
F
.62938 .44255 m .62727 .42889 L .6306 .45697 L F
.61524 .27524 m .62727 .42889 L .62938 .44255 L F
.61493 .33823 m .61494 .33836 L .61494 .33821 L 0 .36 .222 r
F
.61279 .49262 m .6129 .49308 L .61299 .49648 L 0 .825 .204 r
F
.60136 .5874 m .60109 .58224 L .60109 .58224 L 0 1 .156 r
F
.60136 .5874 m .60109 .58224 L .60136 .5874 L F
.60109 .58224 m .60062 .57329 L .60109 .58224 L F
.60109 .58224 m .60109 .58224 L .60085 .57771 L F
.60085 .57771 m .60085 .57771 L .60062 .57329 L F
.6003 .57134 m .60075 .57986 L .60077 .58067 L F
.60007 .58983 m .60099 .59484 L .60022 .59531 L 0 .858 .083 r
F
.60099 .59484 m .60111 .59901 L .60022 .59531 L F
.60091 .58188 m .60073 .57841 L .60072 .57838 L 0 1 .156 r
F
.60091 .5819 m .60073 .57841 L .60091 .58188 L F
.60073 .57841 m .6006 .57609 L .60072 .57838 L F
.60126 .60537 m .60788 .64373 L .60129 .60665 L 0 .858 .083 r
F
.60129 .60665 m .60133 .61095 L .60058 .60615 L F
.60058 .60615 m .60133 .61095 L .60133 .61205 L F
.60147 .62592 m .60153 .62993 L .60137 .62976 L 0 .771 .083 r
F
.60085 .58082 m .60085 .58083 L .6006 .57609 L 0 1 .156 r
F
.60064 .61678 m .6043 .61614 L .60064 .61794 L 0 .297 .144 r
F
.60137 .62976 m .60153 .62993 L .60153 .6303 L 0 .771 .083 r
F
.6006 .57305 m .6008 .5769 L .6006 .57607 L 0 1 .156 r
F
.6008 .5769 m .60085 .5808 L .6006 .57607 L F
.60064 .62291 m .6043 .61614 L .60181 .62385 L 0 .297 .144 r
F
.60064 .61794 m .6043 .61614 L .60064 .62291 L F
.61518 .74198 m .61746 .76283 L .61753 .75023 L 0 .297 .226 r
F
.61518 .74198 m .61753 .75023 L .61761 .73607 L F
.59659 .61288 m .59681 .61345 L .59681 .61345 L 0 .771 .083 r
F
.59688 .61516 m .60265 .59903 L .60313 .60834 L 0 .297 .144 r
F
.59659 .61288 m .60265 .59903 L .59688 .61516 L F
.59631 .61213 m .59659 .61287 L .59659 .61288 L 0 .771 .083 r
F
.59426 .60665 m .59631 .6121 L .59631 .61213 L F
.59641 .60548 m .59816 .60304 L .59693 .60789 L 0 .248 .155 r
F
.58604 .55189 m .59494 .5712 L .59675 .58495 L 0 .849 .145 r
F
.59528 .59621 m .59509 .58216 L .59675 .58495 L 0 .248 .155 r
F
.59528 .59621 m .59675 .58495 L .59679 .59218 L F
.59453 .58466 m .59509 .58216 L .59528 .59621 L F
.58604 .55189 m .59675 .58495 L .59679 .59218 L 0 .849 .145 r
F
.59674 .59473 m .5974 .59203 L .59655 .60528 L 0 .248 .155 r
F
.5974 .59203 m .59843 .58778 L .59759 .59559 L F
.5974 .59203 m .59759 .59559 L .59655 .60528 L F
.57774 .66123 m .57804 .66047 L .57801 .66064 L 0 0 .073 r
F
.57804 .66047 m .58942 .63127 L .57801 .66064 L F
.57804 .66047 m .58653 .63426 L .58942 .63127 L F
.57774 .66123 m .57807 .66024 L .57804 .66047 L F
.57807 .66024 m .58653 .63426 L .57804 .66047 L F
.59642 .6046 m .59679 .59218 L .59655 .60528 L 0 .849 .145 r
F
.58604 .55189 m .59534 .58674 L .59642 .6046 L F
.59534 .58674 m .59679 .59218 L .59642 .6046 L F
.59655 .60528 m .59769 .59469 L .59816 .60304 L 0 .248 .155 r
F
.59769 .59469 m .59843 .58778 L .59817 .60246 L F
.59769 .59469 m .59817 .60246 L .59816 .60304 L F
.57964 .64826 m .5843 .62922 L .58228 .64566 L 0 0 .088 r
F
.5843 .62922 m .58685 .61879 L .58448 .63271 L F
.5843 .62922 m .58448 .63271 L .58228 .64566 L F
.57774 .66123 m .58154 .64706 L .5848 .63869 L 0 0 .073 r
F
.58484 .63945 m .5848 .63869 L .58653 .63426 L F
.57774 .66123 m .5848 .63869 L .58484 .63945 L F
.58348 .63473 m .58902 .63914 L .59364 .64514 L 0 .378 .044 r
F
.5935 .64532 m .59364 .64514 L .59501 .64691 L F
.57774 .66123 m .57922 .66159 L .57674 .66749 L 0 0 .073 r
F
.57141 .69026 m .57571 .67053 L .57307 .68041 L 0 .769 .072 r
F
.57571 .67053 m .57774 .66123 L .57532 .67117 L F
.57571 .67053 m .57532 .67117 L .57307 .68041 L F
.57837 .66352 m .57843 .66348 L .57922 .66159 L 0 .81 .096 r
F
.57632 .66655 m .57922 .66159 L .57765 .66332 L F
.5676 .68782 m .57837 .66352 L .57632 .66655 L F
.57837 .66352 m .57922 .66159 L .57632 .66655 L F
.5676 .68782 m .57765 .66332 L .57306 .67154 L F
.58164 .65785 m .58289 .65496 L .58531 .65201 L 0 0 0 r
F
.57306 .67154 m .58011 .65965 L .58164 .65785 L F
.58011 .65965 m .58289 .65496 L .58164 .65785 L F
.57771 .66399 m .58531 .65201 L .58337 .65482 L F
.57786 .66389 m .58531 .65201 L .57771 .66399 L F
.57306 .67154 m .57765 .66331 L .58289 .65496 L F
.57306 .67154 m .58337 .65482 L .57836 .66153 L F
.57836 .66153 m .58894 .64839 L .59138 .64652 L F
.57836 .66153 m .5871 .65145 L .58914 .64903 L F
.5871 .65145 m .59138 .64652 L .58967 .64844 L F
.5871 .65145 m .58967 .64844 L .58914 .64903 L F
.57414 .66978 m .57786 .66389 L .57771 .66399 L F
.57306 .67154 m .5744 .6694 L .57414 .66978 L F
.5744 .6694 m .57786 .66389 L .57414 .66978 L F
.57409 .67317 m .57674 .66749 L .57843 .66348 L 0 .81 .096 r
F
.57409 .67317 m .57843 .66348 L .57837 .66352 L F
.5676 .68782 m .57445 .67258 L .57409 .67317 L F
.57445 .67258 m .57674 .66749 L .57409 .67317 L F
.57836 .66153 m .58337 .65482 L .58894 .64839 L 0 0 0 r
F
.57836 .66153 m .58914 .64903 L .5837 .65428 L F
.58371 .65428 m .58914 .64903 L .59318 .64553 L F
.59259 .64657 m .59501 .64691 L .59745 .65288 L 0 .378 .044 r
F
.59306 .64572 m .59318 .64553 L .59364 .64514 L 0 0 0 r
F
.59306 .64572 m .59364 .64514 L .5935 .64532 L F
.58371 .65428 m .59318 .64553 L .59306 .64572 L F
.58371 .65428 m .59331 .6455 L .59259 .64657 L F
.59331 .6455 m .5935 .64532 L .59259 .64657 L F
.59165 .64798 m .59745 .65288 L .59482 .65312 L 0 .378 .044 r
F
.59059 .6438 m .59102 .64362 L .59084 .64466 L 0 .008 .064 r
F
.58425 .64869 m .59059 .6438 L .58531 .65201 L 0 .033 .084 r
F
.59059 .6438 m .59138 .64652 L .58894 .64839 L 0 .008 .064 r
F
.59097 .64689 m .59259 .64657 L .59131 .64744 L 0 .378 .044 r
F
.58348 .63473 m .59214 .64599 L .59097 .64689 L F
.59214 .64599 m .59259 .64657 L .59097 .64689 L F
.59059 .6438 m .5911 .64293 L .59108 .64316 L 0 .008 .064 r
F
.59059 .6438 m .59108 .64316 L .59107 .64334 L F
.59059 .6438 m .59107 .64334 L .59105 .64347 L F
.59059 .6438 m .59105 .64347 L .59102 .64362 L F
.58348 .63473 m .5935 .64532 L .59259 .64657 L 0 .378 .044 r
F
.5935 .64532 m .59384 .64568 L .59259 .64657 L F
.59384 .64568 m .59501 .64691 L .59259 .64657 L F
.59097 .64689 m .59131 .64744 L .59025 .64745 L F
.58371 .65428 m .59077 .64793 L .58885 .64848 L 0 0 0 r
F
.59077 .64793 m .59081 .6479 L .59066 .64794 L F
.59077 .64793 m .59066 .64794 L .58885 .64848 L F
.59081 .6479 m .59 .648 L .58885 .64848 L F
.59131 .64744 m .58948 .64805 L .58946 .64806 L F
.59008 .64797 m .58946 .64806 L .58885 .64848 L F
.59131 .64744 m .58946 .64806 L .59008 .64797 L F
.58962 .64915 m .59246 .64668 L .58938 .64918 L F
.59246 .64668 m .59241 .64672 L .58938 .64918 L F
.59259 .64657 m .59182 .64712 L .58938 .64918 L F
.58938 .64918 m .59195 .64701 L .59131 .64744 L F
.59259 .64657 m .59497 .64398 L .59731 .64248 L F
.59259 .64657 m .59731 .64248 L .59182 .64712 L F
.59131 .64744 m .59731 .64248 L .5947 .6444 L F
.59363 .64519 m .5947 .6444 L .60083 .64022 L F
.59131 .64744 m .5904 .64775 L .58997 .64766 L 0 .378 .044 r
F
.59131 .64744 m .58997 .64766 L .59025 .64745 L F
.59165 .64798 m .59081 .64932 L .58948 .64805 L F
.58997 .64766 m .58948 .64805 L .58884 .64745 L F
.59081 .6479 m .59131 .64744 L .59 .648 L 0 0 0 r
F
.59051 .64777 m .58948 .64805 L .58997 .64766 L 0 .378 .044 r
F
.58348 .63473 m .59364 .64514 L .5935 .64532 L F
.5935 .64532 m .59497 .64398 L .59259 .64657 L 0 0 0 r
F
.59131 .64744 m .5947 .6444 L .58949 .64805 L F
.58948 .64805 m .5947 .6444 L .58948 .64805 L F
.58939 .64812 m .60113 .66075 L .60358 .66525 L 0 .297 0 r
F
.58884 .64745 m .58943 .64809 L .58939 .64812 L F
.58936 .64814 m .58939 .64812 L .58929 .64816 L 0 0 0 r
F
.58944 .64808 m .58945 .64807 L .58942 .64809 L F
.58945 .64807 m .58943 .64809 L .58942 .64809 L F
.58946 .64806 m .58948 .64805 L .58944 .64808 L F
.59057 .64729 m .5947 .6444 L .59066 .64723 L F
.59057 .64729 m .59066 .64723 L .58943 .64809 L F
.58945 .64807 m .59057 .64729 L .58943 .64809 L F
.58948 .64805 m .5947 .6444 L .58944 .64808 L F
.58942 .64809 m .5947 .6444 L .59363 .64519 L F
.5893 .64809 m .58933 .64813 L .5892 .6481 L 0 .297 0 r
F
.58933 .64813 m .58933 .64813 L .58933 .64813 L 0 0 0 r
F
.58929 .64816 m .58933 .64813 L .58933 .64813 L F
.58933 .64813 m .58934 .64813 L .58933 .64813 L F
.59195 .64701 m .59731 .64248 L .59131 .64744 L F
.58936 .64814 m .60083 .64022 L .60319 .63872 L F
.58934 .64813 m .60319 .63872 L .58933 .64813 L F
.58934 .64813 m .58933 .64813 L .58933 .64813 L F
.58939 .64812 m .58934 .64813 L .58933 .64813 L F
.58885 .64848 m .58946 .64806 L .58942 .64809 L F
.58939 .64812 m .58936 .64815 L .58934 .64813 L 0 .297 0 r
F
.58939 .64812 m .58934 .64813 L .5893 .64809 L F
.58939 .64812 m .58933 .64813 L .58929 .64816 L 0 0 0 r
F
.58941 .6481 m .58939 .64812 L .58915 .64828 L F
.58915 .64828 m .58939 .64812 L .58936 .64814 L F
.59467 .65724 m .59504 .71312 L .59475 .65971 L 0 .93 .212 r
F
.59467 .65724 m .59475 .65971 L .59472 .65803 L F
.58921 .64812 m .60062 .66371 L .59421 .65715 L 0 .297 0 r
F
.5892 .6481 m .58921 .64812 L .58921 .64812 L F
.58921 .64812 m .60062 .66371 L .58921 .64812 L F
.58348 .63473 m .59097 .64689 L .58884 .64745 L 0 .378 .044 r
F
.59097 .64689 m .59025 .64745 L .58884 .64745 L F
.58348 .63473 m .58884 .64745 L .58284 .63965 L F
.58425 .64869 m .58531 .65201 L .58289 .65496 L 0 .033 .084 r
F
.58371 .65428 m .58885 .64848 L .583 .65356 L 0 0 0 r
F
.58884 .64745 m .58853 .64812 L .58587 .6459 L 0 .297 0 r
F
.58885 .64848 m .58853 .64812 L .58592 .64975 L 0 0 0 r
F
.58853 .64812 m .58789 .64951 L .58716 .64821 L 0 .297 0 r
F
.58853 .64812 m .58716 .64821 L .58587 .6459 L F
.58853 .64812 m .58786 .64734 L .58716 .64821 L 0 0 0 r
F
.5736 .65842 m .58592 .64975 L .58713 .64826 L 0 1 .247 r
F
.57338 .63697 m .58587 .6459 L .58716 .64821 L 0 .236 .005 r
F
.58655 .64836 m .58713 .64826 L .58716 .64821 L 0 1 .247 r
F
.5736 .65842 m .58713 .64826 L .58655 .64836 L F
.58853 .64812 m .58732 .6482 L .58592 .64975 L 0 0 0 r
F
.58655 .64836 m .58716 .64821 L .58789 .64951 L 0 .236 .005 r
F
.57338 .63697 m .58716 .64821 L .58655 .64836 L F
.58655 .64836 m .58716 .64821 L .58786 .64734 L 0 1 .247 r
F
.58387 .64837 m .58655 .64836 L .58391 .64842 L 0 .236 .005 r
F
.57338 .63697 m .58638 .64821 L .58387 .64837 L F
.58638 .64821 m .58655 .64836 L .58387 .64837 L F
.57338 .63697 m .58387 .64837 L .57764 .64449 L F
.5736 .65842 m .58639 .64849 L .58391 .64842 L 0 1 .247 r
F
.58639 .64849 m .58655 .64836 L .58391 .64842 L F
.58387 .64837 m .58391 .64842 L .58355 .64838 L 0 .236 .005 r
F
.58387 .64837 m .58355 .64838 L .57764 .64449 L F
.57764 .64449 m .57991 .64745 L .57535 .64473 L 0 .126 0 r
F
.5736 .65842 m .5837 .64862 L .57772 .65126 L 0 1 .247 r
F
.5837 .64862 m .58375 .64857 L .58367 .64861 L F
.5837 .64862 m .58367 .64861 L .57772 .65126 L F
.58375 .64857 m .58366 .64855 L .57772 .65126 L F
.58388 .64845 m .58355 .64838 L .58343 .64844 L F
.58372 .64852 m .58343 .64844 L .57772 .65126 L F
.58388 .64845 m .58343 .64844 L .58372 .64852 L F
.57772 .65126 m .58265 .64845 L .58199 .64849 L 0 1 .306 r
F
.58265 .64845 m .58282 .64836 L .58199 .64849 L F
.58371 .65428 m .58962 .64915 L .58938 .64918 L 0 0 0 r
F
.5736 .65842 m .57981 .65449 L .58592 .64975 L 0 1 .247 r
F
.57764 .64449 m .58355 .64838 L .58271 .64821 L 0 .126 0 r
F
.58287 .64833 m .58436 .64798 L .59079 .64382 L 0 1 .306 r
F
.57772 .65126 m .58355 .64838 L .58287 .64833 L F
.58355 .64838 m .58301 .64834 L .58271 .64821 L 0 .126 0 r
F
.58355 .64838 m .58436 .64798 L .58287 .64833 L 0 1 .306 r
F
.58375 .64857 m .58388 .64845 L .58366 .64855 L 0 1 .247 r
F
.58355 .64838 m .58437 .64892 L .58301 .64834 L 0 .126 0 r
F
.58287 .64833 m .58437 .64892 L .59092 .65424 L F
.58271 .64821 m .58301 .64834 L .58287 .64833 L F
.58301 .64834 m .58437 .64892 L .58287 .64833 L F
.58282 .64836 m .58287 .64833 L .58237 .64829 L 0 1 .306 r
F
.58287 .64833 m .58238 .64829 L .58237 .64829 L F
.58282 .64836 m .58237 .64829 L .58199 .64849 L F
.57764 .64449 m .58287 .64833 L .58231 .64829 L 0 .126 0 r
F
.58215 .64841 m .59079 .64382 L .58212 .64841 L 0 1 .306 r
F
.58231 .64829 m .59092 .65424 L .59295 .65693 L 0 .126 0 r
F
.58287 .64833 m .59092 .65424 L .58231 .64829 L F
.58231 .64829 m .59079 .64382 L .59275 .64153 L 0 1 .306 r
F
.58212 .64841 m .58235 .64829 L .58231 .64829 L F
.58235 .64829 m .59079 .64382 L .58231 .64829 L F
.58287 .64833 m .59079 .64382 L .58238 .64829 L F
.58206 .64808 m .58231 .64829 L .58128 .64787 L 0 .126 0 r
F
.58199 .64849 m .58215 .64841 L .58212 .64841 L 0 1 .306 r
F
.57772 .65126 m .58228 .64831 L .5815 .64808 L F
.58228 .64831 m .58231 .64829 L .5815 .64808 L F
.57772 .65126 m .58 .64757 L .57539 .64875 L F
.57764 .64449 m .58206 .64808 L .58128 .64787 L 0 .126 0 r
F
.57772 .65126 m .5815 .64808 L .58 .64757 L 0 1 .306 r
F
.58 .64757 m .58909 .65514 L .58192 .65007 L 0 .126 0 r
F
.57991 .64745 m .58009 .6476 L .58 .64757 L F
.58009 .6476 m .58909 .65514 L .58 .64757 L F
.57764 .64449 m .58128 .64787 L .57991 .64745 L F
.57338 .63697 m .57966 .64052 L .58587 .6459 L 0 .236 .005 r
F
.58 .64757 m .58892 .64185 L .58185 .64457 L 0 1 .306 r
F
.58128 .64787 m .58146 .64804 L .57991 .64745 L 0 .126 0 r
F
.58146 .64804 m .5815 .64808 L .58115 .64794 L F
.58146 .64804 m .58115 .64794 L .57991 .64745 L F
.5815 .64808 m .58021 .6477 L .57991 .64745 L F
.5815 .64808 m .59295 .65693 L .58909 .65514 L F
.58128 .64787 m .58158 .6481 L .5815 .64808 L F
.58158 .6481 m .59295 .65693 L .5815 .64808 L F
.5815 .64808 m .58892 .64185 L .58 .64757 L 0 1 .306 r
F
.57991 .64745 m .57801 .64689 L .57535 .64473 L 0 .126 0 r
F
.58 .64757 m .58185 .64457 L .57815 .64696 L 0 1 .306 r
F
.57991 .64745 m .58 .64757 L .57801 .64689 L 0 .126 0 r
F
.58 .64757 m .57812 .64698 L .57539 .64875 L 0 1 .306 r
F
.58 .64757 m .58192 .65007 L .57812 .64698 L 0 .126 0 r
F
.58 .64757 m .57812 .64698 L .57801 .64689 L F
.58 .64757 m .57815 .64696 L .57812 .64698 L 0 1 .306 r
F
.5815 .64808 m .58909 .65514 L .58021 .6477 L 0 .126 0 r
F
.5815 .64808 m .59275 .64153 L .58892 .64185 L 0 1 .306 r
F
.58231 .64829 m .58157 .6481 L .58128 .64787 L 0 .126 0 r
F
.58231 .64829 m .59275 .64153 L .5815 .64808 L 0 1 .306 r
F
.58231 .64829 m .5817 .6482 L .58157 .6481 L 0 .126 0 r
F
.58231 .64829 m .59295 .65693 L .5817 .6482 L F
.58388 .64845 m .58436 .64798 L .58355 .64838 L 0 1 .247 r
F
.58391 .64842 m .58437 .64892 L .5836 .64841 L 0 .236 .005 r
F
.58391 .64842 m .5836 .64841 L .58355 .64838 L F
.58391 .64842 m .58786 .64734 L .58436 .64798 L 0 1 .247 r
F
.58655 .64836 m .58786 .64734 L .58391 .64842 L F
.58391 .64842 m .58655 .64836 L .58424 .64878 L 0 .236 .005 r
F
.58424 .64878 m .58661 .64841 L .58437 .64892 L F
.58655 .64836 m .58661 .64841 L .58424 .64878 L F
.58732 .6482 m .58713 .64826 L .58592 .64975 L 0 0 0 r
F
.58661 .64841 m .58789 .64951 L .58468 .64897 L 0 .236 .005 r
F
.58661 .64841 m .58468 .64897 L .58437 .64892 L F
.58732 .6482 m .58716 .64821 L .58713 .64826 L 0 0 0 r
F
.58852 .6481 m .59403 .64314 L .58786 .64734 L F
.58885 .64848 m .58921 .64812 L .58853 .64812 L F
.58885 .64848 m .58918 .64826 L .58915 .64828 L F
.58904 .64812 m .59421 .65715 L .5885 .64818 L 0 .297 0 r
F
.5892 .6481 m .58921 .64812 L .58904 .64812 L F
.58885 .64848 m .58933 .64813 L .58921 .64812 L 0 0 0 r
F
.58918 .64826 m .58941 .6481 L .58915 .64828 L F
.58885 .64848 m .58936 .64814 L .58929 .64816 L F
.58921 .64812 m .59421 .65715 L .58904 .64812 L 0 .297 0 r
F
.58884 .64745 m .5892 .6481 L .5885 .64818 L F
.58853 .64812 m .58921 .64812 L .58852 .6481 L 0 0 0 r
F
.58884 .64745 m .58951 .64809 L .58945 .6481 L 0 .297 0 r
F
.58884 .64745 m .58936 .64808 L .5893 .64809 L F
.58884 .64745 m .5893 .64809 L .5892 .6481 L F
.59025 .64745 m .58997 .64766 L .58884 .64745 L 0 .378 .044 r
F
.58921 .64812 m .59403 .64314 L .58852 .6481 L 0 0 0 r
F
.59699 .64105 m .59731 .64248 L .59497 .64398 L 0 0 .017 r
F
.59699 .64105 m .60315 .63853 L .59731 .64248 L F
.58921 .64812 m .60028 .63997 L .59403 .64314 L 0 0 0 r
F
.58933 .64813 m .58921 .64812 L .5892 .6481 L 0 .297 0 r
F
.5893 .64809 m .58934 .64813 L .58933 .64813 L F
.58936 .64808 m .58939 .64812 L .5893 .64809 L F
.58933 .64813 m .60028 .63997 L .58921 .64812 L 0 0 0 r
F
.58933 .64813 m .58923 .64814 L .58921 .64812 L 0 .297 0 r
F
.58933 .64813 m .60062 .66371 L .58923 .64814 L F
.58941 .6481 m .60083 .64022 L .58939 .64812 L 0 0 0 r
F
.58939 .64812 m .60083 .64022 L .58936 .64814 L F
.5935 .64532 m .59364 .64514 L .59497 .64398 L F
.60315 .63853 m .60319 .63872 L .60083 .64022 L F
.58933 .64813 m .60319 .63872 L .60028 .63997 L F
.58933 .64813 m .60319 .63872 L .58933 .64813 L F
.58945 .6481 m .59482 .65312 L .60113 .66075 L 0 .297 0 r
F
.58951 .64809 m .59482 .65312 L .58945 .6481 L F
.58933 .64813 m .60358 .66525 L .60062 .66371 L F
.58934 .64813 m .60358 .66525 L .58933 .64813 L F
.58939 .64812 m .60319 .63872 L .58934 .64813 L 0 0 0 r
F
.58943 .64809 m .58945 .6481 L .58939 .64812 L 0 .297 0 r
F
.58945 .6481 m .60113 .66075 L .58939 .64812 L F
.59165 .64798 m .58965 .64805 L .59051 .64777 L 0 .378 .044 r
F
.58965 .64805 m .58948 .64805 L .59051 .64777 L F
.58939 .64812 m .60358 .66525 L .58936 .64815 L 0 .297 0 r
F
.5885 .64818 m .59421 .65715 L .58789 .64951 L F
.59131 .64744 m .59075 .64781 L .5904 .64775 L 0 .378 .044 r
F
.59131 .64744 m .59165 .64798 L .59075 .64781 L F
.59246 .64668 m .59259 .64657 L .59241 .64672 L 0 0 0 r
F
.59131 .64744 m .59259 .64657 L .59165 .64798 L 0 .378 .044 r
F
.59259 .64657 m .59745 .65288 L .59165 .64798 L F
.59165 .64798 m .59482 .65312 L .59081 .64932 L F
.58541 .44081 m .59209 .5109 L .59299 .53808 L 0 .875 .195 r
F
.58906 .40764 m .58896 .41698 L .58875 .392 L 0 1 .183 r
F
.58896 .41698 m .58862 .40669 L .58875 .392 L F
.59553 .48368 m .59507 .4735 L .59647 .47551 L 0 .265 .185 r
F
.59799 .50777 m .5987 .51994 L .59802 .50857 L 0 1 .156 r
F
.59802 .50857 m .5987 .51994 L .59803 .50879 L F
.59149 .28169 m .59156 .28392 L .59131 .27169 L 0 1 .169 r
F
.59634 .45013 m .59954 .48738 L .59766 .49625 L 0 1 .156 r
F
.59016 .27036 m .58946 .30834 L .58743 .26969 L 0 .824 .212 r
F
.5898 .26917 m .58946 .30834 L .59016 .27036 L 0 1 .183 r
F
.58915 .30235 m .58946 .30834 L .58858 .30777 L 0 .824 .212 r
F
.58946 .30834 m .58916 .31677 L .58858 .30777 L F
.58546 .44022 m .59154 .48462 L .59206 .51004 L 0 .875 .195 r
F
.59047 .26749 m .58977 .33725 L .58973 .27704 L 0 1 .183 r
F
.58977 .33725 m .58946 .30834 L .58973 .27704 L F
.58762 .27602 m .58992 .35164 L .58605 .27325 L 0 .824 .212 r
F
.58992 .35164 m .59007 .36614 L .58605 .27325 L F
.58762 .27602 m .58605 .27325 L .58584 .26844 L F
.58323 .50005 m .58572 .48114 L .58906 .51675 L 0 .721 .193 r
F
.58898 .51913 m .58906 .51675 L .58942 .5206 L F
.58323 .50005 m .58906 .51675 L .58898 .51913 L F
.57782 .48209 m .58392 .48136 L .58323 .50005 L F
.58392 .48136 m .58572 .48114 L .58323 .50005 L F
.58513 .44778 m .58942 .5206 L .58572 .48114 L 0 .875 .195 r
F
.58488 .43405 m .58532 .44235 L .58513 .44778 L F
.58532 .44235 m .58942 .5206 L .58513 .44778 L F
.58743 .26969 m .58915 .30235 L .58858 .30777 L 0 .824 .212 r
F
.59821 1.21988 m .59801 1.20591 L .59814 1.20354 L 0 .789 .222 r
F
.59663 .64649 m .60231 .65541 L .59709 .648 L 0 .592 .07 r
F
.59037 .62611 m .59075 .62705 L .59073 .62728 L F
.59037 .62611 m .59073 .62728 L .59059 .62872 L F
.60452 1.04464 m .60516 1.06358 L .60508 1.06667 L 0 .928 .09 r
F
.60448 1.04507 m .60444 1.0421 L .60446 1.04271 L F
.60445 1.0435 m .60444 1.0421 L .60448 1.04507 L F
.60453 1.0351 m .60444 1.03981 L .60454 1.04506 L 0 1 .169 r
F
.60453 1.0351 m .60454 1.04506 L .60492 1.0563 L F
.60448 1.04507 m .60446 1.04271 L .60452 1.04464 L 0 .928 .09 r
F
.60892 .92019 m .61092 .9898 L .61169 .89772 L 0 .654 .228 r
F
.605 .95207 m .60764 .96891 L .60892 .92019 L F
.60764 .96891 m .61092 .9898 L .60892 .92019 L F
.6077 1.01188 m .60764 .96891 L .605 .95207 L F
.61334 1.00505 m .61335 1.00527 L .61335 1.00504 L F
.61335 1.0071 m .61329 .91513 L .61524 .90416 L 0 .548 .225 r
F
.61334 1.00505 m .61335 1.00504 L .61419 .87738 L 0 .654 .228 r
F
.61169 .89772 m .61334 1.00505 L .61419 .87738 L F
.61092 .9898 m .61335 1.00527 L .61169 .89772 L F
.61335 1.0071 m .61339 1.00495 L .6134 1.00492 L 0 .548 .225 r
F
.61339 1.00495 m .61524 .90416 L .6134 1.00492 L F
.6134 1.00492 m .61524 .90416 L .61543 .92246 L F
.60682 1.11292 m .59884 .72068 L .59916 .744 L 0 1 .169 r
F
.61335 1.00527 m .61546 .91787 L .61419 .87738 L 0 .654 .228 r
F
.6018 .90058 m .6026 .93982 L .60262 .94108 L 0 1 .169 r
F
.6018 .90058 m .60262 .94108 L .60182 .90155 L F
.60262 .94108 m .60266 .9433 L .60182 .90155 L F
.60266 .9433 m .60182 .90157 L .60182 .90155 L F
.60266 .94335 m .60182 .90157 L .60266 .9433 L F
.60266 .94335 m .60266 .94343 L .60182 .90157 L F
.60166 .88871 m .60198 .90403 L .60197 .90448 L F
.60177 .89327 m .60198 .90403 L .60166 .88871 L F
.60159 .88418 m .60178 .8938 L .60177 .89327 L F
.60163 .88793 m .60173 .89224 L .60165 .889 L F
.60163 .88793 m .60165 .889 L .60117 .86909 L F
.60163 .88793 m .60162 .88681 L .60173 .89224 L F
.60182 .90155 m .60182 .90157 L .60112 .86713 L F
.60117 .86909 m .6018 .90058 L .60112 .86713 L F
.6018 .90058 m .60182 .90155 L .60112 .86713 L F
.60117 .86909 m .6018 .90029 L .6018 .90058 L F
.60117 .86909 m .60165 .889 L .6018 .90029 L F
.60165 .889 m .60173 .89224 L .6018 .90029 L F
.60112 .86713 m .60182 .90157 L .60183 .9026 L F
.59916 .744 m .60012 .81613 L .60444 1.03981 L F
.59916 .744 m .60444 1.03981 L .60453 1.0351 L F
.60016 .81956 m .60029 .82893 L .60442 1.04078 L F
.60031 .83071 m .60037 .83472 L .60441 1.04124 L F
.60227 1.02188 m .61372 .98423 L .61371 .96099 L 0 1 .252 r
F
.60227 1.02188 m .61362 1.00139 L .61612 .97634 L F
.60227 1.02188 m .60769 1.02096 L .61362 1.00139 L F
.60441 1.04124 m .60444 1.0421 L .60445 1.0435 L 0 .928 .09 r
F
.60388 1.06172 m .60347 1.02756 L .60384 1.05656 L F
.60062 1.04211 m .60769 1.02098 L .60227 1.02189 L 0 1 .25 r
F
.60012 .91317 m .59662 .69863 L .59821 1.15826 L 0 .93 .212 r
F
.5985 1.057 m .60133 1.05294 L .60062 1.04211 L 0 .775 .269 r
F
.59812 1.17911 m .59821 1.15826 L .59662 .69863 L 0 .93 .212 r
F
.59812 1.17911 m .59662 .69863 L .59658 .69646 L F
.59581 .83181 m .59751 1.09491 L .59584 .83067 L F
.59751 1.09491 m .59751 1.09503 L .59584 .83067 L F
.59764 1.11575 m .59765 1.11581 L .59758 1.10552 L F
.59758 1.10546 m .59758 1.10552 L .59584 .83067 L F
.59764 1.11575 m .59758 1.10552 L .59758 1.10546 L F
.59771 1.12581 m .59771 1.12585 L .59741 1.07845 L F
.59741 1.07842 m .59741 1.07845 L .59584 .83067 L F
.59771 1.12581 m .59741 1.07845 L .59741 1.07842 L F
.59775 1.13172 m .59775 1.13196 L .59774 1.12915 L F
.59772 1.12672 m .59772 1.12693 L .59584 .83067 L F
.61419 .87738 m .61429 .88066 L .61431 .88064 L 0 .813 .228 r
F
.61429 .88066 m .61546 .91787 L .61431 .88064 L F
.61431 .88064 m .61546 .91787 L .6155 .91079 L F
.61419 .87738 m .6155 .91079 L .61557 .9001 L F
.60283 .89163 m .60976 .88857 L .61443 .88052 L 0 1 .303 r
F
.60283 .89163 m .61443 .88052 L .61447 .87905 L F
.61419 .87738 m .61571 .87916 L .61606 .85994 L 0 .813 .228 r
F
.61419 .87738 m .61746 .76283 L .61344 .75993 L F
.60283 .89163 m .61447 .87905 L .61465 .87129 L 0 1 .303 r
F
.60283 .89163 m .61498 .85783 L .60789 .86119 L F
.60283 .89163 m .61465 .87129 L .61498 .85783 L F
.60283 .89163 m .60731 .86464 L .60097 .87306 L F
.59798 1.16772 m .59798 1.16771 L .59783 1.14388 L 0 .93 .212 r
F
.59772 1.12693 m .59772 1.12694 L .59584 .83067 L F
.59799 1.16926 m .598 1.16909 L .59784 1.14431 L F
.59772 1.12694 m .59773 1.1273 L .59584 .83067 L F
.60283 .89163 m .60097 .87306 L .59906 .88498 L 0 1 .303 r
F
.58469 .89422 m .60097 .87306 L .59656 .86503 L 0 1 .322 r
F
.58469 .89422 m .59906 .88498 L .60097 .87306 L F
.58469 .89422 m .59208 .89406 L .59906 .88498 L F
.5913 .88439 m .5969 .89047 L .60434 .89072 L 0 1 .374 r
F
.58469 .89422 m .59656 .86503 L .58876 .86623 L 0 1 .322 r
F
.58897 .88325 m .59133 .8854 L .5913 .88439 L 0 1 .374 r
F
.59133 .8854 m .5969 .89047 L .5913 .88439 L F
.59783 1.14388 m .59784 1.14431 L .59773 1.1273 L 0 .93 .212 r
F
.59783 1.14388 m .59773 1.1273 L .59772 1.12694 L F
.59799 1.16926 m .59784 1.14431 L .59783 1.14388 L F
.5912 .86462 m .59656 .86503 L .60384 .85626 L 0 1 .334 r
F
.58876 .86623 m .59123 .86585 L .5912 .86462 L F
.59123 .86585 m .59656 .86503 L .5912 .86462 L F
.59128 .88333 m .60434 .89072 L .60633 .88383 L 0 1 .374 r
F
.59783 1.14387 m .59783 1.14388 L .59772 1.12694 L 0 .93 .212 r
F
.59783 1.14387 m .59772 1.12694 L .59772 1.12693 L F
.59798 1.16772 m .59783 1.14388 L .59783 1.14387 L F
.59117 .86334 m .60384 .85626 L .60576 .84577 L 0 1 .334 r
F
.58876 .86623 m .5912 .86462 L .59117 .86334 L F
.5912 .86462 m .60384 .85626 L .59117 .86334 L F
.58897 .88325 m .5913 .88439 L .59128 .88333 L 0 1 .374 r
F
.5913 .88439 m .60434 .89072 L .59128 .88333 L F
.59773 1.12894 m .59774 1.12915 L .59772 1.12693 L 0 .93 .212 r
F
.59773 1.12894 m .59772 1.12693 L .59772 1.12672 L F
.59775 1.13172 m .59774 1.12915 L .59773 1.12894 L F
.59782 .9268 m .60283 .89163 L .5962 .90414 L 0 1 .292 r
F
.58288 .90829 m .59208 .89406 L .58469 .89422 L 0 1 .309 r
F
.58452 .91499 m .59208 .89406 L .58288 .90829 L F
.58452 .91499 m .5962 .90414 L .59208 .89406 L F
.58056 .91831 m .58541 .9191 L .58452 .91499 L 0 .84 .342 r
F
.59782 .9268 m .5962 .90414 L .59431 .91778 L 0 1 .292 r
F
.58603 .92258 m .59431 .91778 L .58541 .9191 L 0 1 .309 r
F
.58603 .92258 m .58764 .92703 L .59431 .91778 L F
.58573 .92235 m .58679 .92687 L .58603 .92258 L 0 .84 .342 r
F
.58056 .91831 m .58609 .9259 L .58573 .92235 L F
.58609 .9259 m .58679 .92687 L .58573 .92235 L F
.58056 .91831 m .58603 .92258 L .58541 .9191 L F
.58056 .91831 m .58452 .91499 L .58288 .90829 L F
.58056 .91831 m .58288 .90829 L .57797 .89908 L F
.58288 .90829 m .58369 .90196 L .58153 .90252 L 0 1 .309 r
F
.58288 .90829 m .58083 .89955 L .57797 .89908 L 0 .84 .342 r
F
.58056 .91831 m .57797 .89908 L .57642 .9059 L F
.58369 .90196 m .58314 .89637 L .57801 .90344 L 0 1 .309 r
F
.58288 .90829 m .58096 .89957 L .58083 .89955 L 0 .84 .342 r
F
.57638 .93754 m .58056 .91831 L .57409 .91635 L 0 .749 .325 r
F
.58436 .91542 m .58541 .9191 L .58452 .91499 L 0 1 .309 r
F
.57638 .93754 m .58637 .92913 L .58056 .91831 L 0 .749 .325 r
F
.58637 .92913 m .58674 .92882 L .58618 .92787 L F
.58637 .92913 m .58618 .92787 L .58056 .91831 L F
.58674 .92882 m .58649 .92743 L .58056 .91831 L F
.58716 .92846 m .58679 .92687 L .58056 .91831 L F
.58064 .9257 m .58436 .91542 L .58288 .90829 L 0 1 .309 r
F
.58436 .91542 m .58441 .91527 L .58418 .91419 L F
.58436 .91542 m .58418 .91419 L .58288 .90829 L F
.58064 .9257 m .58509 .91954 L .58436 .91542 L F
.58509 .91954 m .58541 .9191 L .58436 .91542 L F
.58674 .92882 m .58716 .92846 L .58649 .92743 L 0 .749 .325 r
F
.58718 .92844 m .59147 .93975 L .58764 .92703 L 0 1 .298 r
F
.59011 .94172 m .59147 .93975 L .58718 .92844 L F
.59283 .96654 m .5924 .95864 L .58954 .95117 L 0 .859 .313 r
F
.5924 .95864 m .59205 .95159 L .59163 .95225 L 0 1 .283 r
F
.59205 .95159 m .59147 .93975 L .5909 .94447 L F
.5924 .95864 m .59079 .94539 L .58954 .95117 L 0 .859 .313 r
F
.59205 .95159 m .5909 .94447 L .59079 .94539 L 0 1 .283 r
F
.59143 .95256 m .59079 .94539 L .58959 .95543 L F
.59205 .95159 m .59079 .94539 L .5912 .95 L F
.59205 .95159 m .5912 .95 L .59154 .95239 L F
.59422 .95637 m .60439 .92518 L .59782 .9268 L F
.5924 .95864 m .59782 .9268 L .59147 .93975 L F
.59283 .96654 m .59319 .96486 L .5924 .95864 L 0 .859 .313 r
F
.58765 .99341 m .59283 .96654 L .5866 .96524 L 0 .758 .296 r
F
.59349 .96706 m .59906 .96833 L .6054 .95532 L 0 1 .283 r
F
.5934 .96655 m .5946 .96409 L .59338 .96573 L F
.59342 .96707 m .59345 .96713 L .59345 .9671 L 0 .859 .313 r
F
.59283 .96654 m .59344 .96764 L .59342 .96707 L F
.5934 .96655 m .59468 .96588 L .5946 .96409 L 0 1 .283 r
F
.59333 .9659 m .5934 .96655 L .59338 .96573 L F
.59345 .9671 m .59468 .96588 L .5934 .96655 L F
.5934 .96655 m .59465 .96655 L .59334 .96596 L 0 .859 .313 r
F
.5934 .96655 m .59334 .96596 L .5933 .96594 L F
.59332 .96595 m .5934 .96655 L .59333 .9659 L 0 1 .283 r
F
.59283 .96654 m .59345 .9671 L .5934 .96655 L 0 .859 .313 r
F
.59284 .96769 m .59337 .96662 L .59332 .96595 L 0 1 .283 r
F
.59283 .96654 m .59338 .96655 L .5933 .96594 L 0 .859 .313 r
F
.59338 .96655 m .5934 .96655 L .59336 .96631 L F
.59338 .96655 m .59336 .96631 L .5933 .96594 L F
.59322 .96457 m .59448 .96166 L .59422 .95637 L 0 1 .283 r
F
.59333 .9659 m .59448 .96166 L .59322 .96457 L F
.59338 .96573 m .5946 .96409 L .59448 .96166 L F
.59319 .96486 m .59453 .96436 L .59428 .95973 L 0 .859 .313 r
F
.59283 .96654 m .59333 .9659 L .59319 .96486 L F
.59319 .96486 m .59333 .9659 L .59322 .96457 L 0 1 .283 r
F
.59333 .9659 m .59453 .96436 L .59319 .96486 L 0 .859 .313 r
F
.59284 .96769 m .59333 .9659 L .59319 .96486 L 0 1 .283 r
F
.59337 .96662 m .5934 .96655 L .59332 .96595 L F
.58765 .99341 m .59463 .98411 L .59283 .96654 L 0 .758 .296 r
F
.59463 .98411 m .59537 .98312 L .59383 .97308 L F
.59463 .98411 m .59383 .97308 L .59283 .96654 L F
.59537 .98312 m .59564 .98275 L .5935 .96776 L F
.59537 .98312 m .5935 .96776 L .59283 .96654 L F
.60219 1.00604 m .60801 .96545 L .60207 .98487 L 0 1 .252 r
F
.60227 1.02188 m .60315 1.01327 L .60219 1.00604 L F
.60315 1.01327 m .60801 .96545 L .60219 1.00604 L F
.60315 1.01327 m .61302 .96466 L .60801 .96545 L F
.60227 1.02188 m .60344 1.01568 L .60315 1.01327 L F
.60344 1.01568 m .61302 .96466 L .60315 1.01327 L F
.5946 .96409 m .6054 .95532 L .60764 .93737 L 0 1 .283 r
F
.59468 .96588 m .6054 .95532 L .5946 .96409 L F
.60801 .96545 m .60764 .93737 L .6054 .95532 L 0 1 .254 r
F
.5969 .96131 m .60807 .9666 L .60476 .95122 L 0 .859 .313 r
F
.59634 .96204 m .59702 .9623 L .5969 .96131 L F
.59702 .9623 m .60807 .9666 L .5969 .96131 L F
.59453 .96436 m .5967 .96472 L .59634 .96204 L F
.5967 .96472 m .60807 .9666 L .59634 .96204 L F
.59564 .98275 m .60207 .98487 L .59906 .96833 L 0 1 .274 r
F
.59717 .99542 m .60207 .98487 L .59564 .98275 L F
.60227 1.02188 m .60207 .98487 L .59986 1.00637 L 0 1 .252 r
F
.59717 .99542 m .59986 1.00637 L .60207 .98487 L 0 1 .274 r
F
.58765 .99341 m .59831 1.00754 L .59717 .99542 L 0 .758 .296 r
F
.58765 .99341 m .59365 1.00833 L .59848 1.00936 L F
.59831 1.00754 m .59848 1.00936 L .59986 1.00637 L 0 1 .274 r
F
.59831 1.00754 m .59848 1.00936 L .59991 1.00966 L 0 .758 .296 r
F
.58765 .99341 m .59848 1.00936 L .59831 1.00754 L F
.58224 1.02326 m .59365 1.00834 L .58765 .99341 L 0 .641 .28 r
F
.58224 1.02326 m .59635 1.0311 L .59365 1.00834 L F
.58791 1.01535 m .59379 1.01947 L .59848 1.00936 L 0 1 .274 r
F
.58791 1.01535 m .59848 1.00936 L .59831 1.00754 L F
.58791 1.01535 m .59831 1.00754 L .59717 .99542 L F
.59831 1.00754 m .59986 1.00637 L .59717 .99542 L F
.59717 .99542 m .59991 1.00966 L .60223 .99649 L 0 .758 .296 r
F
.59831 1.00754 m .59991 1.00966 L .59717 .99542 L F
.59564 .98275 m .60223 .99649 L .59919 .97802 L F
.58765 .99341 m .59717 .99542 L .59564 .98275 L F
.59717 .99542 m .60223 .99649 L .59564 .98275 L F
.58791 1.01535 m .59717 .99542 L .59564 .98275 L 0 1 .274 r
F
.58791 1.01535 m .59564 .98275 L .59284 .96769 L F
.59564 .98275 m .59906 .96833 L .5935 .96776 L F
.59564 .98275 m .5935 .96776 L .59284 .96769 L F
.59564 .98275 m .59919 .97802 L .5935 .96776 L 0 .758 .296 r
F
.59337 .96662 m .59345 .9671 L .5934 .96655 L 0 1 .283 r
F
.59284 .96769 m .59343 .96712 L .59337 .96662 L F
.59343 .96712 m .59345 .9671 L .59337 .96662 L F
.5935 .96711 m .59906 .96833 L .59349 .96706 L F
.5935 .96776 m .59906 .96833 L .59345 .9671 L F
.5934 .96655 m .59472 .96823 L .59465 .96655 L 0 .859 .313 r
F
.59345 .9671 m .5935 .96711 L .59349 .96706 L 0 1 .283 r
F
.59345 .9671 m .59472 .96823 L .5934 .96655 L 0 .859 .313 r
F
.5933 .96594 m .59465 .96655 L .59453 .96436 L F
.59284 .96769 m .5935 .96776 L .59345 .9671 L 0 1 .283 r
F
.59345 .9671 m .59919 .97802 L .60573 .97804 L 0 .859 .313 r
F
.59345 .96713 m .59919 .97802 L .59345 .9671 L F
.59344 .96764 m .59919 .97802 L .59342 .96707 L F
.59284 .96769 m .59319 .96486 L .5924 .95864 L 0 1 .283 r
F
.59319 .96486 m .59782 .9268 L .5924 .95864 L F
.59319 .96486 m .59323 .96466 L .5924 .95864 L 0 .859 .313 r
F
.5924 .95864 m .59802 .94216 L .5915 .94214 L F
.59448 .96166 m .60439 .92518 L .59422 .95637 L 0 1 .283 r
F
.59323 .96466 m .59802 .94216 L .5924 .95864 L 0 .859 .313 r
F
.59154 .95239 m .5912 .95 L .59143 .95256 L 0 1 .283 r
F
.57638 .93754 m .58954 .95117 L .59079 .94539 L 0 .749 .325 r
F
.57638 .93754 m .58305 .9492 L .58954 .95117 L F
.5722 .95754 m .5866 .96524 L .58305 .9492 L 0 .647 .309 r
F
.5722 .95754 m .58464 .97495 L .5866 .96524 L F
.57661 .96119 m .58959 .95543 L .59079 .94539 L 0 1 .298 r
F
.59011 .94172 m .59079 .94539 L .59147 .93975 L F
.57638 .93754 m .59079 .94539 L .59011 .94172 L 0 .749 .325 r
F
.57661 .96119 m .59079 .94539 L .59011 .94172 L 0 1 .298 r
F
.59011 .94172 m .59079 .94539 L .59048 .94183 L 0 .749 .325 r
F
.59048 .94183 m .59079 .94539 L .5915 .94214 L F
.5924 .95864 m .5915 .94214 L .59079 .94539 L 0 .859 .313 r
F
.59284 .96769 m .5924 .95864 L .58959 .95543 L 0 1 .283 r
F
.5924 .95864 m .59163 .95225 L .58959 .95543 L F
.58718 .92844 m .58951 .93581 L .58765 .92805 L 0 .749 .325 r
F
.58951 .93581 m .5915 .94214 L .58912 .93344 L F
.58951 .93581 m .58912 .93344 L .58765 .92805 L F
.57638 .93754 m .59011 .94172 L .58718 .92844 L F
.59011 .94172 m .5915 .94214 L .58718 .92844 L F
.5722 .95754 m .58305 .9492 L .57638 .93754 L 0 .647 .309 r
F
.57661 .96119 m .59011 .94172 L .58718 .92844 L 0 1 .298 r
F
.57661 .96119 m .58718 .92844 L .58064 .9257 L F
.58718 .92844 m .58764 .92703 L .58679 .92687 L F
.58716 .92846 m .58718 .92844 L .58679 .92687 L 0 .749 .325 r
F
.58718 .92844 m .58679 .92687 L .58064 .9257 L 0 1 .298 r
F
.58718 .92844 m .58765 .92805 L .58679 .92687 L 0 .749 .325 r
F
.58582 .9227 m .58679 .92687 L .58603 .92258 L 0 1 .309 r
F
.58064 .9257 m .58679 .92687 L .58582 .9227 L F
.58064 .9257 m .58288 .90829 L .57801 .90344 L F
.58288 .90829 m .58153 .90252 L .57801 .90344 L F
.58369 .90196 m .58469 .89422 L .58314 .89637 L F
.58679 .92687 m .58764 .92703 L .58603 .92258 L F
.58603 .92258 m .58765 .92805 L .59445 .92917 L 0 .84 .342 r
F
.58679 .92687 m .58765 .92805 L .58603 .92258 L F
.58541 .9191 m .59445 .92917 L .59642 .9209 L F
.58603 .92258 m .59445 .92917 L .58541 .9191 L F
.58541 .9191 m .59431 .91778 L .5962 .90414 L 0 1 .309 r
F
.58064 .9257 m .58603 .92258 L .58541 .9191 L F
.58541 .9191 m .5962 .90414 L .58452 .91499 L F
.58452 .91499 m .59642 .9209 L .59226 .90848 L 0 .84 .342 r
F
.58541 .9191 m .59642 .9209 L .58452 .91499 L F
.58288 .90829 m .59226 .90848 L .58476 .90018 L F
.58452 .91499 m .59226 .90848 L .58288 .90829 L F
.58441 .91527 m .58452 .91499 L .58288 .90829 L 0 1 .309 r
F
.58288 .90829 m .58476 .90018 L .58096 .89957 L 0 .84 .342 r
F
.59159 .89472 m .60136 .90153 L .5969 .89047 L 0 .924 .358 r
F
.58476 .90018 m .59175 .90075 L .59159 .89472 L F
.59175 .90075 m .60136 .90153 L .59159 .89472 L F
.59091 .8531 m .60106 .83933 L .59286 .84122 L 0 1 .334 r
F
.58876 .86623 m .59111 .86109 L .59091 .8531 L F
.59111 .86109 m .60106 .83933 L .59091 .8531 L F
.59111 .86109 m .60576 .84577 L .60106 .83933 L F
.59117 .86334 m .60576 .84577 L .59111 .86109 L F
.58876 .86623 m .59286 .84122 L .58555 .84999 L F
.59319 .86744 m .59743 .85265 L .59035 .85259 L 0 1 .39 r
F
.59045 .85589 m .59035 .85259 L .58966 .85259 L F
.59319 .86744 m .59035 .85259 L .59045 .85589 L F
.59123 .88156 m .60633 .88383 L .60155 .87386 L 0 1 .374 r
F
.58897 .88325 m .59128 .88333 L .59123 .88156 L F
.59128 .88333 m .60633 .88383 L .59123 .88156 L F
.59105 .87546 m .60155 .87386 L .59319 .86744 L F
.58897 .88325 m .59123 .88156 L .59105 .87546 L F
.59123 .88156 m .60155 .87386 L .59105 .87546 L F
.59751 1.09491 m .59764 1.11575 L .59751 1.09503 L 0 .93 .212 r
F
.59764 1.11575 m .59771 1.12581 L .59765 1.11581 L F
.58476 .90018 m .59159 .89472 L .58897 .88325 L 0 .924 .358 r
F
.59159 .89472 m .5969 .89047 L .59133 .8854 L F
.59159 .89472 m .59133 .8854 L .58897 .88325 L F
.59771 1.12581 m .59775 1.13172 L .59771 1.12585 L 0 .93 .212 r
F
.59775 1.13172 m .59798 1.16772 L .59775 1.13196 L F
.58876 .86623 m .59117 .86334 L .59111 .86109 L 0 1 .334 r
F
.5961 1.07389 m .59889 1.06673 L .5985 1.057 L 0 .775 .269 r
F
.60175 1.0594 m .60769 1.02098 L .60062 1.04211 L 0 1 .25 r
F
.59889 1.06673 m .60175 1.0594 L .5985 1.057 L 0 .775 .269 r
F
.60175 1.0594 m .60985 1.04529 L .60769 1.02098 L 0 1 .25 r
F
.60175 1.0594 m .60802 1.04335 L .60105 1.05335 L 0 .775 .269 r
F
.60175 1.0594 m .60105 1.05335 L .5985 1.057 L F
.603 1.07016 m .60985 1.04529 L .60175 1.0594 L 0 1 .25 r
F
.60899 1.09187 m .61534 1.01249 L .60985 1.04529 L 0 1 .215 r
F
.60882 1.10084 m .60922 1.0955 L .60899 1.09187 L F
.60922 1.0955 m .61534 1.01249 L .60899 1.09187 L F
.60473 1.02444 m .6136 1.02435 L .61377 1.00409 L 0 .899 .284 r
F
.60238 1.02974 m .60499 1.02848 L .60473 1.02444 L F
.60499 1.02848 m .6136 1.02435 L .60473 1.02444 L F
.60882 1.10084 m .60985 1.04529 L .6073 1.07886 L 0 1 .215 r
F
.60237 1.07247 m .6073 1.07886 L .60985 1.04529 L 0 1 .25 r
F
.5961 1.07389 m .60272 1.08533 L .60237 1.07247 L 0 .775 .269 r
F
.5961 1.07389 m .60145 1.09501 L .60297 1.09467 L F
.60272 1.08533 m .60297 1.09467 L .6073 1.07886 L 0 1 .25 r
F
.60272 1.08533 m .60297 1.09467 L .60752 1.09364 L 0 .775 .269 r
F
.5961 1.07389 m .60297 1.09467 L .60272 1.08533 L F
.5898 1.12185 m .60104 1.09594 L .5961 1.07389 L 0 .642 .257 r
F
.60104 1.09594 m .60145 1.09501 L .60105 1.09344 L F
.60104 1.09594 m .60105 1.09344 L .5961 1.07389 L F
.5961 1.07389 m .60237 1.07247 L .60175 1.0594 L 0 .775 .269 r
F
.59636 1.09431 m .60113 1.06345 L .60062 1.04211 L 0 1 .25 r
F
.60113 1.06345 m .60175 1.0594 L .60116 1.05034 L F
.60113 1.06345 m .60116 1.05034 L .60062 1.04211 L F
.5898 1.12185 m .60315 1.1309 L .60145 1.09501 L 0 .642 .257 r
F
.60315 1.1309 m .60346 1.13112 L .60303 1.12335 L F
.60315 1.1309 m .60303 1.12335 L .60145 1.09501 L F
.59636 1.09431 m .60151 1.09997 L .60259 1.09605 L 0 1 .25 r
F
.60257 1.09465 m .60259 1.09605 L .60297 1.09467 L F
.59636 1.09431 m .60259 1.09605 L .60257 1.09465 L F
.59636 1.09431 m .60297 1.09467 L .60272 1.08533 L F
.59636 1.09431 m .60272 1.08533 L .60237 1.07247 L F
.60272 1.08533 m .6073 1.07886 L .60237 1.07247 L F
.60237 1.07247 m .60752 1.09364 L .61023 1.0707 L 0 .775 .269 r
F
.60272 1.08533 m .60752 1.09364 L .60237 1.07247 L F
.60175 1.0594 m .61023 1.0707 L .60802 1.04335 L F
.60237 1.07247 m .603 1.07016 L .60175 1.0594 L 0 1 .25 r
F
.60237 1.07247 m .61023 1.0707 L .60175 1.0594 L 0 .775 .269 r
F
.59636 1.09431 m .60237 1.07247 L .60175 1.0594 L 0 1 .25 r
F
.60062 1.04211 m .60802 1.04335 L .60238 1.02974 L 0 .775 .269 r
F
.60133 1.05294 m .60802 1.04335 L .60062 1.04211 L F
.60238 1.02974 m .61377 1.00409 L .60843 .99353 L 0 .899 .284 r
F
.61535 1.01248 m .61612 .97634 L .61362 1.00139 L 0 1 .195 r
F
.61377 1.00409 m .61437 1.00274 L .6138 1.00184 L 0 .899 .284 r
F
.61377 1.00409 m .6138 1.00184 L .60843 .99353 L F
.61302 .96466 m .61371 .96099 L .61304 .96151 L 0 1 .252 r
F
.61302 .96466 m .61304 .96151 L .60801 .96545 L F
.59448 .96166 m .60764 .93737 L .60439 .92518 L 0 1 .283 r
F
.5946 .96409 m .60764 .93737 L .59448 .96166 L F
.59465 .96655 m .60573 .97804 L .60807 .9666 L 0 .859 .313 r
F
.59472 .96823 m .60573 .97804 L .59465 .96655 L F
.6155 .91079 m .61546 .91787 L .61568 .91524 L 0 .813 .228 r
F
.61843 .88235 m .62071 .88503 L .62115 .86614 L F
.61984 .92859 m .61843 .88235 L .62307 .85755 L 0 .593 .223 r
F
.61758 .93127 m .61843 .88235 L .61984 .92859 L F
.6154 .92008 m .61546 .91787 L .61543 .92246 L 0 .548 .225 r
F
.60801 .96545 m .61984 .91271 L .61383 .91913 L 0 1 .254 r
F
.61557 .9187 m .61659 .92638 L .61685 .91854 L 0 1 .349 r
F
.62544 .93118 m .62653 .84011 L .62857 .8045 L 0 .306 .198 r
F
.62544 .93118 m .62857 .8045 L .62934 .80588 L F
.62115 .92703 m .62458 .87081 L .62493 .89573 L 0 .593 .223 r
F
.61557 .9001 m .61568 .91524 L .61615 .90959 L 0 .813 .228 r
F
.6155 .91079 m .61568 .91524 L .61557 .9001 L F
.62458 .87081 m .62625 .86129 L .62543 .93078 L 0 .593 .223 r
F
.62544 .93118 m .63432 .77387 L .63402 .83406 L 0 .306 .198 r
F
.61383 .91913 m .62885 .87979 L .62605 .87331 L 0 1 .256 r
F
.62115 .92703 m .62493 .89573 L .62543 .93078 L 0 .593 .223 r
F
.61383 .91913 m .62627 .89584 L .62885 .87979 L 0 1 .256 r
F
.61383 .91913 m .62605 .87331 L .61972 .88071 L F
.61383 .91913 m .61984 .91271 L .62627 .89584 L F
.61383 .91913 m .61972 .88071 L .61326 .89756 L F
.61383 .91913 m .61326 .89756 L .611 .91263 L F
.59782 .9268 m .611 .91263 L .61326 .89756 L 0 1 .292 r
F
.60801 .96545 m .61383 .91913 L .60764 .93737 L 0 1 .254 r
F
.59782 .9268 m .60439 .92518 L .611 .91263 L 0 1 .292 r
F
.60324 .92027 m .61536 .92582 L .61557 .9187 L 0 1 .349 r
F
.61536 .92582 m .61659 .92638 L .61557 .9187 L F
.61571 .87916 m .61843 .88235 L .61606 .85994 L 0 .813 .228 r
F
.61447 .87905 m .61443 .88052 L .61666 .87668 L 0 1 .303 r
F
.61536 .92582 m .61617 .92654 L .61617 .92619 L 0 1 .349 r
F
.61617 .92654 m .61657 .9269 L .61617 .92619 L F
.61617 .92619 m .61657 .9269 L .61659 .92638 L F
.60324 .92027 m .61535 .9263 L .61536 .92582 L F
.61535 .9263 m .61657 .9269 L .61536 .92582 L F
.61377 1.00409 m .61446 1.02393 L .61437 1.00274 L 0 .899 .284 r
F
.6136 1.02435 m .61446 1.02393 L .61377 1.00409 L F
.60787 .40178 m .60787 .40179 L .6044 .26816 L 0 .529 .227 r
F
.60714 .39022 m .60767 .39795 L .60787 .40179 L 0 .919 .089 r
F
.60608 .37326 m .60704 .38759 L .60714 .39022 L F
.60702 .39275 m .60702 .39285 L .6069 .38681 L 0 .501 .225 r
F
.60787 .40172 m .60795 .40607 L .60801 .40715 L 0 .529 .227 r
F
.60731 .39449 m .60909 .42499 L .60746 .39818 L 0 .919 .089 r
F
.60909 .42499 m .60952 .43329 L .60746 .39818 L F
.60608 .37326 m .60731 .39449 L .60746 .39818 L F
.60608 .37326 m .60834 .41353 L .61219 .48063 L F
.60608 .37326 m .60746 .39818 L .60781 .40513 L F
.60608 .37326 m .60781 .40513 L .60834 .41353 L F
.60608 .37326 m .61219 .48063 L .60776 .41071 L F
.61219 .48063 m .6129 .49308 L .61265 .48908 L F
.61219 .48063 m .61265 .48908 L .60776 .41071 L F
.60608 .37326 m .60677 .3808 L .60744 .39351 L F
.62783 .77344 m .62749 .77364 L .62842 .77401 L 0 1 .479 r
F
.62255 .76835 m .62749 .77364 L .62783 .77344 L F
.61606 .85994 m .61843 .88235 L .62273 .79786 L 0 .813 .228 r
F
.61465 .87129 m .61666 .87668 L .61894 .8639 L 0 1 .303 r
F
.61447 .87905 m .61666 .87668 L .61465 .87129 L F
.59782 .9268 m .6069 .9096 L .60699 .89745 L 0 1 .292 r
F
.6069 .9096 m .61326 .89756 L .60699 .89745 L F
.60324 .92027 m .61595 .90699 L .60848 .90062 L 0 1 .349 r
F
.61595 .90699 m .616 .90694 L .61595 .9069 L F
.61595 .90699 m .61595 .9069 L .60848 .90062 L F
.61498 .85783 m .61519 .85726 L .615 .85737 L 0 1 .303 r
F
.61498 .85783 m .615 .85737 L .60789 .86119 L F
.61606 .85994 m .62273 .79786 L .61705 .84021 L 0 .813 .228 r
F
.61498 .85783 m .61894 .8639 L .61519 .85726 L 0 1 .303 r
F
.61465 .87129 m .61894 .8639 L .61498 .85783 L F
.61705 .84021 m .62256 .76874 L .61963 .76536 L 0 .813 .228 r
F
.61705 .84021 m .61963 .76536 L .61746 .76283 L F
.61595 .90699 m .61685 .91854 L .616 .90694 L 0 1 .349 r
F
.60324 .92027 m .61557 .9187 L .61595 .90699 L F
.61557 .9187 m .61685 .91854 L .61595 .90699 L F
.60324 .92027 m .61036 .9277 L .61533 .92706 L F
.61535 .9263 m .61533 .92706 L .61657 .9269 L F
.60324 .92027 m .61533 .92706 L .61535 .9263 L F
.59465 .96655 m .60807 .9666 L .59453 .96436 L 0 .859 .313 r
F
.59428 .95973 m .60476 .95122 L .59802 .94216 L F
.59453 .96436 m .60476 .95122 L .59428 .95973 L F
.59803 .50879 m .5987 .51994 L .59891 .53418 L 0 1 .156 r
F
.59229 .27525 m .59262 .32715 L .59344 .33604 L 0 .93 .212 r
F
.59982 .56307 m .60026 .5717 L .60013 .57314 L 0 1 .156 r
F
.59918 .5834 m .59932 .58191 L .60114 .5934 L 0 .858 .083 r
F
.59459 .54799 m .60144 .5731 L .59843 .58778 L 0 .547 .201 r
F
.60144 .5731 m .60196 .57498 L .60157 .57638 L F
.60144 .5731 m .60157 .57638 L .59843 .58778 L F
.58488 .43405 m .58552 .43885 L .58546 .44022 L 0 .875 .195 r
F
.58269 .51069 m .58942 .5206 L .58958 .55115 L 0 .721 .193 r
F
.57782 .48209 m .58323 .50005 L .58269 .51069 L F
.58323 .50005 m .58942 .5206 L .58269 .51069 L F
.58211 .51858 m .58958 .55115 L .58604 .55189 L F
.57782 .48209 m .58269 .51069 L .58211 .51858 L F
.58269 .51069 m .58958 .55115 L .58211 .51858 L F
.58488 .43405 m .58546 .44022 L .58541 .44081 L 0 .875 .195 r
F
.58488 .43405 m .58541 .44081 L .58532 .44235 L F
.60144 .5731 m .60114 .55716 L .60196 .57498 L 0 .547 .201 r
F
.59459 .54799 m .60073 .55659 L .60144 .5731 L F
.60073 .55659 m .60114 .55716 L .60144 .5731 L F
.60313 .60834 m .60312 .59796 L .60366 .60776 L 0 .297 .144 r
F
.60265 .59903 m .60312 .59796 L .60313 .60834 L F
.60265 .59903 m .6031 .59765 L .60312 .59796 L F
.60264 .59873 m .6031 .59765 L .60265 .59903 L F
.60323 .63061 m .60373 .63184 L .60374 .63197 L 0 .771 .083 r
F
.60322 .63048 m .60373 .63184 L .60323 .63061 L F
.60322 .63048 m .60319 .6301 L .60373 .63184 L F
.60264 .59873 m .60261 .59819 L .6031 .59765 L 0 .297 .144 r
F
.59821 1.19011 m .5981 1.18492 L .59821 1.18095 L 0 .789 .222 r
F
.5981 1.18492 m .59812 1.17926 L .59821 1.18095 L F
.60801 .96545 m .62243 .92277 L .61984 .91271 L 0 1 .254 r
F
.60735 .93124 m .61394 .94069 L .61036 .9277 L 0 .953 .33 r
F
.59802 .94216 m .60724 .94131 L .60735 .93124 L F
.60724 .94131 m .61394 .94069 L .60735 .93124 L F
.59782 .9268 m .60699 .89745 L .60283 .89163 L 0 1 .292 r
F
.60324 .92027 m .60772 .90349 L .60136 .90153 L 0 1 .349 r
F
.59802 .94216 m .60735 .93124 L .60324 .92027 L 0 .953 .33 r
F
.60735 .93124 m .61036 .9277 L .60742 .92463 L F
.60735 .93124 m .60742 .92463 L .60324 .92027 L F
.60312 .59796 m .6031 .59765 L .60339 .59734 L 0 .297 .144 r
F
.61535 1.01248 m .62013 1.00213 L .62576 .97378 L 0 1 .195 r
F
.60882 1.10084 m .62012 1.00214 L .61534 1.01249 L 0 1 .215 r
F
.61446 1.02393 m .61686 1.02278 L .61467 1.00516 L 0 .899 .284 r
F
.61446 1.02393 m .61467 1.00516 L .61437 1.00274 L F
.61659 .92638 m .61657 .9269 L .61749 .92679 L 0 1 .349 r
F
.60439 .26816 m .60677 .3808 L .60787 .40172 L 0 .529 .227 r
F
.61705 .84021 m .62273 .79786 L .62256 .76874 L 0 .813 .228 r
F
.61843 .88235 m .62115 .86614 L .62273 .79786 L F
.61843 .88235 m .62479 .8082 L .62651 .83918 L 0 .593 .223 r
F
.62273 .79786 m .62363 .82167 L .62533 .77371 L 0 .813 .228 r
F
.62363 .82167 m .62554 .7995 L .62533 .77371 L F
.62458 .87081 m .62307 .85755 L .62651 .83918 L 0 .593 .223 r
F
.61146 .55437 m .61589 .58062 L .61573 .58718 L 0 .953 .114 r
F
.61589 .58062 m .61865 .59701 L .61591 .58776 L F
.61589 .58062 m .61591 .58776 L .61573 .58718 L F
.63123 .73883 m .63445 .74272 L .63447 .73117 L 0 .389 .233 r
F
.61809 .5937 m .61815 .59064 L .61865 .59701 L 0 .953 .114 r
F
.61774 .58842 m .61815 .59064 L .61809 .5937 L F
.60608 .37326 m .60787 .40179 L .60909 .42499 L 0 .919 .089 r
F
.60439 .26816 m .60787 .40172 L .6044 .26816 L 0 .529 .227 r
F
.60787 .40172 m .60787 .40178 L .6044 .26816 L F
.6177 .58299 m .62438 .61361 L .61815 .59064 L 0 .953 .114 r
F
.61146 .55437 m .61455 .55559 L .61692 .56645 L F
.61718 .57197 m .61692 .56645 L .62006 .58083 L F
.61146 .55437 m .61692 .56645 L .61718 .57197 L F
.62458 .87081 m .62651 .83918 L .62625 .86129 L 0 .593 .223 r
F
.62273 .79786 m .62533 .77371 L .62447 .77217 L 0 .813 .228 r
F
.62273 .79786 m .62447 .77217 L .62256 .76874 L F
.61685 .91854 m .61749 .92679 L .61985 .91815 L 0 1 .349 r
F
.61659 .92638 m .61749 .92679 L .61685 .91854 L F
.61685 .91854 m .61985 .91815 L .61716 .91032 L F
.61685 .91854 m .61716 .91032 L .616 .90694 L F
.61372 .98423 m .61612 .97634 L .61389 .96211 L 0 1 .252 r
F
.61372 .98423 m .61389 .96211 L .61371 .96099 L F
.59286 .84122 m .6079 .82459 L .60559 .81639 L 0 1 .348 r
F
.6079 .82459 m .61059 .82162 L .60799 .8189 L F
.6079 .82459 m .60799 .8189 L .60559 .81639 L F
.60789 .86119 m .62066 .83021 L .61298 .83461 L 0 1 .315 r
F
.60789 .86119 m .61298 .83461 L .60576 .84577 L F
.60789 .86119 m .60576 .84577 L .60384 .85626 L F
.59743 .85264 m .60622 .85846 L .60857 .85809 L 0 1 .406 r
F
.60789 .86119 m .62467 .83514 L .62066 .83021 L 0 1 .315 r
F
.60789 .86119 m .62237 .8461 L .62467 .83514 L F
.60789 .86119 m .61519 .85726 L .62237 .8461 L F
.60863 .85553 m .60857 .85809 L .61478 .85712 L 0 1 .406 r
F
.59743 .85264 m .60857 .85809 L .60863 .85553 L F
.60772 .90349 m .60848 .90062 L .60776 .90071 L 0 1 .349 r
F
.60772 .90349 m .60776 .90071 L .60136 .90153 L F
.60731 .86464 m .60734 .86212 L .60097 .87306 L 0 1 .303 r
F
.59319 .86744 m .60155 .87386 L .60825 .87391 L 0 1 .39 r
F
.60826 .87349 m .60825 .87391 L .60931 .87392 L F
.59319 .86744 m .60825 .87391 L .60826 .87349 L F
.60699 .89745 m .60976 .88857 L .60705 .88977 L 0 1 .292 r
F
.60699 .89745 m .60705 .88977 L .60283 .89163 L F
.60699 .89745 m .61326 .89756 L .60976 .88857 L F
.60366 .60776 m .60339 .59734 L .60666 .60448 L 0 .297 .144 r
F
.60312 .59796 m .60339 .59734 L .60366 .60776 L F
.59229 .27525 m .59481 .40694 L .59301 .29544 L 0 .93 .212 r
F
.60007 .58983 m .60114 .5934 L .60129 .59647 L 0 .858 .083 r
F
.60002 .58768 m .60114 .5934 L .60007 .58983 L F
.6043 .61614 m .60599 .61584 L .60457 .61857 L 0 .297 .144 r
F
.6043 .61614 m .60457 .61857 L .60181 .62385 L F
.60374 .63197 m .60373 .63184 L .60392 .63246 L 0 .771 .083 r
F
.60196 .57498 m .6067 .56494 L .60342 .58036 L 0 .547 .201 r
F
.60114 .55716 m .6067 .56494 L .60196 .57498 L F
.60196 .57498 m .60342 .58036 L .60224 .58211 L F
.60196 .57498 m .60224 .58211 L .59843 .58778 L F
.60837 .86756 m .60931 .87392 L .61131 .86758 L 0 1 .39 r
F
.59319 .86744 m .60826 .87349 L .60837 .86756 L F
.60826 .87349 m .60931 .87392 L .60837 .86756 L F
.60731 .86464 m .60789 .86119 L .60734 .86212 L 0 1 .303 r
F
.59319 .86744 m .60837 .86756 L .60622 .85847 L 0 1 .39 r
F
.60837 .86756 m .61131 .86758 L .60848 .86252 L F
.60837 .86756 m .60848 .86252 L .60622 .85847 L F
.60138 .61665 m .60666 .60448 L .60599 .61584 L 0 .297 .144 r
F
.60117 .61047 m .60666 .60448 L .60138 .61665 L F
.62674 .73908 m .62748 .75102 L .6271 .74479 L 0 .459 .231 r
F
.62255 .76835 m .63114 .76805 L .63219 .7629 L 0 1 .479 r
F
.63114 .76805 m .6329 .76408 L .63219 .7629 L F
.6342 .86445 m .63991 .81142 L .64295 .8055 L 0 .283 .182 r
F
.63416 .86471 m .6348 .85876 L .6342 .86445 L F
.63416 .86471 m .635 .85213 L .63481 .85832 L F
.63928 .77553 m .63932 .77549 L .63938 .7754 L 0 1 .317 r
F
.64779 .63202 m .64898 .63233 L .64908 .63203 L 0 1 .516 r
F
.64774 .63589 m .65287 .67288 L .64885 .63268 L 0 .122 .176 r
F
.63778 .56531 m .63866 .57159 L .63851 .56932 L F
.65058 .73044 m .65063 .73081 L .65059 .73035 L 0 0 .119 r
F
.64737 .72927 m .64849 .74513 L .64876 .74337 L F
.6404 .68805 m .64445 .73283 L .64535 .73275 L 0 .968 .234 r
F
.6404 .68805 m .64535 .73275 L .64368 .70371 L F
.6404 .68805 m .64368 .70371 L .64276 .68786 L F
.6404 .68805 m .64276 .68786 L .64255 .68133 L F
.6404 .68805 m .64255 .68133 L .64272 .67714 L F
.65321 .8121 m .65413 .82304 L .65463 .82107 L 0 0 .119 r
F
.65321 .8121 m .65463 .82107 L .65591 .81601 L F
.64304 .8142 m .64306 .81398 L .64305 .81404 L 0 .729 .063 r
F
.64304 .8142 m .64306 .81391 L .64306 .81398 L F
.64272 .55863 m .65488 .61866 L .65546 .6152 L 0 .002 .141 r
F
.65805 .63433 m .65784 .63589 L .65929 .64047 L F
.65687 .63677 m .65772 .63554 L .65697 .6361 L 0 1 .332 r
F
.65805 .63433 m .65929 .64047 L .65837 .63218 L 0 .002 .141 r
F
.65413 .82304 m .65607 .83455 L .65591 .81601 L 0 0 .119 r
F
.62255 .76835 m .62974 .77116 L .63114 .76805 L 0 1 .479 r
F
.62255 .76835 m .6287 .77339 L .62974 .77116 L F
.6287 .77339 m .6304 .77478 L .62974 .77116 L F
.63219 .7629 m .63691 .77174 L .63292 .76453 L 0 1 .486 r
F
.62326 .72188 m .63292 .76453 L .63632 .77068 L 0 .193 .233 r
F
.63652 .77033 m .63632 .77068 L .63691 .77174 L F
.62326 .72188 m .63632 .77068 L .63652 .77033 L F
.62326 .72188 m .63652 .77033 L .63685 .76332 L F
.63652 .77033 m .63691 .77174 L .6369 .77021 L F
.63652 .77033 m .6369 .77021 L .63685 .76332 L F
.60191 .6426 m .60658 .65399 L .6021 .6435 L 0 .771 .083 r
F
.60191 .6426 m .6021 .6435 L .60192 .64292 L F
.59104 .38862 m .59107 .38928 L .59107 .38924 L 0 1 .156 r
F
.59042 .26759 m .58973 .27704 L .5898 .26917 L 0 1 .183 r
F
.59047 .26749 m .58973 .27704 L .59042 .26759 L F
.59472 .65803 m .59475 .65971 L .59474 .65849 L 0 .93 .212 r
F
.59504 .71312 m .5951 .71505 L .59475 .65981 L F
.59475 .65971 m .59475 .65981 L .59474 .65849 L F
.59504 .71312 m .59475 .65981 L .59475 .65971 L F
.59798 1.16772 m .59799 1.16926 L .59798 1.16771 L F
.59647 1.38985 m .59645 1.38937 L .59675 1.39091 L 0 0 .1 r
F
.59504 .71312 m .59528 .75119 L .5951 .71505 L 0 .93 .212 r
F
.59528 .75119 m .59572 .81806 L .59532 .7512 L F
.59528 .75119 m .59532 .7512 L .5951 .71505 L F
.59572 .81806 m .59581 .83181 L .59572 .81787 L F
.59572 .81806 m .59572 .81787 L .5951 .71505 L F
.59581 .83181 m .59584 .83067 L .5951 .71505 L F
.5903 .34659 m .59038 .33957 L .59032 .34581 L 0 1 .183 r
F
.66355 .29515 m .67213 .34094 L .66261 .29314 L 0 .593 .03 r
F
.66355 .29515 m .66895 .31799 L .67213 .34094 L F
.66261 .29314 m .67173 .34682 L .66214 .29222 L F
.66261 .29314 m .67213 .34094 L .67173 .34682 L F
0 g
.66909 .33429 m
.66954 .3358 L
s
.62477 .29269 m .62995 .34339 L .6259 .29027 L 0 .264 .216 r
F
.62477 .29269 m .62717 .32832 L .62995 .34339 L F
.66214 .29222 m .66788 .3305 L .6618 .29151 L 0 .593 .03 r
F
.66214 .29222 m .67173 .34682 L .66788 .3305 L F
.6618 .29151 m .6632 .30307 L .6615 .29079 L F
.6618 .29151 m .66788 .3305 L .6632 .30307 L F
.65701 .39805 m .66541 .40623 L .66126 .39353 L 0 .613 .296 r
F
0 g
.65884 .37032 m
.66126 .39353 L
s
.65701 .39805 m .66724 .42784 L .66541 .40623 L 0 .613 .296 r
F
.65701 .39805 m .66551 .44394 L .66724 .42784 L F
.65701 .39805 m .66124 .44846 L .66551 .44394 L F
.65701 .39805 m .65729 .43838 L .66124 .44846 L F
.65701 .39805 m .65548 .41676 L .65729 .43838 L F
0 g
.65505 .37387 m
.65701 .39805 L
s
.65701 .39805 m
.66126 .39353 L
s
.66799 .36652 m
.66867 .36715 L
s
.64304 .42017 m .65137 .42304 L .64744 .41267 L 0 .789 .296 r
F
0 g
.64439 .41786 m
.64744 .41267 L
s
.6455 .38845 m
.64744 .41267 L
s
.6259 .29027 m .62854 .32313 L .62581 .28771 L 0 .264 .216 r
F
.6259 .29027 m .62995 .34339 L .62854 .32313 L F
.62281 .28989 m .63017 .40431 L .62196 .2884 L 0 0 .064 r
F
.62281 .28989 m .63095 .39265 L .63017 .40431 L F
.64304 .42017 m .65271 .44443 L .65137 .42304 L 0 .789 .296 r
F
0 g
.64304 .42017 m
.64439 .41786 L
s
.57411 .28773 m .57204 .39562 L .57361 .2884 L 0 0 .038 r
F
.62196 .2884 m .63017 .40431 L .62502 .34285 L 0 0 .064 r
F
.57533 .28663 m .57204 .39562 L .57411 .28773 L 0 0 .038 r
F
0 g
.57289 .2992 m
.57323 .29228 L
s
.62581 .28771 m .62854 .32313 L .62606 .28653 L 0 .264 .216 r
F
.65834 .28717 m .65929 .30076 L .65659 .28565 L 0 .999 .121 r
F
0 g
.66895 .31799 m
.66922 .31995 L
s
.5774 .28449 m .57204 .39562 L .57533 .28663 L 0 0 .038 r
F
0 g
.57595 .31447 m
.5766 .30327 L
s
.62721 .30353 m
.62854 .32313 L
s
.65659 .28565 m .65871 .32513 L .65335 .28279 L 0 .999 .121 r
F
.65659 .28565 m .65929 .30076 L .65871 .32513 L F
0 g
.65366 .41954 m
.65548 .41676 L
s
.65137 .42304 m
.65366 .41954 L
s
.56265 .28481 m .55975 .44012 L .56303 .28486 L 0 .601 .239 r
F
.56303 .28486 m .55975 .44012 L .56655 .28462 L F
.56265 .28481 m .56081 .33927 L .55975 .44012 L F
.56109 .28446 m .56081 .33927 L .56265 .28481 L 0 .858 .233 r
F
.56655 .28462 m .5698 .36143 L .56798 .28447 L 0 .601 .239 r
F
.56655 .28462 m .55975 .44012 L .5698 .36143 L F
.5774 .28449 m .57705 .3091 L .57204 .39562 L 0 0 .038 r
F
0 g
.5757 .33244 m
.57617 .32984 L
s
.57204 .39562 m .57705 .3091 L .57396 .38157 L 0 0 .038 r
F
.56778 .4186 m .56787 .42571 L .571 .40826 L 0 1 .144 r
F
.56785 .43807 m .56773 .44746 L .57074 .4388 L 0 1 .204 r
F
.56308 .50489 m .57261 .3413 L .57204 .39562 L 0 0 .076 r
F
.56308 .50489 m .57048 .34794 L .57261 .3413 L F
.56798 .28447 m .57396 .38155 L .56863 .28444 L 0 .626 .234 r
F
.56798 .28447 m .5698 .36143 L .57396 .38155 L F
.55858 .28397 m .55577 .3465 L .56109 .28446 L 0 .858 .233 r
F
.56109 .28446 m .55577 .3465 L .56081 .33927 L F
.56863 .28444 m .57705 .30907 L .57185 .28426 L 0 .626 .234 r
F
0 g
.57335 .29141 m
.57337 .28992 L
s
.56863 .28444 m .57396 .38155 L .57705 .30907 L 0 .626 .234 r
F
.57185 .28426 m .57705 .30907 L .57695 .28417 L F
.62488 .28402 m .62673 .32678 L .62425 .28242 L 0 .785 .071 r
F
.55752 .28379 m .55577 .3465 L .55858 .28397 L 0 .858 .233 r
F
.67211 .35827 m .68028 .37942 L .67582 .36231 L 0 .205 .24 r
F
.67211 .35827 m .68317 .39891 L .68028 .37942 L F
.67211 .35827 m .68254 .40768 L .68317 .39891 L F
.67211 .35827 m .67881 .40353 L .68254 .40768 L F
.67211 .35827 m .67448 .38928 L .67881 .40353 L F
.67211 .35827 m .67162 .36991 L .67448 .38928 L F
0 g
.66946 .33723 m
.67211 .35827 L
s
.66867 .36715 m
.67162 .36991 L
s
.5568 .28366 m .55577 .3465 L .55752 .28379 L 0 .858 .233 r
F
.55624 .28351 m .55577 .3465 L .5568 .28366 L F
.57558 .28256 m .57705 .30912 L .57737 .28355 L 0 1 .211 r
F
.55272 .28222 m .55333 .30901 L .55466 .28298 L 0 .973 .224 r
F
.65335 .28279 m .65463 .31459 L .65148 .28117 L 0 .999 .121 r
F
.65335 .28279 m .65871 .32513 L .65463 .31459 L F
0 g
.66541 .40623 m
.66643 .40582 L
s
.56308 .50489 m .57204 .39562 L .5689 .46306 L 0 0 .076 r
F
.56308 .50489 m .56382 .47897 L .56702 .4113 L F
.55629 .51676 m .55999 .47663 L .56401 .43672 L 0 0 .023 r
F
.55696 .51698 m .55664 .52174 L .55953 .5116 L 0 1 .139 r
F
.55508 .53781 m .56542 .43213 L .56483 .44785 L 0 0 .057 r
F
.55508 .53781 m .56294 .45024 L .56542 .43213 L F
.55603 .52947 m .55821 .52894 L .56226 .51531 L 0 1 .185 r
F
.55603 .52947 m .55553 .53504 L .55821 .52894 L F
.55508 .53781 m .56483 .44785 L .5615 .48507 L 0 0 .057 r
F
.55975 .44012 m .5689 .46305 L .5698 .36143 L 0 .601 .239 r
F
.57361 .28155 m .56888 .40976 L .57558 .28256 L 0 1 .211 r
F
.57558 .28256 m .56888 .40976 L .57705 .30912 L F
.62425 .28242 m .62572 .35207 L .6222 .27985 L 0 .785 .071 r
F
.62425 .28242 m .62673 .32678 L .62572 .35207 L F
0 g
.62606 .28653 m
.62721 .30353 L
s
.55219 .28202 m .55169 .2919 L .55272 .28222 L 0 .973 .224 r
F
.55272 .28222 m .55169 .2919 L .55333 .30901 L F
.55204 .28195 m .55169 .2919 L .55219 .28202 L F
.55195 .28189 m .55169 .2919 L .55204 .28195 L F
.55186 .28184 m .55169 .2919 L .55195 .28189 L F
.55176 .28181 m .55169 .2919 L .55186 .28184 L F
.57205 .28071 m .56888 .40976 L .57361 .28155 L 0 1 .211 r
F
.67044 .38977 m .67881 .40353 L .67448 .38928 L 0 .381 .288 r
F
.67044 .38977 m .68112 .42347 L .67881 .40353 L F
.67044 .38977 m .67987 .43574 L .68112 .42347 L F
.67044 .38977 m .6758 .43618 L .67987 .43574 L F
.67044 .38977 m .67164 .42451 L .6758 .43618 L F
.67044 .38977 m .66935 .40463 L .67164 .42451 L F
0 g
.66799 .36652 m
.67044 .38977 L
s
.66643 .40582 m
.66935 .40463 L
s
.65148 .28117 m .65463 .31459 L .65031 .2802 L 0 .999 .121 r
F
.67245 .34045 m .67247 .34565 L .67582 .36231 L 0 0 .12 r
F
0 g
.67247 .34565 m
.67415 .35405 L
s
.67193 .34385 m
.67247 .34565 L
s
.54888 .2807 m .54847 .32318 L .54909 .28078 L 0 .933 .238 r
F
.5718 .28055 m .56888 .40976 L .57205 .28071 L 0 1 .211 r
F
.54707 .27988 m .54121 .4135 L .54888 .2807 L 0 .933 .238 r
F
.54888 .2807 m .54121 .4135 L .54847 .32318 L F
.5718 .28055 m .56987 .3362 L .56888 .40976 L 0 1 .211 r
F
.57136 .28009 m .56987 .3362 L .5718 .28055 L 0 1 .168 r
F
.65031 .2802 m .64602 .36775 L .64968 .28004 L 0 .806 .199 r
F
.65031 .2802 m .65463 .31459 L .64602 .36775 L F
.56941 .30848 m .56489 .40192 L .57094 .28808 L 0 1 .168 r
F
.57087 .27841 m .56941 .30848 L .57136 .28009 L F
.56941 .30848 m .57094 .28808 L .57136 .28009 L F
.57136 .28009 m .56489 .40192 L .56987 .3362 L F
.56888 .40976 m .57396 .38159 L .57705 .30912 L 0 1 .211 r
F
.56888 .40976 m .57043 .42536 L .57396 .38159 L F
.55629 .51676 m .56294 .45024 L .559 .49048 L 0 0 .023 r
F
.56308 .50489 m .5689 .46306 L .56526 .49803 L 0 0 .076 r
F
.55464 .54365 m .56226 .51531 L .55821 .52894 L 0 1 .217 r
F
.55281 .55853 m .56031 .53663 L .5564 .54656 L 0 1 .238 r
F
.55464 .54365 m .5564 .54656 L .56031 .53663 L 0 1 .217 r
F
.55464 .54365 m .55396 .54958 L .5564 .54656 L F
.55281 .55853 m .55195 .56454 L .55411 .56381 L 0 1 .238 r
F
.55346 .56782 m .56382 .47897 L .56308 .50489 L 0 0 .088 r
F
.55346 .56782 m .5615 .48507 L .56382 .47897 L F
.55975 .44012 m .56526 .49802 L .5689 .46305 L 0 .601 .239 r
F
.55508 .53781 m .5615 .48507 L .55762 .5192 L 0 0 .057 r
F
.55346 .56782 m .55762 .5192 L .5615 .48507 L 0 0 .088 r
F
.55975 .44012 m .56132 .48806 L .56526 .49802 L 0 .601 .239 r
F
.55508 .53781 m .55561 .52819 L .559 .49048 L 0 0 .057 r
F
.54647 .57318 m .55709 .50549 L .55379 .52715 L 0 0 .027 r
F
.5445 .58054 m .55396 .54958 L .55464 .54365 L 0 1 .127 r
F
.5445 .58054 m .5505 .56349 L .55396 .54958 L F
.54309 .58817 m .55281 .55853 L .5505 .56349 L 0 1 .144 r
F
.54309 .58817 m .55195 .56454 L .55281 .55853 L F
.54309 .58817 m .54851 .57649 L .55195 .56454 L F
.54309 .58817 m .5505 .56349 L .54655 .57614 L F
.5445 .58054 m .54655 .57614 L .5505 .56349 L 0 1 .127 r
F
.54584 .5816 m .55666 .51113 L .55629 .51676 L 0 0 .048 r
F
.54584 .5816 m .55379 .52715 L .55666 .51113 L F
.54677 .56861 m .55427 .52214 L .54999 .54894 L 0 0 0 r
F
.54647 .57318 m .54999 .54894 L .55427 .52214 L 0 0 .027 r
F
.54584 .5816 m .55629 .51676 L .55291 .53992 L 0 0 .048 r
F
.54647 .57318 m .55379 .52715 L .54955 .55434 L 0 0 .027 r
F
.54584 .5816 m .54955 .55434 L .55379 .52715 L 0 0 .048 r
F
.55346 .56782 m .56308 .50489 L .55965 .54036 L 0 0 .088 r
F
.55346 .56782 m .55416 .55478 L .55762 .5192 L F
.54135 .59661 m .55054 .57346 L .54851 .57649 L 0 1 .164 r
F
.54135 .59661 m .54952 .57935 L .55054 .57346 L F
.54135 .59661 m .54613 .58945 L .54952 .57935 L F
.54135 .59661 m .54851 .57649 L .54476 .58646 L F
.54309 .58817 m .54476 .58646 L .54851 .57649 L 0 1 .144 r
F
.53932 .6055 m .54786 .58801 L .54613 .58945 L 0 1 .187 r
F
.53932 .6055 m .54613 .58945 L .54263 .59706 L F
.54135 .59661 m .54263 .59706 L .54613 .58945 L 0 1 .164 r
F
.54486 .59382 m .55561 .52819 L .55508 .53781 L 0 0 .068 r
F
.54486 .59382 m .55291 .53992 L .55561 .52819 L F
.55097 .53369 m .55965 .54035 L .56132 .48806 L 0 .607 .245 r
F
.5603 .50897 m .57043 .42536 L .56888 .40976 L 0 1 .24 r
F
.5603 .50897 m .5689 .46307 L .57043 .42536 L F
.57133 .27581 m .56732 .67562 L .57209 .27589 L 0 .771 .231 r
F
.57209 .27589 m .56732 .67562 L .57526 .37634 L F
.57089 .2782 m .56489 .40192 L .57087 .27841 L 0 1 .168 r
F
.57109 .2765 m .57031 .29215 L .57089 .2782 L F
.57031 .29215 m .56489 .40192 L .57089 .2782 L F
.571 .27844 m .57029 .29265 L .57109 .2765 L F
.57029 .29265 m .56489 .40192 L .57031 .29215 L F
.57029 .29265 m .57031 .29215 L .57109 .2765 L F
.56063 .42309 m .56589 .36657 L .56608 .36342 L 0 1 .124 r
F
.56057 .42379 m .56064 .42307 L .56063 .42309 L F
.56064 .42307 m .56589 .36657 L .56063 .42309 L F
.56062 .42319 m .56608 .36342 L .56383 .38377 L F
.56057 .42379 m .56063 .42309 L .56062 .42319 L F
.56063 .42309 m .56608 .36342 L .56062 .42319 L F
.55097 .53369 m .55975 .44012 L .55609 .43737 L 0 .607 .245 r
F
.55576 .45631 m .55775 .44269 L .55793 .44126 L 0 .744 .064 r
F
.56057 .42379 m .56772 .33609 L .56717 .34058 L 0 1 .124 r
F
.56656 .34681 m .56717 .34058 L .56683 .34338 L F
.56057 .42379 m .56717 .34058 L .56656 .34681 L F
.56062 .42318 m .56333 .38834 L .56312 .39132 L F
.56061 .42322 m .56333 .38831 L .56062 .42318 L F
.56333 .38831 m .56603 .35365 L .56333 .38834 L F
.56333 .38831 m .56333 .38834 L .56062 .42318 L F
.56057 .42379 m .56487 .36918 L .56478 .37032 L F
.56057 .42379 m .56481 .36997 L .56469 .37152 L F
.55577 .3465 m .55738 .3796 L .56081 .33927 L 0 .858 .233 r
F
.56027 .269 m .55648 .45022 L .56145 .27056 L 0 .993 .218 r
F
.55619 .45296 m .55718 .44564 L .55691 .44741 L 0 .744 .064 r
F
.55619 .45296 m .55691 .44741 L .55605 .45423 L F
.56057 .42379 m .56234 .41221 L .56589 .36657 L 0 1 .124 r
F
.56368 .38902 m .56331 .40093 L .56401 .38602 L 0 .927 .221 r
F
.56359 .39045 m .56331 .40093 L .56368 .38902 L F
.56342 .39284 m .56331 .40093 L .5636 .38976 L F
.56383 .38377 m .56608 .36342 L .56772 .33609 L 0 1 .124 r
F
.56331 .40093 m .56422 .39459 L .56469 .37152 L 0 .927 .221 r
F
.5711 .27643 m .571 .27844 L .57109 .2765 L 0 1 .168 r
F
.57105 .27582 m .56974 .30264 L .5711 .27643 L F
.56939 .30973 m .56489 .40192 L .56957 .30722 L F
.56897 .31581 m .56864 .31998 L .56864 .32138 L 0 .771 .231 r
F
.57105 .27582 m .57063 .28381 L .5696 .30502 L 0 1 .168 r
F
.56974 .30264 m .5696 .30502 L .56489 .40192 L F
.57105 .27582 m .5696 .30502 L .56974 .30264 L F
.56489 .40192 m .56856 .3232 L .56589 .36657 L F
.56856 .3232 m .56864 .32164 L .56853 .32347 L F
.56856 .3232 m .56853 .32347 L .56589 .36657 L F
.56946 .3061 m .56864 .32164 L .56856 .3232 L F
.56996 .29744 m .56856 .3232 L .56489 .40192 L F
.57063 .28381 m .56856 .3232 L .56996 .29744 L F
.56489 .40192 m .56651 .39974 L .56987 .3362 L F
.5603 .50897 m .56888 .40976 L .56524 .42902 L 0 1 .24 r
F
.5603 .50897 m .56526 .49803 L .5689 .46307 L F
.56732 .67562 m .56864 .32164 L .56688 .47482 L 0 .771 .231 r
F
.56692 .34266 m .56772 .33609 L .56844 .32402 L 0 1 .124 r
F
.56834 .32502 m .56844 .32402 L .5685 .32307 L F
.56692 .34266 m .56844 .32402 L .56834 .32502 L F
.56767 .33168 m .56803 .32689 L .5678 .32841 L 0 .927 .221 r
F
.56586 .35591 m .56782 .33071 L .56481 .36997 L 0 1 .124 r
F
.56683 .34338 m .56692 .34266 L .56804 .32793 L F
.56796 .32879 m .56851 .32288 L .56853 .32146 L 0 .927 .221 r
F
.56796 .32879 m .56853 .32146 L .5687 .30593 L F
.56608 .35297 m .56796 .32879 L .56602 .35371 L 0 1 .124 r
F
.56796 .32879 m .56804 .32793 L .56881 .31791 L F
.56796 .32879 m .56881 .31791 L .56796 .32884 L F
.56683 .34338 m .56804 .32793 L .56796 .32879 L F
.56796 .32879 m .56796 .32884 L .56602 .35371 L F
.56864 .32164 m .5685 .32307 L .56589 .36657 L 0 1 .168 r
F
.55097 .53369 m .56132 .48806 L .55975 .44012 L 0 .607 .245 r
F
.55689 .49723 m .56651 .39974 L .56489 .40192 L 0 1 .217 r
F
.55689 .49723 m .56524 .42902 L .56651 .39974 L F
.5603 .50897 m .56524 .42902 L .5619 .47071 L 0 1 .24 r
F
.55689 .49723 m .5619 .47071 L .56524 .42902 L 0 1 .217 r
F
.5603 .50897 m .56156 .51784 L .56526 .49803 L 0 1 .24 r
F
.56145 .53244 m .56688 .47482 L .56851 .32288 L 0 .927 .221 r
F
.56692 .34266 m .5685 .32307 L .56851 .32288 L 0 1 .124 r
F
.56864 .31998 m .56853 .32146 L .56851 .32288 L 0 .771 .231 r
F
.56864 .31998 m .56851 .32288 L .56857 .32224 L F
.56753 .3346 m .56851 .32288 L .56881 .31791 L 0 1 .124 r
F
.56692 .34266 m .56851 .32288 L .56753 .3346 L F
.56857 .32224 m .56851 .32288 L .5685 .32427 L 0 .771 .231 r
F
.56145 .53244 m .56851 .32288 L .56796 .32879 L 0 .927 .221 r
F
.5672 .33857 m .56796 .32883 L .56586 .35591 L 0 1 .124 r
F
.56796 .32883 m .56881 .31791 L .56782 .33071 L F
.56796 .32883 m .56782 .33071 L .56586 .35591 L F
.5676 .33357 m .56794 .32908 L .56767 .33168 L 0 .927 .221 r
F
.55689 .49723 m .56489 .40192 L .56134 .43074 L 0 1 .217 r
F
.56325 .44311 m .56793 .32928 L .5676 .33357 L 0 .927 .221 r
F
.56793 .32928 m .56794 .32908 L .5676 .33357 L F
.56794 .32908 m .56803 .32689 L .56767 .33168 L F
.56697 .35245 m .56754 .34203 L .56796 .32879 L F
.56793 .32928 m .56796 .32879 L .56803 .32689 L F
.56697 .35245 m .56796 .32879 L .56793 .32928 L F
.56593 .3553 m .5673 .34117 L .5676 .33357 L F
.56481 .36997 m .56881 .31791 L .56474 .37081 L 0 1 .124 r
F
.56782 .33071 m .56881 .31791 L .56481 .36997 L F
.56602 .35371 m .5672 .33857 L .56586 .35591 L F
.56864 .32164 m .56864 .31998 L .56856 .3224 L 0 .771 .231 r
F
.56869 .32075 m .56864 .32138 L .56864 .32164 L F
.56864 .32164 m .56881 .31791 L .56851 .32288 L 0 1 .168 r
F
.56864 .32164 m .56851 .32288 L .5685 .32307 L F
.56864 .32164 m .56856 .3224 L .5685 .32427 L 0 .771 .231 r
F
.56864 .31998 m .5687 .30593 L .56853 .32146 L F
.56864 .32164 m .5685 .32427 L .56688 .47482 L F
.57063 .28381 m .56864 .32164 L .56946 .3061 L 0 1 .168 r
F
.56325 .44311 m .56656 .3728 L .56754 .34203 L 0 .927 .221 r
F
.56325 .44311 m .56754 .34203 L .56697 .35245 L F
.5678 .32841 m .56803 .32689 L .5687 .30593 L F
.56469 .37152 m .56422 .39505 L .5673 .34117 L F
.56422 .39505 m .56325 .44311 L .56552 .38588 L F
.56422 .39505 m .56552 .38588 L .5673 .34117 L F
.56244 .40669 m .56243 .40724 L .56245 .40655 L F
.56057 .42379 m .56342 .39284 L .56237 .40772 L 0 1 .124 r
F
.56057 .42379 m .56469 .37152 L .56342 .39284 L F
.56312 .39132 m .56603 .35365 L .56487 .36918 L F
.56333 .38834 m .56603 .35365 L .56312 .39132 L F
.56243 .40724 m .5633 .40121 L .56511 .27309 L 0 .927 .221 r
F
.56349 .27214 m .56332 .27741 L .56237 .40772 L F
.55949 .43453 m .56234 .41221 L .56057 .42379 L 0 1 .201 r
F
.55308 .49849 m .56082 .42637 L .55949 .43453 L F
.56082 .42637 m .56234 .41221 L .55949 .43453 L F
.56133 .41525 m .56134 .41494 L .56133 .41497 L 0 .927 .221 r
F
.56134 .41494 m .56332 .27741 L .56133 .41497 L F
.56133 .41497 m .56332 .27741 L .56132 .40292 L F
.56237 .40759 m .56332 .27741 L .56133 .41525 L F
.55964 .2684 m .55639 .45086 L .56027 .269 L 0 .993 .218 r
F
.55638 .45168 m .55687 .44842 L .55819 .43854 L 0 .744 .064 r
F
.55638 .45168 m .55819 .43854 L .55777 .44139 L F
.55687 .44842 m .55793 .44126 L .56046 .42175 L F
.55687 .44842 m .56046 .42175 L .5607 .41987 L F
.55687 .44842 m .5607 .41987 L .56002 .42482 L F
.55308 .49849 m .56134 .43074 L .56234 .41221 L 0 1 .201 r
F
.55689 .49723 m .56134 .43074 L .5582 .46734 L 0 1 .217 r
F
.55308 .49849 m .5582 .46734 L .56134 .43074 L 0 1 .201 r
F
.55308 .49849 m .56057 .42379 L .55705 .45262 L F
.55308 .49849 m .55465 .49652 L .5582 .46734 L F
.55591 .47748 m .55811 .49067 L .56039 .42836 L 0 .993 .218 r
F
.55591 .47748 m .56039 .42836 L .55957 .43349 L F
.55777 .44139 m .55819 .43854 L .56002 .42482 L 0 .744 .064 r
F
.55777 .44139 m .56002 .42482 L .55942 .42919 L F
.55591 .47748 m .5607 .41987 L .55942 .42919 L 0 .993 .218 r
F
.55691 .44741 m .55725 .44489 L .55707 .44618 L 0 .744 .064 r
F
.55942 .42919 m .5607 .41987 L .56097 .4125 L 0 .993 .218 r
F
.56005 .42047 m .56097 .4125 L .56132 .40292 L F
.55942 .42919 m .56097 .4125 L .56005 .42047 L F
.55691 .44741 m .55707 .44618 L .55684 .44809 L 0 .744 .064 r
F
.55718 .44564 m .55907 .43171 L .55691 .44741 L F
.55942 .42919 m .56005 .42047 L .55707 .44618 L 0 .993 .218 r
F
.56005 .42047 m .56132 .40292 L .55707 .44618 L F
.55907 .43171 m .55773 .44139 L .55691 .44741 L 0 .744 .064 r
F
.55576 .45631 m .55793 .44126 L .55638 .45168 L F
.55638 .45168 m .55777 .44139 L .55619 .45296 L F
.55777 .44139 m .56142 .41435 L .5576 .44254 L F
.55777 .44139 m .5576 .44254 L .55619 .45296 L F
.54797 .47945 m .55738 .3796 L .55577 .3465 L 0 .771 .244 r
F
.54797 .47945 m .55609 .43737 L .55738 .3796 L F
.55964 .2684 m .55794 .31364 L .55623 .45195 L 0 .993 .218 r
F
.55691 .44753 m .55689 .44777 L .55605 .45423 L 0 .744 .064 r
F
.55097 .53369 m .55609 .43737 L .5527 .48152 L 0 .607 .245 r
F
.54797 .47945 m .5527 .48152 L .55609 .43737 L 0 .771 .244 r
F
.54797 .47945 m .5492 .49974 L .5527 .48152 L F
.54889 .50856 m .55705 .45262 L .55775 .44269 L 0 1 .18 r
F
.55633 .45408 m .55619 .45504 L .55617 .45646 L 0 .993 .218 r
F
.55308 .49849 m .55705 .45262 L .55412 .4796 L 0 1 .201 r
F
.54889 .50856 m .55412 .4796 L .55705 .45262 L 0 1 .18 r
F
.5563 .45571 m .55617 .45646 L .55591 .47748 L 0 .993 .218 r
F
.55633 .45408 m .55617 .45646 L .5563 .45571 L F
.55529 .45987 m .55775 .44269 L .55576 .45631 L 0 1 .18 r
F
.54889 .50856 m .55646 .45227 L .55529 .45987 L F
.55646 .45227 m .55775 .44269 L .55529 .45987 L F
.55591 .47748 m .55829 .44464 L .55683 .4526 L 0 .993 .218 r
F
.55707 .44618 m .55691 .44753 L .55684 .44809 L 0 .744 .064 r
F
.55686 .44804 m .55686 .44823 L .55707 .44618 L 0 .993 .218 r
F
.55686 .44823 m .55669 .4534 L .55707 .44618 L F
.55669 .4534 m .55591 .47748 L .55683 .4526 L F
.55669 .4534 m .55683 .4526 L .55707 .44618 L F
.55683 .4526 m .55942 .42919 L .55707 .44618 L F
.55829 .44464 m .55942 .42919 L .55683 .4526 L F
.55634 .45365 m .55633 .45408 L .55643 .45261 L F
.53932 .6055 m .54668 .59367 L .54786 .58801 L 0 1 .187 r
F
.54889 .50856 m .55576 .45631 L .55226 .48023 L 0 1 .18 r
F
.53932 .6055 m .54339 .60208 L .54668 .59367 L 0 1 .187 r
F
.54889 .50856 m .55061 .50365 L .55412 .4796 L 0 1 .18 r
F
.54647 .57318 m .54663 .5709 L .54999 .54894 L 0 0 .027 r
F
.54584 .5816 m .55291 .53992 L .54876 .56531 L 0 0 .048 r
F
.54486 .59382 m .54876 .56531 L .55291 .53992 L 0 0 .068 r
F
.54481 .57641 m .54267 .58522 L .54606 .57125 L 0 0 .007 r
F
.54299 .58432 m .54519 .57656 L .54558 .5742 L 0 0 0 r
F
.54483 .57591 m .54481 .57641 L .54484 .57587 L 0 0 .007 r
F
.53902 .60111 m .54133 .59395 L .54059 .5958 L 0 .735 .064 r
F
.53779 .60526 m .53883 .60195 L .53902 .60111 L F
.53883 .60195 m .54133 .59395 L .53902 .60111 L F
.54651 .5685 m .5466 .56813 L .54672 .56762 L 0 0 .023 r
F
.53735 .6071 m .54133 .59395 L .53779 .60526 L 0 .735 .064 r
F
.53325 .62063 m .53735 .6071 L .53779 .60526 L F
.53826 .60283 m .53919 .59952 L .53949 .5983 L 0 0 0 r
F
.53848 .60337 m .54243 .59148 L .54309 .58817 L 0 .735 .064 r
F
.53325 .62063 m .53769 .60653 L .53848 .60337 L F
.53769 .60653 m .54243 .59148 L .53848 .60337 L F
.53848 .60212 m .5388 .60113 L .53919 .59952 L 0 0 0 r
F
.53769 .60653 m .53956 .60114 L .53932 .60136 L 0 .735 .064 r
F
.54095 .59229 m .54477 .57737 L .54267 .58522 L 0 0 0 r
F
.54112 .59161 m .54267 .58522 L .5427 .58512 L 0 0 .007 r
F
.5388 .60113 m .54047 .59511 L .53949 .5983 L 0 0 0 r
F
.54047 .59511 m .54433 .58116 L .54108 .59265 L F
.54047 .59511 m .54108 .59265 L .53949 .5983 L F
.54344 .58326 m .54477 .57819 L .54496 .57744 L F
.53325 .62063 m .5365 .61059 L .5368 .60935 L 0 .735 .064 r
F
.53737 .6079 m .53911 .60265 L .53956 .60114 L F
.54122 .59119 m .5427 .58512 L .54269 .58517 L 0 0 .007 r
F
.53949 .5983 m .54291 .58618 L .54178 .58986 L 0 0 0 r
F
.53906 .60099 m .53894 .60142 L .53775 .60545 L 0 .735 .064 r
F
.53776 .6054 m .53775 .60545 L .5366 .60937 L F
.53906 .60099 m .53775 .60545 L .53776 .6054 L F
.53325 .62063 m .53779 .60526 L .5366 .60937 L F
.53421 .61774 m .53785 .60442 L .53826 .60283 L 0 0 0 r
F
.53421 .61774 m .53949 .5983 L .53762 .6053 L F
.53949 .5983 m .53935 .59889 L .53762 .6053 L F
.53325 .62063 m .53643 .61087 L .5365 .61059 L 0 .735 .064 r
F
.53421 .61774 m .53854 .60206 L .53848 .60212 L 0 0 0 r
F
.53325 .62063 m .53532 .61428 L .53641 .61095 L 0 .735 .064 r
F
.54008 .59652 m .54397 .58348 L .5445 .58054 L 0 0 0 r
F
.53421 .61774 m .53385 .61879 L .5366 .60937 L F
.53421 .61774 m .53934 .59973 L .54008 .59652 L F
.53934 .59973 m .54397 .58348 L .54008 .59652 L F
.53325 .62063 m .53641 .61095 L .53643 .61087 L 0 .735 .064 r
F
.53987 .59653 m .54344 .58326 L .54299 .58432 L 0 0 0 r
F
.5418 .58851 m .54388 .58026 L .54421 .57849 L 0 0 .007 r
F
.53779 .60526 m .53776 .6054 L .5366 .60937 L 0 .735 .064 r
F
.53626 .61071 m .53894 .60142 L .53844 .60321 L 0 0 0 r
F
.53421 .61774 m .53623 .61077 L .53626 .61071 L F
.53623 .61077 m .53894 .60142 L .53626 .61071 L F
.54046 .59468 m .54344 .58326 L .53987 .59653 L F
.54421 .57849 m .54447 .57783 L .54483 .57591 L 0 0 .007 r
F
.53421 .61774 m .5366 .60937 L .53775 .60545 L 0 0 0 r
F
.53421 .61774 m .53775 .60545 L .53765 .60585 L F
.53939 .59957 m .54371 .58445 L .5436 .58477 L F
.538 .60444 m .53937 .59966 L .53939 .59957 L F
.53655 .60951 m .53798 .60451 L .538 .60444 L F
.53798 .60451 m .53937 .59966 L .538 .60444 L F
.53653 .60958 m .53797 .60454 L .53655 .60951 L F
.53797 .60454 m .53937 .59966 L .53798 .60451 L F
.53797 .60454 m .53798 .60451 L .53655 .60951 L F
.53421 .61774 m .53618 .61096 L .53652 .60964 L F
.53618 .61096 m .53758 .60614 L .53652 .60964 L F
.53652 .60964 m .53758 .60614 L .53797 .60454 L F
.53907 .60277 m .54135 .59661 L .53911 .60265 L 0 .799 .087 r
F
.53208 .62428 m .53876 .60433 L .53907 .60277 L F
.53876 .60433 m .54135 .59661 L .53907 .60277 L F
.53208 .62428 m .54057 .60014 L .54135 .59661 L F
.5364 .61098 m .53907 .60277 L .53641 .61095 L F
.53638 .61114 m .5367 .60983 L .53637 .61119 L 0 0 .007 r
F
.53208 .62428 m .5364 .61098 L .53532 .61428 L 0 .799 .087 r
F
.53907 .60277 m .53907 .60278 L .53641 .61095 L F
.53641 .61095 m .53641 .61095 L .53532 .61428 L F
.53907 .60277 m .53641 .61095 L .53641 .61095 L F
.53494 .6158 m .53762 .6053 L .53935 .59889 L 0 0 0 r
F
.53873 .60144 m .53935 .59889 L .54178 .58986 L F
.53854 .60206 m .5388 .60113 L .53848 .60212 L F
.53494 .6158 m .53935 .59889 L .53873 .60144 L F
.53925 .5993 m .54046 .59468 L .5401 .5958 L F
.54156 .58981 m .54157 .58977 L .5367 .60982 L 0 0 .007 r
F
.5365 .61059 m .53737 .6079 L .5368 .60935 L 0 .735 .064 r
F
.5367 .60982 m .5367 .60982 L .53637 .61119 L 0 0 .007 r
F
.54156 .58981 m .5367 .60982 L .5367 .60982 L F
.5367 .60983 m .54156 .58981 L .5367 .60982 L F
.5367 .60983 m .5367 .60982 L .53637 .61119 L F
.5364 .61098 m .53641 .61095 L .53532 .61428 L 0 .799 .087 r
F
.53907 .60277 m .53911 .60265 L .53907 .60278 L F
.53553 .61348 m .54095 .59229 L .54188 .58848 L 0 0 0 r
F
.53494 .6158 m .53555 .61342 L .53553 .61348 L F
.53555 .61342 m .54095 .59229 L .53553 .61348 L F
.54199 .58791 m .54188 .58848 L .54267 .58522 L F
.53494 .6158 m .54188 .58848 L .54199 .58791 L F
.53494 .6158 m .53925 .5993 L .53987 .59653 L F
.53925 .5993 m .5401 .5958 L .53987 .59653 L F
.53671 .6098 m .54129 .59091 L .5367 .60985 L 0 0 .007 r
F
.54129 .59091 m .54304 .58371 L .54131 .59085 L F
.54129 .59091 m .54131 .59085 L .5367 .60985 L F
.54156 .58981 m .54387 .58028 L .54157 .58977 L F
.53889 .60083 m .54387 .58028 L .53909 .6 L F
.53844 .60321 m .53894 .60142 L .54059 .5958 L 0 0 0 r
F
.53797 .60454 m .54059 .5958 L .54202 .59059 L F
.53797 .60454 m .54202 .59059 L .542 .59042 L F
.53765 .60585 m .53775 .60545 L .53894 .60142 L F
.53779 .60526 m .53906 .60099 L .53776 .6054 L 0 .735 .064 r
F
.53906 .60099 m .54059 .5958 L .53894 .60142 L F
.53758 .60614 m .54059 .5958 L .53797 .60454 L 0 0 0 r
F
.53949 .5983 m .54178 .58986 L .53935 .59889 L F
.53737 .6079 m .53956 .60114 L .53769 .60653 L 0 .735 .064 r
F
.53494 .6158 m .53926 .59873 L .53838 .60238 L 0 0 0 r
F
.53926 .59873 m .54267 .58522 L .53914 .59934 L F
.53926 .59873 m .53914 .59934 L .53838 .60238 L F
.5374 .60808 m .53773 .60665 L .53744 .60799 L 0 0 .023 r
F
.53533 .61432 m .53873 .60144 L .5392 .59951 L 0 0 0 r
F
.5408 .59292 m .53838 .60238 L .54267 .58522 L 0 0 .007 r
F
.53565 .61309 m .5392 .59951 L .53925 .5993 L 0 0 0 r
F
.53708 .61006 m .53735 .61006 L .54057 .60014 L 0 .799 .087 r
F
.53208 .62428 m .5367 .61181 L .53708 .61006 L F
.5367 .61181 m .53735 .61006 L .53708 .61006 L F
.53545 .615 m .53838 .60238 L .5408 .59292 L 0 0 .007 r
F
.53545 .615 m .54086 .59243 L .54136 .59032 L F
.54143 .59001 m .54136 .59032 L .54196 .58778 L F
.53566 .61306 m .5392 .59951 L .53565 .61309 L 0 0 0 r
F
.53545 .615 m .54136 .59032 L .54143 .59001 L 0 0 .007 r
F
.53773 .60665 m .54254 .58544 L .53762 .60719 L 0 0 .023 r
F
.5373 .60821 m .53911 .60265 L .53737 .6079 L 0 .735 .064 r
F
.53773 .60665 m .53762 .60719 L .53744 .60799 L 0 0 .023 r
F
.54086 .59243 m .54632 .56969 L .54325 .58234 L 0 0 .007 r
F
.54254 .58544 m .54325 .58234 L .54257 .58534 L 0 0 .023 r
F
.54254 .58544 m .54257 .58534 L .53744 .60799 L F
.53421 .61774 m .53653 .60958 L .53655 .60951 L 0 0 0 r
F
.53937 .59966 m .54371 .58445 L .53939 .59957 L F
.5421 .58716 m .54196 .58778 L .54325 .58234 L 0 0 .007 r
F
.53539 .6141 m .53873 .60144 L .53533 .61432 L 0 0 0 r
F
.53545 .615 m .54196 .58778 L .5421 .58716 L 0 0 .007 r
F
.54617 .56999 m .54325 .58234 L .5466 .56813 L 0 0 .023 r
F
.54251 .58593 m .54325 .58234 L .54617 .56999 L F
.54307 .58364 m .54672 .56762 L .54351 .58171 L F
.54037 .59503 m .54327 .58394 L .54344 .58326 L 0 0 0 r
F
.54033 .5952 m .54327 .58394 L .54037 .59503 L F
.54033 .5952 m .54178 .58986 L .54477 .57819 L F
.53995 .59681 m .54178 .58986 L .54033 .5952 L F
.53744 .60799 m .54145 .59027 L .54251 .58593 L 0 0 .023 r
F
.53779 .60645 m .54251 .58593 L .54247 .58609 L F
.53261 .62323 m .53932 .6055 L .53735 .61006 L 0 .845 .107 r
F
.5307 .62853 m .53244 .62388 L .53261 .62323 L F
.53244 .62388 m .53932 .6055 L .53261 .62323 L F
.54632 .57061 m .54679 .56782 L .54677 .56861 L 0 0 .036 r
F
.53762 .60722 m .53761 .60725 L .53911 .60265 L 0 .735 .064 r
F
.54327 .58394 m .54477 .57819 L .54344 .58326 L 0 0 0 r
F
.53932 .60136 m .53956 .60114 L .54243 .59148 L 0 .735 .064 r
F
.54133 .59395 m .54151 .593 L .54059 .5958 L F
.54291 .58618 m .543 .5857 L .54178 .58986 L 0 0 0 r
F
.54344 .58326 m .54519 .57656 L .54299 .58432 L F
.54433 .58116 m .5443 .58122 L .54178 .58986 L F
.54477 .57737 m .54477 .57725 L .54267 .58522 L F
.5307 .62853 m .53842 .60912 L .53932 .6055 L 0 .845 .107 r
F
.53225 .62465 m .53533 .61779 L .53842 .60912 L F
.5307 .62853 m .53204 .62542 L .53225 .62465 L F
.53204 .62542 m .53533 .61779 L .53225 .62465 L F
.54443 .57898 m .5453 .57452 L .54632 .57061 L 0 0 .036 r
F
.53136 .62768 m .537 .61455 L .53533 .61779 L 0 .878 .122 r
F
.52914 .63322 m .53116 .62841 L .53136 .62768 L F
.53116 .62841 m .537 .61455 L .53136 .62768 L F
.53575 .6174 m .54369 .58173 L .54388 .58102 L 0 0 .036 r
F
.54441 .57906 m .54388 .58102 L .54443 .57898 L F
.53575 .6174 m .54388 .58102 L .54441 .57906 L F
.54369 .58173 m .5453 .57452 L .54443 .57898 L F
.5453 .57452 m .54679 .56782 L .54632 .57061 L F
.53325 .62063 m .5328 .62201 L .53532 .61428 L 0 .735 .064 r
F
.53313 .62101 m .5328 .62201 L .53325 .62063 L 0 0 .021 r
F
.53085 .62813 m .53467 .61752 L .53382 .61981 L 0 .845 .107 r
F
.53084 .62816 m .53467 .61752 L .53085 .62813 L F
.52914 .63322 m .53599 .61818 L .537 .61455 L 0 .878 .122 r
F
.52914 .63322 m .53306 .62561 L .53599 .61818 L F
.53229 .6237 m .53382 .61981 L .53735 .61006 L 0 .799 .087 r
F
.53208 .62428 m .53225 .62384 L .53229 .6237 L F
.53225 .62384 m .53382 .61981 L .53229 .6237 L F
.54346 .582 m .54304 .58371 L .54387 .58028 L 0 0 .007 r
F
.54447 .57783 m .54481 .57641 L .54483 .57591 L F
.54447 .57783 m .54387 .58028 L .54481 .57641 L F
.54484 .57587 m .54606 .57125 L .54632 .56969 L F
.54481 .57641 m .54606 .57125 L .54484 .57587 L F
.53935 .60124 m .54351 .58171 L .54679 .56782 L 0 0 .036 r
F
.53575 .6174 m .53908 .60209 L .53935 .60124 L F
.53908 .60209 m .54351 .58171 L .53935 .60124 L F
.5274 .6382 m .53442 .62356 L .53306 .62561 L 0 .967 .132 r
F
.5274 .6382 m .53331 .62712 L .53442 .62356 L F
.5274 .6382 m .53058 .63337 L .53331 .62712 L F
.52956 .63215 m .53533 .61779 L .53208 .62575 L 0 .878 .122 r
F
.52914 .63322 m .52953 .63224 L .52956 .63215 L F
.52953 .63224 m .53533 .61779 L .52956 .63215 L F
.5329 .62172 m .53267 .62242 L .53313 .62101 L 0 0 .021 r
F
.5307 .62853 m .53208 .62575 L .53533 .61779 L 0 .845 .107 r
F
.52551 .64335 m .5316 .63237 L .53058 .63337 L 0 1 .138 r
F
.52551 .64335 m .53041 .63581 L .5316 .63237 L F
.52823 .6363 m .53306 .62561 L .53015 .63191 L 0 .967 .132 r
F
.53144 .62623 m .53155 .62592 L .53208 .62428 L 0 0 .01 r
F
.52914 .63322 m .53015 .63191 L .53306 .62561 L 0 .878 .122 r
F
.52551 .64335 m .52791 .64097 L .53041 .63581 L 0 1 .138 r
F
.52488 .64617 m .52858 .64087 L .52791 .64097 L 0 1 .142 r
F
.52412 .64747 m .52477 .64652 L .52488 .64617 L F
.52477 .64652 m .52858 .64087 L .52488 .64617 L F
.53407 .61818 m .53385 .61879 L .53421 .61774 L 0 0 .031 r
F
.52411 .64751 m .5248 .64648 L .52412 .64747 L 0 1 .142 r
F
.5248 .64648 m .52858 .64087 L .52481 .64645 L F
.5248 .64648 m .52481 .64645 L .52412 .64747 L F
.53035 .62957 m .5301 .63037 L .5307 .62853 L 0 0 0 r
F
.52396 .64785 m .52429 .64735 L .52404 .64761 L 0 1 .142 r
F
.52429 .64735 m .52858 .64087 L .52437 .64712 L F
.52429 .64735 m .52437 .64712 L .52404 .64761 L F
.529 .6336 m .52846 .63518 L .52914 .63322 L 0 0 0 r
F
.52392 .64792 m .52732 .64416 L .52858 .64087 L 0 1 .142 r
F
.52348 .64857 m .52382 .64818 L .52392 .64792 L F
.52382 .64818 m .52732 .64416 L .52392 .64792 L F
.52842 .63531 m .52846 .63518 L .529 .6336 L 0 0 0 r
F
.52992 .63084 m .52985 .63109 L .53035 .62957 L F
.5287 .63448 m .52842 .63531 L .529 .6336 L F
.53137 .62646 m .53103 .62751 L .53144 .62623 L 0 0 .01 r
F
.52413 .64847 m .52434 .64843 L .52446 .64745 L 0 1 .142 r
F
.52434 .64843 m .52507 .64831 L .5246 .64764 L F
.52434 .64843 m .5246 .64764 L .52446 .64745 L F
.53254 .62286 m .53217 .62402 L .53258 .62274 L 0 0 .021 r
F
.52476 .64711 m .52507 .64831 L .52732 .64416 L 0 1 .142 r
F
.52459 .64763 m .52507 .64831 L .52476 .64711 L F
.52687 .64055 m .53058 .63337 L .52803 .63817 L 0 1 .138 r
F
.5265 .64132 m .52683 .64066 L .52687 .64055 L F
.52683 .64066 m .53058 .63337 L .52687 .64055 L F
.53214 .62413 m .53211 .6242 L .53254 .62286 L 0 0 .021 r
F
.52641 .64157 m .52674 .64093 L .5265 .64132 L 0 1 .138 r
F
.52674 .64093 m .53058 .63337 L .52681 .64072 L F
.52674 .64093 m .52681 .64072 L .5265 .64132 L F
.52992 .63084 m .53061 .62879 L .53003 .63054 L 0 0 0 r
F
.5236 .64855 m .52413 .64847 L .52366 .64836 L 0 1 .142 r
F
.52285 .65158 m .52319 .65142 L .5234 .65077 L 0 1 .143 r
F
.52226 .65244 m .52273 .65192 L .52285 .65158 L F
.52273 .65192 m .52319 .65142 L .52285 .65158 L F
.52797 .63657 m .52818 .63599 L .5287 .63448 L 0 0 0 r
F
.52221 .65276 m .52235 .6526 L .52235 .65235 L 0 1 .143 r
F
.52235 .6526 m .52341 .65134 L .52247 .65224 L F
.52235 .6526 m .52247 .65224 L .52235 .65235 L F
.52341 .65134 m .52349 .65108 L .52226 .65244 L F
.52377 .65022 m .52539 .64899 L .52507 .64831 L F
.5234 .65077 m .52367 .65052 L .52377 .65022 L F
.52367 .65052 m .52539 .64899 L .52377 .65022 L F
.53114 .62729 m .53176 .6253 L .53214 .62413 L 0 0 .021 r
F
.52341 .65134 m .52539 .64899 L .52349 .65108 L 0 1 .143 r
F
.52319 .65142 m .52539 .64899 L .5234 .65077 L F
.52817 .63648 m .53306 .62561 L .52823 .6363 L 0 .967 .132 r
F
.5274 .6382 m .52803 .63817 L .53058 .63337 L F
.53231 .62388 m .53331 .62054 L .5338 .61907 L 0 0 .031 r
F
.52302 .6518 m .52407 .65212 L .52539 .64899 L 0 1 .143 r
F
.5307 .62853 m .5301 .63037 L .53208 .62575 L 0 .845 .107 r
F
.52411 .64742 m .52791 .64097 L .52574 .64441 L 0 1 .142 r
F
.52408 .64752 m .52791 .64097 L .52411 .64742 L F
.52376 .64809 m .52399 .6477 L .5238 .64799 L F
.52399 .6477 m .52791 .64097 L .52402 .64761 L F
.52399 .6477 m .52402 .64761 L .5238 .64799 L F
.53399 .61894 m .53468 .61646 L .53494 .6158 L 0 0 .038 r
F
.53208 .62428 m .53155 .62592 L .53382 .61981 L 0 .799 .087 r
F
.52551 .64335 m .52574 .64441 L .52791 .64097 L 0 1 .138 r
F
.52914 .63322 m .52846 .63518 L .53015 .63191 L 0 .878 .122 r
F
.52263 .65168 m .52269 .6516 L .52264 .65166 L 0 1 .143 r
F
.52885 .63403 m .52914 .63322 L .52891 .63388 L 0 0 0 r
F
.52879 .63423 m .52853 .63494 L .5301 .63037 L F
.52886 .63399 m .52874 .63439 L .52908 .63334 L F
.52269 .6516 m .52348 .65051 L .5227 .65158 L 0 1 .143 r
F
.52348 .65051 m .52348 .65051 L .5227 .65158 L F
.52382 .65004 m .52382 .65004 L .52264 .65166 L F
.52383 .65003 m .52384 .65001 L .52264 .65166 L F
.52244 .65217 m .52507 .64831 L .52259 .65174 L F
.5221 .65289 m .52274 .65264 L .52302 .6518 L F
.52196 .65326 m .52407 .65212 L .5221 .65289 L F
.5283 .63562 m .52885 .63403 L .5284 .63533 L 0 0 0 r
F
.52155 .65366 m .52156 .65365 L .52163 .65344 L 0 1 .143 r
F
.52179 .65351 m .52407 .65212 L .52186 .65332 L F
.52674 .64002 m .52671 .6401 L .52734 .63836 L 0 0 0 r
F
.52734 .63836 m .52671 .6401 L .5274 .6382 L F
.52378 .64823 m .52413 .64847 L .52446 .64745 L 0 1 .142 r
F
.52373 .64838 m .52413 .64847 L .52378 .64823 L F
.52198 .65339 m .5221 .65535 L .52407 .65212 L 0 1 .143 r
F
.52885 .63403 m .52891 .63388 L .5272 .63883 L 0 0 0 r
F
.52818 .63599 m .52842 .63531 L .5287 .63448 L F
.52555 .64326 m .52641 .64157 L .52556 .64324 L 0 1 .138 r
F
.52357 .64856 m .52332 .65055 L .52507 .64831 L 0 1 .142 r
F
.52348 .64857 m .52346 .64887 L .52357 .64856 L F
.52346 .64887 m .52332 .65055 L .52357 .64856 L F
.52383 .65003 m .52507 .64831 L .52384 .65001 L 0 1 .143 r
F
.52343 .65058 m .52507 .64831 L .52352 .65029 L F
.5274 .6382 m .52666 .64025 L .52803 .63817 L 0 .967 .132 r
F
.52376 .65159 m .53294 .62183 L .53132 .62725 L 0 0 .031 r
F
.53294 .62183 m .53421 .61774 L .53309 .62143 L F
.53294 .62183 m .53309 .62143 L .53132 .62725 L F
.52551 .64335 m .52471 .64544 L .52574 .64441 L 0 1 .138 r
F
.52348 .64857 m .52264 .65066 L .52271 .65065 L 0 1 .142 r
F
.5254 .64365 m .52471 .64544 L .52551 .64335 L 0 0 0 r
F
.52347 .64868 m .52272 .65065 L .52332 .65055 L 0 1 .142 r
F
.52158 .65364 m .5216 .65402 L .52179 .65351 L 0 1 .143 r
F
.52148 .6537 m .52152 .6538 L .52158 .65364 L F
.52152 .6538 m .5216 .65402 L .52158 .65364 L F
.52518 .64423 m .52467 .64555 L .5254 .64365 L 0 0 0 r
F
.5214 .65391 m .52145 .654 L .52148 .6537 L 0 1 .143 r
F
.5216 .65402 m .5221 .65535 L .52179 .65351 L F
.52239 .65207 m .52244 .65217 L .52259 .65174 L F
.52511 .64443 m .52453 .64594 L .52518 .64423 L 0 0 0 r
F
.52145 .65363 m .52176 .65318 L .52147 .65359 L 0 1 .143 r
F
.52176 .65318 m .52244 .65217 L .52177 .65315 L F
.52176 .65318 m .52177 .65315 L .52147 .65359 L F
.52606 .64192 m .52588 .64237 L .52666 .64025 L 0 0 0 r
F
.52609 .64182 m .52615 .64166 L .52619 .64156 L F
.52533 .64394 m .52588 .64237 L .52606 .64192 L F
.52536 .64386 m .52606 .64192 L .52609 .64182 L F
.52601 .64204 m .52619 .64156 L .52667 .64021 L F
.51996 .65791 m .5221 .65535 L .52013 .65746 L 0 1 .142 r
F
.52154 .65419 m .52079 .65652 L .5221 .65535 L 0 1 .143 r
F
.52134 .65378 m .52091 .65594 L .52154 .65419 L F
.52091 .65594 m .52079 .65652 L .52154 .65419 L F
.52159 .65429 m .5221 .65535 L .52165 .65414 L F
.52191 .6536 m .5221 .65535 L .52198 .65339 L F
.52182 .65367 m .5221 .65535 L .5219 .65345 L F
.5212 .65598 m .52739 .63825 L .52778 .6371 L 0 0 0 r
F
.52739 .63825 m .52755 .63779 L .52778 .6371 L F
.52556 .64324 m .52598 .64241 L .52603 .64228 L 0 1 .138 r
F
.5212 .65598 m .52781 .63701 L .5272 .63883 L 0 0 0 r
F
.52778 .6371 m .52755 .63779 L .52797 .63657 L F
.52781 .63701 m .52793 .63667 L .52785 .6369 L F
.52781 .63701 m .52785 .6369 L .5272 .63883 L F
.52032 .6578 m .52519 .64428 L .52532 .64395 L F
.52032 .6578 m .52533 .64394 L .52533 .64394 L F
.5238 .64799 m .52408 .64752 L .52411 .64742 L 0 1 .142 r
F
.52032 .6578 m .52563 .64311 L .52601 .64204 L 0 0 0 r
F
.52563 .64311 m .52619 .64156 L .52601 .64204 L F
.52013 .65746 m .52065 .65691 L .52079 .65652 L 0 1 .142 r
F
.52065 .65691 m .5221 .65535 L .52079 .65652 L F
.52065 .65691 m .52079 .65652 L .52079 .65652 L F
.51911 .65892 m .51996 .65791 L .52013 .65746 L F
.52032 .6578 m .52533 .64394 L .52536 .64386 L 0 0 0 r
F
.52533 .64394 m .52606 .64192 L .52536 .64386 L F
.52032 .6578 m .52601 .64204 L .52576 .6428 L F
.52606 .64192 m .52615 .64166 L .52609 .64182 L F
.52619 .64156 m .52617 .64159 L .52621 .64149 L F
.52615 .64166 m .52617 .64159 L .52619 .64156 L F
.52619 .64156 m .52625 .6414 L .52667 .64021 L F
.52621 .64149 m .52666 .64025 L .52671 .6401 L F
.52617 .64159 m .52666 .64025 L .52621 .64149 L F
.52601 .64204 m .52656 .64054 L .52619 .64159 L F
.52601 .64204 m .52619 .64159 L .52576 .6428 L F
.52053 .65722 m .52206 .65668 L .5221 .65535 L 0 1 .142 r
F
.52446 .64616 m .52447 .64609 L .52511 .64443 L 0 0 0 r
F
.51947 .65865 m .52206 .65668 L .51958 .65836 L 0 1 .142 r
F
.51954 .65847 m .51958 .65836 L .51958 .65836 L F
.51947 .65865 m .51958 .65836 L .51954 .65847 L F
.52179 .65351 m .52186 .65332 L .52164 .65344 L 0 1 .143 r
F
.52134 .65378 m .5221 .65289 L .52226 .65244 L F
.5244 .64633 m .52396 .64745 L .52446 .64616 L 0 0 0 r
F
.51974 .65845 m .5207 .65963 L .52206 .65668 L 0 1 .142 r
F
.51961 .65877 m .5207 .65963 L .51974 .65845 L F
.51932 .65902 m .5207 .65963 L .51947 .65866 L F
.52145 .654 m .52159 .65429 L .52152 .6538 L 0 1 .143 r
F
.52348 .64857 m .52376 .64809 L .5238 .64799 L 0 1 .142 r
F
.52348 .64857 m .5236 .64855 L .52366 .64836 L F
.523 .64983 m .52264 .65066 L .52348 .64857 L 0 0 0 r
F
.51927 .65899 m .51903 .66203 L .5207 .65963 L 0 1 .142 r
F
.51922 .65911 m .51903 .66203 L .51927 .65899 L F
.5191 .65926 m .51903 .66203 L .51922 .65897 L F
.52147 .65359 m .52177 .65315 L .52183 .653 L 0 1 .143 r
F
.51911 .65915 m .51816 .66228 L .51903 .66203 L 0 1 .142 r
F
.51911 .65892 m .51893 .65958 L .51911 .65915 L F
.51893 .65958 m .51816 .66228 L .51911 .65915 L F
.52145 .654 m .52152 .6538 L .52148 .6537 L 0 1 .143 r
F
.52156 .65365 m .52164 .65344 L .52163 .65344 L F
.52134 .65378 m .52046 .65585 L .52079 .65652 L F
.51835 .662 m .52311 .64956 L .52249 .65128 L 0 0 0 r
F
.52311 .64956 m .52348 .64857 L .52323 .64926 L F
.52311 .64956 m .52323 .64926 L .52249 .65128 L F
.51835 .662 m .52235 .65143 L .523 .64983 L F
.52235 .65143 m .52264 .65066 L .523 .64983 L F
.51922 .65897 m .51922 .65911 L .51927 .65899 L 0 1 .142 r
F
.51911 .65892 m .5191 .65926 L .51922 .65897 L F
.52156 .65365 m .52179 .65351 L .52164 .65344 L 0 1 .143 r
F
.51937 .65982 m .52249 .65128 L .52376 .64794 L 0 0 0 r
F
.524 .64736 m .52376 .64794 L .52471 .64544 L F
.52177 .65315 m .52226 .65243 L .52183 .653 L 0 1 .143 r
F
.51937 .65982 m .52376 .64794 L .524 .64736 L 0 0 0 r
F
.51937 .65982 m .52391 .64759 L .5244 .64633 L F
.52391 .64759 m .52396 .64745 L .5244 .64633 L F
.51947 .65866 m .51961 .65877 L .51974 .65845 L 0 1 .142 r
F
.51912 .65892 m .51932 .65902 L .51947 .65866 L F
.51911 .65892 m .51947 .65865 L .51958 .65836 L F
.51746 .66284 m .51935 .6625 L .51903 .66203 L 0 .989 .142 r
F
.5174 .66288 m .51745 .66287 L .51746 .66284 L F
.51745 .66287 m .51935 .6625 L .51746 .66284 L F
.52089 .65495 m .52046 .65585 L .52134 .65378 L 0 0 0 r
F
.51739 .66289 m .51935 .6625 L .5174 .66288 L 0 .989 .142 r
F
.51736 .66292 m .51935 .6625 L .51737 .66289 L F
.51744 .6629 m .51892 .66338 L .51935 .6625 L F
.5173 .66293 m .51741 .66296 L .51744 .6629 L F
.51741 .66296 m .51892 .66338 L .51744 .6629 L F
.52084 .6551 m .52021 .65653 L .52089 .65495 L 0 0 0 r
F
.51735 .66294 m .51806 .66402 L .51892 .66338 L 0 .989 .142 r
F
.5173 .66293 m .51733 .66297 L .51735 .66294 L F
.51733 .66297 m .51806 .66402 L .51735 .66294 L F
.52024 .65645 m .52034 .65616 L .52039 .65604 L 0 0 0 r
F
.51731 .66292 m .51903 .66203 L .51816 .66228 L 0 .989 .142 r
F
.5173 .66293 m .51731 .66292 L .51731 .66292 L F
.51731 .66292 m .51903 .66203 L .51731 .66292 L F
.51911 .65892 m .5182 .66095 L .51816 .66228 L 0 1 .142 r
F
.51907 .65904 m .5182 .66095 L .51911 .65892 L 0 0 0 r
F
.51619 .66538 m .51756 .66605 L .51806 .66403 L 0 .922 .137 r
F
.5161 .66544 m .51615 .66546 L .51619 .66538 L F
.51615 .66546 m .51756 .66605 L .51619 .66538 L F
.51883 .65967 m .51819 .66099 L .51907 .65904 L 0 0 0 r
F
.51615 .66546 m .51618 .66873 L .51756 .66605 L 0 .922 .137 r
F
.5161 .66544 m .51611 .66556 L .51615 .66546 L F
.51611 .66556 m .51618 .66873 L .51615 .66546 L F
.51878 .6598 m .51807 .66131 L .51883 .65967 L 0 0 0 r
F
.5173 .66293 m .51734 .66401 L .51806 .66402 L 0 .989 .142 r
F
.5162 .66533 m .51806 .66403 L .51734 .66401 L 0 .922 .137 r
F
.5161 .66544 m .51617 .66539 L .5162 .66533 L F
.51617 .66539 m .51806 .66403 L .5162 .66533 L F
.51615 .6667 m .51901 .6592 L .51881 .65997 L 0 0 0 r
F
.51901 .6592 m .51911 .65892 L .51908 .65905 L F
.51901 .6592 m .51908 .65905 L .51881 .65997 L F
.51615 .6667 m .51805 .66138 L .51878 .6598 L F
.51805 .66138 m .51807 .66131 L .51878 .6598 L F
.51807 .66131 m .51819 .66099 L .51883 .65967 L F
.51819 .66099 m .5182 .66095 L .51907 .65904 L F
.51727 .66431 m .52019 .65656 L .52024 .65645 L F
.52019 .65656 m .52034 .65616 L .52024 .65645 L F
.51727 .66431 m .52017 .65664 L .52084 .6551 L F
.52017 .65664 m .52021 .65653 L .52084 .6551 L F
.52021 .65653 m .52046 .65585 L .52089 .65495 L F
.51727 .66431 m .52089 .65495 L .52069 .65563 L F
.52089 .65495 m .52134 .65378 L .52109 .65451 L F
.52089 .65495 m .52109 .65451 L .52069 .65563 L F
.51737 .66289 m .51739 .66289 L .5174 .66288 L 0 .989 .142 r
F
.5173 .66293 m .51736 .66292 L .51737 .66289 L F
.51727 .66431 m .51881 .65997 L .52004 .6569 L 0 0 0 r
F
.52016 .65663 m .52004 .6569 L .52034 .65616 L F
.51727 .66431 m .52004 .6569 L .52016 .65663 L F
.52039 .65604 m .52034 .65616 L .52046 .65585 L F
.51937 .65982 m .5244 .64633 L .52418 .64698 L F
.5244 .64633 m .52446 .64616 L .52444 .64624 L F
.5244 .64633 m .52444 .64624 L .52418 .64698 L F
.52446 .64616 m .52551 .64335 L .52471 .64554 L F
.52446 .64616 m .52471 .64554 L .52418 .64698 L F
.52396 .64745 m .52447 .64609 L .52446 .64616 L F
.51993 .65795 m .5203 .65788 L .52053 .65722 L 0 1 .142 r
F
.51958 .65836 m .51984 .65819 L .51993 .65795 L F
.51984 .65819 m .5203 .65788 L .51993 .65795 L F
.5203 .65788 m .52206 .65668 L .52053 .65722 L F
.52519 .64428 m .52588 .64237 L .52533 .64394 L 0 0 0 r
F
.52625 .6414 m .52671 .6401 L .52674 .64002 L F
.52656 .64054 m .52667 .64021 L .52659 .64044 L F
.52667 .64021 m .52625 .6414 L .52674 .64002 L F
.52656 .64054 m .52659 .64044 L .52576 .6428 L F
.52447 .64609 m .52453 .64594 L .52511 .64443 L F
.52183 .653 m .52226 .65243 L .52239 .65207 L 0 1 .143 r
F
.52226 .65243 m .52244 .65217 L .52239 .65207 L F
.52366 .64836 m .52373 .64838 L .52378 .64823 L 0 1 .142 r
F
.52348 .64857 m .52396 .64785 L .52404 .64761 L F
.52032 .6578 m .52418 .64698 L .52588 .64237 L 0 0 0 r
F
.52134 .65378 m .52145 .65363 L .52147 .65359 L 0 1 .143 r
F
.52159 .65429 m .52165 .65414 L .52152 .6538 L F
.52667 .64021 m .52702 .63926 L .52676 .63999 L 0 0 0 r
F
.52667 .64021 m .52676 .63999 L .52576 .6428 L F
.52453 .64594 m .52467 .64555 L .52518 .64423 L F
.52467 .64555 m .52471 .64544 L .5254 .64365 L F
.52348 .64863 m .52271 .65065 L .52272 .65065 L 0 1 .142 r
F
.52348 .64863 m .52272 .65065 L .52347 .64868 L F
.52348 .64857 m .52271 .65065 L .52348 .64863 L F
.52702 .63926 m .5274 .6382 L .5271 .63904 L 0 0 0 r
F
.52702 .63926 m .5271 .63904 L .52576 .6428 L F
.52199 .65441 m .52853 .63494 L .52868 .63455 L F
.52866 .63463 m .52876 .63432 L .52879 .63423 L F
.52598 .64241 m .52641 .64157 L .52603 .64228 L 0 1 .138 r
F
.52199 .65441 m .52854 .63498 L .52886 .63399 L 0 0 0 r
F
.52854 .63498 m .52874 .63439 L .52886 .63399 L F
.52199 .65441 m .52904 .63346 L .52848 .63516 L F
.52904 .63346 m .52908 .63334 L .52906 .63342 L F
.52904 .63346 m .52906 .63342 L .52848 .63516 L F
.5219 .65345 m .52191 .6536 L .52198 .65339 L 0 1 .143 r
F
.52179 .65351 m .52182 .65367 L .5219 .65345 L F
.52754 .63782 m .52794 .63664 L .52846 .63518 L 0 0 0 r
F
.52755 .63779 m .52818 .63599 L .52797 .63657 L F
.52793 .63667 m .52802 .63642 L .52796 .6366 L F
.52793 .63667 m .52796 .6366 L .5272 .63883 L F
.52134 .65378 m .5214 .65391 L .52148 .6537 L 0 1 .143 r
F
.5212 .65598 m .52576 .6428 L .5273 .63847 L 0 0 0 r
F
.52741 .63816 m .5273 .63847 L .52786 .63688 L F
.5212 .65598 m .5273 .63847 L .52741 .63816 L F
.52802 .63642 m .5283 .63562 L .52809 .63623 L F
.52802 .63642 m .52809 .63623 L .5272 .63883 L F
.52274 .65264 m .52407 .65212 L .52302 .6518 L 0 1 .143 r
F
.52908 .63334 m .5295 .63213 L .52992 .63084 L 0 0 0 r
F
.52908 .63334 m .52992 .63084 L .52924 .63289 L F
.52874 .63439 m .5295 .63213 L .52908 .63334 L F
.52268 .65313 m .52848 .63516 L .52957 .63189 L 0 0 .01 r
F
.5295 .63213 m .52985 .63109 L .52992 .63084 L 0 0 0 r
F
.53061 .62879 m .53063 .62875 L .52848 .63516 L F
.52985 .63109 m .5301 .63037 L .53035 .62957 L F
.52987 .63107 m .52957 .63189 L .53155 .62592 L 0 0 .01 r
F
.52992 .63084 m .53003 .63054 L .52848 .63516 L 0 0 0 r
F
.52954 .6321 m .52957 .63189 L .52987 .63107 L 0 0 .01 r
F
.5274 .6382 m .52815 .63654 L .5282 .63636 L 0 .967 .132 r
F
.52268 .65313 m .52892 .63389 L .52954 .6321 L 0 0 .01 r
F
.52892 .63389 m .52957 .63189 L .52954 .6321 L F
.52348 .65051 m .52382 .65004 L .52348 .65051 L 0 1 .143 r
F
.52269 .6516 m .5227 .65158 L .52264 .65166 L F
.52268 .65313 m .52958 .63195 L .52987 .63106 L 0 0 .01 r
F
.52958 .63195 m .52981 .63126 L .52987 .63106 L F
.52268 .65313 m .52987 .63106 L .52961 .63192 L F
.52987 .63106 m .52981 .63126 L .53012 .6303 L F
.52987 .63106 m .53012 .6303 L .52996 .63079 L F
.52987 .63106 m .52996 .63079 L .52961 .63192 L F
.52382 .65004 m .52383 .65003 L .52382 .65004 L 0 1 .143 r
F
.53087 .62816 m .53084 .62824 L .53114 .62729 L 0 0 .021 r
F
.52327 .65217 m .53058 .62904 L .53087 .62816 L F
.53058 .62904 m .53084 .62824 L .53087 .62816 L F
.52304 .65101 m .52343 .65058 L .52332 .65055 L 0 1 .143 r
F
.52264 .65166 m .52298 .6512 L .52304 .65101 L F
.52298 .6512 m .52343 .65058 L .52304 .65101 L F
.52343 .65058 m .52352 .65029 L .52332 .65055 L F
.53193 .62512 m .53196 .62493 L .53231 .62388 L 0 0 .031 r
F
.52376 .65159 m .53161 .62609 L .53193 .62512 L F
.53161 .62609 m .53196 .62493 L .53193 .62512 L F
.52327 .65217 m .53087 .62816 L .53055 .62924 L 0 0 .021 r
F
.53087 .62816 m .53157 .62593 L .53103 .62769 L F
.53087 .62816 m .53103 .62769 L .53055 .62924 L F
.52259 .65174 m .52263 .65168 L .52264 .65166 L 0 1 .143 r
F
.53314 .62175 m .53351 .62032 L .53399 .61894 L 0 0 .038 r
F
.52413 .6514 m .53273 .62292 L .53314 .62175 L F
.53273 .62292 m .53351 .62032 L .53314 .62175 L F
.53351 .62032 m .53468 .61646 L .53399 .61894 L F
.53157 .62593 m .53279 .62209 L .53173 .62548 L 0 0 .021 r
F
.53157 .62593 m .53173 .62548 L .53055 .62924 L F
.5283 .63562 m .5284 .63533 L .5272 .63883 L 0 0 0 r
F
.53196 .62493 m .53331 .62054 L .53231 .62388 L 0 0 .031 r
F
.52163 .65344 m .52196 .65326 L .5221 .65289 L 0 1 .143 r
F
.52199 .65441 m .5272 .63883 L .52853 .63494 L 0 0 0 r
F
.52134 .65378 m .52155 .65366 L .52163 .65344 L 0 1 .143 r
F
.53084 .62824 m .53176 .6253 L .53114 .62729 L 0 0 .021 r
F
.53012 .6303 m .53066 .62864 L .53104 .62746 L 0 0 .01 r
F
.52981 .63126 m .53066 .62864 L .53012 .6303 L F
.53104 .62746 m .53094 .6278 L .53137 .62646 L F
.53066 .62864 m .53094 .6278 L .53104 .62746 L F
.53061 .62879 m .5307 .62853 L .53063 .62875 L 0 0 0 r
F
.53012 .6303 m .53158 .6258 L .53032 .62972 L 0 0 .01 r
F
.53012 .6303 m .53032 .62972 L .52961 .63192 L F
.52908 .63334 m .52924 .63289 L .52848 .63516 L 0 0 0 r
F
.5221 .65289 m .52221 .65276 L .52226 .65244 L 0 1 .143 r
F
.52221 .65276 m .52235 .65235 L .52226 .65244 L F
.53176 .6253 m .53211 .6242 L .53214 .62413 L 0 0 .021 r
F
.53211 .6242 m .53217 .62402 L .53254 .62286 L F
.53094 .6278 m .53103 .62751 L .53137 .62646 L 0 0 .01 r
F
.52446 .64745 m .52459 .64763 L .52476 .64711 L 0 1 .142 r
F
.5338 .61907 m .53356 .61973 L .53407 .61818 L 0 0 .031 r
F
.53331 .62054 m .53356 .61973 L .5338 .61907 L F
.52603 .64228 m .52641 .64157 L .5265 .64132 L 0 1 .138 r
F
.52551 .64335 m .52555 .64326 L .52556 .64324 L F
.53356 .61973 m .53385 .61879 L .53407 .61818 L 0 0 .031 r
F
.53158 .6258 m .53208 .62428 L .53165 .62561 L 0 0 .01 r
F
.53103 .62751 m .53155 .62592 L .53144 .62623 L F
.53158 .6258 m .53165 .62561 L .52961 .63192 L F
.52404 .64761 m .52411 .64751 L .52412 .64747 L 0 1 .142 r
F
.53279 .62209 m .53325 .62063 L .53284 .62192 L 0 0 .021 r
F
.53279 .62209 m .53284 .62192 L .53055 .62924 L F
.5282 .63636 m .52817 .63648 L .52823 .6363 L 0 .967 .132 r
F
.52815 .63654 m .52817 .63648 L .5282 .63636 L F
.53258 .62274 m .53247 .62308 L .5329 .62172 L 0 0 .021 r
F
.53217 .62402 m .53247 .62308 L .53258 .62274 L F
.53247 .62308 m .53267 .62242 L .5329 .62172 L F
.53267 .62242 m .5328 .62201 L .53313 .62101 L F
.5307 .62853 m .53084 .62816 L .53085 .62813 L 0 .845 .107 r
F
.53467 .61752 m .53735 .61006 L .53473 .61729 L F
.53467 .61752 m .53473 .61729 L .53382 .61981 L F
.53789 .60606 m .54247 .58609 L .54307 .58364 L 0 0 .023 r
F
.53572 .61549 m .5374 .60808 L .53744 .60799 L F
.53572 .61549 m .53744 .60799 L .53744 .60799 L F
.53572 .61549 m .53779 .60647 L .53779 .60645 L F
.53572 .61549 m .53784 .60625 L .53789 .60606 L F
.53779 .60647 m .54251 .58593 L .53779 .60645 L F
.53784 .60625 m .54247 .58609 L .53789 .60606 L F
.54015 .59561 m .54387 .58028 L .54447 .57783 L 0 0 .007 r
F
.54156 .58981 m .54304 .58371 L .54346 .582 L F
.54269 .58517 m .5427 .58512 L .54304 .58371 L F
.54247 .58609 m .54564 .57232 L .54651 .5685 L 0 0 .023 r
F
.54251 .58593 m .54564 .57232 L .54247 .58609 L F
.54564 .57232 m .5466 .56813 L .54651 .5685 L F
.54247 .58609 m .54672 .56762 L .54307 .58364 L F
.53909 .6 m .54009 .59588 L .54015 .59561 L 0 0 .007 r
F
.54009 .59588 m .54387 .58028 L .54015 .59561 L F
.53637 .61119 m .53889 .60083 L .53909 .6 L F
.54131 .59085 m .54304 .58371 L .54156 .58981 L F
.54183 .58872 m .54388 .58026 L .5418 .58851 L F
.54112 .59161 m .5427 .58512 L .54122 .59119 L F
.54112 .59164 m .54267 .58522 L .54112 .59161 L F
.54145 .59027 m .54325 .58234 L .54251 .58593 L 0 0 .023 r
F
.53545 .615 m .53638 .61114 L .53637 .61119 L 0 0 .007 r
F
.53494 .6158 m .53539 .6141 L .53533 .61432 L 0 0 0 r
F
.5367 .60985 m .54131 .59085 L .54156 .58981 L 0 0 .007 r
F
.53667 .60997 m .53671 .6098 L .5367 .60985 L F
.53545 .615 m .53667 .60997 L .53667 .60997 L F
.53667 .60997 m .53671 .6098 L .53667 .60997 L F
.53672 .60977 m .5408 .59292 L .54081 .59288 L F
.53545 .615 m .53672 .60977 L .53672 .60977 L F
.53672 .60977 m .5408 .59292 L .53672 .60977 L F
.53677 .60957 m .54081 .59288 L .54094 .59235 L F
.53545 .615 m .5368 .60944 L .53677 .60957 L F
.5368 .60944 m .54081 .59288 L .53677 .60957 L F
.54094 .59235 m .54112 .59161 L .54122 .59119 L F
.54081 .59288 m .54112 .59161 L .54094 .59235 L F
.54081 .59288 m .54112 .59164 L .54112 .59161 L F
.5408 .59292 m .54112 .59164 L .54081 .59288 L F
.53545 .615 m .54183 .58872 L .5418 .58851 L F
.542 .59042 m .54202 .59059 L .54371 .58445 L 0 0 0 r
F
.5436 .58477 m .54371 .58445 L .54397 .58348 L F
.53643 .61087 m .53641 .61095 L .53761 .60725 L 0 .735 .064 r
F
.53643 .61087 m .53761 .60725 L .53762 .60722 L F
.53494 .6158 m .53566 .61306 L .53565 .61309 L 0 0 0 r
F
.53925 .5993 m .54033 .5952 L .54037 .59503 L F
.5392 .59951 m .54033 .5952 L .53925 .5993 L F
.5365 .61059 m .5373 .60821 L .53737 .6079 L 0 .735 .064 r
F
.53643 .61087 m .5373 .60821 L .5365 .61059 L F
.5392 .59951 m .53995 .59681 L .54033 .5952 L 0 0 0 r
F
.53873 .60144 m .53995 .59681 L .5392 .59951 L F
.5368 .60935 m .53737 .6079 L .53769 .60653 L 0 .735 .064 r
F
.54496 .57744 m .54477 .57819 L .54519 .57656 L 0 0 0 r
F
.54133 .59395 m .54309 .58817 L .54151 .593 L 0 .735 .064 r
F
.54388 .58026 m .54447 .57783 L .54421 .57849 L 0 0 .007 r
F
.54291 .58618 m .54433 .58116 L .543 .5857 L 0 0 0 r
F
.54433 .58116 m .5445 .58054 L .5443 .58122 L F
.54477 .57737 m .54558 .5742 L .54477 .57725 L F
.53575 .6174 m .54677 .56861 L .54346 .58379 L 0 0 .036 r
F
.53545 .615 m .54325 .58234 L .53888 .60088 L 0 0 .007 r
F
.53572 .61549 m .53888 .60088 L .54325 .58234 L 0 0 .023 r
F
.53572 .61549 m .54351 .58171 L .5391 .60112 L F
.53575 .6174 m .5391 .60112 L .54351 .58171 L 0 0 .036 r
F
.54174 .59102 m .55097 .53369 L .54746 .53473 L 0 .625 .253 r
F
.54534 .5562 m .55465 .49652 L .55308 .49849 L 0 1 .246 r
F
.54534 .5562 m .55337 .51367 L .55465 .49652 L F
.54486 .59382 m .55508 .53781 L .55165 .5608 L 0 0 .068 r
F
.54534 .5562 m .55308 .49849 L .54966 .51659 L 0 1 .246 r
F
.5445 .58054 m .54397 .58348 L .54655 .57614 L 0 1 .127 r
F
.54584 .5816 m .54613 .57776 L .54955 .55434 L 0 0 .048 r
F
.54889 .50856 m .55226 .48023 L .5496 .4985 L 0 1 .18 r
F
.54957 .49102 m .55256 .46847 L .55028 .4696 L 0 .881 .237 r
F
.53957 .56075 m .5492 .49974 L .54797 .47945 L 0 .727 .253 r
F
.5443 .52305 m .55226 .48023 L .55248 .4775 L 0 1 .145 r
F
.55192 .48021 m .55248 .4775 L .55255 .47666 L F
.5443 .52305 m .55248 .4775 L .55192 .48021 L F
.53716 .53545 m .54462 .49041 L .54604 .45351 L 0 .8 .252 r
F
.53957 .56075 m .54797 .47945 L .54462 .49041 L 0 .727 .253 r
F
.53957 .56075 m .54462 .49041 L .54137 .5255 L F
.53716 .53545 m .54137 .5255 L .54462 .49041 L 0 .8 .252 r
F
.53934 .53889 m .54699 .50675 L .54698 .50665 L 0 1 .129 r
F
.54476 .51523 m .54698 .50665 L .54698 .50652 L F
.53934 .53889 m .54698 .50665 L .54476 .51523 L F
.5443 .52305 m .55255 .47666 L .55206 .479 L 0 1 .145 r
F
.53957 .56075 m .54746 .53473 L .5492 .49974 L 0 .727 .253 r
F
.537 .61455 m .5448 .60193 L .54339 .60208 L 0 1 .202 r
F
.537 .61455 m .54348 .60729 L .5448 .60193 L F
.537 .61455 m .54032 .61418 L .54348 .60729 L F
.537 .61455 m .54339 .60208 L .54017 .60765 L F
.53932 .6055 m .54017 .60765 L .54339 .60208 L 0 1 .187 r
F
.54135 .59661 m .54057 .60014 L .54263 .59706 L 0 1 .164 r
F
.537 .61455 m .53742 .61801 L .54032 .61418 L 0 1 .202 r
F
.53932 .6055 m .53842 .60912 L .54017 .60765 L 0 1 .187 r
F
.5443 .52305 m .5496 .4985 L .55226 .48023 L 0 1 .145 r
F
.54948 .49362 m .55206 .479 L .54957 .49102 L 0 .881 .237 r
F
.55094 .48538 m .55206 .479 L .55163 .48145 L 0 1 .145 r
F
.5443 .52305 m .55111 .48439 L .55094 .48538 L F
.55111 .48439 m .55206 .479 L .55094 .48538 L F
.5443 .52305 m .55094 .48538 L .54922 .49512 L F
.55094 .48538 m .55157 .48182 L .55052 .48773 L F
.55094 .48538 m .55052 .48773 L .54922 .49512 L F
.54476 .51523 m .54698 .50652 L .54677 .47584 L 0 .92 .24 r
F
.53957 .56075 m .54386 .56116 L .54746 .53473 L 0 .727 .253 r
F
.54191 .55744 m .55061 .50365 L .54889 .50856 L 0 1 .244 r
F
.54191 .55744 m .54966 .51659 L .55061 .50365 L F
.537 .61455 m .53599 .61818 L .53742 .61801 L 0 1 .202 r
F
.53554 .62078 m .54663 .5709 L .54647 .57318 L 0 0 .047 r
F
.53554 .62078 m .54346 .58379 L .54663 .5709 L F
.5443 .52305 m .54618 .51687 L .5496 .4985 L 0 1 .145 r
F
.54191 .55744 m .54665 .53886 L .54966 .51659 L 0 1 .244 r
F
.54309 .58817 m .54243 .59148 L .54476 .58646 L 0 1 .144 r
F
.53554 .62078 m .54647 .57318 L .5431 .58893 L 0 0 .047 r
F
.54191 .55744 m .54889 .50856 L .54557 .52599 L 0 1 .244 r
F
.53934 .53889 m .54464 .51871 L .54699 .50675 L 0 1 .129 r
F
.54457 .51907 m .54698 .50652 L .54476 .51523 L 0 .92 .24 r
F
.5443 .52305 m .54948 .49362 L .54699 .50675 L 0 1 .145 r
F
.54948 .49362 m .55028 .4696 L .54806 .50098 L 0 .881 .237 r
F
.54948 .49362 m .54966 .49259 L .54886 .49685 L 0 1 .145 r
F
.54948 .49362 m .54886 .49685 L .54699 .50675 L F
.54966 .49259 m .5484 .49916 L .54699 .50675 L F
.54948 .49362 m .54806 .50098 L .54798 .50214 L 0 .881 .237 r
F
.53575 .6174 m .54346 .58379 L .53906 .60335 L 0 0 .036 r
F
.53554 .62078 m .53906 .60335 L .54346 .58379 L 0 0 .047 r
F
.53442 .62356 m .54139 .61508 L .54032 .61418 L 0 1 .212 r
F
.53442 .62356 m .53993 .62011 L .54139 .61508 L F
.53442 .62356 m .53694 .62565 L .53993 .62011 L F
.53442 .62356 m .54032 .61418 L .53742 .61801 L F
.53442 .62356 m .5344 .62801 L .53694 .62565 L F
.53509 .62563 m .54613 .57776 L .54584 .5816 L 0 0 .057 r
F
.53509 .62563 m .5431 .58893 L .54613 .57776 L F
.53817 .56218 m .54618 .51687 L .5443 .52305 L 0 1 .244 r
F
.53817 .56218 m .54557 .52599 L .54618 .51687 L F
.53509 .62563 m .54584 .5816 L .54242 .59725 L 0 0 .057 r
F
.53957 .56075 m .54047 .57237 L .54386 .56116 L 0 .727 .253 r
F
.54191 .55744 m .54557 .52599 L .54288 .54437 L 0 1 .244 r
F
.53817 .56218 m .54288 .54437 L .54557 .52599 L F
.54191 .55744 m .54332 .55641 L .54665 .53886 L F
.53554 .62078 m .5431 .58893 L .53874 .60775 L 0 0 .047 r
F
.53509 .62563 m .53874 .60775 L .5431 .58893 L 0 0 .057 r
F
.5443 .52305 m .54699 .50675 L .54464 .51871 L 0 1 .145 r
F
.5316 .63237 m .53766 .62739 L .53694 .62565 L 0 1 .217 r
F
.5316 .63237 m .53609 .63207 L .53766 .62739 L F
.5316 .63237 m .53694 .62565 L .5344 .62801 L F
.53441 .63184 m .54529 .58849 L .54486 .59382 L 0 0 .067 r
F
.53441 .63184 m .54242 .59725 L .54529 .58849 L F
.54174 .59102 m .54746 .53473 L .54386 .56116 L 0 .625 .253 r
F
.54486 .59382 m .54529 .58849 L .54876 .56531 L 0 0 .068 r
F
.54174 .59102 m .55209 .55874 L .55097 .53369 L 0 .625 .253 r
F
.55054 .57346 m .54952 .57935 L .55137 .58031 L 0 1 .252 r
F
.54786 .58801 m .54668 .59367 L .54821 .59588 L 0 1 .262 r
F
.5448 .60193 m .54348 .60729 L .54465 .61041 L 0 1 .27 r
F
.54355 .60932 m .55416 .55478 L .55346 .56782 L 0 0 .087 r
F
.54355 .60932 m .55165 .5608 L .55416 .55478 L F
.54486 .59382 m .55165 .5608 L .5476 .58191 L 0 0 .068 r
F
.54355 .60932 m .5476 .58191 L .55165 .5608 L 0 0 .087 r
F
.54355 .60932 m .55346 .56782 L .55 .5886 L F
.54355 .60932 m .54412 .60275 L .5476 .58191 L F
.54174 .59102 m .55 .5886 L .55209 .55874 L 0 .625 .253 r
F
.53441 .63184 m .54486 .59382 L .54144 .60859 L 0 0 .067 r
F
.54355 .60932 m .55 .5886 L .54608 .60324 L 0 0 .087 r
F
.54174 .59102 m .54608 .60324 L .55 .5886 L 0 .625 .253 r
F
.53509 .62563 m .54242 .59725 L .53815 .61435 L 0 0 .057 r
F
.53441 .63184 m .53815 .61435 L .54242 .59725 L 0 0 .067 r
F
.54139 .61508 m .54074 .62387 L .54328 .62387 L 0 1 .276 r
F
.54139 .61508 m .53993 .62011 L .54074 .62387 L F
.5316 .63237 m .5333 .63642 L .53609 .63207 L 0 1 .217 r
F
.52858 .64087 m .53366 .63882 L .5333 .63642 L 0 1 .218 r
F
.52858 .64087 m .53198 .64316 L .53366 .63882 L F
.5335 .63921 m .54412 .60275 L .54355 .60932 L 0 0 .079 r
F
.5335 .63921 m .54144 .60859 L .54412 .60275 L F
.54174 .59102 m .54253 .60428 L .54608 .60324 L 0 .625 .253 r
F
.53494 .6158 m .53468 .61646 L .53762 .6053 L 0 0 0 r
F
.53545 .615 m .53527 .61518 L .53838 .60238 L 0 0 .007 r
F
.53572 .61549 m .53564 .61514 L .53888 .60088 L 0 0 .023 r
F
.53575 .6174 m .53576 .61646 L .5391 .60112 L 0 0 .036 r
F
.52413 .6514 m .53132 .62725 L .53468 .61646 L 0 0 .038 r
F
.52413 .6514 m .53494 .6158 L .53188 .62608 L F
.52438 .65165 m .53527 .61518 L .53545 .615 L 0 0 .043 r
F
.52438 .65165 m .53188 .62608 L .53527 .61518 L F
.52438 .65165 m .53545 .615 L .53225 .62588 L F
.52539 .64899 m .52942 .6494 L .52943 .64648 L 0 1 .215 r
F
.52539 .64899 m .52767 .65338 L .52942 .6494 L F
.52539 .64899 m .52537 .65581 L .52767 .65338 L F
.52539 .64899 m .52943 .64648 L .52769 .64657 L F
.52539 .64899 m .52406 .65504 L .52537 .65581 L F
.52539 .64899 m .52407 .65212 L .52406 .65504 L F
.52451 .65233 m .53564 .61514 L .53572 .61549 L 0 0 .047 r
F
.52451 .65233 m .53225 .62588 L .53564 .61514 L F
.52451 .65233 m .53572 .61549 L .53242 .62676 L F
.52858 .64087 m .52732 .64416 L .52769 .64657 L 0 1 .218 r
F
.52452 .65346 m .53576 .61646 L .53575 .6174 L 0 0 .049 r
F
.52452 .65346 m .53242 .62676 L .53576 .61646 L F
.52452 .65346 m .53575 .6174 L .53238 .62878 L F
.52858 .64087 m .52943 .64648 L .53198 .64316 L 0 1 .218 r
F
.52858 .64087 m .5333 .63642 L .53114 .63755 L F
.5316 .63237 m .53114 .63755 L .5333 .63642 L 0 1 .217 r
F
.53442 .62356 m .53331 .62712 L .5344 .62801 L 0 1 .212 r
F
.52858 .64087 m .52769 .64657 L .52943 .64648 L 0 1 .218 r
F
.5316 .63237 m .53041 .63581 L .53114 .63755 L 0 1 .217 r
F
.52441 .65503 m .53565 .61925 L .53554 .62078 L 0 0 .052 r
F
.52441 .65503 m .53238 .62878 L .53565 .61925 L F
.53231 .62995 m .54174 .59102 L .53839 .59423 L 0 .649 .263 r
F
.53554 .62078 m .53565 .61925 L .53906 .60335 L 0 0 .047 r
F
.53509 .62563 m .5353 .62352 L .53874 .60775 L 0 0 .057 r
F
.52441 .65503 m .53554 .62078 L .53214 .63198 L 0 0 .052 r
F
.53441 .63184 m .53471 .6292 L .53815 .61435 L 0 0 .067 r
F
.53231 .62995 m .54253 .60428 L .54174 .59102 L 0 .649 .263 r
F
.53976 .60316 m .54844 .55969 L .54505 .57068 L 0 1 .282 r
F
.53976 .60316 m .54959 .5626 L .54844 .55969 L F
.53976 .60316 m .5477 .57735 L .54959 .5626 L F
.53089 .6144 m .53839 .59423 L .54047 .57237 L 0 .71 .263 r
F
.52376 .65159 m .53055 .62924 L .53385 .61879 L 0 0 .031 r
F
.53231 .62995 m .53839 .59423 L .5347 .61178 L 0 .649 .263 r
F
.53089 .6144 m .5347 .61178 L .53839 .59423 L 0 .71 .263 r
F
.53742 .59956 m .54662 .55695 L .54534 .5562 L 0 1 .279 r
F
.53742 .59956 m .54505 .57068 L .54662 .55695 L F
.53742 .59956 m .54534 .5562 L .54208 .56851 L F
.53089 .6144 m .54047 .57237 L .53957 .56075 L 0 .71 .263 r
F
.53481 .59817 m .54332 .55641 L .54191 .55744 L 0 1 .28 r
F
.53481 .59817 m .54208 .56851 L .54332 .55641 L F
.53976 .60316 m .54505 .57068 L .54167 .58832 L 0 1 .282 r
F
.53742 .59956 m .54167 .58832 L .54505 .57068 L 0 1 .279 r
F
.53976 .60316 m .54403 .59416 L .5477 .57735 L 0 1 .282 r
F
.53742 .59956 m .54208 .56851 L .539 .58573 L 0 1 .279 r
F
.53481 .59817 m .539 .58573 L .54208 .56851 L 0 1 .28 r
F
.53441 .63184 m .54144 .60859 L .5373 .62299 L 0 0 .067 r
F
.5335 .63921 m .5373 .62299 L .54144 .60859 L 0 0 .079 r
F
.53742 .59956 m .53839 .60072 L .54167 .58832 L 0 1 .279 r
F
.53976 .60316 m .54062 .60524 L .54403 .59416 L 0 1 .282 r
F
.52206 .65668 m .52499 .65912 L .52537 .65581 L 0 1 .208 r
F
.52206 .65668 m .52537 .65581 L .52406 .65504 L F
.52417 .65702 m .5353 .62352 L .53509 .62563 L 0 0 .055 r
F
.52417 .65702 m .53214 .63198 L .5353 .62352 L F
.53766 .62739 m .54371 .62808 L .54328 .62387 L 0 1 .281 r
F
.53766 .62739 m .54328 .62387 L .54074 .62387 L F
.53766 .62739 m .53652 .63629 L .53867 .63724 L F
.53766 .62739 m .53609 .63207 L .53652 .63629 L F
.5335 .63921 m .54355 .60932 L .54016 .62242 L 0 0 .079 r
F
.52417 .65702 m .53509 .62563 L .53169 .63632 L 0 0 .055 r
F
.5335 .63921 m .53389 .63613 L .5373 .62299 L 0 0 .079 r
F
.53231 .62995 m .54016 .62242 L .54253 .60428 L 0 .649 .263 r
F
.52206 .65668 m .52318 .66278 L .52499 .65912 L 0 1 .208 r
F
.52382 .65938 m .53471 .6292 L .53441 .63184 L 0 0 .059 r
F
.52382 .65938 m .53169 .63632 L .53471 .6292 L F
.5335 .63921 m .54016 .62242 L .53619 .63332 L 0 0 .079 r
F
.53231 .62995 m .53619 .63332 L .54016 .62242 L 0 .649 .263 r
F
.52382 .65938 m .53441 .63184 L .53105 .64169 L 0 0 .059 r
F
.53231 .62995 m .53282 .63656 L .53619 .63332 L 0 .649 .263 r
F
.52452 .65346 m .52792 .64148 L .53242 .62676 L 0 0 .049 r
F
.52452 .65346 m .53238 .62878 L .52789 .64308 L F
.52441 .65503 m .52789 .64308 L .53238 .62878 L 0 0 .052 r
F
.52441 .65503 m .53214 .63198 L .5277 .64542 L F
.52417 .65702 m .5277 .64542 L .53214 .63198 L 0 0 .055 r
F
.52452 .65346 m .52453 .65296 L .52792 .64148 L 0 0 .049 r
F
.52441 .65503 m .52447 .65435 L .52789 .64308 L 0 0 .052 r
F
.52417 .65702 m .53169 .63632 L .52735 .64849 L 0 0 .055 r
F
.52382 .65938 m .52735 .64849 L .53169 .63632 L 0 0 .059 r
F
.52417 .65702 m .52428 .65617 L .5277 .64542 L 0 0 .055 r
F
.52206 .65668 m .52118 .66443 L .52318 .66278 L 0 1 .208 r
F
.51935 .6625 m .52139 .66633 L .52118 .66443 L 0 1 .209 r
F
.51935 .6625 m .52082 .6674 L .52139 .66633 L F
.51935 .6625 m .51986 .66695 L .52082 .6674 L F
.51756 .66605 m .51901 .67062 L .51986 .66695 L 0 1 .193 r
F
.51756 .66605 m .51717 .67384 L .51901 .67062 L F
.52206 .65668 m .52032 .66295 L .52118 .66443 L 0 1 .208 r
F
.51935 .6625 m .52118 .66443 L .52032 .66295 L 0 1 .209 r
F
.51935 .6625 m .51914 .66529 L .51986 .66695 L F
.51756 .66605 m .51986 .66695 L .51914 .66529 L 0 1 .193 r
F
.51756 .66605 m .51559 .6746 L .51717 .67384 L F
.51409 .67261 m .51439 .67846 L .51559 .6746 L 0 1 .178 r
F
.51409 .67261 m .51254 .68139 L .51439 .67846 L F
.51409 .67261 m .51559 .6746 L .51533 .6724 L F
.51756 .66605 m .51533 .6724 L .51559 .6746 L 0 1 .193 r
F
.51316 .68035 m .52453 .65296 L .52452 .65346 L 0 0 .05 r
F
.51316 .68035 m .52452 .65346 L .52112 .66177 L F
.51316 .68035 m .52447 .65435 L .52441 .65503 L 0 0 .048 r
F
.51316 .68035 m .52112 .66177 L .52447 .65435 L F
.52276 .6584 m .53282 .63656 L .53231 .62995 L 0 .678 .273 r
F
.53096 .63527 m .54062 .60524 L .53976 .60316 L 0 1 .308 r
F
.53096 .63527 m .53848 .61599 L .54062 .60524 L F
.53233 .63869 m .54183 .60905 L .53848 .61599 L 0 1 .311 r
F
.53967 .61485 m .54697 .50656 L .54457 .51907 L 0 .92 .24 r
F
.54697 .50656 m .54698 .50652 L .54457 .51907 L F
.54966 .49259 m .5504 .48839 L .5484 .49916 L 0 1 .145 r
F
.54476 .51523 m .54698 .50652 L .54695 .5057 L 0 1 .129 r
F
.53817 .56218 m .5443 .52305 L .54112 .53853 L 0 1 .244 r
F
.53934 .53889 m .54136 .53248 L .54464 .51871 L 0 1 .129 r
F
.53817 .56218 m .5397 .55991 L .54288 .54437 L 0 1 .244 r
F
.53481 .59817 m .54191 .55744 L .5388 .5701 L 0 1 .28 r
F
.53967 .61485 m .54476 .51523 L .54293 .52331 L 0 .92 .24 r
F
.54476 .51523 m .54481 .51431 L .54301 .52293 L F
.53934 .53889 m .54476 .51523 L .54293 .52327 L 0 1 .129 r
F
.54481 .51431 m .54677 .47584 L .54293 .52331 L 0 .92 .24 r
F
.53716 .53545 m .53815 .54493 L .54137 .5255 L 0 .8 .252 r
F
.54113 .53066 m .54437 .48304 L .54123 .5249 L 0 .92 .24 r
F
.53934 .53889 m .54293 .52327 L .5419 .52751 L 0 1 .129 r
F
.54111 .53076 m .5419 .52751 L .54113 .53066 L F
.53934 .53889 m .5419 .52751 L .54111 .53076 L F
.53716 .53545 m .54604 .45351 L .54471 .43915 L 0 .8 .252 r
F
.5293 .60055 m .53815 .54493 L .53716 .53545 L 0 .756 .262 r
F
.53915 .5369 m .53925 .53632 L .53819 .53995 L 0 .956 .244 r
F
.53925 .53632 m .54123 .5249 L .53819 .53995 L F
.53819 .53995 m .54123 .5249 L .54065 .49548 L F
.5293 .60055 m .53716 .53545 L .53415 .54869 L 0 .756 .262 r
F
.53405 .55438 m .54023 .53356 L .53819 .53995 L 0 .875 .115 r
F
.54023 .53356 m .54065 .53214 L .53819 .53995 L F
.53716 .53545 m .54471 .43915 L .54154 .4581 L 0 .8 .252 r
F
.53716 .53545 m .54154 .4581 L .53862 .49807 L F
.53666 .54478 m .54065 .49548 L .5381 .50488 L 0 .956 .244 r
F
.53819 .53995 m .54065 .49548 L .53666 .54478 L F
.53504 .54812 m .5381 .50488 L .53512 .54149 L F
.53405 .55438 m .53929 .53787 L .54097 .53123 L 0 .875 .115 r
F
.53405 .55438 m .54097 .53123 L .54095 .53127 L F
.53405 .55438 m .54098 .53118 L .54065 .53214 L F
.53652 .54569 m .53681 .54469 L .53664 .54527 L F
.53405 .55438 m .53819 .53995 L .53652 .54569 L F
.53819 .53995 m .53831 .53954 L .53652 .54569 L F
.54095 .53127 m .54097 .53123 L .54098 .53118 L F
.53089 .6144 m .53957 .56075 L .53638 .56931 L 0 .71 .263 r
F
.53817 .56218 m .54112 .53853 L .53878 .55301 L 0 1 .244 r
F
.5293 .60055 m .53638 .56931 L .53815 .54493 L 0 .756 .262 r
F
.53415 .56921 m .54112 .53853 L .54136 .53248 L 0 1 .242 r
F
.53415 .56921 m .53878 .55301 L .54112 .53853 L F
.53415 .56921 m .54136 .53248 L .53934 .53889 L F
.53089 .6144 m .53638 .56931 L .533 .59243 L 0 .71 .263 r
F
.53198 .59876 m .5397 .55991 L .53817 .56218 L 0 1 .284 r
F
.53198 .59876 m .5388 .5701 L .5397 .55991 L F
.53934 .53889 m .54113 .53067 L .53929 .53787 L 0 1 .129 r
F
.52413 .6514 m .52708 .64105 L .53132 .62725 L 0 0 .038 r
F
.52413 .6514 m .53188 .62608 L .52752 .64051 L F
.52438 .65165 m .52752 .64051 L .53188 .62608 L 0 0 .043 r
F
.52438 .65165 m .53225 .62588 L .5278 .64064 L F
.52451 .65233 m .5278 .64064 L .53225 .62588 L 0 0 .047 r
F
.52451 .65233 m .53242 .62676 L .52792 .64148 L F
.52451 .65233 m .52447 .652 L .5278 .64064 L F
.52206 .65668 m .5207 .65963 L .52032 .66295 L 0 1 .208 r
F
.51316 .68035 m .52447 .652 L .52451 .65233 L 0 0 .053 r
F
.51935 .6625 m .51892 .66338 L .51914 .66529 L 0 1 .209 r
F
.51316 .68035 m .52107 .66031 L .52447 .652 L 0 0 .053 r
F
.51316 .68035 m .52451 .65233 L .52114 .66088 L F
.51316 .68035 m .52114 .66088 L .52453 .65296 L 0 0 .05 r
F
.52276 .6584 m .53231 .62995 L .52913 .63442 L 0 .678 .273 r
F
.53096 .63527 m .53976 .60316 L .53654 .61139 L 0 1 .308 r
F
.53967 .61485 m .54113 .53066 L .53945 .5741 L 0 .92 .24 r
F
.54113 .53066 m .54123 .5249 L .54101 .53107 L F
.54113 .53067 m .54113 .53066 L .54101 .53107 L 0 1 .129 r
F
.54113 .53067 m .54101 .53107 L .53929 .53787 L F
.54113 .53066 m .54101 .53107 L .53945 .5741 L 0 .92 .24 r
F
.54113 .53066 m .54126 .53009 L .54101 .53107 L 0 1 .129 r
F
.54065 .53214 m .54098 .53118 L .54101 .53107 L 0 .875 .115 r
F
.54064 .5323 m .54101 .53107 L .54065 .53214 L 0 .956 .244 r
F
.53481 .59817 m .5388 .5701 L .53607 .586 L 0 1 .28 r
F
.53198 .59876 m .53607 .586 L .5388 .5701 L 0 1 .284 r
F
.53481 .59817 m .53589 .59847 L .539 .58573 L 0 1 .28 r
F
.52327 .65217 m .52961 .63192 L .5328 .62201 L 0 0 .021 r
F
.52268 .65313 m .52961 .63192 L .52577 .64381 L 0 0 .01 r
F
.52327 .65217 m .52577 .64381 L .52961 .63192 L 0 0 .021 r
F
.53089 .6144 m .53148 .62045 L .5347 .61178 L 0 .71 .263 r
F
.52327 .65217 m .53055 .62924 L .5265 .64217 L 0 0 .021 r
F
.52376 .65159 m .5265 .64217 L .53055 .62924 L 0 0 .031 r
F
.52199 .65441 m .52848 .63516 L .52491 .64588 L 0 0 0 r
F
.52268 .65313 m .52491 .64588 L .52848 .63516 L 0 0 .01 r
F
.52376 .65159 m .53132 .62725 L .52708 .64105 L 0 0 .031 r
F
.5212 .65598 m .5272 .63883 L .52392 .64831 L 0 0 0 r
F
.52199 .65441 m .52392 .64831 L .5272 .63883 L F
.5212 .65598 m .52282 .65102 L .52576 .6428 L F
.52207 .65222 m .52913 .63442 L .53148 .62045 L 0 .709 .272 r
F
.52939 .63276 m .53742 .59956 L .53436 .60869 L 0 1 .307 r
F
.51835 .662 m .52069 .65563 L .52264 .65066 L 0 0 0 r
F
.52207 .65222 m .53148 .62045 L .53089 .6144 L 0 .709 .272 r
F
.52764 .63119 m .53589 .59847 L .53481 .59817 L 0 1 .307 r
F
.52764 .63119 m .53436 .60869 L .53589 .59847 L F
.53425 .61138 m .54101 .53107 L .54064 .5323 L 0 .956 .244 r
F
.53425 .61138 m .53945 .5741 L .54101 .53107 L F
.54065 .53214 m .54101 .53107 L .54123 .5249 L F
.54065 .53214 m .54101 .53107 L .54126 .53009 L 0 .875 .115 r
F
.53831 .53954 m .54081 .53083 L .53683 .54461 L F
.53831 .53954 m .53683 .54461 L .53652 .54569 L F
.535 .55088 m .53671 .54335 L .53504 .54812 L 0 .956 .244 r
F
.5293 .60055 m .533 .59243 L .53638 .56931 L 0 .756 .262 r
F
.53415 .56921 m .53579 .56617 L .53878 .55301 L 0 1 .242 r
F
.53415 .56921 m .53934 .53889 L .53635 .55203 L F
.5293 .60055 m .52996 .60587 L .533 .59243 L 0 .756 .262 r
F
.53198 .59876 m .53817 .56218 L .53525 .57443 L 0 1 .284 r
F
.53405 .55438 m .5362 .54827 L .53929 .53787 L 0 .875 .115 r
F
.5293 .60055 m .53415 .54869 L .5311 .57598 L 0 .756 .262 r
F
.52894 .60097 m .53579 .56617 L .53415 .56921 L 0 1 .29 r
F
.52894 .60097 m .53525 .57443 L .53579 .56617 L F
.53415 .56921 m .53635 .55203 L .53439 .56314 L 0 1 .242 r
F
.52754 .58875 m .5311 .57598 L .53415 .54869 L 0 .79 .261 r
F
.52989 .57749 m .53635 .55203 L .5362 .54827 L 0 1 .238 r
F
.52989 .57749 m .53439 .56314 L .53635 .55203 L F
.53198 .59876 m .53525 .57443 L .53289 .58852 L 0 1 .284 r
F
.52894 .60097 m .53289 .58852 L .53525 .57443 L 0 1 .29 r
F
.52989 .57749 m .5362 .54827 L .53405 .55438 L 0 1 .238 r
F
.53198 .59876 m .53314 .5983 L .53607 .586 L 0 1 .284 r
F
.52207 .65222 m .53089 .6144 L .52788 .62199 L 0 .709 .272 r
F
.52764 .63119 m .53481 .59817 L .53194 .60779 L 0 1 .307 r
F
.53664 .54527 m .53671 .54335 L .53522 .54993 L 0 .956 .244 r
F
.53501 .55063 m .53825 .53962 L .53515 .55006 L 0 .875 .115 r
F
.53405 .55438 m .53664 .54527 L .53502 .55057 L F
.52128 .6465 m .52996 .60587 L .5293 .60055 L 0 .733 .272 r
F
.52128 .6465 m .52788 .62199 L .52996 .60587 L F
.52894 .60097 m .53415 .56921 L .53145 .58056 L 0 1 .29 r
F
.52989 .57749 m .53162 .57406 L .53439 .56314 L 0 1 .238 r
F
.52894 .60097 m .53018 .5999 L .53289 .58852 L 0 1 .29 r
F
.53405 .55438 m .53498 .55071 L .5336 .55516 L 0 .875 .115 r
F
.52939 .63276 m .53436 .60869 L .53124 .62205 L 0 1 .307 r
F
.52764 .63119 m .53124 .62205 L .53436 .60869 L F
.53425 .61138 m .53501 .55063 L .53369 .58124 L 0 .956 .244 r
F
.53501 .55063 m .53512 .54149 L .53476 .55132 L F
.53498 .55071 m .53501 .55063 L .53473 .55145 L 0 .875 .115 r
F
.53501 .55063 m .53476 .55132 L .53473 .55145 L F
.53501 .55063 m .53476 .55132 L .53369 .58124 L 0 .956 .244 r
F
.53501 .55063 m .53515 .55006 L .53476 .55132 L 0 .875 .115 r
F
.53498 .55071 m .53473 .55145 L .5336 .55516 L F
.52754 .58875 m .53452 .51593 L .53171 .53289 L 0 .79 .261 r
F
.52754 .58875 m .5356 .52303 L .53452 .51593 L F
.52754 .58875 m .53415 .54869 L .5356 .52303 L F
.52754 .58875 m .53171 .53289 L .52903 .56281 L F
.52563 .5792 m .53171 .53289 L .53284 .50704 L 0 .813 .261 r
F
.52563 .5792 m .52903 .56281 L .53171 .53289 L F
.53041 .56214 m .53418 .51935 L .53151 .52924 L 0 .988 .249 r
F
.5285 .5688 m .5336 .55516 L .53456 .552 L 0 .849 .109 r
F
.5285 .5688 m .53456 .552 L .53432 .55259 L F
.5285 .5688 m .53469 .55156 L .53412 .55297 L F
.53469 .55156 m .53473 .55145 L .53412 .55297 L F
.52563 .5792 m .52641 .58275 L .52903 .56281 L 0 .813 .261 r
F
.52872 .56634 m .53151 .52924 L .52873 .56086 L 0 .988 .249 r
F
.52754 .58875 m .52826 .59322 L .5311 .57598 L 0 .79 .261 r
F
.52128 .6465 m .5293 .60055 L .52648 .61099 L 0 .733 .272 r
F
.52989 .57749 m .53405 .55438 L .53128 .5653 L 0 1 .238 r
F
.5204 .64134 m .52826 .59322 L .52754 .58875 L 0 .751 .271 r
F
.52573 .60443 m .53162 .57406 L .52989 .57749 L 0 1 .297 r
F
.5204 .64134 m .52648 .61099 L .52826 .59322 L 0 .751 .271 r
F
.52573 .60443 m .53145 .58056 L .53162 .57406 L 0 1 .297 r
F
.52894 .60097 m .53145 .58056 L .52949 .59267 L 0 1 .29 r
F
.52573 .60443 m .52949 .59267 L .53145 .58056 L 0 1 .297 r
F
.52128 .6465 m .52444 .6382 L .52788 .62199 L 0 .733 .272 r
F
.52574 .63053 m .53314 .5983 L .53198 .59876 L 0 1 .31 r
F
.52574 .63053 m .53198 .59876 L .52933 .60848 L F
.52989 .57749 m .53128 .5653 L .52975 .57374 L 0 1 .238 r
F
.5204 .64134 m .52754 .58875 L .52495 .60166 L 0 .751 .271 r
F
.52573 .60443 m .52989 .57749 L .52744 .58771 L 0 1 .297 r
F
.52573 .60443 m .52703 .60291 L .52949 .59267 L F
.5237 .63071 m .53018 .5999 L .52894 .60097 L 0 1 .315 r
F
.5237 .63071 m .52933 .60848 L .53018 .5999 L F
.51944 .63683 m .52641 .58275 L .52563 .5792 L 0 .762 .271 r
F
.51944 .63683 m .52495 .60166 L .52641 .58275 L F
.52543 .58631 m .53128 .5653 L .53075 .56318 L 0 1 .233 r
F
.52543 .58631 m .52975 .57374 L .53128 .5653 L F
.5285 .5688 m .53075 .56318 L .5336 .55516 L 0 .849 .109 r
F
.52543 .58631 m .52724 .58274 L .52975 .57374 L 0 1 .233 r
F
.5204 .64134 m .52337 .63029 L .52648 .61099 L 0 .751 .271 r
F
.5237 .63071 m .52894 .60097 L .52653 .61048 L 0 1 .315 r
F
.52574 .63053 m .52933 .60848 L .52695 .621 L 0 1 .31 r
F
.5237 .63071 m .52695 .621 L .52933 .60848 L 0 1 .315 r
F
.5285 .5688 m .53382 .5538 L .53191 .55874 L 0 .849 .109 r
F
.53409 .55327 m .53412 .55297 L .53186 .55966 L 0 .988 .249 r
F
.53412 .55297 m .53512 .54149 L .53212 .55819 L F
.53382 .5538 m .53412 .55297 L .53191 .55874 L 0 .849 .109 r
F
.53412 .55297 m .53212 .55819 L .53186 .55966 L 0 .988 .249 r
F
.53432 .55259 m .53456 .552 L .53473 .55145 L 0 .849 .109 r
F
.53404 .55381 m .53476 .55144 L .53476 .55132 L 0 .988 .249 r
F
.53412 .55297 m .53476 .55132 L .53512 .54149 L F
.53412 .55297 m .53473 .55145 L .53476 .55132 L 0 .849 .109 r
F
.53404 .55381 m .53476 .55132 L .53412 .55297 L 0 .988 .249 r
F
.53412 .55297 m .53476 .55132 L .53515 .55006 L 0 .849 .109 r
F
.53412 .55297 m .53515 .55006 L .53191 .55874 L F
.53191 .55874 m .53515 .55006 L .5343 .55171 L F
.53039 .56267 m .53193 .55842 L .53041 .56214 L 0 .988 .249 r
F
.52543 .58631 m .53075 .56318 L .5285 .5688 L 0 1 .233 r
F
.52871 .56729 m .53041 .56214 L .52872 .56634 L 0 .988 .249 r
F
.5285 .5688 m .53039 .56285 L .52871 .56729 L 0 .849 .109 r
F
.53193 .55842 m .53418 .51935 L .53041 .56214 L 0 .988 .249 r
F
.53193 .55842 m .53512 .54149 L .53418 .51935 L F
.5322 .55774 m .53512 .54149 L .53193 .55842 L F
.53039 .56285 m .5343 .55171 L .5316 .55903 L 0 .849 .109 r
F
.5285 .5688 m .53199 .5585 L .53039 .56285 L F
.53039 .56285 m .53191 .55874 L .53039 .56267 L 0 .988 .249 r
F
.53191 .55874 m .53193 .55842 L .53039 .56267 L F
.53199 .5585 m .5343 .55171 L .53039 .56285 L 0 .849 .109 r
F
.52871 .56739 m .53039 .56285 L .52871 .56729 L 0 .988 .249 r
F
.52862 .6159 m .53039 .56285 L .52871 .56739 L F
.53039 .56285 m .53041 .56214 L .52871 .56729 L F
.52871 .56729 m .53039 .56285 L .52872 .56725 L 0 .849 .109 r
F
.52872 .56725 m .5316 .55903 L .52874 .56709 L F
.53039 .56285 m .5316 .55903 L .52872 .56725 L F
.52862 .6159 m .53191 .55885 L .53039 .56285 L 0 .988 .249 r
F
.53191 .55885 m .53191 .55874 L .53039 .56285 L F
.53041 .56214 m .53151 .52924 L .52872 .56634 L F
.53186 .55966 m .5322 .55774 L .53193 .55842 L F
.52862 .6159 m .53409 .55327 L .53186 .55966 L F
.52862 .6159 m .53369 .58124 L .53476 .55144 L F
.53405 .55438 m .53502 .55057 L .535 .55063 L 0 .875 .115 r
F
.52862 .6159 m .53476 .55144 L .53404 .55381 L 0 .988 .249 r
F
.535 .55063 m .53502 .55057 L .53501 .55063 L 0 .875 .115 r
F
.53664 .54527 m .53819 .53995 L .53666 .54478 L 0 .956 .244 r
F
.53664 .54527 m .53825 .53962 L .53501 .55063 L 0 .875 .115 r
F
.53664 .54527 m .53522 .54993 L .535 .55088 L 0 .956 .244 r
F
.53425 .61138 m .53664 .54527 L .535 .55088 L F
.53671 .54335 m .5381 .50488 L .53504 .54812 L F
.54059 .53292 m .54065 .53214 L .53799 .54358 L F
.54065 .53214 m .54072 .53131 L .54032 .53308 L F
.54065 .53214 m .54032 .53308 L .53799 .54358 L F
.54072 .53131 m .54123 .5249 L .53925 .53632 L F
.54072 .53131 m .53925 .53632 L .53799 .54358 L F
.53664 .54527 m .54081 .53083 L .53825 .53962 L 0 .875 .115 r
F
.53681 .54469 m .54081 .53083 L .53664 .54527 L F
.53425 .61138 m .53819 .53995 L .53664 .54527 L 0 .956 .244 r
F
.54293 .52327 m .54437 .48304 L .54113 .53066 L 0 .92 .24 r
F
.53819 .53995 m .54126 .53009 L .54081 .53083 L 0 .875 .115 r
F
.54065 .53214 m .54126 .53009 L .53819 .53995 L F
.53799 .54358 m .53915 .5369 L .53819 .53995 L 0 .956 .244 r
F
.53425 .61138 m .54059 .53292 L .53799 .54358 L F
.53967 .61485 m .54293 .52327 L .54113 .53066 L 0 .92 .24 r
F
.54113 .53066 m .54293 .52327 L .54119 .53041 L 0 1 .129 r
F
.54119 .53041 m .54454 .51629 L .54126 .53009 L F
.54476 .51523 m .54301 .52293 L .54298 .52309 L 0 .92 .24 r
F
.54476 .51523 m .54298 .52309 L .54303 .52288 L F
.54293 .52327 m .54454 .51629 L .54119 .53041 L 0 1 .129 r
F
.54303 .52288 m .54298 .52309 L .54293 .52331 L 0 .92 .24 r
F
.54293 .52327 m .54695 .5057 L .54454 .51629 L 0 1 .129 r
F
.54476 .51523 m .54695 .5057 L .54293 .52327 L F
.54454 .51629 m .54695 .5057 L .54789 .50261 L 0 0 .046 r
F
.54534 .5562 m .55007 .53866 L .55337 .51367 L 0 1 .246 r
F
.54534 .5562 m .54966 .51659 L .54665 .53886 L F
.54534 .5562 m .54662 .55695 L .55007 .53866 L F
.54183 .60905 m .55119 .56864 L .5477 .57735 L 0 1 .288 r
F
.54183 .60905 m .55219 .57379 L .55119 .56864 L F
.54183 .60905 m .55 .5886 L .55219 .57379 L F
.54183 .60905 m .5477 .57735 L .54403 .59416 L F
.54183 .60905 m .54608 .60324 L .55 .5886 L F
.54359 .61707 m .55 .5886 L .54608 .60325 L 0 1 .295 r
F
.53366 .63882 m .53867 .63724 L .53652 .63629 L 0 1 .284 r
F
.53366 .63882 m .53204 .64769 L .53377 .6494 L F
.53727 .63331 m .54421 .62082 L .54359 .61707 L 0 1 .315 r
F
.53351 .64296 m .53568 .63846 L .53727 .63331 L F
.53568 .63846 m .54421 .62082 L .53727 .63331 L F
.53568 .63846 m .54154 .63043 L .54421 .62082 L F
.53351 .64296 m .53501 .64062 L .53568 .63846 L F
.53501 .64062 m .54154 .63043 L .53568 .63846 L F
.54363 .62485 m .55 .58861 L .54608 .60325 L 0 .502 .25 r
F
.5475 .60054 m .54551 .60653 L .54781 .59904 L 0 0 .105 r
F
.53351 .64296 m .53727 .63331 L .54016 .62242 L 0 1 .315 r
F
.53727 .63331 m .54359 .61707 L .54107 .621 L F
.53727 .63331 m .54107 .621 L .54016 .62242 L F
.53351 .64296 m .53736 .63951 L .54154 .63043 L F
.53351 .64296 m .53392 .64488 L .53736 .63951 L F
.53413 .64541 m .54363 .62485 L .54069 .6228 L 0 .578 .261 r
F
.54191 .62717 m .54261 .61979 L .54508 .60803 L 0 0 .105 r
F
.54518 .60769 m .54508 .60803 L .54532 .60689 L F
.54191 .62717 m .54508 .60803 L .54518 .60769 L F
.53352 .64672 m .53413 .64541 L .54016 .62243 L 0 .578 .261 r
F
.53413 .64541 m .54069 .6228 L .54016 .62243 L F
.54564 .60577 m .54532 .60689 L .54608 .60325 L 0 0 .105 r
F
.54191 .62717 m .54532 .60689 L .54564 .60577 L F
.54191 .62717 m .54535 .60744 L .5475 .60054 L F
.54535 .60744 m .54551 .60653 L .5475 .60054 L F
.54781 .59904 m .54608 .60324 L .55 .58862 L F
.54608 .60324 m .54608 .60325 L .55 .58862 L F
.55 .58862 m .54608 .60325 L .55 .5886 L F
.54551 .60653 m .54608 .60325 L .54781 .59904 L F
.54191 .62717 m .55 .5886 L .55229 .58891 L F
.54191 .62717 m .55229 .58891 L .55142 .604 L F
.54183 .60905 m .54257 .61203 L .54608 .60324 L 0 1 .288 r
F
.53519 .65352 m .5434 .64945 L .54649 .64248 L 0 1 .324 r
F
.54363 .62485 m .5443 .639 L .54798 .64861 L 0 .502 .25 r
F
.53446 .64796 m .54154 .63043 L .53736 .63951 L 0 1 .32 r
F
.53519 .65352 m .54263 .6396 L .53829 .64654 L 0 1 .324 r
F
.53446 .64796 m .53829 .64654 L .54263 .6396 L 0 1 .32 r
F
.53352 .64672 m .5443 .639 L .54363 .62485 L 0 .578 .261 r
F
.54191 .62717 m .55142 .604 L .54795 .62058 L 0 0 .105 r
F
.54191 .62717 m .54795 .62058 L .5442 .62752 L F
.53568 .65948 m .5469 .64947 L .5434 .64945 L 0 1 .326 r
F
.53344 .65411 m .53811 .65611 L .53638 .653 L 0 1 .323 r
F
.53568 .65948 m .5434 .64945 L .53894 .65413 L 0 1 .326 r
F
.53519 .65352 m .53894 .65413 L .5434 .64945 L 0 1 .324 r
F
.53446 .64796 m .53478 .65013 L .53829 .64654 L 0 1 .32 r
F
.53352 .64672 m .54165 .65242 L .5443 .639 L 0 .578 .261 r
F
.53995 .64617 m .54795 .62058 L .54998 .62682 L 0 .121 .123 r
F
.53995 .64617 m .5442 .62752 L .54795 .62058 L F
.54487 .63158 m .54948 .49362 L .54703 .51542 L 0 .881 .237 r
F
.54948 .49362 m .54798 .50214 L .54703 .51542 L F
.54487 .63158 m .55192 .48209 L .54948 .49362 L F
.55192 .48209 m .55206 .479 L .55035 .4887 L F
.54922 .49512 m .55067 .4869 L .54948 .49362 L 0 1 .145 r
F
.55192 .48209 m .55035 .4887 L .54948 .49362 L 0 .881 .237 r
F
.54727 .50611 m .54789 .50261 L .55053 .49396 L 0 0 .046 r
F
.54454 .51629 m .54789 .50261 L .54727 .50611 L F
.54948 .49362 m .55227 .47783 L .54966 .49259 L 0 1 .145 r
F
.55067 .4869 m .55227 .47783 L .54948 .49362 L F
.55157 .48182 m .55227 .47783 L .54922 .49512 L F
.55206 .479 m .55255 .47666 L .55256 .47656 L F
.55253 .47668 m .55256 .47656 L .55256 .4762 L 0 .881 .237 r
F
.54487 .63158 m .55256 .4762 L .55206 .479 L F
.55206 .479 m .55256 .47656 L .55261 .4759 L 0 1 .145 r
F
.55346 .56782 m .55965 .54036 L .55582 .56162 L 0 0 .088 r
F
.55097 .53369 m .55582 .56162 L .55965 .54035 L 0 .607 .245 r
F
.55097 .53369 m .55209 .55874 L .55582 .56162 L F
.54844 .55969 m .5583 .50014 L .55689 .49723 L 0 1 .252 r
F
.54844 .55969 m .5567 .52095 L .5583 .50014 L F
.54844 .55969 m .55689 .49723 L .55337 .51367 L F
.54844 .55969 m .55313 .54593 L .5567 .52095 L F
.54844 .55969 m .55337 .51367 L .55007 .53866 L F
.54844 .55969 m .54959 .5626 L .55313 .54593 L F
.54487 .63158 m .55254 .52191 L .55256 .47656 L 0 .881 .237 r
F
.54487 .63158 m .55256 .47656 L .55253 .47668 L F
.55206 .479 m .55256 .4762 L .55256 .46847 L F
.53967 .61485 m .54703 .51542 L .54698 .50776 L 0 .92 .24 r
F
.53967 .61485 m .54698 .50776 L .54684 .5086 L F
.54675 .50904 m .55053 .49396 L .55291 .48884 L 0 0 .046 r
F
.54684 .5086 m .54698 .50776 L .54698 .50652 L 0 .92 .24 r
F
.54454 .51629 m .54727 .50611 L .54675 .50904 L 0 0 .046 r
F
.54727 .50611 m .55053 .49396 L .54675 .50904 L F
.55163 .48145 m .55261 .4759 L .55227 .47783 L 0 1 .145 r
F
.55206 .479 m .55261 .4759 L .55163 .48145 L F
.54966 .49259 m .55227 .47783 L .5504 .48839 L F
.54297 .52213 m .54677 .47584 L .54437 .48304 L 0 .92 .24 r
F
.54293 .52331 m .54305 .52184 L .54297 .52213 L F
.54305 .52184 m .54677 .47584 L .54297 .52213 L F
.55206 .479 m .55256 .46847 L .54957 .49102 L 0 .881 .237 r
F
.55227 .47877 m .55295 .47528 L .55183 .48149 L 0 0 .018 r
F
.5563 .45571 m .55591 .47748 L .55638 .45527 L 0 .993 .218 r
F
.55605 .45545 m .55619 .45504 L .55586 .45665 L 0 .744 .064 r
F
.55576 .45631 m .55637 .45292 L .55614 .45518 L F
.55576 .45631 m .55605 .45545 L .55586 .45665 L F
.55576 .45631 m .55605 .45423 L .55595 .45524 L F
.55576 .45631 m .55638 .45168 L .55619 .45296 L F
.55576 .45631 m .55619 .45296 L .55605 .45423 L F
.5559 .45679 m .55794 .31364 L .55586 .40069 L 0 .993 .218 r
F
.55591 .47748 m .55619 .45504 L .5559 .45679 L F
.55619 .45504 m .55599 .45623 L .55586 .45665 L 0 .744 .064 r
F
.55633 .45408 m .5563 .45571 L .55641 .45351 L 0 .993 .218 r
F
.55665 .45002 m .55591 .47748 L .55688 .44751 L F
.55688 .44752 m .55688 .44751 L .55688 .4475 L F
.55691 .44741 m .55684 .44809 L .55605 .45423 L 0 .744 .064 r
F
.55665 .45002 m .55688 .44751 L .55688 .44752 L 0 .993 .218 r
F
.55643 .45261 m .55641 .45351 L .55664 .45039 L F
.55638 .45527 m .55591 .47748 L .55653 .45431 L F
.55314 .47511 m .55628 .45811 L .55898 .44684 L 0 0 .018 r
F
.55237 .47885 m .55357 .47253 L .55314 .47511 L F
.55357 .47253 m .55628 .45811 L .55314 .47511 L F
.55641 .45351 m .55638 .45527 L .55659 .45223 L 0 .993 .218 r
F
.55638 .45527 m .55653 .45431 L .55659 .45223 L F
.55641 .45351 m .55659 .45223 L .55664 .45039 L F
.55619 .45504 m .55621 .45497 L .55604 .45609 L 0 .744 .064 r
F
.5563 .45571 m .55638 .45527 L .55641 .45351 L 0 .993 .218 r
F
.55621 .45497 m .55898 .44684 L .55608 .45596 L 0 .744 .064 r
F
.55621 .45497 m .55608 .45596 L .55604 .45609 L F
.55119 .56864 m .56156 .51784 L .5603 .50897 L 0 1 .264 r
F
.55119 .56864 m .55965 .54036 L .56156 .51784 L F
.56243 .40724 m .56237 .40772 L .56145 .53244 L 0 .927 .221 r
F
.56243 .40724 m .56145 .53244 L .5633 .40121 L F
.55689 .49723 m .5583 .50014 L .5619 .47071 L 0 1 .217 r
F
.56145 .53244 m .56235 .41019 L .56134 .42486 L 0 .927 .221 r
F
.55621 .45497 m .56266 .41839 L .55898 .44684 L 0 .744 .064 r
F
.55634 .45353 m .55619 .45504 L .55633 .45408 L 0 .993 .218 r
F
.55595 .45524 m .55657 .45088 L .55637 .45292 L 0 .744 .064 r
F
.55957 .43349 m .56039 .42836 L .5607 .41987 L 0 .993 .218 r
F
.56057 .42379 m .5622 .40919 L .56133 .41527 L 0 1 .124 r
F
.5622 .40919 m .56237 .40772 L .56133 .41527 L F
.56134 .42486 m .56237 .40759 L .56133 .41525 L 0 .927 .221 r
F
.56235 .41019 m .56237 .40759 L .56134 .42486 L F
.56331 .40093 m .56145 .53244 L .56422 .39459 L F
.55605 .45423 m .56485 .39196 L .55595 .45524 L 0 .744 .064 r
F
.55639 .45086 m .55619 .45504 L .55634 .45353 L 0 .993 .218 r
F
.55619 .45504 m .55625 .45456 L .55621 .45497 L 0 .744 .064 r
F
.55614 .45518 m .55622 .45474 L .55619 .45504 L F
.55622 .45474 m .55625 .45456 L .55619 .45504 L F
.55625 .45456 m .56266 .41839 L .55621 .45497 L F
.55643 .45261 m .55664 .45039 L .55665 .45002 L 0 .993 .218 r
F
.55657 .45088 m .55702 .44767 L .55637 .45292 L 0 .744 .064 r
F
.55644 .45202 m .55643 .45261 L .55665 .45002 L 0 .993 .218 r
F
.55105 .48572 m .55898 .44684 L .55912 .45229 L 0 0 .018 r
F
.5504 .48839 m .55131 .48398 L .55105 .48572 L F
.55131 .48398 m .55898 .44684 L .55105 .48572 L F
.55633 .45408 m .55641 .45351 L .55643 .45261 L 0 .993 .218 r
F
.55637 .45292 m .56266 .41839 L .55614 .45518 L 0 .744 .064 r
F
.55605 .45423 m .55695 .44731 L .55665 .45002 L F
.55586 .45665 m .55604 .45609 L .55592 .45687 L F
.55619 .45504 m .55794 .31364 L .5559 .45679 L 0 .993 .218 r
F
.55619 .45504 m .55604 .45609 L .55599 .45623 L 0 .744 .064 r
F
.55295 .47528 m .55628 .45811 L .5524 .47847 L 0 0 .018 r
F
.55295 .47528 m .5524 .47847 L .55183 .48149 L F
.55907 .43171 m .56142 .41435 L .55773 .44139 L 0 .744 .064 r
F
.55942 .42919 m .56002 .42482 L .56142 .41435 L F
.56002 .42482 m .5607 .41987 L .56142 .41435 L F
.56133 .41527 m .56161 .41295 L .56142 .41435 L 0 1 .124 r
F
.56161 .41295 m .56146 .41402 L .56142 .41435 L F
.55707 .44618 m .56142 .41435 L .56194 .40864 L 0 .744 .064 r
F
.55725 .44489 m .56142 .41435 L .55707 .44618 L F
.56151 .41338 m .56142 .41435 L .56168 .4122 L F
.55665 .45002 m .56193 .40876 L .56141 .41631 L F
.55695 .44731 m .56193 .40876 L .55665 .45002 L F
.55688 .4475 m .55686 .44804 L .55707 .44618 L 0 .993 .218 r
F
.55217 .47982 m .55245 .47838 L .55237 .47885 L 0 0 .018 r
F
.55245 .47838 m .55628 .45811 L .55237 .47885 L F
.55183 .48149 m .5524 .47847 L .55217 .47982 L F
.5524 .47847 m .55628 .45811 L .55217 .47982 L F
.55592 .45687 m .55898 .44684 L .55628 .45811 L 0 .744 .064 r
F
.55604 .45609 m .55898 .44684 L .55592 .45687 L F
.55639 .45086 m .55623 .45195 L .55619 .45504 L 0 .993 .218 r
F
.55964 .2684 m .55623 .45195 L .55639 .45086 L F
.55974 .42557 m .55967 .42619 L .55689 .44777 L 0 .744 .064 r
F
.55974 .42557 m .55689 .44777 L .55691 .44753 L F
.55707 .44618 m .55974 .42557 L .55691 .44753 L F
.55707 .44618 m .56132 .40292 L .56332 .27741 L 0 .993 .218 r
F
.55643 .45261 m .55702 .44767 L .55666 .45133 L 0 .744 .064 r
F
.55637 .45292 m .55648 .45204 L .55643 .45261 L F
.55648 .45204 m .55702 .44767 L .55643 .45261 L F
.55639 .45086 m .55634 .45365 L .55648 .45022 L 0 .993 .218 r
F
.55634 .45365 m .55643 .45261 L .55648 .45022 L F
.55639 .45086 m .55648 .45022 L .56027 .269 L F
.55667 .44895 m .55665 .45002 L .55688 .4475 L F
.5504 .48839 m .55227 .47877 L .55183 .48149 L 0 0 .018 r
F
.56349 .27214 m .56237 .40772 L .56243 .40724 L 0 .927 .221 r
F
.56237 .40772 m .56342 .39284 L .56244 .40701 L 0 1 .124 r
F
.56349 .27214 m .56244 .40669 L .56511 .27309 L 0 .927 .221 r
F
.56244 .40669 m .56245 .40655 L .56511 .27309 L F
.56342 .39284 m .56587 .36632 L .56244 .40701 L 0 1 .124 r
F
.56587 .36632 m .5656 .3707 L .56244 .40701 L F
.56244 .40701 m .5656 .3707 L .56432 .39027 L F
.56237 .40772 m .56432 .39027 L .56161 .41295 L F
.56237 .40772 m .56161 .41295 L .56133 .41527 L F
.56161 .41295 m .56432 .39027 L .56146 .41402 L F
.56587 .36632 m .56784 .34485 L .5656 .3707 L F
.57133 .27581 m .56876 .3194 L .56869 .32075 L 0 .771 .231 r
F
.56876 .3194 m .56864 .32138 L .56867 .32094 L F
.56876 .3194 m .56867 .32094 L .56869 .32075 L F
.56974 .30264 m .57005 .29748 L .5711 .27643 L 0 1 .168 r
F
.57133 .27581 m .5687 .30593 L .56864 .31998 L 0 .771 .231 r
F
.57133 .27581 m .56864 .31998 L .56897 .31581 L F
.57063 .28381 m .56881 .31791 L .56864 .32164 L 0 1 .168 r
F
.56974 .30264 m .56939 .30973 L .57005 .29748 L F
.56939 .30973 m .56957 .30722 L .57005 .29748 L F
.57133 .27581 m .56864 .32164 L .57113 .29539 L 0 .771 .231 r
F
.56784 .3315 m .56881 .31791 L .56964 .30869 L 0 1 .124 r
F
.56469 .37152 m .5673 .34117 L .56593 .3553 L 0 .927 .221 r
F
.56474 .37081 m .56881 .31791 L .56784 .3315 L 0 1 .124 r
F
.5656 .3707 m .56784 .34485 L .56474 .38486 L F
.5656 .3707 m .56474 .38486 L .56432 .39027 L F
.56603 .35365 m .56608 .35297 L .56602 .35371 L F
.57113 .29539 m .56864 .32164 L .56732 .67562 L 0 .771 .231 r
F
.56057 .42379 m .56061 .42322 L .56062 .42318 L 0 1 .124 r
F
.55666 .45133 m .56485 .39196 L .56266 .41839 L 0 .744 .064 r
F
.55702 .44767 m .56485 .39196 L .55666 .45133 L F
.5636 .38976 m .56359 .39045 L .56368 .38902 L 0 .927 .221 r
F
.56344 .39125 m .56342 .39284 L .5636 .38976 L F
.56344 .39125 m .56401 .38602 L .56469 .37152 L F
.56342 .39284 m .56698 .3425 L .56386 .38809 L 0 1 .124 r
F
.56469 .37152 m .56698 .3425 L .56342 .39284 L F
.56386 .38809 m .56964 .30869 L .56784 .34485 L F
.56698 .3425 m .56964 .30869 L .56386 .38809 L F
.56145 .27056 m .55667 .44895 L .56332 .27741 L 0 .993 .218 r
F
.55667 .44895 m .55707 .44618 L .56332 .27741 L F
.55648 .45022 m .55644 .45202 L .55667 .44895 L F
.55644 .45202 m .55665 .45002 L .55667 .44895 L F
.55648 .45022 m .55667 .44895 L .56145 .27056 L F
.55974 .42557 m .56194 .40864 L .55967 .42619 L 0 .744 .064 r
F
.56194 .40864 m .56151 .41338 L .56432 .39027 L F
.56194 .40864 m .56432 .39027 L .56193 .40876 L F
.56194 .40864 m .56193 .40876 L .55967 .42619 L F
.5635 .38713 m .56344 .39125 L .56469 .37152 L 0 .927 .221 r
F
.56151 .41338 m .56168 .4122 L .56432 .39027 L 0 .744 .064 r
F
.56141 .41631 m .56432 .39027 L .56485 .39196 L F
.56193 .40876 m .56432 .39027 L .56141 .41631 L F
.56511 .27309 m .56377 .36841 L .56665 .27427 L 0 .927 .221 r
F
.56377 .36841 m .5635 .38713 L .5641 .36569 L F
.56377 .36841 m .5641 .36569 L .56665 .27427 L F
.56478 .37032 m .56487 .36918 L .56481 .36997 L 0 1 .124 r
F
.5635 .38713 m .56469 .37152 L .56665 .27427 L 0 .927 .221 r
F
.56665 .27427 m .56469 .37152 L .5687 .30593 L F
.56469 .37152 m .5676 .33357 L .5687 .30593 L F
.56469 .37152 m .56481 .36997 L .56474 .37081 L 0 1 .124 r
F
.56325 .44311 m .56145 .53244 L .56656 .3728 L 0 .927 .221 r
F
.56266 .41839 m .56485 .39196 L .56656 .3833 L 0 .167 .147 r
F
.56622 .39142 m .56656 .3833 L .5688 .3719 L F
.56266 .41839 m .56656 .3833 L .56622 .39142 L F
.56576 .4026 m .5688 .3719 L .5719 .37135 L F
.56266 .41839 m .56622 .39142 L .56576 .4026 L F
.56622 .39142 m .5688 .3719 L .56576 .4026 L F
.64968 .28004 m .64617 .29867 L .64925 .27992 L 0 .806 .199 r
F
.64968 .28004 m .64602 .36775 L .64617 .29867 L F
0 g
.64617 .29867 m
.64925 .27992 L
s
.54675 .27975 m .54121 .4135 L .54707 .27988 L 0 .933 .238 r
F
.6222 .27985 m .62572 .35207 L .62128 .2782 L 0 .785 .071 r
F
0 g
.6255 .29828 m
.62673 .32678 L
s
.62538 .29564 m
.6255 .29828 L
s
.62488 .28402 m
.62538 .29564 L
s
.54675 .27975 m .54439 .30886 L .54121 .4135 L 0 .933 .238 r
F
.65871 .32513 m .6632 .30307 L .66788 .3305 L 0 .944 .133 r
F
.65871 .32513 m .65929 .30076 L .6632 .30307 L F
0 g
.6615 .29079 m
.6632 .30307 L
s
.66304 .30297 m
.6632 .30307 L
s
.65929 .30076 m
.66292 .3029 L
s
.66292 .3029 m
.66304 .30297 L
s
.65834 .28717 m
.65929 .30076 L
s
.54434 .27845 m .54439 .30886 L .54471 .27864 L 0 .979 .237 r
F
0 g
.58167 .71119 m
.58178 .72301 L
s
.58153 .69574 m
.58167 .71119 L
s
.58067 .60229 m
.5808 .61652 L
s
.5808 .61652 m
.58099 .63692 L
s
.58049 .58319 m
.58067 .60229 L
s
.58047 .58006 m
.58049 .58319 L
s
.57971 .49817 m
.57996 .52559 L
s
.54283 .27742 m .53749 .40087 L .54434 .27845 L 0 .979 .237 r
F
.54434 .27845 m .53749 .40087 L .54439 .30886 L F
.57249 .27593 m .57526 .37634 L .57521 .27749 L 0 1 .197 r
F
.65271 .44443 m .66124 .44846 L .65729 .43838 L 0 .761 .306 r
F
0 g
.65548 .41676 m
.65729 .43838 L
s
.54271 .27735 m .53749 .40087 L .54283 .27742 L 0 .979 .237 r
F
0 g
.62029 .27738 m
.62092 .30202 L
s
.54271 .27735 m .54006 .31238 L .53749 .40087 L 0 .979 .237 r
F
.65271 .44443 m .66243 .46816 L .66124 .44846 L 0 .761 .306 r
F
.65271 .44443 m .66005 .48436 L .66243 .46816 L F
.65271 .44443 m .65545 .49045 L .66005 .48436 L F
0 g
.65137 .42304 m
.65271 .44443 L
s
.65271 .44443 m
.65729 .43838 L
s
.67245 .34045 m .6804 .37087 L .67584 .35121 L 0 0 .12 r
F
0 g
.67211 .35827 m
.67499 .36141 L
s
.67245 .34045 m .68379 .3877 L .6804 .37087 L 0 0 .12 r
F
.67245 .34045 m .68371 .39034 L .68379 .3877 L F
.67245 .34045 m .68028 .37942 L .68371 .39034 L F
0 g
.67044 .38977 m
.67448 .38928 L
s
.67245 .34045 m .67582 .36231 L .68028 .37942 L 0 0 .12 r
F
0 g
.66895 .31799 m
.67245 .34045 L
s
.67499 .36141 m
.67582 .36231 L
s
.67415 .35405 m
.67501 .3583 L
s
.67501 .3583 m
.67582 .36231 L
s
.67162 .36991 m
.67448 .38928 L
s
.57209 .27589 m .57526 .37634 L .57249 .27593 L 0 .771 .231 r
F
.53963 .27511 m .54017 .28219 L .54059 .27583 L 0 1 .21 r
F
0 g
.54226 .28329 m
.54271 .27735 L
s
.57102 .27926 m
.57133 .27581 L
s
.57098 .27974 m
.57102 .27926 L
s
.54471 .43915 m .55169 .2919 L .54847 .32318 L 0 .871 .24 r
F
.54471 .43915 m .55333 .30901 L .55169 .2919 L F
0 g
.55169 .2919 m
.55176 .28181 L
s
.54448 .30062 m
.54471 .27864 L
s
.56665 .27427 m .5687 .30593 L .56863 .27526 L 0 .927 .221 r
F
.53925 .27483 m .53824 .29008 L .53963 .27511 L 0 1 .21 r
F
.53963 .27511 m .53824 .29008 L .54017 .28219 L F
.53906 .27459 m .53824 .29008 L .53925 .27483 L F
.53892 .27431 m .53824 .29008 L .53906 .27459 L F
.66724 .42784 m .6758 .43618 L .67164 .42451 L 0 .584 .305 r
F
0 g
.66935 .40463 m
.67164 .42451 L
s
.66724 .42784 m .67748 .45543 L .6758 .43618 L 0 .584 .305 r
F
.66724 .42784 m .67556 .4694 L .67748 .45543 L F
.66724 .42784 m .67114 .47272 L .67556 .4694 L F
.66724 .42784 m .66718 .46317 L .67114 .47272 L F
.66724 .42784 m .66551 .44394 L .66718 .46317 L F
0 g
.66541 .40623 m
.66724 .42784 L
s
.66724 .42784 m
.67164 .42451 L
s
.53866 .27391 m .53824 .29008 L .53892 .27431 L 0 1 .21 r
F
.53814 .27344 m .53824 .29008 L .53866 .27391 L F
.5727 .27289 m .56964 .30869 L .57255 .27309 L 0 0 .105 r
F
.53747 .27284 m .53526 .30348 L .53762 .27297 L 0 1 .205 r
F
.57384 .2713 m .56784 .34485 L .5727 .27289 L 0 0 .105 r
F
.5727 .27289 m .56784 .34485 L .56964 .30869 L F
0 g
.57081 .28037 m
.57105 .27582 L
s
.53644 .27191 m .53321 .31347 L .53747 .27284 L 0 1 .205 r
F
.53747 .27284 m .53321 .31347 L .53526 .30348 L F
0 g
.66278 .44683 m
.66551 .44394 L
s
.66124 .44846 m
.66278 .44683 L
s
.56145 .27056 m .56332 .27741 L .56331 .27196 L 0 .993 .218 r
F
0 g
.56331 .27196 m
.56332 .27741 L
s
.56332 .27741 m
.56349 .27214 L
s
.53583 .27105 m .53321 .31347 L .53644 .27191 L 0 1 .205 r
F
.53355 .39854 m .54017 .28219 L .53824 .29008 L 0 1 .238 r
F
.53355 .39854 m .54006 .31238 L .54017 .28219 L F
0 g
.54017 .28219 m
.54059 .27583 L
s
.54012 .29657 m
.54017 .28219 L
s
.60229 .81744 m
.6024 .82262 L
s
.60256 .8305 m
.60278 .84169 L
s
.60202 .80364 m
.60229 .81744 L
s
.60178 .79169 m
.60202 .80364 L
s
.60052 .7295 m
.60178 .79169 L
s
.60042 .72431 m
.60052 .7295 L
s
.60021 .71368 m
.60033 .71979 L
s
.60033 .71979 m
.60033 .71979 L
s
.60033 .71979 m
.60033 .71979 L
s
.60033 .71979 m
.60042 .72431 L
s
.59937 .67232 m
.60021 .71368 L
s
.60309 .85716 m
.60316 .86057 L
s
.59856 .63198 m
.59857 .63256 L
s
.59894 .65062 m
.59909 .65828 L
s
.59917 .66223 m
.59937 .67232 L
s
.64818 .46666 m
.64818 .46665 L
s
.57709 .26842 m .56784 .34485 L .57384 .2713 L 0 0 .105 r
F
0 g
.57063 .28381 m
.57081 .28037 L
s
.57063 .28381 m
.57098 .27974 L
s
.56863 .27526 m
.56864 .28263 L
s
.53526 .26991 m .53321 .31347 L .53583 .27105 L 0 1 .205 r
F
0 g
.62748 .32998 m
.62821 .33394 L
s
.62717 .32832 m
.62748 .32998 L
s
.53428 .26824 m .53321 .31347 L .53526 .26991 L 0 1 .205 r
F
.60252 .26898 m .60608 .37326 L .6002 .26748 L 0 .974 .197 r
F
.58584 .26844 m .58601 .34056 L .58379 .26777 L 0 .824 .212 r
F
.5773 .26825 m .56784 .34485 L .57709 .26842 L 0 0 .105 r
F
.58379 .26777 m .58178 .27241 L .58171 .26829 L 0 .824 .212 r
F
.5789 .26829 m .57559 .3255 L .5773 .26825 L 0 .635 .215 r
F
.5789 .26829 m .58178 .27241 L .57559 .3255 L F
.5773 .26825 m .57559 .3255 L .56784 .34485 L 0 0 .105 r
F
0 g
.56881 .31791 m
.57063 .28381 L
s
.5687 .30593 m
.57063 .28381 L
s
.56964 .30869 m
.57 .30432 L
s
.57 .30432 m
.57255 .27309 L
s
.56869 .30187 m
.5687 .30593 L
s
.56864 .28263 m
.56868 .30033 L
s
.56868 .30033 m
.56869 .30187 L
s
.53428 .26824 m .53412 .27033 L .53321 .31347 L 0 1 .205 r
F
0 g
.67881 .40353 m
.67935 .40413 L
s
.58379 .26777 m .58601 .34056 L .58178 .27241 L 0 .824 .212 r
F
0 g
.57736 .31029 m
.578 .31265 L
s
.61146 .2675 m .61492 .33785 L .61233 .26471 L 0 .196 .185 r
F
.59194 .26747 m .59038 .33957 L .59047 .26749 L 0 .623 .221 r
F
0 g
.60536 .36035 m
.60608 .37326 L
s
.59915 .26737 m .59038 .33957 L .59194 .26747 L 0 .623 .221 r
F
.53298 .26618 m .53412 .27033 L .53382 .26746 L 0 1 .201 r
F
.59999 .2673 m .59038 .33957 L .59915 .26737 L 0 .623 .221 r
F
.59999 .2673 m .60257 .3885 L .59038 .33957 L F
0 g
.601 .28178 m
.60157 .29211 L
s
.6002 .26748 m
.601 .28178 L
s
.53321 .31347 m .53412 .27033 L .53272 .29919 L 0 1 .205 r
F
.53298 .26618 m .52792 .33972 L .53412 .27033 L 0 1 .201 r
F
.52792 .33972 m .53272 .29919 L .53412 .27033 L F
0 g
.53412 .27033 m
.53428 .26824 L
s
.53382 .26746 m
.53412 .27033 L
s
.53274 .26571 m .52792 .33972 L .53298 .26618 L 0 1 .201 r
F
.55715 .26498 m .55769 .27007 L .55788 .26604 L 0 1 .132 r
F
.54471 .43915 m .55235 .36396 L .55333 .30901 L 0 .871 .24 r
F
0 g
.55333 .30901 m
.55466 .28298 L
s
.53254 .2649 m .53074 .27971 L .53274 .26571 L 0 1 .11 r
F
.53274 .26571 m .53074 .27971 L .52792 .33972 L 0 1 .201 r
F
.66243 .46816 m .67114 .47272 L .66718 .46317 L 0 .741 .316 r
F
0 g
.66551 .44394 m
.66718 .46317 L
s
.66243 .46816 m .67217 .49078 L .67114 .47272 L 0 .741 .316 r
F
.66243 .46816 m .66957 .50531 L .67217 .49078 L F
0 g
.66243 .46816 m
.66718 .46317 L
s
.66124 .44846 m
.66243 .46816 L
s
.67173 .34682 m .67213 .34094 L .67584 .35121 L 0 .647 .052 r
F
0 g
.6752 .34944 m
.67549 .35025 L
s
.67213 .34094 m
.6752 .34944 L
s
.66922 .31995 m
.67213 .34094 L
s
.57559 .3255 m .58178 .27241 L .58601 .34056 L 0 .635 .215 r
F
0 g
.57768 .32852 m
.57833 .34878 L
s
.57761 .32842 m
.5784 .35592 L
s
.5789 .26829 m
.58178 .27241 L
s
.58171 .26829 m
.58178 .27241 L
s
.6758 .43618 m
.6766 .43609 L
s
.53355 .39854 m .53824 .29008 L .53547 .3265 L 0 1 .238 r
F
0 g
.53806 .29244 m
.53824 .29008 L
s
.53548 .30061 m
.53762 .27297 L
s
.53814 .27344 m
.53824 .29008 L
s
.55682 .26448 m .55531 .29717 L .55715 .26498 L 0 1 .132 r
F
.55715 .26498 m .55531 .29717 L .55769 .27007 L F
.5324 .26433 m .53074 .27971 L .53254 .2649 L 0 1 .11 r
F
.61233 .26471 m .61492 .33785 L .61266 .26396 L 0 .196 .185 r
F
.55668 .264 m .55531 .29717 L .55682 .26448 L 0 1 .132 r
F
0 g
.68028 .37942 m
.68063 .38053 L
s
.53228 .26355 m .53074 .27971 L .5324 .26433 L 0 1 .11 r
F
.55664 .26325 m .55531 .29717 L .55668 .264 L 0 1 .132 r
F
.67173 .34682 m .67584 .35121 L .6804 .37087 L 0 .647 .052 r
F
0 g
.67245 .34045 m
.67584 .35121 L
s
.67549 .35025 m
.67584 .35121 L
s
.5321 .26187 m .53074 .27971 L .53228 .26355 L 0 1 .11 r
F
0 g
.6173 .47249 m
.61732 .47306 L
s
.6173 .47244 m
.6173 .47249 L
s
.61728 .47199 m
.6173 .47244 L
s
.54797 .47945 m .55577 .3465 L .55235 .36396 L 0 .771 .244 r
F
.55028 .4696 m .55769 .27007 L .55531 .29717 L 0 1 .217 r
F
.55028 .4696 m .55794 .31364 L .55769 .27007 L F
0 g
.55769 .27007 m
.55788 .26604 L
s
.5564 .26148 m .55531 .29717 L .55664 .26325 L 0 1 .132 r
F
0 g
.62737 .33836 m
.6281 .3494 L
s
.62854 .32316 m .64128 .44037 L .63649 .3996 L 0 0 .118 r
F
.62854 .32316 m .64239 .44115 L .64128 .44037 L F
.62854 .32316 m .63649 .3996 L .63131 .3469 L F
.62854 .32316 m .62995 .34341 L .63463 .38332 L F
0 g
.62874 .34595 m
.62926 .35174 L
s
.62717 .32832 m
.62874 .34595 L
s
.62937 .34025 m
.62995 .34339 L
s
.62821 .33394 m
.62937 .34025 L
s
.62938 .36089 m
.62965 .36394 L
s
.62926 .35951 m
.62938 .36089 L
s
.62906 .35727 m
.62926 .35951 L
s
.53176 .25915 m .53074 .27971 L .5321 .26187 L 0 1 .11 r
F
0 g
.66005 .48436 m
.66014 .48605 L
s
.65784 .48728 m
.66005 .48436 L
s
.65545 .49045 m
.65784 .48728 L
s
.55612 .26065 m .55531 .29717 L .5564 .26148 L 0 1 .132 r
F
0 g
.65545 .49045 m
.65599 .50828 L
s
.54121 .4135 m .54439 .30886 L .54198 .36464 L 0 .933 .238 r
F
.53749 .40087 m .54198 .36464 L .54439 .30886 L 0 .979 .237 r
F
0 g
.54439 .30886 m
.54448 .30062 L
s
.54439 .30886 m
.54675 .27975 L
s
.53658 .31192 m
.53806 .29244 L
s
.68112 .42347 m .68961 .43614 L .68529 .42362 L 0 .348 .296 r
F
.68112 .42347 m .6918 .45333 L .68961 .43614 L F
.68112 .42347 m .69038 .46369 L .6918 .45333 L F
.68112 .42347 m .68619 .46348 L .69038 .46369 L F
.68112 .42347 m .68203 .45288 L .68619 .46348 L F
.68112 .42347 m .67987 .43574 L .68203 .45288 L F
0 g
.67881 .40353 m
.68112 .42347 L
s
.6766 .43609 m
.67987 .43574 L
s
.55612 .26065 m .55503 .28438 L .55531 .29717 L 0 1 .132 r
F
.55571 .25991 m .55503 .28438 L .55612 .26065 L 0 1 .127 r
F
.55372 .27975 m .55353 .28281 L .55533 .26546 L F
.55353 .28281 m .5489 .3594 L .55503 .26983 L F
.55353 .28281 m .55503 .26983 L .55533 .26546 L F
.55481 .25601 m .55301 .2875 L .55505 .25766 L F
.55301 .2875 m .5489 .3594 L .55353 .28281 L F
.55301 .2875 m .55353 .28281 L .55505 .25766 L F
.55481 .25601 m .55351 .27285 L .55247 .29234 L F
.55301 .2875 m .55247 .29234 L .5489 .3594 L F
.55481 .25601 m .55247 .29234 L .55301 .2875 L F
.54471 .43915 m .54847 .32318 L .54577 .38289 L 0 .871 .24 r
F
.54121 .4135 m .54577 .38289 L .54847 .32318 L 0 .933 .238 r
F
.54121 .4135 m .54264 .42202 L .54577 .38289 L F
.54189 .41286 m .55001 .32389 L .54894 .32199 L 0 1 .132 r
F
.54486 .36426 m .54894 .32199 L .54573 .35001 L F
.54189 .41286 m .54622 .35711 L .54486 .36426 L F
.54622 .35711 m .54894 .32199 L .54486 .36426 L F
.53749 .40087 m .53901 .40444 L .54198 .36464 L 0 .979 .237 r
F
.54189 .41286 m .54506 .36109 L .54223 .38823 L 0 1 .132 r
F
.54506 .36109 m .54573 .35001 L .54432 .36544 L F
.54506 .36109 m .54432 .36544 L .54223 .38823 L F
.54573 .35001 m .5459 .35124 L .54491 .35797 L 0 0 .003 r
F
.54016 .39009 m .54442 .36265 L .54564 .35324 L 0 .729 .056 r
F
.54016 .39009 m .54564 .35324 L .54537 .35482 L F
.54102 .385 m .54442 .36265 L .54016 .39009 L F
.54 .38997 m .5459 .35124 L .54494 .35608 L F
.54354 .3644 m .54494 .35608 L .54413 .36015 L F
.54 .38997 m .54494 .35608 L .54354 .3644 L F
.54082 .38562 m .5459 .35124 L .54 .38997 L F
.5489 .3594 m .55259 .29027 L .55001 .32389 L 0 1 .127 r
F
.55259 .29027 m .55351 .27285 L .55188 .29663 L F
.55259 .29027 m .55188 .29663 L .55001 .32389 L F
.55571 .25991 m .5489 .3594 L .55503 .28438 L F
.5478 .33351 m .55458 .27733 L .55331 .28958 L 0 0 .003 r
F
.54642 .34457 m .54825 .32948 L .5478 .33351 L F
.54825 .32948 m .55458 .27733 L .5478 .33351 L F
.5489 .3594 m .55001 .32389 L .54824 .35442 L 0 1 .127 r
F
.54189 .41286 m .54824 .35442 L .55001 .32389 L 0 1 .132 r
F
.53168 .50229 m .53901 .40444 L .53749 .40087 L 0 .885 .251 r
F
.53728 .40958 m .54073 .38759 L .54442 .36265 L 0 .729 .056 r
F
.53728 .40958 m .54413 .36015 L .54026 .3836 L F
.54044 .38285 m .54969 .33841 L .54763 .35309 L 0 0 .057 r
F
.54026 .3836 m .54054 .38225 L .54044 .38285 L F
.54054 .38225 m .54969 .33841 L .54044 .38285 L F
.54064 .38256 m .54763 .35309 L .54332 .37528 L F
.54026 .3836 m .54096 .38071 L .54064 .38256 L F
.54096 .38071 m .54763 .35309 L .54064 .38256 L F
.54537 .35482 m .54564 .35324 L .5459 .35124 L 0 .729 .056 r
F
.53728 .40958 m .54102 .385 L .54016 .39009 L F
.53728 .40958 m .54082 .38562 L .54 .38997 L F
.54642 .34457 m .54867 .32661 L .54616 .34676 L 0 0 .003 r
F
.54867 .32661 m .55331 .28958 L .54855 .32764 L F
.54867 .32661 m .54855 .32764 L .54616 .34676 L F
.54783 .33415 m .55331 .28958 L .54972 .3198 L F
.54616 .34676 m .54855 .32764 L .54783 .33415 L F
.54855 .32764 m .55331 .28958 L .54783 .33415 L F
.54573 .35001 m .54642 .34457 L .54616 .34676 L F
.54573 .35001 m .54666 .34238 L .54642 .34457 L F
.54666 .34238 m .55458 .27733 L .54642 .34457 L F
.55505 .25766 m .55372 .27975 L .55571 .25991 L 0 1 .127 r
F
.55372 .27975 m .55533 .26546 L .55571 .25991 L F
0 g
.54847 .32318 m
.55169 .2919 L
s
.54867 .30928 m
.54909 .28078 L
s
.5486 .31392 m
.54867 .30928 L
s
.54847 .3231 m
.5486 .31392 L
s
.65871 .32513 m .66788 .3305 L .67092 .36772 L 0 .944 .133 r
F
0 g
.66788 .3305 m
.66798 .33171 L
s
.67114 .47272 m
.67231 .47184 L
s
.68317 .39891 m .68254 .40768 L .68529 .42362 L 0 .174 .233 r
F
0 g
.67935 .40413 m
.68254 .40768 L
s
.53176 .25915 m .53062 .26972 L .53074 .27971 L 0 1 .11 r
F
.67748 .45543 m .68619 .46348 L .68203 .45288 L 0 .564 .316 r
F
0 g
.67987 .43574 m
.68203 .45288 L
s
.67748 .45543 m .68773 .48066 L .68619 .46348 L 0 .564 .316 r
F
.67748 .45543 m .68562 .49296 L .68773 .48066 L F
.67748 .45543 m .68106 .49548 L .68562 .49296 L F
.67748 .45543 m .67709 .48656 L .68106 .49548 L F
.67748 .45543 m .67556 .4694 L .67709 .48656 L F
0 g
.6758 .43618 m
.67748 .45543 L
s
.67748 .45543 m
.68203 .45288 L
s
.67231 .47184 m
.67556 .4694 L
s
.68317 .39891 m .69141 .41758 L .68697 .40312 L 0 .174 .233 r
F
.68317 .39891 m .69419 .43361 L .69141 .41758 L F
.68317 .39891 m .69343 .44045 L .69419 .43361 L F
.68317 .39891 m .68961 .43614 L .69343 .44045 L F
.68317 .39891 m .68529 .42362 L .68961 .43614 L F
0 g
.68438 .41834 m
.68529 .42362 L
s
.68112 .42347 m
.68529 .42362 L
s
.68028 .37942 m
.68317 .39891 L
s
.68254 .40768 m
.68438 .41834 L
s
.61801 .38546 m .62099 .40341 L .6207 .41375 L 0 .765 .068 r
F
.60964 .2568 m .61698 .37236 L .61063 .27191 L 0 0 .114 r
F
.60959 .25556 m .6104 .26839 L .6101 .25791 L F
.6104 .26839 m .61698 .37236 L .61286 .30381 L F
.6104 .26839 m .61286 .30381 L .6101 .25791 L F
.61698 .37236 m .62099 .40341 L .61674 .354 L 0 0 .128 r
F
.61732 .36819 m .61674 .354 L .62099 .40341 L 0 .765 .068 r
F
.60629 .26213 m .61572 .34508 L .61732 .36819 L F
.61572 .34508 m .61674 .354 L .61732 .36819 L F
.60629 .26213 m .61617 .35707 L .61801 .38546 L F
.61617 .35707 m .62099 .40341 L .61801 .38546 L F
.60964 .25669 m .61063 .27191 L .60959 .25556 L 0 0 .114 r
F
.60964 .2568 m .61063 .27191 L .60964 .25669 L F
0 g
.65599 .50828 m
.65822 .50571 L
s
.61455 .25615 m .61524 .27524 L .61398 .25319 L 0 .633 .026 r
F
.55499 .25551 m .55351 .27285 L .55481 .25601 L 0 0 .053 r
F
.64602 .36775 m .65463 .31459 L .65786 .38263 L 0 .806 .199 r
F
.53295 .25331 m .53217 .25649 L .53226 .25561 L 0 0 .02 r
F
.60959 .25556 m .6101 .25791 L .60972 .25233 L 0 0 .114 r
F
0 g
.54847 .32318 m
.54847 .3231 L
s
.55516 .25504 m .55351 .27285 L .55499 .25551 L 0 0 .053 r
F
.53074 .27971 m .53062 .26972 L .52959 .28305 L 0 1 .11 r
F
.52792 .33972 m .53074 .27971 L .52807 .3094 L 0 1 .201 r
F
.53749 .40087 m .54006 .31238 L .53795 .36114 L 0 .979 .237 r
F
.53355 .39854 m .53795 .36114 L .54006 .31238 L 0 1 .238 r
F
0 g
.54006 .31238 m
.54226 .28329 L
s
.54006 .31238 m
.54012 .29657 L
s
.55545 .25421 m .55351 .27285 L .55516 .25504 L 0 0 .053 r
F
0 g
.62995 .34341 m
.6301 .34466 L
s
.53315 .25258 m .53217 .25649 L .53295 .25331 L 0 0 .002 r
F
.5242 .3206 m .53062 .26972 L .52909 .27415 L 0 1 .114 r
F
.5242 .3206 m .52909 .27415 L .52602 .29348 L F
.53315 .25258 m .52602 .29348 L .53217 .25649 L 0 0 .002 r
F
.52602 .29348 m .52909 .27415 L .53217 .25649 L F
0 g
.53041 .28331 m
.53074 .27971 L
s
.53217 .25649 m
.53226 .25561 L
s
.67217 .49078 m .68106 .49548 L .67709 .48656 L 0 .729 .326 r
F
0 g
.67556 .4694 m
.67709 .48656 L
s
.67217 .49078 m .68192 .51203 L .68106 .49548 L 0 .729 .326 r
F
.67217 .49078 m .67911 .52517 L .68192 .51203 L F
0 g
.67217 .49078 m
.67709 .48656 L
s
.67114 .47272 m
.67217 .49078 L
s
.5294 .40368 m .53526 .30348 L .53321 .31347 L 0 1 .24 r
F
.5294 .40368 m .53547 .3265 L .53526 .30348 L F
0 g
.53526 .30348 m
.53548 .30061 L
s
.55633 .25165 m .55351 .27285 L .55545 .25421 L 0 0 .053 r
F
.67173 .34682 m .67941 .38719 L .67483 .3666 L 0 .647 .052 r
F
.67173 .34682 m .68316 .3976 L .67941 .38719 L F
.67173 .34682 m .68355 .39079 L .68316 .3976 L F
.67173 .34682 m .6804 .37087 L .68355 .39079 L F
0 g
.66788 .3305 m
.67173 .34682 L
s
.61398 .25319 m .61524 .27524 L .61385 .25256 L 0 .633 .026 r
F
0 g
.61415 .26165 m
.61436 .28194 L
s
.66481 .51031 m
.66484 .51175 L
s
.66652 .5085 m
.66957 .50531 L
s
.66481 .51031 m
.66652 .5085 L
s
.5242 .3206 m .52959 .28305 L .53062 .26972 L 0 1 .114 r
F
0 g
.53062 .26972 m
.53137 .26281 L
s
.65871 .32513 m .66627 .38761 L .66168 .36238 L 0 .944 .133 r
F
.65871 .32513 m .67025 .3899 L .66627 .38761 L F
.65871 .32513 m .67092 .36772 L .67025 .3899 L F
0 g
.65463 .31459 m
.65871 .32513 L
s
.53318 .25247 m .52602 .29348 L .53315 .25258 L 0 0 .002 r
F
.53318 .25247 m .5314 .26424 L .52602 .29348 L F
0 g
.52992 .26942 m
.53217 .25649 L
s
.53012 .27116 m
.53062 .26972 L
s
.53003 .2876 m
.53041 .28331 L
s
.52996 .28198 m
.53074 .27971 L
s
.62572 .35211 m .62674 .32681 L .63131 .3469 L 0 1 .146 r
F
0 g
.62974 .33999 m
.63014 .34177 L
s
.62674 .32681 m
.62891 .33634 L
s
.62891 .33634 m
.62974 .33999 L
s
.62838 .34964 m
.62906 .35727 L
s
.60972 .25233 m .6101 .25791 L .60976 .25204 L 0 0 .114 r
F
0 g
.66957 .50531 m
.67018 .51713 L
s
.60976 .25204 m .6101 .25791 L .60958 .25186 L 0 1 .123 r
F
.52792 .33972 m .53006 .329 L .53272 .29919 L 0 1 .201 r
F
.60958 .25186 m .61045 .29369 L .6072 .24897 L 0 1 .123 r
F
.60958 .25186 m .6101 .25791 L .61045 .29369 L F
.55718 .24915 m .55351 .27285 L .55633 .25165 L 0 0 .053 r
F
.68379 .3877 m .68371 .39034 L .68697 .40312 L 0 0 .105 r
F
0 g
.68603 .39945 m
.68648 .40121 L
s
.68371 .39034 m
.68603 .39945 L
s
.68325 .38889 m
.68371 .39034 L
s
.6804 .37087 m
.68059 .37204 L
s
.68619 .46348 m
.68685 .46351 L
s
.569 .31584 m
.56964 .30869 L
s
.56881 .31791 m
.569 .31584 L
s
.55718 .24915 m .55458 .27733 L .55351 .27285 L 0 0 .053 r
F
.4618 .88708 m .46953 .89135 L .47013 .88852 L 0 1 .522 r
F
.4618 .88708 m .45998 .89411 L .46953 .89135 L F
0 g
.46953 .89135 m
.4783 .89205 L
s
.6072 .24897 m .60629 .26213 L .60531 .24621 L 0 1 .123 r
F
.6072 .24897 m .61045 .29369 L .60629 .26213 L F
.61348 .24893 m .61506 .26073 L .61296 .24838 L 0 1 .112 r
F
.4618 .88708 m .44784 .89497 L .45998 .89411 L 0 1 .522 r
F
0 g
.45998 .89411 m
.46953 .89135 L
s
.5242 .3206 m .52685 .30483 L .52959 .28305 L 0 1 .114 r
F
0 g
.52959 .28305 m
.52996 .28198 L
s
.66551 .52667 m
.66938 .52288 L
s
.68379 .3877 m .68697 .40312 L .69141 .41758 L 0 0 .105 r
F
0 g
.68317 .39891 m
.68697 .40312 L
s
.68648 .40121 m
.68697 .40312 L
s
.68106 .49548 m
.682 .49495 L
s
.5361 .24691 m .53483 .25117 L .53504 .2485 L 0 0 .09 r
F
.61524 .27524 m .61921 .30771 L .61506 .26073 L 0 0 .125 r
F
.61524 .27524 m .61787 .3027 L .61921 .30771 L F
.62572 .35211 m .63414 .48081 L .62885 .41769 L 0 1 .146 r
F
.63203 .39062 m .64041 .45767 L .6353 .41533 L 0 0 .083 r
F
.63018 .40433 m .63095 .39268 L .6353 .41533 L 0 .974 .102 r
F
.63018 .40433 m .6353 .41533 L .64041 .45767 L F
.63018 .40433 m .63861 .49928 L .63342 .44973 L F
.62572 .35211 m .63887 .50195 L .63414 .48081 L 0 1 .146 r
F
.6255 .37531 m .6289 .39002 L .62516 .36334 L 0 .186 .2 r
F
.62579 .38531 m .62807 .38876 L .6255 .37531 L F
.62807 .38876 m .6289 .39002 L .6255 .37531 L F
.61849 .30914 m .62579 .38529 L .62151 .33487 L 0 0 .125 r
F
.62572 .35211 m .63978 .46623 L .63887 .50195 L 0 1 .146 r
F
.62572 .35211 m .63649 .3996 L .63978 .46623 L F
.62579 .38531 m .63522 .44258 L .63086 .40632 L 0 .186 .2 r
F
.62653 .38643 m .63086 .40632 L .6289 .39002 L F
.62579 .38531 m .63086 .40632 L .62653 .38643 L F
.62819 .39308 m .63438 .42249 L .63667 .43301 L 0 0 .048 r
F
.62405 .36719 m .62517 .38033 L .62541 .38133 L 0 0 .125 r
F
.6232 .36187 m .62467 .37825 L .62405 .36719 L F
.62467 .37825 m .6304 .44183 L .62517 .38033 L F
.62467 .37825 m .62517 .38033 L .62405 .36719 L F
.62588 .37199 m .62828 .39281 L .62818 .39328 L 0 .621 .044 r
F
.61849 .30914 m .6232 .36187 L .62405 .36719 L 0 0 .125 r
F
.61787 .3027 m .6183 .30753 L .61849 .30914 L F
.6183 .30753 m .6232 .36187 L .61849 .30914 L F
.62501 .36683 m .6243 .35861 L .62588 .37199 L 0 .621 .044 r
F
.61765 .30174 m .62302 .36076 L .61827 .30726 L 0 0 .125 r
F
.62302 .36076 m .6232 .36187 L .61787 .3027 L F
.62207 .35029 m .6306 .45697 L .6304 .44183 L F
.61524 .27524 m .62108 .34434 L .62207 .35029 L F
.62108 .34434 m .6306 .45697 L .62207 .35029 L F
.62302 .36076 m .6304 .44183 L .6232 .36187 L F
.62429 .37516 m .63385 .42113 L .63195 .41531 L 0 0 .048 r
F
.63462 .42752 m .63804 .43945 L .63442 .4227 L 0 .243 .228 r
F
.63496 .4362 m .63801 .43949 L .63462 .42752 L F
.63669 .44094 m .63801 .43949 L .63496 .4362 L F
.63801 .43949 m .63804 .43945 L .63462 .42752 L F
.63385 .42113 m .63468 .42611 L .63195 .41531 L 0 0 .048 r
F
.63385 .42113 m .63698 .4363 L .63499 .42802 L F
.63503 .42685 m .63588 .43003 L .63634 .43267 L F
.63565 .42988 m .63634 .43267 L .63698 .4363 L F
.63503 .42685 m .63634 .43267 L .63565 .42988 L F
.63438 .42249 m .63442 .4227 L .63667 .43301 L F
.62865 .39595 m .63514 .42579 L .63529 .42664 L F
.63489 .42538 m .63529 .42664 L .63588 .43003 L F
.62865 .39595 m .63529 .42664 L .63489 .42538 L F
.62865 .39595 m .63588 .43003 L .63503 .42685 L F
.63664 .43286 m .63442 .4227 L .63651 .43238 L F
.63667 .43301 m .63664 .43286 L .63804 .43945 L F
.63664 .43286 m .63651 .43238 L .63804 .43945 L F
.63514 .42579 m .63804 .43945 L .63736 .43744 L F
.63514 .42579 m .63736 .43744 L .63698 .4363 L F
.64309 .45642 m .64439 .46204 L .64562 .46576 L 0 0 .109 r
F
.63321 .41997 m .64365 .45926 L .64309 .45642 L F
.64365 .45926 m .64439 .46204 L .64309 .45642 L F
.64165 .44901 m .64254 .45167 L .64284 .45211 L 0 0 .143 r
F
.64254 .45167 m .64856 .46957 L .64346 .454 L F
.64254 .45167 m .64346 .454 L .64284 .45211 L F
.64856 .46957 m .64995 .46928 L .64675 .46203 L 0 .058 .175 r
F
.6481 .46578 m .64675 .46203 L .64995 .46928 L 0 .379 0 r
F
.6422 .45199 m .64856 .46957 L .64254 .45167 L 0 0 .143 r
F
.64173 .4496 m .64254 .45167 L .64155 .44873 L F
.6422 .45199 m .64254 .45167 L .64173 .4496 L F
.63348 .42107 m .64439 .46204 L .63321 .41997 L 0 0 .109 r
F
.63887 .50195 m .63978 .46623 L .64404 .46201 L 0 .838 .18 r
F
.64237 .45446 m .64341 .46045 L .64695 .47165 L 0 0 .109 r
F
.63195 .41531 m .6409 .45057 L .64237 .45446 L F
.6409 .45057 m .64341 .46045 L .64237 .45446 L F
.63304 .41944 m .64224 .45331 L .64029 .44671 L F
.64224 .45331 m .64562 .46576 L .64029 .44671 L F
.63321 .41997 m .64562 .46576 L .63304 .41944 L F
.64029 .44671 m .64912 .47226 L .64856 .46957 L 0 0 .143 r
F
.64912 .47226 m .65417 .48687 L .65127 .47791 L F
.64912 .47226 m .65127 .47791 L .64856 .46957 L F
.63522 .44258 m .64434 .47734 L .63804 .43945 L 0 .243 .228 r
F
.63195 .41531 m .63698 .4363 L .64232 .45635 L 0 0 .109 r
F
.63195 .41531 m .64232 .45635 L .64248 .45681 L F
.63522 .44258 m .63669 .44094 L .63496 .4362 L 0 .243 .228 r
F
.62579 .38531 m .63992 .48617 L .63522 .44258 L 0 .186 .2 r
F
.64029 .44671 m .65575 .49392 L .65417 .48687 L 0 0 .143 r
F
.64029 .44671 m .65225 .48601 L .65575 .49392 L F
.64029 .44671 m .64562 .46576 L .65225 .48601 L F
.63381 .4386 m .63983 .44889 L .64627 .46112 L 0 .379 0 r
F
.64633 .46127 m .64627 .46112 L .64675 .46203 L F
.63381 .4386 m .64627 .46112 L .64633 .46127 L F
.63381 .4386 m .64633 .46127 L .6481 .46578 L F
.64633 .46127 m .64675 .46203 L .6481 .46578 L F
.63381 .4386 m .6481 .46578 L .64757 .46701 L F
.6481 .46578 m .64995 .46928 L .64917 .46854 L F
.6481 .46578 m .64917 .46854 L .64757 .46701 L F
.64155 .44873 m .64165 .44901 L .64193 .44934 L 0 0 .143 r
F
.64165 .44901 m .64284 .45211 L .64193 .44934 L F
.64029 .44671 m .6422 .45199 L .64155 .44873 L F
.63195 .41531 m .63348 .42107 L .63321 .41997 L 0 0 .109 r
F
.63195 .41531 m .63321 .41997 L .63304 .41944 L F
.64248 .45681 m .64232 .45635 L .64341 .46045 L F
.64439 .46204 m .64695 .47165 L .64631 .46879 L F
.64439 .46204 m .64631 .46879 L .64562 .46576 L F
.63195 .41531 m .63304 .41944 L .63251 .41744 L F
.62541 .38133 m .6304 .44183 L .62579 .38529 L 0 0 .125 r
F
.62517 .38033 m .6304 .44183 L .62541 .38133 L F
.62579 .38531 m .6406 .50885 L .63992 .48617 L 0 .186 .2 r
F
.62579 .38531 m .63677 .49512 L .6406 .50885 L F
.62579 .38531 m .6304 .44184 L .63677 .49512 L F
.62346 .3708 m .63195 .41531 L .6257 .38585 L 0 0 .048 r
F
.63195 .41531 m .63386 .42256 L .63061 .40942 L 0 0 .109 r
F
.63042 .41367 m .63061 .40942 L .63386 .42256 L 0 .683 .07 r
F
.61524 .27524 m .61964 .34201 L .62624 .42024 L 0 0 .125 r
F
.61895 .38402 m .62929 .40654 L .63042 .41367 L 0 .683 .07 r
F
.62929 .40654 m .63061 .40942 L .63042 .41367 L F
.62346 .3708 m .62406 .37371 L .62429 .37516 L 0 0 .048 r
F
.62406 .37371 m .63385 .42113 L .62429 .37516 L F
.61476 .30567 m .61911 .32725 L .6235 .35347 L 0 .621 .044 r
F
.62371 .35531 m .6235 .35347 L .62516 .36334 L F
.61476 .30567 m .6235 .35347 L .62371 .35531 L F
.61715 .2962 m .61765 .30174 L .61787 .3027 L 0 0 .125 r
F
.61765 .30174 m .61827 .30726 L .61787 .3027 L F
.61476 .30567 m .62732 .38768 L .62346 .3708 L 0 .621 .044 r
F
.62732 .38768 m .62818 .39328 L .62346 .3708 L F
.62346 .3708 m .62797 .39214 L .62819 .39308 L 0 0 .048 r
F
.62386 .37266 m .62819 .39308 L .62375 .3722 L F
.62819 .39308 m .63514 .42579 L .62821 .39318 L F
.62819 .39308 m .62821 .39318 L .62375 .3722 L F
.61476 .30567 m .62371 .35531 L .62501 .36683 L 0 .621 .044 r
F
.62371 .35531 m .6243 .35861 L .62501 .36683 L F
.62797 .39214 m .62818 .39328 L .63442 .4227 L 0 0 .048 r
F
.62346 .3708 m .62771 .39102 L .62797 .39214 L F
.62771 .39102 m .62818 .39328 L .62797 .39214 L F
.62797 .39214 m .63438 .42249 L .62819 .39308 L F
.63251 .41744 m .63805 .43826 L .63386 .42256 L 0 0 .109 r
F
.63304 .41944 m .63805 .43826 L .63251 .41744 L F
.63805 .43826 m .64029 .44671 L .63827 .43911 L F
.64029 .44671 m .64193 .44934 L .63871 .43968 L 0 0 .143 r
F
.63961 .44421 m .63871 .43968 L .64193 .44934 L 0 .484 .025 r
F
.6264 .41503 m .63806 .43837 L .63961 .44421 L F
.63806 .43837 m .63871 .43968 L .63961 .44421 L F
.63805 .43826 m .63827 .43911 L .63548 .42863 L 0 0 .109 r
F
.63514 .42736 m .63548 .42863 L .63386 .42256 L F
.63805 .43826 m .63548 .42863 L .63514 .42736 L F
.62375 .3722 m .62821 .39318 L .62865 .39595 L 0 0 .048 r
F
.62821 .39318 m .63514 .42579 L .62865 .39595 L F
.61524 .27524 m .61715 .2962 L .61787 .3027 L 0 0 .125 r
F
.62697 .38443 m .62588 .37199 L .6278 .38974 L 0 .621 .044 r
F
.61476 .30567 m .62501 .36683 L .62697 .38443 L F
.62501 .36683 m .62588 .37199 L .62697 .38443 L F
.62732 .38768 m .6278 .38974 L .62818 .39328 L F
.61476 .30567 m .6278 .38974 L .62732 .38768 L F
.62346 .3708 m .62386 .37266 L .62375 .3722 L 0 0 .048 r
F
.62588 .37199 m .62516 .36334 L .6289 .39002 L 0 .621 .044 r
F
.6243 .35861 m .62516 .36334 L .62588 .37199 L F
.61787 .3027 m .61849 .30914 L .62131 .33244 L 0 0 .125 r
F
.61849 .30914 m .62151 .33487 L .62131 .33244 L F
.61787 .3027 m .62131 .33244 L .61921 .30771 L F
.62588 .37199 m .6289 .39002 L .62828 .39281 L 0 .621 .044 r
F
.61296 .24838 m .61921 .30771 L .61105 .24635 L 0 1 .112 r
F
.61296 .24838 m .61506 .26073 L .61921 .30771 L F
0 g
.61436 .28194 m
.61438 .28365 L
s
.61438 .28365 m
.61439 .28488 L
s
.55874 .24683 m .55743 .26714 L .55803 .24768 L 0 .028 .113 r
F
0 g
.68961 .43614 m
.69005 .43663 L
s
.5361 .24691 m .53591 .25421 L .53483 .25117 L 0 0 .09 r
F
.5382 .24425 m .53591 .25421 L .5361 .24691 L F
.55874 .24683 m .55939 .26713 L .55743 .26714 L 0 .028 .113 r
F
.56324 .24224 m .55939 .26713 L .55874 .24683 L F
.5489 .3594 m .55155 .33548 L .55503 .28438 L 0 1 .127 r
F
0 g
.62502 .34285 m
.62555 .34918 L
s
.62502 .34285 m
.62562 .35882 L
s
.5294 .40368 m .53321 .31347 L .53062 .34623 L 0 1 .24 r
F
0 g
.53275 .31927 m
.53321 .31347 L
s
.53272 .29919 m
.53321 .31347 L
s
.53053 .32374 m
.53272 .29919 L
s
.61105 .24635 m .6191 .32724 L .60996 .24501 L 0 1 .112 r
F
.61105 .24635 m .61921 .30771 L .6191 .32724 L F
.49212 .87585 m .47103 .88429 L .47949 .88492 L 0 1 .518 r
F
0 g
.47013 .88852 m
.47949 .88492 L
s
.60531 .24621 m .60629 .26213 L .60487 .24562 L 0 1 .123 r
F
.52788 .28483 m .53483 .25117 L .53591 .25421 L 0 0 .082 r
F
.52788 .28483 m .5314 .26424 L .53483 .25117 L F
0 g
.52909 .27415 m
.52992 .26942 L
s
.52761 .29881 m
.52959 .28305 L
s
.53483 .25117 m
.53504 .2485 L
s
.53197 .26206 m
.53483 .25117 L
s
.4618 .88708 m .43948 .89353 L .44784 .89497 L 0 1 .522 r
F
0 g
.67495 .52872 m
.67553 .52822 L
s
.68773 .48066 m .69658 .48819 L .69243 .47861 L 0 .554 .326 r
F
.68773 .48066 m .69798 .50362 L .69658 .48819 L F
.68773 .48066 m .69568 .51459 L .69798 .50362 L F
.68773 .48066 m .69098 .51661 L .69568 .51459 L F
.68773 .48066 m .68701 .50836 L .69098 .51661 L F
.68773 .48066 m .68562 .49296 L .68701 .50836 L F
0 g
.68619 .46348 m
.68773 .48066 L
s
.682 .49495 m
.68562 .49296 L
s
.60996 .24501 m .61476 .30565 L .60905 .24371 L 0 1 .112 r
F
0 g
.61289 .27131 m
.61342 .28865 L
s
.60996 .24501 m .6191 .32724 L .61476 .30565 L 0 1 .112 r
F
.68379 .3877 m .69173 .41347 L .68721 .39757 L 0 0 .105 r
F
.68379 .3877 m .69502 .42636 L .69173 .41347 L F
.68379 .3877 m .69487 .42757 L .69502 .42636 L F
.68379 .3877 m .69141 .41758 L .69487 .42757 L F
0 g
.6804 .37087 m
.68379 .3877 L
s
.68192 .51203 m .69098 .51661 L .68701 .50836 L 0 .722 .337 r
F
0 g
.68562 .49296 m
.68701 .50836 L
s
.68192 .51203 m .69168 .53182 L .69098 .51661 L 0 .722 .337 r
F
.68192 .51203 m .68865 .54382 L .69168 .53182 L F
.68192 .51203 m .67911 .52517 L .6798 .54036 L F
0 g
.68106 .49548 m
.68192 .51203 L
s
.68192 .51203 m
.68701 .50836 L
s
.67553 .52822 m
.67911 .52517 L
s
.6918 .45333 m .69038 .46369 L .69243 .47861 L 0 .33 .304 r
F
0 g
.68685 .46351 m
.69038 .46369 L
s
.60905 .24371 m .60877 .26036 L .60765 .24186 L 0 1 .112 r
F
.60905 .24371 m .61476 .30565 L .60877 .26036 L F
0 g
.61348 .24893 m
.61506 .26073 L
s
.67911 .52517 m
.6798 .54036 L
s
.55351 .27285 m .55458 .27733 L .55272 .29094 L 0 0 .053 r
F
.53945 .24283 m .53756 .26241 L .53917 .24309 L 0 .117 .121 r
F
.53355 .39854 m .53547 .3265 L .53369 .36757 L 0 1 .238 r
F
.5294 .40368 m .53369 .36757 L .53547 .3265 L 0 1 .24 r
F
0 g
.53526 .30348 m
.53547 .3265 L
s
.53547 .3265 m
.53658 .31192 L
s
.53945 .24283 m .53868 .27033 L .53756 .26241 L 0 .117 .121 r
F
.54015 .24233 m .53868 .27033 L .53945 .24283 L F
.6918 .45333 m .70039 .46477 L .69608 .45378 L 0 .33 .304 r
F
.6918 .45333 m .70245 .47975 L .70039 .46477 L F
.6918 .45333 m .70088 .48869 L .70245 .47975 L F
.6918 .45333 m .69658 .48819 L .70088 .48869 L F
.6918 .45333 m .69243 .47861 L .69658 .48819 L F
0 g
.68773 .48066 m
.69243 .47861 L
s
.68961 .43614 m
.6918 .45333 L
s
.69038 .46369 m
.69243 .47861 L
s
.54797 .47945 m .55235 .36396 L .54934 .42092 L 0 .771 .244 r
F
.54471 .43915 m .54934 .42092 L .55235 .36396 L 0 .871 .24 r
F
.55028 .4696 m .55531 .29717 L .55206 .36276 L 0 1 .217 r
F
0 g
.55255 .35284 m
.55333 .3094 L
s
.55503 .28438 m
.55531 .29717 L
s
.46361 .88008 m .47103 .88429 L .47163 .88148 L 0 1 .522 r
F
.46361 .88008 m .4618 .88708 L .47103 .88429 L F
.49212 .87585 m .47163 .88148 L .47103 .88429 L 0 1 .518 r
F
0 g
.47103 .88429 m
.47949 .88492 L
s
.54015 .24233 m .54272 .26067 L .53868 .27033 L 0 .117 .121 r
F
.5445 .23941 m .54272 .26067 L .54015 .24233 L F
.4618 .88708 m .44049 .89076 L .43948 .89353 L 0 1 .522 r
F
.4618 .88708 m .45007 .88799 L .44049 .89076 L F
.46361 .88008 m .45007 .88799 L .4618 .88708 L F
0 g
.4618 .88708 m
.47103 .88429 L
s
.4618 .88708 m
.47013 .88852 L
s
.67571 .54384 m
.6798 .54036 L
s
.56364 .24187 m .56239 .27303 L .56352 .24196 L 0 .224 .16 r
F
.60127 .24191 m .60597 .27176 L .59858 .24011 L 0 .97 .146 r
F
.56364 .24187 m .56443 .28095 L .56239 .27303 L 0 .224 .16 r
F
.56397 .2417 m .56443 .28095 L .56364 .24187 L F
.60765 .24186 m .60877 .26036 L .60695 .24107 L 0 1 .112 r
F
.49212 .87585 m .48068 .87786 L .47163 .88148 L 0 1 .518 r
F
.49289 .86888 m .49212 .87585 L .50083 .87225 L 0 1 .519 r
F
.49289 .86888 m .48068 .87786 L .49212 .87585 L F
0 g
.49212 .87585 m
.49501 .87607 L
s
.62572 .35211 m .63131 .3469 L .63649 .3996 L 0 1 .146 r
F
0 g
.62562 .35882 m
.62602 .36947 L
s
.62574 .35151 m
.62575 .35155 L
s
.62854 .32316 m
.63131 .3469 L
s
.63014 .34177 m
.63131 .3469 L
s
.56397 .2417 m .56906 .26622 L .56443 .28095 L 0 .224 .16 r
F
.56895 .23934 m .56906 .26622 L .56397 .2417 L F
.49289 .86888 m .50083 .87225 L .50101 .86947 L 0 1 .519 r
F
0 g
.49212 .87585 m
.50083 .87225 L
s
.50083 .87225 m
.50096 .87225 L
s
.43265 .88868 m .43948 .89353 L .44049 .89076 L 0 1 .525 r
F
.43265 .88868 m .42981 .89556 L .43948 .89353 L F
0 g
.43948 .89353 m
.44784 .89497 L
s
.60695 .24107 m .60877 .26036 L .60322 .23976 L 0 .826 .178 r
F
.43265 .88868 m .41792 .89549 L .42981 .89556 L 0 1 .525 r
F
0 g
.42981 .89556 m
.43948 .89353 L
s
.52602 .29348 m .5314 .26424 L .52788 .28483 L 0 0 .002 r
F
0 g
.5314 .26424 m
.53197 .26206 L
s
.5314 .26424 m
.53318 .25247 L
s
.59858 .24011 m .60972 .31662 L .59764 .23948 L 0 .97 .146 r
F
.59858 .24011 m .60597 .27176 L .60972 .31662 L F
.60629 .26213 m .60972 .31662 L .60597 .27176 L 0 .765 .068 r
F
.60629 .26213 m .61604 .37764 L .60972 .31662 L F
.60322 .23976 m .60822 .28885 L .60003 .23838 L 0 .826 .178 r
F
.60629 .26213 m .61045 .29369 L .61674 .354 L 0 .765 .068 r
F
.60322 .23976 m .60877 .26036 L .60822 .28885 L 0 .826 .178 r
F
.59764 .23948 m .60907 .33952 L .5972 .23913 L 0 .97 .146 r
F
.59764 .23948 m .60972 .31662 L .60907 .33952 L F
.49289 .86888 m .47254 .87728 L .48068 .87786 L 0 1 .519 r
F
0 g
.47163 .88148 m
.48068 .87786 L
s
.5445 .23941 m .54696 .23999 L .54272 .26067 L 0 .117 .121 r
F
.54715 .23758 m .54696 .23999 L .5445 .23941 L F
.56895 .23934 m .57314 .2389 L .56906 .26622 L 0 .224 .16 r
F
.5732 .23729 m .57314 .2389 L .56895 .23934 L F
.59836 .25289 m .60439 .32455 L .59828 .25501 L 0 .97 .146 r
F
.5972 .23913 m .60907 .33952 L .60439 .32455 L F
.59686 .23882 m .60439 .32455 L .59848 .2865 L F
.59239 .30901 m .59726 .3115 L .60315 .33327 L 0 .852 .147 r
F
.59239 .30901 m .60315 .33327 L .60618 .36008 L F
.60439 .32457 m .60618 .36008 L .60315 .33327 L 0 .953 .106 r
F
.60439 .32457 m .61232 .3951 L .60618 .36008 L F
.60439 .32457 m .61747 .4148 L .61232 .3951 L F
.60439 .32457 m .61869 .40572 L .61747 .4148 L F
.60439 .32457 m .61518 .37419 L .61869 .40572 L F
.60439 .32457 m .60907 .33954 L .61518 .37419 L F
.59626 .3156 m .60557 .3227 L .60391 .34039 L 0 .662 .166 r
F
.58915 .24258 m .58558 .25168 L .58873 .23795 L 0 .615 .187 r
F
.59131 .23592 m .59529 .25115 L .59112 .24487 L 0 .797 .177 r
F
.59176 .23591 m .59512 .23995 L .59112 .24487 L 0 .615 .187 r
F
.59286 .28363 m .59848 .2865 L .59725 .31149 L 0 .797 .177 r
F
.58995 .24052 m .59031 .24586 L .58558 .25168 L 0 .615 .187 r
F
.5886 .23568 m .58558 .25168 L .58368 .23552 L 0 .555 .182 r
F
.58924 .2357 m .58873 .23795 L .5886 .23568 L F
.58873 .23795 m .58558 .25168 L .5886 .23568 L F
.59686 .23882 m .59848 .2865 L .59641 .23844 L 0 .97 .146 r
F
.59641 .23844 m .59529 .25115 L .59572 .23796 L F
.59641 .23844 m .59848 .2865 L .59529 .25115 L F
.59116 .25841 m .59529 .25115 L .59848 .2865 L 0 .797 .177 r
F
.59112 .24487 m .59529 .25115 L .59116 .25841 L F
.59116 .25841 m .59512 .23995 L .59818 .26686 L 0 .615 .187 r
F
.58558 .25168 m .59112 .24487 L .59116 .25841 L F
.59112 .24487 m .59512 .23995 L .59116 .25841 L F
.5911 .23759 m .59112 .24487 L .59031 .24586 L F
.5911 .23759 m .59031 .24586 L .58995 .24052 L F
.59131 .23592 m .59112 .24487 L .5911 .23593 L 0 .797 .177 r
F
.5911 .23586 m .58915 .24258 L .58924 .2357 L 0 .615 .187 r
F
.59131 .23592 m .5911 .23593 L .5911 .23586 L 0 .797 .177 r
F
.59176 .23591 m .5911 .23759 L .5911 .23586 L 0 .615 .187 r
F
.5911 .23759 m .58915 .24258 L .5911 .23586 L F
.58915 .24258 m .58873 .23795 L .58924 .2357 L F
.5911 .23586 m .58538 .23621 L .58659 .23441 L 0 .797 .177 r
F
.5911 .23593 m .58538 .23621 L .5911 .23586 L F
.58538 .23621 m .59112 .24487 L .59116 .25841 L F
.58558 .25168 m .5904 .28832 L .58685 .29619 L 0 .615 .187 r
F
.58558 .25168 m .59096 .27158 L .5904 .28832 L F
.5904 .28832 m .59046 .26997 L .59079 .2766 L 0 .797 .177 r
F
.5904 .28832 m .59079 .2766 L .59239 .309 L F
.59153 .2894 m .59286 .28363 L .59244 .30607 L F
.58558 .25168 m .59051 .25762 L .59096 .27158 L 0 .615 .187 r
F
.59035 .26774 m .59096 .27158 L .59153 .2894 L 0 .797 .177 r
F
.59096 .27158 m .59286 .28363 L .59153 .2894 L F
.59096 .27158 m .59116 .25841 L .59286 .28363 L F
.59051 .25762 m .59116 .25841 L .59096 .27158 L 0 .615 .187 r
F
.58538 .23621 m .59116 .25841 L .59096 .27158 L 0 .797 .177 r
F
.59116 .25841 m .59848 .2865 L .59286 .28363 L F
.59116 .25841 m .59818 .26686 L .59096 .27158 L 0 .615 .187 r
F
.59096 .27158 m .59818 .26686 L .597 .2939 L F
.59035 .26774 m .59244 .30607 L .59239 .309 L 0 .797 .177 r
F
.59286 .28363 m .59725 .31149 L .59529 .31048 L F
.59286 .28363 m .59529 .31048 L .59239 .309 L F
.5904 .28832 m .597 .2939 L .5923 .3028 L 0 .615 .187 r
F
.59096 .27158 m .597 .2939 L .5904 .28832 L F
.58538 .23621 m .5904 .28832 L .58673 .28711 L 0 .797 .177 r
F
.5904 .28832 m .59239 .309 L .5901 .30013 L F
.5904 .28832 m .5901 .30013 L .58685 .29619 L 0 .615 .187 r
F
.5904 .28832 m .5901 .30013 L .58673 .28711 L 0 .797 .177 r
F
.5904 .28832 m .59035 .30044 L .5901 .30013 L 0 .615 .187 r
F
.5904 .28832 m .5923 .3028 L .59035 .30044 L F
.58538 .23621 m .59035 .26774 L .59046 .26997 L 0 .797 .177 r
F
.58538 .23621 m .59046 .26997 L .5904 .28832 L F
.59176 .23591 m .59112 .24487 L .5911 .23759 L 0 .615 .187 r
F
.5911 .23593 m .59112 .24487 L .58538 .23621 L 0 .797 .177 r
F
.5923 .30281 m .59647 .30906 L .59626 .3156 L 0 .662 .166 r
F
.59647 .30906 m .60557 .3227 L .59626 .3156 L F
.5972 .23913 m .59836 .25289 L .59686 .23882 L 0 .97 .146 r
F
.59836 .25289 m .59828 .25501 L .59686 .23882 L F
0 g
.60071 .30085 m
.60103 .31588 L
s
.60281 .31436 m
.60306 .31893 L
s
.60513 .35622 m
.60536 .36035 L
s
.46361 .88008 m .44202 .8866 L .45007 .88799 L 0 1 .522 r
F
0 g
.44049 .89076 m
.45007 .88799 L
s
.52788 .28483 m .53591 .25421 L .53377 .2712 L 0 0 .082 r
F
0 g
.53591 .25421 m
.5382 .24425 L
s
.69141 .41758 m
.69168 .41836 L
s
.50101 .86947 m
.50126 .86933 L
s
.50206 .86889 m
.50638 .86651 L
s
.69419 .43361 m .69343 .44045 L .69608 .45378 L 0 .154 .229 r
F
0 g
.69343 .44045 m
.69552 .45096 L
s
.69005 .43663 m
.69343 .44045 L
s
.60003 .23838 m .60381 .28793 L .59846 .23751 L 0 .826 .178 r
F
.60003 .23838 m .60822 .28885 L .60381 .28793 L F
0 g
.69098 .51661 m
.69177 .51627 L
s
.55028 .4696 m .55586 .40069 L .55794 .31364 L 0 1 .217 r
F
0 g
.55794 .31364 m
.55964 .2684 L
s
.55769 .27007 m
.55794 .31364 L
s
.52792 .33972 m .52807 .3094 L .52706 .33129 L 0 1 .201 r
F
.5224 .36652 m .52807 .3094 L .52685 .30483 L F
.5224 .36652 m .52706 .33129 L .52807 .3094 L F
0 g
.52807 .3094 m
.53003 .2876 L
s
.59846 .23751 m .59818 .26686 L .59685 .23674 L 0 .826 .178 r
F
.59846 .23751 m .60381 .28793 L .59818 .26686 L F
0 g
.62295 .38121 m
.6231 .38713 L
s
.62092 .30202 m
.62187 .33906 L
s
.62128 .2782 m
.62572 .35207 L
s
.62409 .42575 m
.62457 .4447 L
s
.62357 .40544 m
.62409 .42575 L
s
.62356 .40495 m
.62357 .40544 L
s
.62323 .39213 m
.62326 .39342 L
s
.62331 .39529 m
.62356 .40495 L
s
.6231 .38713 m
.62323 .39213 L
s
.5224 .36652 m .52685 .30483 L .5242 .3206 L 0 1 .201 r
F
0 g
.52685 .30483 m
.52807 .3094 L
s
.52685 .30483 m
.52761 .29881 L
s
.577 .23641 m .57314 .2389 L .57465 .23695 L 0 .341 .182 r
F
.59685 .23674 m .59512 .23995 L .59521 .2363 L 0 .826 .178 r
F
.59685 .23674 m .59818 .26686 L .59512 .23995 L F
.43265 .88868 m .41005 .89342 L .41792 .89549 L 0 1 .525 r
F
.69419 .43361 m .69608 .45378 L .70039 .46477 L 0 .154 .229 r
F
0 g
.6918 .45333 m
.69608 .45378 L
s
.69552 .45096 m
.69608 .45378 L
s
.5785 .23606 m .56906 .26622 L .577 .23641 L 0 .341 .182 r
F
.577 .23641 m .56906 .26622 L .57314 .2389 L F
0 g
.59512 .23995 m
.59521 .2363 L
s
.58009 .23565 m .58053 .25127 L .5785 .23606 L 0 .555 .182 r
F
.5785 .23606 m .58053 .25127 L .56906 .26622 L 0 .341 .182 r
F
0 g
.57314 .2389 m
.5732 .23729 L
s
.57314 .2389 m
.57465 .23695 L
s
.69658 .48819 m
.69713 .48825 L
s
.55125 .23585 m .54696 .23999 L .55098 .23596 L 0 .237 .156 r
F
0 g
.59176 .23591 m
.59512 .23995 L
s
.55135 .23581 m .54272 .26067 L .55125 .23585 L 0 .237 .156 r
F
.55125 .23585 m .54272 .26067 L .54696 .23999 L F
.69168 .53182 m .68865 .54382 L .68918 .55785 L 0 .722 .347 r
F
0 g
.68865 .54382 m
.68918 .55785 L
s
.68604 .56021 m
.68918 .55785 L
s
.68529 .54624 m
.68865 .54382 L
s
.55301 .23502 m .55297 .25042 L .55135 .23581 L 0 .304 .167 r
F
.55135 .23581 m .55297 .25042 L .54272 .26067 L 0 .237 .156 r
F
0 g
.54696 .23999 m
.54715 .23758 L
s
.54696 .23999 m
.55098 .23596 L
s
.58368 .23552 m .58053 .25127 L .58009 .23565 L 0 .555 .182 r
F
.46544 .87315 m .47254 .87728 L .47314 .8745 L 0 1 .523 r
F
.46544 .87315 m .46361 .88008 L .47254 .87728 L F
.49289 .86888 m .47314 .8745 L .47254 .87728 L 0 1 .519 r
F
0 g
.47254 .87728 m
.48068 .87786 L
s
.69168 .53182 m .7009 .53615 L .69693 .52852 L 0 .722 .347 r
F
.69168 .53182 m .70144 .55019 L .7009 .53615 L F
.69168 .53182 m .69819 .56127 L .70144 .55019 L F
0 g
.69098 .51661 m
.69168 .53182 L
s
.58368 .23552 m .58558 .25168 L .58053 .25127 L 0 .555 .182 r
F
.46361 .88008 m .44304 .88384 L .44202 .8866 L 0 1 .522 r
F
.46361 .88008 m .4523 .88104 L .44304 .88384 L F
.46544 .87315 m .4523 .88104 L .46361 .88008 L 0 1 .523 r
F
0 g
.46361 .88008 m
.47254 .87728 L
s
.46361 .88008 m
.47163 .88148 L
s
.55611 .23413 m .55297 .25042 L .55301 .23502 L 0 .304 .167 r
F
.49289 .86888 m .48187 .8709 L .47314 .8745 L 0 1 .519 r
F
.49367 .8621 m .49289 .86888 L .50129 .86535 L 0 1 .52 r
F
.49367 .8621 m .48187 .8709 L .49289 .86888 L F
0 g
.49289 .86888 m
.50101 .86947 L
s
.43551 .88182 m .44202 .8866 L .44304 .88384 L 0 1 .525 r
F
.43551 .88182 m .43265 .88868 L .44202 .8866 L F
0 g
.44202 .8866 m
.45007 .88799 L
s
.69419 .43361 m .70248 .44993 L .69806 .43765 L 0 .154 .229 r
F
.69419 .43361 m .70515 .46334 L .70248 .44993 L F
.69419 .43361 m .70428 .46889 L .70515 .46334 L F
.69419 .43361 m .70039 .46477 L .70428 .46889 L F
0 g
.69141 .41758 m
.69419 .43361 L
s
.52508 .41383 m .53006 .329 L .52792 .33972 L 0 1 .242 r
F
.52508 .41383 m .53062 .34623 L .53006 .329 L F
0 g
.53006 .329 m
.53053 .32374 L
s
.49367 .8621 m .50129 .86535 L .50147 .86265 L 0 1 .52 r
F
0 g
.49289 .86888 m
.50129 .86535 L
s
.50129 .86535 m
.50646 .86502 L
s
.61023 .27142 m
.61045 .29369 L
s
.61459 .30433 m
.61491 .33653 L
s
.61369 .29754 m
.61487 .3361 L
s
.61148 .28082 m
.61286 .30381 L
s
.61286 .30381 m
.61295 .30533 L
s
.61295 .30533 m
.61299 .3059 L
s
.61299 .3059 m
.61303 .30657 L
s
.61042 .2902 m
.61086 .29763 L
s
.61559 .37661 m
.61575 .37935 L
s
.61486 .40482 m
.61499 .40854 L
s
.58659 .23441 m .58538 .23621 L .5852 .23397 L 0 .795 .177 r
F
.69798 .50362 m .69568 .51459 L .69693 .52852 L 0 .552 .337 r
F
0 g
.69177 .51627 m
.69568 .51459 L
s
.67025 .3899 m .67483 .3666 L .67941 .38719 L 0 .885 .131 r
F
.67025 .3899 m .67092 .36772 L .67483 .3666 L F
0 g
.67173 .34682 m
.67483 .3666 L
s
.66798 .33171 m
.67092 .36772 L
s
.67481 .36661 m
.67483 .3666 L
s
.67479 .36661 m
.67481 .36661 L
s
.67092 .36772 m
.67479 .36661 L
s
.55611 .23413 m .55756 .24776 L .55297 .25042 L 0 .304 .167 r
F
0 g
.55483 .27462 m
.55718 .24915 L
s
.56115 .23295 m .55756 .24776 L .55611 .23413 L 0 .304 .167 r
F
.43265 .88868 m .41147 .89072 L .41005 .89342 L 0 1 .525 r
F
.43265 .88868 m .42117 .88869 L .41147 .89072 L F
.43551 .88182 m .42117 .88869 L .43265 .88868 L F
0 g
.43265 .88868 m
.44049 .89076 L
s
.43265 .88868 m
.44202 .8866 L
s
.5852 .23397 m .58538 .23621 L .58469 .23384 L 0 .795 .177 r
F
.69798 .50362 m .70696 .5105 L .70281 .50185 L 0 .552 .337 r
F
.69798 .50362 m .70822 .52447 L .70696 .5105 L F
.69798 .50362 m .70574 .53442 L .70822 .52447 L F
.69798 .50362 m .7009 .53615 L .70574 .53442 L F
.69798 .50362 m .69693 .52852 L .7009 .53615 L F
0 g
.69658 .48819 m
.69798 .50362 L
s
.69168 .53182 m
.69693 .52852 L
s
.69568 .51459 m
.69693 .52852 L
s
.56643 .23223 m .55756 .24777 L .56115 .23295 L 0 .406 .18 r
F
.57946 .23256 m .57867 .24924 L .57512 .23243 L 0 .561 .185 r
F
.49367 .8621 m .47405 .87036 L .48187 .8709 L 0 1 .52 r
F
0 g
.47314 .8745 m
.48187 .8709 L
s
.56906 .26622 m .58053 .25127 L .57903 .27975 L 0 .341 .182 r
F
.57512 .23243 m .57405 .26021 L .57138 .23205 L 0 .561 .185 r
F
.57512 .23243 m .57867 .24924 L .57405 .26021 L F
.46544 .87315 m .44457 .87969 L .4523 .88104 L 0 1 .523 r
F
0 g
.44304 .88384 m
.4523 .88104 L
s
.56694 .23216 m .55756 .24777 L .56643 .23223 L 0 .406 .18 r
F
.56875 .23193 m .56897 .25253 L .56694 .23216 L 0 .561 .185 r
F
.56694 .23216 m .56897 .25253 L .55756 .24777 L 0 .406 .18 r
F
.58558 .25168 m .58685 .29619 L .58431 .27855 L 0 .615 .187 r
F
.58538 .23621 m .58673 .28711 L .58409 .26068 L 0 .797 .177 r
F
0 g
.58469 .23384 m
.58538 .23621 L
s
.57138 .23205 m .56897 .25253 L .56875 .23193 L 0 .561 .185 r
F
.57138 .23205 m .57405 .26021 L .56897 .25253 L F
.4042 .88811 m .41005 .89342 L .41147 .89072 L 0 1 .528 r
F
.4042 .88811 m .40035 .89477 L .41005 .89342 L F
0 g
.41005 .89342 m
.41792 .89549 L
s
.52602 .29348 m .52477 .30269 L .52416 .30576 L 0 0 .002 r
F
.5242 .3206 m .52602 .29348 L .52325 .31538 L 0 1 .114 r
F
.52602 .29348 m .52788 .28483 L .52477 .30269 L 0 0 .002 r
F
0 g
.74984 .73329 m
.75064 .73123 L
s
.68316 .3976 m .68721 .39757 L .69173 .41347 L 0 .662 .058 r
F
.68316 .3976 m .68355 .39079 L .68721 .39757 L F
0 g
.68379 .3877 m
.68721 .39757 L
s
.68702 .39721 m
.68721 .39757 L
s
.68686 .39692 m
.68702 .39721 L
s
.68355 .39079 m
.68686 .39692 L
s
.68059 .37204 m
.68355 .39079 L
s
.69575 .5628 m
.69819 .56127 L
s
.50147 .86265 m
.50688 .8596 L
s
.54972 .3198 m .55743 .26714 L .55939 .26713 L 0 0 .102 r
F
.54972 .3198 m .55331 .28958 L .55743 .26714 L F
0 g
.55743 .26714 m
.55803 .24796 L
s
.54573 .35001 m .55272 .29094 L .55458 .27733 L 0 0 .003 r
F
0 g
.55427 .31821 m
.55531 .29717 L
s
.55172 .29901 m
.55188 .29663 L
s
.55209 .29364 m
.55351 .27285 L
s
.55188 .29663 m
.55209 .29364 L
s
.55458 .27733 m
.55483 .27462 L
s
.4042 .88811 m .38881 .89387 L .40035 .89477 L 0 1 .528 r
F
0 g
.40035 .89477 m
.41005 .89342 L
s
.69654 .57681 m
.6974 .57648 L
s
.43551 .88182 m .41361 .88668 L .42117 .88869 L 0 1 .525 r
F
0 g
.41147 .89072 m
.42117 .88869 L
s
.70039 .46477 m
.70075 .46515 L
s
.70245 .47975 m .70088 .48869 L .70281 .50185 L 0 .325 .314 r
F
0 g
.69713 .48825 m
.70088 .48869 L
s
.62572 .35211 m
.62626 .36336 L
s
.62626 .36336 m
.62683 .37524 L
s
.7009 .53615 m
.70144 .55019 L
s
.70158 .5359 m
.70574 .53442 L
s
.7009 .53615 m
.70158 .5359 L
s
.69819 .56128 m
.69907 .57138 L
s
.46726 .86627 m .47405 .87036 L .47466 .86761 L 0 1 .523 r
F
.46726 .86627 m .46544 .87315 L .47405 .87036 L F
.49367 .8621 m .47466 .86761 L .47405 .87036 L 0 1 .52 r
F
0 g
.47405 .87036 m
.48187 .8709 L
s
.46544 .87315 m .44559 .87693 L .44457 .87969 L 0 1 .523 r
F
.46544 .87315 m .45454 .87412 L .44559 .87693 L F
.46726 .86627 m .45454 .87412 L .46544 .87315 L F
0 g
.46544 .87315 m
.47405 .87036 L
s
.46544 .87315 m
.47314 .8745 L
s
.70245 .47975 m .70281 .50185 L .70696 .5105 L 0 .325 .314 r
F
0 g
.69798 .50362 m
.70281 .50185 L
s
.70088 .48869 m
.70281 .50185 L
s
.43837 .87496 m .44457 .87969 L .44559 .87693 L 0 1 .525 r
F
.43837 .87496 m .43551 .88182 L .44457 .87969 L F
0 g
.44457 .87969 m
.4523 .88104 L
s
.5224 .36652 m .52463 .3558 L .52706 .33129 L 0 1 .201 r
F
0 g
.75064 .73123 m
.75874 .72748 L
s
.49367 .8621 m .48307 .86407 L .47466 .86761 L 0 1 .52 r
F
.49445 .85554 m .49367 .8621 L .50175 .85869 L 0 1 .521 r
F
.49445 .85554 m .48307 .86407 L .49367 .8621 L F
0 g
.49367 .8621 m
.50147 .86265 L
s
.74877 .72188 m
.74999 .71761 L
s
.70144 .55019 m .71297 .55781 L .70777 .5487 L 0 .734 .359 r
F
.70144 .55019 m .71423 .57228 L .71297 .55781 L F
.43551 .88182 m .41503 .88398 L .41361 .88668 L 0 1 .525 r
F
.43551 .88182 m .42443 .88189 L .41503 .88398 L F
.43837 .87496 m .42443 .88189 L .43551 .88182 L F
0 g
.43551 .88182 m
.44304 .88384 L
s
.43551 .88182 m
.44457 .87969 L
s
.49445 .85554 m .50175 .85869 L .50193 .8561 L 0 1 .521 r
F
0 g
.49367 .8621 m
.50175 .85869 L
s
.50175 .85869 m
.50683 .85828 L
s
.54135 .40456 m
.54172 .38089 L
s
.54183 .37406 m
.54198 .36464 L
s
.54082 .38021 m
.54198 .36464 L
s
.7484 .71836 m
.74999 .71761 L
s
.5294 .40368 m .53062 .34623 L .52921 .38016 L 0 1 .24 r
F
.52508 .41383 m .52921 .38016 L .53062 .34623 L 0 1 .242 r
F
0 g
.53006 .329 m
.53062 .34623 L
s
.53062 .34623 m
.53275 .31927 L
s
.70245 .47975 m .71115 .48994 L .70685 .48027 L 0 .325 .314 r
F
.70245 .47975 m .71309 .50315 L .71115 .48994 L F
.70245 .47975 m .71137 .51107 L .71309 .50315 L F
.70245 .47975 m .70696 .5105 L .71137 .51107 L F
0 g
.70039 .46477 m
.70245 .47975 L
s
.52508 .41383 m .52792 .33972 L .52554 .3685 L 0 1 .242 r
F
0 g
.52746 .34519 m
.52792 .33972 L
s
.52511 .35094 m
.52706 .33129 L
s
.52706 .33129 m
.52792 .33972 L
s
.53355 .39854 m .53515 .39834 L .53795 .36114 L 0 1 .238 r
F
0 g
.53595 .38781 m
.53795 .36114 L
s
.54972 .3198 m .55939 .26713 L .55789 .28776 L 0 0 .102 r
F
0 g
.55331 .28958 m
.5536 .288 L
s
.55331 .28958 m
.55388 .28405 L
s
.55388 .28405 m
.55458 .27733 L
s
.5554 .27821 m
.55743 .26714 L
s
.55939 .26713 m
.56209 .24966 L
s
.57559 .3255 m .58032 .42736 L .57682 .39496 L 0 .635 .215 r
F
.57559 .3255 m .58488 .43405 L .58032 .42736 L F
.57559 .3255 m .58739 .41041 L .58488 .43405 L F
0 g
.57815 .32921 m
.5783 .34501 L
s
.57559 .3255 m .58601 .34056 L .58739 .41041 L 0 .635 .215 r
F
.56784 .34485 m .57559 .3255 L .5719 .37135 L 0 0 .105 r
F
.54573 .35001 m .54894 .32199 L .55272 .29094 L 0 0 .003 r
F
0 g
.54986 .31446 m
.55047 .30942 L
s
.55047 .30942 m
.55272 .29094 L
s
.55001 .32389 m
.5505 .31676 L
s
.55256 .32064 m
.55368 .30429 L
s
.55169 .29943 m
.55172 .29901 L
s
.55272 .29094 m
.55351 .27285 L
s
.69502 .42636 m .69487 .42757 L .69806 .43765 L 0 0 .097 r
F
0 g
.69747 .43578 m
.69774 .43664 L
s
.69487 .42757 m
.69747 .43578 L
s
.69168 .41836 m
.69487 .42757 L
s
.60877 .26036 m
.60929 .26427 L
s
.60929 .26427 m
.61159 .28167 L
s
.61159 .28167 m
.61362 .297 L
s
.60822 .28885 m
.60877 .26036 L
s
.52979 .29093 m .53756 .26241 L .53868 .27033 L 0 .049 .108 r
F
.52979 .29093 m .53377 .2712 L .53756 .26241 L F
0 g
.53756 .26241 m
.53917 .24309 L
s
.53537 .26748 m
.53756 .26241 L
s
.4042 .88811 m .3815 .89126 L .38881 .89387 L 0 1 .528 r
F
.69502 .42636 m .69806 .43765 L .70248 .44993 L 0 0 .097 r
F
0 g
.69419 .43361 m
.69806 .43765 L
s
.69774 .43664 m
.69806 .43765 L
s
.5242 .3206 m .52325 .31538 L .52265 .32515 L 0 1 .114 r
F
.5224 .36652 m .5242 .3206 L .52176 .34508 L 0 1 .201 r
F
.46726 .86627 m .44712 .87279 L .45454 .87412 L 0 1 .523 r
F
0 g
.44559 .87693 m
.45454 .87412 L
s
.49445 .85554 m .47557 .86352 L .48307 .86407 L 0 1 .521 r
F
0 g
.47466 .86761 m
.48307 .86407 L
s
.40806 .88143 m .41361 .88668 L .41503 .88398 L 0 1 .528 r
F
.40806 .88143 m .4042 .88811 L .41361 .88668 L F
0 g
.41361 .88668 m
.42117 .88869 L
s
.52788 .28483 m .52632 .30419 L .52569 .30201 L 0 0 .082 r
F
.52788 .28483 m .52979 .29093 L .52632 .30419 L F
.52788 .28483 m .53377 .2712 L .52979 .29093 L F
0 g
.53377 .2712 m
.53537 .26748 L
s
.53377 .2712 m
.53591 .25421 L
s
.70659 .58337 m
.70852 .58293 L
s
.70822 .52447 m .70574 .53442 L .70777 .5487 L 0 .566 .35 r
F
0 g
.50193 .8561 m
.50488 .85442 L
s
.50488 .85442 m
.50887 .85217 L
s
.4042 .88811 m .38332 .88867 L .3815 .89126 L 0 1 .528 r
F
.4042 .88811 m .39306 .88732 L .38332 .88867 L F
.40806 .88143 m .39306 .88732 L .4042 .88811 L F
0 g
.4042 .88811 m
.41147 .89072 L
s
.4042 .88811 m
.41361 .88668 L
s
.70522 .59785 m
.70523 .59785 L
s
.70696 .5105 m
.70822 .52447 L
s
.70743 .51056 m
.71137 .51107 L
s
.70696 .5105 m
.70743 .51056 L
s
.43837 .87496 m .41718 .87992 L .42443 .88189 L 0 1 .525 r
F
0 g
.41503 .88398 m
.42443 .88189 L
s
.70822 .52447 m .70777 .5487 L .71297 .55781 L 0 .566 .35 r
F
0 g
.70144 .55019 m
.70777 .5487 L
s
.70574 .53442 m
.70777 .5487 L
s
.70822 .52447 m .71959 .53464 L .71415 .52455 L 0 .566 .35 r
F
.70822 .52447 m .72164 .54897 L .71959 .53464 L F
.70822 .52447 m .71892 .55794 L .72164 .54897 L F
.70822 .52447 m .71297 .55781 L .71892 .55794 L F
0 g
.58053 .25127 m
.58457 .2516 L
s
.56784 .34485 m .5719 .37135 L .5688 .3719 L 0 0 .105 r
F
0 g
.56801 .34951 m
.56826 .3567 L
s
.56784 .34485 m
.56801 .34951 L
s
.56826 .3567 m
.5688 .3719 L
s
.56674 .3591 m
.56784 .34485 L
s
.56528 .37784 m
.56674 .3591 L
s
.4691 .85947 m .47557 .86352 L .47618 .86081 L 0 1 .523 r
F
.4691 .85947 m .46726 .86627 L .47557 .86352 L F
.49445 .85554 m .47618 .86081 L .47557 .86352 L 0 1 .521 r
F
0 g
.47557 .86352 m
.48307 .86407 L
s
.46726 .86627 m .44815 .87004 L .44712 .87279 L 0 1 .523 r
F
.46726 .86627 m .45679 .86724 L .44815 .87004 L F
.4691 .85947 m .45679 .86724 L .46726 .86627 L F
0 g
.46726 .86627 m
.47557 .86352 L
s
.46726 .86627 m
.47466 .86761 L
s
.44124 .8681 m .44712 .87279 L .44815 .87004 L 0 1 .525 r
F
.44124 .8681 m .43837 .87496 L .44712 .87279 L F
0 g
.44712 .87279 m
.45454 .87412 L
s
.6573 .43565 m .66168 .36238 L .66627 .38761 L 0 .76 .193 r
F
.6573 .43565 m .65786 .38263 L .66168 .36238 L F
0 g
.65871 .32513 m
.66168 .36238 L
s
.49115 .93966 m .49038 .94554 L .4998 .94405 L 0 1 .539 r
F
.49115 .93966 m .47801 .94516 L .49038 .94554 L F
.54272 .26067 m .55297 .25042 L .55068 .27378 L 0 .237 .156 r
F
0 g
.55297 .25042 m
.55756 .24776 L
s
.55756 .24777 m .557 .28774 L .5554 .27276 L 0 .406 .18 r
F
0 g
.5536 .288 m
.5554 .27821 L
s
.55388 .31554 m .56239 .27303 L .56443 .28095 L 0 .145 .133 r
F
.55388 .31554 m .55789 .28776 L .56239 .27303 L F
.54972 .3198 m .55789 .28776 L .55388 .31554 L 0 0 .102 r
F
.55388 .31554 m .56443 .28095 L .56265 .30404 L 0 .145 .133 r
F
.55756 .24777 m .56193 .28983 L .557 .28774 L 0 .406 .18 r
F
.55756 .24777 m .56687 .2776 L .56193 .28983 L F
0 g
.56271 .26427 m
.56322 .25013 L
s
.55756 .24777 m .56897 .25253 L .56687 .2776 L 0 .406 .18 r
F
.70515 .46334 m .70428 .46889 L .70685 .48027 L 0 .148 .228 r
F
0 g
.70428 .46889 m
.70647 .47858 L
s
.70075 .46515 m
.70428 .46889 L
s
.43837 .87496 m .41861 .87722 L .41718 .87992 L 0 1 .525 r
F
.43837 .87496 m .4277 .87509 L .41861 .87722 L F
.44124 .8681 m .4277 .87509 L .43837 .87496 L F
0 g
.43837 .87496 m
.44559 .87693 L
s
.43837 .87496 m
.44712 .87279 L
s
.68316 .3976 m .69173 .41347 L .69484 .43048 L 0 .662 .058 r
F
0 g
.69173 .41347 m
.69185 .41411 L
s
.49445 .85554 m .48427 .85739 L .47618 .86081 L 0 1 .521 r
F
.49523 .84922 m .49445 .85554 L .50221 .85231 L 0 1 .524 r
F
.49523 .84922 m .48427 .85739 L .49445 .85554 L F
0 g
.49445 .85554 m
.50193 .8561 L
s
.37669 .88558 m .3815 .89126 L .38332 .88867 L 0 1 .531 r
F
.37669 .88558 m .37186 .89197 L .3815 .89126 L F
0 g
.3815 .89126 m
.38881 .89387 L
s
.70515 .46334 m .70685 .48027 L .71115 .48994 L 0 .148 .228 r
F
0 g
.70245 .47975 m
.70685 .48027 L
s
.70647 .47858 m
.70685 .48027 L
s
.49115 .93966 m .46917 .94312 L .47801 .94516 L 0 1 .539 r
F
.51744 .35704 m .52325 .31538 L .52133 .32034 L 0 1 .124 r
F
0 g
.5236 .32662 m
.5242 .3206 L
s
.51744 .35704 m .52265 .32515 L .52325 .31538 L 0 1 .124 r
F
0 g
.52325 .31538 m
.52508 .30087 L
s
.52355 .32713 m
.5236 .32662 L
s
.49523 .84922 m .50221 .85231 L .50239 .84984 L 0 1 .524 r
F
0 g
.49445 .85554 m
.50221 .85231 L
s
.50221 .85231 m
.5085 .85178 L
s
.40806 .88143 m .38606 .88477 L .39306 .88732 L 0 1 .528 r
F
0 g
.38332 .88867 m
.39306 .88732 L
s
.49115 .93966 m .4998 .94405 L .49998 .9417 L 0 1 .539 r
F
0 g
.49038 .94554 m
.4998 .94405 L
s
.4998 .94405 m
.49988 .94406 L
s
.54272 .26067 m .54152 .29454 L .54037 .28409 L 0 .237 .156 r
F
.54272 .26067 m .54595 .2901 L .54152 .29454 L F
.54272 .26067 m .55068 .27378 L .54595 .2901 L F
0 g
.55068 .27378 m
.55297 .25042 L
s
.5294 .40368 m .53109 .40083 L .53369 .36757 L 0 1 .24 r
F
.67025 .3899 m .67941 .38719 L .68228 .41704 L 0 .885 .131 r
F
0 g
.67941 .38719 m
.67943 .38737 L
s
.71297 .55781 m
.71423 .57228 L
s
.71384 .55783 m
.71892 .55794 L
s
.71297 .55781 m
.71384 .55783 L
s
.51744 .35704 m .52133 .32034 L .51815 .3368 L 0 1 .124 r
F
.51815 .3368 m .52416 .30576 L .52477 .30269 L 0 0 0 r
F
.51815 .3368 m .52133 .32034 L .52416 .30576 L F
0 g
.52416 .30576 m
.52602 .29348 L
s
.5227 .32501 m
.5242 .3206 L
s
.41194 .87474 m .41718 .87992 L .41861 .87722 L 0 1 .528 r
F
.41194 .87474 m .40806 .88143 L .41718 .87992 L F
0 g
.41718 .87992 m
.42443 .88189 L
s
.4691 .85947 m .44969 .86591 L .45679 .86724 L 0 1 .523 r
F
0 g
.44815 .87004 m
.45679 .86724 L
s
.54572 .38573 m
.54577 .38289 L
s
.54536 .38805 m
.54573 .38335 L
s
.54573 .38335 m
.54575 .38317 L
s
.54575 .38317 m
.54577 .38289 L
s
.49114 .94187 m .49979 .94572 L .49998 .94238 L 0 1 .502 r
F
.49114 .94187 m .49037 .9501 L .49979 .94572 L F
0 g
.49979 .94572 m
.50897 .94617 L
s
.49523 .84922 m .47709 .85677 L .48427 .85739 L 0 1 .524 r
F
0 g
.47618 .86081 m
.48427 .85739 L
s
.37669 .88558 m .36079 .89032 L .37186 .89197 L 0 1 .531 r
F
0 g
.37186 .89197 m
.3815 .89126 L
s
.51744 .35704 m .52017 .34298 L .52265 .32515 L 0 1 .124 r
F
0 g
.52265 .32515 m
.5227 .32501 L
s
.49114 .94187 m .47796 .95261 L .49037 .9501 L 0 1 .502 r
F
0 g
.49037 .9501 m
.49979 .94572 L
s
.71423 .57228 m .72428 .57645 L .72005 .56971 L 0 .744 .373 r
F
.71423 .57228 m .72463 .58871 L .72428 .57645 L F
.69502 .42636 m .70295 .44816 L .69848 .43516 L 0 0 .097 r
F
.69502 .42636 m .70617 .45832 L .70295 .44816 L F
.69502 .42636 m .70596 .45881 L .70617 .45832 L F
.69502 .42636 m .70248 .44993 L .70596 .45881 L F
0 g
.69173 .41347 m
.69502 .42636 L
s
.46138 .93792 m .45956 .94382 L .46917 .94312 L 0 1 .537 r
F
.46138 .93792 m .44735 .94239 L .45956 .94382 L F
.57405 .26021 m .57867 .24924 L .58409 .26068 L 0 .634 .181 r
F
0 g
.58044 .25298 m
.58053 .25127 L
s
.57867 .24924 m
.57946 .23256 L
s
.68316 .3976 m .69074 .4304 L .68623 .41456 L 0 .662 .058 r
F
.68316 .3976 m .69444 .43724 L .69074 .4304 L F
.68316 .3976 m .69484 .43048 L .69444 .43724 L F
0 g
.67941 .38719 m
.68316 .3976 L
s
.40806 .88143 m .38788 .88217 L .38606 .88477 L 0 1 .528 r
F
.40806 .88143 m .39732 .88074 L .38788 .88217 L F
.41194 .87474 m .39732 .88074 L .40806 .88143 L F
0 g
.40806 .88143 m
.41503 .88398 L
s
.40806 .88143 m
.41718 .87992 L
s
.70248 .44993 m
.70269 .45046 L
s
.61045 .29369 m
.61195 .30809 L
s
.61195 .30809 m
.6126 .31434 L
s
.7382 .66565 m
.73844 .66362 L
s
.71309 .50316 m .71137 .51107 L .71415 .52455 L 0 .339 .328 r
F
0 g
.71137 .51107 m
.71332 .52053 L
s
.44124 .8681 m .42076 .87315 L .4277 .87509 L 0 1 .525 r
F
0 g
.41861 .87722 m
.4277 .87509 L
s
.52459 .93309 m
.52972 .93032 L
s
.46138 .93792 m .46917 .94312 L .46977 .94077 L 0 1 .537 r
F
.49115 .93966 m .46977 .94077 L .46917 .94312 L 0 1 .539 r
F
0 g
.46917 .94312 m
.47801 .94516 L
s
.45956 .94382 m
.46917 .94312 L
s
.50239 .84984 m
.50359 .84919 L
s
.50359 .84919 m
.50741 .84712 L
s
.59038 .33957 m .60064 .44004 L .59647 .47551 L 0 .623 .221 r
F
.59038 .33957 m .60257 .3885 L .60064 .44004 L F
0 g
.5913 .38746 m
.59157 .40162 L
s
.59157 .40162 m
.59176 .41107 L
s
.59038 .33957 m
.5913 .38746 L
s
.59008 .3684 m
.59038 .33957 L
s
.59003 .37332 m
.59008 .3684 L
s
.58998 .3785 m
.59003 .37332 L
s
.5028 .94095 m
.50912 .93928 L
s
.49998 .9417 m
.5028 .94095 L
s
.72463 .58871 m .72106 .60978 L .72506 .61555 L 0 .761 .384 r
F
.72463 .58871 m .72088 .59829 L .72106 .60978 L F
0 g
.71602 .61239 m
.72106 .60978 L
s
.72088 .59829 m
.72106 .60978 L
s
.71915 .59904 m
.72088 .59829 L
s
.46138 .93792 m .43894 .93955 L .44735 .94239 L 0 1 .537 r
F
.71309 .50316 m .71415 .52455 L .71959 .53464 L 0 .339 .328 r
F
0 g
.70822 .52447 m
.71415 .52455 L
s
.71332 .52053 m
.71415 .52455 L
s
.51815 .3368 m .52477 .30269 L .52408 .3059 L 0 0 0 r
F
.51815 .3368 m .52408 .3059 L .52207 .31562 L F
.51815 .3368 m .52251 .31324 L .51887 .33047 L F
.51914 .3298 m .52632 .30419 L .52373 .31821 L 0 0 .048 r
F
.51887 .33047 m .51934 .32882 L .51914 .3298 L F
.51934 .32882 m .52632 .30419 L .51914 .3298 L F
.52207 .31562 m .52408 .3059 L .52251 .31324 L 0 0 0 r
F
0 g
.52408 .3059 m
.52477 .30269 L
s
.52087 .33794 m
.52265 .32515 L
s
.52214 .31824 m
.52287 .31636 L
s
.52169 .31941 m
.52214 .31824 L
s
.52136 .32026 m
.52169 .31941 L
s
.52477 .30269 m
.52788 .28483 L
s
.49998 .94238 m
.50233 .94119 L
s
.50233 .94119 m
.5028 .94095 L
s
.5028 .94095 m
.50296 .94087 L
s
.50296 .94087 m
.5067 .93899 L
s
.72623 .62632 m
.72623 .62632 L
s
.72451 .62559 m
.72454 .62508 L
s
.72462 .62354 m
.7247 .62209 L
s
.59035 .38204 m
.59104 .38862 L
s
.58799 .35949 m
.58998 .3785 L
s
.58998 .3785 m
.59013 .37995 L
s
.59013 .37995 m
.59035 .38204 L
s
.58692 .34925 m
.58799 .35949 L
s
.58601 .34056 m
.58692 .34925 L
s
.58601 .34056 m
.58698 .38959 L
s
.70515 .46334 m .7135 .47752 L .7091 .46702 L 0 .148 .228 r
F
.70515 .46334 m .71608 .48896 L .7135 .47752 L F
.70515 .46334 m .7151 .49368 L .71608 .48896 L F
.70515 .46334 m .71115 .48994 L .7151 .49368 L F
0 g
.70248 .44993 m
.70515 .46334 L
s
.49114 .94187 m .46911 .95211 L .47796 .95261 L 0 1 .502 r
F
.52979 .29093 m .53868 .27033 L .5362 .28931 L 0 .049 .108 r
F
0 g
.53868 .27033 m
.54272 .26067 L
s
.4691 .85947 m .45072 .86316 L .44969 .86591 L 0 1 .523 r
F
.4691 .85947 m .45904 .8604 L .45072 .86316 L F
.47094 .85273 m .4691 .85947 L .47709 .85677 L 0 1 .524 r
F
.47094 .85273 m .45904 .8604 L .4691 .85947 L F
0 g
.4691 .85947 m
.47618 .86081 L
s
.76535 .70421 m
.76653 .69798 L
s
.44412 .86125 m .44969 .86591 L .45072 .86316 L 0 1 .525 r
F
.44412 .86125 m .44124 .8681 L .44969 .86591 L F
0 g
.44969 .86591 m
.45679 .86724 L
s
.72463 .58871 m .72506 .61555 L .73104 .61304 L 0 .761 .384 r
F
0 g
.7247 .62209 m
.72506 .61555 L
s
.52061 .42715 m .52463 .3558 L .5224 .36652 L 0 1 .245 r
F
.52061 .42715 m .52554 .3685 L .52463 .3558 L F
0 g
.52463 .3558 m
.52511 .35094 L
s
.56641 .48698 m
.56641 .48696 L
s
.6201 .34748 m
.62029 .35164 L
s
.62238 .39735 m
.62295 .40973 L
s
.62215 .3923 m
.62238 .39735 L
s
.62295 .40973 m
.62336 .41881 L
s
.47094 .85273 m .47709 .85677 L .4777 .8541 L 0 1 .524 r
F
.49523 .84922 m .4777 .8541 L .47709 .85677 L F
0 g
.47709 .85677 m
.48427 .85739 L
s
.4691 .85947 m
.47709 .85677 L
s
.77611 .70543 m
.7765 .70525 L
s
.71115 .48994 m
.71309 .50315 L
s
.71144 .49022 m
.7151 .49368 L
s
.71115 .48994 m
.71144 .49022 L
s
.38154 .87917 m .38606 .88477 L .38788 .88217 L 0 1 .53 r
F
.38154 .87917 m .37669 .88558 L .38606 .88477 L F
0 g
.38606 .88477 m
.39306 .88732 L
s
.72164 .54897 m .72005 .56971 L .72428 .57645 L 0 .579 .365 r
F
.72164 .54897 m .71892 .55794 L .72005 .56971 L F
0 g
.71423 .57228 m
.72005 .56971 L
s
.71892 .55794 m
.72005 .56971 L
s
.56906 .26622 m .56949 .30552 L .56748 .29486 L 0 .341 .182 r
F
0 g
.56906 .26623 m
.56906 .26622 L
s
.56738 .27158 m
.56906 .26623 L
s
.56906 .26622 m .57446 .29901 L .56949 .30552 L 0 .341 .182 r
F
.56906 .26622 m .57903 .27975 L .57446 .29901 L F
0 g
.56906 .26623 m
.56906 .26622 L
s
.44124 .8681 m .4222 .87044 L .42076 .87315 L 0 1 .525 r
F
.44124 .8681 m .43098 .86828 L .4222 .87044 L F
.44412 .86125 m .43098 .86828 L .44124 .8681 L F
0 g
.44124 .8681 m
.44815 .87004 L
s
.44124 .8681 m
.44969 .86591 L
s
.49115 .93966 m .4792 .93928 L .46977 .94077 L 0 1 .539 r
F
.54471 .43915 m .54604 .45351 L .54934 .42092 L 0 .871 .24 r
F
.54437 .48304 m .55155 .33548 L .5489 .3594 L 0 1 .218 r
F
.54437 .48304 m .55206 .36276 L .55155 .33548 L F
0 g
.55155 .33548 m
.55256 .32064 L
s
.54448 .39897 m
.54536 .38805 L
s
.49193 .93336 m .49177 .93509 L .50026 .93728 L 0 1 .498 r
F
.49177 .93509 m .49115 .93966 L .49752 .93866 L 0 1 .54 r
F
.49177 .93509 m .49114 .94187 L .49752 .93866 L 0 1 .498 r
F
.49177 .93509 m .49752 .93866 L .50026 .93728 L F
.49193 .93393 m .49177 .93509 L .50025 .93823 L 0 1 .54 r
F
.49177 .93509 m .49752 .93866 L .50025 .93823 L F
0 g
.49415 .94035 m
.49998 .9417 L
s
.49176 .93515 m .4792 .93928 L .49115 .93966 L 0 1 .54 r
F
.49177 .93509 m .4917 .93511 L .49176 .93515 L F
.4917 .93511 m .4792 .93928 L .49176 .93515 L F
.4907 .93444 m .4792 .93928 L .49177 .93509 L F
.4907 .93444 m .47063 .94409 L .47917 .94453 L 0 1 .498 r
F
.4907 .93444 m .47068 .93726 L .4792 .93928 L 0 1 .54 r
F
.49193 .93336 m .49031 .93418 L .4907 .93444 L 0 1 .498 r
F
.49193 .93393 m .49031 .93418 L .4907 .93444 L 0 1 .54 r
F
.49031 .93418 m .47068 .93726 L .49063 .93445 L F
.49031 .93418 m .47124 .94082 L .47063 .94409 L 0 1 .498 r
F
.49031 .93418 m .47128 .93495 L .47068 .93726 L 0 1 .54 r
F
.49193 .93393 m .49012 .93401 L .49031 .93418 L F
.49012 .93401 m .47128 .93495 L .49031 .93418 L F
.49193 .93336 m .49012 .93401 L .49031 .93418 L 0 1 .498 r
F
.49012 .93401 m .49012 .93402 L .49031 .93418 L F
.49012 .93402 m .47124 .94082 L .49031 .93418 L F
.49031 .93418 m .49063 .93445 L .4907 .93444 L 0 1 .54 r
F
.49031 .93418 m .4903 .93418 L .4907 .93444 L 0 1 .498 r
F
.4903 .93418 m .47063 .94409 L .4907 .93444 L F
.49177 .93509 m .47917 .94453 L .49114 .94187 L F
.49193 .93336 m .4907 .93444 L .49177 .93509 L F
.4907 .93444 m .47917 .94453 L .49177 .93509 L F
.49193 .93393 m .4907 .93444 L .49177 .93509 L 0 1 .54 r
F
0 g
.46977 .94077 m
.47267 .94031 L
s
.41194 .87474 m .39062 .87826 L .39732 .88074 L 0 1 .528 r
F
0 g
.38788 .88217 m
.39732 .88074 L
s
.43208 .93366 m .42923 .93956 L .43894 .93955 L 0 1 .535 r
F
.43208 .93366 m .41729 .93721 L .42923 .93956 L F
.71309 .50316 m .72421 .51644 L .71859 .50544 L 0 .339 .328 r
F
.71309 .50316 m .72701 .52998 L .72421 .51644 L F
.71309 .50316 m .7251 .53699 L .72701 .52998 L F
.71309 .50316 m .71959 .53464 L .7251 .53699 L F
.49523 .84922 m .48548 .85086 L .4777 .8541 L 0 1 .524 r
F
.49601 .84311 m .49523 .84922 L .50267 .84623 L 0 1 .526 r
F
.49601 .84311 m .48548 .85086 L .49523 .84922 L F
0 g
.49523 .84922 m
.50239 .84984 L
s
.37669 .88558 m .35412 .88723 L .36079 .89032 L 0 1 .531 r
F
.43208 .93366 m .43894 .93955 L .43996 .93719 L 0 1 .535 r
F
.46138 .93792 m .43996 .93719 L .43894 .93955 L 0 1 .537 r
F
0 g
.43894 .93955 m
.44735 .94239 L
s
.42923 .93956 m
.43894 .93955 L
s
.41583 .86802 m .42076 .87315 L .4222 .87044 L 0 1 .527 r
F
.41583 .86802 m .41194 .87474 L .42076 .87315 L F
0 g
.42076 .87315 m
.4277 .87509 L
s
.49701 .93891 m
.49752 .93866 L
s
.49193 .93336 m .50026 .93728 L .50044 .93382 L 0 1 .498 r
F
0 g
.49932 .93775 m
.50026 .93728 L
s
.50026 .93728 m
.50033 .93728 L
s
.49601 .84311 m .50267 .84623 L .50286 .84388 L 0 1 .526 r
F
0 g
.49523 .84922 m
.50267 .84623 L
s
.50267 .84623 m
.50983 .84579 L
s
.37669 .88558 m .35632 .88477 L .35412 .88723 L 0 1 .531 r
F
.37669 .88558 m .36601 .88406 L .35632 .88477 L F
.38154 .87917 m .36601 .88406 L .37669 .88558 L 0 1 .53 r
F
0 g
.37669 .88558 m
.38606 .88477 L
s
.37669 .88558 m
.38332 .88867 L
s
.5224 .36652 m .52176 .34508 L .52117 .36192 L 0 1 .201 r
F
.51674 .39269 m .52176 .34508 L .52017 .34298 L 0 1 .206 r
F
.51674 .39269 m .52117 .36192 L .52176 .34508 L F
0 g
.52176 .34508 m
.52355 .32713 L
s
.49114 .94187 m .46972 .94893 L .46911 .95211 L 0 1 .502 r
F
.49114 .94187 m .47917 .94453 L .46972 .94893 L F
0 g
.49114 .94187 m
.49701 .93891 L
s
.49114 .94187 m
.49998 .94238 L
s
.47094 .85273 m .45226 .85904 L .45904 .8604 L 0 1 .524 r
F
0 g
.45072 .86316 m
.45904 .8604 L
s
.49193 .93393 m .50025 .93823 L .50044 .93595 L 0 1 .54 r
F
0 g
.50025 .93823 m
.50912 .93928 L
s
.49752 .93866 m
.50025 .93823 L
s
.72463 .58871 m .73484 .59237 L .73062 .58616 L 0 .761 .384 r
F
.72463 .58871 m .73502 .60389 L .73484 .59237 L F
.72463 .58871 m .73104 .61304 L .73502 .60389 L F
0 g
.73104 .61304 m
.73105 .62318 L
s
.72506 .61555 m
.73104 .61304 L
s
.4613 .94829 m .46911 .95211 L .46972 .94893 L 0 1 .509 r
F
.4613 .94829 m .45946 .9561 L .46911 .95211 L F
0 g
.46911 .95211 m
.47796 .95261 L
s
.41194 .87474 m .39245 .87564 L .39062 .87826 L 0 1 .528 r
F
.41194 .87474 m .4016 .87413 L .39245 .87564 L F
.41583 .86802 m .4016 .87413 L .41194 .87474 L 0 1 .527 r
F
0 g
.41194 .87474 m
.41861 .87722 L
s
.41194 .87474 m
.42076 .87315 L
s
.72164 .54897 m .72428 .57645 L .72963 .57522 L 0 .579 .365 r
F
0 g
.72428 .57645 m
.72463 .58871 L
s
.49601 .84311 m .47861 .8501 L .48548 .85086 L 0 1 .526 r
F
0 g
.4777 .8541 m
.48548 .85086 L
s
.71959 .53464 m
.72164 .54897 L
s
.7202 .5349 m
.7251 .53699 L
s
.71959 .53464 m
.7202 .5349 L
s
.43208 .93366 m .40939 .93368 L .41729 .93721 L 0 1 .535 r
F
.44412 .86125 m .42435 .86637 L .43098 .86828 L 0 1 .525 r
F
0 g
.4222 .87044 m
.43098 .86828 L
s
.64602 .36775 m .65356 .45945 L .64918 .4373 L 0 .806 .199 r
F
.64602 .36775 m .6573 .43565 L .65356 .45945 L F
.64602 .36775 m .65786 .38263 L .6573 .43565 L F
0 g
.65463 .31459 m
.65786 .38263 L
s
.64602 .36775 m
.64918 .4373 L
s
.65786 .38263 m
.66168 .36238 L
s
.46138 .93792 m .44958 .93649 L .43996 .93719 L 0 1 .537 r
F
.4632 .93211 m .46138 .93792 L .47068 .93726 L 0 1 .538 r
F
.4632 .93211 m .44958 .93649 L .46138 .93792 L F
0 g
.46138 .93792 m
.46977 .94077 L
s
.4613 .94829 m .44718 .95825 L .45946 .9561 L 0 1 .509 r
F
0 g
.45946 .9561 m
.46911 .95211 L
s
.59818 .26686 m
.60381 .28793 L
s
.597 .2939 m
.59818 .26686 L
s
.54934 .3227 m
.55001 .32389 L
s
.56732 .67562 m .57597 .5705 L .57526 .37634 L 0 .771 .231 r
F
0 g
.57524 .32982 m
.57526 .37634 L
s
.50044 .93382 m
.50237 .93278 L
s
.52508 .41383 m .52554 .3685 L .52453 .3963 L 0 1 .242 r
F
.52061 .42715 m .52453 .3963 L .52554 .3685 L 0 1 .245 r
F
0 g
.52463 .3558 m
.52554 .3685 L
s
.52554 .3685 m
.52746 .34519 L
s
.52106 .93267 m
.52808 .9335 L
s
.72164 .54897 m .73141 .55501 L .72699 .5477 L 0 .579 .365 r
F
.72164 .54897 m .73254 .56682 L .73141 .55501 L F
.72164 .54897 m .72963 .57522 L .73254 .56682 L F
.51674 .39269 m .52017 .34298 L .51744 .35704 L 0 1 .206 r
F
0 g
.52017 .34298 m
.52176 .34508 L
s
.52017 .34298 m
.52087 .33794 L
s
.4632 .93211 m .47068 .93726 L .47128 .93495 L 0 1 .538 r
F
0 g
.46138 .93792 m
.47068 .93726 L
s
.47068 .93726 m
.47698 .93875 L
s
.57446 .29901 m .57903 .27975 L .58431 .27855 L 0 .414 .176 r
F
.57446 .29901 m .58431 .27855 L .58685 .29619 L F
.57405 .26021 m .58409 .26068 L .58673 .28711 L 0 .634 .181 r
F
0 g
.58409 .26068 m
.58538 .23621 L
s
.57867 .24924 m
.58409 .26068 L
s
.46972 .94893 m
.47917 .94453 L
s
.50286 .84388 m
.50819 .84132 L
s
.4632 .93211 m .44149 .93366 L .44958 .93649 L 0 1 .538 r
F
0 g
.43996 .93719 m
.44958 .93649 L
s
.51887 .33047 m .52569 .30201 L .52632 .30419 L 0 0 .048 r
F
.51887 .33047 m .52251 .31324 L .52569 .30201 L F
0 g
.52569 .30201 m
.52788 .28483 L
s
.52251 .31324 m
.52408 .3059 L
s
.52251 .31324 m
.52325 .31064 L
s
.52325 .31064 m
.52569 .30201 L
s
.4999 .93582 m
.50044 .93595 L
s
.50044 .93595 m
.50926 .93355 L
s
.52634 .91728 m
.52666 .9173 L
s
.52508 .41383 m .52683 .40925 L .52921 .38016 L 0 1 .242 r
F
.52979 .29093 m .52791 .31568 L .52727 .31004 L 0 .049 .108 r
F
.52979 .29093 m .53175 .30676 L .52791 .31568 L F
.52979 .29093 m .5362 .28931 L .53175 .30676 L F
0 g
.52632 .30419 m
.52979 .29093 L
s
.38641 .87273 m .39062 .87826 L .39245 .87564 L 0 1 .53 r
F
.38641 .87273 m .38154 .87917 L .39062 .87826 L F
0 g
.39062 .87826 m
.39732 .88074 L
s
.64221 .4393 m
.64248 .44154 L
s
.63951 .41655 m
.64221 .4393 L
s
.6417 .43526 m
.64239 .44115 L
s
.6401 .42154 m
.6417 .43526 L
s
.64009 .42146 m
.6401 .42154 L
s
.63951 .41655 m
.64009 .42146 L
s
.447 .85439 m .45226 .85904 L .45329 .85629 L 0 1 .525 r
F
.447 .85439 m .44412 .86125 L .45226 .85904 L F
.47094 .85273 m .45329 .85629 L .45226 .85904 L 0 1 .524 r
F
0 g
.45226 .85904 m
.45904 .8604 L
s
.52934 .93033 m
.53073 .9303 L
s
.47094 .85273 m .4613 .85358 L .45329 .85629 L 0 1 .524 r
F
.47278 .84601 m .47094 .85273 L .47861 .8501 L F
.47278 .84601 m .4613 .85358 L .47094 .85273 L F
0 g
.47094 .85273 m
.4777 .8541 L
s
.75833 .66257 m
.76068 .66146 L
s
.47278 .84601 m .47861 .8501 L .47923 .84744 L 0 1 .524 r
F
.49601 .84311 m .47923 .84744 L .47861 .8501 L 0 1 .526 r
F
0 g
.47861 .8501 m
.48548 .85086 L
s
.47094 .85273 m
.47861 .8501 L
s
.44412 .86125 m .42579 .86364 L .42435 .86637 L 0 1 .525 r
F
.44412 .86125 m .43427 .86145 L .42579 .86364 L F
.447 .85439 m .43427 .86145 L .44412 .86125 L F
0 g
.44412 .86125 m
.45226 .85904 L
s
.44412 .86125 m
.45072 .86316 L
s
.57446 .29901 m .57459 .33286 L .57254 .3218 L 0 .414 .176 r
F
.57405 .26021 m .57427 .30241 L .57214 .28295 L 0 .634 .181 r
F
.57446 .29901 m .57995 .33164 L .57459 .33286 L 0 .414 .176 r
F
.57446 .29901 m .585 .31897 L .57995 .33164 L F
.57446 .29901 m .58685 .29619 L .585 .31897 L F
.57405 .26021 m .57975 .31411 L .57427 .30241 L 0 .634 .181 r
F
.57405 .26021 m .58489 .31012 L .57975 .31411 L F
.57405 .26021 m .58673 .28711 L .58489 .31012 L F
0 g
.56897 .25253 m
.57405 .26021 L
s
.73254 .56682 m .73062 .58616 L .73484 .59237 L 0 .602 .378 r
F
.73254 .56682 m .72963 .57522 L .73062 .58616 L F
0 g
.72463 .58871 m
.73062 .58616 L
s
.72963 .57522 m
.73062 .58616 L
s
.72428 .57645 m
.72963 .57522 L
s
.52117 .93255 m
.52934 .93033 L
s
.3504 .88128 m .35412 .88723 L .35632 .88477 L 0 1 .533 r
F
.3504 .88128 m .34461 .88732 L .35412 .88723 L F
0 g
.35412 .88723 m
.36079 .89032 L
s
.54894 .32199 m
.54986 .31446 L
s
.38154 .87917 m .35963 .88107 L .36601 .88406 L 0 1 .53 r
F
0 g
.35632 .88477 m
.36601 .88406 L
s
.41583 .86802 m .39521 .87171 L .4016 .87413 L 0 1 .527 r
F
0 g
.39245 .87564 m
.4016 .87413 L
s
.40352 .92723 m .40939 .93368 L .41081 .93134 L 0 1 .532 r
F
.40352 .92723 m .39966 .93306 L .40939 .93368 L F
.43208 .93366 m .41081 .93134 L .40939 .93368 L 0 1 .535 r
F
0 g
.40939 .93368 m
.41729 .93721 L
s
.52061 .42715 m .5224 .36652 L .52029 .39155 L 0 1 .245 r
F
0 g
.52199 .37139 m
.5224 .36652 L
s
.40352 .92723 m .3881 .92989 L .39966 .93306 L 0 1 .532 r
F
0 g
.39966 .93306 m
.40939 .93368 L
s
.49271 .92455 m .50072 .92853 L .50091 .92493 L 0 1 .493 r
F
.49271 .92455 m .49193 .93336 L .50072 .92853 L F
0 g
.50072 .92853 m
.50646 .92888 L
s
.4613 .94829 m .43873 .95762 L .44718 .95825 L 0 1 .509 r
F
.49012 .93401 m .48038 .93622 L .47124 .94082 L 0 1 .498 r
F
.49193 .93336 m .48995 .93386 L .49015 .93401 L F
.49271 .92455 m .48548 .9314 L .49193 .93336 L 0 1 .493 r
F
.48548 .9314 m .48039 .93352 L .48945 .93384 L 0 1 .541 r
F
.48548 .9314 m .48945 .93384 L .48995 .93386 L F
.49012 .93401 m .48039 .93352 L .47128 .93495 L 0 1 .54 r
F
.48995 .93386 m .48039 .93352 L .49012 .93401 L F
.48548 .9314 m .47219 .93151 L .48039 .93352 L 0 1 .541 r
F
.49271 .92455 m .48307 .92985 L .48548 .9314 L 0 1 .493 r
F
.4927 .92839 m .48307 .92985 L .48548 .9314 L 0 1 .541 r
F
.48307 .92985 m .47219 .93151 L .485 .9314 L F
.48307 .92985 m .47277 .93249 L .47216 .93585 L 0 1 .493 r
F
.48307 .92985 m .47279 .92924 L .47219 .93151 L 0 1 .541 r
F
.49271 .92455 m .48191 .92885 L .48307 .92985 L 0 1 .493 r
F
.4927 .92839 m .48191 .92885 L .48307 .92985 L 0 1 .541 r
F
.48191 .92885 m .47279 .92924 L .48307 .92985 L F
.48191 .92885 m .48184 .92888 L .48307 .92985 L 0 1 .493 r
F
.48184 .92888 m .47277 .93249 L .48307 .92985 L F
.48307 .92985 m .485 .9314 L .48548 .9314 L 0 1 .541 r
F
.48307 .92985 m .48301 .92988 L .48548 .9314 L 0 1 .493 r
F
.48548 .9314 m .47216 .93585 L .48038 .93622 L F
.48301 .92988 m .47216 .93585 L .48548 .9314 L F
.48548 .9314 m .48038 .93622 L .48995 .93386 L F
.48548 .9314 m .48995 .93386 L .49193 .93336 L F
.4862 .93109 m .48548 .9314 L .48995 .93386 L 0 1 .541 r
F
.4927 .92839 m .4862 .93109 L .49193 .93393 L F
.4862 .93109 m .48995 .93386 L .49193 .93393 L F
.49015 .93401 m .48995 .93386 L .49012 .93401 L 0 1 .498 r
F
.48995 .93386 m .48038 .93622 L .49012 .93401 L F
.49193 .93393 m .48995 .93386 L .49012 .93401 L 0 1 .54 r
F
0 g
.47128 .93495 m
.47236 .93478 L
s
.70617 .45832 m .7091 .46702 L .7135 .47752 L 0 0 .097 r
F
.70617 .45832 m .70596 .45881 L .7091 .46702 L F
0 g
.70515 .46334 m
.7091 .46702 L
s
.70596 .45881 m
.7087 .46599 L
s
.7087 .46599 m
.70888 .46645 L
s
.70888 .46645 m
.7091 .46702 L
s
.70269 .45046 m
.70596 .45881 L
s
.38154 .87917 m .36184 .87859 L .35963 .88107 L 0 1 .53 r
F
.38154 .87917 m .37124 .87778 L .36184 .87859 L F
.38641 .87273 m .37124 .87778 L .38154 .87917 L F
0 g
.38154 .87917 m
.39062 .87826 L
s
.38154 .87917 m
.38788 .88217 L
s
.492 .93337 m
.50044 .93382 L
s
.49201 .93332 m
.50072 .92853 L
s
.73502 .60389 m .74539 .60704 L .74118 .60131 L 0 .782 .395 r
F
.73502 .60389 m .7454 .61796 L .74539 .60704 L F
.41974 .86127 m .42435 .86637 L .42579 .86364 L 0 1 .527 r
F
.41974 .86127 m .41583 .86802 L .42435 .86637 L F
0 g
.42435 .86637 m
.43098 .86828 L
s
.43208 .93366 m .42054 .93133 L .41081 .93134 L 0 1 .535 r
F
.43494 .92781 m .43208 .93366 L .44149 .93366 L F
.43494 .92781 m .42054 .93133 L .43208 .93366 L F
0 g
.43208 .93366 m
.43996 .93719 L
s
.67025 .3899 m .67753 .43754 L .67306 .41987 L 0 .885 .131 r
F
.67025 .3899 m .68149 .4363 L .67753 .43754 L F
.67025 .3899 m .68228 .41704 L .68149 .4363 L F
.51674 .39269 m .51902 .38233 L .52117 .36192 L 0 1 .206 r
F
0 g
.51947 .37807 m
.52117 .36192 L
s
.52117 .36192 m
.5224 .36652 L
s
.4927 .92839 m .49193 .93393 L .50071 .93259 L 0 1 .541 r
F
0 g
.49193 .93393 m
.4999 .93582 L
s
.43494 .92781 m .44149 .93366 L .44251 .93131 L 0 1 .535 r
F
.4632 .93211 m .44251 .93131 L .44149 .93366 L 0 1 .538 r
F
0 g
.44149 .93366 m
.44958 .93649 L
s
.43208 .93366 m
.44149 .93366 L
s
.49601 .84311 m .48668 .84444 L .47923 .84744 L 0 1 .526 r
F
.49679 .83706 m .49601 .84311 L .50314 .84038 L 0 1 .528 r
F
.49679 .83706 m .48668 .84444 L .49601 .84311 L F
0 g
.49601 .84311 m
.50286 .84388 L
s
.61921 .30771 m
.6201 .31825 L
s
.61917 .31461 m
.6192 .30985 L
s
.6192 .30985 m
.61921 .30771 L
s
.69444 .43724 m .69848 .43516 L .70295 .44816 L 0 .623 .055 r
F
.69444 .43724 m .69484 .43048 L .69848 .43516 L F
0 g
.69502 .42636 m
.69848 .43516 L
s
.69837 .43502 m
.69848 .43516 L
s
.69829 .43492 m
.69837 .43502 L
s
.69484 .43048 m
.69829 .43492 L
s
.69185 .41411 m
.69484 .43048 L
s
.71608 .48897 m .71511 .49368 L .71859 .50544 L 0 .162 .237 r
F
0 g
.71759 .50208 m
.71807 .50368 L
s
.71511 .49368 m
.71759 .50208 L
s
.46314 .94029 m .47063 .94409 L .47124 .94082 L 0 1 .505 r
F
.46314 .94029 m .4613 .94829 L .47063 .94409 L F
0 g
.47063 .94409 m
.47917 .94453 L
s
.71608 .48897 m .71859 .50544 L .72421 .51644 L 0 .162 .237 r
F
0 g
.71309 .50316 m
.71859 .50544 L
s
.71807 .50368 m
.71859 .50544 L
s
.47278 .84601 m .45484 .85216 L .4613 .85358 L 0 1 .524 r
F
0 g
.45329 .85629 m
.4613 .85358 L
s
.41583 .86802 m .39704 .86908 L .39521 .87171 L 0 1 .527 r
F
.41583 .86802 m .40589 .8675 L .39704 .86908 L F
.41974 .86127 m .40589 .8675 L .41583 .86802 L F
0 g
.41583 .86802 m
.4222 .87044 L
s
.41583 .86802 m
.42435 .86637 L
s
.73254 .56682 m .73484 .59237 L .74033 .59104 L 0 .602 .378 r
F
0 g
.73484 .59237 m
.73502 .60389 L
s
.63899 .42086 m
.64128 .44037 L
s
.63817 .41387 m
.63899 .42086 L
s
.63649 .3996 m
.63817 .41387 L
s
.63673 .40444 m
.6369 .40785 L
s
.63779 .42596 m
.638 .43021 L
s
.638 .43021 m
.63844 .43913 L
s
.6369 .40785 m
.63718 .41355 L
s
.63718 .41355 m
.63779 .42596 L
s
.63939 .45848 m
.63942 .45901 L
s
.6386 .4424 m
.63863 .44303 L
s
.63942 .45901 m
.63978 .46623 L
s
.63649 .3996 m
.63673 .40444 L
s
.49679 .83706 m .50314 .84038 L .50332 .83806 L 0 1 .528 r
F
0 g
.49601 .84311 m
.50314 .84038 L
s
.50314 .84038 m
.50775 .84043 L
s
.3504 .88128 m .33412 .88498 L .34461 .88732 L 0 1 .533 r
F
0 g
.34461 .88732 m
.35412 .88723 L
s
.7746 .678 m
.77483 .67663 L
s
.50091 .92493 m
.50511 .92247 L
s
.72701 .52998 m .72699 .5477 L .73141 .55501 L 0 .354 .342 r
F
.72701 .52998 m .72511 .53699 L .72699 .5477 L F
0 g
.72164 .54897 m
.72699 .5477 L
s
.72511 .53699 m
.72699 .5477 L
s
.4613 .94829 m .43976 .95464 L .43873 .95762 L 0 1 .509 r
F
.4613 .94829 m .44944 .95063 L .43976 .95464 L F
.46314 .94029 m .44944 .95063 L .4613 .94829 L 0 1 .505 r
F
0 g
.4613 .94829 m
.46972 .94893 L
s
.4613 .94829 m
.47063 .94409 L
s
.4927 .92839 m .50071 .93259 L .5009 .9304 L 0 1 .541 r
F
0 g
.50071 .93259 m
.50926 .93355 L
s
.49193 .93393 m
.50071 .93259 L
s
.447 .85439 m .42796 .85955 L .43427 .86145 L 0 1 .525 r
F
0 g
.42579 .86364 m
.43427 .86145 L
s
.43494 .92781 m .41295 .92782 L .42054 .93133 L 0 1 .535 r
F
0 g
.41081 .93134 m
.42054 .93133 L
s
.49679 .83706 m .48015 .84344 L .48668 .84444 L 0 1 .528 r
F
0 g
.47923 .84744 m
.48668 .84444 L
s
.52866 .49416 m .53515 .39834 L .53355 .39854 L 0 .913 .252 r
F
0 g
.53162 .39405 m
.53369 .36757 L
s
.52866 .49416 m .53471 .42805 L .53515 .39834 L 0 .913 .252 r
F
0 g
.53515 .39834 m
.53595 .38781 L
s
.53168 .50229 m .53749 .40087 L .53471 .42805 L 0 .885 .251 r
F
0 g
.53749 .40087 m
.53795 .36114 L
s
.40352 .92723 m .38078 .92578 L .3881 .92989 L 0 1 .532 r
F
0 g
.52026 .90713 m
.52033 .90713 L
s
.47124 .94082 m
.48038 .93622 L
s
.4632 .93211 m .45182 .93065 L .44251 .93131 L 0 1 .538 r
F
.46503 .9264 m .4632 .93211 L .47219 .93151 L F
.46503 .9264 m .45182 .93065 L .4632 .93211 L F
0 g
.4632 .93211 m
.47128 .93495 L
s
.6573 .43565 m .66627 .38761 L .66905 .43662 L 0 .76 .193 r
F
0 g
.66627 .38761 m
.67025 .3899 L
s
.52866 .49416 m .53355 .39854 L .53098 .42649 L 0 .913 .252 r
F
0 g
.53317 .4027 m
.53355 .39854 L
s
.53355 .39854 m
.53369 .36757 L
s
.53168 .50229 m .53823 .43784 L .53901 .40444 L 0 .885 .251 r
F
0 g
.53901 .40444 m
.53984 .39327 L
s
.77036 .66347 m
.77144 .66301 L
s
.52554 .92774 m
.5291 .92815 L
s
.5291 .92815 m
.53007 .92772 L
s
.39129 .86625 m .39521 .87171 L .39704 .86908 L 0 1 .53 r
F
.39129 .86625 m .38641 .87273 L .39521 .87171 L F
0 g
.39521 .87171 m
.4016 .87413 L
s
.46503 .9264 m .47219 .93151 L .47279 .92924 L 0 1 .538 r
F
0 g
.4632 .93211 m
.47219 .93151 L
s
.47219 .93151 m
.47408 .93197 L
s
.43182 .9538 m .43873 .95762 L .43976 .95464 L 0 1 .513 r
F
.43182 .9538 m .42895 .96111 L .43873 .95762 L F
0 g
.43873 .95762 m
.44718 .95825 L
s
.46503 .9264 m .44404 .92782 L .45182 .93065 L 0 1 .538 r
F
0 g
.44251 .93131 m
.45182 .93065 L
s
.3562 .87521 m .35963 .88107 L .36184 .87859 L 0 1 .533 r
F
.3562 .87521 m .3504 .88128 L .35963 .88107 L F
0 g
.35963 .88107 m
.36601 .88406 L
s
.50332 .83806 m
.50992 .8356 L
s
.74343 .58303 m .74118 .60131 L .74539 .60704 L 0 .631 .39 r
F
.74343 .58303 m .74033 .59104 L .74118 .60131 L F
0 g
.73502 .60389 m
.74118 .60131 L
s
.7454 .61796 m .75593 .6206 L .75171 .6153 L 0 .806 .405 r
F
.73254 .56682 m .74244 .57205 L .73803 .56545 L 0 .602 .378 r
F
.73254 .56682 m .74343 .58303 L .74244 .57205 L F
.73254 .56682 m .74033 .59104 L .74343 .58303 L F
0 g
.73484 .59237 m
.74033 .59104 L
s
.74033 .59104 m
.74118 .60131 L
s
.38641 .87273 m .36516 .87486 L .37124 .87778 L 0 1 .53 r
F
0 g
.36184 .87859 m
.37124 .87778 L
s
.4499 .84749 m .45484 .85216 L .45588 .8494 L 0 1 .524 r
F
.4499 .84749 m .447 .85439 L .45484 .85216 L F
.47278 .84601 m .45588 .8494 L .45484 .85216 L F
0 g
.45484 .85216 m
.4613 .85358 L
s
.77099 .67069 m
.77153 .66313 L
s
.51815 .3368 m .51602 .34519 L .51587 .34749 L 0 0 0 r
F
.51815 .3368 m .51887 .33047 L .51602 .34519 L F
.51744 .35704 m .51815 .3368 L .51564 .35473 L 0 1 .124 r
F
.4935 .91537 m .50119 .91941 L .50137 .91565 L 0 1 .487 r
F
.4935 .91537 m .49271 .92455 L .50119 .91941 L F
0 g
.50119 .91941 m
.50409 .9196 L
s
.50073 .93036 m
.5009 .9304 L
s
.5009 .9304 m
.5094 .92808 L
s
.41974 .86127 m .3998 .86513 L .40589 .8675 L 0 1 .527 r
F
0 g
.39704 .86908 m
.40589 .8675 L
s
.447 .85439 m .42941 .85681 L .42796 .85955 L 0 1 .525 r
F
.447 .85439 m .43757 .8546 L .42941 .85681 L F
.4499 .84749 m .43757 .8546 L .447 .85439 L 0 1 .524 r
F
0 g
.447 .85439 m
.45484 .85216 L
s
.447 .85439 m
.45329 .85629 L
s
.47278 .84601 m .46357 .84676 L .45588 .8494 L 0 1 .524 r
F
.47464 .83924 m .47278 .84601 L .48015 .84344 L F
.47464 .83924 m .46357 .84676 L .47278 .84601 L F
0 g
.47278 .84601 m
.47923 .84744 L
s
.72701 .52998 m .73141 .55501 L .73626 .55561 L 0 .354 .342 r
F
0 g
.73141 .55501 m
.73254 .56682 L
s
.52026 .90713 m
.52027 .90712 L
s
.52266 .90539 m
.5243 .90421 L
s
.49271 .92455 m .48094 .928 L .48191 .92885 L 0 1 .493 r
F
.4927 .92839 m .48159 .9279 L .48094 .928 L 0 1 .541 r
F
.48191 .92885 m .48094 .928 L .47279 .92924 L F
.4927 .92839 m .48094 .928 L .48191 .92885 L F
.49271 .92455 m .48159 .92764 L .48094 .928 L 0 1 .493 r
F
.48191 .92885 m .48094 .928 L .47277 .93249 L F
.4935 .91537 m .48159 .92764 L .49271 .92455 L 0 1 .487 r
F
0 g
.49271 .92455 m
.50119 .91941 L
s
.49271 .92455 m
.50091 .92493 L
s
.47464 .83924 m .48015 .84344 L .48076 .84077 L 0 1 .524 r
F
.49679 .83706 m .48076 .84077 L .48015 .84344 L 0 1 .528 r
F
0 g
.48015 .84344 m
.48668 .84444 L
s
.47278 .84601 m
.48015 .84344 L
s
.46314 .94029 m .4413 .95011 L .44944 .95063 L 0 1 .505 r
F
0 g
.43976 .95464 m
.44944 .95063 L
s
.60381 .28795 m .60822 .28886 L .61403 .30871 L 0 .871 .138 r
F
.38641 .87273 m .36738 .87237 L .36516 .87486 L 0 1 .53 r
F
.38641 .87273 m .37649 .87146 L .36738 .87237 L F
.39129 .86625 m .37649 .87146 L .38641 .87273 L F
0 g
.38641 .87273 m
.39521 .87171 L
s
.38641 .87273 m
.39245 .87564 L
s
.43182 .9538 m .4169 .96277 L .42895 .96111 L 0 1 .513 r
F
0 g
.42895 .96111 m
.43873 .95762 L
s
.4074 .92141 m .41295 .92782 L .41438 .92548 L 0 1 .532 r
F
.4074 .92141 m .40352 .92723 L .41295 .92782 L F
.43494 .92781 m .41438 .92548 L .41295 .92782 L 0 1 .535 r
F
0 g
.41295 .92782 m
.42054 .93133 L
s
.51744 .35704 m .51564 .35473 L .5155 .36211 L 0 1 .124 r
F
.51674 .39269 m .51744 .35704 L .51527 .37748 L 0 1 .206 r
F
.54595 .29011 m .55068 .27378 L .5554 .27276 L 0 .285 .16 r
F
.40352 .92723 m .3826 .92348 L .38078 .92578 L 0 1 .532 r
F
.40352 .92723 m .39236 .9241 L .3826 .92348 L F
.4074 .92141 m .39236 .9241 L .40352 .92723 L F
0 g
.40352 .92723 m
.41295 .92782 L
s
.40352 .92723 m
.41081 .93134 L
s
.52549 .49084 m .53109 .40083 L .5294 .40368 L 0 .941 .254 r
F
0 g
.52872 .38616 m
.52921 .38016 L
s
.52549 .49084 m .53098 .42649 L .53109 .40083 L 0 .941 .254 r
F
0 g
.53109 .40083 m
.53162 .39405 L
s
.53103 .41503 m
.53109 .40083 L
s
.68149 .4363 m .68623 .41456 L .69074 .4304 L 0 .824 .123 r
F
.68149 .4363 m .68228 .41704 L .68623 .41456 L F
0 g
.68316 .3976 m
.68623 .41456 L
s
.67943 .38737 m
.68228 .41704 L
s
.68228 .41704 m
.68623 .41456 L
s
.42365 .85448 m .42796 .85955 L .42941 .85681 L 0 1 .526 r
F
.42365 .85448 m .41974 .86127 L .42796 .85955 L F
0 g
.42796 .85955 m
.43427 .86145 L
s
.55028 .4696 m .55206 .36276 L .55008 .42386 L 0 1 .217 r
F
.54437 .48304 m .55008 .42386 L .55206 .36276 L 0 1 .218 r
F
0 g
.55155 .33548 m
.55206 .36276 L
s
.55206 .36276 m
.55427 .31821 L
s
.70617 .45832 m .7135 .47752 L .717 .48526 L 0 0 .097 r
F
0 g
.7135 .47752 m
.71365 .47786 L
s
.7135 .47752 m
.71608 .48896 L
s
.78673 .66531 m .78078 .68284 L .78474 .68686 L 0 .912 .442 r
F
.78673 .66531 m .78163 .67361 L .78078 .68284 L F
0 g
.77772 .68429 m
.78078 .68284 L
s
.77483 .67663 m
.78163 .67361 L
s
.78078 .68284 m
.78163 .67361 L
s
.56454 .50365 m
.56506 .501 L
s
.56423 .50524 m
.56454 .50365 L
s
.56381 .50737 m
.56423 .50524 L
s
.74343 .58303 m .74539 .60704 L .75101 .60555 L 0 .631 .39 r
F
0 g
.74539 .60704 m
.7454 .61796 L
s
.46499 .93208 m .47216 .93585 L .47277 .93249 L 0 1 .5 r
F
.46499 .93208 m .46314 .94029 L .47216 .93585 L F
0 g
.47216 .93585 m
.48038 .93622 L
s
.37597 .91886 m .38078 .92578 L .3826 .92348 L 0 1 .53 r
F
.37597 .91886 m .37113 .92456 L .38078 .92578 L F
0 g
.38078 .92578 m
.3881 .92989 L
s
.71608 .48897 m .72686 .50571 L .72111 .4941 L 0 .162 .237 r
F
.71608 .48897 m .73036 .51753 L .72686 .50571 L F
.71608 .48897 m .72926 .52164 L .73036 .51753 L F
.71608 .48897 m .72421 .51644 L .72926 .52164 L F
.43494 .92781 m .42381 .92548 L .41438 .92548 L 0 1 .535 r
F
.43781 .922 m .43494 .92781 L .44404 .92782 L F
.43781 .922 m .42381 .92548 L .43494 .92781 L F
0 g
.43494 .92781 m
.44251 .93131 L
s
.78673 .66531 m .78474 .68686 L .7917 .68368 L 0 .912 .442 r
F
0 g
.7829 .69648 m
.78474 .68686 L
s
.47279 .92924 m
.48094 .928 L
s
.3504 .88128 m .32815 .88149 L .33412 .88498 L 0 1 .533 r
F
.3504 .88128 m .33072 .87918 L .32815 .88149 L F
.3504 .88128 m .34027 .87909 L .33072 .87918 L F
.3562 .87521 m .34027 .87909 L .3504 .88128 L F
0 g
.3504 .88128 m
.35963 .88107 L
s
.3504 .88128 m
.35632 .88477 L
s
.72421 .51644 m
.72701 .52998 L
s
.7246 .51684 m
.72926 .52164 L
s
.72421 .51644 m
.7246 .51684 L
s
.50137 .91565 m
.50495 .91334 L
s
.41974 .86127 m .40165 .86248 L .3998 .86513 L 0 1 .527 r
F
.41974 .86127 m .4102 .86083 L .40165 .86248 L F
.42365 .85448 m .4102 .86083 L .41974 .86127 L 0 1 .526 r
F
0 g
.41974 .86127 m
.42579 .86364 L
s
.41974 .86127 m
.42796 .85955 L
s
.53175 .30676 m .54037 .28409 L .54152 .29454 L 0 .147 .122 r
F
.53175 .30676 m .5362 .28931 L .54037 .28409 L F
0 g
.54037 .28409 m
.54272 .26067 L
s
.5362 .28931 m
.53868 .27033 L
s
.5362 .28931 m
.54037 .28409 L
s
.53452 .51593 m .54121 .4135 L .53823 .43784 L 0 .85 .251 r
F
.53452 .51593 m .54264 .42202 L .54121 .4135 L F
0 g
.54121 .4135 m
.54135 .40456 L
s
.53481 .42139 m
.53515 .39834 L
s
.54595 .29011 m .5554 .27276 L .557 .28774 L 0 .285 .16 r
F
0 g
.5554 .27276 m
.55756 .24777 L
s
.55068 .27378 m
.5554 .27276 L
s
.43781 .922 m .44404 .92782 L .44507 .9255 L 0 1 .535 r
F
.46503 .9264 m .44507 .9255 L .44404 .92782 L 0 1 .538 r
F
0 g
.44404 .92782 m
.45182 .93065 L
s
.43494 .92781 m
.44404 .92782 L
s
.47464 .83924 m .45743 .84524 L .46357 .84676 L 0 1 .524 r
F
0 g
.45588 .8494 m
.46357 .84676 L
s
.37597 .91886 m .36005 .92063 L .37113 .92456 L 0 1 .53 r
F
0 g
.37113 .92456 m
.38078 .92578 L
s
.46314 .94029 m .44233 .94707 L .4413 .95011 L 0 1 .505 r
F
.46314 .94029 m .4517 .94285 L .44233 .94707 L F
.46499 .93208 m .4517 .94285 L .46314 .94029 L 0 1 .5 r
F
0 g
.46314 .94029 m
.47124 .94082 L
s
.46314 .94029 m
.47216 .93585 L
s
.49348 .92309 m .4927 .92839 L .50117 .92719 L 0 1 .542 r
F
.49348 .92309 m .48159 .9279 L .4927 .92839 L F
0 g
.4927 .92839 m
.50073 .93036 L
s
.49679 .83706 m .4879 .83803 L .48076 .84077 L 0 1 .528 r
F
0 g
.49679 .83706 m
.50332 .83806 L
s
.49776 .82929 m .49679 .83706 L .50363 .83409 L 0 1 .527 r
F
.49776 .82929 m .4879 .83803 L .49679 .83706 L F
0 g
.56134 .43074 m
.56135 .43065 L
s
.72701 .52998 m .73642 .53831 L .73186 .53053 L 0 .354 .342 r
F
.72701 .52998 m .73831 .54907 L .73642 .53831 L F
.72701 .52998 m .73626 .55561 L .73831 .54907 L F
.4499 .84749 m .43158 .85269 L .43757 .8546 L 0 1 .524 r
F
0 g
.42941 .85681 m
.43757 .8546 L
s
.48076 .84077 m
.4879 .83803 L
s
.47277 .93249 m
.48026 .92838 L
s
.48026 .92838 m
.48094 .928 L
s
.48094 .928 m
.48096 .92799 L
s
.4935 .91537 m .47691 .92543 L .48159 .92764 L 0 1 .487 r
F
.49348 .92309 m .47691 .92543 L .48159 .9279 L 0 1 .542 r
F
.47691 .92543 m .4737 .92588 L .47935 .92733 L F
.47691 .92543 m .47431 .92367 L .4737 .92588 L F
.4935 .91537 m .47491 .92365 L .47691 .92543 L 0 1 .487 r
F
.49348 .92309 m .47491 .92365 L .47691 .92543 L 0 1 .542 r
F
.47491 .92365 m .47431 .92367 L .47691 .92543 L F
.47491 .92365 m .47473 .92373 L .47691 .92543 L 0 1 .487 r
F
.47691 .92543 m .47431 .92392 L .4737 .92738 L F
.47473 .92373 m .47431 .92392 L .47691 .92543 L F
.47691 .92543 m .47935 .92733 L .48042 .9276 L 0 1 .542 r
F
.47691 .92543 m .48042 .9276 L .48159 .92764 L 0 1 .487 r
F
.47691 .92543 m .48042 .9276 L .48159 .9279 L 0 1 .542 r
F
.47691 .92543 m .4737 .92738 L .48042 .9276 L 0 1 .487 r
F
0 g
.48037 .9276 m
.48042 .9276 L
s
.48096 .92799 m
.48097 .92799 L
s
.48097 .92799 m
.48127 .92782 L
s
.48042 .9276 m
.48159 .9279 L
s
.48094 .928 m
.48159 .9279 L
s
.52549 .49084 m .5294 .40368 L .52707 .43094 L 0 .941 .254 r
F
0 g
.52755 .42534 m
.52894 .40911 L
s
.52894 .40911 m
.5294 .40368 L
s
.52921 .38016 m
.5294 .40368 L
s
.59848 .2865 m
.60046 .29929 L
s
.4074 .92141 m .38534 .92002 L .39236 .9241 L 0 1 .532 r
F
0 g
.3826 .92348 m
.39236 .9241 L
s
.43781 .922 m .41653 .92198 L .42381 .92548 L 0 1 .535 r
F
0 g
.41438 .92548 m
.42381 .92548 L
s
.62293 .38102 m
.62308 .38273 L
s
.62308 .38273 m
.62414 .39533 L
s
.62437 .39802 m
.62467 .4016 L
s
.62561 .4128 m
.62624 .42024 L
s
.62467 .4016 m
.62561 .4128 L
s
.69444 .43724 m .70295 .44816 L .70601 .46261 L 0 .623 .055 r
F
0 g
.70295 .44816 m
.70302 .44848 L
s
.49776 .82929 m .48179 .83623 L .4879 .83803 L 0 1 .527 r
F
.60381 .28795 m .60557 .3227 L .60266 .30238 L 0 .871 .138 r
F
.60381 .28795 m .61142 .34284 L .60557 .3227 L F
.60381 .28795 m .61629 .34923 L .61142 .34284 L F
.60381 .28795 m .61739 .33449 L .61629 .34923 L F
0 g
.61272 .34557 m
.61339 .36401 L
s
.6126 .31434 m
.61321 .32015 L
s
.61303 .30669 m
.61401 .32289 L
s
.60381 .28795 m .61403 .30871 L .61739 .33449 L 0 .871 .138 r
F
0 g
.61076 .29754 m
.61203 .30187 L
s
.60822 .28886 m
.61053 .29676 L
s
.61053 .29676 m
.61076 .29754 L
s
.61362 .297 m
.61476 .30565 L
s
.61203 .30187 m
.61319 .30585 L
s
.49776 .82929 m .50363 .83409 L .50386 .8311 L 0 1 .527 r
F
0 g
.49679 .83706 m
.50363 .83409 L
s
.50363 .83409 m
.51011 .8355 L
s
.7543 .59783 m .75171 .6153 L .75593 .6206 L 0 .664 .402 r
F
.7543 .59783 m .75101 .60555 L .75171 .6153 L F
0 g
.7454 .61796 m
.75171 .6153 L
s
.70617 .45832 m .7141 .4768 L .70965 .46602 L 0 0 .097 r
F
.70617 .45832 m .71725 .48506 L .7141 .4768 L F
.70617 .45832 m .717 .48526 L .71725 .48506 L F
0 g
.71365 .47786 m
.717 .48526 L
s
.70295 .44816 m
.70617 .45832 L
s
.52061 .42715 m .52241 .4215 L .52453 .3963 L 0 1 .245 r
F
.49348 .92309 m .50117 .92719 L .50136 .92511 L 0 1 .542 r
F
0 g
.4927 .92839 m
.50117 .92719 L
s
.50117 .92719 m
.5094 .92808 L
s
.52283 .89424 m
.52435 .89298 L
s
.39619 .85972 m .3998 .86513 L .40165 .86248 L 0 1 .529 r
F
.39619 .85972 m .39129 .86625 L .3998 .86513 L F
0 g
.3998 .86513 m
.40589 .8675 L
s
.61476 .30567 m .61739 .33449 L .61403 .30871 L 0 .621 .044 r
F
0 g
.61441 .30714 m
.61441 .3071 L
s
.61416 .30815 m
.61441 .30714 L
s
.61403 .30871 m
.61416 .30815 L
s
.61319 .30585 m
.61403 .30871 L
s
.61476 .30567 m .62346 .3708 L .61739 .33449 L 0 .621 .044 r
F
0 g
.61441 .3071 m
.61476 .30567 L
s
.61623 .34914 m
.61674 .354 L
s
.62065 .35397 m
.62293 .38102 L
s
.6191 .32724 m
.61911 .32652 L
s
.61911 .32622 m
.61911 .32579 L
s
.61911 .32652 m
.61911 .32622 L
s
.61911 .32579 m
.61917 .31461 L
s
.62151 .33487 m
.62267 .3485 L
s
.62131 .33244 m
.62151 .33487 L
s
.62114 .3305 m
.62123 .33151 L
s
.62123 .33151 m
.62131 .33244 L
s
.6201 .31825 m
.62114 .3305 L
s
.62082 .36326 m
.62208 .39086 L
s
.6204 .35401 m
.62066 .35961 L
s
.62066 .35961 m
.62082 .36326 L
s
.6203 .3519 m
.6204 .35401 L
s
.61512 .36871 m
.61559 .37661 L
s
.36201 .86909 m .36516 .87486 L .36738 .87237 L 0 1 .532 r
F
.36201 .86909 m .3562 .87521 L .36516 .87486 L F
0 g
.36516 .87486 m
.37124 .87778 L
s
.51604 .44231 m .51902 .38233 L .51674 .39269 L 0 1 .249 r
F
.51604 .44231 m .52029 .39155 L .51902 .38233 L F
0 g
.51902 .38233 m
.51947 .37807 L
s
.54437 .48304 m .5489 .3594 L .54561 .4104 L 0 1 .218 r
F
.4943 .90578 m .50166 .90986 L .50184 .90591 L 0 1 .479 r
F
.4943 .90578 m .4935 .91537 L .50166 .90986 L F
0 g
.50166 .90986 m
.50509 .91009 L
s
.46503 .9264 m .45406 .92489 L .44507 .9255 L 0 1 .538 r
F
.46686 .92081 m .46503 .9264 L .4737 .92588 L F
.46686 .92081 m .45406 .92489 L .46503 .9264 L F
0 g
.46503 .9264 m
.47279 .92924 L
s
.43471 .94636 m .4413 .95011 L .44233 .94707 L 0 1 .51 r
F
.43471 .94636 m .43182 .9538 L .4413 .95011 L F
0 g
.4413 .95011 m
.44944 .95063 L
s
.56266 .41839 m .5719 .37135 L .5724 .39396 L 0 .167 .147 r
F
0 g
.56656 .3833 m
.5688 .3719 L
s
.56489 .39175 m
.56656 .3833 L
s
.56485 .39196 m
.56489 .39175 L
s
.56432 .39027 m
.56474 .38486 L
s
.56474 .38486 m
.56528 .37784 L
s
.5719 .37135 m
.575 .33277 L
s
.73831 .54907 m .73803 .56545 L .74244 .57205 L 0 .384 .356 r
F
.73831 .54907 m .73626 .55561 L .73803 .56545 L F
0 g
.73254 .56682 m
.73803 .56545 L
s
.73626 .55561 m
.73803 .56545 L
s
.73141 .55501 m
.73626 .55561 L
s
.39129 .86625 m .37071 .86862 L .37649 .87146 L 0 1 .53 r
F
0 g
.36738 .87237 m
.37649 .87146 L
s
.43182 .9538 m .40892 .96195 L .4169 .96277 L 0 1 .513 r
F
.54972 .3198 m .54969 .33841 L .54816 .34086 L 0 0 .102 r
F
.54972 .3198 m .55388 .31554 L .54969 .33841 L F
.54573 .35001 m .54972 .3198 L .5459 .35124 L 0 0 .003 r
F
0 g
.5459 .35124 m
.54656 .34583 L
s
.54959 .32155 m
.54972 .3198 L
s
.54916 .32737 m
.54959 .32155 L
s
.4935 .91537 m .47485 .92359 L .47491 .92365 L 0 1 .487 r
F
.49348 .92309 m .48279 .92247 L .47485 .92359 L 0 1 .542 r
F
.47491 .92365 m .47485 .92359 L .47431 .92367 L F
.49348 .92309 m .47485 .92359 L .47491 .92365 L F
.4935 .91537 m .48281 .91877 L .47485 .92359 L 0 1 .487 r
F
.47491 .92365 m .47485 .92359 L .47431 .92392 L F
.4943 .90578 m .48281 .91877 L .4935 .91537 L 0 1 .479 r
F
0 g
.4935 .91537 m
.50166 .90986 L
s
.4935 .91537 m
.50137 .91565 L
s
.42365 .85448 m .40442 .8585 L .4102 .86083 L 0 1 .526 r
F
0 g
.40165 .86248 m
.4102 .86083 L
s
.52344 .88539 m
.52344 .88539 L
s
.7543 .59783 m .75593 .6206 L .76168 .61893 L 0 .664 .402 r
F
0 g
.75586 .62438 m
.75593 .6206 L
s
.45281 .84052 m .45743 .84524 L .45847 .84245 L 0 1 .523 r
F
.45281 .84052 m .4499 .84749 L .45743 .84524 L F
.47464 .83924 m .45847 .84245 L .45743 .84524 L 0 1 .524 r
F
0 g
.45743 .84524 m
.46357 .84676 L
s
.37597 .91886 m .35339 .91601 L .36005 .92063 L 0 1 .53 r
F
.54189 .41286 m .54476 .39259 L .54824 .35442 L 0 1 .132 r
F
0 g
.54586 .38058 m
.54824 .35442 L
s
.54471 .43915 m
.54572 .38573 L
s
.54824 .35442 m
.5489 .3594 L
s
.54781 .37638 m
.5489 .3594 L
s
.46686 .92081 m .4737 .92588 L .47431 .92367 L 0 1 .538 r
F
0 g
.46503 .9264 m
.4737 .92588 L
s
.4737 .92588 m
.47395 .92594 L
s
.39129 .86625 m .37293 .86612 L .37071 .86862 L 0 1 .53 r
F
.39129 .86625 m .38176 .8651 L .37293 .86612 L F
.39619 .85972 m .38176 .8651 L .39129 .86625 L 0 1 .529 r
F
0 g
.39129 .86625 m
.3998 .86513 L
s
.39129 .86625 m
.39704 .86908 L
s
.46686 .92081 m .44661 .92203 L .45406 .92489 L 0 1 .538 r
F
0 g
.44507 .9255 m
.45406 .92489 L
s
.46499 .93208 m .44388 .94245 L .4517 .94285 L 0 1 .5 r
F
0 g
.44233 .94707 m
.4517 .94285 L
s
.4499 .84749 m .43303 .84994 L .43158 .85269 L 0 1 .524 r
F
.4499 .84749 m .44089 .8477 L .43303 .84994 L F
.45281 .84052 m .44089 .8477 L .4499 .84749 L 0 1 .523 r
F
0 g
.4499 .84749 m
.45743 .84524 L
s
.4499 .84749 m
.45588 .8494 L
s
.53452 .51593 m .54154 .4581 L .54264 .42202 L 0 .85 .251 r
F
0 g
.5421 .43987 m
.54264 .42202 L
s
.54264 .42202 m
.54448 .39897 L
s
.53827 .43629 m
.53858 .42302 L
s
.53858 .42302 m
.53901 .40444 L
s
.74343 .58303 m .75346 .58751 L .74906 .58151 L 0 .631 .39 r
F
.74343 .58303 m .7543 .59783 L .75346 .58751 L F
.74343 .58303 m .75101 .60555 L .7543 .59783 L F
0 g
.74539 .60704 m
.75101 .60555 L
s
.75101 .60555 m
.75171 .6153 L
s
.43182 .9538 m .41036 .95918 L .40892 .96195 L 0 1 .513 r
F
.43182 .9538 m .42019 .95568 L .41036 .95918 L F
.43471 .94636 m .42019 .95568 L .43182 .9538 L 0 1 .51 r
F
0 g
.43182 .9538 m
.4413 .95011 L
s
.43182 .9538 m
.43976 .95464 L
s
.47464 .83924 m .46585 .83987 L .45847 .84245 L 0 1 .524 r
F
0 g
.47464 .83924 m
.48076 .84077 L
s
.47692 .8307 m .47464 .83924 L .48179 .83623 L 0 1 .523 r
F
.47692 .8307 m .46585 .83987 L .47464 .83924 L F
0 g
.50184 .90591 m
.50367 .90459 L
s
.50616 .9028 m
.50741 .90189 L
s
.50213 .89984 m
.50484 .89998 L
s
.52061 .42715 m .52029 .39155 L .5197 .41427 L 0 1 .245 r
F
.51604 .44231 m .5197 .41427 L .52029 .39155 L 0 1 .249 r
F
0 g
.51902 .38233 m
.52029 .39155 L
s
.52029 .39155 m
.52199 .37139 L
s
.46684 .92365 m .4737 .92738 L .47431 .92392 L 0 1 .495 r
F
.46684 .92365 m .46499 .93208 L .4737 .92738 L F
0 g
.4737 .92738 m
.48037 .9276 L
s
.56317 .5142 m
.56423 .51289 L
s
.42758 .84764 m .43158 .85269 L .43303 .84994 L 0 1 .526 r
F
.42758 .84764 m .42365 .85448 L .43158 .85269 L F
0 g
.43158 .85269 m
.43757 .8546 L
s
.3562 .87521 m .33458 .87571 L .34027 .87909 L 0 1 .533 r
F
.3562 .87521 m .33716 .87338 L .33458 .87571 L F
.3562 .87521 m .34643 .87317 L .33716 .87338 L F
.36201 .86909 m .34643 .87317 L .3562 .87521 L 0 1 .532 r
F
0 g
.3562 .87521 m
.36516 .87486 L
s
.3562 .87521 m
.36184 .87859 L
s
.41128 .91559 m .41653 .92198 L .41797 .91964 L 0 1 .532 r
F
.41128 .91559 m .4074 .92141 L .41653 .92198 L F
.43781 .922 m .41797 .91964 L .41653 .92198 L 0 1 .535 r
F
0 g
.41653 .92198 m
.42381 .92548 L
s
.4074 .92141 m .38717 .91772 L .38534 .92002 L 0 1 .532 r
F
.4074 .92141 m .39663 .91831 L .38717 .91772 L F
.41128 .91559 m .39663 .91831 L .4074 .92141 L F
0 g
.4074 .92141 m
.41653 .92198 L
s
.4074 .92141 m
.41438 .92548 L
s
.50136 .92511 m
.50954 .92294 L
s
.78673 .66531 m .7917 .68368 L .79703 .67538 L 0 .912 .442 r
F
0 g
.78474 .68686 m
.7917 .68368 L
s
.51887 .33047 m .5164 .34617 L .51625 .34463 L 0 0 .048 r
F
0 g
.51711 .34167 m
.51815 .3368 L
s
.51887 .33047 m .51961 .33482 L .5164 .34617 L 0 0 .048 r
F
.51887 .33047 m .52373 .31821 L .51961 .33482 L F
.47692 .8307 m .48179 .83623 L .48255 .83285 L 0 1 .523 r
F
.49776 .82929 m .48255 .83285 L .48179 .83623 L 0 1 .527 r
F
0 g
.48179 .83623 m
.4879 .83803 L
s
.47464 .83924 m
.48179 .83623 L
s
.38083 .91316 m .38534 .92002 L .38717 .91772 L 0 1 .53 r
F
.38083 .91316 m .37597 .91886 L .38534 .92002 L F
0 g
.38534 .92002 m
.39236 .9241 L
s
.51054 .38965 m .5155 .36211 L .51564 .35473 L 0 1 .136 r
F
0 g
.51686 .3625 m
.51744 .35704 L
s
.51054 .38965 m .51331 .37705 L .5155 .36211 L 0 1 .136 r
F
0 g
.5155 .36211 m
.51744 .35704 L
s
.50386 .8311 m
.50826 .82963 L
s
.51054 .38965 m .51564 .35473 L .51334 .35987 L 0 1 .136 r
F
0 g
.51669 .36408 m
.51686 .3625 L
s
.51564 .35473 m
.51727 .3431 L
s
.42365 .85448 m .40626 .85584 L .40442 .8585 L 0 1 .526 r
F
.42365 .85448 m .41452 .85411 L .40626 .85584 L F
.42758 .84764 m .41452 .85411 L .42365 .85448 L F
0 g
.42365 .85448 m
.42941 .85681 L
s
.42365 .85448 m
.43158 .85269 L
s
.32557 .87535 m .32815 .88149 L .33072 .87918 L 0 1 .535 r
F
0 g
.33072 .87918 m
.34027 .87909 L
s
.32557 .87535 m .31888 .88098 L .32815 .88149 L 0 1 .535 r
F
0 g
.32815 .88149 m
.33412 .88498 L
s
.52219 .49149 m .52683 .40925 L .52508 .41383 L 0 .969 .257 r
F
.52219 .49149 m .52707 .43094 L .52683 .40925 L F
0 g
.52683 .40925 m
.52872 .38616 L
s
.52683 .40925 m
.52688 .41386 L
s
.73831 .54907 m .74244 .57205 L .7474 .57235 L 0 .384 .356 r
F
0 g
.74244 .57205 m
.74343 .58303 L
s
.46499 .93208 m .44492 .93935 L .44388 .94245 L 0 1 .5 r
F
.46499 .93208 m .45397 .9349 L .44492 .93935 L F
.46684 .92365 m .45397 .9349 L .46499 .93208 L 0 1 .495 r
F
0 g
.46499 .93208 m
.47277 .93249 L
s
.46499 .93208 m
.4737 .92738 L
s
.56432 .39027 m
.56485 .39196 L
s
.37597 .91886 m .3556 .91378 L .35339 .91601 L 0 1 .53 r
F
.37597 .91886 m .36528 .91501 L .3556 .91378 L F
.38083 .91316 m .36528 .91501 L .37597 .91886 L F
0 g
.37597 .91886 m
.38534 .92002 L
s
.37597 .91886 m
.3826 .92348 L
s
.45847 .84245 m
.46585 .83987 L
s
.43781 .922 m .42709 .91965 L .41797 .91964 L 0 1 .535 r
F
.44068 .91622 m .43781 .922 L .44661 .92203 L 0 1 .534 r
F
.44068 .91622 m .42709 .91965 L .43781 .922 L F
0 g
.43781 .922 m
.44507 .9255 L
s
.47431 .92392 m
.47445 .92383 L
s
.47445 .92383 m
.47468 .92369 L
s
.47468 .92369 m
.47485 .92359 L
s
.4943 .90578 m .47524 .91865 L .48281 .91877 L 0 1 .479 r
F
0 g
.47485 .92359 m
.48281 .91877 L
s
.47692 .8307 m .46021 .83773 L .46585 .83987 L 0 1 .523 r
F
.56193 .28983 m .56687 .2776 L .57214 .28295 L 0 .476 .173 r
F
0 g
.56687 .2776 m
.56897 .25253 L
s
.56835 .2791 m
.56906 .26623 L
s
.47431 .92367 m
.47485 .92359 L
s
.45281 .84052 m .43521 .84578 L .44089 .8477 L 0 1 .523 r
F
0 g
.43303 .84994 m
.44089 .8477 L
s
.44068 .91622 m .44661 .92203 L .44763 .91973 L 0 1 .534 r
F
.46686 .92081 m .44763 .91973 L .44661 .92203 L 0 1 .538 r
F
0 g
.44661 .92203 m
.45406 .92489 L
s
.43781 .922 m
.44661 .92203 L
s
.59805 .46203 m
.59954 .48738 L
s
.51961 .33482 m .52727 .31004 L .52791 .31568 L 0 0 .084 r
F
.51961 .33482 m .52373 .31821 L .52727 .31004 L F
0 g
.52727 .31004 m
.52979 .29093 L
s
.52373 .31821 m
.52632 .30419 L
s
.52373 .31821 m
.52727 .31004 L
s
.56246 .53592 m
.56269 .53525 L
s
.73036 .51754 m .73186 .53053 L .73642 .53831 L 0 .181 .247 r
F
.73036 .51754 m .72926 .52164 L .73186 .53053 L F
0 g
.72701 .52998 m
.73186 .53053 L
s
.72926 .52164 m
.73165 .5298 L
s
.73165 .5298 m
.73186 .53053 L
s
.50028 .90124 m
.50213 .89984 L
s
.77796 .65393 m
.77894 .65349 L
s
.41128 .91559 m .38992 .91426 L .39663 .91831 L 0 1 .532 r
F
0 g
.38717 .91772 m
.39663 .91831 L
s
.49426 .91807 m .49348 .92309 L .50163 .9221 L 0 1 .542 r
F
.49426 .91807 m .48279 .92247 L .49348 .92309 L F
0 g
.49348 .92309 m
.50136 .92511 L
s
.36785 .86294 m .37071 .86862 L .37293 .86612 L 0 1 .532 r
F
.36785 .86294 m .36201 .86909 L .37071 .86862 L F
0 g
.37071 .86862 m
.37649 .87146 L
s
.4011 .85315 m .40442 .8585 L .40626 .85584 L 0 1 .528 r
F
.4011 .85315 m .39619 .85972 L .40442 .8585 L F
0 g
.40442 .8585 m
.4102 .86083 L
s
.51011 .37414 m .51587 .34749 L .51602 .34519 L 0 .778 .076 r
F
.51011 .37414 m .51334 .35987 L .51587 .34749 L F
0 g
.51587 .34749 m
.51632 .34537 L
s
.51373 .37419 m
.5155 .36211 L
s
.51674 .39269 m .51527 .37748 L .51513 .39062 L 0 1 .206 r
F
.51098 .41771 m .51527 .37748 L .51331 .37705 L 0 1 .214 r
F
.51098 .41771 m .51513 .39062 L .51527 .37748 L F
0 g
.51527 .37748 m
.51669 .36408 L
s
.5134 .37707 m
.51527 .37748 L
s
.40299 .9581 m .40892 .96195 L .41036 .95918 L 0 1 .514 r
F
.40299 .9581 m .39909 .96486 L .40892 .96195 L F
0 g
.40892 .96195 m
.4169 .96277 L
s
.44068 .91622 m .42013 .91615 L .42709 .91965 L 0 1 .534 r
F
0 g
.41797 .91964 m
.42709 .91965 L
s
.34969 .90873 m .35339 .91601 L .3556 .91378 L 0 1 .529 r
F
.34969 .90873 m .34389 .91422 L .35339 .91601 L F
0 g
.35339 .91601 m
.36005 .92063 L
s
.69444 .43724 m .70193 .46416 L .69747 .45167 L 0 .623 .055 r
F
.69444 .43724 m .7056 .46885 L .70193 .46416 L F
.69444 .43724 m .70601 .46261 L .7056 .46885 L F
.39619 .85972 m .37627 .86234 L .38176 .8651 L 0 1 .529 r
F
0 g
.37293 .86612 m
.38176 .8651 L
s
.4943 .90578 m .47585 .91509 L .47524 .91865 L 0 1 .479 r
F
.4943 .90578 m .48403 .90957 L .47585 .91509 L F
0 g
.4943 .90578 m
.50184 .90591 L
s
.4943 .90578 m
.50028 .90124 L
s
.56328 .52435 m
.5635 .52343 L
s
.56031 .53663 m
.56113 .53325 L
s
.56199 .52971 m
.56316 .52484 L
s
.56113 .53325 m
.56145 .53192 L
s
.56153 .53159 m
.56199 .52971 L
s
.56316 .52484 m
.56328 .52435 L
s
.43761 .93878 m .44388 .94245 L .44492 .93935 L 0 1 .505 r
F
.43761 .93878 m .43471 .94636 L .44388 .94245 L F
0 g
.44388 .94245 m
.4517 .94285 L
s
.49426 .91807 m .47523 .92039 L .48279 .92247 L 0 1 .542 r
F
0 g
.47485 .92359 m
.48279 .92247 L
s
.49776 .82929 m .4894 .82988 L .48255 .83285 L 0 1 .527 r
F
0 g
.48255 .83285 m
.4894 .82988 L
s
.49776 .82929 m
.50386 .8311 L
s
.55818 .32707 m .56748 .29486 L .56949 .30552 L 0 .224 .149 r
F
.55818 .32707 m .56265 .30404 L .56748 .29486 L F
0 g
.56748 .29486 m
.56798 .28575 L
s
.56615 .29739 m
.56748 .29486 L
s
.43471 .94636 m .41252 .95498 L .42019 .95568 L 0 1 .51 r
F
0 g
.41036 .95918 m
.42019 .95568 L
s
.50232 .89569 m
.50365 .89457 L
s
.5059 .8927 m
.50769 .89121 L
s
.50376 .88934 m
.5054 .88936 L
s
.32557 .87535 m .30906 .87799 L .31888 .88098 L 0 1 .535 r
F
0 g
.31888 .88098 m
.32815 .88149 L
s
.49851 .82281 m .49776 .82929 L .50417 .82695 L 0 1 .523 r
F
.49851 .82281 m .4894 .82988 L .49776 .82929 L F
.71725 .48507 m .72111 .4941 L .72686 .50571 L 0 0 .104 r
F
.71725 .48507 m .717 .48527 L .72111 .4941 L F
0 g
.71608 .48897 m
.72111 .4941 L
s
.717 .48527 m
.72066 .49313 L
s
.72066 .49313 m
.72086 .49356 L
s
.72086 .49356 m
.72111 .4941 L
s
.5214 .85882 m
.5214 .85882 L
s
.52219 .49149 m .52508 .41383 L .523 .43955 L 0 .969 .257 r
F
0 g
.52487 .41643 m
.52508 .41383 L
s
.52453 .3963 m
.52508 .41383 L
s
.52264 .41885 m
.52453 .3963 L
s
.51604 .44231 m .51674 .39269 L .51491 .4144 L 0 1 .249 r
F
0 g
.51638 .39696 m
.51674 .39269 L
s
.49809 .89574 m
.50232 .89569 L
s
.42758 .84764 m .40904 .85182 L .41452 .85411 L 0 1 .526 r
F
0 g
.40626 .85584 m
.41452 .85411 L
s
.68149 .4363 m .69074 .4304 L .69346 .45456 L 0 .824 .123 r
F
0 g
.69074 .4304 m
.69444 .43724 L
s
.39619 .85972 m .3785 .85981 L .37627 .86234 L 0 1 .529 r
F
.39619 .85972 m .38705 .85869 L .3785 .85981 L F
.4011 .85315 m .38705 .85869 L .39619 .85972 L 0 1 .528 r
F
0 g
.39619 .85972 m
.40442 .8585 L
s
.39619 .85972 m
.40165 .86248 L
s
.7543 .59783 m .76168 .61893 L .76515 .61138 L 0 .664 .402 r
F
0 g
.76168 .61893 m
.76193 .62315 L
s
.75593 .6206 m
.76168 .61893 L
s
.49426 .91807 m .50163 .9221 L .50182 .92015 L 0 1 .542 r
F
0 g
.49348 .92309 m
.50163 .9221 L
s
.50163 .9221 m
.50954 .92294 L
s
.46684 .92365 m .44647 .93464 L .45397 .9349 L 0 1 .495 r
F
0 g
.44492 .93935 m
.45397 .9349 L
s
.38083 .91316 m .35891 .91044 L .36528 .91501 L 0 1 .53 r
F
0 g
.3556 .91378 m
.36528 .91501 L
s
.46686 .92081 m .45632 .91921 L .44763 .91973 L 0 1 .538 r
F
.34969 .90873 m .33342 .90959 L .34389 .91422 L 0 1 .529 r
F
0 g
.34389 .91422 m
.35339 .91601 L
s
.46871 .91499 m .46851 .91591 L .47524 .91865 L 0 1 .488 r
F
.46851 .91591 m .46686 .92081 L .47205 .92055 L 0 1 .538 r
F
.46851 .91591 m .46684 .92365 L .47205 .92055 L 0 1 .488 r
F
.46851 .91591 m .47205 .92055 L .47524 .91865 L F
.46871 .91532 m .46851 .91591 L .47523 .92039 L 0 1 .538 r
F
.46851 .91591 m .47205 .92055 L .47523 .92039 L F
0 g
.46975 .92192 m
.47431 .92367 L
s
.46849 .91595 m .45632 .91921 L .46686 .92081 L 0 1 .538 r
F
.46851 .91591 m .46847 .91592 L .46849 .91595 L F
.46847 .91592 m .45632 .91921 L .46849 .91595 L F
.46818 .91549 m .45632 .91921 L .46851 .91591 L F
.46818 .91549 m .44907 .92667 L .45625 .92676 L 0 1 .488 r
F
.46805 .91528 m .45858 .9136 L .45021 .91402 L 0 1 .538 r
F
.46871 .91499 m .46809 .91535 L .46818 .91549 L 0 1 .488 r
F
.46871 .91532 m .46801 .91521 L .46805 .91528 L 0 1 .538 r
F
.46801 .91521 m .45858 .9136 L .46805 .91528 L F
.46815 .9155 m .44918 .9163 L .45632 .91921 L F
.46871 .91499 m .46818 .91549 L .46851 .91591 L 0 1 .488 r
F
.46871 .91532 m .46809 .91535 L .46815 .9155 L 0 1 .538 r
F
.46809 .91535 m .44918 .9163 L .46815 .9155 L F
.46809 .91535 m .45012 .92344 L .44907 .92667 L 0 1 .488 r
F
.46871 .91499 m .46806 .91528 L .46809 .91535 L F
.46809 .91535 m .45021 .91402 L .44918 .9163 L 0 1 .538 r
F
.46871 .91532 m .46807 .91528 L .46809 .91535 L F
.46807 .91528 m .45021 .91402 L .46809 .91535 L F
.46807 .91528 m .45854 .91843 L .45012 .92344 L 0 1 .488 r
F
.46871 .91499 m .47524 .91865 L .47585 .91509 L F
.47058 .90612 m .46871 .91499 L .47678 .90967 L 0 1 .48 r
F
.47058 .90612 m .46525 .91156 L .46871 .91499 L F
.46525 .91156 m .45858 .9136 L .46757 .91513 L 0 1 .537 r
F
.46525 .91156 m .46757 .91513 L .46805 .91521 L F
.46525 .91156 m .45168 .91856 L .45854 .91843 L 0 1 .48 r
F
.46525 .91156 m .45176 .91061 L .45858 .9136 L 0 1 .537 r
F
.47058 .90612 m .46443 .91016 L .46525 .91156 L 0 1 .48 r
F
.47055 .90994 m .46443 .91016 L .46525 .91156 L 0 1 .537 r
F
.46443 .91016 m .45176 .91061 L .46495 .91154 L F
.46443 .91016 m .45273 .91527 L .45168 .91856 L 0 1 .48 r
F
.46443 .91016 m .45279 .90835 L .45176 .91061 L 0 1 .537 r
F
.47058 .90612 m .46422 .90937 L .46443 .91016 L 0 1 .48 r
F
.47055 .90994 m .46422 .90937 L .46443 .91016 L 0 1 .537 r
F
.46422 .90937 m .45279 .90835 L .46443 .91016 L F
.46422 .90937 m .46415 .90941 L .46443 .91016 L 0 1 .48 r
F
.46415 .90941 m .45273 .91527 L .46443 .91016 L F
.46443 .91016 m .46495 .91154 L .46525 .91156 L 0 1 .537 r
F
.46443 .91016 m .46437 .9102 L .46525 .91156 L 0 1 .48 r
F
.46437 .9102 m .45168 .91856 L .46525 .91156 L F
.46525 .91156 m .45854 .91843 L .46805 .91521 L F
.46525 .91156 m .46805 .91521 L .46871 .91499 L F
.46616 .91128 m .46525 .91156 L .46805 .91521 L 0 1 .537 r
F
.47055 .90994 m .46616 .91128 L .46871 .91532 L F
.46871 .91499 m .46805 .91521 L .46808 .91527 L 0 1 .488 r
F
.46616 .91128 m .46805 .91521 L .46871 .91532 L 0 1 .537 r
F
.46808 .91527 m .46805 .91521 L .46807 .91528 L 0 1 .488 r
F
.46805 .91521 m .45854 .91843 L .46807 .91528 L F
.46806 .91528 m .45012 .92344 L .46809 .91535 L F
.46809 .91535 m .46809 .91536 L .46812 .9154 L F
.46809 .91535 m .46812 .9154 L .46818 .91549 L F
.46809 .91536 m .44907 .92667 L .46818 .91549 L F
.46851 .91591 m .45625 .92676 L .46684 .92365 L F
.46818 .91549 m .45625 .92676 L .46851 .91591 L F
.46871 .91532 m .46818 .91549 L .46851 .91591 L 0 1 .538 r
F
0 g
.44763 .91973 m
.45632 .91921 L
s
.53168 .50229 m .53471 .42805 L .53249 .46827 L 0 .885 .251 r
F
.52866 .49416 m .53249 .46827 L .53471 .42805 L 0 .913 .252 r
F
0 g
.53471 .42805 m
.53749 .40087 L
s
.53471 .42805 m
.53481 .42139 L
s
.78673 .66531 m .7979 .66611 L .79371 .66209 L 0 .912 .442 r
F
.78673 .66531 m .79703 .67538 L .7979 .66611 L F
0 g
.78673 .66531 m
.79371 .66209 L
s
.78673 .66531 m
.7872 .65898 L
s
.74959 .5661 m .74906 .58151 L .75346 .58751 L 0 .423 .37 r
F
.74959 .5661 m .7474 .57235 L .74906 .58151 L F
0 g
.74343 .58303 m
.74906 .58151 L
s
.49851 .82281 m .50417 .82695 L .50434 .8244 L 0 1 .523 r
F
0 g
.49776 .82929 m
.50417 .82695 L
s
.50417 .82695 m
.50832 .82829 L
s
.49851 .82281 m .48355 .82829 L .4894 .82988 L 0 1 .523 r
F
.43471 .94636 m .41397 .95217 L .41252 .95498 L 0 1 .51 r
F
.43471 .94636 m .42349 .94847 L .41397 .95217 L F
.43761 .93878 m .42349 .94847 L .43471 .94636 L 0 1 .505 r
F
0 g
.43471 .94636 m
.44388 .94245 L
s
.43471 .94636 m
.44233 .94707 L
s
.47192 .92062 m
.47205 .92055 L
s
.47396 .91941 m
.47524 .91865 L
s
.47524 .91865 m
.48281 .91877 L
s
.56134 .43074 m
.56135 .43054 L
s
.36201 .86909 m .34103 .86989 L .34643 .87317 L 0 1 .532 r
F
.36201 .86909 m .34362 .86755 L .34103 .86989 L F
.36201 .86909 m .35262 .86721 L .34362 .86755 L F
.36785 .86294 m .35262 .86721 L .36201 .86909 L F
0 g
.36201 .86909 m
.37071 .86862 L
s
.36201 .86909 m
.36738 .87237 L
s
.45281 .84052 m .43667 .84299 L .43521 .84578 L 0 1 .523 r
F
.45281 .84052 m .44422 .84073 L .43667 .84299 L F
0 g
.45281 .84052 m
.45847 .84245 L
s
.4564 .83178 m .45281 .84052 L .46021 .83773 L 0 1 .522 r
F
.4564 .83178 m .44422 .84073 L .45281 .84052 L F
0 g
.6126 .34438 m
.61276 .346 L
s
.61276 .346 m
.6131 .34922 L
s
.6131 .34922 m
.61351 .35319 L
s
.60907 .33952 m
.60919 .33515 L
s
.7543 .59783 m .76446 .60159 L .76006 .59612 L 0 .664 .402 r
F
.7543 .59783 m .76515 .61138 L .76446 .60159 L F
.73831 .54907 m .74782 .55622 L .74327 .54932 L 0 .384 .356 r
F
.73831 .54907 m .74959 .5661 L .74782 .55622 L F
.73831 .54907 m .7474 .57235 L .74959 .5661 L F
0 g
.74244 .57205 m
.7474 .57235 L
s
.7474 .57235 m
.74906 .58151 L
s
.4564 .83178 m .46021 .83773 L .46149 .83424 L 0 1 .522 r
F
.47692 .8307 m .46149 .83424 L .46021 .83773 L 0 1 .523 r
F
0 g
.46021 .83773 m
.46585 .83987 L
s
.45281 .84052 m
.46021 .83773 L
s
.40299 .9581 m .38739 .96598 L .39909 .96486 L 0 1 .514 r
F
0 g
.39909 .96486 m
.40892 .96195 L
s
.46096 .9896 m .45914 .99431 L .46881 .99575 L 0 1 .529 r
F
.46096 .9896 m .44685 .99053 L .45914 .99431 L F
.49095 .99739 m .47771 .99919 L .49018 1.00191 L 0 1 .531 r
F
.49095 .99739 m .46881 .99575 L .47771 .99919 L F
0 g
.56142 .4984 m
.56142 .50301 L
s
.56133 .41262 m
.56133 .41329 L
s
.56135 .42853 m
.56135 .43191 L
s
.56133 .41167 m
.56133 .41262 L
s
.56132 .40292 m
.56132 .40306 L
s
.56132 .40306 m
.56133 .40946 L
s
.56133 .40946 m
.56133 .41167 L
s
.56079 .41748 m
.5608 .41731 L
s
.55978 .44502 m
.56001 .43891 L
s
.5608 .41731 m
.56087 .41532 L
s
.56131 .40314 m
.56132 .40292 L
s
.56097 .4125 m
.56131 .40314 L
s
.56087 .41532 m
.56097 .4125 L
s
.54595 .29011 m .54434 .32127 L .54322 .31048 L 0 .285 .16 r
F
0 g
.54594 .29011 m
.54595 .2901 L
s
.54595 .29011 m .54911 .32026 L .54434 .32127 L 0 .285 .16 r
F
.54595 .29011 m .55432 .30811 L .54911 .32026 L F
0 g
.54656 .34583 m
.54972 .3198 L
s
.54595 .29011 m .557 .28774 L .55432 .30811 L 0 .285 .16 r
F
0 g
.54595 .29011 m
.54595 .29011 L
s
.58673 .28711 m
.58869 .29469 L
s
.58869 .29469 m
.5889 .29549 L
s
.5889 .29549 m
.5901 .30013 L
s
.58489 .31012 m
.58673 .28711 L
s
.46096 .9896 m .4384 .98625 L .44685 .99053 L 0 1 .529 r
F
.33227 .86967 m .33458 .87571 L .33716 .87338 L 0 1 .535 r
F
0 g
.33716 .87338 m
.34643 .87317 L
s
.33227 .86967 m .32557 .87535 L .33458 .87571 L 0 1 .535 r
F
0 g
.33458 .87571 m
.34027 .87909 L
s
.43152 .84072 m .43521 .84578 L .43667 .84299 L 0 1 .525 r
F
.43152 .84072 m .42758 .84764 L .43521 .84578 L F
0 g
.43521 .84578 m
.44089 .8477 L
s
.45459 .9185 m
.45632 .91921 L
s
.49095 .99739 m .49018 1.00191 L .49967 1.00262 L 0 1 .531 r
F
.52866 .49416 m .53098 .42649 L .52914 .4639 L 0 .913 .252 r
F
.52549 .49084 m .52914 .4639 L .53098 .42649 L 0 .941 .254 r
F
0 g
.53098 .42649 m
.53317 .4027 L
s
.53098 .42649 m
.53103 .41503 L
s
.64239 .44115 m
.64351 .44591 L
s
.64351 .44591 m
.64519 .45296 L
s
.64519 .45296 m
.64678 .45963 L
s
.53175 .30676 m .54152 .29454 L .53869 .31325 L 0 .147 .122 r
F
0 g
.54152 .29454 m
.54594 .29011 L
s
.46871 .91532 m .47523 .92039 L .47584 .91824 L 0 1 .538 r
F
.49426 .91807 m .47584 .91824 L .47523 .92039 L 0 1 .542 r
F
0 g
.47205 .92055 m
.47523 .92039 L
s
.47523 .92039 m
.48279 .92247 L
s
.54528 .35434 m
.54573 .35001 L
s
.54453 .36312 m
.54495 .35852 L
s
.51098 .41771 m .51331 .37705 L .51054 .38965 L 0 1 .214 r
F
0 g
.51331 .37705 m
.51373 .37419 L
s
.51331 .37705 m
.5134 .37707 L
s
.51011 .37414 m .51602 .34519 L .51337 .3545 L 0 .778 .076 r
F
0 g
.51352 .35899 m
.51587 .34749 L
s
.51395 .35851 m
.51564 .35473 L
s
.51602 .34519 m
.51887 .33047 L
s
.55388 .31554 m .55361 .34209 L .55203 .33893 L 0 .145 .133 r
F
.55388 .31554 m .55818 .32706 L .55361 .34209 L F
.55388 .31554 m .56265 .30404 L .55818 .32706 L F
0 g
.61911 .32725 m
.62215 .34541 L
s
.62215 .34541 m
.62219 .34565 L
s
.62219 .34565 m
.6235 .35347 L
s
.6235 .35347 m
.62416 .35743 L
s
.62416 .35743 m
.62516 .36334 L
s
.56193 .28983 m .57214 .28295 L .57427 .30241 L 0 .476 .173 r
F
0 g
.56265 .30404 m
.56361 .29154 L
s
.56265 .30404 m
.56615 .29739 L
s
.57214 .28295 m
.57405 .26021 L
s
.56687 .2776 m
.57214 .28295 L
s
.46684 .92365 m .44751 .93147 L .44647 .93464 L 0 1 .495 r
F
.46684 .92365 m .45625 .92676 L .44751 .93147 L F
0 g
.46684 .92365 m
.47192 .92062 L
s
.46684 .92365 m
.47431 .92392 L
s
.73036 .51754 m .73642 .53831 L .74075 .54125 L 0 .181 .247 r
F
0 g
.73642 .53831 m
.73831 .54907 L
s
.41128 .91559 m .39176 .91196 L .38992 .91426 L 0 1 .532 r
F
.41128 .91559 m .40092 .91253 L .39176 .91196 L F
.41518 .90979 m .41128 .91559 L .42013 .91615 L 0 1 .531 r
F
.41518 .90979 m .40092 .91253 L .41128 .91559 L F
0 g
.41128 .91559 m
.41797 .91964 L
s
.5923 .30281 m .597 .29391 L .60266 .30238 L 0 .662 .166 r
F
0 g
.597 .29391 m
.599 .2969 L
s
.59804 .29546 m
.59848 .2865 L
s
.47678 .91446 m
.48403 .90957 L
s
.47585 .91509 m
.47678 .91446 L
s
.41518 .90979 m .42013 .91615 L .42157 .91382 L 0 1 .531 r
F
.44068 .91622 m .42157 .91382 L .42013 .91615 L 0 1 .534 r
F
0 g
.42013 .91615 m
.42709 .91965 L
s
.41128 .91559 m
.42013 .91615 L
s
.51098 .41771 m .51329 .40786 L .51513 .39062 L 0 1 .214 r
F
0 g
.51336 .4072 m
.51513 .39062 L
s
.51513 .39062 m
.51674 .39269 L
s
.38571 .90744 m .38992 .91426 L .39176 .91196 L 0 1 .529 r
F
.38571 .90744 m .38083 .91316 L .38992 .91426 L F
0 g
.38992 .91426 m
.39663 .91831 L
s
.4315 .97929 m .42864 .98418 L .4384 .98625 L 0 1 .525 r
F
.4315 .97929 m .41665 .97948 L .42864 .98418 L F
.42758 .84764 m .4109 .84913 L .40904 .85182 L 0 1 .526 r
F
.42758 .84764 m .41885 .84734 L .4109 .84913 L F
.43152 .84072 m .41885 .84734 L .42758 .84764 L 0 1 .525 r
F
0 g
.42758 .84764 m
.43303 .84994 L
s
.42758 .84764 m
.43521 .84578 L
s
.79703 .67538 m
.7979 .66611 L
s
.51054 .38965 m .51334 .35987 L .51011 .37414 L 0 1 .136 r
F
0 g
.51334 .35987 m
.51395 .35851 L
s
.51334 .35987 m
.51352 .35899 L
s
.38083 .91316 m .36113 .90821 L .35891 .91044 L 0 1 .53 r
F
.38083 .91316 m .37053 .90937 L .36113 .90821 L F
.38571 .90744 m .37053 .90937 L .38083 .91316 L 0 1 .529 r
F
0 g
.38083 .91316 m
.38992 .91426 L
s
.38083 .91316 m
.38717 .91772 L
s
.71222 .87587 m
.71281 .87577 L
s
.46882 .91499 m
.47585 .91509 L
s
.47692 .8307 m .46866 .83122 L .46149 .83424 L 0 1 .523 r
F
0 g
.47692 .8307 m
.48255 .83285 L
s
.47868 .82391 m .47693 .8307 L .48355 .82829 L 0 1 .52 r
F
.47868 .82391 m .46866 .83122 L .47693 .8307 L F
.53175 .30676 m .52953 .33304 L .52888 .32553 L 0 .147 .122 r
F
.53175 .30676 m .53375 .32776 L .52953 .33304 L F
.53175 .30676 m .53869 .31325 L .53375 .32776 L F
0 g
.53869 .31325 m
.54152 .29454 L
s
.50341 .82414 m
.50434 .8244 L
s
.50434 .8244 m
.51047 .82274 L
s
.4315 .97929 m .40872 .97447 L .41665 .97948 L 0 1 .525 r
F
.74959 .5661 m .75346 .58751 L .75851 .58747 L 0 .423 .37 r
F
0 g
.75346 .58751 m
.7543 .59783 L
s
.46096 .9896 m .46881 .99575 L .46941 .99389 L 0 1 .529 r
F
.49095 .99739 m .46941 .99389 L .46881 .99575 L 0 1 .531 r
F
0 g
.46881 .99575 m
.47771 .99919 L
s
.45914 .99431 m
.46881 .99575 L
s
.47868 .82391 m .48355 .82829 L .48413 .82559 L 0 1 .52 r
F
.49851 .82281 m .48413 .82559 L .48355 .82829 L 0 1 .523 r
F
0 g
.48355 .82829 m
.4894 .82988 L
s
.47693 .8307 m
.48355 .82829 L
s
.50182 .92015 m
.50447 .91951 L
s
.50507 .91936 m
.50969 .91824 L
s
.43667 .84299 m
.44422 .84073 L
s
.4564 .83178 m .4391 .83829 L .44422 .84073 L 0 1 .522 r
F
0 g
.52148 1.00658 m
.52579 1.0065 L
s
.4315 .97929 m .4384 .98625 L .43941 .9843 L 0 1 .525 r
F
.46096 .9896 m .43941 .9843 L .4384 .98625 L 0 1 .529 r
F
0 g
.4384 .98625 m
.44685 .99053 L
s
.42864 .98418 m
.4384 .98625 L
s
.44068 .91622 m .43038 .91385 L .42157 .91382 L 0 1 .534 r
F
.44357 .91049 m .44068 .91622 L .44918 .9163 L F
.44357 .91049 m .43038 .91385 L .44068 .91622 L F
0 g
.44068 .91622 m
.44763 .91973 L
s
.3737 .85673 m .37627 .86234 L .3785 .85981 L 0 1 .531 r
F
.3737 .85673 m .36785 .86294 L .37627 .86234 L F
0 g
.37627 .86234 m
.38176 .8651 L
s
.7056 .46885 m .70965 .46602 L .7141 .4768 L 0 .556 .048 r
F
.7056 .46885 m .70601 .46261 L .70965 .46602 L F
0 g
.70617 .45832 m
.70965 .46602 L
s
.70961 .46598 m
.70965 .46602 L
s
.70958 .46595 m
.70961 .46598 L
s
.70601 .46261 m
.70958 .46595 L
s
.70302 .44848 m
.70601 .46261 L
s
.53452 .51593 m .53823 .43784 L .53566 .47923 L 0 .85 .251 r
F
.53168 .50229 m .53566 .47923 L .53823 .43784 L 0 .885 .251 r
F
0 g
.53823 .43784 m
.54121 .4135 L
s
.53823 .43784 m
.53827 .43629 L
s
.46149 .83424 m
.46866 .83122 L
s
.49094 .99965 m .49016 1.00655 L .49967 1.00431 L 0 1 .529 r
F
0 g
.49018 1.00191 m
.49068 1.00195 L
s
.49094 .99965 m .47766 1.00676 L .49016 1.00655 L 0 1 .529 r
F
.49095 .99739 m .49967 1.00262 L .49986 1.00084 L 0 1 .531 r
F
0 g
.49599 1.00234 m
.49967 1.00262 L
s
.49967 1.00262 m
.49978 1.00265 L
s
.40603 .84652 m .40904 .85182 L .4109 .84913 L 0 1 .528 r
F
.40603 .84652 m .4011 .85315 L .40904 .85182 L F
0 g
.40904 .85182 m
.41452 .85411 L
s
.56031 .53663 m
.56097 .53641 L
s
.56165 .53619 m
.56246 .53592 L
s
.32557 .87535 m .30386 .87415 L .30906 .87799 L 0 1 .535 r
F
.32557 .87535 m .30678 .87202 L .30386 .87415 L F
.32557 .87535 m .31609 .87254 L .30678 .87202 L F
.33227 .86967 m .31609 .87254 L .32557 .87535 L F
0 g
.32557 .87535 m
.33458 .87571 L
s
.32557 .87535 m
.33072 .87918 L
s
.4011 .85315 m .38185 .85601 L .38705 .85869 L 0 1 .528 r
F
0 g
.3785 .85981 m
.38705 .85869 L
s
.44357 .91049 m .44918 .9163 L .45021 .91402 L 0 1 .534 r
F
0 g
.44068 .91622 m
.44918 .9163 L
s
.44918 .9163 m
.45203 .91746 L
s
.41518 .90979 m .39451 .9085 L .40092 .91253 L 0 1 .531 r
F
0 g
.39176 .91196 m
.40092 .91253 L
s
.3555 .90322 m .35891 .91044 L .36113 .90821 L 0 1 .528 r
F
.3555 .90322 m .34969 .90873 L .35891 .91044 L F
0 g
.35891 .91044 m
.36528 .91501 L
s
.4069 .95123 m .41252 .95498 L .41397 .95217 L 0 1 .51 r
F
.4069 .95123 m .40299 .9581 L .41252 .95498 L F
0 g
.41252 .95498 m
.42019 .95568 L
s
.49426 .91807 m .484 .91724 L .47584 .91824 L 0 1 .542 r
F
.34969 .90873 m .32747 .90453 L .33342 .90959 L 0 1 .529 r
F
.44051 .93106 m .44647 .93464 L .44751 .93147 L 0 1 .499 r
F
.44051 .93106 m .43761 .93878 L .44647 .93464 L F
0 g
.44647 .93464 m
.45397 .9349 L
s
.51604 .44231 m .51788 .43607 L .5197 .41427 L 0 1 .249 r
F
0 g
.5559 .4549 m
.5559 .45679 L
s
.5559 .45679 m
.5559 .45791 L
s
.5559 .45791 m
.5559 .46009 L
s
.5559 .4544 m
.5559 .4549 L
s
.5559 .45321 m
.5559 .45397 L
s
.5559 .45397 m
.5559 .4544 L
s
.55589 .44959 m
.5559 .45321 L
s
.55589 .44499 m
.55589 .44959 L
s
.55588 .43285 m
.55589 .44499 L
s
.55028 .4696 m .55256 .46847 L .55586 .40069 L 0 1 .217 r
F
0 g
.55356 .44798 m
.55586 .40069 L
s
.55586 .40069 m
.55588 .43285 L
s
.47868 .82391 m .46319 .82955 L .46866 .83122 L 0 1 .52 r
F
.40284 .96684 m .39897 .97183 L .40872 .97447 L F
.40284 .96684 m .38738 .96632 L .39897 .97183 L F
.5188 .49529 m .52241 .4215 L .52061 .42715 L 0 .999 .26 r
F
.5188 .49529 m .523 .43955 L .52241 .4215 L F
0 g
.52241 .4215 m
.52264 .41885 L
s
.52642 .91642 m
.52692 .91632 L
s
.49094 .99965 m .49967 1.00431 L .49985 1.00152 L 0 1 .529 r
F
0 g
.49016 1.00655 m
.49967 1.00431 L
s
.49967 1.00431 m
.50894 1.00608 L
s
.43761 .93878 m .41614 .94792 L .42349 .94847 L 0 1 .505 r
F
0 g
.41397 .95217 m
.42349 .94847 L
s
.44357 .91049 m .42373 .91033 L .43038 .91385 L 0 1 .534 r
F
0 g
.42157 .91382 m
.43038 .91385 L
s
.5088 .91814 m
.50969 .91824 L
s
.49094 .99965 m .46874 1.00489 L .47766 1.00676 L 0 1 .529 r
F
.43152 .84072 m .41369 .84508 L .41885 .84734 L 0 1 .525 r
F
0 g
.4109 .84913 m
.41885 .84734 L
s
.4011 .85315 m .38409 .85346 L .38185 .85601 L 0 1 .528 r
F
.4011 .85315 m .39235 .85223 L .38409 .85346 L F
.40603 .84652 m .39235 .85223 L .4011 .85315 L F
0 g
.4011 .85315 m
.40904 .85182 L
s
.4011 .85315 m
.40626 .85584 L
s
.49851 .82281 m .49054 .82324 L .48413 .82559 L 0 1 .523 r
F
0 g
.48311 .82528 m
.48413 .82559 L
s
.49925 .81564 m .49851 .82281 L .50461 .82034 L 0 1 .517 r
F
.49925 .81564 m .49054 .82324 L .49851 .82281 L F
0 g
.49851 .82281 m
.50341 .82414 L
s
.51961 .33482 m .52791 .31568 L .52496 .33115 L 0 0 .084 r
F
0 g
.52791 .31568 m
.53175 .30676 L
s
.44751 .93147 m
.45625 .92676 L
s
.40284 .96684 m .40872 .97447 L .41015 .97248 L 0 1 .52 r
F
.4315 .97929 m .41015 .97248 L .40872 .97447 L 0 1 .525 r
F
0 g
.40872 .97447 m
.41665 .97948 L
s
.39897 .97183 m
.40872 .97447 L
s
.36785 .86294 m .3475 .86403 L .35262 .86721 L 0 1 .532 r
F
.34969 .90873 m .33005 .9024 L .32747 .90453 L 0 1 .529 r
F
.34969 .90873 m .33958 .90421 L .33005 .9024 L F
.3555 .90322 m .33958 .90421 L .34969 .90873 L 0 1 .528 r
F
0 g
.34969 .90873 m
.3556 .91378 L
s
.34969 .90873 m
.35891 .91044 L
s
.36785 .86294 m .35009 .86167 L .3475 .86403 L 0 1 .532 r
F
.36785 .86294 m .35882 .8612 L .35009 .86167 L F
.3737 .85673 m .35882 .8612 L .36785 .86294 L 0 1 .531 r
F
0 g
.36785 .86294 m
.37627 .86234 L
s
.36785 .86294 m
.37293 .86612 L
s
.47058 .90612 m .47678 .90967 L .4774 .90601 L 0 1 .48 r
F
0 g
.47678 .90967 m
.48403 .90957 L
s
.49504 .91335 m .49426 .91807 L .5021 .91735 L 0 1 .541 r
F
.49504 .91335 m .484 .91724 L .49426 .91807 L F
0 g
.49426 .91807 m
.50182 .92015 L
s
.79366 .65855 m
.79371 .66209 L
s
.52549 .49084 m .52707 .43094 L .52562 .46472 L 0 .941 .254 r
F
.52219 .49149 m .52562 .46472 L .52707 .43094 L 0 .969 .257 r
F
0 g
.52707 .43094 m
.52755 .42534 L
s
.52688 .41386 m
.52707 .43094 L
s
.38571 .90744 m .36445 .90485 L .37053 .90937 L 0 1 .529 r
F
0 g
.36113 .90821 m
.37053 .90937 L
s
.76515 .61138 m .77544 .61447 L .77105 .60946 L 0 .699 .413 r
F
.49095 .99739 m .4789 .99459 L .46941 .99389 L 0 1 .531 r
F
.33899 .86396 m .34103 .86989 L .34362 .86755 L 0 1 .534 r
F
0 g
.34362 .86755 m
.35262 .86721 L
s
.33899 .86396 m .33227 .86967 L .34103 .86989 L 0 1 .534 r
F
0 g
.34103 .86989 m
.34643 .87317 L
s
.6605 .86129 m
.66052 .86127 L
s
.40299 .9581 m .38749 .96269 L .38739 .96598 L 0 1 .514 r
F
.40284 .96684 m .38749 .96269 L .38738 .96632 L 0 1 .52 r
F
.38749 .96269 m .38005 .96068 L .38655 .96568 L F
.38749 .96269 m .3818 .96236 L .37996 .96492 L 0 1 .514 r
F
.38749 .96269 m .38188 .95867 L .38005 .96068 L 0 1 .52 r
F
.40299 .9581 m .3881 .9611 L .38749 .96269 L 0 1 .514 r
F
.40284 .96684 m .3881 .9611 L .38749 .96269 L 0 1 .52 r
F
.3881 .9611 m .38188 .95867 L .38749 .96269 L F
.3881 .9611 m .38797 .96112 L .38749 .96269 L 0 1 .514 r
F
.38797 .96112 m .3818 .96236 L .38749 .96269 L F
.38749 .96269 m .38655 .96568 L .38685 .96591 L 0 1 .52 r
F
.38749 .96269 m .38685 .96591 L .38739 .96598 L 0 1 .514 r
F
.38749 .96269 m .38685 .96591 L .38738 .96632 L 0 1 .52 r
F
.38749 .96269 m .37996 .96492 L .38685 .96591 L 0 1 .514 r
F
.43761 .93878 m .41759 .94506 L .41614 .94792 L 0 1 .505 r
F
.43761 .93878 m .4268 .94114 L .41759 .94506 L F
.44051 .93106 m .4268 .94114 L .43761 .93878 L 0 1 .499 r
F
0 g
.43761 .93878 m
.44647 .93464 L
s
.43761 .93878 m
.44492 .93935 L
s
.49504 .91335 m .47675 .91504 L .484 .91724 L 0 1 .541 r
F
0 g
.47584 .91824 m
.484 .91724 L
s
.46885 .91489 m
.47678 .90967 L
s
.71725 .48507 m .72686 .50571 L .73141 .51427 L 0 0 .104 r
F
0 g
.72686 .50571 m
.72704 .50605 L
s
.72686 .50571 m
.73036 .51753 L
s
.38685 .96591 m
.38738 .96632 L
s
.46096 .9896 m .44909 .98574 L .43941 .9843 L 0 1 .529 r
F
.73036 .51754 m .73934 .52844 L .73467 .52043 L 0 .181 .247 r
F
.73036 .51754 m .74194 .53737 L .73934 .52844 L F
.73036 .51754 m .74075 .54125 L .74194 .53737 L F
.49925 .81564 m .50461 .82034 L .50478 .81747 L 0 1 .517 r
F
0 g
.49851 .82281 m
.50461 .82034 L
s
.50461 .82034 m
.51047 .82274 L
s
.49925 .81564 m .485 .82142 L .49054 .82324 L 0 1 .517 r
F
0 g
.48413 .82559 m
.49054 .82324 L
s
.64128 .44037 m
.64162 .44305 L
s
.64162 .44305 m
.64274 .45179 L
s
.76085 .58138 m .76006 .59612 L .76446 .60159 L 0 .468 .385 r
F
.76085 .58138 m .75851 .58747 L .76006 .59612 L F
0 g
.7543 .59783 m
.76006 .59612 L
s
.49823 .88312 m
.49996 .88143 L
s
.40299 .9581 m .38836 .96042 L .3881 .9611 L 0 1 .514 r
F
.40284 .96684 m .39165 .96131 L .38836 .96042 L 0 1 .52 r
F
.3881 .9611 m .38836 .96042 L .38188 .95867 L F
.40284 .96684 m .38836 .96042 L .3881 .9611 L F
.40299 .9581 m .39168 .95944 L .38836 .96042 L 0 1 .514 r
F
.3881 .9611 m .38836 .96042 L .3818 .96236 L F
.4069 .95123 m .39168 .95944 L .40299 .9581 L 0 1 .51 r
F
0 g
.40299 .9581 m
.41036 .95918 L
s
.40299 .9581 m
.41252 .95498 L
s
.50516 .87167 m
.50715 .86926 L
s
.59035 .30044 m
.5923 .3028 L
s
.5901 .30013 m
.59035 .30044 L
s
.58685 .29619 m
.5901 .30013 L
s
.64091 .46465 m
.64095 .46507 L
s
.64088 .46413 m
.64091 .46465 L
s
.47801 .90555 m
.48439 .90071 L
s
.4774 .90601 m
.47801 .90555 L
s
.45021 .91402 m
.45571 .91374 L
s
.55818 .32707 m .56949 .30552 L .56734 .327 L 0 .224 .149 r
F
.56193 .28983 m .56105 .32401 L .55942 .3097 L 0 .476 .173 r
F
.55818 .32707 m .56734 .327 L .56241 .34504 L 0 .224 .149 r
F
.56193 .28983 m .56637 .32949 L .56105 .32401 L 0 .476 .173 r
F
.56241 .34504 m .56734 .327 L .57254 .3218 L 0 .264 .149 r
F
.56193 .28983 m .57181 .32241 L .56637 .32949 L 0 .476 .173 r
F
.56193 .28983 m .57427 .30241 L .57181 .32241 L F
0 g
.557 .28774 m
.56193 .28983 L
s
.5923 .30281 m .60266 .30238 L .60557 .3227 L 0 .662 .166 r
F
0 g
.60266 .30238 m
.60381 .28795 L
s
.599 .2969 m
.60266 .30238 L
s
.50269 1.00078 m
.5027 1.00078 L
s
.49986 1.00084 m
.50269 1.00078 L
s
.62869 .42092 m
.6287 .42091 L
s
.47055 .90994 m .46871 .91532 L .47675 .91504 L 0 1 .537 r
F
0 g
.46871 .91532 m
.47584 .91824 L
s
.43639 .83208 m .4391 .83829 L .4409 .8348 L 0 1 .523 r
F
.43639 .83208 m .43152 .84072 L .4391 .83829 L F
.4564 .83178 m .4409 .8348 L .4391 .83829 L 0 1 .522 r
F
0 g
.4391 .83829 m
.44422 .84073 L
s
.49985 1.00152 m
.50212 1.00093 L
s
.50212 1.00093 m
.5027 1.00078 L
s
.5027 1.00078 m
.50908 .99912 L
s
.74194 .53737 m .74327 .54932 L .74782 .55622 L 0 .211 .264 r
F
.74194 .53737 m .74075 .54125 L .74327 .54932 L F
0 g
.73831 .54907 m
.74327 .54932 L
s
.74075 .54125 m
.74311 .54882 L
s
.74311 .54882 m
.74327 .54932 L
s
.73642 .53831 m
.74075 .54125 L
s
.60064 .44004 m .60257 .3885 L .60776 .41071 L 0 .825 .204 r
F
0 g
.60257 .3885 m
.60608 .40353 L
s
.60161 .34316 m
.60257 .3885 L
s
.43152 .84072 m .41555 .84236 L .41369 .84508 L 0 1 .525 r
F
.43152 .84072 m .4232 .84049 L .41555 .84236 L F
0 g
.43152 .84072 m
.43667 .84299 L
s
.43639 .83208 m .4232 .84049 L .43152 .84072 L 0 1 .523 r
F
0 g
.43152 .84072 m
.4391 .83829 L
s
.45915 .82494 m .46319 .82955 L .46417 .82681 L 0 1 .52 r
F
.45915 .82494 m .4564 .83178 L .46319 .82955 L F
.47868 .82391 m .46417 .82681 L .46319 .82955 L F
0 g
.46319 .82955 m
.46866 .83122 L
s
.49504 .91335 m .5021 .91735 L .50228 .91555 L 0 1 .541 r
F
0 g
.49426 .91807 m
.5021 .91735 L
s
.5021 .91735 m
.50459 .91764 L
s
.46087 1.00013 m .45903 1.00679 L .46874 1.00489 L 0 1 .532 r
F
.46087 1.00013 m .44668 1.00663 L .45903 1.00679 L F
.4564 .83178 m .44832 .83201 L .4409 .8348 L 0 1 .522 r
F
0 g
.4564 .83178 m
.46149 .83424 L
s
.45915 .82494 m .44832 .83201 L .4564 .83178 L 0 1 .52 r
F
0 g
.4564 .83178 m
.46319 .82955 L
s
.3906 .90171 m .39451 .9085 L .39636 .90619 L 0 1 .529 r
F
.3906 .90171 m .38571 .90744 L .39451 .9085 L F
.41518 .90979 m .39636 .90619 L .39451 .9085 L 0 1 .531 r
F
0 g
.39451 .9085 m
.40092 .91253 L
s
.46087 1.00013 m .46874 1.00489 L .46935 1.00219 L 0 1 .532 r
F
.49094 .99965 m .46935 1.00219 L .46874 1.00489 L 0 1 .529 r
F
0 g
.46874 1.00489 m
.47766 1.00676 L
s
.45903 1.00679 m
.46874 1.00489 L
s
.66812 .47713 m .67306 .41987 L .67753 .43754 L 0 .72 .183 r
F
.66812 .47713 m .66905 .43662 L .67306 .41987 L F
0 g
.67025 .3899 m
.67306 .41987 L
s
.41518 .90979 m .40522 .90674 L .39636 .90619 L 0 1 .531 r
F
.4191 .90398 m .41518 .90979 L .42373 .91033 L 0 1 .53 r
F
.4191 .90398 m .40522 .90674 L .41518 .90979 L F
0 g
.41518 .90979 m
.42157 .91382 L
s
.51011 .37414 m .51337 .3545 L .50966 .36928 L 0 .778 .076 r
F
.50966 .36928 m .51625 .34463 L .5164 .34617 L 0 0 0 r
F
.50966 .36928 m .51337 .3545 L .51625 .34463 L F
0 g
.51625 .34463 m
.51887 .33047 L
s
.51337 .3545 m
.51602 .34519 L
s
.51419 .35166 m
.51625 .34463 L
s
.51337 .3545 m
.51419 .35166 L
s
.46279 .98501 m .46096 .9896 L .47032 .99114 L 0 1 .527 r
F
.46279 .98501 m .44909 .98574 L .46096 .9896 L F
0 g
.46096 .9896 m
.46941 .99389 L
s
.4315 .97929 m .41991 .97454 L .41015 .97248 L 0 1 .525 r
F
.4191 .90398 m .42373 .91033 L .42518 .908 L 0 1 .53 r
F
.44357 .91049 m .42518 .908 L .42373 .91033 L 0 1 .534 r
F
0 g
.42373 .91033 m
.43038 .91385 L
s
.41518 .90979 m
.42373 .91033 L
s
.46279 .98501 m .44095 .98142 L .44909 .98574 L 0 1 .527 r
F
0 g
.43941 .9843 m
.44909 .98574 L
s
.38571 .90744 m .36667 .90261 L .36445 .90485 L 0 1 .529 r
F
.38571 .90744 m .37579 .90372 L .36667 .90261 L F
.3906 .90171 m .37579 .90372 L .38571 .90744 L F
0 g
.38571 .90744 m
.39451 .9085 L
s
.38571 .90744 m
.39176 .91196 L
s
.47868 .82391 m .47081 .82439 L .46417 .82681 L 0 1 .52 r
F
.48043 .81678 m .47868 .82391 L .485 .82142 L 0 1 .516 r
F
.48043 .81678 m .47081 .82439 L .47868 .82391 L F
0 g
.47868 .82391 m
.48311 .82528 L
s
.49173 .99252 m .49158 .99383 L .50013 .99727 L 0 1 .526 r
F
.49156 .99404 m .4789 .99459 L .49095 .99739 L 0 1 .527 r
F
.49148 .99399 m .4789 .99459 L .49156 .99404 L F
.49154 .99396 m .4789 .99459 L .49157 .99398 L F
.49157 .99398 m .49148 .99399 L .49156 .99404 L F
.49157 .99396 m .49154 .99396 L .49157 .99398 L F
.49158 .99383 m .49157 .99396 L .49206 .99415 L 0 1 .526 r
F
.49158 .99383 m .49206 .99415 L .50013 .99727 L F
.49157 .99396 m .49747 .99796 L .50013 .99727 L F
.49173 .99309 m .49157 .99396 L .50013 .99823 L 0 1 .527 r
F
.49157 .99396 m .49095 .99739 L .49737 .99798 L F
.49157 .99396 m .49737 .99798 L .49747 .99796 L 0 1 .526 r
F
.49157 .99396 m .49737 .99798 L .50013 .99823 L 0 1 .527 r
F
.49157 .99396 m .49094 .99965 L .49737 .99798 L 0 1 .526 r
F
.49157 .99396 m .47887 .99994 L .49094 .99965 L F
.49173 .99252 m .49049 .99323 L .49157 .99396 L F
.49049 .99323 m .4789 .99459 L .49157 .99396 L 0 1 .527 r
F
.49049 .99323 m .47887 .99994 L .49157 .99396 L 0 1 .526 r
F
.4905 .99323 m .49049 .99323 L .49157 .99396 L 0 1 .527 r
F
.49049 .99323 m .47032 .99114 L .4789 .99459 L F
.49173 .99309 m .4901 .99294 L .49049 .99323 L F
.4901 .99294 m .47032 .99114 L .49049 .99323 L F
.49173 .99252 m .4901 .99294 L .49049 .99323 L 0 1 .526 r
F
.4901 .99294 m .49007 .99295 L .49049 .99323 L F
.49007 .99295 m .47088 .99531 L .47027 .99808 L F
.4901 .99294 m .47092 .98933 L .47032 .99114 L 0 1 .527 r
F
.49173 .99309 m .48991 .99276 L .4901 .99294 L F
.48991 .99276 m .47092 .98933 L .4901 .99294 L F
.4901 .99294 m .48984 .99277 L .49007 .99295 L 0 1 .526 r
F
.49173 .99252 m .48991 .99276 L .4901 .99294 L F
.48991 .99276 m .48984 .99277 L .4901 .99294 L F
.48984 .99277 m .47088 .99531 L .49007 .99295 L F
.49049 .99323 m .47027 .99808 L .47887 .99994 L F
.49007 .99295 m .47027 .99808 L .49049 .99323 L F
.49173 .99252 m .50013 .99727 L .50032 .99438 L F
.48991 .99276 m .4801 .99017 L .47092 .98933 L 0 1 .527 r
F
.48996 .99275 m .4899 .99275 L .48991 .99276 L 0 1 .526 r
F
.49173 .99309 m .48973 .99259 L .48991 .99276 L 0 1 .527 r
F
.48973 .99259 m .4801 .99017 L .48991 .99276 L F
.48991 .99276 m .48008 .99292 L .47088 .99531 L 0 1 .526 r
F
.4899 .99275 m .48008 .99292 L .48991 .99276 L F
.49173 .99252 m .48973 .99259 L .48996 .99275 L F
.48973 .99259 m .48008 .99292 L .48996 .99275 L F
.49252 .98512 m .49173 .99252 L .5006 .98996 L 0 1 .524 r
F
.49252 .98512 m .48522 .9897 L .49173 .99252 L F
.48859 .99186 m .4801 .99017 L .48967 .99257 L 0 1 .521 r
F
.48522 .9897 m .4801 .99017 L .48842 .99182 L F
.48522 .9897 m .48842 .99182 L .48859 .99186 L F
.48522 .9897 m .4718 .9911 L .48008 .99292 L 0 1 .524 r
F
.48522 .9897 m .47183 .98668 L .4801 .99017 L 0 1 .521 r
F
.49252 .98512 m .48279 .98793 L .48522 .9897 L 0 1 .524 r
F
.49251 .98903 m .48279 .98793 L .48522 .9897 L 0 1 .521 r
F
.48279 .98793 m .47183 .98668 L .48498 .98964 L F
.48279 .98793 m .47242 .98825 L .4718 .9911 L 0 1 .524 r
F
.48279 .98793 m .47244 .98494 L .47183 .98668 L 0 1 .521 r
F
.49252 .98512 m .48163 .98682 L .48279 .98793 L 0 1 .524 r
F
.49251 .98903 m .48163 .98682 L .48279 .98793 L 0 1 .521 r
F
.48163 .98682 m .47244 .98494 L .48279 .98793 L F
.48163 .98682 m .48142 .98685 L .48279 .98793 L 0 1 .524 r
F
.48142 .98685 m .47242 .98825 L .48279 .98793 L F
.48279 .98793 m .48498 .98964 L .48522 .9897 L 0 1 .521 r
F
.48279 .98793 m .48262 .98797 L .48522 .9897 L 0 1 .524 r
F
.48262 .98797 m .4718 .9911 L .48522 .9897 L F
.48522 .9897 m .48008 .99292 L .48973 .99259 L F
.48522 .9897 m .48973 .99259 L .49173 .99252 L F
.48531 .98969 m .48522 .9897 L .48859 .99186 L 0 1 .521 r
F
.49251 .98903 m .48562 .98966 L .49173 .99309 L F
.48562 .98966 m .48531 .98969 L .48667 .99041 L F
.48562 .98966 m .48667 .99041 L .49173 .99309 L F
.48531 .98969 m .48967 .99257 L .49173 .99309 L F
.49173 .99309 m .4905 .99323 L .49157 .99396 L 0 1 .527 r
F
0 g
.49444 .99874 m
.49986 1.00084 L
s
.46941 .99389 m
.47483 .99429 L
s
.76085 .58138 m .76446 .60159 L .76961 .60119 L 0 .468 .385 r
F
0 g
.76446 .60159 m
.76515 .61138 L
s
.5188 .49529 m .52061 .42715 L .51881 .45088 L 0 .999 .26 r
F
0 g
.52039 .43007 m
.52061 .42715 L
s
.5197 .41427 m
.52061 .42715 L
s
.51812 .43311 m
.5197 .41427 L
s
.50478 .81747 m
.50887 .816 L
s
.47055 .90994 m .47675 .91504 L .47737 .91294 L 0 1 .537 r
F
.49504 .91335 m .47737 .91294 L .47675 .91504 L 0 1 .541 r
F
0 g
.46871 .91532 m
.47675 .91504 L
s
.47675 .91504 m
.484 .91724 L
s
.48043 .81678 m .485 .82142 L .48559 .81856 L 0 1 .516 r
F
.49925 .81564 m .48559 .81856 L .485 .82142 L 0 1 .517 r
F
0 g
.485 .82142 m
.49054 .82324 L
s
.47868 .82391 m
.485 .82142 L
s
.37957 .85048 m .38185 .85601 L .38409 .85346 L 0 1 .531 r
F
.37957 .85048 m .3737 .85673 L .38185 .85601 L F
0 g
.38185 .85601 m
.38705 .85869 L
s
.33227 .86967 m .31116 .86882 L .31609 .87254 L 0 1 .535 r
F
.33227 .86967 m .31408 .86667 L .31116 .86882 L F
.33227 .86967 m .32314 .86704 L .31408 .86667 L F
.33899 .86396 m .32314 .86704 L .33227 .86967 L 0 1 .534 r
F
0 g
.33227 .86967 m
.34103 .86989 L
s
.33227 .86967 m
.33716 .87338 L
s
.51141 .45842 m .51329 .40786 L .51098 .41771 L 0 1 .254 r
F
.51141 .45842 m .51491 .4144 L .51329 .40786 L F
0 g
.51329 .40786 m
.51336 .4072 L
s
.49737 .99798 m
.49743 .99799 L
s
.43436 .97448 m .4315 .97929 L .44095 .98142 L 0 1 .523 r
F
.43436 .97448 m .41991 .97454 L .4315 .97929 L F
0 g
.4315 .97929 m
.43941 .9843 L
s
.52219 .99843 m
.52332 .99811 L
s
.52879 .99658 m
.52892 .99655 L
s
.74959 .5661 m .7592 .57217 L .75465 .56601 L 0 .423 .37 r
F
.74959 .5661 m .76085 .58138 L .7592 .57217 L F
.74959 .5661 m .75851 .58747 L .76085 .58138 L F
0 g
.75346 .58751 m
.75851 .58747 L
s
.75851 .58747 m
.76006 .59612 L
s
.32492 .89696 m .32747 .90453 L .33005 .9024 L 0 1 .528 r
F
.32492 .89696 m .31823 .90217 L .32747 .90453 L F
0 g
.32747 .90453 m
.33342 .90959 L
s
.37524 .95249 m .37039 .95749 L .38005 .96068 L 0 1 .514 r
F
.37524 .95249 m .35931 .95124 L .37039 .95749 L F
.71725 .48507 m .72758 .50516 L .72178 .49357 L 0 0 .104 r
F
.71725 .48507 m .73172 .51405 L .72758 .50516 L F
.71725 .48507 m .73141 .51427 L .73172 .51405 L F
0 g
.72704 .50605 m
.73141 .51427 L
s
.51054 .38965 m .50791 .38917 L .50822 .39486 L 0 1 .136 r
F
.51054 .38965 m .51011 .37414 L .50791 .38917 L F
.51098 .41771 m .51054 .38965 L .50869 .40693 L 0 1 .214 r
F
.37524 .95249 m .38005 .96068 L .38188 .95867 L 0 1 .514 r
F
0 g
.37039 .95749 m
.38005 .96068 L
s
.38005 .96068 m
.38212 .96227 L
s
.40603 .84652 m .38745 .84962 L .39235 .85223 L 0 1 .528 r
F
0 g
.38409 .85346 m
.39235 .85223 L
s
.41098 .83981 m .41369 .84508 L .41555 .84236 L 0 1 .527 r
F
.41098 .83981 m .40603 .84652 L .41369 .84508 L F
0 g
.41369 .84508 m
.41885 .84734 L
s
.51604 .44231 m .51491 .4144 L .51476 .433 L 0 1 .249 r
F
.51141 .45842 m .51476 .433 L .51491 .4144 L 0 1 .254 r
F
0 g
.51329 .40786 m
.51491 .4144 L
s
.51491 .4144 m
.51638 .39696 L
s
.3555 .90322 m .33391 .89921 L .33958 .90421 L 0 1 .528 r
F
.43436 .97448 m .4123 .96951 L .41991 .97454 L 0 1 .523 r
F
0 g
.41015 .97248 m
.41991 .97454 L
s
.36133 .89769 m .36445 .90485 L .36667 .90261 L 0 1 .528 r
F
.36133 .89769 m .3555 .90322 L .36445 .90485 L F
0 g
.36445 .90485 m
.37053 .90937 L
s
.51961 .33482 m .51679 .35445 L .51663 .35038 L 0 0 .084 r
F
.51961 .33482 m .52037 .34618 L .51679 .35445 L F
.51961 .33482 m .52496 .33115 L .52037 .34618 L F
.46087 1.00013 m .43818 1.00459 L .44668 1.00663 L 0 1 .532 r
F
.44343 .92321 m .44907 .92667 L .45012 .92344 L 0 1 .492 r
F
.44343 .92321 m .44051 .93106 L .44907 .92667 L F
0 g
.44907 .92667 m
.45625 .92676 L
s
.41082 .94428 m .41614 .94792 L .41759 .94506 L 0 1 .504 r
F
.41082 .94428 m .4069 .95123 L .41614 .94792 L F
0 g
.41614 .94792 m
.42349 .94847 L
s
.52092 .99808 m .50908 1.00065 L .5212 1.00219 L 0 1 .523 r
F
0 g
.5212 1.00219 m
.52559 1.00336 L
s
.52092 .99808 m .50013 .99823 L .50908 1.00065 L 0 1 .523 r
F
0 g
.5027 1.00078 m
.50908 1.00065 L
s
.50013 .99727 m
.50465 .9982 L
s
.44357 .91049 m .43368 .90807 L .42518 .908 L 0 1 .534 r
F
.44647 .90478 m .44357 .91049 L .45176 .91061 L 0 1 .533 r
F
.44647 .90478 m .43368 .90807 L .44357 .91049 L F
0 g
.44357 .91049 m
.45021 .91402 L
s
.4409 .8348 m
.44832 .83201 L
s
.49094 .99965 m .47887 .99994 L .46935 1.00219 L 0 1 .529 r
F
0 g
.49094 .99965 m
.49985 1.00152 L
s
.49094 .99965 m
.49737 .99798 L
s
.49902 .99755 m
.50013 .99727 L
s
.48043 .81678 m .46565 .82262 L .47081 .82439 L 0 1 .516 r
F
0 g
.46417 .82681 m
.47081 .82439 L
s
.45915 .82494 m .44328 .83015 L .44832 .83201 L 0 1 .52 r
F
.4191 .90398 m .39912 .90272 L .40522 .90674 L 0 1 .53 r
F
0 g
.39636 .90619 m
.40522 .90674 L
s
.7056 .46885 m .7141 .4768 L .71711 .48902 L 0 .556 .048 r
F
0 g
.7141 .4768 m
.71725 .48506 L
s
.46279 .98501 m .47032 .99114 L .47092 .98933 L 0 1 .527 r
F
0 g
.46096 .9896 m
.47032 .99114 L
s
.47032 .99114 m
.47685 .99376 L
s
.46935 1.00219 m
.47887 .99994 L
s
.52541 .91465 m
.52585 .9147 L
s
.3737 .85673 m .35399 .85812 L .35882 .8612 L 0 1 .531 r
F
.44051 .93106 m .41976 .94074 L .4268 .94114 L 0 1 .499 r
F
0 g
.41759 .94506 m
.4268 .94114 L
s
.43436 .97448 m .44095 .98142 L .44197 .97952 L 0 1 .523 r
F
.46279 .98501 m .44197 .97952 L .44095 .98142 L 0 1 .527 r
F
0 g
.44095 .98142 m
.44909 .98574 L
s
.4315 .97929 m
.44095 .98142 L
s
.47245 .89707 m .47834 .90046 L .47896 .89671 L 0 1 .47 r
F
.47245 .89707 m .47058 .90612 L .47834 .90046 L F
0 g
.47834 .90046 m
.48341 .90016 L
s
.40603 .84652 m .3897 .84704 L .38745 .84962 L 0 1 .528 r
F
.40603 .84652 m .39767 .84571 L .3897 .84704 L F
.41098 .83981 m .39767 .84571 L .40603 .84652 L 0 1 .527 r
F
0 g
.40603 .84652 m
.4109 .84913 L
s
.40603 .84652 m
.41369 .84508 L
s
.50228 .91555 m
.50642 .91476 L
s
.3737 .85673 m .35659 .85575 L .35399 .85812 L 0 1 .531 r
F
.3737 .85673 m .36505 .85515 L .35659 .85575 L F
.37957 .85048 m .36505 .85515 L .3737 .85673 L F
0 g
.3737 .85673 m
.38185 .85601 L
s
.3737 .85673 m
.3785 .85981 L
s
.34573 .8582 m .3475 .86403 L .35009 .86167 L 0 1 .534 r
F
0 g
.35009 .86167 m
.35882 .8612 L
s
.34573 .8582 m .33899 .86396 L .3475 .86403 L 0 1 .534 r
F
0 g
.3475 .86403 m
.35262 .86721 L
s
.45074 .92307 m
.45854 .91843 L
s
.45012 .92344 m
.45074 .92307 L
s
.41555 .84236 m
.4232 .84049 L
s
.43639 .83208 m .41866 .83778 L .4232 .84049 L 0 1 .523 r
F
.59239 .30901 m .59316 .34427 L .59067 .32334 L 0 .852 .147 r
F
.59071 .32233 m .59067 .32334 L .59063 .32298 L F
.59239 .30901 m .59067 .32334 L .59071 .32233 L F
.59243 .31098 m .59909 .36638 L .59316 .34427 L F
.59239 .30901 m .59249 .30989 L .59243 .31098 L F
.59249 .30989 m .59909 .36638 L .59243 .31098 L F
.57995 .33165 m .58774 .33358 L .58742 .34557 L 0 .457 .162 r
F
.58742 .34557 m .59316 .34427 L .59086 .35969 L 0 .687 .163 r
F
.58774 .33358 m .58849 .33377 L .58742 .34557 L 0 .457 .162 r
F
.57995 .33165 m .585 .31897 L .58931 .32004 L F
.58921 .32182 m .58931 .32004 L .59063 .32298 L 0 .687 .163 r
F
.58921 .32182 m .58931 .32004 L .59059 .32036 L 0 .457 .162 r
F
.57995 .33165 m .58931 .32004 L .58921 .32182 L F
.57975 .31412 m .58489 .31013 L .58931 .32004 L 0 .687 .163 r
F
.57975 .31412 m .58931 .32004 L .58921 .32182 L F
.58849 .33377 m .59063 .32298 L .59316 .34427 L F
.58921 .32182 m .59063 .32298 L .58849 .33377 L F
.58849 .33377 m .59059 .32036 L .59303 .3349 L 0 .457 .162 r
F
.57995 .33165 m .58921 .32182 L .58849 .33377 L F
.58921 .32182 m .59059 .32036 L .58849 .33377 L F
.57975 .31412 m .58921 .32182 L .58849 .33377 L 0 .687 .163 r
F
.57975 .31412 m .58849 .33377 L .58742 .34557 L F
.58849 .33377 m .59316 .34427 L .58742 .34557 L F
.58849 .33377 m .59025 .33421 L .58742 .34557 L 0 .457 .162 r
F
.58742 .34557 m .59025 .33421 L .58966 .34974 L F
.58742 .34557 m .59086 .35969 L .58705 .35908 L 0 .687 .163 r
F
.58742 .34557 m .58705 .35908 L .58583 .35888 L F
.57995 .33165 m .58509 .34123 L .58524 .35972 L 0 .457 .162 r
F
.58509 .34123 m .58533 .34167 L .5853 .3476 L F
.58509 .34123 m .5853 .3476 L .58524 .35972 L F
.58579 .3626 m .59684 .40108 L .59073 .39664 L 0 .715 .139 r
F
.5872 .34515 m .58583 .35888 L .58574 .35901 L 0 .457 .162 r
F
.58577 .35579 m .58574 .35901 L .58524 .35972 L F
.5872 .34515 m .58574 .35901 L .58577 .35579 L F
.58572 .36056 m .5995 .39111 L .59684 .40108 L 0 .715 .139 r
F
.58586 .35957 m .59086 .35969 L .59697 .37349 L F
.58577 .36027 m .5995 .39111 L .58579 .36071 L F
.58577 .35999 m .58581 .3601 L .58577 .36027 L F
.58581 .3601 m .5995 .39111 L .58577 .36027 L F
.58561 .36137 m .58572 .36056 L .58579 .3626 L F
.58557 .36119 m .58562 .36128 L .58561 .36137 L 0 .47 .143 r
F
.58524 .35972 m .58571 .36054 L .58557 .36119 L F
.58524 .35972 m .58577 .35999 L .58567 .36045 L F
.58523 .35878 m .58571 .36054 L .58561 .36137 L 0 .715 .139 r
F
.58571 .36054 m .58572 .36056 L .58561 .36137 L F
.58572 .36056 m .59684 .40108 L .58579 .3626 L F
.58575 .35951 m .5858 .35949 L .58577 .35999 L 0 .47 .143 r
F
.58524 .35972 m .58575 .35951 L .58577 .35999 L F
.58533 .34167 m .58566 .35665 L .58524 .35972 L 0 .457 .162 r
F
.58577 .35999 m .59697 .37349 L .5995 .39111 L 0 .715 .139 r
F
.58578 .35949 m .5858 .35947 L .5858 .35949 L 0 .47 .143 r
F
.58524 .35972 m .58583 .35888 L .58578 .35949 L F
.58523 .35878 m .5858 .35949 L .58577 .35999 L 0 .715 .139 r
F
.5858 .35949 m .59697 .37349 L .58577 .35999 L F
.58583 .35888 m .59086 .35969 L .5858 .35946 L F
.58583 .35888 m .5858 .35947 L .58578 .35949 L 0 .47 .143 r
F
.58583 .35888 m .5858 .35946 L .58577 .35946 L 0 .715 .139 r
F
.58583 .35888 m .59013 .35269 L .5858 .35947 L 0 .47 .143 r
F
.5858 .35949 m .59013 .35269 L .58985 .35777 L F
.5858 .35947 m .59013 .35269 L .5858 .35949 L F
.58561 .36137 m .59652 .37934 L .59056 .3838 L F
.58562 .36128 m .59652 .37934 L .58561 .36137 L F
.58571 .36054 m .59652 .37934 L .58557 .36119 L F
.59909 .36638 m .5995 .39111 L .59697 .37349 L 0 .86 .113 r
F
.59909 .36638 m .60578 .41305 L .5995 .39111 L F
.58567 .36045 m .59914 .36691 L .59652 .37934 L 0 .47 .143 r
F
.58572 .36046 m .58577 .35999 L .58572 .36056 L 0 .715 .139 r
F
.58573 .3599 m .58577 .35999 L .58572 .36046 L F
.58577 .35999 m .58579 .36071 L .58572 .36056 L F
.58577 .35999 m .59914 .36691 L .58572 .36048 L 0 .47 .143 r
F
.58577 .35999 m .58572 .36048 L .58567 .36045 L F
.5858 .35949 m .58588 .35949 L .58586 .35957 L 0 .715 .139 r
F
.58588 .35949 m .59086 .35969 L .58586 .35957 L F
.58577 .35946 m .5858 .35946 L .5858 .35949 L F
.5858 .35946 m .59086 .35969 L .5858 .35949 L F
.5858 .35949 m .5967 .35486 L .58577 .35999 L 0 .47 .143 r
F
.58577 .35999 m .5967 .35486 L .59914 .36691 L F
.58523 .35878 m .58573 .3599 L .58572 .36056 L 0 .715 .139 r
F
.57995 .33165 m .58524 .35972 L .5796 .35831 L 0 .457 .162 r
F
.58524 .35972 m .58503 .36647 L .58258 .3721 L 0 .47 .143 r
F
.58523 .35878 m .58503 .36647 L .58254 .36859 L 0 .715 .139 r
F
.57085 .38313 m .58243 .38107 L .58092 .3921 L 0 .292 .126 r
F
.5667 .36487 m .5796 .35831 L .57672 .37315 L 0 .285 .141 r
F
.5667 .36487 m .57672 .37315 L .57085 .38313 L F
.57085 .38313 m .57672 .37315 L .58258 .3721 L 0 .292 .126 r
F
.58485 .37312 m .5846 .38267 L .58403 .37881 L 0 .715 .139 r
F
.58485 .37312 m .58403 .37881 L .58385 .37759 L F
.57085 .38313 m .58258 .3721 L .58356 .37631 L 0 .292 .126 r
F
.58331 .38091 m .58356 .37631 L .58385 .37759 L F
.57085 .38313 m .58356 .37631 L .58331 .38091 L F
.58503 .36647 m .58385 .37759 L .58258 .3721 L 0 .47 .143 r
F
.57066 .36358 m .58254 .36859 L .58385 .37759 L 0 .55 .143 r
F
.58331 .38091 m .58403 .37881 L .5846 .38267 L F
.58121 .3907 m .58242 .38659 L .58136 .39334 L F
.58331 .38091 m .58293 .38818 L .58136 .39334 L F
.57997 .39686 m .58136 .39334 L .58769 .40218 L 0 .557 .121 r
F
.5793 .39724 m .58032 .39486 L .57997 .39686 L 0 .289 .108 r
F
.56993 .42497 m .5724 .39396 L .57682 .39496 L 0 .518 .203 r
F
.56993 .42497 m .57682 .39496 L .58032 .42736 L F
.57913 .41807 m .58616 .42134 L .57929 .41903 L 0 .557 .121 r
F
.57503 .39962 m .57926 .39485 L .57925 .39726 L 0 .289 .108 r
F
.57085 .38313 m .57957 .3909 L .57503 .39962 L 0 .292 .126 r
F
.58092 .3921 m .58136 .39334 L .58074 .39335 L 0 .55 .143 r
F
.58036 .39361 m .58059 .39335 L .5793 .39724 L 0 .289 .108 r
F
.58059 .39335 m .58136 .39334 L .57997 .39686 L 0 .557 .121 r
F
.58059 .39335 m .58135 .39249 L .58032 .39486 L 0 .289 .108 r
F
.58059 .39335 m .58032 .39486 L .5793 .39724 L F
.58488 .43405 m .58739 .41041 L .59261 .44906 L 0 .875 .195 r
F
.57947 .39971 m .58769 .40218 L .58975 .41409 L 0 .557 .121 r
F
.57957 .3909 m .57926 .39485 L .57503 .39962 L 0 .292 .126 r
F
.57925 .39726 m .57957 .3945 L .5793 .39724 L 0 .289 .108 r
F
.57926 .39485 m .57957 .3945 L .57925 .39726 L F
.57957 .3945 m .57954 .39642 L .5793 .39724 L F
.57997 .39686 m .58043 .39717 L .57947 .39971 L 0 .557 .121 r
F
.58043 .39717 m .58769 .40218 L .57947 .39971 L F
.57841 .40252 m .57879 .40243 L .57873 .4028 L 0 .289 .108 r
F
.57503 .39962 m .57947 .39971 L .57841 .40252 L F
.59073 .39664 m .58975 .41409 L .58769 .40218 L 0 .714 .111 r
F
.57947 .39971 m .5798 .40016 L .57873 .4028 L 0 .557 .121 r
F
.5798 .40016 m .58975 .41409 L .57873 .4028 L F
.57873 .4028 m .58975 .41409 L .58616 .42134 L F
.57767 .40941 m .57854 .40401 L .57797 .41121 L F
.57735 .40752 m .57854 .40401 L .57767 .40941 L F
.57714 .40678 m .57754 .40688 L .57735 .40752 L 0 .289 .108 r
F
.57503 .39962 m .57873 .4028 L .57714 .40678 L F
.57845 .40376 m .57854 .40401 L .57735 .40752 L 0 .557 .121 r
F
.57845 .40376 m .5786 .40326 L .57854 .40401 L F
.57797 .41121 m .57921 .40399 L .57913 .41807 L F
.57865 .40259 m .57921 .40399 L .57797 .41121 L F
.57921 .40399 m .58616 .42134 L .57913 .41807 L F
.57873 .4028 m .58601 .40906 L .57754 .40688 L 0 .289 .108 r
F
.57873 .4028 m .57754 .40688 L .57714 .40678 L F
.57947 .39971 m .57883 .40242 L .57841 .40252 L F
.57923 .3997 m .58757 .39261 L .58957 .39991 L F
.57503 .39962 m .57925 .39726 L .57923 .3997 L F
.57925 .39726 m .58757 .39261 L .57923 .3997 L F
.57497 .3934 m .57865 .40259 L .5786 .40326 L 0 .557 .121 r
F
.57497 .3934 m .5786 .40326 L .57845 .40376 L F
.57497 .3934 m .57845 .40376 L .57735 .40752 L F
.57735 .40752 m .58601 .40906 L .57924 .41394 L 0 .289 .108 r
F
.57754 .40688 m .58601 .40906 L .57735 .40752 L F
.57947 .39971 m .58957 .39991 L .57883 .40242 L F
.57497 .3934 m .57947 .39971 L .57873 .4028 L 0 .557 .121 r
F
.57873 .4028 m .58957 .39991 L .58601 .40906 L 0 .289 .108 r
F
.57879 .40243 m .58957 .39991 L .57873 .4028 L F
.57497 .3934 m .57997 .39686 L .57947 .39971 L 0 .557 .121 r
F
.57975 .3967 m .58059 .39335 L .57997 .39686 L F
.57957 .3909 m .5809 .39209 L .57926 .39485 L 0 .292 .126 r
F
.5809 .39209 m .58059 .39335 L .57926 .39485 L F
.57957 .3945 m .58036 .39361 L .57954 .39642 L 0 .289 .108 r
F
.57497 .3934 m .58059 .39335 L .57975 .3967 L 0 .557 .121 r
F
.5809 .39209 m .58135 .39249 L .58059 .39335 L 0 .292 .126 r
F
.56266 .41839 m .5724 .39396 L .56993 .42497 L 0 .167 .147 r
F
.57085 .38313 m .57503 .39962 L .56912 .40067 L 0 .292 .126 r
F
.57503 .39962 m .57298 .41382 L .57143 .40876 L 0 .289 .108 r
F
.57503 .39962 m .57735 .40752 L .57298 .41382 L F
.57735 .40752 m .57913 .41807 L .57569 .41364 L 0 .557 .121 r
F
.57735 .40752 m .57562 .41387 L .57298 .41382 L 0 .289 .108 r
F
.57913 .41807 m .57912 .41878 L .57294 .4101 L 0 .557 .121 r
F
.57735 .40752 m .57924 .41394 L .57562 .41387 L 0 .289 .108 r
F
.57497 .3934 m .57735 .40752 L .57294 .4101 L 0 .557 .121 r
F
.57735 .40752 m .57569 .41364 L .57294 .4101 L F
.57913 .41807 m .57929 .41903 L .57912 .41878 L F
.57997 .39686 m .58135 .39249 L .58757 .39261 L 0 .289 .108 r
F
.58032 .39486 m .58135 .39249 L .57997 .39686 L F
.58092 .3921 m .58121 .3907 L .58136 .39334 L 0 .55 .143 r
F
.58121 .3907 m .58331 .38091 L .58242 .38659 L F
.58188 .3851 m .58293 .38269 L .58092 .3921 L 0 .292 .126 r
F
.58243 .38107 m .58331 .38091 L .58188 .3851 L F
.58331 .38091 m .5846 .38267 L .58293 .38818 L 0 .55 .143 r
F
.58331 .38091 m .58374 .38084 L .58188 .3851 L 0 .292 .126 r
F
.57066 .36358 m .58331 .38091 L .58092 .3921 L 0 .55 .143 r
F
.58293 .38269 m .58374 .38084 L .58092 .3921 L 0 .292 .126 r
F
.58331 .38091 m .58385 .37759 L .58403 .37881 L 0 .55 .143 r
F
.57066 .36358 m .58385 .37759 L .58331 .38091 L F
.58331 .38091 m .58385 .37759 L .58457 .38069 L 0 .292 .126 r
F
.57066 .36358 m .58092 .3921 L .57497 .3934 L 0 .55 .143 r
F
.58092 .3921 m .58074 .39335 L .57497 .3934 L F
.58092 .3921 m .58374 .38084 L .58135 .39249 L 0 .292 .126 r
F
.58374 .38084 m .58457 .38069 L .58286 .38695 L F
.58374 .38084 m .58286 .38695 L .58135 .39249 L F
.58503 .36647 m .58485 .37312 L .58385 .37759 L 0 .715 .139 r
F
.58503 .36647 m .58385 .37759 L .58254 .36859 L F
.58503 .36647 m .58396 .37807 L .58385 .37759 L 0 .47 .143 r
F
.58503 .36647 m .58457 .38069 L .58396 .37807 L F
.58503 .36647 m .58579 .3626 L .5846 .38267 L 0 .715 .139 r
F
.58579 .3626 m .59073 .39664 L .58632 .38659 L F
.58579 .3626 m .58632 .38659 L .5846 .38267 L F
.58503 .36647 m .59056 .3838 L .58457 .38069 L 0 .47 .143 r
F
.58524 .35972 m .58561 .36137 L .58503 .36647 L F
.58561 .36137 m .58579 .3626 L .58503 .36647 L 0 .715 .139 r
F
.58561 .36137 m .59056 .3838 L .58503 .36647 L 0 .47 .143 r
F
.58554 .3609 m .58561 .36137 L .58503 .36647 L 0 .715 .139 r
F
.58523 .35878 m .58554 .3609 L .58503 .36647 L F
.58533 .34167 m .5872 .34515 L .58566 .35665 L 0 .457 .162 r
F
.5872 .34515 m .59076 .35179 L .58583 .35888 L F
.58523 .35878 m .58583 .35888 L .58577 .35946 L 0 .715 .139 r
F
.587 .34387 m .58742 .34557 L .58583 .35888 L 0 .687 .163 r
F
.57975 .31412 m .587 .34387 L .58523 .35878 L F
.587 .34387 m .58583 .35888 L .58523 .35878 L F
.58985 .35777 m .59076 .35179 L .5967 .35486 L 0 .47 .143 r
F
.59013 .35269 m .59076 .35179 L .58985 .35777 L F
.58966 .34974 m .59303 .3349 L .59076 .35179 L 0 .457 .162 r
F
.59025 .33421 m .59303 .3349 L .58966 .34974 L F
.59239 .30901 m .60445 .37438 L .59909 .36638 L 0 .852 .147 r
F
.59239 .30901 m .60618 .36008 L .60445 .37438 L F
.5923 .30281 m .59303 .3349 L .59059 .32036 L 0 .662 .166 r
F
0 g
.59059 .32036 m
.59182 .30782 L
s
.5901 .30013 m
.59037 .30118 L
s
.59037 .30118 m
.59189 .30706 L
s
.5923 .30281 m .59875 .34352 L .59303 .3349 L 0 .662 .166 r
F
.5923 .30281 m .60391 .34039 L .59875 .34352 L F
0 g
.59182 .30782 m
.5923 .30281 L
s
.5212 1.00219 m
.52628 1.00216 L
s
.44647 .90478 m .45176 .91061 L .45279 .90835 L 0 1 .533 r
F
0 g
.44357 .91049 m
.45176 .91061 L
s
.45176 .91061 m
.45718 .91299 L
s
.74194 .53737 m .74782 .55622 L .75221 .55855 L 0 .211 .264 r
F
0 g
.74782 .55622 m
.74959 .5661 L
s
.49925 .81564 m .4917 .81608 L .48559 .81856 L 0 1 .517 r
F
.5 .80779 m .49925 .81564 L .50505 .81293 L 0 1 .508 r
F
.5 .80779 m .4917 .81608 L .49925 .81564 L F
0 g
.49925 .81564 m
.50478 .81747 L
s
.54026 .3836 m .54816 .34086 L .54969 .33841 L 0 0 .057 r
F
0 g
.54969 .33841 m
.55388 .31554 L
s
.54026 .3836 m .54413 .36015 L .54816 .34086 L 0 0 .057 r
F
0 g
.54816 .34086 m
.54916 .32737 L
s
.54413 .36015 m
.54494 .35608 L
s
.54494 .35608 m
.5459 .35124 L
s
.54457 .35802 m
.54816 .34086 L
s
.54413 .36015 m
.54457 .35802 L
s
.3555 .90322 m .3365 .89708 L .33391 .89921 L 0 1 .528 r
F
.3555 .90322 m .34575 .8988 L .3365 .89708 L F
0 g
.33005 .9024 m
.33958 .90421 L
s
.36133 .89769 m .34575 .8988 L .3555 .90322 L 0 1 .528 r
F
0 g
.3555 .90322 m
.36113 .90821 L
s
.3555 .90322 m
.36445 .90485 L
s
.32492 .89696 m .30845 .8969 L .31823 .90217 L 0 1 .528 r
F
0 g
.31823 .90217 m
.32747 .90453 L
s
.51011 .37414 m .50711 .38176 L .50743 .38355 L 0 .778 .076 r
F
.51011 .37414 m .50966 .36928 L .50711 .38176 L F
0 g
.38662 .96588 m
.38685 .96591 L
s
.40672 .96189 m .40284 .96684 L .4123 .96951 L 0 1 .518 r
F
.40672 .96189 m .39165 .96131 L .40284 .96684 L F
0 g
.40284 .96684 m
.41015 .97248 L
s
.30245 .8679 m .30386 .87415 L .30678 .87202 L 0 1 .537 r
F
0 g
.30678 .87202 m
.31609 .87254 L
s
.30245 .8679 m .29491 .87307 L .30386 .87415 L 0 1 .537 r
F
0 g
.30386 .87415 m
.30906 .87799 L
s
.37524 .95249 m .35266 .94505 L .35931 .95124 L 0 1 .514 r
F
0 g
.57571 .3326 m
.5762 .36004 L
s
.47896 .89671 m
.48333 .89296 L
s
.48567 .89095 m
.48649 .89025 L
s
.3906 .90171 m .37001 .89924 L .37579 .90372 L 0 1 .529 r
F
0 g
.36667 .90261 m
.37579 .90372 L
s
.49504 .91335 m .4852 .91221 L .47737 .91294 L 0 1 .541 r
F
.44647 .90478 m .42735 .90451 L .43368 .90807 L 0 1 .533 r
F
0 g
.42518 .908 m
.43368 .90807 L
s
.49173 .99309 m .50013 .99823 L .50032 .99655 L 0 1 .527 r
F
.52092 .99808 m .50032 .99655 L .50013 .99823 L 0 1 .523 r
F
0 g
.50013 .99823 m
.50908 1.00065 L
s
.49743 .99799 m
.50013 .99823 L
s
.44051 .93106 m .42122 .93785 L .41976 .94074 L 0 1 .499 r
F
.44051 .93106 m .43012 .93369 L .42122 .93785 L F
.44343 .92321 m .43012 .93369 L .44051 .93106 L 0 1 .492 r
F
0 g
.44051 .93106 m
.44907 .92667 L
s
.44051 .93106 m
.44751 .93147 L
s
.37506 .96103 m .37996 .96492 L .3818 .96236 L 0 1 .509 r
F
.37506 .96103 m .37017 .96723 L .37996 .96492 L F
0 g
.37996 .96492 m
.38662 .96588 L
s
.38825 .96045 m
.38836 .96042 L
s
.4069 .95123 m .38927 .95698 L .39168 .95944 L 0 1 .51 r
F
.38927 .95698 m .38886 .95907 L .39168 .95944 L F
.40672 .96189 m .38927 .95698 L .39165 .96131 L 0 1 .518 r
F
.38927 .95698 m .38462 .95567 L .38866 .95892 L F
.38927 .95698 m .38646 .95367 L .38462 .95567 L F
.4069 .95123 m .39 .95511 L .38927 .95698 L 0 1 .51 r
F
.40672 .96189 m .39 .95511 L .38927 .95698 L 0 1 .518 r
F
.39 .95511 m .38646 .95367 L .38927 .95698 L F
.39 .95511 m .38985 .95515 L .38927 .95698 L 0 1 .51 r
F
.38927 .95698 m .38641 .95593 L .38457 .95851 L F
.38985 .95515 m .38641 .95593 L .38927 .95698 L F
.38927 .95698 m .38866 .95892 L .38886 .95907 L 0 1 .518 r
F
.38927 .95698 m .38886 .95907 L .39165 .96131 L F
.38927 .95698 m .38457 .95851 L .38886 .95907 L 0 1 .51 r
F
0 g
.38836 .96042 m
.38846 .96039 L
s
.38846 .96039 m
.38995 .95995 L
s
.77209 .59516 m .77105 .60946 L .77544 .61447 L 0 .519 .399 r
F
.77209 .59516 m .76961 .60119 L .77105 .60946 L F
0 g
.76515 .61138 m
.77105 .60946 L
s
.38836 .96042 m
.39165 .96131 L
s
.38188 .95867 m
.38836 .96042 L
s
.5 .80779 m .50505 .81293 L .50523 .80974 L 0 1 .508 r
F
0 g
.49925 .81564 m
.50505 .81293 L
s
.50505 .81293 m
.50893 .81464 L
s
.5 .80779 m .48646 .81414 L .4917 .81608 L 0 1 .508 r
F
0 g
.48559 .81856 m
.4917 .81608 L
s
.4069 .95123 m .39015 .95472 L .39 .95511 L 0 1 .51 r
F
.40672 .96189 m .39593 .95634 L .39015 .95472 L 0 1 .518 r
F
.39 .95511 m .39015 .95472 L .38646 .95367 L F
.40672 .96189 m .39015 .95472 L .39 .95511 L F
.4069 .95123 m .396 .95281 L .39015 .95472 L 0 1 .51 r
F
.39 .95511 m .39015 .95472 L .38641 .95593 L F
.41082 .94428 m .396 .95281 L .4069 .95123 L 0 1 .504 r
F
0 g
.4069 .95123 m
.41397 .95217 L
s
.4069 .95123 m
.41614 .94792 L
s
.52219 .49149 m .523 .43955 L .52197 .46945 L 0 .969 .257 r
F
.5188 .49529 m .52197 .46945 L .523 .43955 L 0 .999 .26 r
F
0 g
.523 .43955 m
.52487 .41643 L
s
.52241 .4215 m
.523 .43955 L
s
.46422 .90937 m .46085 .90806 L .45279 .90835 L 0 1 .537 r
F
.46431 .90933 m .46404 .90868 L .46422 .90937 L 0 1 .48 r
F
.47058 .90612 m .46404 .90868 L .46431 .90933 L F
.47245 .89707 m .46314 .90738 L .47058 .90612 L 0 1 .47 r
F
.46314 .90738 m .46085 .90806 L .46388 .90865 L 0 1 .535 r
F
.46314 .90738 m .46388 .90865 L .46404 .90868 L F
.46404 .90868 m .46085 .90806 L .46422 .90937 L 0 1 .537 r
F
.46314 .90738 m .4543 .91031 L .46084 .90994 L 0 1 .47 r
F
.46267 .90752 m .45435 .90495 L .46085 .90806 L 0 1 .535 r
F
.46257 .90722 m .45435 .90495 L .46267 .90752 L F
.46183 .90482 m .45435 .90495 L .46257 .90722 L F
.46183 .90482 m .46257 .90722 L .46314 .90738 L F
.47245 .89707 m .46139 .90258 L .4614 .90262 L 0 1 .47 r
F
.46155 .90339 m .46139 .90258 L .45539 .90269 L 0 1 .535 r
F
.46155 .90339 m .46119 .90273 L .46142 .90347 L 0 1 .47 r
F
.47245 .89707 m .4614 .90262 L .46155 .90339 L F
.4614 .90262 m .46119 .90273 L .46155 .90339 L F
.46183 .90482 m .45539 .90269 L .45435 .90495 L 0 1 .535 r
F
.47245 .89707 m .46142 .90347 L .46183 .90482 L 0 1 .47 r
F
.47245 .89707 m .46183 .90482 L .46314 .90738 L F
.47241 .90463 m .46155 .90339 L .46183 .90482 L 0 1 .535 r
F
.46155 .90339 m .45539 .90269 L .46183 .90482 L F
.47241 .90463 m .46313 .90255 L .46139 .90258 L F
.47241 .90463 m .46139 .90258 L .46155 .90339 L F
.47245 .89707 m .46314 .90131 L .46139 .90258 L 0 1 .47 r
F
.4614 .90262 m .46139 .90258 L .46119 .90273 L F
.46142 .90347 m .46119 .90273 L .45535 .90698 L F
.46183 .90482 m .45535 .90698 L .4543 .91031 L F
.46142 .90347 m .45535 .90698 L .46183 .90482 L F
.46314 .90738 m .46257 .90722 L .46267 .90752 L 0 1 .535 r
F
.47241 .90463 m .46183 .90482 L .46314 .90738 L F
.46183 .90482 m .46171 .90491 L .46314 .90738 L 0 1 .47 r
F
.46171 .90491 m .4543 .91031 L .46314 .90738 L F
.46314 .90738 m .46084 .90994 L .46404 .90868 L F
.46314 .90738 m .46404 .90868 L .47058 .90612 L F
.46345 .90729 m .46314 .90738 L .46404 .90868 L 0 1 .535 r
F
.47241 .90463 m .46345 .90729 L .47055 .90994 L F
.46345 .90729 m .46404 .90868 L .47055 .90994 L F
.47055 .90994 m .46404 .90868 L .46422 .90937 L 0 1 .537 r
F
.46422 .90937 m .46084 .90994 L .45273 .91527 L 0 1 .48 r
F
.46404 .90868 m .46084 .90994 L .46422 .90937 L F
0 g
.47189 .9061 m
.4774 .90601 L
s
.47233 .90484 m
.47834 .90046 L
s
.49669 .87476 m .48773 .88029 L .48052 .88728 L 0 1 .447 r
F
0 g
.49669 .87476 m
.50075 .87427 L
s
.40672 .96189 m .4123 .96951 L .41373 .96754 L 0 1 .518 r
F
.43436 .97448 m .41373 .96754 L .4123 .96951 L 0 1 .523 r
F
0 g
.4123 .96951 m
.41991 .97454 L
s
.40284 .96684 m
.4123 .96951 L
s
.38887 .95908 m
.39165 .96131 L
s
.38886 .95907 m
.38887 .95908 L
s
.3818 .96236 m
.38825 .96045 L
s
.53452 .51593 m .53862 .49807 L .54154 .4581 L 0 .85 .251 r
F
0 g
.54154 .4581 m
.54471 .43915 L
s
.54154 .4581 m
.5421 .43987 L
s
.7976 .64605 m .80418 .66351 L .80839 .656 L 0 .811 .444 r
F
0 g
.7979 .66611 m
.80418 .66351 L
s
.52613 .91336 m
.52622 .91335 L
s
.4619 .81788 m .46565 .82262 L .46663 .81978 L 0 1 .517 r
F
.4619 .81788 m .45915 .82494 L .46565 .82262 L F
.48043 .81678 m .46663 .81978 L .46565 .82262 L 0 1 .516 r
F
0 g
.46565 .82262 m
.47081 .82439 L
s
.5241 .99212 m
.52614 .99255 L
s
.49583 .9089 m .49504 .91335 L .50256 .91297 L 0 1 .538 r
F
.49583 .9089 m .4852 .91221 L .49504 .91335 L F
0 g
.49504 .91335 m
.50228 .91555 L
s
.45915 .82494 m .44465 .82743 L .44328 .83015 L 0 1 .52 r
F
.45915 .82494 m .45146 .8252 L .44465 .82743 L F
.4619 .81788 m .45146 .8252 L .45915 .82494 L 0 1 .517 r
F
0 g
.45915 .82494 m
.46565 .82262 L
s
.45915 .82494 m
.46417 .82681 L
s
.47092 .98933 m
.47216 .98945 L
s
.46279 .98501 m .45133 .98105 L .44197 .97952 L 0 1 .527 r
F
.43123 .99972 m .43818 1.00459 L .43921 1.00201 L 0 1 .536 r
F
.43123 .99972 m .42835 1.00603 L .43818 1.00459 L F
.46087 1.00013 m .43921 1.00201 L .43818 1.00459 L 0 1 .532 r
F
0 g
.43818 1.00459 m
.44668 1.00663 L
s
.49583 .9089 m .47829 .90981 L .4852 .91221 L 0 1 .538 r
F
0 g
.47737 .91294 m
.4852 .91221 L
s
.49183 .99254 m
.50032 .99438 L
s
.50034 .99437 m
.50922 .99189 L
s
.50032 .99438 m
.50034 .99437 L
s
.33899 .86396 m .31848 .86345 L .32314 .86704 L 0 1 .534 r
F
.33899 .86396 m .32141 .86129 L .31848 .86345 L F
.33899 .86396 m .33021 .86151 L .32141 .86129 L F
.34573 .8582 m .33021 .86151 L .33899 .86396 L F
0 g
.33899 .86396 m
.3475 .86403 L
s
.33899 .86396 m
.34362 .86755 L
s
.5418 .38035 m
.54204 .37876 L
s
.54081 .3871 m
.5418 .38035 L
s
.45279 .90835 m
.45494 .90827 L
s
.77209 .59516 m .77544 .61447 L .78069 .61372 L 0 .519 .399 r
F
0 g
.77544 .61447 m
.77596 .62342 L
s
.50966 .36928 m .5164 .34617 L .51339 .35803 L 0 0 0 r
F
0 g
.5164 .34617 m
.51961 .33482 L
s
.69255 .471 m .69747 .45167 L .70193 .46416 L 0 .76 .111 r
F
.69255 .471 m .69346 .45456 L .69747 .45167 L F
0 g
.69444 .43724 m
.69747 .45167 L
s
.44011 .82535 m .44328 .83015 L .44465 .82743 L 0 1 .522 r
F
.44011 .82535 m .43639 .83208 L .44328 .83015 L F
0 g
.44328 .83015 m
.44832 .83201 L
s
.39551 .89596 m .39912 .90272 L .40097 .9004 L 0 1 .528 r
F
.39551 .89596 m .3906 .90171 L .39912 .90272 L F
.4191 .90398 m .40097 .9004 L .39912 .90272 L 0 1 .53 r
F
0 g
.39912 .90272 m
.40522 .90674 L
s
.43123 .99972 m .41626 1.00539 L .42835 1.00603 L 0 1 .536 r
F
0 g
.42835 1.00603 m
.43818 1.00459 L
s
.38546 .84416 m .38745 .84962 L .3897 .84704 L 0 1 .53 r
F
.38546 .84416 m .37957 .85048 L .38745 .84962 L F
0 g
.38745 .84962 m
.39235 .85223 L
s
.48043 .81678 m .47297 .81727 L .46663 .81978 L 0 1 .516 r
F
.4822 .80925 m .48043 .81678 L .48646 .81414 L 0 1 .511 r
F
.4822 .80925 m .47297 .81727 L .48043 .81678 L F
0 g
.48043 .81678 m
.48559 .81856 L
s
.50523 .80974 m
.50942 .80771 L
s
.46087 1.00013 m .44894 1.00011 L .43921 1.00201 L 0 1 .532 r
F
.46272 .99333 m .46087 1.00013 L .47027 .99808 L 0 1 .531 r
F
.46272 .99333 m .44894 1.00011 L .46087 1.00013 L F
0 g
.46087 1.00013 m
.46935 1.00219 L
s
.46272 .99333 m .47027 .99808 L .47088 .99531 L 0 1 .531 r
F
0 g
.46087 1.00013 m
.47027 .99808 L
s
.47027 .99808 m
.47887 .99994 L
s
.33163 .89173 m .33391 .89921 L .3365 .89708 L 0 1 .527 r
F
.33163 .89173 m .32492 .89696 L .33391 .89921 L F
0 g
.33391 .89921 m
.33958 .90421 L
s
.3906 .90171 m .37224 .897 L .37001 .89924 L 0 1 .529 r
F
.3906 .90171 m .38107 .89805 L .37224 .897 L F
.39551 .89596 m .38107 .89805 L .3906 .90171 L 0 1 .528 r
F
0 g
.3906 .90171 m
.39912 .90272 L
s
.3906 .90171 m
.39636 .90619 L
s
.4822 .80925 m .48646 .81414 L .48705 .8111 L 0 1 .511 r
F
.5 .80779 m .48705 .8111 L .48646 .81414 L 0 1 .508 r
F
0 g
.48646 .81414 m
.4917 .81608 L
s
.48043 .81678 m
.48646 .81414 L
s
.47241 .90463 m .47055 .90994 L .47829 .90981 L 0 1 .535 r
F
0 g
.47055 .90994 m
.47737 .91294 L
s
.4191 .90398 m .40954 .90094 L .40097 .9004 L 0 1 .53 r
F
.42303 .89816 m .4191 .90398 L .42735 .90451 L 0 1 .529 r
F
.42303 .89816 m .40954 .90094 L .4191 .90398 L F
0 g
.4191 .90398 m
.42518 .908 L
s
.51533 .5015 m .51788 .43607 L .51604 .44231 L 0 1 .264 r
F
.51533 .5015 m .51881 .45088 L .51788 .43607 L F
0 g
.51788 .43607 m
.51812 .43311 L
s
.37506 .96103 m .35891 .96778 L .37017 .96723 L 0 1 .509 r
F
0 g
.37017 .96723 m
.37996 .96492 L
s
.43639 .83208 m .42096 .83438 L .41866 .83778 L 0 1 .523 r
F
.43639 .83208 m .42856 .83194 L .42096 .83438 L F
0 g
.43639 .83208 m
.4409 .8348 L
s
.44011 .82535 m .42856 .83194 L .43639 .83208 L 0 1 .522 r
F
0 g
.43639 .83208 m
.44328 .83015 L
s
.68149 .4363 m .68856 .47362 L .68417 .4606 L 0 .824 .123 r
F
.68149 .4363 m .69255 .471 L .68856 .47362 L F
.68149 .4363 m .69346 .45456 L .69255 .471 L F
0 g
.69074 .4304 m
.69346 .45456 L
s
.69346 .45456 m
.69747 .45167 L
s
.41098 .83981 m .39307 .84316 L .39767 .84571 L 0 1 .527 r
F
0 g
.3897 .84704 m
.39767 .84571 L
s
.42303 .89816 m .42735 .90451 L .4288 .90218 L 0 1 .529 r
F
.44647 .90478 m .4288 .90218 L .42735 .90451 L 0 1 .533 r
F
0 g
.42735 .90451 m
.43368 .90807 L
s
.4191 .90398 m
.42735 .90451 L
s
.52092 .99808 m .50922 .99648 L .50032 .99655 L 0 1 .523 r
F
.73172 .51405 m .73467 .52043 L .73934 .52844 L 0 0 .118 r
F
.73172 .51405 m .73141 .51428 L .73467 .52043 L F
0 g
.73036 .51754 m
.73467 .52043 L
s
.73141 .51428 m
.7345 .52011 L
s
.7345 .52011 m
.73458 .52025 L
s
.73458 .52025 m
.73467 .52043 L
s
.34897 .93641 m .35266 .94505 L .35487 .94307 L 0 1 .509 r
F
.34897 .93641 m .34317 .94134 L .35266 .94505 L F
.37524 .95249 m .35487 .94307 L .35266 .94505 L 0 1 .514 r
F
0 g
.35266 .94505 m
.35931 .95124 L
s
.51098 .41771 m .50869 .40693 L .509 .41732 L 0 1 .214 r
F
.51141 .45842 m .51098 .41771 L .50947 .43656 L 0 1 .254 r
F
.36133 .89769 m .34037 .89388 L .34575 .8988 L 0 1 .528 r
F
0 g
.3365 .89708 m
.34575 .8988 L
s
.30245 .8679 m .28587 .86949 L .29491 .87307 L 0 1 .537 r
F
0 g
.29491 .87307 m
.30386 .87415 L
s
.43436 .97448 m .42319 .96967 L .41373 .96754 L 0 1 .523 r
F
0 g
.52132 .99134 m
.5218 .99119 L
s
.34897 .93641 m .33271 .9344 L .34317 .94134 L 0 1 .509 r
F
0 g
.34317 .94134 m
.35266 .94505 L
s
.41707 .83143 m .41866 .83778 L .42096 .83438 L 0 1 .525 r
F
.41707 .83143 m .41098 .8398 L .41866 .83778 L F
0 g
.41866 .83778 m
.4232 .84049 L
s
.37524 .95249 m .36455 .94626 L .35487 .94307 L 0 1 .514 r
F
.38011 .94751 m .37524 .95249 L .38462 .95567 L 0 1 .512 r
F
.38011 .94751 m .36455 .94626 L .37524 .95249 L F
0 g
.37524 .95249 m
.38188 .95867 L
s
.44636 .91523 m .45168 .91856 L .45273 .91527 L 0 1 .483 r
F
.44636 .91523 m .44343 .92321 L .45168 .91856 L F
0 g
.45168 .91856 m
.45854 .91843 L
s
.49583 .9089 m .50256 .91297 L .50275 .91131 L 0 1 .538 r
F
0 g
.49504 .91335 m
.50256 .91297 L
s
.50256 .91297 m
.5074 .91373 L
s
.36717 .89214 m .37001 .89924 L .37224 .897 L 0 1 .527 r
F
.36717 .89214 m .36133 .89769 L .37001 .89924 L F
0 g
.37001 .89924 m
.37579 .90372 L
s
.37957 .85048 m .36049 .85217 L .36505 .85515 L 0 1 .531 r
F
.53452 .51593 m .5356 .52303 L .53862 .49807 L 0 .85 .251 r
F
.5381 .50488 m .54476 .39259 L .54189 .41286 L 0 1 .222 r
F
.5381 .50488 m .54561 .4104 L .54476 .39259 L F
0 g
.54476 .39259 m
.54586 .38058 L
s
.41476 .93723 m .41976 .94074 L .42122 .93785 L 0 1 .497 r
F
.41476 .93723 m .41082 .94428 L .41976 .94074 L F
0 g
.41976 .94074 m
.4268 .94114 L
s
.76085 .58138 m .76961 .60119 L .77209 .59516 L 0 .468 .385 r
F
0 g
.76446 .60159 m
.76961 .60119 L
s
.76961 .60119 m
.77105 .60946 L
s
.47434 .88794 m .47989 .89107 L .48052 .88728 L 0 1 .457 r
F
.47434 .88794 m .47245 .89707 L .47989 .89107 L F
0 g
.47989 .89107 m
.48649 .89025 L
s
.46462 .98057 m .45133 .98105 L .46279 .98501 L 0 1 .523 r
F
.46462 .98057 m .44351 .97669 L .45133 .98105 L F
0 g
.44197 .97952 m
.45133 .98105 L
s
.46462 .98057 m .46279 .98501 L .47183 .98668 L 0 1 .523 r
F
0 g
.46279 .98501 m
.47092 .98933 L
s
.35249 .8524 m .35399 .85812 L .35659 .85575 L 0 1 .533 r
F
0 g
.35659 .85575 m
.36505 .85515 L
s
.35249 .8524 m .34573 .8582 L .35399 .85812 L 0 1 .533 r
F
0 g
.35399 .85812 m
.35882 .8612 L
s
.4822 .80925 m .46811 .81543 L .47297 .81727 L 0 1 .511 r
F
0 g
.46663 .81978 m
.47297 .81727 L
s
.38011 .94751 m .38462 .95567 L .38646 .95367 L 0 1 .512 r
F
0 g
.37524 .95249 m
.38462 .95567 L
s
.38462 .95567 m
.38588 .95668 L
s
.50361 .41903 m .50822 .39486 L .50791 .38917 L 0 1 .156 r
F
.50361 .41903 m .50638 .40765 L .50822 .39486 L F
0 g
.50822 .39486 m
.51054 .38965 L
s
.73566 .86251 m
.73629 .8624 L
s
.4619 .81788 m .44671 .82331 L .45146 .8252 L 0 1 .517 r
F
0 g
.44465 .82743 m
.45146 .8252 L
s
.31 .86269 m .31116 .86882 L .31408 .86667 L 0 1 .536 r
F
0 g
.31408 .86667 m
.32314 .86704 L
s
.31 .86269 m .30245 .8679 L .31116 .86882 L 0 1 .536 r
F
0 g
.31116 .86882 m
.31609 .87254 L
s
.37957 .85048 m .3631 .84977 L .36049 .85217 L 0 1 .531 r
F
.37957 .85048 m .37129 .84905 L .3631 .84977 L F
.38546 .84416 m .37129 .84905 L .37957 .85048 L 0 1 .53 r
F
0 g
.37957 .85048 m
.38745 .84962 L
s
.37957 .85048 m
.38409 .85346 L
s
.47241 .90463 m .47829 .90981 L .4789 .90774 L 0 1 .535 r
F
.49583 .9089 m .4789 .90774 L .47829 .90981 L 0 1 .538 r
F
0 g
.47055 .90994 m
.47829 .90981 L
s
.47829 .90981 m
.4852 .91221 L
s
.7535 .55473 m .75465 .56601 L .7592 .57217 L 0 .247 .284 r
F
.7535 .55473 m .75221 .55855 L .75465 .56601 L F
0 g
.74959 .5661 m
.75465 .56601 L
s
.32492 .89696 m .30328 .89145 L .30845 .8969 L 0 1 .528 r
F
.43724 .96974 m .43436 .97448 L .44351 .97669 L 0 1 .52 r
F
.43724 .96974 m .42319 .96967 L .43436 .97448 L F
0 g
.43436 .97448 m
.44197 .97952 L
s
.44343 .92321 m .4234 .93347 L .43012 .93369 L 0 1 .492 r
F
0 g
.42122 .93785 m
.43012 .93369 L
s
.41098 .83981 m .39532 .84056 L .39307 .84316 L 0 1 .527 r
F
.41098 .83981 m .403 .83912 L .39532 .84056 L F
0 g
.41098 .83981 m
.41555 .84236 L
s
.41707 .83143 m .403 .83912 L .41098 .8398 L 0 1 .525 r
F
0 g
.41098 .8398 m
.41866 .83778 L
s
.45313 .91501 m
.46084 .90994 L
s
.45273 .91527 m
.45313 .91501 L
s
.48052 .88728 m
.48773 .88029 L
s
.32492 .89696 m .3062 .88946 L .30328 .89145 L 0 1 .528 r
F
.32492 .89696 m .31549 .89183 L .3062 .88946 L F
.33163 .89173 m .31549 .89183 L .32492 .89696 L 0 1 .527 r
F
0 g
.32492 .89696 m
.33391 .89921 L
s
.32492 .89696 m
.33005 .9024 L
s
.51141 .45842 m .51326 .45189 L .51476 .433 L 0 1 .254 r
F
.50519 .44139 m .50869 .40693 L .50638 .40765 L 0 1 .227 r
F
.50519 .44139 m .509 .41732 L .50869 .40693 L F
0 g
.50869 .40693 m
.51054 .38965 L
s
.46272 .99333 m .44076 .99812 L .44894 1.00011 L 0 1 .531 r
F
0 g
.43921 1.00201 m
.44894 1.00011 L
s
.5 .80779 m .49285 .80838 L .48705 .8111 L 0 1 .508 r
F
.50076 .79931 m .5 .80779 L .5055 .80476 L 0 1 .5 r
F
.50076 .79931 m .49285 .80838 L .5 .80779 L F
0 g
.5 .80779 m
.50523 .80974 L
s
.76085 .58138 m .77055 .58647 L .76601 .58094 L 0 .468 .385 r
F
.76085 .58138 m .77209 .59516 L .77055 .58647 L F
.78331 .60767 m .78069 .61372 L .78202 .62169 L 0 .572 .413 r
F
0 g
.77646 .62368 m
.78202 .62169 L
s
.42303 .89816 m .40375 .89692 L .40954 .90094 L 0 1 .529 r
F
0 g
.40097 .9004 m
.40954 .90094 L
s
.54557 .80604 m
.54591 .80662 L
s
.36133 .89769 m .34296 .89173 L .34037 .89388 L 0 1 .528 r
F
.36133 .89769 m .35195 .89337 L .34296 .89173 L F
.36717 .89214 m .35195 .89337 L .36133 .89769 L 0 1 .527 r
F
0 g
.36133 .89769 m
.36667 .90261 L
s
.36133 .89769 m
.37001 .89924 L
s
.43724 .96974 m .41588 .96459 L .42319 .96967 L 0 1 .52 r
F
0 g
.41373 .96754 m
.42319 .96967 L
s
.49251 .98903 m .49173 .99309 L .50059 .9941 L 0 1 .521 r
F
0 g
.49173 .99309 m
.50032 .99655 L
s
.47088 .99531 m
.48008 .99292 L
s
.44647 .90478 m .437 .9023 L .4288 .90218 L 0 1 .533 r
F
.44938 .89907 m .44647 .90478 L .45435 .90495 L 0 1 .531 r
F
.44938 .89907 m .437 .9023 L .44647 .90478 L F
0 g
.44647 .90478 m
.45279 .90835 L
s
.50361 .41903 m .50791 .38917 L .50525 .3943 L 0 1 .156 r
F
0 g
.50662 .40757 m
.50869 .40693 L
s
.50791 .38917 m
.51011 .37414 L
s
.50076 .79931 m .5055 .80476 L .50568 .8013 L 0 1 .5 r
F
0 g
.5 .80779 m
.5055 .80476 L
s
.5055 .80476 m
.50928 .80642 L
s
.43123 .99972 m .40825 1.0031 L .41626 1.00539 L 0 1 .536 r
F
0 g
.5268 .99968 m
.5277 .99992 L
s
.44343 .92321 m .42486 .93054 L .4234 .93347 L 0 1 .492 r
F
.44343 .92321 m .43346 .92614 L .42486 .93054 L F
.44636 .91523 m .43346 .92614 L .44343 .92321 L 0 1 .483 r
F
0 g
.44343 .92321 m
.45168 .91856 L
s
.44343 .92321 m
.45012 .92344 L
s
.53375 .32777 m .53869 .31326 L .54322 .31048 L 0 .203 .131 r
F
.39551 .89596 m .37559 .89361 L .38107 .89805 L 0 1 .528 r
F
0 g
.37224 .897 m
.38107 .89805 L
s
.49252 .98512 m .5006 .98996 L .50079 .98695 L 0 1 .524 r
F
0 g
.49607 .99126 m
.5006 .98996 L
s
.5006 .98996 m
.50922 .99189 L
s
.47434 .88794 m .46314 .90131 L .47245 .89707 L 0 1 .457 r
F
0 g
.47245 .89707 m
.47896 .89671 L
s
.47245 .89707 m
.47989 .89107 L
s
.37996 .95476 m .38457 .95851 L .38641 .95593 L 0 1 .503 r
F
.37996 .95476 m .37506 .96103 L .38457 .95851 L F
0 g
.38457 .95851 m
.38886 .95907 L
s
.3901 .95473 m
.39015 .95472 L
s
.41082 .94428 m .39128 .95129 L .396 .95281 L 0 1 .504 r
F
.39128 .95129 m .39108 .95226 L .396 .95281 L F
.41062 .95699 m .39128 .95129 L .39593 .95634 L 0 1 .515 r
F
.39128 .95129 m .38921 .95068 L .39099 .95218 L F
.39128 .95129 m .39105 .9487 L .38921 .95068 L F
.41082 .94428 m .39213 .94915 L .39128 .95129 L 0 1 .504 r
F
.41062 .95699 m .39213 .94915 L .39128 .95129 L 0 1 .515 r
F
.39213 .94915 m .39105 .9487 L .39128 .95129 L F
.39213 .94915 m .39196 .9492 L .39128 .95129 L 0 1 .504 r
F
.39128 .95129 m .39104 .94944 L .38919 .95204 L F
.39196 .9492 m .39104 .94944 L .39128 .95129 L F
.39128 .95129 m .39099 .95218 L .39108 .95226 L 0 1 .515 r
F
.39128 .95129 m .39108 .95226 L .39593 .95634 L F
.39128 .95129 m .38919 .95204 L .39108 .95226 L 0 1 .504 r
F
0 g
.39015 .95472 m
.39034 .95465 L
s
.39034 .95465 m
.39293 .95381 L
s
.50076 .79931 m .48793 .8064 L .49285 .80838 L 0 1 .5 r
F
0 g
.48705 .8111 m
.49285 .80838 L
s
.38011 .94751 m .35819 .94009 L .36455 .94626 L 0 1 .512 r
F
0 g
.35487 .94307 m
.36455 .94626 L
s
.74194 .53737 m .75097 .54662 L .74632 .53966 L 0 .211 .264 r
F
.74194 .53737 m .7535 .55473 L .75097 .54662 L F
.74194 .53737 m .75221 .55855 L .7535 .55473 L F
0 g
.74782 .55622 m
.75221 .55855 L
s
.61688 .41256 m
.61692 .41824 L
s
.61731 .47231 m
.61731 .47273 L
s
.7976 .64605 m
.79839 .64572 L
s
.79757 .64511 m
.7976 .64605 L
s
.42096 .83438 m
.42856 .83194 L
s
.44011 .82535 m .424 .82986 L .42856 .83194 L 0 1 .522 r
F
.44938 .89907 m .45435 .90495 L .45539 .90269 L 0 1 .531 r
F
0 g
.44647 .90478 m
.45435 .90495 L
s
.45435 .90495 m
.45664 .90605 L
s
.41082 .94428 m .39218 .94903 L .39213 .94915 L 0 1 .504 r
F
.41062 .95699 m .40023 .9514 L .39218 .94903 L 0 1 .515 r
F
.39213 .94915 m .39218 .94903 L .39105 .9487 L F
.41062 .95699 m .39218 .94903 L .39213 .94915 L F
.41082 .94428 m .40032 .9461 L .39218 .94903 L 0 1 .504 r
F
.39213 .94915 m .39218 .94903 L .39104 .94944 L F
.41476 .93723 m .40032 .9461 L .41082 .94428 L 0 1 .497 r
F
0 g
.41082 .94428 m
.41759 .94506 L
s
.41082 .94428 m
.41976 .94074 L
s
.57427 .30241 m
.57975 .31411 L
s
.43724 .96974 m .44351 .97669 L .44454 .97482 L 0 1 .52 r
F
.46462 .98057 m .44454 .97482 L .44351 .97669 L 0 1 .523 r
F
0 g
.44351 .97669 m
.45133 .98105 L
s
.43436 .97448 m
.44351 .97669 L
s
.52064 .99433 m .50922 .99648 L .52092 .99808 L 0 1 .511 r
F
0 g
.52092 .99808 m
.5268 .99968 L
s
.52064 .99433 m .50059 .9941 L .50922 .99648 L 0 1 .511 r
F
0 g
.50032 .99655 m
.50922 .99648 L
s
.53375 .32777 m .54322 .31048 L .54434 .32127 L 0 .203 .131 r
F
0 g
.54322 .31048 m
.54595 .29011 L
s
.53869 .31326 m
.54322 .31048 L
s
.50519 .44139 m .50751 .43208 L .509 .41732 L 0 1 .227 r
F
0 g
.509 .41732 m
.51098 .41771 L
s
.46462 .98057 m .47183 .98668 L .47244 .98494 L 0 1 .523 r
F
0 g
.47183 .98668 m
.47471 .98789 L
s
.46279 .98501 m
.47183 .98668 L
s
.41062 .95699 m .40672 .96189 L .41588 .96459 L 0 1 .515 r
F
.41062 .95699 m .39593 .95634 L .40672 .96189 L F
0 g
.40672 .96189 m
.41373 .96754 L
s
.44938 .89907 m .43098 .89868 L .437 .9023 L 0 1 .531 r
F
0 g
.4288 .90218 m
.437 .9023 L
s
.34897 .93641 m .32679 .92773 L .33271 .9344 L 0 1 .509 r
F
0 g
.39015 .95472 m
.39593 .95634 L
s
.38646 .95367 m
.39015 .95472 L
s
.51533 .5015 m .51604 .44231 L .51455 .4639 L 0 1 .264 r
F
0 g
.51585 .44508 m
.51604 .44231 L
s
.51476 .433 m
.51604 .44231 L
s
.34573 .8582 m .32582 .85803 L .33021 .86151 L 0 1 .534 r
F
.34573 .8582 m .32876 .85586 L .32582 .85803 L F
.34573 .8582 m .3373 .85593 L .32876 .85586 L F
.35249 .8524 m .3373 .85593 L .34573 .8582 L 0 1 .533 r
F
0 g
.34573 .8582 m
.35399 .85812 L
s
.34573 .8582 m
.35009 .86167 L
s
.52037 .34618 m .52888 .32553 L .52953 .33304 L 0 .028 .099 r
F
.52037 .34618 m .52496 .33115 L .52888 .32553 L F
0 g
.52888 .32553 m
.53175 .30676 L
s
.52496 .33115 m
.52791 .31568 L
s
.52496 .33115 m
.52888 .32553 L
s
.46467 .81056 m .46811 .81543 L .4691 .81248 L 0 1 .514 r
F
.46467 .81056 m .4619 .81788 L .46811 .81543 L F
.4822 .80925 m .4691 .81248 L .46811 .81543 L 0 1 .511 r
F
0 g
.46811 .81543 m
.47297 .81727 L
s
.50275 .91131 m
.50502 .91109 L
s
.50988 .91062 m
.50998 .91061 L
s
.4619 .81788 m .44809 .82052 L .44671 .82331 L 0 1 .517 r
F
.4619 .81788 m .45461 .8182 L .44809 .82052 L F
.46467 .81056 m .45461 .8182 L .4619 .81788 L 0 1 .514 r
F
0 g
.4619 .81788 m
.46811 .81543 L
s
.4619 .81788 m
.46663 .81978 L
s
.52092 .99808 m
.52583 .99814 L
s
.52583 .99814 m
.52881 .99818 L
s
.49583 .9089 m .48642 .90735 L .4789 .90774 L 0 1 .538 r
F
0 g
.54762 .79312 m
.54801 .79261 L
s
.50568 .8013 m
.51088 .79804 L
s
.7535 .55473 m .7592 .57217 L .76364 .57391 L 0 .247 .284 r
F
0 g
.75221 .55855 m
.75465 .56601 L
s
.7592 .57217 m
.76085 .58138 L
s
.39137 .83776 m .39307 .84316 L .39532 .84056 L 0 1 .529 r
F
.39137 .83776 m .38546 .84416 L .39307 .84316 L F
0 g
.39307 .84316 m
.39767 .84571 L
s
.44384 .81846 m .44671 .82331 L .44809 .82052 L 0 1 .519 r
F
.44384 .81846 m .44011 .82535 L .44671 .82331 L F
0 g
.44671 .82331 m
.45146 .8252 L
s
.41062 .95699 m .41588 .96459 L .41732 .96264 L 0 1 .515 r
F
.43724 .96974 m .41732 .96264 L .41588 .96459 L 0 1 .52 r
F
0 g
.41588 .96459 m
.42319 .96967 L
s
.40672 .96189 m
.41588 .96459 L
s
.52103 .98394 m
.52319 .98442 L
s
.5275 .98539 m
.52778 .98545 L
s
.39109 .95227 m
.39593 .95634 L
s
.39108 .95226 m
.39109 .95227 L
s
.38641 .95593 m
.3901 .95473 L
s
.7056 .46885 m .71301 .49113 L .70859 .48108 L 0 .556 .048 r
F
.7056 .46885 m .71667 .49454 L .71301 .49113 L F
.7056 .46885 m .71711 .48902 L .71667 .49454 L F
0 g
.7141 .4768 m
.71711 .48902 L
s
.4822 .80925 m .47514 .80982 L .4691 .81248 L 0 1 .511 r
F
.48397 .80129 m .4822 .80925 L .48793 .8064 L 0 1 .506 r
F
.48397 .80129 m .47514 .80982 L .4822 .80925 L F
0 g
.4822 .80925 m
.48705 .8111 L
s
.30245 .8679 m .28149 .86535 L .28587 .86949 L 0 1 .537 r
F
.30245 .8679 m .28473 .86343 L .28149 .86535 L F
.30245 .8679 m .29373 .86452 L .28473 .86343 L F
.31 .86269 m .29373 .86452 L .30245 .8679 L 0 1 .536 r
F
0 g
.30245 .8679 m
.31116 .86882 L
s
.30245 .8679 m
.30678 .87202 L
s
.33837 .88647 m .34037 .89388 L .34296 .89173 L 0 1 .526 r
F
.33837 .88647 m .33163 .89173 L .34037 .89388 L F
0 g
.34037 .89388 m
.34575 .8988 L
s
.61739 .33449 m
.61984 .34911 L
s
.61984 .34911 m
.62116 .357 L
s
.61738 .33472 m
.61739 .33449 L
s
.73172 .51405 m .73934 .52844 L .7431 .53412 L 0 0 .118 r
F
0 g
.73934 .52844 m
.74194 .53737 L
s
.51943 .91134 m
.52088 .91156 L
s
.49251 .98903 m .50059 .9941 L .50078 .99253 L 0 1 .521 r
F
.52064 .99433 m .50078 .99253 L .50059 .9941 L 0 1 .511 r
F
0 g
.50059 .9941 m
.50922 .99648 L
s
.49173 .99309 m
.50059 .9941 L
s
.55818 .32707 m .55751 .35439 L .55596 .34871 L 0 .224 .149 r
F
0 g
.55818 .32707 m
.55818 .32706 L
s
.55818 .32707 m .56241 .34504 L .55751 .35439 L 0 .224 .149 r
F
0 g
.55818 .32708 m
.55818 .32707 L
s
.48397 .80129 m .48793 .8064 L .48852 .80317 L 0 1 .506 r
F
.50076 .79931 m .48852 .80317 L .48793 .8064 L 0 1 .5 r
F
0 g
.48793 .8064 m
.49285 .80838 L
s
.4822 .80925 m
.48793 .8064 L
s
.50079 .98695 m
.50509 .98564 L
s
.50509 .98564 m
.50648 .98521 L
s
.50966 .36928 m .5063 .38232 L .50663 .38123 L 0 0 0 r
F
.50966 .36928 m .50921 .37235 L .5063 .38232 L F
.50966 .36928 m .51339 .35803 L .50921 .37235 L F
.43413 .9933 m .44076 .99812 L .44179 .99551 L 0 1 .535 r
F
.43413 .9933 m .43123 .99972 L .44076 .99812 L F
.46272 .99333 m .44179 .99551 L .44076 .99812 L 0 1 .531 r
F
0 g
.44076 .99812 m
.44894 1.00011 L
s
.54591 .78922 m
.54792 .78986 L
s
.52549 .49084 m .52678 .49162 L .52914 .4639 L 0 .941 .254 r
F
.5188 .49529 m .51881 .45088 L .51822 .477 L 0 .999 .26 r
F
.51533 .5015 m .51822 .477 L .51881 .45088 L 0 1 .264 r
F
0 g
.51788 .43607 m
.51881 .45088 L
s
.51881 .45088 m
.52039 .43007 L
s
.50519 .44139 m .50638 .40765 L .50361 .41903 L 0 1 .227 r
F
0 g
.50638 .40765 m
.50822 .39486 L
s
.50638 .40765 m
.50662 .40757 L
s
.44011 .82535 m .42575 .82722 L .424 .82986 L 0 1 .522 r
F
.44011 .82535 m .43266 .82529 L .42575 .82722 L F
.44384 .81846 m .43266 .82529 L .44011 .82535 L 0 1 .519 r
F
0 g
.44011 .82535 m
.44465 .82743 L
s
.44011 .82535 m
.44671 .82331 L
s
.66812 .47713 m .67753 .43754 L .67998 .47438 L 0 .72 .183 r
F
0 g
.67753 .43754 m
.68149 .4363 L
s
.56266 .41839 m .56594 .44545 L .56311 .44141 L 0 .167 .147 r
F
.56266 .41839 m .56993 .42497 L .56594 .44545 L F
0 g
.55898 .44684 m
.56266 .41839 L
s
.39532 .84056 m
.403 .83912 L
s
.41707 .83143 m .39909 .83617 L .403 .83912 L 0 1 .525 r
F
.40044 .89019 m .40375 .89692 L .4056 .89459 L 0 1 .526 r
F
0 g
.40085 .90031 m
.40097 .9004 L
s
.40044 .89019 m .39551 .89596 L .40375 .89692 L 0 1 .526 r
F
.42303 .89816 m .4056 .89459 L .40375 .89692 L 0 1 .529 r
F
0 g
.40375 .89692 m
.40954 .90094 L
s
.60064 .44004 m .60776 .41071 L .6129 .49308 L 0 .825 .204 r
F
0 g
.60608 .37326 m
.60776 .41071 L
s
.60608 .40353 m
.60776 .41071 L
s
.37506 .96103 m .35211 .96645 L .35891 .96778 L 0 1 .509 r
F
.37506 .96103 m .35434 .96413 L .35211 .96645 L F
.37506 .96103 m .36419 .9618 L .35434 .96413 L F
.37996 .95476 m .36419 .9618 L .37506 .96103 L 0 1 .503 r
F
0 g
.37506 .96103 m
.38457 .95851 L
s
.37506 .96103 m
.3818 .96236 L
s
.61279 .36064 m
.61284 .36094 L
s
.60907 .33954 m
.61279 .36064 L
s
.61316 .36274 m
.6132 .36296 L
s
.61306 .36217 m
.61316 .36274 L
s
.61284 .36094 m
.61306 .36217 L
s
.39551 .89596 m .37782 .89135 L .37559 .89361 L 0 1 .528 r
F
.39551 .89596 m .38637 .89236 L .37782 .89135 L F
.40044 .89019 m .38637 .89236 L .39551 .89596 L 0 1 .526 r
F
0 g
.39551 .89596 m
.40375 .89692 L
s
.39551 .89596 m
.40085 .90031 L
s
.43123 .99972 m .40969 1.00068 L .40825 1.0031 L 0 1 .536 r
F
.43123 .99972 m .41955 .99923 L .40969 1.00068 L F
.43413 .9933 m .41955 .99923 L .43123 .99972 L 0 1 .535 r
F
0 g
.43123 .99972 m
.44076 .99812 L
s
.43123 .99972 m
.43921 1.00201 L
s
.36717 .89214 m .34685 .88851 L .35195 .89337 L 0 1 .527 r
F
0 g
.34296 .89173 m
.35195 .89337 L
s
.46272 .99333 m .45121 .99345 L .44179 .99551 L 0 1 .531 r
F
.46457 .98635 m .46272 .99333 L .4718 .9911 L 0 1 .53 r
F
.46457 .98635 m .45121 .99345 L .46272 .99333 L F
0 g
.46272 .99333 m
.47088 .99531 L
s
.502 .40689 m .50743 .38355 L .50711 .38176 L 0 .931 .112 r
F
.502 .40689 m .50525 .3943 L .50743 .38355 L F
0 g
.50743 .38355 m
.51011 .37414 L
s
.50556 .39273 m
.50743 .38355 L
s
.31758 .85744 m .31848 .86345 L .32141 .86129 L 0 1 .536 r
F
0 g
.32141 .86129 m
.33021 .86151 L
s
.31758 .85744 m .31 .86269 L .31848 .86345 L 0 1 .536 r
F
0 g
.31848 .86345 m
.32314 .86704 L
s
.58489 .31013 m
.58818 .31749 L
s
.58818 .31749 m
.58867 .3186 L
s
.58867 .3186 m
.58931 .32004 L
s
.58559 .3117 m
.58685 .29619 L
s
.46457 .98635 m .4718 .9911 L .47242 .98825 L 0 1 .53 r
F
0 g
.46272 .99333 m
.4718 .9911 L
s
.4718 .9911 m
.48008 .99292 L
s
.38546 .84416 m .36702 .84616 L .37129 .84905 L 0 1 .53 r
F
0 g
.45539 .90269 m
.46139 .90258 L
s
.35927 .84654 m .36049 .85217 L .3631 .84977 L 0 1 .532 r
F
0 g
.3631 .84977 m
.37129 .84905 L
s
.35927 .84654 m .35249 .8524 L .36049 .85217 L 0 1 .532 r
F
0 g
.36049 .85217 m
.36505 .85515 L
s
.52866 .49416 m .52989 .49678 L .53249 .46827 L 0 .913 .252 r
F
0 g
.52738 .48458 m
.52914 .4639 L
s
.80827 .64737 m
.80839 .656 L
s
.42303 .89816 m .41387 .89513 L .4056 .89459 L 0 1 .529 r
F
.42697 .89231 m .42303 .89816 L .43098 .89868 L 0 1 .528 r
F
.42697 .89231 m .41387 .89513 L .42303 .89816 L F
0 g
.42303 .89816 m
.4288 .90218 L
s
.54332 .37528 m .55203 .33893 L .55361 .34209 L 0 0 .096 r
F
0 g
.54348 .37459 m
.54351 .37429 L
s
.54332 .37528 m .54763 .35309 L .55203 .33893 L 0 0 .096 r
F
0 g
.55203 .33893 m
.55388 .31554 L
s
.54942 .34733 m
.55203 .33893 L
s
.46462 .98057 m .45358 .97648 L .44454 .97482 L 0 1 .523 r
F
.4493 .90717 m .4543 .91031 L .45535 .90698 L 0 1 .471 r
F
.4493 .90717 m .44636 .91523 L .4543 .91031 L F
0 g
.4543 .91031 m
.46084 .90994 L
s
.35479 .93149 m .35819 .94009 L .36041 .9381 L 0 1 .507 r
F
.35479 .93149 m .34897 .93641 L .35819 .94009 L F
.38011 .94751 m .36041 .9381 L .35819 .94009 L 0 1 .512 r
F
0 g
.35819 .94009 m
.36455 .94626 L
s
.77209 .59516 m .78069 .61372 L .78331 .60767 L 0 .519 .399 r
F
0 g
.77544 .61447 m
.78069 .61372 L
s
.78069 .61372 m
.78202 .62169 L
s
.33163 .89173 m .31059 .88646 L .31549 .89183 L 0 1 .527 r
F
.38546 .84416 m .36963 .84373 L .36702 .84616 L 0 1 .53 r
F
.38546 .84416 m .37755 .84288 L .36963 .84373 L F
.39137 .83776 m .37755 .84288 L .38546 .84416 L 0 1 .529 r
F
0 g
.38546 .84416 m
.39307 .84316 L
s
.38546 .84416 m
.3897 .84704 L
s
.71668 .49454 m .72178 .49357 L .72758 .50516 L 0 .47 .037 r
F
.71668 .49454 m .71712 .48903 L .72178 .49357 L F
0 g
.71725 .48507 m
.72178 .49357 L
s
.71712 .48903 m
.72178 .49357 L
s
.48397 .80129 m .47058 .80795 L .47514 .80982 L 0 1 .506 r
F
0 g
.4691 .81248 m
.47514 .80982 L
s
.30192 .88369 m .30328 .89145 L .3062 .88946 L 0 1 .527 r
F
.30192 .88369 m .29437 .88856 L .30328 .89145 L F
0 g
.30328 .89145 m
.30845 .8969 L
s
.34897 .93641 m .32937 .9258 L .32679 .92773 L 0 1 .509 r
F
.34897 .93641 m .33888 .92952 L .32937 .9258 L F
.35479 .93149 m .33888 .92952 L .34897 .93641 L 0 1 .507 r
F
0 g
.34897 .93641 m
.35819 .94009 L
s
.34897 .93641 m
.35487 .94307 L
s
.49662 .90456 m .48642 .90735 L .49583 .9089 L 0 1 .534 r
F
.49662 .90456 m .47982 .90464 L .48642 .90735 L F
0 g
.4789 .90774 m
.48642 .90735 L
s
.49662 .90456 m .49583 .9089 L .50303 .90887 L 0 1 .534 r
F
0 g
.49583 .9089 m
.50275 .91131 L
s
.49252 .98512 m .4813 .98569 L .48064 .98588 L 0 1 .524 r
F
.48163 .98682 m .48064 .98588 L .47244 .98494 L 0 1 .521 r
F
.48163 .98682 m .48064 .98588 L .47242 .98825 L 0 1 .524 r
F
.49252 .98512 m .48064 .98588 L .48163 .98682 L F
.49251 .98903 m .4813 .98595 L .48064 .98588 L 0 1 .521 r
F
.49251 .98903 m .48064 .98588 L .48163 .98682 L F
0 g
.47244 .98494 m
.48064 .98588 L
s
.46467 .81056 m .45016 .81629 L .45461 .8182 L 0 1 .514 r
F
0 g
.44809 .82052 m
.45461 .8182 L
s
.37304 .88656 m .37559 .89361 L .37782 .89135 L 0 1 .526 r
F
.37304 .88656 m .36717 .89214 L .37559 .89361 L F
0 g
.37559 .89361 m
.38107 .89805 L
s
.52087 .98376 m
.5218 .98344 L
s
.42697 .89231 m .43098 .89868 L .43243 .89634 L 0 1 .528 r
F
.44938 .89907 m .43243 .89634 L .43098 .89868 L 0 1 .531 r
F
0 g
.43098 .89868 m
.437 .9023 L
s
.42303 .89816 m
.43098 .89868 L
s
.54911 .32026 m .55432 .30811 L .55942 .3097 L 0 .321 .156 r
F
0 g
.55432 .30811 m
.557 .28774 L
s
.41871 .9301 m .4234 .93347 L .42486 .93054 L 0 1 .488 r
F
.41871 .9301 m .41476 .93723 L .4234 .93347 L F
0 g
.4234 .93347 m
.43012 .93369 L
s
.33163 .89173 m .31352 .88446 L .31059 .88646 L 0 1 .527 r
F
.33163 .89173 m .32255 .88672 L .31352 .88446 L F
0 g
.3062 .88946 m
.31549 .89183 L
s
.33837 .88647 m .32255 .88672 L .33163 .89173 L 0 1 .526 r
F
0 g
.33163 .89173 m
.34037 .89388 L
s
.33163 .89173 m
.3365 .89708 L
s
.40229 .9981 m .40825 1.0031 L .40969 1.00068 L 0 1 .538 r
F
.40229 .9981 m .39839 1.00402 L .40825 1.0031 L F
0 g
.40825 1.0031 m
.41626 1.00539 L
s
.50076 .79931 m .49402 .80013 L .48852 .80317 L 0 1 .5 r
F
.50151 .79032 m .50076 .79931 L .50594 .79594 L 0 1 .491 r
F
.50151 .79032 m .49402 .80013 L .50076 .79931 L F
0 g
.50076 .79931 m
.50568 .8013 L
s
.71741 .83777 m
.71741 .83777 L
s
.45535 .90698 m
.46139 .90258 L
s
.47434 .88794 m .46026 .89929 L .46314 .90131 L 0 1 .457 r
F
.46026 .89929 m .46117 .90152 L .46314 .90131 L F
.47427 .89931 m .46026 .89929 L .46313 .90255 L 0 1 .533 r
F
.46026 .89929 m .45695 .89929 L .46069 .90126 L F
.46026 .89929 m .45799 .89701 L .45695 .89929 L F
.47434 .88794 m .46001 .8973 L .46026 .89929 L 0 1 .457 r
F
.47427 .89931 m .46001 .8973 L .46026 .89929 L 0 1 .533 r
F
.46001 .8973 m .45799 .89701 L .46026 .89929 L F
.46001 .8973 m .45984 .89741 L .46026 .89929 L 0 1 .457 r
F
.46026 .89929 m .45798 .89863 L .45693 .90198 L F
.45984 .89741 m .45798 .89863 L .46026 .89929 L F
.46026 .89929 m .46069 .90126 L .46117 .90152 L 0 1 .533 r
F
.46026 .89929 m .46117 .90152 L .46313 .90255 L F
.46026 .89929 m .45693 .90198 L .46117 .90152 L 0 1 .457 r
F
0 g
.46139 .90258 m
.46146 .90253 L
s
.46146 .90253 m
.46214 .90203 L
s
.50993 .9106 m
.50998 .91061 L
s
.47427 .89931 m .47241 .90463 L .47982 .90464 L 0 1 .533 r
F
.47427 .89931 m .46313 .90255 L .47241 .90463 L F
0 g
.47241 .90463 m
.4789 .90774 L
s
.46139 .90258 m
.46313 .90255 L
s
.42173 .82493 m .424 .82986 L .42575 .82722 L 0 1 .523 r
F
.42173 .82493 m .41707 .83143 L .424 .82986 L F
0 g
.424 .82986 m
.42856 .83194 L
s
.38011 .94751 m .36981 .94129 L .36041 .9381 L 0 1 .512 r
F
.385 .94254 m .38011 .94751 L .38921 .95068 L 0 1 .509 r
F
.385 .94254 m .36981 .94129 L .38011 .94751 L F
0 g
.38011 .94751 m
.38646 .95367 L
s
.44636 .91523 m .42705 .92611 L .43346 .92614 L 0 1 .483 r
F
0 g
.42486 .93054 m
.43346 .92614 L
s
.52219 .49149 m .52353 .49079 L .52562 .46472 L 0 .969 .257 r
F
.50151 .79032 m .50594 .79594 L .50612 .79225 L 0 1 .491 r
F
0 g
.50076 .79931 m
.50594 .79594 L
s
.50594 .79594 m
.51088 .79804 L
s
.51943 .91134 m
.5215 .91143 L
s
.43724 .96974 m .42648 .96485 L .41732 .96264 L 0 1 .52 r
F
0 g
.7998 .63658 m
.80279 .63578 L
s
.32427 .91873 m .32679 .92773 L .32937 .9258 L 0 1 .505 r
F
.32427 .91873 m .31757 .92351 L .32679 .92773 L F
0 g
.32679 .92773 m
.33271 .9344 L
s
.36717 .89214 m .34945 .88636 L .34685 .88851 L 0 1 .527 r
F
.36717 .89214 m .35817 .88792 L .34945 .88636 L F
.37304 .88656 m .35817 .88792 L .36717 .89214 L 0 1 .526 r
F
0 g
.36717 .89214 m
.37224 .897 L
s
.36717 .89214 m
.37559 .89361 L
s
.69255 .471 m .70193 .46416 L .70452 .48393 L 0 .76 .111 r
F
0 g
.70193 .46416 m
.7056 .46885 L
s
.46117 .90152 m
.46313 .90255 L
s
.51737 .78717 m
.51742 .78719 L
s
.51812 .78749 m
.51828 .78756 L
s
.52252 .78907 m
.52313 .78848 L
s
.52428 .78737 m
.52443 .78723 L
s
.52467 .78699 m
.52582 .78588 L
s
.52599 .78571 m
.52632 .7854 L
s
.385 .94254 m .38921 .95068 L .39105 .9487 L 0 1 .509 r
F
0 g
.38011 .94751 m
.38921 .95068 L
s
.38921 .95068 m
.3898 .95118 L
s
.6573 .43565 m .66905 .43662 L .66812 .47713 L 0 .76 .193 r
F
0 g
.66905 .43662 m
.67306 .41987 L
s
.66627 .38761 m
.66905 .43662 L
s
.54437 .48304 m .54561 .4104 L .54387 .45479 L 0 1 .218 r
F
.5381 .50488 m .54387 .45479 L .54561 .4104 L 0 1 .222 r
F
0 g
.54476 .39259 m
.54561 .4104 L
s
.54561 .4104 m
.54781 .37638 L
s
.59103 .43736 m
.59118 .43848 L
s
.59118 .43848 m
.59261 .44906 L
s
.58829 .41705 m
.5898 .42824 L
s
.5898 .42824 m
.591 .43718 L
s
.591 .43718 m
.59103 .43736 L
s
.59126 .39702 m
.59214 .43104 L
s
.59214 .43104 m
.59261 .44906 L
s
.58698 .38959 m
.58704 .3926 L
s
.58949 .42599 m
.58961 .41438 L
s
.58978 .39838 m
.58982 .39455 L
s
.59214 .43104 m
.59247 .44801 L
s
.59187 .41694 m
.59214 .43104 L
s
.59176 .41107 m
.59187 .41694 L
s
.47434 .88794 m .45998 .89702 L .46001 .8973 L 0 1 .457 r
F
.47427 .89931 m .46542 .89702 L .45998 .89702 L 0 1 .533 r
F
.46001 .8973 m .45998 .89702 L .45799 .89701 L F
.47427 .89931 m .45998 .89702 L .46001 .8973 L F
.47434 .88794 m .46545 .8926 L .45998 .89702 L 0 1 .457 r
F
.46001 .8973 m .45998 .89702 L .45798 .89863 L F
0 g
.47434 .88794 m
.48052 .88728 L
s
.40229 .9981 m .38666 1.00283 L .39839 1.00402 L 0 1 .538 r
F
0 g
.39839 1.00402 m
.40825 1.0031 L
s
.50151 .79032 m .4894 .7982 L .49402 .80013 L 0 1 .491 r
F
0 g
.48852 .80317 m
.49402 .80013 L
s
.49331 .9774 m .49252 .98512 L .50107 .98233 L 0 1 .52 r
F
.49331 .9774 m .4813 .98569 L .49252 .98512 L F
0 g
.49252 .98512 m
.50079 .98695 L
s
.46457 .98635 m .44335 .99155 L .45121 .99345 L 0 1 .53 r
F
0 g
.44179 .99551 m
.45121 .99345 L
s
.71712 .83595 m
.71712 .83595 L
s
.44636 .91523 m .42852 .92315 L .42705 .92611 L 0 1 .483 r
F
.44636 .91523 m .4368 .91848 L .42852 .92315 L F
.4493 .90717 m .4368 .91848 L .44636 .91523 L 0 1 .471 r
F
0 g
.44636 .91523 m
.4543 .91031 L
s
.44636 .91523 m
.45273 .91527 L
s
.42697 .89231 m .40839 .89109 L .41387 .89513 L 0 1 .528 r
F
0 g
.4056 .89459 m
.41387 .89513 L
s
.54189 .41286 m .54223 .38823 L .5408 .411 L 0 1 .132 r
F
.53437 .45813 m .54223 .38823 L .54073 .38759 L 0 1 .152 r
F
0 g
.54084 .38764 m
.54089 .38766 L
s
.54089 .38766 m
.54094 .38768 L
s
.53437 .45813 m .5408 .411 L .54223 .38823 L 0 1 .152 r
F
0 g
.54223 .38823 m
.54346 .37481 L
s
.54094 .38768 m
.54223 .38823 L
s
.52064 .99433 m .50936 .99262 L .50078 .99253 L 0 1 .511 r
F
.77209 .59516 m .78188 .59937 L .77735 .59437 L 0 .519 .399 r
F
.77209 .59516 m .78331 .60767 L .78188 .59937 L F
.41707 .83143 m .40187 .83292 L .39909 .83617 L 0 1 .525 r
F
.41707 .83143 m .40958 .83089 L .40187 .83292 L F
0 g
.41707 .83143 m
.42096 .83438 L
s
.42173 .82493 m .40958 .83089 L .41707 .83143 L 0 1 .523 r
F
0 g
.41707 .83143 m
.424 .82986 L
s
.55023 .45615 m
.55028 .4696 L
s
.54437 .48304 m .54677 .47584 L .55008 .42386 L 0 1 .218 r
F
0 g
.5472 .46919 m
.55008 .42386 L
s
.54677 .47584 m
.5472 .46919 L
s
.55008 .42386 m
.55023 .45615 L
s
.54797 .47945 m
.5488 .44405 L
s
.51141 .45842 m .50947 .43656 L .50978 .45184 L 0 1 .254 r
F
.50677 .4749 m .50947 .43656 L .50751 .43208 L 0 1 .26 r
F
.50677 .4749 m .50978 .45184 L .50947 .43656 L F
0 g
.50947 .43656 m
.51098 .41771 L
s
.60627 .32511 m
.60636 .32539 L
s
.60615 .32469 m
.60627 .32511 L
s
.60557 .3227 m
.60615 .32469 L
s
.60485 .33041 m
.60557 .3227 L
s
.44384 .81846 m .42839 .82322 L .43266 .82529 L 0 1 .519 r
F
0 g
.42575 .82722 m
.43266 .82529 L
s
.38488 .94842 m .38919 .95204 L .39104 .94944 L 0 1 .495 r
F
.38488 .94842 m .37996 .95476 L .38919 .95204 L F
0 g
.38919 .95204 m
.39108 .95226 L
s
.47242 .98825 m
.47979 .98612 L
s
.47979 .98612 m
.48064 .98588 L
s
.39104 .94944 m
.39216 .94903 L
s
.39216 .94903 m
.39218 .94903 L
s
.41476 .93723 m .39382 .9455 L .40032 .9461 L 0 1 .497 r
F
0 g
.39218 .94903 m
.40032 .9461 L
s
.40044 .89019 m .38118 .88795 L .38637 .89236 L 0 1 .526 r
F
0 g
.37782 .89135 m
.38637 .89236 L
s
.35249 .8524 m .33317 .85258 L .3373 .85593 L 0 1 .533 r
F
.35249 .8524 m .33612 .85038 L .33317 .85258 L F
.35249 .8524 m .34441 .85031 L .33612 .85038 L F
.35927 .84654 m .34441 .85031 L .35249 .8524 L 0 1 .532 r
F
0 g
.35249 .8524 m
.36049 .85217 L
s
.35249 .8524 m
.35659 .85575 L
s
.32427 .91873 m .30783 .91593 L .31757 .92351 L 0 1 .505 r
F
0 g
.31757 .92351 m
.32679 .92773 L
s
.52349 .78358 m
.52361 .78362 L
s
.52444 .78394 m
.52579 .78446 L
s
.50361 .41903 m .50525 .3943 L .502 .40689 L 0 1 .156 r
F
0 g
.50525 .3943 m
.50556 .39273 L
s
.50525 .3943 m
.50791 .38917 L
s
.46646 .97629 m .45358 .97648 L .46462 .98057 L 0 1 .519 r
F
.46646 .97629 m .44608 .97204 L .45358 .97648 L F
0 g
.44454 .97482 m
.45358 .97648 L
s
.50921 .37235 m .51663 .35038 L .51679 .35445 L 0 0 .048 r
F
.50921 .37235 m .51339 .35803 L .51663 .35038 L F
0 g
.51663 .35038 m
.51961 .33482 L
s
.51339 .35803 m
.5164 .34617 L
s
.51339 .35803 m
.51663 .35038 L
s
.49331 .9774 m .50107 .98233 L .50126 .97917 L 0 1 .52 r
F
0 g
.49252 .98512 m
.50107 .98233 L
s
.50107 .98233 m
.50311 .98282 L
s
.47427 .89931 m .47982 .90464 L .48044 .90257 L 0 1 .533 r
F
.49662 .90456 m .48044 .90257 L .47982 .90464 L 0 1 .534 r
F
0 g
.47982 .90464 m
.48642 .90735 L
s
.47241 .90463 m
.47982 .90464 L
s
.46646 .97629 m .46462 .98057 L .47335 .9824 L 0 1 .519 r
F
0 g
.46462 .98057 m
.47244 .98494 L
s
.44012 .96509 m .43724 .96974 L .44608 .97204 L 0 1 .517 r
F
.44012 .96509 m .42648 .96485 L .43724 .96974 L F
0 g
.43724 .96974 m
.44454 .97482 L
s
.50677 .4749 m .50751 .43208 L .50519 .44139 L 0 1 .26 r
F
0 g
.50751 .43208 m
.50947 .43656 L
s
.50751 .43208 m
.509 .41732 L
s
.43413 .9933 m .41186 .99703 L .41955 .99923 L 0 1 .535 r
F
0 g
.40969 1.00068 m
.41955 .99923 L
s
.76502 .57003 m .76601 .58094 L .77055 .58647 L 0 .285 .307 r
F
.76502 .57003 m .76364 .57391 L .76601 .58094 L F
0 g
.76085 .58138 m
.76601 .58094 L
s
.41476 .93723 m .39568 .94287 L .39382 .9455 L 0 1 .497 r
F
.41476 .93723 m .40466 .93932 L .39568 .94287 L F
.41871 .9301 m .40466 .93932 L .41476 .93723 L 0 1 .488 r
F
0 g
.41476 .93723 m
.4234 .93347 L
s
.41476 .93723 m
.42122 .93785 L
s
.44938 .89907 m .44032 .89651 L .43243 .89634 L 0 1 .531 r
F
.4523 .89332 m .44938 .89907 L .45695 .89929 L 0 1 .529 r
F
.4523 .89332 m .44032 .89651 L .44938 .89907 L F
0 g
.44938 .89907 m
.45539 .90269 L
s
.49662 .90456 m .50303 .90887 L .50321 .90728 L 0 1 .534 r
F
0 g
.50303 .90887 m
.50546 .90948 L
s
.49583 .9089 m
.50303 .90887 L
s
.385 .94254 m .36374 .93513 L .36981 .94129 L 0 1 .509 r
F
0 g
.36041 .9381 m
.36981 .94129 L
s
.44012 .96509 m .41949 .95973 L .42648 .96485 L 0 1 .517 r
F
0 g
.41732 .96264 m
.42648 .96485 L
s
.54682 .4832 m
.54797 .47945 L
s
.31 .86269 m .2896 .86052 L .29373 .86452 L 0 1 .536 r
F
.31 .86269 m .29285 .85858 L .2896 .86052 L F
.31 .86269 m .3016 .85952 L .29285 .85858 L F
.31758 .85744 m .3016 .85952 L .31 .86269 L F
0 g
.31 .86269 m
.31848 .86345 L
s
.31 .86269 m
.31408 .86667 L
s
.30192 .88369 m .28539 .88269 L .29437 .88856 L 0 1 .527 r
F
0 g
.29437 .88856 m
.30328 .89145 L
s
.50612 .79225 m
.51102 .7885 L
s
.502 .40689 m .50711 .38176 L .50409 .39009 L 0 .931 .112 r
F
0 g
.50529 .38677 m
.50711 .38176 L
s
.50711 .38176 m
.50863 .37435 L
s
.49331 .9774 m .47658 .98286 L .4813 .98569 L 0 1 .52 r
F
.47658 .98286 m .48013 .98543 L .4813 .98569 L F
.49329 .98527 m .47658 .98286 L .4813 .98595 L 0 1 .513 r
F
.47658 .98286 m .47335 .9824 L .47946 .98513 L F
.47658 .98286 m .47396 .98074 L .47335 .9824 L F
.49331 .9774 m .47456 .98088 L .47658 .98286 L 0 1 .52 r
F
.49329 .98527 m .47456 .98088 L .47658 .98286 L 0 1 .513 r
F
.47456 .98088 m .47396 .98074 L .47658 .98286 L F
.47456 .98088 m .47415 .98095 L .47658 .98286 L 0 1 .52 r
F
.47658 .98286 m .47396 .98099 L .47334 .98392 L F
.47415 .98095 m .47396 .98099 L .47658 .98286 L F
.47658 .98286 m .47946 .98513 L .48013 .98543 L 0 1 .513 r
F
.47658 .98286 m .48013 .98543 L .4813 .98595 L F
.47658 .98286 m .47334 .98392 L .48013 .98543 L 0 1 .52 r
F
0 g
.47924 .98523 m
.48013 .98543 L
s
.48064 .98588 m
.4807 .98586 L
s
.4807 .98586 m
.48094 .98579 L
s
.35479 .93149 m .33324 .9229 L .33888 .92952 L 0 1 .507 r
F
0 g
.32937 .9258 m
.33888 .92952 L
s
.46745 .80295 m .47058 .80795 L .47158 .80486 L 0 1 .51 r
F
.46745 .80295 m .46467 .81056 L .47058 .80795 L F
.48397 .80129 m .47158 .80486 L .47058 .80795 L 0 1 .506 r
F
0 g
.47058 .80795 m
.47514 .80982 L
s
.51737 .78717 m
.51742 .78713 L
s
.51805 .78656 m
.51828 .78635 L
s
.49329 .98527 m .4813 .98595 L .49251 .98903 L 0 1 .513 r
F
0 g
.48013 .98543 m
.4813 .98595 L
s
.48064 .98588 m
.4813 .98595 L
s
.54911 .32026 m .55942 .3097 L .56105 .32401 L 0 .321 .156 r
F
0 g
.55942 .3097 m
.56193 .28983 L
s
.55432 .30811 m
.55942 .3097 L
s
.46467 .81056 m .45155 .81342 L .45016 .81629 L 0 1 .514 r
F
.46467 .81056 m .45777 .81097 L .45155 .81342 L F
.46745 .80295 m .45777 .81097 L .46467 .81056 L 0 1 .51 r
F
0 g
.46467 .81056 m
.47058 .80795 L
s
.46467 .81056 m
.4691 .81248 L
s
.80279 .63578 m
.80332 .63938 L
s
.56135 .48371 m
.5614 .48257 L
s
.56114 .48898 m
.56135 .48371 L
s
.56095 .49343 m
.56114 .48898 L
s
.5583 .50014 m
.55979 .48791 L
s
.55979 .48791 m
.55982 .48766 L
s
.55982 .48766 m
.56139 .47481 L
s
.51184 .5095 m .51326 .45189 L .51141 .45842 L 0 1 .268 r
F
.51184 .5095 m .51455 .4639 L .51326 .45189 L F
0 g
.51326 .45189 m
.51476 .433 L
s
.65534 .50545 m
.65573 .50772 L
s
.5442 .76715 m
.5452 .76555 L
s
.44758 .81138 m .45016 .81629 L .45155 .81342 L 0 1 .517 r
F
.44758 .81138 m .44384 .81846 L .45016 .81629 L F
0 g
.45016 .81629 m
.45461 .8182 L
s
.64377 .46228 m
.64394 .46211 L
s
.64356 .46249 m
.64377 .46228 L
s
.63978 .46623 m
.64017 .46583 L
s
.64017 .46583 m
.64109 .46493 L
s
.64211 .46392 m
.64356 .46249 L
s
.6573 .43565 m .66424 .4984 L .66002 .48568 L 0 .76 .193 r
F
.6573 .43565 m .66812 .47713 L .66424 .4984 L F
0 g
.6573 .43565 m
.66002 .48568 L
s
.65356 .45945 m
.65371 .45846 L
s
.65371 .45846 m
.65486 .45114 L
s
.65486 .45114 m
.6573 .43565 L
s
.48397 .80129 m .47732 .80201 L .47158 .80486 L 0 1 .506 r
F
.48575 .79292 m .48397 .80129 L .4894 .7982 L 0 1 .499 r
F
.48575 .79292 m .47732 .80201 L .48397 .80129 L F
0 g
.48397 .80129 m
.48852 .80317 L
s
.34512 .88118 m .34685 .88851 L .34945 .88636 L 0 1 .525 r
F
.34512 .88118 m .33837 .88647 L .34685 .88851 L F
0 g
.34685 .88851 m
.35195 .89337 L
s
.49329 .98527 m .49251 .98903 L .50105 .99027 L 0 1 .513 r
F
0 g
.49251 .98903 m
.50078 .99253 L
s
.4523 .89332 m .45695 .89929 L .45799 .89701 L 0 1 .529 r
F
0 g
.44938 .89907 m
.45695 .89929 L
s
.45695 .89929 m
.45766 .89966 L
s
.53424 .77259 m
.53533 .77301 L
s
.39865 .82979 m .39909 .83617 L .40187 .83292 L 0 1 .527 r
F
.39865 .82979 m .39137 .83776 L .39909 .83617 L F
0 g
.39909 .83617 m
.403 .83912 L
s
.48575 .79292 m .4894 .7982 L .48999 .7948 L 0 1 .499 r
F
.50151 .79032 m .48999 .7948 L .4894 .7982 L 0 1 .491 r
F
0 g
.4894 .7982 m
.49402 .80013 L
s
.48397 .80129 m
.4894 .7982 L
s
.4523 .89332 m .43462 .89282 L .44032 .89651 L 0 1 .529 r
F
0 g
.43243 .89634 m
.44032 .89651 L
s
.39105 .9487 m
.39218 .94903 L
s
.32517 .85216 m .32582 .85803 L .32876 .85586 L 0 1 .535 r
F
0 g
.32876 .85586 m
.3373 .85593 L
s
.32517 .85216 m .31758 .85744 L .32582 .85803 L 0 1 .535 r
F
0 g
.32582 .85803 m
.33021 .86151 L
s
.41453 .95211 m .41062 .95699 L .41949 .95973 L 0 1 .512 r
F
.41453 .95211 m .40023 .9514 L .41062 .95699 L F
0 g
.41062 .95699 m
.41732 .96264 L
s
.54406 .76524 m
.5452 .76555 L
s
.53168 .50229 m .53284 .50704 L .53566 .47923 L 0 .885 .251 r
F
0 g
.534 .49557 m
.53566 .47923 L
s
.53484 .50558 m
.53566 .47923 L
s
.53452 .51593 m
.53484 .50558 L
s
.53113 .48312 m
.53249 .46827 L
s
.5221 .97616 m
.52412 .97665 L
s
.44384 .81846 m .43015 .82053 L .42839 .82322 L 0 1 .519 r
F
.44384 .81846 m .43678 .81849 L .43015 .82053 L F
.44758 .81138 m .43678 .81849 L .44384 .81846 L 0 1 .517 r
F
0 g
.44384 .81846 m
.44809 .82052 L
s
.44384 .81846 m
.45016 .81629 L
s
.44012 .96509 m .44608 .97204 L .44711 .97022 L 0 1 .517 r
F
.46646 .97629 m .44711 .97022 L .44608 .97204 L 0 1 .519 r
F
0 g
.44608 .97204 m
.45358 .97648 L
s
.43724 .96974 m
.44608 .97204 L
s
.52888 .9966 m
.52898 .99663 L
s
.52821 .99642 m
.52888 .9966 L
s
.52401 .99526 m
.52502 .99554 L
s
.52729 .99617 m
.52821 .99642 L
s
.36607 .84062 m .36702 .84616 L .36963 .84373 L 0 1 .531 r
F
.36607 .84062 m .35927 .84654 L .36702 .84616 L F
0 g
.36702 .84616 m
.37129 .84905 L
s
.39137 .83776 m .37356 .84008 L .37755 .84288 L 0 1 .529 r
F
0 g
.36963 .84373 m
.37755 .84288 L
s
.80827 .64737 m
.81382 .64556 L
s
.37304 .88656 m .35335 .88312 L .35817 .88792 L 0 1 .526 r
F
0 g
.34945 .88636 m
.35817 .88792 L
s
.50126 .97917 m
.50132 .97915 L
s
.50132 .97915 m
.50298 .97858 L
s
.50372 .97833 m
.50519 .97783 L
s
.50532 .97778 m
.50951 .97635 L
s
.33837 .88647 m .31792 .88145 L .32255 .88672 L 0 1 .526 r
F
.37996 .95476 m .35769 .96063 L .36419 .9618 L 0 1 .503 r
F
.37996 .95476 m .35992 .95829 L .35769 .96063 L F
.37996 .95476 m .36948 .95577 L .35992 .95829 L F
.38488 .94842 m .36948 .95577 L .37996 .95476 L 0 1 .495 r
F
0 g
.37996 .95476 m
.38919 .95204 L
s
.37996 .95476 m
.38641 .95593 L
s
.30948 .8788 m .31059 .88646 L .31352 .88446 L 0 1 .526 r
F
.30948 .8788 m .30192 .88369 L .31059 .88646 L F
0 g
.31059 .88646 m
.31549 .89183 L
s
.56241 .34504 m .57254 .3218 L .57459 .33286 L 0 .264 .149 r
F
0 g
.57139 .32295 m
.57254 .3218 L
s
.57181 .32241 m
.57427 .30241 L
s
.57254 .3218 m
.57398 .30477 L
s
.46646 .97629 m .47335 .9824 L .47396 .98074 L 0 1 .519 r
F
0 g
.47335 .9824 m
.47364 .98252 L
s
.46462 .98057 m
.47335 .9824 L
s
.5188 .49529 m .52017 .49342 L .52197 .46945 L 0 .999 .26 r
F
0 g
.58931 .32004 m
.59059 .32036 L
s
.57995 .33165 m .5796 .35831 L .57762 .34851 L 0 .457 .162 r
F
.57975 .31412 m .57946 .34572 L .57741 .32933 L 0 .687 .163 r
F
.57975 .31412 m .58523 .35878 L .57946 .34572 L F
.41453 .95211 m .39382 .94572 L .40023 .9514 L 0 1 .512 r
F
0 g
.39218 .94903 m
.40023 .9514 L
s
.52035 .99106 m .50936 .99262 L .52064 .99433 L 0 1 .491 r
F
0 g
.52064 .99433 m
.52401 .99526 L
s
.52035 .99106 m .50105 .99027 L .50936 .99262 L 0 1 .491 r
F
0 g
.50078 .99253 m
.50936 .99262 L
s
.74344 .53368 m .74632 .53966 L .75097 .54662 L 0 0 .134 r
F
.74344 .53368 m .7431 .53412 L .74632 .53966 L F
0 g
.74194 .53737 m
.74632 .53966 L
s
.74622 .53949 m
.74627 .53956 L
s
.74627 .53956 m
.74632 .53966 L
s
.52205 .77836 m
.5236 .77659 L
s
.52384 .77632 m
.52597 .77389 L
s
.40538 .88437 m .40839 .89109 L .41025 .88875 L 0 1 .525 r
F
0 g
.40527 .89431 m
.4056 .89459 L
s
.40538 .88437 m .40044 .89019 L .40839 .89109 L 0 1 .525 r
F
.42697 .89231 m .41025 .88875 L .40839 .89109 L 0 1 .528 r
F
0 g
.40839 .89109 m
.41387 .89513 L
s
.50151 .79032 m .49518 .79142 L .48999 .7948 L 0 1 .491 r
F
.50227 .78089 m .50151 .79032 L .50639 .7866 L 0 1 .482 r
F
.50227 .78089 m .49518 .79142 L .50151 .79032 L F
0 g
.50151 .79032 m
.50612 .79225 L
s
.53411 .7686 m
.53452 .76804 L
s
.39137 .83776 m .37619 .83763 L .37356 .84008 L 0 1 .529 r
F
.39137 .83776 m .38382 .83664 L .37619 .83763 L F
0 g
.39137 .83776 m
.39532 .84056 L
s
.39865 .82979 m .38382 .83663 L .39137 .83776 L 0 1 .527 r
F
0 g
.39137 .83776 m
.39909 .83617 L
s
.43703 .98678 m .44335 .99155 L .44438 .98889 L 0 1 .534 r
F
.43703 .98678 m .43413 .9933 L .44335 .99155 L F
.46457 .98635 m .44438 .98889 L .44335 .99155 L 0 1 .53 r
F
0 g
.44335 .99155 m
.45121 .99345 L
s
.76502 .57003 m .77055 .58647 L .77505 .58763 L 0 .285 .307 r
F
0 g
.77055 .58647 m
.77209 .59516 L
s
.41453 .95211 m .41949 .95973 L .42093 .95779 L 0 1 .512 r
F
.44012 .96509 m .42093 .95779 L .41949 .95973 L 0 1 .517 r
F
0 g
.41949 .95973 m
.42648 .96485 L
s
.41062 .95699 m
.41949 .95973 L
s
.45225 .89905 m .45693 .90198 L .45798 .89863 L 0 1 .456 r
F
.45225 .89905 m .4493 .90717 L .45693 .90198 L F
0 g
.45693 .90198 m
.46117 .90152 L
s
.40044 .89019 m .38343 .88568 L .38118 .88795 L 0 1 .526 r
F
.40044 .89019 m .39168 .88664 L .38343 .88568 L F
.40538 .88437 m .39168 .88664 L .40044 .89019 L 0 1 .525 r
F
0 g
.40044 .89019 m
.40839 .89109 L
s
.40044 .89019 m
.40527 .89431 L
s
.49662 .90456 m .48764 .90254 L .48044 .90257 L 0 1 .534 r
F
0 g
.48044 .90257 m
.48764 .90254 L
s
.47427 .89931 m
.48044 .90257 L
s
.48575 .79292 m .47307 .80014 L .47732 .80201 L 0 1 .499 r
F
0 g
.47158 .80486 m
.47732 .80201 L
s
.33837 .88647 m .32085 .87943 L .31792 .88145 L 0 1 .526 r
F
.33837 .88647 m .32963 .88159 L .32085 .87943 L F
0 g
.31352 .88446 m
.32255 .88672 L
s
.34512 .88118 m .32963 .88159 L .33837 .88647 L 0 1 .525 r
F
0 g
.33837 .88647 m
.34685 .88851 L
s
.33837 .88647 m
.34296 .89173 L
s
.46745 .80295 m .45362 .80905 L .45777 .81097 L 0 1 .51 r
F
0 g
.45155 .81342 m
.45777 .81097 L
s
.40229 .9981 m .37922 1.00025 L .38666 1.00283 L 0 1 .538 r
F
.50361 .41903 m .50015 .41974 L .50093 .42423 L 0 1 .156 r
F
.50361 .41903 m .502 .40689 L .50015 .41974 L F
.50519 .44139 m .50361 .41903 L .5021 .43383 L 0 1 .227 r
F
0 g
.40187 .83292 m
.40958 .83089 L
s
.42173 .82493 m .40554 .8286 L .40958 .83089 L 0 1 .523 r
F
.53437 .45813 m .54073 .38759 L .53728 .40958 L 0 1 .152 r
F
0 g
.54073 .38759 m
.54081 .3871 L
s
.54073 .38759 m
.54084 .38764 L
s
.50227 .78089 m .50639 .7866 L .50657 .78274 L 0 1 .482 r
F
0 g
.50151 .79032 m
.50639 .7866 L
s
.50639 .7866 m
.51102 .7885 L
s
.46457 .98635 m .45349 .98665 L .44438 .98889 L 0 1 .53 r
F
.46644 .97918 m .46457 .98635 L .47334 .98392 L 0 1 .528 r
F
.46644 .97918 m .45349 .98665 L .46457 .98635 L F
0 g
.46457 .98635 m
.47242 .98825 L
s
.43413 .9933 m .41331 .99458 L .41186 .99703 L 0 1 .535 r
F
.43413 .9933 m .42286 .99298 L .41331 .99458 L F
.43703 .98678 m .42286 .99298 L .43413 .9933 L 0 1 .534 r
F
0 g
.43413 .9933 m
.44335 .99155 L
s
.43413 .9933 m
.44179 .99551 L
s
.46644 .97918 m .47334 .98392 L .47396 .98099 L 0 1 .528 r
F
0 g
.46457 .98635 m
.47334 .98392 L
s
.47334 .98392 m
.47924 .98523 L
s
.42641 .81829 m .42839 .82322 L .43015 .82053 L 0 1 .521 r
F
.42641 .81829 m .42173 .82493 L .42839 .82322 L F
0 g
.42839 .82322 m
.43266 .82529 L
s
.32427 .91873 m .3027 .90885 L .30783 .91593 L 0 1 .505 r
F
0 g
.45798 .89863 m
.45998 .89702 L
s
.45998 .89702 m
.46545 .8926 L
s
.34829 .96254 m .35211 .96645 L .35434 .96413 L 0 1 .499 r
F
0 g
.35434 .96413 m
.36419 .9618 L
s
.34829 .96254 m .34245 .96816 L .35211 .96645 L 0 1 .499 r
F
0 g
.35211 .96645 m
.35891 .96778 L
s
.37892 .88094 m .38118 .88795 L .38343 .88568 L 0 1 .525 r
F
.37892 .88094 m .37304 .88656 L .38118 .88795 L F
0 g
.38118 .88795 m
.38637 .89236 L
s
.49662 .90456 m
.50321 .90728 L
s
.50321 .90728 m
.50741 .90746 L
s
.42267 .9229 m .42705 .92611 L .42852 .92315 L 0 1 .476 r
F
.42267 .9229 m .41871 .9301 L .42705 .92611 L F
0 g
.42705 .92611 m
.43346 .92614 L
s
.36063 .92656 m .36374 .93513 L .36597 .93314 L 0 1 .504 r
F
.36063 .92656 m .35479 .93149 L .36374 .93513 L F
.385 .94254 m .36597 .93314 L .36374 .93513 L 0 1 .509 r
F
0 g
.36374 .93513 m
.36981 .94129 L
s
.35479 .93149 m .33583 .92096 L .33324 .9229 L 0 1 .507 r
F
.35479 .93149 m .34507 .92464 L .33583 .92096 L F
.36063 .92656 m .34507 .92464 L .35479 .93149 L 0 1 .504 r
F
0 g
.35479 .93149 m
.36374 .93513 L
s
.35479 .93149 m
.36041 .9381 L
s
.52178 .97516 m
.5233 .97456 L
s
.54848 .74866 m
.54864 .7483 L
s
.52064 .99433 m
.52351 .99445 L
s
.52351 .99445 m
.52502 .99451 L
s
.42697 .89231 m .41822 .88927 L .41025 .88875 L 0 1 .528 r
F
.43093 .88641 m .42697 .89231 L .43462 .89282 L 0 1 .526 r
F
.43093 .88641 m .41822 .88927 L .42697 .89231 L F
0 g
.42697 .89231 m
.43243 .89634 L
s
.54332 .37528 m .55361 .34209 L .55124 .35893 L 0 0 .096 r
F
0 g
.54763 .35309 m
.54942 .34733 L
s
.54763 .35309 m
.54969 .33841 L
s
.55361 .34209 m
.55818 .32707 L
s
.55689 .49723 m
.55723 .48937 L
s
.55723 .48937 m
.55737 .48622 L
s
.55619 .48391 m
.55652 .48114 L
s
.53375 .32777 m .53114 .35247 L .5305 .34459 L 0 .203 .131 r
F
0 g
.53375 .32777 m
.53375 .32776 L
s
.53375 .32777 m .5357 .34968 L .53114 .35247 L 0 .203 .131 r
F
.53375 .32777 m .54113 .33808 L .5357 .34968 L F
.53375 .32777 m .54434 .32127 L .54113 .33808 L F
0 g
.53375 .32777 m
.53375 .32777 L
s
.73172 .51405 m .74017 .52749 L .73547 .51971 L 0 0 .118 r
F
.73172 .51405 m .74344 .53368 L .74017 .52749 L F
.73172 .51405 m .7431 .53412 L .74344 .53368 L F
0 g
.73934 .52844 m
.7431 .53412 L
s
.7431 .53412 m
.74622 .53949 L
s
.7535 .55473 m .76258 .56253 L .75794 .55642 L 0 .247 .284 r
F
.7535 .55473 m .76502 .57003 L .76258 .56253 L F
.7535 .55473 m .76364 .57391 L .76502 .57003 L F
0 g
.76364 .57391 m
.76601 .58094 L
s
.7592 .57217 m
.76364 .57391 L
s
.4493 .90717 m .43072 .91868 L .4368 .91848 L 0 1 .471 r
F
.50227 .78089 m .49088 .78957 L .49518 .79142 L 0 1 .482 r
F
0 g
.48999 .7948 m
.49518 .79142 L
s
.54108 .75602 m
.54284 .75272 L
s
.64702 .50105 m
.64733 .49195 L
s
.64733 .49195 m
.64751 .48652 L
s
.64751 .48652 m
.64759 .48413 L
s
.64759 .48413 m
.64776 .47924 L
s
.64776 .47924 m
.64797 .47294 L
s
.64813 .46825 m
.64814 .46783 L
s
.64823 .46538 m
.64877 .44938 L
s
.64877 .44938 m
.64914 .43843 L
s
.64914 .43843 m
.64918 .4373 L
s
.45998 .89702 m
.46542 .89702 L
s
.45799 .89701 m
.45998 .89702 L
s
.33099 .91395 m .33324 .9229 L .33583 .92096 L 0 1 .502 r
F
.33099 .91395 m .32427 .91873 L .33324 .9229 L F
0 g
.33324 .9229 m
.33888 .92952 L
s
.50677 .4749 m .50862 .46828 L .50978 .45184 L 0 1 .26 r
F
.40621 .99211 m .41186 .99703 L .41331 .99458 L 0 1 .537 r
F
.40621 .99211 m .40229 .9981 L .41186 .99703 L F
0 g
.41186 .99703 m
.41955 .99923 L
s
.37304 .88656 m .35596 .88095 L .35335 .88312 L 0 1 .526 r
F
.37304 .88656 m .3644 .88243 L .35596 .88095 L F
.37892 .88094 m .3644 .88243 L .37304 .88656 L 0 1 .525 r
F
0 g
.37304 .88656 m
.37782 .89135 L
s
.37304 .88656 m
.38118 .88795 L
s
.43093 .88641 m .43462 .89282 L .43608 .89046 L 0 1 .526 r
F
.4523 .89332 m .43608 .89046 L .43462 .89282 L 0 1 .529 r
F
0 g
.43462 .89282 m
.44032 .89651 L
s
.42697 .89231 m
.43462 .89282 L
s
.53846 .75166 m
.54284 .75272 L
s
.53254 .97408 m
.53275 .97415 L
s
.49329 .98527 m .50105 .99027 L .50124 .98883 L 0 1 .513 r
F
.52035 .99106 m .50124 .98883 L .50105 .99027 L 0 1 .491 r
F
0 g
.50105 .99027 m
.50936 .99262 L
s
.49251 .98903 m
.50105 .99027 L
s
.52037 .34618 m .52953 .33304 L .52623 .34841 L 0 .028 .099 r
F
0 g
.52953 .33304 m
.53375 .32777 L
s
.42173 .82493 m .40766 .82608 L .40554 .8286 L 0 1 .523 r
F
.42173 .82493 m .41461 .82451 L .40766 .82608 L F
.42641 .81829 m .41461 .82451 L .42173 .82493 L 0 1 .521 r
F
0 g
.42173 .82493 m
.42575 .82722 L
s
.42173 .82493 m
.42839 .82322 L
s
.53145 .76002 m
.53411 .76104 L
s
.35927 .84654 m .34055 .84707 L .34441 .85031 L 0 1 .532 r
F
.35927 .84654 m .34351 .84486 L .34055 .84707 L F
.35927 .84654 m .35154 .84463 L .34351 .84486 L F
.36607 .84062 m .35154 .84463 L .35927 .84654 L 0 1 .531 r
F
0 g
.35927 .84654 m
.36702 .84616 L
s
.35927 .84654 m
.3631 .84977 L
s
.44758 .81138 m .43279 .81645 L .43678 .81849 L 0 1 .517 r
F
0 g
.43015 .82053 m
.43678 .81849 L
s
.385 .94254 m .37508 .93632 L .36597 .93314 L 0 1 .509 r
F
.39479 .94274 m .39382 .9455 L .39568 .94287 L 0 1 .486 r
F
.38991 .93758 m .385 .94254 L .3932 .9455 L 0 1 .506 r
F
.38991 .93758 m .3932 .9455 L .39334 .94523 L F
.38991 .93758 m .39351 .94561 L .39351 .94559 L F
.38991 .93758 m .39352 .94561 L .39364 .94534 L F
.39472 .94273 m .39382 .94572 L .39566 .94373 L F
.38991 .93758 m .39364 .94534 L .39472 .94273 L F
.39472 .94273 m .39364 .94534 L .39479 .94274 L 0 1 .486 r
F
.39364 .94534 m .39382 .9455 L .39479 .94274 L F
.39364 .94534 m .39382 .94572 L .39472 .94273 L 0 1 .506 r
F
.38982 .94203 m .39364 .94534 L .39472 .94273 L 0 1 .486 r
F
.39483 .93263 m .38991 .93758 L .39569 .93974 L 0 1 .503 r
F
.39483 .93263 m .39569 .93974 L .39586 .93943 L F
.39483 .93263 m .39592 .93982 L .39704 .93762 L F
.39714 .93771 m .3961 .93976 L .39847 .9389 L 0 1 .473 r
F
.41871 .9301 m .39847 .9389 L .40466 .93932 L 0 1 .488 r
F
.41871 .9301 m .40033 .93624 L .39847 .9389 L F
.39776 .93594 m .39847 .9389 L .40033 .93624 L 0 1 .473 r
F
.39483 .93263 m .39704 .93762 L .39776 .93594 L 0 1 .503 r
F
.39477 .93559 m .39704 .93762 L .39776 .93594 L 0 1 .473 r
F
.39704 .93762 m .39847 .9389 L .39776 .93594 L F
.39776 .93594 m .39704 .93762 L .39782 .936 L 0 1 .503 r
F
.39782 .936 m .39844 .94076 L .40029 .93878 L F
.39704 .93762 m .39844 .94076 L .39782 .936 L F
.39704 .93762 m .3961 .93976 L .39714 .93771 L 0 1 .473 r
F
.39477 .93559 m .39607 .93964 L .39704 .93762 L F
.39607 .93964 m .3961 .93976 L .39704 .93762 L F
.39977 .92767 m .39483 .93263 L .39856 .93407 L 0 1 .498 r
F
.39874 .93372 m .39856 .93407 L .39868 .93402 L 0 1 .457 r
F
.40076 .93004 m .39917 .93307 L .40314 .93224 L F
.39917 .93307 m .39868 .93402 L .39871 .93401 L F
.39917 .93307 m .39871 .93401 L .40314 .93224 L F
.41871 .9301 m .40902 .93247 L .40033 .93624 L 0 1 .488 r
F
.42267 .9229 m .40314 .93224 L .40902 .93247 L 0 1 .476 r
F
.42267 .9229 m .40501 .92956 L .40314 .93224 L F
.40106 .92921 m .40314 .93224 L .40501 .92956 L 0 1 .457 r
F
.40103 .92917 m .40071 .93 L .40106 .92921 L 0 1 .498 r
F
.39977 .92767 m .40066 .92987 L .40103 .92917 L F
.40066 .92987 m .40071 .93 L .40103 .92917 L F
.40473 .92258 m .40439 .92303 L .40782 .92553 L 0 1 .436 r
F
.40439 .92303 m .40394 .92383 L .40782 .92553 L F
.40439 .92303 m .39977 .92767 L .40145 .92834 L 0 1 .494 r
F
.40381 .92378 m .40145 .92834 L .40782 .92553 L 0 1 .436 r
F
.42267 .9229 m .41339 .92555 L .40501 .92956 L 0 1 .476 r
F
.40473 .92269 m .40439 .92303 L .40773 .93086 L 0 1 .494 r
F
.40439 .92303 m .40145 .92834 L .40773 .93086 L F
.40439 .92303 m .40381 .92378 L .40394 .92383 L 0 1 .436 r
F
.39977 .92767 m .39856 .93407 L .40071 .93 L 0 1 .498 r
F
.40381 .92378 m .39974 .9291 L .40145 .92834 L 0 1 .436 r
F
.39974 .9291 m .40071 .93 L .40106 .92921 L 0 1 .457 r
F
.40071 .93 m .40314 .93224 L .40106 .92921 L F
.40106 .92921 m .40071 .93 L .40109 .92924 L 0 1 .498 r
F
.40109 .92924 m .40307 .93581 L .40493 .93384 L F
.40071 .93 m .40307 .93581 L .40109 .92924 L F
.40071 .93 m .39856 .93407 L .40307 .93581 L F
.39974 .9291 m .39477 .93559 L .39856 .93407 L 0 1 .457 r
F
.39974 .9291 m .39856 .93407 L .39874 .93372 L F
.39974 .9291 m .39868 .93402 L .40076 .93004 L F
.39586 .93943 m .39569 .93974 L .39592 .93982 L 0 1 .503 r
F
.39605 .93957 m .39592 .93982 L .3961 .93976 L 0 1 .473 r
F
.39704 .93762 m .39592 .93982 L .39844 .94076 L 0 1 .503 r
F
.39477 .93559 m .38982 .94203 L .39592 .93982 L 0 1 .473 r
F
.39477 .93559 m .39592 .93982 L .39605 .93957 L F
.39334 .94523 m .3932 .9455 L .39351 .94561 L 0 1 .506 r
F
.39364 .94534 m .39351 .94561 L .39382 .9455 L 0 1 .486 r
F
.39351 .94559 m .39351 .94561 L .39352 .94561 L 0 1 .506 r
F
.38982 .94203 m .38488 .94842 L .39351 .94561 L 0 1 .486 r
F
.38982 .94203 m .39351 .94561 L .39364 .94534 L F
.39364 .94534 m .39352 .94561 L .39382 .94572 L 0 1 .506 r
F
0 g
.39351 .94561 m
.39352 .94561 L
s
.38935 .94696 m
.39105 .9487 L
s
.38991 .93758 m .37508 .93632 L .385 .94254 L 0 1 .506 r
F
0 g
.385 .94254 m
.38748 .94506 L
s
.385 .94254 m
.38846 .94379 L
s
.54543 .73615 m
.54547 .73616 L
s
.28128 .85907 m .28149 .86535 L .28473 .86343 L 0 1 .538 r
F
0 g
.28473 .86343 m
.29373 .86452 L
s
.28128 .85907 m .27296 .86372 L .28149 .86535 L 0 1 .538 r
F
0 g
.28149 .86535 m
.28587 .86949 L
s
.4493 .90717 m .43219 .91568 L .43072 .91868 L 0 1 .471 r
F
0 g
.42876 .92301 m
.4368 .91848 L
s
.42852 .92315 m
.42876 .92301 L
s
.4493 .90717 m .44016 .91075 L .43219 .91568 L 0 1 .471 r
F
.45225 .89905 m .44016 .91075 L .4493 .90717 L 0 1 .456 r
F
0 g
.4493 .90717 m
.45693 .90198 L
s
.4493 .90717 m
.45535 .90698 L
s
.51533 .5015 m .51455 .4639 L .5144 .48652 L 0 1 .264 r
F
.51184 .5095 m .5144 .48652 L .51455 .4639 L 0 1 .268 r
F
0 g
.51326 .45189 m
.51455 .4639 L
s
.51455 .4639 m
.51585 .44508 L
s
.31758 .85744 m .29773 .85566 L .3016 .85952 L 0 1 .536 r
F
.31758 .85744 m .30098 .85371 L .29773 .85566 L F
.31758 .85744 m .3095 .85447 L .30098 .85371 L F
.32517 .85216 m .3095 .85447 L .31758 .85744 L 0 1 .535 r
F
0 g
.31758 .85744 m
.32582 .85803 L
s
.31758 .85744 m
.32141 .86129 L
s
.51184 .5095 m .51141 .45842 L .51024 .47789 L 0 1 .268 r
F
0 g
.50978 .45184 m
.51141 .45842 L
s
.46646 .97629 m .45584 .97203 L .44711 .97022 L 0 1 .519 r
F
0 g
.50657 .78274 m
.51116 .77855 L
s
.30192 .88369 m .28106 .8769 L .28539 .88269 L 0 1 .527 r
F
.30192 .88369 m .28431 .87507 L .28106 .8769 L F
.30192 .88369 m .29326 .87798 L .28431 .87507 L F
.30948 .8788 m .29326 .87798 L .30192 .88369 L 0 1 .526 r
F
0 g
.30192 .88369 m
.31059 .88646 L
s
.30192 .88369 m
.3062 .88946 L
s
.51681 .76576 m .52136 .77214 L .52111 .7676 L 0 1 .458 r
F
0 g
.5205 .77309 m
.52136 .77214 L
s
.52136 .77214 m
.52597 .77388 L
s
.32427 .91873 m .30563 .90699 L .3027 .90885 L 0 1 .505 r
F
.32427 .91873 m .31488 .91123 L .30563 .90699 L F
.33099 .91395 m .31488 .91123 L .32427 .91873 L 0 1 .502 r
F
0 g
.32427 .91873 m
.32937 .9258 L
s
.32427 .91873 m
.33324 .9229 L
s
.78331 .60767 m .79319 .61106 L .78867 .60652 L 0 .572 .413 r
F
.78331 .60767 m .79451 .61908 L .79319 .61106 L F
.71668 .49454 m .72758 .50516 L .73159 .5172 L 0 .47 .037 r
F
0 g
.72758 .50516 m
.73172 .51405 L
s
.49331 .9774 m .4745 .98081 L .47456 .98088 L 0 1 .52 r
F
.49329 .98527 m .4825 .98197 L .4745 .98081 L 0 1 .513 r
F
.47456 .98088 m .4745 .98081 L .47396 .98074 L F
.49329 .98527 m .4745 .98081 L .47456 .98088 L F
.49331 .9774 m .48252 .97819 L .4745 .98081 L 0 1 .52 r
F
.47456 .98088 m .4745 .98081 L .47396 .98099 L F
.49411 .96933 m .49331 .9774 L .50154 .97432 L 0 1 .517 r
F
.49411 .96933 m .48252 .97819 L .49331 .9774 L F
0 g
.49331 .9774 m
.50126 .97917 L
s
.52037 .34618 m .51718 .36708 L .51703 .36161 L 0 .028 .099 r
F
.52037 .34618 m .52114 .36142 L .51718 .36708 L F
.52037 .34618 m .52623 .34841 L .52114 .36142 L F
0 g
.52623 .34841 m
.52953 .33304 L
s
.394 .94552 m
.40032 .9461 L
s
.39568 .94287 m
.40466 .93932 L
s
.40008 .93901 m
.40466 .93932 L
s
.40229 .9981 m .38107 .99799 L .37922 1.00025 L 0 1 .538 r
F
.40229 .9981 m .39097 .99707 L .38107 .99799 L F
.40621 .99211 m .39097 .99707 L .40229 .9981 L 0 1 .537 r
F
0 g
.40229 .9981 m
.40969 1.00068 L
s
.40229 .9981 m
.41186 .99703 L
s
.50519 .44139 m .5021 .43383 L .50287 .44215 L 0 1 .227 r
F
.50677 .4749 m .50519 .44139 L .50403 .45782 L 0 1 .26 r
F
.41453 .95211 m .39566 .94373 L .39382 .94572 L 0 1 .512 r
F
0 g
.39382 .94572 m
.40023 .9514 L
s
.39352 .94561 m
.39382 .94572 L
s
.49759 .89896 m .48764 .90254 L .49662 .90456 L 0 1 .525 r
F
.47657 .8926 m .47427 .89931 L .48147 .89906 L 0 1 .528 r
F
.47657 .8926 m .46542 .89702 L .47427 .89931 L F
.46644 .97918 m .44594 .98486 L .45349 .98665 L F
0 g
.44438 .98889 m
.45349 .98665 L
s
.40538 .88437 m .3868 .88225 L .39168 .88664 L 0 1 .525 r
F
0 g
.38343 .88568 m
.39168 .88664 L
s
.51681 .76576 m .50685 .77672 L .51116 .77855 L 0 1 .458 r
F
.43093 .88641 m .41305 .88522 L .41822 .88927 L 0 1 .526 r
F
0 g
.41025 .88875 m
.41822 .88927 L
s
.47396 .98074 m
.4745 .98081 L
s
.44012 .96509 m .42978 .96009 L .42093 .95779 L 0 1 .517 r
F
.49759 .89896 m .49662 .90456 L .50353 .90452 L 0 1 .525 r
F
.42267 .9229 m .40902 .93247 L .41871 .9301 L 0 1 .476 r
F
0 g
.41871 .9301 m
.42705 .92611 L
s
.41871 .9301 m
.42486 .93054 L
s
.47023 .79503 m .47307 .80014 L .47406 .79693 L 0 1 .505 r
F
.47023 .79503 m .46745 .80295 L .47307 .80014 L F
.48575 .79292 m .47406 .79693 L .47307 .80014 L 0 1 .499 r
F
0 g
.47307 .80014 m
.47732 .80201 L
s
.49411 .96933 m .50154 .97432 L .50173 .971 L 0 1 .517 r
F
0 g
.49331 .9774 m
.50154 .97432 L
s
.50154 .97432 m
.50951 .97635 L
s
.47396 .98099 m
.47445 .98083 L
s
.47445 .98083 m
.4745 .98081 L
s
.47657 .8926 m .45974 .89317 L .46542 .89702 L 0 1 .528 r
F
.46745 .80295 m .45501 .80609 L .45362 .80905 L 0 1 .51 r
F
.46745 .80295 m .46094 .80348 L .45501 .80609 L F
.47023 .79503 m .46094 .80348 L .46745 .80295 L 0 1 .505 r
F
0 g
.46745 .80295 m
.47307 .80014 L
s
.46745 .80295 m
.47158 .80486 L
s
.51915 .90957 m
.52059 .90993 L
s
.52059 .90993 m
.5235 .91066 L
s
.52404 .9108 m
.52416 .91083 L
s
.5381 .50488 m .54189 .41286 L .53866 .45311 L 0 1 .222 r
F
0 g
.5417 .41524 m
.54189 .41286 L
s
.54081 .42636 m
.5417 .41524 L
s
.5415 .41221 m
.54189 .41286 L
s
.33278 .84682 m .33317 .85258 L .33612 .85038 L 0 1 .534 r
F
0 g
.33612 .85038 m
.34441 .85031 L
s
.33278 .84682 m .32517 .85216 L .33317 .85258 L 0 1 .534 r
F
0 g
.33317 .85258 m
.3373 .85593 L
s
.36063 .92656 m .33971 .91805 L .34507 .92464 L 0 1 .504 r
F
0 g
.33583 .92096 m
.34507 .92464 L
s
.53101 .75883 m
.53405 .75405 L
s
.54543 .73615 m
.54545 .7361 L
s
.54689 .73244 m
.5469 .73242 L
s
.48575 .79292 m .4795 .79383 L .47406 .79693 L 0 1 .499 r
F
.48754 .78417 m .48575 .79292 L .49088 .78957 L 0 1 .492 r
F
.48754 .78417 m .4795 .79383 L .48575 .79292 L F
0 g
.48575 .79292 m
.48999 .7948 L
s
.45134 .80408 m .45362 .80905 L .45501 .80609 L 0 1 .513 r
F
.45134 .80408 m .44758 .81138 L .45362 .80905 L F
0 g
.45362 .80905 m
.45777 .81097 L
s
.48754 .78417 m .49088 .78957 L .49147 .78601 L 0 1 .492 r
F
.50227 .78089 m .49147 .78601 L .49088 .78957 L 0 1 .482 r
F
0 g
.49088 .78957 m
.49518 .79142 L
s
.48575 .79292 m
.49088 .78957 L
s
.43703 .98678 m .41548 .99089 L .42286 .99298 L 0 1 .534 r
F
0 g
.41331 .99458 m
.42286 .99298 L
s
.38991 .93758 m .36931 .93017 L .37508 .93632 L 0 1 .506 r
F
0 g
.36597 .93314 m
.37508 .93632 L
s
.35189 .87586 m .35335 .88312 L .35596 .88095 L 0 1 .524 r
F
.35189 .87586 m .34512 .88118 L .35335 .88312 L F
0 g
.35335 .88312 m
.35817 .88792 L
s
.49411 .96933 m .47489 .97653 L .48252 .97819 L 0 1 .517 r
F
0 g
.4745 .98081 m
.48252 .97819 L
s
.73976 .83857 m
.74027 .83849 L
s
.77652 .58362 m .77735 .59437 L .78188 .59937 L 0 .324 .33 r
F
.77652 .58362 m .77505 .58763 L .77735 .59437 L F
0 g
.77209 .59516 m
.77735 .59437 L
s
.74344 .53368 m .75097 .54662 L .75475 .55128 L 0 0 .134 r
F
0 g
.75097 .54662 m
.7535 .55473 L
s
.50625 .90578 m
.50817 .90667 L
s
.44758 .81138 m .43456 .8137 L .43279 .81645 L 0 1 .517 r
F
.44758 .81138 m .4409 .81152 L .43456 .8137 L F
.45134 .80408 m .4409 .81152 L .44758 .81138 L 0 1 .513 r
F
0 g
.44758 .81138 m
.45155 .81342 L
s
.44758 .81138 m
.45362 .80905 L
s
.34829 .96254 m .33175 .96812 L .34245 .96816 L 0 1 .499 r
F
0 g
.34245 .96816 m
.35211 .96645 L
s
.4523 .89332 m .44366 .89068 L .43608 .89046 L 0 1 .529 r
F
0 g
.43608 .89046 m
.44366 .89068 L
s
.4523 .89332 m
.45799 .89701 L
s
.37289 .83463 m .37356 .84008 L .37619 .83763 L 0 1 .53 r
F
.37289 .83463 m .36607 .84062 L .37356 .84008 L F
0 g
.37356 .84008 m
.37755 .84288 L
s
.53756 .74619 m
.54048 .73995 L
s
.45591 .88612 m .4523 .89332 L .45974 .89317 L 0 1 .525 r
F
.45591 .88612 m .44366 .89068 L .4523 .89332 L F
.50921 .37235 m .51679 .35445 L .51342 .36739 L 0 0 .048 r
F
0 g
.51679 .35445 m
.52037 .34618 L
s
.52911 .74758 m .52075 .76075 L .52503 .76225 L 0 1 .434 r
F
0 g
.52111 .7676 m
.52503 .76225 L
s
.54911 .32026 m .54716 .34786 L .54603 .3373 L 0 .321 .156 r
F
.54911 .32026 m .55231 .3495 L .54716 .34786 L F
.54911 .32026 m .55801 .3411 L .55231 .3495 L F
0 g
.55699 .33869 m
.55818 .32708 L
s
.54911 .32026 m .56105 .32401 L .55801 .3411 L 0 .321 .156 r
F
0 g
.54434 .32127 m
.54911 .32026 L
s
.54713 .72285 m
.54769 .72098 L
s
.502 .40689 m .49817 .41386 L .49897 .4153 L 0 .931 .112 r
F
.502 .40689 m .50037 .40304 L .49817 .41386 L F
.502 .40689 m .50409 .39009 L .50037 .40304 L F
0 g
.37619 .83763 m
.38382 .83664 L
s
.39865 .82979 m .38058 .8335 L .38382 .83663 L 0 1 .527 r
F
.50037 .40304 m .50663 .38123 L .5063 .38232 L 0 .718 .056 r
F
.50037 .40304 m .50409 .39009 L .50663 .38123 L F
0 g
.50663 .38123 m
.50668 .38102 L
s
.50409 .39009 m
.50529 .38677 L
s
.50409 .39009 m
.50663 .38123 L
s
.52005 .96696 m
.52225 .96753 L
s
.52765 .96891 m
.52766 .96891 L
s
.53213 .96774 m
.53321 .96742 L
s
.53452 .96702 m
.53452 .96701 L
s
.53613 .7389 m
.54048 .73995 L
s
.31706 .87388 m .31792 .88145 L .32085 .87943 L 0 1 .526 r
F
.31706 .87388 m .30948 .8788 L .31792 .88145 L F
0 g
.31792 .88145 m
.32255 .88672 L
s
.54252 .72269 m
.54427 .72312 L
s
.50227 .78089 m .49636 .78228 L .49147 .78601 L 0 1 .482 r
F
0 g
.50227 .78089 m
.50657 .78274 L
s
.50307 .77068 m .50227 .78089 L .50685 .77672 L 0 1 .472 r
F
.50307 .77068 m .49636 .78228 L .50227 .78089 L F
.34512 .88118 m .32527 .8764 L .32963 .88159 L 0 1 .525 r
F
.40421 .8236 m .40554 .8286 L .40766 .82608 L F
.40421 .8236 m .39865 .82979 L .40554 .8286 L F
0 g
.40554 .8286 m
.40958 .83089 L
s
.44302 .96051 m .44012 .96509 L .44866 .9675 L 0 1 .512 r
F
.44302 .96051 m .42978 .96009 L .44012 .96509 L F
0 g
.44012 .96509 m
.44711 .97022 L
s
.46831 .97184 m .46812 .97258 L .47489 .97653 L 0 1 .525 r
F
.4681 .97264 m .45584 .97203 L .46646 .97629 L 0 1 .513 r
F
.46811 .97262 m .46808 .97261 L .4681 .97264 L F
.46808 .97261 m .45584 .97203 L .4681 .97264 L F
.46812 .97258 m .46811 .97262 L .46817 .97265 L 0 1 .525 r
F
.46812 .97258 m .46817 .97265 L .47489 .97653 L F
.46811 .97262 m .47177 .97751 L .47489 .97653 L F
.46831 .97218 m .46811 .97262 L .47488 .9783 L 0 1 .513 r
F
.46811 .97262 m .46646 .97629 L .47168 .97754 L F
.46811 .97262 m .47168 .97754 L .47177 .97751 L 0 1 .525 r
F
.46811 .97262 m .47168 .97754 L .47488 .9783 L 0 1 .513 r
F
.46811 .97262 m .46644 .97918 L .47168 .97754 L 0 1 .525 r
F
.46811 .97262 m .45578 .97971 L .46644 .97918 L F
.46831 .97184 m .46777 .97217 L .46811 .97262 L F
.46777 .97217 m .46776 .97217 L .46811 .97262 L 0 1 .513 r
F
.46776 .97217 m .45584 .97203 L .46802 .97261 L F
.46776 .97217 m .46802 .97261 L .46811 .97262 L F
.46776 .97217 m .44866 .9675 L .45584 .97203 L F
.46831 .97218 m .46769 .97203 L .46776 .97217 L F
.46769 .97203 m .44866 .9675 L .46776 .97217 L F
.46771 .97204 m .44969 .96571 L .44866 .9675 L F
.46831 .97184 m .46769 .97203 L .46777 .97217 L 0 1 .525 r
F
.46769 .97203 m .46768 .97204 L .46771 .97208 L F
.46769 .97203 m .46771 .97208 L .46777 .97217 L F
.46765 .97195 m .45811 .96771 L .44969 .96571 L 0 1 .513 r
F
.46831 .97218 m .46762 .97188 L .46765 .97195 L F
.46762 .97188 m .45811 .96771 L .46765 .97195 L F
.46831 .97218 m .46768 .97196 L .46771 .97204 L F
.46768 .97196 m .44969 .96571 L .46771 .97204 L F
.47019 .96432 m .46556 .96749 L .46831 .97184 L 0 1 .523 r
F
.46556 .96749 m .46483 .96799 L .46764 .97189 L F
.46556 .96749 m .46764 .97189 L .46831 .97184 L F
.46831 .97184 m .47489 .97653 L .47551 .97351 L 0 1 .525 r
F
.47019 .96432 m .46831 .97184 L .47644 .96893 L 0 1 .523 r
F
.47016 .96821 m .46483 .96799 L .46831 .97218 L 0 1 .505 r
F
.46483 .96799 m .46482 .96799 L .46488 .96807 L F
.46483 .96799 m .46488 .96807 L .46831 .97218 L F
.46482 .96799 m .45811 .96771 L .46734 .97176 L F
.46494 .96816 m .46734 .97176 L .46761 .97188 L F
.46482 .96799 m .46734 .97176 L .46494 .96816 L F
.46483 .96799 m .45117 .97112 L .45807 .97262 L 0 1 .523 r
F
.46483 .96799 m .45125 .96304 L .45811 .96771 L 0 1 .505 r
F
.47019 .96432 m .464 .96653 L .46483 .96799 L 0 1 .523 r
F
.47016 .96821 m .464 .96653 L .46483 .96799 L 0 1 .505 r
F
.464 .96653 m .45125 .96304 L .46463 .96792 L F
.464 .96653 m .45222 .96832 L .45117 .97112 L 0 1 .523 r
F
.464 .96653 m .45229 .96128 L .45125 .96304 L 0 1 .505 r
F
.47019 .96432 m .46379 .96574 L .464 .96653 L 0 1 .523 r
F
.47016 .96821 m .46379 .96574 L .464 .96653 L 0 1 .505 r
F
.46379 .96574 m .45229 .96128 L .464 .96653 L F
.46379 .96574 m .46365 .96577 L .464 .96653 L 0 1 .523 r
F
.46365 .96577 m .45222 .96832 L .464 .96653 L F
.464 .96653 m .46463 .96792 L .46483 .96799 L 0 1 .505 r
F
.464 .96653 m .46388 .96657 L .46483 .96799 L 0 1 .523 r
F
.46388 .96657 m .45117 .97112 L .46483 .96799 L F
.46483 .96799 m .45807 .97262 L .46764 .97189 L F
.46765 .97196 m .45807 .97262 L .4496 .97528 L 0 1 .525 r
F
.46482 .96799 m .46761 .97188 L .46764 .97189 L 0 1 .505 r
F
.46831 .97184 m .46764 .97189 L .46768 .97195 L 0 1 .525 r
F
.46831 .97184 m .46763 .97196 L .46768 .97204 L F
.46665 .97019 m .46764 .97189 L .46831 .97218 L 0 1 .505 r
F
.46482 .96799 m .46764 .97189 L .46665 .97019 L F
.46768 .97195 m .46762 .97189 L .46765 .97196 L 0 1 .525 r
F
.46764 .97189 m .46762 .97189 L .46768 .97195 L F
.46762 .97189 m .45807 .97262 L .46765 .97196 L F
.46768 .97204 m .4496 .97528 L .44855 .97804 L F
.46763 .97196 m .4496 .97528 L .46768 .97204 L F
.46777 .97217 m .45578 .97971 L .46811 .97262 L F
.46778 .97217 m .46777 .97217 L .46811 .97262 L 0 1 .513 r
F
.46777 .97217 m .44855 .97804 L .45578 .97971 L 0 1 .525 r
F
.46768 .97204 m .44855 .97804 L .46777 .97217 L F
.46831 .97218 m .46778 .97217 L .46811 .97262 L 0 1 .513 r
F
0 g
.46964 .97818 m
.47396 .98074 L
s
.44711 .97022 m
.44799 .9704 L
s
.44799 .9704 m
.45119 .97107 L
s
.39472 .94273 m
.39479 .94274 L
s
.39479 .94274 m
.39568 .94287 L
s
.30138 .89956 m .3027 .90885 L .30563 .90699 L 0 1 .501 r
F
.30138 .89956 m .29383 .90412 L .3027 .90885 L F
0 g
.3027 .90885 m
.30783 .91593 L
s
.44302 .96051 m .4231 .95491 L .42978 .96009 L 0 1 .512 r
F
0 g
.42093 .95779 m
.42978 .96009 L
s
.50307 .77068 m .50685 .77672 L .50704 .77254 L 0 1 .472 r
F
.51681 .76576 m .50704 .77254 L .50685 .77672 L 0 1 .458 r
F
0 g
.50685 .77672 m
.51116 .77855 L
s
.50227 .78089 m
.50685 .77672 L
s
.37892 .88094 m .35987 .87769 L .3644 .88243 L 0 1 .525 r
F
0 g
.35596 .88095 m
.3644 .88243 L
s
.52035 .99106 m .50951 .98917 L .50124 .98883 L 0 1 .491 r
F
0 g
.53339 .74909 m
.53405 .74461 L
s
.51533 .5015 m .51673 .49876 L .51822 .477 L 0 1 .264 r
F
.47657 .8926 m .48147 .89906 L .48224 .89645 L 0 1 .528 r
F
0 g
.47427 .89931 m
.48147 .89906 L
s
.48147 .89906 m
.48764 .90254 L
s
.48754 .78417 m .47556 .792 L .4795 .79383 L 0 1 .492 r
F
0 g
.47406 .79693 m
.4795 .79383 L
s
.37432 .99511 m .37922 1.00025 L .38107 .99799 L 0 1 .538 r
F
.37432 .99511 m .36942 1.00061 L .37922 1.00025 L F
0 g
.37922 1.00025 m
.38666 1.00283 L
s
.38488 .94842 m .36328 .95477 L .36948 .95577 L 0 1 .495 r
F
.38488 .94842 m .36552 .95241 L .36328 .95477 L F
.38488 .94842 m .37479 .94969 L .36552 .95241 L F
.38982 .94203 m .37479 .94969 L .38488 .94842 L 0 1 .486 r
F
0 g
.38488 .94842 m
.39351 .94561 L
s
.38488 .94842 m
.39104 .94944 L
s
.3946 .9426 m
.39472 .94273 L
s
.39299 .94088 m
.3946 .9426 L
s
.41453 .95211 m .40454 .94648 L .39566 .94373 L 0 1 .512 r
F
0 g
.39472 .94273 m
.39566 .94373 L
s
.51915 .90957 m
.52128 .90989 L
s
.52128 .90989 m
.52361 .91023 L
s
.52385 .91027 m
.52494 .91043 L
s
.42641 .81829 m .41085 .82227 L .41461 .82451 L 0 1 .521 r
F
0 g
.40766 .82608 m
.41461 .82451 L
s
.34512 .88118 m .32821 .87437 L .32527 .8764 L 0 1 .525 r
F
.34512 .88118 m .33673 .87643 L .32821 .87437 L F
0 g
.32085 .87943 m
.32963 .88159 L
s
.35189 .87586 m .33673 .87643 L .34512 .88118 L 0 1 .524 r
F
0 g
.34512 .88118 m
.35335 .88312 L
s
.34512 .88118 m
.34945 .88636 L
s
.45591 .88612 m .43853 .88649 L .44366 .89068 L 0 1 .525 r
F
.47023 .79503 m .4571 .80158 L .46094 .80348 L 0 1 .505 r
F
0 g
.45501 .80609 m
.46094 .80348 L
s
.49147 .78601 m
.49636 .78228 L
s
.4311 .81151 m .43279 .81645 L .43456 .8137 L 0 1 .519 r
F
.4311 .81151 m .42641 .81829 L .43279 .81645 L F
0 g
.43279 .81645 m
.43678 .81849 L
s
.41845 .94727 m .41453 .95211 L .4231 .95491 L 0 1 .508 r
F
.41845 .94727 m .40454 .94648 L .41453 .95211 L F
0 g
.41453 .95211 m
.42093 .95779 L
s
.53235 .74155 m
.53405 .74461 L
s
.33099 .91395 m .31002 .90421 L .31488 .91123 L 0 1 .502 r
F
0 g
.30563 .90699 m
.31488 .91123 L
s
.49946 .46372 m .5021 .43383 L .49946 .43535 L 0 1 .241 r
F
.49946 .46372 m .50287 .44215 L .5021 .43383 L F
0 g
.5021 .43383 m
.50361 .41903 L
s
.50307 .77068 m .49238 .78042 L .49636 .78228 L 0 1 .472 r
F
.51681 .76576 m .51131 .76785 L .50704 .77254 L 0 1 .458 r
F
.51652 .75449 m .51681 .76576 L .52075 .76075 L 0 1 .449 r
F
.51652 .75449 m .51131 .76785 L .51681 .76576 L F
0 g
.51681 .76576 m
.52111 .7676 L
s
.49407 .98186 m .4825 .98197 L .49329 .98527 L 0 1 .501 r
F
.49407 .98186 m .47488 .9783 L .4825 .98197 L F
0 g
.4745 .98081 m
.4825 .98197 L
s
.45591 .88612 m .45974 .89317 L .46103 .89032 L 0 1 .525 r
F
.47657 .8926 m .46103 .89032 L .45974 .89317 L 0 1 .528 r
F
0 g
.45974 .89317 m
.46542 .89702 L
s
.4523 .89332 m
.45974 .89317 L
s
.54791 .59641 m
.54791 .5964 L
s
.5481 .59571 m
.5481 .59572 L
s
.28962 .85438 m .2896 .86052 L .29285 .85858 L 0 1 .537 r
F
0 g
.29285 .85858 m
.3016 .85952 L
s
.28962 .85438 m .28128 .85907 L .2896 .86052 L 0 1 .537 r
F
0 g
.2896 .86052 m
.29373 .86452 L
s
.54252 .72269 m
.54341 .72007 L
s
.5396 .70948 m .54492 .71565 L .54362 .7103 L 0 1 .397 r
F
0 g
.54408 .71811 m
.54492 .71565 L
s
.54492 .71565 m
.54605 .71576 L
s
.41034 .8785 m .41305 .88522 L .41491 .88286 L 0 1 .523 r
F
.41034 .8785 m .40538 .88437 L .41305 .88522 L F
.43093 .88641 m .41491 .88286 L .41305 .88522 L 0 1 .526 r
F
0 g
.41305 .88522 m
.41822 .88927 L
s
.40538 .88437 m .38905 .87996 L .3868 .88225 L 0 1 .525 r
F
.40538 .88437 m .39702 .88087 L .38905 .87996 L F
.41034 .8785 m .39702 .88087 L .40538 .88437 L 0 1 .523 r
F
0 g
.40538 .88437 m
.41305 .88522 L
s
.40538 .88437 m
.41025 .88875 L
s
.53358 .73063 m .53613 .7389 L .53528 .73369 L 0 1 .411 r
F
0 g
.53586 .74129 m
.53613 .7389 L
s
.51652 .75449 m .52075 .76075 L .5205 .75614 L 0 1 .449 r
F
.52911 .74758 m .5205 .75614 L .52075 .76075 L 0 1 .434 r
F
0 g
.52075 .76075 m
.52503 .76225 L
s
.51681 .76576 m
.52075 .76075 L
s
.49759 .89896 m .50353 .90452 L .50376 .90244 L 0 1 .525 r
F
0 g
.50353 .90452 m
.50543 .9054 L
s
.49662 .90456 m
.50353 .90452 L
s
.35416 .95688 m .35769 .96063 L .35992 .95829 L 0 1 .49 r
F
0 g
.35992 .95829 m
.36948 .95577 L
s
.35416 .95688 m .34829 .96254 L .35769 .96063 L 0 1 .49 r
F
0 g
.35769 .96063 m
.36419 .9618 L
s
.39865 .82979 m .38381 .83044 L .38058 .8335 L 0 1 .527 r
F
.39865 .82979 m .39156 .82885 L .38381 .83044 L F
0 g
.39865 .82979 m
.40187 .83292 L
s
.40421 .8236 m .39156 .82885 L .39865 .82979 L 0 1 .525 r
F
0 g
.39865 .82979 m
.40554 .8286 L
s
.49946 .46372 m .50174 .45495 L .50287 .44215 L 0 1 .241 r
F
0 g
.50287 .44215 m
.50519 .44139 L
s
.28128 .85907 m .26478 .8596 L .27296 .86372 L 0 1 .538 r
F
0 g
.27296 .86372 m
.28149 .86535 L
s
.53437 .45813 m .53743 .44097 L .5408 .411 L 0 1 .152 r
F
0 g
.53762 .43929 m
.53853 .43117 L
s
.53853 .43117 m
.5408 .411 L
s
.5408 .411 m
.5415 .41221 L
s
.52005 .96696 m
.52209 .96598 L
s
.52311 .96548 m
.52765 .96329 L
s
.43995 .98016 m .44594 .98486 L .44699 .98214 L 0 1 .532 r
F
.43995 .98016 m .43703 .98678 L .44594 .98486 L F
.46644 .97918 m .44699 .98214 L .44594 .98486 L 0 1 .528 r
F
0 g
.44594 .98486 m
.45349 .98665 L
s
.77652 .58362 m .78188 .59937 L .78645 .59998 L 0 .324 .33 r
F
0 g
.78188 .59937 m
.78331 .60767 L
s
.42665 .91564 m .43072 .91868 L .43219 .91568 L 0 1 .461 r
F
.42665 .91564 m .42267 .9229 L .43072 .91868 L F
0 g
.43072 .91868 m
.4368 .91848 L
s
.38482 .87528 m .3868 .88225 L .38905 .87996 L 0 1 .523 r
F
.38482 .87528 m .37892 .88094 L .3868 .88225 L F
0 g
.3868 .88225 m
.39168 .88664 L
s
.32517 .85216 m .30588 .85076 L .3095 .85447 L 0 1 .535 r
F
.32517 .85216 m .30914 .84879 L .30588 .85076 L F
.32517 .85216 m .31742 .84939 L .30914 .84879 L F
.33278 .84682 m .31742 .84939 L .32517 .85216 L 0 1 .534 r
F
0 g
.32517 .85216 m
.33317 .85258 L
s
.32517 .85216 m
.32876 .85586 L
s
.30138 .89956 m .28491 .89595 L .29383 .90412 L 0 1 .501 r
F
0 g
.29383 .90412 m
.3027 .90885 L
s
.36607 .84062 m .34795 .84152 L .35154 .84463 L 0 1 .531 r
F
.36607 .84062 m .35091 .83927 L .34795 .84152 L F
.36607 .84062 m .35869 .83889 L .35091 .83927 L F
.37289 .83463 m .35869 .83889 L .36607 .84062 L 0 1 .53 r
F
0 g
.36607 .84062 m
.37356 .84008 L
s
.36607 .84062 m
.36963 .84373 L
s
.40621 .99211 m .38384 .9946 L .39097 .99707 L 0 1 .537 r
F
0 g
.38107 .99799 m
.39097 .99707 L
s
.41845 .94727 m .39844 .94076 L .40454 .94648 L 0 1 .508 r
F
0 g
.39566 .94373 m
.40454 .94648 L
s
.46644 .97918 m .45578 .97971 L .44699 .98214 L 0 1 .528 r
F
0 g
.46644 .97918 m
.47396 .98099 L
s
.46644 .97918 m
.47168 .97754 L
s
.66727 .99056 m
.66806 .99051 L
s
.44302 .96051 m .44866 .9675 L .44969 .96571 L 0 1 .512 r
F
0 g
.44012 .96509 m
.44866 .9675 L
s
.44866 .9675 m
.45179 .96947 L
s
.49672 .44573 m .50093 .42423 L .50015 .41974 L 0 1 .191 r
F
.49672 .44573 m .49946 .43535 L .50093 .42423 L F
0 g
.50093 .42423 m
.50361 .41903 L
s
.49411 .96933 m .47551 .97351 L .47489 .97653 L 0 1 .517 r
F
0 g
.47489 .97653 m
.48252 .97819 L
s
.47346 .97698 m
.47489 .97653 L
s
.42641 .81829 m .41298 .81971 L .41085 .82227 L 0 1 .521 r
F
.42641 .81829 m .41965 .818 L .41298 .81971 L F
.4311 .81151 m .41965 .818 L .42641 .81829 L 0 1 .519 r
F
0 g
.42641 .81829 m
.43015 .82053 L
s
.42641 .81829 m
.43279 .81645 L
s
.51976 .95729 m .50201 .96588 L .50966 .96784 L 0 1 .496 r
F
0 g
.50173 .971 m
.50966 .96784 L
s
.56993 .42497 m .57331 .48103 L .57031 .46237 L 0 .518 .203 r
F
.56993 .42497 m .57782 .48209 L .57331 .48103 L F
0 g
.57545 .42624 m
.57559 .46596 L
s
.56993 .42497 m .58078 .46481 L .57782 .48209 L 0 .518 .203 r
F
0 g
.57565 .48158 m
.57597 .5705 L
s
.57906 .42707 m
.57935 .45959 L
s
.57947 .47242 m
.57956 .48188 L
s
.56993 .42497 m .58032 .42736 L .58078 .46481 L 0 .518 .203 r
F
.45225 .89905 m .43439 .91118 L .44016 .91075 L 0 1 .456 r
F
.36063 .92656 m .3423 .91611 L .33971 .91805 L 0 1 .504 r
F
.36063 .92656 m .35128 .91976 L .3423 .91611 L F
.36649 .92162 m .36063 .92656 L .36931 .93017 L 0 1 .501 r
F
.36649 .92162 m .35128 .91976 L .36063 .92656 L F
0 g
.36063 .92656 m
.36597 .93314 L
s
.43703 .98678 m .41693 .98841 L .41548 .99089 L 0 1 .534 r
F
.43703 .98678 m .42618 .98665 L .41693 .98841 L F
.43995 .98016 m .42618 .98665 L .43703 .98678 L 0 1 .532 r
F
0 g
.43703 .98678 m
.44594 .98486 L
s
.43703 .98678 m
.44438 .98889 L
s
.49407 .98186 m .49329 .98527 L .50152 .9868 L 0 1 .501 r
F
0 g
.49329 .98527 m
.50124 .98883 L
s
.36649 .92162 m .36931 .93017 L .37154 .92818 L 0 1 .501 r
F
.38991 .93758 m .37154 .92818 L .36931 .93017 L 0 1 .506 r
F
0 g
.36931 .93017 m
.37508 .93632 L
s
.36063 .92656 m
.36931 .93017 L
s
.30948 .8788 m .28918 .8723 L .29326 .87798 L 0 1 .526 r
F
.30948 .8788 m .29243 .87046 L .28918 .8723 L F
.30948 .8788 m .30114 .87325 L .29243 .87046 L F
.31706 .87388 m .30114 .87325 L .30948 .8788 L F
0 g
.30948 .8788 m
.31792 .88145 L
s
.30948 .8788 m
.31352 .88446 L
s
.52911 .74758 m .52409 .7505 L .5205 .75614 L 0 1 .434 r
F
0 g
.52911 .74758 m
.53339 .74909 L
s
.52768 .73499 m .52911 .74758 L .53235 .74155 L 0 1 .425 r
F
.52768 .73499 m .52409 .7505 L .52911 .74758 L F
0 g
.54362 .7103 m
.54393 .70905 L
s
.54405 .70861 m
.54553 .70279 L
s
.33774 .90915 m .33971 .91805 L .3423 .91611 L 0 1 .499 r
F
.33774 .90915 m .33099 .91395 L .33971 .91805 L F
0 g
.33971 .91805 m
.34507 .92464 L
s
.37432 .99511 m .35816 .99884 L .36942 1.00061 L 0 1 .538 r
F
0 g
.36942 1.00061 m
.37922 1.00025 L
s
.52768 .73499 m .53235 .74155 L .53164 .73643 L 0 1 .425 r
F
0 g
.52911 .74758 m
.53235 .74155 L
s
.45134 .80408 m .43721 .80951 L .4409 .81152 L 0 1 .513 r
F
0 g
.43456 .8137 m
.4409 .81152 L
s
.52765 .96329 m
.52902 .96388 L
s
.53434 .96616 m
.53435 .96616 L
s
.51652 .75449 m .50732 .7662 L .51131 .76785 L 0 1 .449 r
F
0 g
.50704 .77254 m
.51131 .76785 L
s
.37892 .88094 m .36248 .8755 L .35987 .87769 L 0 1 .525 r
F
.37892 .88094 m .37066 .8769 L .36248 .8755 L F
.38482 .87528 m .37066 .8769 L .37892 .88094 L 0 1 .523 r
F
0 g
.37892 .88094 m
.38343 .88568 L
s
.37892 .88094 m
.3868 .88225 L
s
.50921 .37235 m .50548 .38833 L .50581 .38536 L 0 0 .048 r
F
.50921 .37235 m .50875 .38061 L .50548 .38833 L F
.50921 .37235 m .51342 .36739 L .50875 .38061 L F
.41845 .94727 m .4231 .95491 L .42455 .95299 L 0 1 .508 r
F
.44302 .96051 m .42455 .95299 L .4231 .95491 L 0 1 .512 r
F
0 g
.4231 .95491 m
.42978 .96009 L
s
.41453 .95211 m
.4231 .95491 L
s
.54726 .64745 m
.54728 .64677 L
s
.79451 .61908 m .80449 .62172 L .79997 .61757 L 0 .626 .426 r
F
.43093 .88641 m .42258 .88337 L .41491 .88286 L 0 1 .526 r
F
0 g
.43093 .88641 m
.43608 .89046 L
s
.43581 .87904 m .43093 .88641 L .43853 .88649 L 0 1 .523 r
F
.43581 .87904 m .42258 .88337 L .43093 .88641 L F
0 g
.53528 .73369 m
.53528 .73368 L
s
.70349 .49786 m .70859 .48108 L .71301 .49113 L 0 .689 .104 r
F
.70349 .49786 m .70452 .48393 L .70859 .48108 L F
0 g
.7056 .46885 m
.70859 .48108 L
s
.5396 .70948 m .534 .72594 L .53802 .72674 L 0 1 .397 r
F
0 g
.53528 .73368 m
.53802 .72674 L
s
.76136 .81529 m .7733 .81312 L .76961 .81085 L 0 1 .492 r
F
.45225 .89905 m .43587 .90818 L .43439 .91118 L 0 1 .456 r
F
0 g
.43223 .91565 m
.44016 .91075 L
s
.43219 .91568 m
.43223 .91565 L
s
.45225 .89905 m .44353 .90297 L .43587 .90818 L 0 1 .456 r
F
0 g
.45225 .89905 m
.45798 .89863 L
s
.68415 .81203 m
.68612 .80581 L
s
.52168 .99144 m
.52628 .99274 L
s
.33099 .91395 m .31295 .90235 L .31002 .90421 L 0 1 .502 r
F
.33099 .91395 m .32195 .90652 L .31295 .90235 L F
.33774 .90915 m .32195 .90652 L .33099 .91395 L 0 1 .499 r
F
0 g
.33099 .91395 m
.33583 .92096 L
s
.33099 .91395 m
.33971 .91805 L
s
.46831 .97218 m .47488 .9783 L .47549 .97672 L 0 1 .513 r
F
.49407 .98186 m .47549 .97672 L .47488 .9783 L 0 1 .501 r
F
0 g
.47488 .9783 m
.4825 .98197 L
s
.47168 .97754 m
.47488 .9783 L
s
.5205 .75614 m
.52409 .7505 L
s
.34041 .84143 m .34055 .84707 L .34351 .84486 L 0 1 .533 r
F
0 g
.34351 .84486 m
.35154 .84463 L
s
.34041 .84143 m .33278 .84682 L .34055 .84707 L 0 1 .533 r
F
0 g
.34055 .84707 m
.34441 .85031 L
s
.5384 .50377 m
.53849 .50148 L
s
.5356 .52303 m
.53663 .51456 L
s
.53663 .51456 m
.53813 .50217 L
s
.54378 .6487 m
.54726 .64745 L
s
.41015 .98605 m .41548 .99089 L .41693 .98841 L 0 1 .536 r
F
.41015 .98605 m .40621 .99211 L .41548 .99089 L F
0 g
.41548 .99089 m
.42286 .99298 L
s
.52146 .56705 m .52678 .49162 L .52549 .49084 L 0 .846 .263 r
F
.52146 .56705 m .52632 .51539 L .52678 .49162 L F
0 g
.52678 .49162 m
.52738 .48458 L
s
.50835 .51877 m .50862 .46828 L .50677 .4749 L 0 1 .273 r
F
.50835 .51877 m .51024 .47789 L .50862 .46828 L F
0 g
.50862 .46828 m
.50978 .45184 L
s
.52146 .56705 m .52549 .49084 L .52342 .51276 L 0 .846 .263 r
F
0 g
.52532 .49263 m
.52549 .49084 L
s
.52549 .49084 m
.52562 .46472 L
s
.47303 .78679 m .47556 .792 L .47656 .78866 L 0 1 .499 r
F
.47303 .78679 m .47023 .79503 L .47556 .792 L F
.48754 .78417 m .47656 .78866 L .47556 .792 L 0 1 .492 r
F
0 g
.47556 .792 m
.4795 .79383 L
s
.52768 .73499 m .52012 .74906 L .52409 .7505 L 0 1 .425 r
F
.54548 .68456 m .54036 .69729 L .54167 .70244 L 0 1 .374 r
F
.54548 .68456 m .542 .68963 L .54036 .69729 L F
0 g
.54548 .68456 m
.54683 .68461 L
s
.54548 .68456 m
.54634 .67973 L
s
.55592 .45687 m
.55594 .45694 L
s
.5559 .45679 m
.55592 .45687 L
s
.55586 .45668 m
.5559 .45679 L
s
.55586 .45665 m
.55586 .45668 L
s
.55576 .45631 m
.55586 .45665 L
s
.55576 .45631 m
.55576 .45631 L
s
.55496 .46178 m
.55576 .45631 L
s
.61142 .34284 m .61629 .34923 L .6224 .3676 L 0 .832 .102 r
F
0 g
.61629 .34923 m
.61738 .33472 L
s
.47023 .79503 m .45849 .79852 L .4571 .80158 L 0 1 .505 r
F
.47023 .79503 m .46412 .79571 L .45849 .79852 L F
.47303 .78679 m .46412 .79571 L .47023 .79503 L 0 1 .499 r
F
0 g
.47023 .79503 m
.47556 .792 L
s
.47023 .79503 m
.47406 .79693 L
s
.40033 .93624 m
.40214 .93545 L
s
.40429 .93452 m
.40902 .93247 L
s
.40361 .93226 m
.40902 .93247 L
s
.49411 .96933 m .48375 .97042 L .47551 .97351 L 0 1 .517 r
F
.49491 .96087 m .49411 .96933 L .50201 .96588 L 0 1 .512 r
F
.49491 .96087 m .48375 .97042 L .49411 .96933 L F
0 g
.49411 .96933 m
.50173 .971 L
s
.48754 .78417 m .48169 .7853 L .47656 .78866 L 0 1 .492 r
F
0 g
.48754 .78417 m
.49147 .78601 L
s
.48941 .77466 m .48754 .78417 L .49238 .78042 L 0 1 .483 r
F
.48941 .77466 m .48169 .7853 L .48754 .78417 L F
.52007 .98845 m .50951 .98917 L .52035 .99106 L 0 1 .457 r
F
0 g
.52035 .99106 m
.52168 .99144 L
s
.52007 .98845 m .50152 .9868 L .50951 .98917 L 0 1 .457 r
F
0 g
.50124 .98883 m
.50951 .98917 L
s
.48941 .77466 m .49238 .78042 L .493 .77655 L 0 1 .483 r
F
.50307 .77068 m .493 .77655 L .49238 .78042 L 0 1 .472 r
F
0 g
.49238 .78042 m
.49636 .78228 L
s
.48754 .78417 m
.49238 .78042 L
s
.53164 .73643 m
.53165 .73636 L
s
.53165 .73636 m
.53205 .73275 L
s
.38991 .93758 m .38037 .93136 L .37154 .92818 L 0 1 .506 r
F
.39483 .93263 m .38037 .93136 L .38991 .93758 L 0 1 .503 r
F
0 g
.38991 .93758 m
.3925 .93855 L
s
.38991 .93758 m
.39174 .93954 L
s
.54526 .67052 m
.54552 .66819 L
s
.5236 .57199 m .52866 .49416 L .52632 .51539 L 0 .831 .262 r
F
.5236 .57199 m .52989 .49678 L .52866 .49416 L F
0 g
.52866 .49416 m
.52914 .4639 L
s
.49672 .44573 m .50015 .41974 L .49716 .42481 L 0 1 .191 r
F
0 g
.49951 .43503 m
.50093 .42423 L
s
.49989 .4351 m
.5021 .43383 L
s
.50015 .41974 m
.502 .40689 L
s
.43581 .87904 m .43853 .88649 L .44033 .88354 L 0 1 .523 r
F
.45591 .88612 m .44033 .88354 L .43853 .88649 L 0 1 .525 r
F
0 g
.43853 .88649 m
.44366 .89068 L
s
.43093 .88641 m
.43853 .88649 L
s
.41491 .88286 m
.42258 .88337 L
s
.41034 .8785 m .39243 .8765 L .39702 .88087 L 0 1 .523 r
F
0 g
.38905 .87996 m
.39702 .88087 L
s
.61142 .34284 m .61281 .36548 L .60992 .34976 L 0 .832 .102 r
F
.61142 .34284 m .61895 .38402 L .61281 .36548 L F
0 g
.61351 .35319 m
.61377 .35566 L
s
.61142 .34284 m .62423 .39294 L .61895 .38402 L 0 .832 .102 r
F
.61142 .34284 m .6257 .38585 L .62423 .39294 L F
.61142 .34284 m .6224 .3676 L .6257 .38585 L F
0 g
.61629 .34923 m
.6207 .36249 L
s
.61568 .37416 m
.61604 .37764 L
s
.60636 .32539 m
.61142 .34284 L
s
.62104 .36351 m
.62156 .36509 L
s
.6207 .36249 m
.62104 .36351 L
s
.76502 .57003 m .77505 .58763 L .77652 .58362 L 0 .285 .307 r
F
0 g
.77505 .58763 m
.77735 .59437 L
s
.77055 .58647 m
.77505 .58763 L
s
.28091 .86903 m .28106 .8769 L .28431 .87507 L 0 1 .526 r
F
0 g
.28431 .87507 m
.29326 .87798 L
s
.28091 .86903 m .27258 .87349 L .28106 .8769 L 0 1 .526 r
F
0 g
.28106 .8769 m
.28539 .88269 L
s
.42665 .91564 m .41339 .92555 L .42267 .9229 L 0 1 .461 r
F
0 g
.42267 .9229 m
.42852 .92315 L
s
.42267 .9229 m
.43072 .91868 L
s
.51924 .56426 m .52353 .49079 L .52219 .49149 L 0 .86 .265 r
F
0 g
.52041 .49011 m
.52197 .46945 L
s
.51924 .56426 m .52342 .51276 L .52353 .49079 L 0 .86 .265 r
F
0 g
.52353 .49079 m
.52562 .46472 L
s
.52346 .50381 m
.52353 .49079 L
s
.45511 .79655 m .4571 .80158 L .45849 .79852 L 0 1 .509 r
F
.45511 .79655 m .45134 .80408 L .4571 .80158 L F
0 g
.4571 .80158 m
.46094 .80348 L
s
.53155 .71784 m .53358 .73063 L .534 .72594 L 0 1 .402 r
F
.53155 .71784 m .53216 .73175 L .53358 .73063 L F
0 g
.53358 .73063 m
.53528 .73369 L
s
.49491 .96087 m .50201 .96588 L .5022 .96237 L 0 1 .512 r
F
.51976 .95729 m .5022 .96237 L .50201 .96588 L 0 1 .496 r
F
0 g
.50201 .96588 m
.50966 .96784 L
s
.49411 .96933 m
.50201 .96588 L
s
.48224 .89645 m
.48914 .89641 L
s
.65573 .50773 m
.65767 .51189 L
s
.44699 .98214 m
.45578 .97971 L
s
.40621 .99211 m .38569 .99233 L .38384 .9946 L 0 1 .537 r
F
.40621 .99211 m .39529 .99126 L .38569 .99233 L F
.41015 .98605 m .39529 .99126 L .40621 .99211 L 0 1 .536 r
F
0 g
.40621 .99211 m
.41331 .99458 L
s
.40621 .99211 m
.41548 .99089 L
s
.53669 .69674 m .54167 .70244 L .54036 .69729 L 0 1 .386 r
F
.53669 .69674 m .5396 .70948 L .54167 .70244 L F
0 g
.54167 .70244 m
.54548 .70257 L
s
.35868 .87049 m .35987 .87769 L .36248 .8755 L 0 1 .523 r
F
.35868 .87049 m .35189 .87586 L .35987 .87769 L F
0 g
.35987 .87769 m
.3644 .88243 L
s
.50677 .4749 m .50403 .45782 L .5048 .47041 L 0 1 .26 r
F
.50218 .49138 m .50403 .45782 L .50174 .45495 L 0 1 .266 r
F
.50218 .49138 m .5048 .47041 L .50403 .45782 L F
0 g
.50403 .45782 m
.50519 .44139 L
s
.50178 .45499 m
.50403 .45782 L
s
.56637 .32949 m .57181 .32241 L .57741 .32933 L 0 .524 .16 r
F
.50307 .77068 m .49759 .77237 L .493 .77655 L 0 1 .472 r
F
.50387 .76017 m .50307 .77068 L .50732 .7662 L 0 1 .463 r
F
.50387 .76017 m .49759 .77237 L .50307 .77068 L F
0 g
.50307 .77068 m
.50704 .77254 L
s
.53155 .71784 m .53057 .72879 L .53216 .73175 L 0 1 .402 r
F
0 g
.53208 .73251 m
.53216 .73175 L
s
.36649 .92162 m .3462 .91319 L .35128 .91976 L 0 1 .501 r
F
0 g
.3423 .91611 m
.35128 .91976 L
s
.43581 .87904 m .41804 .87887 L .42258 .88337 L 0 1 .523 r
F
.5396 .70948 m .53315 .7208 L .534 .72594 L 0 1 .397 r
F
0 g
.534 .72594 m
.53802 .72674 L
s
.5396 .70948 m .53555 .71375 L .53315 .7208 L 0 1 .397 r
F
.53669 .69674 m .53555 .71375 L .5396 .70948 L 0 1 .386 r
F
0 g
.5396 .70948 m
.54362 .7103 L
s
.5396 .70948 m
.54167 .70244 L
s
.46845 .97187 m
.47551 .97351 L
s
.32466 .86893 m .32527 .8764 L .32821 .87437 L 0 1 .525 r
F
.32466 .86893 m .31706 .87388 L .32527 .8764 L F
0 g
.32527 .8764 m
.32963 .88159 L
s
.45134 .80408 m .43899 .80669 L .43721 .80951 L 0 1 .513 r
F
.45134 .80408 m .44504 .80436 L .43899 .80669 L F
.45511 .79655 m .44504 .80436 L .45134 .80408 L 0 1 .509 r
F
0 g
.45134 .80408 m
.45501 .80609 L
s
.45134 .80408 m
.4571 .80158 L
s
.41845 .94727 m .40029 .93878 L .39844 .94076 L 0 1 .508 r
F
0 g
.39592 .93982 m
.39844 .94076 L
s
.39844 .94076 m
.40454 .94648 L
s
.50387 .76017 m .50732 .7662 L .50751 .76191 L 0 1 .463 r
F
.51652 .75449 m .50751 .76191 L .50732 .7662 L 0 1 .449 r
F
0 g
.50732 .7662 m
.51131 .76785 L
s
.50307 .77068 m
.50732 .7662 L
s
.56411 .50418 m
.56515 .49863 L
s
.56515 .49863 m
.56526 .49804 L
s
.56526 .49804 m
.56526 .49803 L
s
.56526 .49804 m
.56526 .49804 L
s
.56489 .50349 m
.56498 .50207 L
s
.56498 .50207 m
.56526 .49805 L
s
.56526 .49805 m
.56526 .49805 L
s
.53462 .95679 m
.53464 .95679 L
s
.5236 .57199 m .52909 .52191 L .52989 .49678 L 0 .831 .262 r
F
0 g
.52989 .49678 m
.53113 .48312 L
s
.49074 1.05849 m .47736 1.06184 L .48996 1.06402 L 0 1 .537 r
F
.49074 1.05849 m .46837 1.05855 L .47736 1.06184 L F
.53155 .71784 m .534 .72594 L .53315 .7208 L 0 1 .402 r
F
0 g
.53358 .73063 m
.534 .72594 L
s
.40979 .81731 m .41085 .82227 L .41298 .81971 L 0 1 .523 r
F
.40979 .81731 m .40421 .8236 L .41085 .82227 L F
0 g
.41085 .82227 m
.41461 .82451 L
s
.47657 .8926 m .46824 .89007 L .46103 .89032 L 0 1 .528 r
F
0 g
.46103 .89032 m
.46824 .89007 L
s
.47657 .8926 m
.48224 .89645 L
s
.35189 .87586 m .33263 .87132 L .33673 .87643 L 0 1 .524 r
F
0 g
.52035 .99106 m
.52153 .99117 L
s
.52153 .99117 m
.52543 .99152 L
s
.38129 .82716 m .38058 .8335 L .38381 .83044 L 0 1 .528 r
F
.38129 .82716 m .37289 .83463 L .38058 .8335 L F
0 g
.38058 .8335 m
.38382 .83663 L
s
.49074 1.05849 m .48996 1.06402 L .49954 1.064 L 0 1 .537 r
F
.51924 .56426 m .52219 .49149 L .52041 .51337 L 0 .86 .265 r
F
0 g
.52061 .51085 m
.52203 .49347 L
s
.52203 .49347 m
.52219 .49149 L
s
.52197 .46945 m
.52219 .49149 L
s
.49946 .46372 m .49946 .43535 L .49672 .44573 L 0 1 .241 r
F
0 g
.49946 .43535 m
.49989 .4351 L
s
.49946 .43535 m
.49951 .43503 L
s
.34829 .96254 m .32565 .96654 L .33175 .96812 L 0 1 .499 r
F
.34829 .96254 m .32824 .96446 L .32565 .96654 L F
.34829 .96254 m .33797 .96274 L .32824 .96446 L F
.35416 .95688 m .33797 .96274 L .34829 .96254 L 0 1 .49 r
F
0 g
.34829 .96254 m
.35769 .96063 L
s
.34829 .96254 m
.35434 .96413 L
s
.67876 .50613 m .68417 .4606 L .68856 .47362 L 0 .678 .17 r
F
.67876 .50613 m .67998 .47438 L .68417 .4606 L F
0 g
.68149 .4363 m
.68417 .4606 L
s
.58032 .42736 m
.58488 .43405 L
s
.58032 .42736 m
.5807 .45878 L
s
.44969 .96571 m
.45034 .96586 L
s
.45034 .96586 m
.45658 .96735 L
s
.50037 .40304 m .5063 .38232 L .50292 .39257 L 0 .718 .056 r
F
0 g
.50446 .38789 m
.5063 .38232 L
s
.5063 .38232 m
.50921 .37235 L
s
.76502 .57003 m .77416 .57655 L .76953 .57116 L 0 .285 .307 r
F
.76502 .57003 m .77652 .58362 L .77416 .57655 L F
.75513 .55052 m .75794 .55642 L .76258 .56253 L 0 0 .153 r
F
.75513 .55052 m .75475 .55128 L .75794 .55642 L F
0 g
.7535 .55473 m
.75794 .55642 L
s
.75791 .55638 m
.75794 .55642 L
s
.78801 .59578 m .78867 .60652 L .79319 .61106 L 0 .362 .354 r
F
.78801 .59578 m .78645 .59998 L .78867 .60652 L F
0 g
.78331 .60767 m
.78867 .60652 L
s
.30895 .89499 m .31002 .90421 L .31295 .90235 L 0 1 .498 r
F
.30895 .89499 m .30138 .89956 L .31002 .90421 L F
0 g
.31002 .90421 m
.31488 .91123 L
s
.49491 .96087 m .47644 .96893 L .48375 .97042 L 0 1 .512 r
F
0 g
.47551 .97351 m
.48375 .97042 L
s
.54036 .69729 m
.542 .68963 L
s
.77779 .79425 m .7733 .81312 L .78094 .80837 L 0 1 .491 r
F
.77779 .79425 m .76961 .81085 L .7733 .81312 L F
0 g
.77038 .82102 m
.7733 .81312 L
s
.43995 .98016 m .41912 .98467 L .42618 .98665 L 0 1 .532 r
F
0 g
.41693 .98841 m
.42618 .98665 L
s
.51652 .75449 m .51146 .75689 L .50751 .76191 L 0 1 .449 r
F
0 g
.51652 .75449 m
.5205 .75614 L
s
.51622 .74261 m .51652 .75449 L .52012 .74906 L 0 1 .439 r
F
.51622 .74261 m .51146 .75689 L .51652 .75449 L F
0 g
.68287 .80755 m
.68612 .80581 L
s
.39483 .93263 m .3749 .9252 L .38037 .93136 L 0 1 .503 r
F
0 g
.37154 .92818 m
.38037 .93136 L
s
.47656 .78866 m
.48169 .7853 L
s
.44302 .96051 m .43309 .95539 L .42455 .95299 L 0 1 .512 r
F
.49407 .98186 m .50152 .9868 L .5017 .98553 L 0 1 .501 r
F
.52007 .98845 m .5017 .98553 L .50152 .9868 L 0 1 .457 r
F
0 g
.50152 .9868 m
.50951 .98917 L
s
.49329 .98527 m
.50152 .9868 L
s
.46044 1.05283 m .4586 1.0583 L .46837 1.05855 L 0 1 .538 r
F
.46044 1.05283 m .44617 1.05576 L .4586 1.0583 L F
.51622 .74261 m .52012 .74906 L .51986 .74423 L 0 1 .439 r
F
.52768 .73499 m .51986 .74423 L .52012 .74906 L 0 1 .425 r
F
0 g
.52012 .74906 m
.52409 .7505 L
s
.51652 .75449 m
.52012 .74906 L
s
.48941 .77466 m .47809 .78342 L .48169 .7853 L 0 1 .483 r
F
.4311 .81151 m .41617 .81582 L .41965 .818 L 0 1 .519 r
F
0 g
.41298 .81971 m
.41965 .818 L
s
.29799 .84966 m .29773 .85566 L .30098 .85371 L 0 1 .537 r
F
0 g
.30098 .85371 m
.3095 .85447 L
s
.29799 .84966 m .28962 .85438 L .29773 .85566 L 0 1 .537 r
F
0 g
.29773 .85566 m
.3016 .85952 L
s
.49759 .89896 m
.50376 .90244 L
s
.50376 .90244 m
.50647 .90284 L
s
.76215 .835 m .76356 .84806 L .77128 .84287 L 0 1 .491 r
F
0 g
.75925 .84882 m
.76356 .84806 L
s
.28128 .85907 m .26129 .85522 L .26478 .8596 L 0 1 .538 r
F
.28128 .85907 m .26482 .85352 L .26129 .85522 L F
.28128 .85907 m .27341 .85517 L .26482 .85352 L F
.28962 .85438 m .27341 .85517 L .28128 .85907 L 0 1 .537 r
F
0 g
.28128 .85907 m
.28473 .86343 L
s
.28128 .85907 m
.2896 .86052 L
s
.53728 .40958 m .54026 .3836 L .53653 .40878 L 0 .729 .056 r
F
.54026 .3836 m .53924 .39483 L .53815 .39855 L 0 0 .057 r
F
.54026 .3836 m .54332 .37528 L .53924 .39483 L F
0 g
.53885 .39357 m
.53997 .38566 L
s
.53997 .38566 m
.54026 .3836 L
s
.38482 .87528 m .36641 .87221 L .37066 .8769 L 0 1 .523 r
F
0 g
.36248 .8755 m
.37066 .8769 L
s
.50218 .49138 m .50174 .45495 L .49946 .46372 L 0 1 .266 r
F
0 g
.50174 .45495 m
.50287 .44215 L
s
.50174 .45495 m
.50178 .45499 L
s
.35189 .87586 m .33559 .86928 L .33263 .87132 L 0 1 .524 r
F
.35189 .87586 m .34385 .87123 L .33559 .86928 L F
0 g
.32821 .87437 m
.33673 .87643 L
s
.35868 .87049 m .34385 .87123 L .35189 .87586 L 0 1 .523 r
F
0 g
.35189 .87586 m
.35987 .87769 L
s
.35189 .87586 m
.35596 .88095 L
s
.52127 1.06373 m .5089 1.06713 L .52156 1.0691 L 0 1 .534 r
F
.52127 1.06373 m .49954 1.064 L .5089 1.06713 L F
.71668 .49454 m .72642 .51709 L .72065 .50657 L 0 .47 .037 r
F
.71668 .49454 m .73112 .52165 L .72642 .51709 L F
.71668 .49454 m .73159 .5172 L .73112 .52165 L F
0 g
.72758 .50516 m
.73159 .5172 L
s
.52768 .73499 m .5231 .7382 L .51986 .74423 L 0 1 .425 r
F
.52624 .7225 m .52768 .73499 L .53057 .72879 L 0 1 .414 r
F
.52624 .7225 m .5231 .7382 L .52768 .73499 L F
0 g
.52768 .73499 m
.53164 .73643 L
s
.53155 .71784 m .52986 .72372 L .53057 .72879 L 0 1 .402 r
F
0 g
.53057 .72879 m
.53216 .73175 L
s
.52624 .7225 m .53057 .72879 L .52986 .72373 L 0 1 .414 r
F
0 g
.52768 .73499 m
.53057 .72879 L
s
.38381 .83044 m
.39156 .82885 L
s
.40421 .8236 m .38809 .82637 L .39156 .82885 L 0 1 .525 r
F
.47303 .78679 m .46058 .79385 L .46412 .79571 L 0 1 .499 r
F
0 g
.45849 .79852 m
.46412 .79571 L
s
.39776 .93594 m
.39781 .93594 L
s
.39781 .93594 m
.40033 .93624 L
s
.51184 .5095 m .51024 .47789 L .51055 .49738 L 0 1 .268 r
F
.50835 .51877 m .51055 .49738 L .51024 .47789 L 0 1 .273 r
F
0 g
.50862 .46828 m
.51024 .47789 L
s
.51024 .47789 m
.51141 .45842 L
s
.54378 .6487 m
.54379 .64858 L
s
.50387 .76017 m .49394 .77064 L .49759 .77237 L 0 1 .463 r
F
0 g
.493 .77655 m
.49759 .77237 L
s
.70637 .80182 m
.70644 .80179 L
s
.53315 .7208 m
.53315 .72079 L
s
.53669 .69674 m .53187 .7132 L .53555 .71375 L 0 1 .386 r
F
0 g
.53315 .72079 m
.53555 .71375 L
s
.43581 .80456 m .43721 .80951 L .43899 .80669 L 0 1 .516 r
F
.43581 .80456 m .4311 .81151 L .43721 .80951 L F
0 g
.43721 .80951 m
.4409 .81152 L
s
.56241 .34504 m .57459 .33286 L .57211 .35131 L 0 .264 .149 r
F
0 g
.57459 .33286 m
.57776 .33214 L
s
.30138 .89956 m .28064 .8885 L .28491 .89595 L 0 1 .501 r
F
.77779 .79425 m .77153 .80277 L .76961 .81085 L 0 1 .491 r
F
0 g
.76136 .81529 m
.76961 .81085 L
s
.33278 .84682 m .31404 .84582 L .31742 .84939 L 0 1 .534 r
F
.33278 .84682 m .31731 .84383 L .31404 .84582 L F
.33278 .84682 m .32536 .84426 L .31731 .84383 L F
.34041 .84143 m .32536 .84426 L .33278 .84682 L 0 1 .533 r
F
0 g
.33278 .84682 m
.34055 .84707 L
s
.33278 .84682 m
.33612 .85038 L
s
.33774 .90915 m .31736 .89955 L .32195 .90652 L 0 1 .499 r
F
0 g
.31295 .90235 m
.32195 .90652 L
s
.51976 .95729 m .50981 .95869 L .5022 .96237 L 0 1 .496 r
F
.38982 .94203 m .36889 .94886 L .37479 .94969 L 0 1 .486 r
F
.38982 .94203 m .37113 .94649 L .36889 .94886 L F
.38982 .94203 m .38012 .94356 L .37113 .94649 L F
.39477 .93559 m .38012 .94356 L .38982 .94203 L 0 1 .473 r
F
0 g
.38982 .94203 m
.39472 .94273 L
s
.38982 .94203 m
.39592 .93982 L
s
.49407 .98186 m .48371 .97824 L .47549 .97672 L 0 1 .501 r
F
0 g
.50751 .76191 m
.51146 .75689 L
s
.46044 1.05283 m .43762 1.05225 L .44617 1.05576 L 0 1 .538 r
F
.40421 .8236 m .39056 .824 L .38809 .82637 L 0 1 .525 r
F
.40421 .8236 m .39748 .82282 L .39056 .824 L F
.40979 .81731 m .39748 .82282 L .40421 .8236 L 0 1 .523 r
F
0 g
.40421 .8236 m
.41085 .82227 L
s
.40421 .8236 m
.40766 .82608 L
s
.51695 .56343 m .52017 .49342 L .5188 .49529 L 0 .876 .268 r
F
.51695 .56343 m .52041 .51337 L .52017 .49342 L F
0 g
.52017 .49342 m
.52041 .49011 L
s
.52017 .49342 m
.52025 .50064 L
s
.56105 .32401 m
.56637 .32949 L
s
.55801 .3411 m
.56105 .32401 L
s
.54246 .61356 m
.54455 .61056 L
s
.54396 .60856 m
.5446 .61028 L
s
.51184 .5095 m .51324 .50611 L .5144 .48652 L 0 1 .268 r
F
0 g
.54183 .67004 m
.54205 .66849 L
s
.61604 .37765 m .61869 .40572 L .61518 .37419 L 0 .545 0 r
F
0 g
.61526 .37452 m
.61539 .37505 L
s
.61518 .37419 m
.61526 .37452 L
s
.6146 .37088 m
.61518 .37419 L
s
.61849 .39905 m .62511 .45713 L .62061 .42107 L 0 .545 0 r
F
.62511 .45713 m .62734 .47062 L .6239 .44711 L 0 0 .074 r
F
.62353 .45146 m .6239 .44711 L .62734 .47062 L 0 .771 .071 r
F
.61232 .3951 m .62251 .44086 L .62353 .45146 L F
.62251 .44086 m .6239 .44711 L .62353 .45146 L F
.61604 .37765 m .61849 .39905 L .61869 .40572 L 0 .545 0 r
F
.61849 .39905 m .62061 .42107 L .61869 .40572 L F
0 g
.61539 .37505 m
.61604 .37765 L
s
.61695 .42155 m
.61718 .45429 L
s
.61718 .45429 m
.61731 .47231 L
s
.62398 .43231 m
.62453 .44431 L
s
.62336 .41881 m
.62398 .43231 L
s
.61661 .45328 m
.61728 .47199 L
s
.61508 .41086 m
.61661 .45328 L
s
.51622 .74261 m .5078 .75528 L .51146 .75689 L 0 1 .439 r
F
.30138 .89956 m .28388 .88675 L .28064 .8885 L 0 1 .501 r
F
.30138 .89956 m .29278 .8915 L .28388 .88675 L F
.30895 .89499 m .29278 .8915 L .30138 .89956 L 0 1 .498 r
F
0 g
.30138 .89956 m
.31002 .90421 L
s
.30138 .89956 m
.30563 .90699 L
s
.52604 .95341 m
.52604 .95341 L
s
.51947 .9465 m .50981 .95869 L .51976 .95729 L 0 1 .486 r
F
0 g
.51976 .95729 m
.52272 .95546 L
s
.51976 .95729 m
.52461 .95854 L
s
.37289 .83463 m .35536 .83589 L .35869 .83889 L 0 1 .53 r
F
.37289 .83463 m .35834 .83363 L .35536 .83589 L F
.37289 .83463 m .36586 .83309 L .35834 .83363 L F
0 g
.37289 .83463 m
.37619 .83763 L
s
.38129 .82716 m .36586 .83309 L .37289 .83463 L 0 1 .528 r
F
0 g
.37289 .83463 m
.38058 .8335 L
s
.37923 .98957 m .38384 .9946 L .38569 .99233 L 0 1 .537 r
F
.37923 .98957 m .37432 .99511 L .38384 .9946 L F
0 g
.38384 .9946 m
.39097 .99707 L
s
.31706 .87388 m .29731 .86768 L .30114 .87325 L 0 1 .526 r
F
.31706 .87388 m .30057 .86582 L .29731 .86768 L F
.31706 .87388 m .30905 .86848 L .30057 .86582 L F
.32466 .86893 m .30905 .86848 L .31706 .87388 L 0 1 .525 r
F
0 g
.31706 .87388 m
.32527 .8764 L
s
.31706 .87388 m
.32085 .87943 L
s
.46044 1.05283 m .46837 1.05855 L .46898 1.05634 L 0 1 .538 r
F
.49074 1.05849 m .46898 1.05634 L .46837 1.05855 L 0 1 .537 r
F
0 g
.46837 1.05855 m
.47736 1.06184 L
s
.4586 1.0583 m
.46837 1.05855 L
s
.52127 1.06373 m .52156 1.0691 L .53088 1.06899 L 0 1 .534 r
F
.52563 .5792 m .53168 .50229 L .52909 .52191 L 0 .813 .261 r
F
.52563 .5792 m .53284 .50704 L .53168 .50229 L F
0 g
.53168 .50229 m
.53249 .46827 L
s
.52915 .52001 m
.52989 .49678 L
s
.52643 .50991 m
.52678 .49162 L
s
.53284 .50704 m
.534 .49557 L
s
.47833 .88722 m .47657 .8926 L .48325 .89291 L 0 1 .523 r
F
.47833 .88722 m .46824 .89007 L .47657 .8926 L F
.4311 .81151 m .41831 .8132 L .41617 .81582 L 0 1 .519 r
F
.4311 .81151 m .42471 .81136 L .41831 .8132 L F
.43581 .80456 m .42471 .81136 L .4311 .81151 L 0 1 .516 r
F
0 g
.4311 .81151 m
.43456 .8137 L
s
.4311 .81151 m
.43721 .80951 L
s
.54646 .37834 m .55596 .34871 L .55751 .35439 L 0 .083 .108 r
F
.54646 .37834 m .55124 .35893 L .55596 .34871 L F
0 g
.55596 .34871 m
.55651 .34331 L
s
.55124 .35893 m
.55436 .35218 L
s
.55436 .35218 m
.55596 .34871 L
s
.49074 1.05849 m .49954 1.064 L .49973 1.06178 L 0 1 .537 r
F
.52127 1.06373 m .49973 1.06178 L .49954 1.064 L 0 1 .534 r
F
0 g
.49954 1.064 m
.5089 1.06713 L
s
.48996 1.06402 m
.49954 1.064 L
s
.50835 .51877 m .50677 .4749 L .50595 .49237 L 0 1 .273 r
F
.45591 .88612 m .44778 .88338 L .44033 .88354 L 0 1 .525 r
F
0 g
.44033 .88354 m
.44778 .88338 L
s
.45591 .88612 m
.46103 .89032 L
s
.73112 .52165 m .73547 .51971 L .74017 .52749 L 0 .405 .016 r
F
.73112 .52165 m .73159 .5172 L .73547 .51971 L F
0 g
.73172 .51405 m
.73547 .51971 L
s
.73159 .5172 m
.73547 .51971 L
s
.52624 .7225 m .51948 .73698 L .5231 .7382 L 0 1 .414 r
F
0 g
.51986 .74423 m
.5231 .7382 L
s
.36004 .95117 m .36328 .95477 L .36552 .95241 L 0 1 .479 r
F
0 g
.36552 .95241 m
.37479 .94969 L
s
.36004 .95117 m .35416 .95688 L .36328 .95477 L 0 1 .479 r
F
0 g
.36328 .95477 m
.36948 .95577 L
s
.47833 .88722 m .46274 .88649 L .46824 .89007 L 0 1 .523 r
F
.37432 .99511 m .35137 .99596 L .35816 .99884 L 0 1 .538 r
F
0 g
.53461 .95677 m
.53464 .95679 L
s
.53155 .71784 m .53028 .71903 L .52986 .72372 L 0 1 .402 r
F
0 g
.52986 .72372 m
.52986 .72369 L
s
.28091 .86903 m .26449 .86707 L .27258 .87349 L 0 1 .526 r
F
0 g
.27258 .87349 m
.28106 .8769 L
s
.78801 .59578 m .79319 .61106 L .79782 .61115 L 0 .362 .354 r
F
0 g
.79319 .61106 m
.79451 .61908 L
s
.39768 .93585 m
.39776 .93594 L
s
.39675 .93479 m
.39768 .93585 L
s
.41845 .94727 m .40887 .94157 L .40029 .93878 L 0 1 .508 r
F
0 g
.39776 .93594 m
.40029 .93878 L
s
.43064 .90836 m .43439 .91118 L .43587 .90818 L 0 1 .441 r
F
.43064 .90836 m .42665 .91564 L .43439 .91118 L F
0 g
.43439 .91118 m
.44016 .91075 L
s
.45511 .79655 m .44165 .80239 L .44504 .80436 L 0 1 .509 r
F
0 g
.43899 .80669 m
.44504 .80436 L
s
.51947 .9465 m .50249 .95699 L .50981 .95869 L 0 1 .486 r
F
0 g
.5022 .96237 m
.50981 .95869 L
s
.44593 .956 m .44302 .96051 L .45125 .96304 L 0 1 .507 r
F
.44593 .956 m .43309 .95539 L .44302 .96051 L F
0 g
.44302 .96051 m
.44969 .96571 L
s
.76811 .7886 m .76407 .80742 L .77153 .80277 L 0 1 .487 r
F
.76811 .7886 m .76037 .8051 L .76407 .80742 L F
0 g
.76136 .81529 m
.76407 .80742 L
s
.52953 .70538 m .53155 .71784 L .53187 .7132 L 0 1 .391 r
F
.52953 .70538 m .53028 .71903 L .53155 .71784 L F
0 g
.53155 .71784 m
.53315 .7208 L
s
.41034 .8785 m .39469 .87419 L .39243 .8765 L 0 1 .523 r
F
.41034 .8785 m .40237 .87504 L .39469 .87419 L F
0 g
.41034 .8785 m
.41491 .88286 L
s
.44593 .956 m .42673 .95012 L .43309 .95539 L 0 1 .507 r
F
0 g
.42455 .95299 m
.43309 .95539 L
s
.41646 .87117 m .41034 .87849 L .41804 .87887 L 0 1 .52 r
F
.41646 .87117 m .40237 .87504 L .41034 .87849 L F
.39075 .86955 m .39243 .8765 L .39469 .87419 L 0 1 .521 r
F
.39075 .86955 m .38482 .87528 L .39243 .8765 L F
0 g
.39243 .8765 m
.39702 .88087 L
s
.53377 .68478 m .53841 .68984 L .53711 .68504 L 0 1 .372 r
F
.53377 .68478 m .53669 .69674 L .53841 .68984 L F
0 g
.53841 .68984 m
.542 .68963 L
s
.50218 .49138 m .50401 .4848 L .5048 .47041 L 0 1 .266 r
F
0 g
.5048 .47041 m
.50677 .4749 L
s
.34807 .83599 m .34795 .84152 L .35091 .83927 L 0 1 .532 r
F
0 g
.35091 .83927 m
.35869 .83889 L
s
.34807 .83599 m .34041 .84143 L .34795 .84152 L 0 1 .532 r
F
0 g
.34795 .84152 m
.35154 .84463 L
s
.5566 .47093 m .56311 .44141 L .56594 .44545 L 0 .182 .142 r
F
0 g
.55928 .45879 m
.55978 .44502 L
s
.56135 .43191 m
.56137 .44932 L
s
.5566 .47093 m .55912 .45229 L .56311 .44141 L 0 .182 .142 r
F
0 g
.56266 .41839 m
.56311 .44141 L
s
.69255 .471 m .69945 .50088 L .69511 .4909 L 0 .76 .111 r
F
.69255 .471 m .70349 .49786 L .69945 .50088 L F
.69255 .471 m .70452 .48393 L .70349 .49786 L F
0 g
.70193 .46416 m
.70452 .48393 L
s
.70452 .48393 m
.70859 .48108 L
s
.43587 .90818 m
.44353 .90297 L
s
.53669 .69674 m .53102 .7082 L .53187 .7132 L 0 1 .386 r
F
0 g
.53187 .7132 m
.53555 .71375 L
s
.53669 .69674 m .53308 .70115 L .53102 .7082 L 0 1 .386 r
F
.53377 .68478 m .53308 .70115 L .53669 .69674 L 0 1 .372 r
F
0 g
.53669 .69674 m
.54036 .69729 L
s
.53669 .69674 m
.53841 .68984 L
s
.3445 .90433 m .3462 .91319 L .3488 .91124 L 0 1 .496 r
F
.3445 .90433 m .33774 .90915 L .3462 .91319 L F
.36649 .92162 m .3488 .91124 L .3462 .91319 L 0 1 .501 r
F
0 g
.3462 .91319 m
.35128 .91976 L
s
.52953 .70538 m .52879 .71621 L .53028 .71903 L 0 1 .391 r
F
0 g
.52986 .72369 m
.53028 .71903 L
s
.51695 .56343 m .5188 .49529 L .51732 .51658 L 0 .876 .268 r
F
0 g
.51822 .477 m
.5188 .49529 L
s
.44288 .97343 m .44855 .97804 L .4496 .97528 L 0 1 .531 r
F
.44288 .97343 m .43995 .98016 L .44855 .97804 L F
0 g
.44855 .97804 m
.45578 .97971 L
s
.62636 .4311 m
.62647 .44071 L
s
.62624 .42024 m
.62636 .4311 L
s
.62647 .44071 m
.62653 .4463 L
s
.62653 .4463 m
.62662 .45437 L
s
.62662 .45437 m
.62671 .46172 L
s
.62685 .47463 m
.62687 .47675 L
s
.62681 .47101 m
.62685 .47463 L
s
.45867 .88047 m .45591 .88612 L .46274 .88649 L 0 1 .521 r
F
.45867 .88047 m .44778 .88338 L .45591 .88612 L F
0 g
.54072 .66152 m
.54088 .6595 L
s
.41646 .87117 m .41804 .87887 L .42034 .87592 L 0 1 .52 r
F
.43581 .87904 m .42034 .87592 L .41804 .87887 L 0 1 .523 r
F
0 g
.41804 .87887 m
.42258 .88337 L
s
.41034 .87849 m
.41804 .87887 L
s
.38482 .87528 m .36903 .87001 L .36641 .87221 L 0 1 .523 r
F
.38482 .87528 m .37693 .87133 L .36903 .87001 L F
.39075 .86955 m .37693 .87133 L .38482 .87528 L 0 1 .521 r
F
0 g
.38482 .87528 m
.38905 .87996 L
s
.38482 .87528 m
.39243 .8765 L
s
.42239 .94245 m .41845 .94727 L .42673 .95012 L 0 1 .503 r
F
.42239 .94245 m .40887 .94157 L .41845 .94727 L F
0 g
.41845 .94727 m
.42455 .95299 L
s
.49395 .43609 m .49897 .4153 L .49817 .41386 L 0 1 .139 r
F
.49395 .43609 m .49716 .42481 L .49897 .4153 L F
0 g
.49897 .4153 m
.502 .40689 L
s
.49754 .4228 m
.49897 .4153 L
s
.49834 .89415 m .49759 .89896 L .50406 .89949 L 0 1 .519 r
F
.36649 .92162 m .3575 .91486 L .3488 .91124 L 0 1 .501 r
F
.37237 .91668 m .36649 .92162 L .3749 .9252 L 0 1 .497 r
F
.37237 .91668 m .3575 .91486 L .36649 .92162 L F
0 g
.36649 .92162 m
.37154 .92818 L
s
.6568 .98558 m
.65699 .98557 L
s
.47019 .96432 m .47644 .96893 L .47707 .96583 L 0 1 .523 r
F
.49491 .96087 m .47707 .96583 L .47644 .96893 L 0 1 .512 r
F
0 g
.47644 .96893 m
.48375 .97042 L
s
.4685 .97177 m
.47644 .96893 L
s
.41015 .98605 m .38847 .9889 L .39529 .99126 L 0 1 .536 r
F
0 g
.38569 .99233 m
.39529 .99126 L
s
.52953 .70538 m .53187 .7132 L .53102 .70821 L 0 1 .391 r
F
0 g
.53155 .71784 m
.53187 .7132 L
s
.28926 .86454 m .28918 .8723 L .29243 .87046 L 0 1 .526 r
F
0 g
.29243 .87046 m
.30114 .87325 L
s
.28926 .86454 m .28091 .86903 L .28918 .8723 L 0 1 .526 r
F
0 g
.28918 .8723 m
.29326 .87798 L
s
.47596 .77786 m .47809 .78342 L .47914 .77979 L 0 1 .491 r
F
.47596 .77786 m .47303 .78679 L .47809 .78342 L F
.48941 .77466 m .47914 .77979 L .47809 .78342 L 0 1 .483 r
F
0 g
.47809 .78342 m
.48169 .7853 L
s
.53746 .66213 m
.54072 .66152 L
s
.37237 .91668 m .3749 .9252 L .37714 .92321 L 0 1 .497 r
F
.39483 .93263 m .37714 .92321 L .3749 .9252 L 0 1 .503 r
F
0 g
.3749 .9252 m
.38037 .93136 L
s
.36649 .92162 m
.3749 .9252 L
s
.47016 .96821 m .46831 .97218 L .47641 .9744 L 0 1 .505 r
F
0 g
.46831 .97218 m
.47549 .97672 L
s
.76811 .7886 m .76209 .79705 L .76037 .8051 L 0 1 .487 r
F
0 g
.75951 .80557 m
.76037 .8051 L
s
.43995 .98016 m .42058 .98216 L .41912 .98467 L 0 1 .532 r
F
.43995 .98016 m .42951 .98023 L .42058 .98216 L F
.44288 .97343 m .42951 .98023 L .43995 .98016 L 0 1 .531 r
F
0 g
.43995 .98016 m
.44699 .98214 L
s
.43995 .98016 m
.44855 .97804 L
s
.33774 .90915 m .3203 .89768 L .31736 .89955 L 0 1 .499 r
F
.33774 .90915 m .32904 .9018 L .3203 .89768 L F
.3445 .90433 m .32904 .9018 L .33774 .90915 L 0 1 .496 r
F
0 g
.33774 .90915 m
.3462 .91319 L
s
.33774 .90915 m
.3423 .91611 L
s
.43064 1.0463 m .42775 1.0516 L .43762 1.05225 L 0 1 .539 r
F
.43064 1.0463 m .4156 1.04858 L .42775 1.0516 L F
.37432 .99511 m .3536 .99388 L .35137 .99596 L 0 1 .538 r
F
.37432 .99511 m .36345 .99352 L .3536 .99388 L F
.37923 .98957 m .36345 .99352 L .37432 .99511 L 0 1 .537 r
F
0 g
.37432 .99511 m
.38384 .9946 L
s
.37432 .99511 m
.38107 .99799 L
s
.49129 .76484 m .49394 .77064 L .49456 .76663 L 0 1 .474 r
F
.49129 .76484 m .48941 .77466 L .49394 .77064 L F
.50387 .76017 m .49456 .76663 L .49394 .77064 L 0 1 .463 r
F
0 g
.49394 .77064 m
.49759 .77237 L
s
.47303 .78679 m .46198 .79068 L .46058 .79385 L 0 1 .499 r
F
.47303 .78679 m .46732 .78766 L .46198 .79068 L F
0 g
.47303 .78679 m
.47656 .78866 L
s
.47596 .77786 m .46732 .78766 L .47303 .78679 L 0 1 .491 r
F
0 g
.47303 .78679 m
.47809 .78342 L
s
.56693 .49879 m
.56694 .50224 L
s
.56145 .53244 m .56372 .57539 L .56688 .47482 L 0 .927 .221 r
F
0 g
.56372 .57539 m
.56401 .5663 L
s
.56401 .5663 m
.56518 .52899 L
s
.56688 .47482 m
.56693 .49879 L
s
.56142 .50301 m
.56145 .53244 L
s
.48941 .77466 m .48399 .77603 L .47914 .77979 L 0 1 .483 r
F
.49129 .76484 m .48399 .77603 L .48941 .77466 L 0 1 .474 r
F
0 g
.48941 .77466 m
.493 .77655 L
s
.48941 .77466 m
.49394 .77064 L
s
.55255 .49034 m
.55265 .48969 L
s
.53711 .68504 m
.53842 .67762 L
s
.59875 .34352 m .60391 .34039 L .60992 .34976 L 0 .672 .138 r
F
0 g
.60391 .34039 m
.60485 .33041 L
s
.75513 .55052 m .76258 .56253 L .76637 .56626 L 0 0 .153 r
F
0 g
.76258 .56253 m
.76502 .57003 L
s
.5504 .48839 m .55261 .4759 L .55628 .45811 L 0 0 .018 r
F
0 g
.55371 .4824 m
.55412 .4796 L
s
.55379 .48552 m
.55412 .4796 L
s
.55424 .46668 m
.55426 .46658 L
s
.55426 .46658 m
.55496 .46178 L
s
.55359 .47117 m
.55424 .46668 L
s
.55594 .45694 m
.55628 .45811 L
s
.42239 .94245 m .40307 .93581 L .40887 .94157 L 0 1 .503 r
F
0 g
.40029 .93878 m
.40887 .94157 L
s
.45867 .88047 m .44272 .8796 L .44778 .88338 L 0 1 .521 r
F
.50387 .76017 m .49882 .76215 L .49456 .76663 L 0 1 .463 r
F
0 g
.50387 .76017 m
.50751 .76191 L
s
.52007 .98845 m .50965 .98624 L .5017 .98553 L 0 1 .457 r
F
0 g
.50488 .98581 m
.50965 .98624 L
s
.50478 .9858 m
.50488 .98581 L
s
.50334 .98568 m
.50478 .9858 L
s
.5017 .98553 m
.50334 .98568 L
s
.5047 .749 m .50387 .76017 L .5078 .75528 L 0 1 .452 r
F
.5047 .749 m .49882 .76214 L .50387 .76017 L F
.74344 .53368 m .75189 .54496 L .74721 .53832 L 0 0 .134 r
F
.74344 .53368 m .75513 .55052 L .75189 .54496 L F
.74344 .53368 m .75475 .55128 L .75513 .55052 L F
0 g
.75097 .54662 m
.75475 .55128 L
s
.75475 .55128 m
.75791 .55638 L
s
.50037 .40304 m .49617 .41411 L .49697 .41335 L 0 .718 .056 r
F
.50037 .40304 m .49872 .40519 L .49617 .41411 L F
.50037 .40304 m .50292 .39257 L .49872 .40519 L F
.47833 .88722 m .48325 .89291 L .48383 .8908 L 0 1 .523 r
F
0 g
.48325 .89291 m
.48914 .89641 L
s
.47657 .8926 m
.48325 .89291 L
s
.5047 .749 m .5078 .75528 L .508 .75073 L 0 1 .452 r
F
.51622 .74261 m .508 .75073 L .5078 .75528 L 0 1 .439 r
F
0 g
.5078 .75528 m
.51146 .75689 L
s
.50387 .76017 m
.5078 .75528 L
s
.45889 .78876 m .46058 .79385 L .46198 .79068 L 0 1 .504 r
F
.45889 .78876 m .45511 .79655 L .46058 .79385 L F
0 g
.46058 .79385 m
.46412 .79571 L
s
.77779 .79425 m .78094 .80837 L .78746 .79974 L 0 1 .491 r
F
0 g
.7733 .81312 m
.78094 .80837 L
s
.43064 1.0463 m .43762 1.05225 L .43866 1.0501 L 0 1 .539 r
F
.46044 1.05283 m .43866 1.0501 L .43762 1.05225 L 0 1 .538 r
F
0 g
.43762 1.05225 m
.44617 1.05576 L
s
.42775 1.0516 m
.43762 1.05225 L
s
.59082 .35135 m
.59303 .3349 L
s
.59076 .35179 m
.59082 .35135 L
s
.42665 .91564 m .40782 .92553 L .41339 .92555 L 0 1 .461 r
F
0 g
.40691 .92865 m
.41339 .92555 L
s
.45867 .88047 m .46274 .88649 L .46372 .88425 L 0 1 .521 r
F
.47833 .88722 m .46372 .88425 L .46274 .88649 L 0 1 .523 r
F
0 g
.46274 .88649 m
.46824 .89007 L
s
.45591 .88612 m
.46274 .88649 L
s
.49491 .96087 m .48498 .96237 L .47707 .96583 L 0 1 .512 r
F
.49571 .95207 m .49491 .96087 L .50249 .95699 L 0 1 .507 r
F
.49571 .95207 m .48498 .96237 L .49491 .96087 L F
0 g
.49491 .96087 m
.5022 .96237 L
s
.33229 .86394 m .33263 .87132 L .33559 .86928 L 0 1 .524 r
F
.33229 .86394 m .32466 .86893 L .33263 .87132 L F
0 g
.33263 .87132 m
.33673 .87643 L
s
.51622 .74261 m .51161 .7453 L .508 .75073 L 0 1 .439 r
F
.51592 .73071 m .51622 .74261 L .51948 .73698 L 0 1 .428 r
F
.51592 .73071 m .51161 .7453 L .51622 .74261 L F
0 g
.51622 .74261 m
.51986 .74423 L
s
.52953 .70538 m .52808 .71127 L .52879 .71621 L 0 1 .391 r
F
0 g
.52879 .71621 m
.53028 .71903 L
s
.5248 .71026 m .52879 .71622 L .52808 .71127 L 0 1 .402 r
F
.5248 .71026 m .52624 .7225 L .52879 .71622 L F
.51592 .73071 m .51948 .73698 L .51922 .73214 L 0 1 .428 r
F
.52624 .7225 m .51922 .73214 L .51948 .73698 L 0 1 .414 r
F
0 g
.51948 .73698 m
.5231 .7382 L
s
.51622 .74261 m
.51948 .73698 L
s
.53102 .7082 m
.53102 .7082 L
s
.53377 .68478 m .52974 .7009 L .53308 .70115 L 0 1 .372 r
F
0 g
.53102 .7082 m
.53308 .70115 L
s
.52624 .7225 m .52212 .72594 L .51922 .73214 L 0 1 .414 r
F
.5248 .71026 m .52212 .72594 L .52624 .7225 L 0 1 .402 r
F
0 g
.52624 .7225 m
.52986 .72373 L
s
.52624 .7225 m
.52879 .71622 L
s
.4141 .97993 m .41912 .98467 L .42058 .98216 L 0 1 .535 r
F
.4141 .97993 m .41015 .98605 L .41912 .98467 L F
0 g
.41912 .98467 m
.42618 .98665 L
s
.49571 .95207 m .50249 .95699 L .50268 .95332 L 0 1 .507 r
F
.51947 .9465 m .50268 .95332 L .50249 .95699 L 0 1 .486 r
F
0 g
.50249 .95699 m
.50981 .95869 L
s
.49491 .96087 m
.50249 .95699 L
s
.28962 .85438 m .27014 .85096 L .27341 .85517 L 0 1 .537 r
F
.28962 .85438 m .27368 .84924 L .27014 .85096 L F
.28962 .85438 m .28204 .85071 L .27368 .84924 L F
.29799 .84966 m .28204 .85071 L .28962 .85438 L F
0 g
.28962 .85438 m
.29285 .85858 L
s
.28962 .85438 m
.29773 .85566 L
s
.45511 .79655 m .44343 .79948 L .44165 .80239 L 0 1 .509 r
F
.45511 .79655 m .4492 .79697 L .44343 .79948 L F
.45889 .78876 m .4492 .79697 L .45511 .79655 L 0 1 .504 r
F
0 g
.45511 .79655 m
.45849 .79852 L
s
.45511 .79655 m
.46058 .79385 L
s
.41539 .81089 m .41617 .81582 L .41831 .8132 L 0 1 .52 r
F
.41539 .81089 m .40979 .81731 L .41617 .81582 L F
0 g
.41617 .81582 m
.41965 .818 L
s
.49486 .97881 m .48371 .97824 L .49407 .98186 L 0 .983 .485 r
F
.49486 .97881 m .47641 .9744 L .48371 .97824 L F
0 g
.47549 .97672 m
.48371 .97824 L
s
.30637 .84491 m .30588 .85076 L .30914 .84879 L 0 1 .536 r
F
0 g
.30914 .84879 m
.31742 .84939 L
s
.30637 .84491 m .29799 .84966 L .30588 .85076 L 0 1 .536 r
F
0 g
.30588 .85076 m
.3095 .85447 L
s
.3655 .86508 m .36641 .87221 L .36903 .87001 L 0 1 .522 r
F
.3655 .86508 m .35868 .87049 L .36641 .87221 L F
0 g
.36641 .87221 m
.37066 .8769 L
s
.42665 .91564 m .40969 .92284 L .40782 .92553 L 0 1 .461 r
F
.42665 .91564 m .41778 .9186 L .40969 .92284 L F
.43064 .90836 m .41778 .9186 L .42665 .91564 L 0 1 .441 r
F
0 g
.42665 .91564 m
.43439 .91118 L
s
.42665 .91564 m
.43219 .91568 L
s
.44593 .956 m .45125 .96304 L .45229 .96128 L 0 1 .507 r
F
0 g
.45125 .96304 m
.45733 .96718 L
s
.44302 .96051 m
.45125 .96304 L
s
.42239 .94245 m .42673 .95012 L .42818 .94821 L 0 1 .503 r
F
.44593 .956 m .42818 .94821 L .42673 .95012 L 0 1 .507 r
F
0 g
.42673 .95012 m
.43309 .95539 L
s
.41845 .94727 m
.42673 .95012 L
s
.35868 .87049 m .34002 .8662 L .34385 .87123 L 0 1 .523 r
F
.70349 .49786 m .71301 .49113 L .71549 .50746 L 0 .689 .104 r
F
0 g
.71301 .49113 m
.71667 .49454 L
s
.49074 1.05849 m .47857 1.05632 L .46898 1.05634 L 0 1 .537 r
F
.41646 .87117 m .39847 .87028 L .40237 .87504 L 0 1 .52 r
F
0 g
.40237 .87504 m
.40237 .87504 L
s
.39469 .87419 m
.40237 .87504 L
s
.56637 .32949 m .57741 .32933 L .57946 .34572 L 0 .524 .16 r
F
0 g
.57741 .32933 m
.57975 .31412 L
s
.57181 .32241 m
.57741 .32933 L
s
.49672 .44573 m .49716 .42481 L .49395 .43609 L 0 1 .191 r
F
0 g
.49716 .42481 m
.49754 .4228 L
s
.49716 .42481 m
.50015 .41974 L
s
.5188 .90678 m
.52082 .90772 L
s
.52082 .90772 m
.52375 .90908 L
s
.52375 .90908 m
.52532 .90981 L
s
.53141 .91551 m
.53154 .91564 L
s
.52807 .91237 m
.52808 .91237 L
s
.62346 .3708 m .6257 .38585 L .6224 .3676 L 0 0 .048 r
F
0 g
.62335 .37047 m
.62346 .3708 L
s
.62261 .36824 m
.62335 .37047 L
s
.62248 .36785 m
.62261 .36824 L
s
.6224 .3676 m
.62248 .36785 L
s
.62156 .36509 m
.6224 .3676 L
s
.62116 .357 m
.62346 .3708 L
s
.52127 1.06373 m .50904 1.06166 L .49973 1.06178 L 0 1 .534 r
F
.52127 1.06373 m .53088 1.06899 L .53064 1.06687 L F
0 g
.53088 1.06899 m
.54051 1.07196 L
s
.52156 1.0691 m
.53088 1.06899 L
s
.31655 .8904 m .31736 .89955 L .3203 .89768 L 0 1 .496 r
F
.31655 .8904 m .30895 .89499 L .31736 .89955 L F
0 g
.31736 .89955 m
.32195 .90652 L
s
.37237 .91668 m .35271 .90831 L .3575 .91486 L 0 1 .497 r
F
0 g
.3488 .91124 m
.3575 .91486 L
s
.39483 .93263 m .38568 .9264 L .37714 .92321 L 0 1 .503 r
F
0 g
.39856 .93407 m
.39856 .93407 L
s
.39977 .92767 m .38568 .9264 L .39483 .93263 L 0 1 .498 r
F
0 g
.39483 .93263 m
.39653 .93329 L
s
.39483 .93263 m
.39601 .93397 L
s
.77652 .58362 m .78645 .59998 L .78801 .59578 L 0 .324 .33 r
F
0 g
.78645 .59998 m
.78867 .60652 L
s
.78188 .59937 m
.78645 .59998 L
s
.79947 .60671 m .79997 .61757 L .80449 .62172 L 0 .415 .376 r
F
.79947 .60671 m .79782 .61115 L .79997 .61757 L F
0 g
.79451 .61908 m
.79997 .61757 L
s
.49456 .76663 m
.49882 .76215 L
s
.38772 .82137 m .38809 .82637 L .39056 .824 L 0 1 .526 r
F
.38772 .82137 m .38129 .82716 L .38809 .82637 L F
0 g
.38809 .82637 m
.39156 .82885 L
s
.43064 1.0463 m .40757 1.04478 L .4156 1.04858 L 0 1 .539 r
F
.49129 .76484 m .48071 .77424 L .48399 .77603 L 0 1 .474 r
F
0 g
.47914 .77979 m
.48399 .77603 L
s
.51462 .56432 m .51673 .49876 L .51533 .5015 L 0 .893 .271 r
F
.51462 .56432 m .51732 .51658 L .51673 .49876 L F
0 g
.51673 .49876 m
.51822 .477 L
s
.51673 .49876 m
.51673 .49878 L
s
.43581 .80456 m .42152 .80923 L .42471 .81136 L 0 1 .516 r
F
0 g
.41831 .8132 m
.42471 .81136 L
s
.40979 .81731 m .39427 .82042 L .39748 .82282 L 0 1 .523 r
F
0 g
.39056 .824 m
.39748 .82282 L
s
.53728 .40958 m .53653 .40878 L .53547 .41872 L 0 .729 .056 r
F
.53437 .45813 m .53728 .40958 L .53389 .43961 L 0 1 .152 r
F
.52114 .36142 m .52623 .34842 L .5305 .34459 L 0 .097 .104 r
F
0 g
.4496 .97528 m
.45807 .97262 L
s
.41015 .98605 m .39032 .98661 L .38847 .9889 L 0 1 .536 r
F
.41015 .98605 m .39962 .98539 L .39032 .98661 L F
.4141 .97993 m .39962 .98539 L .41015 .98605 L 0 1 .535 r
F
0 g
.41015 .98605 m
.41693 .98841 L
s
.41015 .98605 m
.41912 .98467 L
s
.49946 .46372 m .49558 .45857 L .49681 .46528 L 0 1 .241 r
F
.49946 .46372 m .49672 .44573 L .49558 .45857 L F
.50218 .49138 m .49946 .46372 L .49866 .47811 L 0 1 .266 r
F
.5047 .749 m .49551 .76042 L .49882 .76214 L 0 1 .452 r
F
.56241 .34504 m .56144 .37014 L .55986 .36357 L 0 .264 .149 r
F
.56241 .34504 m .5667 .36486 L .56144 .37014 L F
.56241 .34504 m .57211 .35131 L .5667 .36486 L F
.35416 .95688 m .33215 .96133 L .33797 .96274 L 0 1 .49 r
F
.35416 .95688 m .33475 .95924 L .33215 .96133 L F
.35416 .95688 m .3442 .95733 L .33475 .95924 L F
.36004 .95117 m .3442 .95733 L .35416 .95688 L 0 1 .479 r
F
0 g
.35416 .95688 m
.36328 .95477 L
s
.35416 .95688 m
.35992 .95829 L
s
.34041 .84143 m .32223 .84083 L .32536 .84426 L 0 1 .533 r
F
.34041 .84143 m .32551 .83882 L .32223 .84083 L F
.34041 .84143 m .33331 .83908 L .32551 .83882 L F
.34807 .83599 m .33331 .83908 L .34041 .84143 L 0 1 .532 r
F
0 g
.34041 .84143 m
.34795 .84152 L
s
.34041 .84143 m
.34351 .84486 L
s
.28054 .87902 m .28064 .8885 L .28388 .88675 L 0 1 .498 r
F
.28054 .87902 m .27221 .88329 L .28064 .8885 L F
0 g
.28064 .8885 m
.28491 .89595 L
s
.43581 .87904 m .42796 .876 L .42034 .87592 L 0 1 .523 r
F
0 g
.43581 .87904 m
.44033 .88354 L
s
.30895 .89499 m .28876 .88413 L .29278 .8915 L 0 1 .498 r
F
.43954 .8733 m .43581 .87904 L .44272 .8796 L 0 1 .519 r
F
.43954 .8733 m .42796 .876 L .43581 .87904 L F
.49486 .97881 m .49407 .98186 L .50198 .98376 L 0 .983 .485 r
F
0 g
.49407 .98186 m
.5017 .98553 L
s
.49672 .44573 m .49247 .44727 L .49372 .45085 L 0 1 .191 r
F
.49672 .44573 m .49395 .43609 L .49247 .44727 L F
0 g
.46198 .79068 m
.46732 .78766 L
s
.47596 .77786 m .46413 .78574 L .46732 .78766 L 0 1 .491 r
F
.49834 .89415 m .50406 .89949 L .50424 .89765 L 0 1 .519 r
F
0 g
.50406 .89949 m
.50759 .90171 L
s
.49759 .89896 m
.50406 .89949 L
s
.35868 .87049 m .34298 .86414 L .34002 .8662 L 0 1 .523 r
F
.35868 .87049 m .35099 .86599 L .34298 .86414 L F
0 g
.33559 .86928 m
.34385 .87123 L
s
.3655 .86508 m .35099 .86599 L .35868 .87049 L 0 1 .522 r
F
0 g
.35868 .87049 m
.36641 .87221 L
s
.35868 .87049 m
.36248 .8755 L
s
.52953 .70538 m .52839 .70662 L .52808 .71127 L 0 1 .391 r
F
0 g
.52808 .71127 m
.52808 .71125 L
s
.51592 .73071 m .5083 .74388 L .51161 .7453 L 0 1 .428 r
F
0 g
.508 .75073 m
.51161 .7453 L
s
.44053 .79741 m .44165 .80239 L .44343 .79948 L 0 1 .512 r
F
.44053 .79741 m .43581 .80456 L .44165 .80239 L F
0 g
.44165 .80239 m
.44504 .80436 L
s
.55622 .50033 m
.55689 .49723 L
s
.42034 .87592 m
.42796 .876 L
s
.53746 .66213 m
.53774 .65949 L
s
.5248 .71026 m .51883 .72494 L .52212 .72594 L 0 1 .402 r
F
0 g
.51922 .73214 m
.52212 .72594 L
s
.49571 .95207 m .478 .96114 L .48498 .96237 L 0 1 .507 r
F
0 g
.47707 .96583 m
.48498 .96237 L
s
.39075 .86955 m .37297 .86669 L .37693 .87133 L 0 1 .521 r
F
0 g
.36903 .87001 m
.37693 .87133 L
s
.51947 .9465 m .50996 .94882 L .50268 .95332 L 0 1 .486 r
F
.51917 .93476 m .50996 .94882 L .51947 .9465 L 0 1 .473 r
F
0 g
.51947 .9465 m
.52102 .94525 L
s
.51947 .9465 m
.52203 .9471 L
s
.40979 .81731 m .39675 .81801 L .39427 .82042 L 0 1 .523 r
F
.40979 .81731 m .40341 .81668 L .39675 .81801 L F
.41539 .81089 m .40341 .81668 L .40979 .81731 L 0 1 .52 r
F
0 g
.40979 .81731 m
.41617 .81582 L
s
.40979 .81731 m
.41298 .81971 L
s
.52932 .94261 m
.53079 .94346 L
s
.5275 .69353 m .52953 .70538 L .52974 .7009 L 0 1 .378 r
F
.5275 .69353 m .52839 .70662 L .52953 .70538 L F
0 g
.52953 .70538 m
.53102 .70821 L
s
.76811 .7886 m .77153 .80277 L .77779 .79425 L 0 1 .487 r
F
0 g
.76407 .80742 m
.77153 .80277 L
s
.76961 .81085 m
.77153 .80277 L
s
.52114 .36142 m .5305 .34459 L .53114 .35247 L 0 .097 .104 r
F
0 g
.5305 .34459 m
.53375 .32777 L
s
.52623 .34842 m
.5305 .34459 L
s
.63426 .43456 m
.63498 .44061 L
s
.63256 .42042 m
.63365 .42954 L
s
.6339 .43159 m
.63426 .43456 L
s
.63234 .41863 m
.63256 .42042 L
s
.6289 .39002 m
.62909 .39158 L
s
.62909 .39158 m
.62947 .39475 L
s
.62947 .39475 m
.62985 .39792 L
s
.62985 .39792 m
.63067 .40474 L
s
.62875 .39067 m
.62877 .39058 L
s
.62877 .39058 m
.62878 .39055 L
s
.62853 .39168 m
.62875 .39067 L
s
.62839 .39232 m
.62853 .39168 L
s
.62821 .39315 m
.62839 .39232 L
s
.62878 .39055 m
.6289 .39002 L
s
.50875 .38061 m .51342 .36739 L .51703 .36161 L 0 0 .07 r
F
0 g
.51342 .36739 m
.51679 .35445 L
s
.50875 .38061 m .51703 .36161 L .51718 .36708 L 0 0 .07 r
F
0 g
.51703 .36161 m
.52037 .34618 L
s
.51342 .36739 m
.51703 .36161 L
s
.47016 .96821 m .47641 .9744 L .47703 .97289 L 0 1 .505 r
F
.49486 .97881 m .47703 .97289 L .47641 .9744 L 0 .983 .485 r
F
0 g
.47641 .9744 m
.48371 .97824 L
s
.46831 .97218 m
.47641 .9744 L
s
.42239 .94245 m .40493 .93384 L .40307 .93581 L 0 1 .503 r
F
0 g
.39856 .93407 m
.40307 .93581 L
s
.40307 .93581 m
.40887 .94157 L
s
.28091 .86903 m .26105 .86101 L .26449 .86707 L 0 1 .526 r
F
.28091 .86903 m .26459 .85935 L .26105 .86101 L F
.28091 .86903 m .27311 .86279 L .26459 .85935 L F
.28926 .86454 m .27311 .86279 L .28091 .86903 L F
0 g
.28091 .86903 m
.28918 .8723 L
s
.28091 .86903 m
.28431 .87507 L
s
.43954 .8733 m .44272 .8796 L .4441 .8773 L 0 1 .519 r
F
.45867 .88047 m .4441 .8773 L .44272 .8796 L 0 1 .521 r
F
0 g
.44272 .8796 m
.44778 .88338 L
s
.43581 .87904 m
.44272 .8796 L
s
.56637 .32949 m .56502 .35655 L .56345 .3441 L 0 .524 .16 r
F
.5667 .36487 m .57762 .34851 L .5796 .35831 L 0 .285 .141 r
F
.5667 .36487 m .57211 .35131 L .57762 .34851 L F
.56637 .32949 m .57066 .36358 L .56502 .35655 L 0 .524 .16 r
F
.56637 .32949 m .57658 .36044 L .57066 .36358 L F
.56637 .32949 m .57946 .34572 L .57658 .36044 L F
.53085 .67407 m .53516 .67824 L .53385 .67398 L 0 1 .354 r
F
.53085 .67407 m .53377 .68478 L .53516 .67824 L F
0 g
.53516 .67824 m
.53842 .67762 L
s
.54332 .37528 m .55124 .35893 L .54646 .37834 L 0 0 .096 r
F
0 g
.55124 .35893 m
.55263 .34903 L
s
.3445 .90433 m .32471 .89488 L .32904 .9018 L 0 1 .496 r
F
0 g
.3203 .89768 m
.32904 .9018 L
s
.32466 .86893 m .30547 .86302 L .30905 .86848 L 0 1 .525 r
F
.32466 .86893 m .30874 .86114 L .30547 .86302 L F
.32466 .86893 m .31697 .86368 L .30874 .86114 L F
.33229 .86394 m .31697 .86368 L .32466 .86893 L 0 1 .524 r
F
0 g
.32466 .86893 m
.33263 .87132 L
s
.32466 .86893 m
.32821 .87437 L
s
.53377 .68478 m .52888 .69615 L .52974 .7009 L 0 1 .372 r
F
0 g
.52974 .7009 m
.53308 .70115 L
s
.53377 .68478 m .53061 .68924 L .52888 .69615 L 0 1 .372 r
F
.53085 .67407 m .53061 .68924 L .53377 .68478 L 0 1 .354 r
F
0 g
.53377 .68478 m
.53711 .68504 L
s
.53377 .68478 m
.53516 .67824 L
s
.30895 .89499 m .29201 .88237 L .28876 .88413 L 0 1 .498 r
F
.30895 .89499 m .30068 .88704 L .29201 .88237 L F
0 g
.28388 .88675 m
.29278 .8915 L
s
.31655 .8904 m .30068 .88704 L .30895 .89499 L 0 1 .496 r
F
0 g
.30895 .89499 m
.31736 .89955 L
s
.30895 .89499 m
.31295 .90235 L
s
.53884 .62605 m
.53907 .62578 L
s
.54031 .62185 m
.54036 .6221 L
s
.40106 .92921 m
.40108 .92922 L
s
.40108 .92922 m
.40434 .9295 L
s
.44288 .97343 m .42277 .97838 L .42951 .98023 L 0 1 .531 r
F
0 g
.42058 .98216 m
.42951 .98023 L
s
.38129 .82716 m .36331 .8298 L .36586 .83309 L 0 1 .528 r
F
.39977 .92767 m .38051 .92023 L .38568 .9264 L 0 1 .498 r
F
0 g
.37714 .92321 m
.38568 .9264 L
s
.5275 .69353 m .52701 .70401 L .52839 .70662 L 0 1 .378 r
F
0 g
.52808 .71125 m
.52839 .70662 L
s
.48383 .8908 m
.4903 .89133 L
s
.49395 .43609 m .49817 .41386 L .49482 .42142 L 0 1 .139 r
F
0 g
.49616 .41841 m
.49817 .41386 L
s
.49817 .41386 m
.50037 .40304 L
s
.52573 .92753 m
.53125 .92777 L
s
.53125 .92777 m
.53271 .92783 L
s
.54332 .37528 m .54201 .39271 L .54089 .39233 L 0 0 .096 r
F
.54332 .37528 m .54646 .37834 L .54201 .39271 L F
0 g
.52615 .93584 m
.53271 .92789 L
s
.47833 .88722 m .4704 .88456 L .46372 .88425 L 0 1 .523 r
F
.5275 .69353 m .52974 .7009 L .52888 .69615 L 0 1 .378 r
F
0 g
.52953 .70538 m
.52974 .7009 L
s
.43581 .80456 m .42366 .80656 L .42152 .80923 L 0 1 .516 r
F
.43581 .80456 m .42979 .80455 L .42366 .80656 L F
.44053 .79741 m .42979 .80455 L .43581 .80456 L 0 1 .512 r
F
0 g
.43581 .80456 m
.43899 .80669 L
s
.43581 .80456 m
.44165 .80239 L
s
.65621 .52801 m
.65621 .52812 L
s
.65558 .51182 m
.65621 .52801 L
s
.65513 .50021 m
.65558 .51182 L
s
.65356 .45945 m
.65471 .48927 L
s
.65481 .49179 m
.65513 .50021 L
s
.55491 1.0738 m
.55567 1.07379 L
s
.39477 .93559 m .37451 .94292 L .38012 .94356 L 0 1 .473 r
F
.39477 .93559 m .37677 .94053 L .37451 .94292 L F
.39477 .93559 m .38546 .93738 L .37677 .94053 L F
.39974 .9291 m .38546 .93738 L .39477 .93559 L 0 1 .457 r
F
0 g
.39477 .93559 m
.39776 .93594 L
s
.39477 .93559 m
.39856 .93407 L
s
.49153 1.05278 m .47857 1.05632 L .49074 1.05849 L 0 1 .536 r
F
.49153 1.05278 m .4699 1.053 L .47857 1.05632 L F
0 g
.46898 1.05634 m
.47857 1.05632 L
s
.46044 1.05283 m .44844 1.05035 L .43866 1.0501 L 0 1 .538 r
F
0 g
.65542 .50766 m
.65755 .51181 L
s
.65755 .51181 m
.65766 .51203 L
s
.52007 .98845 m
.52109 .98876 L
s
.52109 .98876 m
.52252 .98918 L
s
.52401 .98962 m
.52444 .98975 L
s
.5188 .90678 m
.52501 .9082 L
s
.49153 1.05278 m .49074 1.05849 L .50001 1.0584 L 0 1 .536 r
F
0 g
.49074 1.05849 m
.49973 1.06178 L
s
.35574 .83048 m .35536 .83589 L .35834 .83363 L 0 1 .53 r
F
0 g
.35834 .83363 m
.36586 .83309 L
s
.35574 .83048 m .34807 .83599 L .35536 .83589 L 0 1 .53 r
F
0 g
.35536 .83589 m
.35869 .83889 L
s
.60064 .44004 m .60612 .53099 L .60212 .50137 L 0 .825 .204 r
F
.60064 .44004 m .61146 .55436 L .60612 .53099 L F
.60064 .44004 m .61454 .55557 L .61146 .55436 L F
0 g
.59647 .47551 m
.59799 .46253 L
s
.59799 .46253 m
.59799 .46253 L
s
.59799 .46253 m
.59799 .46253 L
s
.59799 .46253 m
.59799 .46253 L
s
.59799 .46253 m
.59822 .46059 L
s
.59822 .46059 m
.59846 .45852 L
s
.59846 .45852 m
.60064 .44004 L
s
.70102 .97075 m .68767 .98068 L .69724 .9783 L 0 1 .536 r
F
.70102 .97075 m .68528 .97932 L .68767 .98068 L F
0 g
.68573 .98178 m
.68767 .98068 L
s
.43954 .8733 m .42339 .87199 L .42796 .876 L 0 1 .519 r
F
.51462 .56432 m .51533 .5015 L .51418 .52183 L 0 .893 .271 r
F
0 g
.51526 .50281 m
.51533 .5015 L
s
.5144 .48652 m
.51533 .5015 L
s
.79947 .60671 m .80449 .62172 L .80918 .62131 L 0 .415 .376 r
F
0 g
.80449 .62172 m
.80553 .62846 L
s
.73112 .52165 m .74017 .52749 L .74332 .53601 L 0 .405 .016 r
F
0 g
.74017 .52749 m
.74344 .53368 L
s
.45889 .78876 m .4461 .79505 L .4492 .79697 L 0 1 .504 r
F
0 g
.44343 .79948 m
.4492 .79697 L
s
.51917 .93476 m .50296 .94774 L .50996 .94882 L 0 1 .473 r
F
0 g
.50268 .95332 m
.50996 .94882 L
s
.62099 .40341 m
.6223 .41977 L
s
.6223 .41977 m
.62255 .42291 L
s
.62255 .42291 m
.62279 .42588 L
s
.62279 .42588 m
.62342 .43372 L
s
.62342 .43372 m
.62381 .4386 L
s
.62658 .47306 m
.62703 .47865 L
s
.62752 .48478 m
.62778 .48809 L
s
.62644 .47128 m
.62658 .47306 L
s
.62078 .41105 m
.62094 .40521 L
s
.62075 .41192 m
.62078 .41105 L
s
.62074 .41252 m
.62075 .41192 L
s
.6207 .41375 m
.62074 .41252 L
s
.62094 .40521 m
.62095 .40489 L
s
.62095 .40489 m
.62099 .40341 L
s
.29763 .86002 m .29731 .86768 L .30057 .86582 L 0 1 .525 r
F
0 g
.30057 .86582 m
.30905 .86848 L
s
.29763 .86002 m .28926 .86454 L .29731 .86768 L 0 1 .525 r
F
0 g
.29731 .86768 m
.30114 .87325 L
s
.50369 .98431 m
.504 .98441 L
s
.504 .98441 m
.50965 .98624 L
s
.38129 .82716 m .36697 .82698 L .36331 .8298 L 0 1 .528 r
F
.38129 .82716 m .37469 .82584 L .36697 .82698 L F
0 g
.38129 .82716 m
.38381 .83044 L
s
.38772 .82137 m .37469 .82584 L .38129 .82716 L 0 1 .526 r
F
0 g
.38129 .82716 m
.38809 .82637 L
s
.44593 .956 m .43641 .95073 L .42818 .94821 L 0 1 .507 r
F
.46229 1.04725 m .46044 1.05283 L .4699 1.053 L 0 1 .538 r
F
.46229 1.04725 m .44844 1.05035 L .46044 1.05283 L F
0 g
.46044 1.05283 m
.46898 1.05634 L
s
.5049 .52894 m .50401 .4848 L .50218 .49138 L 0 1 .277 r
F
.5049 .52894 m .50595 .49237 L .50401 .4848 L F
0 g
.50401 .4848 m
.5048 .47041 L
s
.74284 .78718 m
.74318 .78514 L
s
.34756 .9907 m .35137 .99596 L .3536 .99388 L 0 1 .538 r
F
.34756 .9907 m .34171 .99575 L .35137 .99596 L F
0 g
.35137 .99596 m
.35816 .99884 L
s
.77652 .58362 m .78571 .589 L .78109 .5842 L 0 .324 .33 r
F
.77652 .58362 m .78801 .59578 L .78571 .589 L F
.46379 .96574 m .46038 .9654 L .45222 .96832 L 0 1 .523 r
F
.47019 .96432 m .4636 .96504 L .46395 .96571 L F
.47207 .95666 m .47019 .96432 L .478 .96114 L 0 1 .519 r
F
.47207 .95666 m .4627 .96366 L .47019 .96432 L F
.4627 .96366 m .46039 .96349 L .4635 .96499 L 0 .987 .496 r
F
.4627 .96366 m .4635 .96499 L .4636 .96504 L F
.46379 .96574 m .46039 .96349 L .45229 .96128 L 0 1 .505 r
F
.4636 .96504 m .46039 .96349 L .46379 .96574 L F
.4627 .96366 m .4538 .9641 L .46038 .9654 L 0 1 .519 r
F
.4627 .96366 m .45385 .95865 L .46039 .96349 L 0 .987 .496 r
F
.47207 .95666 m .46138 .96101 L .4627 .96366 L 0 1 .519 r
F
.47202 .96436 m .46138 .96101 L .4627 .96366 L 0 .987 .496 r
F
.46138 .96101 m .45385 .95865 L .46232 .96345 L F
.46138 .96101 m .45485 .96127 L .4538 .9641 L 0 1 .519 r
F
.46138 .96101 m .45489 .9569 L .45385 .95865 L 0 .987 .496 r
F
.47207 .95666 m .46109 .9596 L .46138 .96101 L 0 1 .519 r
F
.47202 .96436 m .46109 .9596 L .46138 .96101 L 0 .987 .496 r
F
.46109 .9596 m .45489 .9569 L .46138 .96101 L F
.46109 .9596 m .46085 .95966 L .46138 .96101 L 0 1 .519 r
F
.46085 .95966 m .45485 .96127 L .46138 .96101 L F
.46138 .96101 m .46232 .96345 L .4627 .96366 L 0 .987 .496 r
F
.46138 .96101 m .46116 .9611 L .4627 .96366 L 0 1 .519 r
F
.46116 .9611 m .4538 .9641 L .4627 .96366 L F
.4627 .96366 m .46038 .9654 L .4636 .96504 L F
.4627 .96366 m .4636 .96504 L .47019 .96432 L F
.46289 .96368 m .4627 .96366 L .4636 .96504 L 0 .987 .496 r
F
.47202 .96436 m .46289 .96368 L .47016 .96821 L F
.46289 .96368 m .4636 .96504 L .47016 .96821 L F
.46395 .96571 m .4636 .96504 L .46379 .96574 L 0 1 .523 r
F
.4636 .96504 m .46038 .9654 L .46379 .96574 L F
.47016 .96821 m .4636 .96504 L .46379 .96574 L 0 1 .505 r
F
0 g
.45229 .96128 m
.45461 .96191 L
s
.36594 .94543 m .36889 .94886 L .37113 .94649 L 0 1 .465 r
F
0 g
.37113 .94649 m
.38012 .94356 L
s
.36594 .94543 m .36004 .95117 L .36889 .94886 L 0 1 .465 r
F
0 g
.36889 .94886 m
.37479 .94969 L
s
.26554 .85366 m
.27341 .85517 L
s
.28054 .87902 m .26419 .87457 L .27221 .88329 L 0 1 .498 r
F
0 g
.27221 .88329 m
.28064 .8885 L
s
.76215 .835 m .77128 .84287 L .77428 .83663 L 0 1 .491 r
F
.38416 .98398 m .38847 .9889 L .39032 .98661 L 0 1 .536 r
F
.38416 .98398 m .37923 .98957 L .38847 .9889 L F
0 g
.38847 .9889 m
.39529 .99126 L
s
.5357 .34968 m .54113 .33808 L .54603 .3373 L 0 .237 .13 r
F
0 g
.54113 .33808 m
.54434 .32127 L
s
.53344 .65411 m .5319 .6682 L .53484 .66707 L 0 1 .323 r
F
0 g
.53385 .67398 m
.53484 .66707 L
s
.5504 .48839 m .55912 .45229 L .5566 .47093 L 0 0 .018 r
F
0 g
.55257 .4682 m
.55356 .44798 L
s
.55256 .46847 m
.55257 .4682 L
s
.55465 .49652 m
.55619 .48391 L
s
.55308 .49849 m
.55379 .48552 L
s
.55271 .48926 m
.55371 .4824 L
s
.55453 .46662 m
.55628 .45811 L
s
.55397 .46931 m
.55453 .46662 L
s
.55345 .47183 m
.55397 .46931 L
s
.55323 .47292 m
.55345 .47183 L
s
.55261 .4759 m
.55323 .47292 L
s
.55912 .45229 m
.56311 .44141 L
s
.55898 .44684 m
.55912 .45229 L
s
.52099 1.05813 m .50904 1.06166 L .52127 1.06373 L 0 1 .532 r
F
.52099 1.05813 m .50001 1.0584 L .50904 1.06166 L F
0 g
.49973 1.06178 m
.50904 1.06166 L
s
.75841 .78278 m .76209 .79705 L .76811 .7886 L 0 1 .482 r
F
0 g
.75929 .79879 m
.76209 .79705 L
s
.76037 .8051 m
.76209 .79705 L
s
.53359 .52154 m
.53452 .51593 L
s
.50835 .51877 m .50974 .51492 L .51055 .49738 L 0 1 .273 r
F
.49325 .75432 m .49551 .76042 L .49616 .75614 L 0 1 .463 r
F
.49325 .75432 m .49129 .76483 L .49551 .76042 L F
.5047 .749 m .49616 .75614 L .49551 .76042 L 0 1 .452 r
F
0 g
.49551 .76042 m
.49882 .76214 L
s
.49129 .76484 m .48177 .77048 L .48071 .77424 L 0 1 .474 r
F
.49129 .76484 m .4863 .76645 L .48177 .77048 L F
0 g
.49129 .76484 m
.49456 .76663 L
s
.49325 .75432 m .4863 .76645 L .49129 .76483 L 0 1 .463 r
F
0 g
.49129 .76483 m
.49551 .76042 L
s
.4789 .76863 m .48071 .77424 L .48177 .77048 L 0 1 .482 r
F
.4789 .76863 m .47596 .77786 L .48071 .77424 L F
0 g
.48071 .77424 m
.48399 .77603 L
s
.32296 .96264 m .32565 .96654 L .32824 .96446 L 0 1 .481 r
F
0 g
.32824 .96446 m
.33797 .96274 L
s
.32296 .96264 m .3162 .96765 L .32565 .96654 L 0 1 .481 r
F
0 g
.32565 .96654 m
.33175 .96812 L
s
.5275 .69353 m .5263 .69929 L .52701 .70401 L 0 1 .378 r
F
0 g
.52701 .70401 m
.52839 .70662 L
s
.52335 .69852 m .52701 .70401 L .5263 .69929 L 0 1 .386 r
F
.52335 .69852 m .5248 .71026 L .52701 .70401 L F
.37923 .98957 m .35695 .99076 L .36345 .99352 L 0 1 .537 r
F
0 g
.3536 .99388 m
.36345 .99352 L
s
.55119 .56864 m .5603 .50897 L .5567 .52095 L 0 1 .264 r
F
0 g
.55975 .53931 m
.56144 .52183 L
s
.55965 .54036 m
.55975 .53931 L
s
.5603 .50897 m
.56095 .49343 L
s
.52888 .69615 m
.52888 .69614 L
s
.53085 .67407 m .5276 .68933 L .53061 .68924 L 0 1 .354 r
F
0 g
.52888 .69614 m
.53061 .68924 L
s
.5248 .71026 m .51858 .72016 L .51883 .72494 L 0 1 .402 r
F
.5248 .71026 m .52113 .71387 L .51858 .72016 L F
.52335 .69852 m .52113 .71387 L .5248 .71026 L 0 1 .386 r
F
0 g
.5248 .71026 m
.52808 .71127 L
s
.5248 .71026 m
.52701 .70401 L
s
.50554 .73769 m .5083 .74388 L .5085 .73928 L 0 1 .44 r
F
.50554 .73769 m .5047 .749 L .5083 .74388 L F
.51592 .73071 m .5085 .73928 L .5083 .74388 L 0 1 .428 r
F
0 g
.5083 .74388 m
.51161 .7453 L
s
.5047 .749 m .5001 .75124 L .49616 .75614 L 0 1 .452 r
F
.50554 .73769 m .5001 .75124 L .5047 .749 L 0 1 .44 r
F
0 g
.5047 .749 m
.508 .75073 L
s
.5047 .749 m
.5083 .74388 L
s
.51561 .71891 m .51883 .72494 L .51858 .72016 L 0 1 .414 r
F
.51561 .71891 m .51592 .73071 L .51883 .72494 L F
0 g
.51883 .72494 m
.52212 .72594 L
s
.47596 .77786 m .46559 .78232 L .46413 .78574 L 0 1 .491 r
F
.47596 .77786 m .47067 .77894 L .46559 .78232 L F
.4789 .76863 m .47067 .77894 L .47596 .77786 L 0 1 .482 r
F
0 g
.47596 .77786 m
.47914 .77979 L
s
.47596 .77786 m
.48071 .77424 L
s
.46229 1.04725 m .44021 1.04687 L .44844 1.05035 L 0 1 .538 r
F
0 g
.43866 1.0501 m
.44844 1.05035 L
s
.51592 .73071 m .51176 .73364 L .5085 .73928 L 0 1 .428 r
F
.51561 .71891 m .51176 .73364 L .51592 .73071 L 0 1 .414 r
F
0 g
.51592 .73071 m
.51883 .72494 L
s
.51592 .73071 m
.51922 .73214 L
s
.29799 .84966 m .279 .84666 L .28204 .85071 L 0 1 .537 r
F
.29799 .84966 m .28256 .84493 L .279 .84666 L F
.29799 .84966 m .2907 .84622 L .28256 .84493 L F
.30637 .84491 m .2907 .84622 L .29799 .84966 L 0 1 .536 r
F
0 g
.29799 .84966 m
.30588 .85076 L
s
.29799 .84966 m
.30098 .85371 L
s
.35129 .89949 m .35271 .90831 L .35532 .90636 L 0 1 .493 r
F
.35129 .89949 m .3445 .90433 L .35271 .90831 L F
.37237 .91668 m .35532 .90636 L .35271 .90831 L 0 1 .497 r
F
0 g
.35271 .90831 m
.3575 .91486 L
s
.68101 .9777 m
.68169 .97732 L
s
.55256 .47578 m
.55256 .47547 L
s
.55256 .47199 m
.55256 .46903 L
s
.55256 .47362 m
.55256 .47199 L
s
.55256 .47547 m
.55256 .47362 L
s
.55256 .4762 m
.55256 .47578 L
s
.55256 .46903 m
.55256 .46847 L
s
.39805 .86242 m .39847 .87028 L .40125 .86739 L 0 1 .519 r
F
.39805 .86242 m .39075 .86955 L .39847 .87028 L F
.41646 .87117 m .40125 .86739 L .39847 .87028 L 0 1 .52 r
F
0 g
.39075 .86955 m
.39847 .87028 L
s
.39847 .87028 m
.40237 .87504 L
s
.53648 .65061 m
.53655 .64885 L
s
.39075 .86955 m .3756 .86446 L .37297 .86669 L 0 1 .521 r
F
.39075 .86955 m .38322 .86569 L .3756 .86446 L F
0 g
.39075 .86955 m
.39469 .87419 L
s
.39805 .86242 m .38322 .86569 L .39075 .86955 L 0 1 .519 r
F
0 g
.39075 .86955 m
.39075 .86955 L
s
.49834 .89415 m
.50102 .89574 L
s
.50102 .89574 m
.50424 .89765 L
s
.50424 .89765 m
.50622 .8981 L
s
.50965 .89888 m
.51006 .89897 L
s
.31477 .8401 m .31404 .84582 L .31731 .84383 L 0 1 .535 r
F
0 g
.31731 .84383 m
.32536 .84426 L
s
.31477 .8401 m .30637 .84491 L .31404 .84582 L 0 1 .535 r
F
0 g
.31404 .84582 m
.31742 .84939 L
s
.76679 .56512 m .76953 .57116 L .77416 .57655 L 0 .063 .172 r
F
.76679 .56512 m .76637 .56626 L .76953 .57116 L F
0 g
.76502 .57003 m
.76953 .57116 L
s
.76953 .57115 m
.76953 .57116 L
s
.70102 .97075 m .69724 .9783 L .70762 .97375 L 0 1 .536 r
F
.70112 .97419 m .68775 .98351 L .69736 .98252 L 0 1 .54 r
F
0 g
.68767 .98068 m
.6941 .97908 L
s
.70112 .97419 m .68534 .98144 L .68775 .98351 L 0 1 .54 r
F
0 g
.68123 .98733 m
.68775 .98351 L
s
.48009 .88151 m .47833 .88722 L .48471 .88752 L 0 1 .517 r
F
.48009 .88151 m .4704 .88456 L .47833 .88722 L F
0 g
.47833 .88722 m
.48383 .8908 L
s
.48009 .88151 m .4652 .88081 L .4704 .88456 L 0 1 .517 r
F
0 g
.46372 .88425 m
.4704 .88456 L
s
.45867 .88047 m .45094 .87767 L .4441 .8773 L 0 1 .521 r
F
0 g
.52007 .98845 m
.52192 .98877 L
s
.52376 .98907 m
.52437 .98918 L
s
.52192 .98877 m
.52197 .98877 L
s
.52331 .989 m
.52376 .98907 L
s
.40159 1.0386 m .39768 1.04366 L .40757 1.04478 L 0 1 .539 r
F
.40159 1.0386 m .38592 1.04011 L .39768 1.04366 L F
.52146 .56705 m .52342 .51276 L .52193 .54296 L 0 .846 .263 r
F
.51924 .56426 m .52193 .54296 L .52342 .51276 L 0 .86 .265 r
F
0 g
.52342 .51276 m
.52346 .50381 L
s
.52342 .51276 m
.52532 .49263 L
s
.40159 1.0386 m .40757 1.04478 L .40901 1.04273 L 0 1 .539 r
F
.43064 1.0463 m .40901 1.04273 L .40757 1.04478 L F
0 g
.40757 1.04478 m
.4156 1.04858 L
s
.39768 1.04366 m
.40757 1.04478 L
s
.52805 .916 m
.52821 .91566 L
s
.52821 .91566 m
.5287 .91461 L
s
.52573 .91371 m
.52625 .91325 L
s
.5566 .47093 m .56594 .44545 L .56592 .46267 L 0 .182 .142 r
F
0 g
.56139 .46668 m
.56142 .4984 L
s
.56594 .44545 m
.56993 .42497 L
s
.73967 .78737 m
.74318 .78514 L
s
.3445 .90433 m .32766 .893 L .32471 .89488 L 0 1 .496 r
F
.3445 .90433 m .33615 .89706 L .32766 .893 L F
.35129 .89949 m .33615 .89706 L .3445 .90433 L 0 1 .493 r
F
0 g
.3445 .90433 m
.35271 .90831 L
s
.3445 .90433 m
.3488 .91124 L
s
.46286 .78034 m .46413 .78574 L .46559 .78232 L 0 1 .497 r
F
.46286 .78034 m .45889 .78876 L .46413 .78574 L F
0 g
.46413 .78574 m
.46732 .78766 L
s
.40106 .92921 m
.40109 .92924 L
s
.40103 .92917 m
.40106 .92921 L
s
.40064 .9287 m
.40103 .92917 L
s
.42239 .94245 m .41322 .93668 L .40493 .93384 L 0 1 .503 r
F
0 g
.40109 .92924 m
.40493 .93384 L
s
.46229 1.04725 m .4699 1.053 L .47052 1.05074 L 0 1 .538 r
F
.49153 1.05278 m .47052 1.05074 L .4699 1.053 L 0 1 .536 r
F
0 g
.4699 1.053 m
.47857 1.05632 L
s
.46044 1.05283 m
.4699 1.053 L
s
.49872 .40519 m .50581 .38536 L .50548 .38833 L 0 0 0 r
F
.49872 .40519 m .50292 .39257 L .50581 .38536 L F
0 g
.50292 .39257 m
.50446 .38789 L
s
.50581 .38536 m
.50921 .37235 L
s
.50292 .39257 m
.50581 .38536 L
s
.37237 .91668 m .36375 .90994 L .35532 .90636 L 0 1 .497 r
F
.37826 .91171 m .37237 .91668 L .38051 .92023 L 0 1 .493 r
F
.37826 .91171 m .36375 .90994 L .37237 .91668 L F
0 g
.37237 .91668 m
.37714 .92321 L
s
.33993 .8589 m .34002 .8662 L .34298 .86414 L 0 1 .523 r
F
.33993 .8589 m .33229 .86394 L .34002 .8662 L F
0 g
.34002 .8662 m
.34385 .87123 L
s
.47207 .95666 m .478 .96114 L .47863 .95797 L 0 1 .519 r
F
0 g
.47186 .96469 m
.47707 .96583 L
s
.49571 .95207 m .47863 .95797 L .478 .96114 L 0 1 .507 r
F
0 g
.478 .96114 m
.48498 .96237 L
s
.47108 .96395 m
.478 .96114 L
s
.50835 .51877 m .50595 .49237 L .50672 .50909 L 0 1 .273 r
F
.5049 .52894 m .50672 .50909 L .50595 .49237 L 0 1 .277 r
F
0 g
.50401 .4848 m
.50595 .49237 L
s
.50595 .49237 m
.50677 .4749 L
s
.49486 .97881 m .50198 .98376 L .50217 .98266 L 0 .983 .485 r
F
0 g
.50198 .98376 m
.50369 .98431 L
s
.49407 .98186 m
.50198 .98376 L
s
.5236 .57199 m .52632 .51539 L .52442 .54652 L 0 .831 .262 r
F
.52146 .56705 m .52442 .54652 L .52632 .51539 L 0 .846 .263 r
F
0 g
.52632 .51539 m
.52866 .49416 L
s
.52632 .51539 m
.52643 .50991 L
s
.59875 .34352 m .60992 .34976 L .61281 .36548 L 0 .672 .138 r
F
0 g
.60992 .34976 m
.61142 .34284 L
s
.60391 .34039 m
.60992 .34976 L
s
.76215 .835 m .77428 .83663 L .77054 .83351 L 0 1 .491 r
F
.44582 .96662 m .45117 .97112 L .45222 .96832 L 0 1 .528 r
F
.44582 .96662 m .44288 .97343 L .45117 .97112 L F
0 g
.45117 .97112 m
.45807 .97262 L
s
.67876 .50613 m .68856 .47362 L .69077 .50234 L 0 .678 .17 r
F
0 g
.68856 .47362 m
.69255 .471 L
s
.52099 1.05813 m .52127 1.06373 L .53027 1.06362 L 0 1 .532 r
F
0 g
.52127 1.06373 m
.53064 1.06687 L
s
.49153 1.05278 m .50001 1.0584 L .5002 1.0561 L 0 1 .536 r
F
.52099 1.05813 m .5002 1.0561 L .50001 1.0584 L 0 1 .532 r
F
0 g
.50001 1.0584 m
.50904 1.06166 L
s
.49074 1.05849 m
.50001 1.0584 L
s
.42101 .80432 m .42152 .80923 L .42366 .80656 L 0 1 .517 r
F
.42101 .80432 m .41539 .81089 L .42152 .80923 L F
0 g
.42152 .80923 m
.42471 .81136 L
s
.46144 .8746 m .45867 .88047 L .4652 .88081 L 0 1 .517 r
F
.46144 .8746 m .45094 .87767 L .45867 .88047 L F
0 g
.45867 .88047 m
.46372 .88425 L
s
.56397 1.07475 m
.56405 1.07479 L
s
.4141 .97993 m .39311 .98316 L .39962 .98539 L 0 1 .535 r
F
0 g
.39032 .98661 m
.39962 .98539 L
s
.45889 .78876 m .44788 .79206 L .4461 .79505 L 0 1 .504 r
F
.45889 .78876 m .45337 .78936 L .44788 .79206 L F
0 g
.45889 .78876 m
.46198 .79068 L
s
.46286 .78034 m .45337 .78935 L .45889 .78876 L 0 1 .497 r
F
0 g
.45889 .78876 m
.46413 .78574 L
s
.49384 .48478 m .49681 .46528 L .49558 .45857 L 0 1 .256 r
F
.49384 .48478 m .49607 .4765 L .49681 .46528 L F
0 g
.49681 .46528 m
.49946 .46372 L
s
.37826 .91171 m .38051 .92023 L .38276 .91823 L 0 1 .493 r
F
.39977 .92767 m .38276 .91823 L .38051 .92023 L 0 1 .498 r
F
0 g
.38051 .92023 m
.38568 .9264 L
s
.37237 .91668 m
.38051 .92023 L
s
.59909 .36638 m .6116 .42457 L .60578 .41305 L 0 .86 .113 r
F
.59909 .36638 m .6137 .41725 L .6116 .42457 L F
.59909 .36638 m .6107 .39611 L .6137 .41725 L F
.59909 .36638 m .60445 .37438 L .6107 .39611 L F
.59875 .34352 m .59914 .36691 L .5967 .35486 L 0 .672 .138 r
F
.59875 .34352 m .60519 .3764 L .59914 .36691 L F
.59875 .34352 m .61079 .37694 L .60519 .3764 L F
.59875 .34352 m .61281 .36548 L .61079 .37694 L F
0 g
.59303 .3349 m
.59875 .34352 L
s
.5967 .35486 m
.59875 .34352 L
s
.49486 .97881 m .48493 .97478 L .47703 .97289 L 0 .983 .485 r
F
.37923 .98957 m .35919 .98867 L .35695 .99076 L 0 1 .537 r
F
.37923 .98957 m .36875 .98816 L .35919 .98867 L F
.38416 .98398 m .36875 .98816 L .37923 .98957 L 0 1 .536 r
F
0 g
.37923 .98957 m
.38847 .9889 L
s
.37923 .98957 m
.38569 .99233 L
s
.3655 .86508 m .34743 .86104 L .35099 .86599 L 0 1 .522 r
F
.5381 .50488 m .54065 .49548 L .54387 .45479 L 0 1 .222 r
F
0 g
.54065 .49548 m
.54117 .48889 L
s
.54117 .48889 m
.54387 .45479 L
s
.54387 .45479 m
.54437 .48304 L
s
.44288 .97343 m .42423 .97585 L .42277 .97838 L 0 1 .531 r
F
.44288 .97343 m .43286 .97373 L .42423 .97585 L F
.44582 .96662 m .43286 .97373 L .44288 .97343 L 0 1 .528 r
F
0 g
.44288 .97343 m
.4496 .97528 L
s
.44288 .97343 m
.45117 .97112 L
s
.49384 .48478 m .49558 .45857 L .49264 .46067 L 0 1 .256 r
F
0 g
.49558 .45857 m
.49672 .44573 L
s
.49571 .95207 m .48622 .95409 L .47863 .95797 L 0 1 .507 r
F
.49652 .94309 m .49571 .95207 L .50296 .94774 L 0 1 .5 r
F
.49652 .94309 m .48622 .95409 L .49571 .95207 L F
0 g
.49571 .95207 m
.50268 .95332 L
s
.70102 .97075 m .69099 .97506 L .68528 .97932 L 0 1 .536 r
F
0 g
.67843 .98032 m
.68528 .97932 L
s
.44885 .95152 m .43641 .95073 L .44593 .956 L 0 1 .5 r
F
.44885 .95152 m .43037 .94535 L .43641 .95073 L F
0 g
.42818 .94821 m
.43641 .95073 L
s
.49652 .94309 m .50296 .94774 L .50315 .94398 L 0 1 .5 r
F
.51917 .93476 m .50315 .94398 L .50296 .94774 L 0 1 .473 r
F
0 g
.50296 .94774 m
.50996 .94882 L
s
.49571 .95207 m
.50296 .94774 L
s
.41646 .87117 m .40897 .86777 L .40125 .86739 L 0 1 .52 r
F
0 g
.41646 .87117 m
.42034 .87592 L
s
.42114 .86547 m .41646 .87117 L .42339 .87199 L 0 1 .518 r
F
.42114 .86547 m .40897 .86777 L .41646 .87117 L F
.39415 .81548 m .39427 .82042 L .39675 .81801 L 0 1 .523 r
F
.39415 .81548 m .38772 .82137 L .39427 .82042 L F
0 g
.39427 .82042 m
.39748 .82282 L
s
.5275 .69353 m .52651 .69479 L .5263 .69929 L 0 1 .378 r
F
0 g
.5263 .69929 m
.5263 .69928 L
s
.54646 .37834 m .55751 .35439 L .55477 .3708 L 0 .083 .108 r
F
0 g
.55751 .35439 m
.56241 .34504 L
s
.37233 .8596 m .37297 .86669 L .3756 .86446 L 0 1 .52 r
F
.37233 .8596 m .3655 .86508 L .37297 .86669 L F
0 g
.37297 .86669 m
.37693 .87133 L
s
.81092 .61661 m .81126 .62768 L .81577 .63148 L 0 .49 .397 r
F
.81092 .61661 m .80918 .62131 L .81126 .62768 L F
0 g
.80631 .62932 m
.81126 .62768 L
s
.34807 .83599 m .33043 .83579 L .33331 .83908 L 0 1 .532 r
F
.34807 .83599 m .33372 .83376 L .33043 .83579 L F
.34807 .83599 m .34129 .83384 L .33372 .83376 L F
.35574 .83048 m .34129 .83384 L .34807 .83599 L 0 1 .53 r
F
0 g
.34807 .83599 m
.35536 .83589 L
s
.34807 .83599 m
.35091 .83927 L
s
.40473 .92258 m .40782 .92553 L .40969 .92284 L 0 1 .436 r
F
0 g
.40606 .92631 m
.40782 .92553 L
s
.40782 .92553 m
.41339 .92555 L
s
.43064 .90836 m .41251 .9188 L .41778 .9186 L 0 1 .441 r
F
.44885 .95152 m .44593 .956 L .45385 .95865 L 0 1 .5 r
F
0 g
.44593 .956 m
.45229 .96128 L
s
.51917 .93476 m .5101 .93841 L .50315 .94398 L 0 1 .473 r
F
0 g
.51917 .93476 m
.52615 .93584 L
s
.51881 .92087 m .5101 .93841 L .51917 .93475 L 0 1 .457 r
F
0 g
.51917 .93475 m
.52573 .92753 L
s
.2889 .87473 m .28876 .88413 L .29201 .88237 L 0 1 .495 r
F
.2889 .87473 m .28054 .87902 L .28876 .88413 L F
0 g
.28876 .88413 m
.29278 .8915 L
s
.5357 .34968 m .54603 .3373 L .54716 .34786 L 0 .237 .13 r
F
0 g
.54603 .3373 m
.54911 .32026 L
s
.54113 .33808 m
.54603 .3373 L
s
.42114 .86547 m .42339 .87199 L .42516 .8697 L 0 1 .518 r
F
.43954 .8733 m .42516 .8697 L .42339 .87199 L 0 1 .519 r
F
0 g
.42339 .87199 m
.42796 .876 L
s
.41646 .87117 m
.42339 .87199 L
s
.41539 .81089 m .40047 .81436 L .40341 .81668 L 0 1 .52 r
F
0 g
.39675 .81801 m
.40341 .81668 L
s
.52335 .69852 m .51819 .71311 L .52113 .71387 L 0 1 .386 r
F
0 g
.51858 .72016 m
.52113 .71387 L
s
.51227 .5667 m .51324 .50611 L .51184 .5095 L 0 .912 .274 r
F
.51227 .5667 m .51418 .52183 L .51324 .50611 L F
0 g
.51324 .50611 m
.5144 .48652 L
s
.46144 .8746 m .44618 .87381 L .45094 .87767 L 0 1 .517 r
F
0 g
.4441 .8773 m
.45094 .87767 L
s
.34756 .9907 m .33103 .99339 L .34171 .99575 L 0 1 .538 r
F
0 g
.34171 .99575 m
.35137 .99596 L
s
.42635 .93762 m .42239 .94245 L .43037 .94535 L 0 1 .498 r
F
.42635 .93762 m .41322 .93668 L .42239 .94245 L F
0 g
.42239 .94245 m
.42818 .94821 L
s
.52547 .68267 m .5275 .69353 L .5276 .68933 L 0 1 .36 r
F
.52547 .68267 m .52651 .69479 L .5275 .69353 L F
0 g
.5275 .69353 m
.52888 .69615 L
s
.48177 .77048 m
.4863 .76645 L
s
.49325 .75432 m .48338 .76464 L .4863 .76645 L 0 1 .463 r
F
0 g
.59316 .34427 m
.59489 .35073 L
s
.59489 .35073 m
.59589 .35445 L
s
.59195 .35241 m
.59316 .34427 L
s
.50554 .73769 m .49714 .74966 L .5001 .75124 L 0 1 .44 r
F
0 g
.49616 .75614 m
.5001 .75124 L
s
.77779 .79425 m .78746 .79974 L .78941 .79163 L 0 1 .491 r
F
.51924 .56426 m .52041 .51337 L .51936 .542 L 0 .86 .265 r
F
.51695 .56343 m .51936 .542 L .52041 .51337 L 0 .876 .268 r
F
0 g
.52041 .51337 m
.52061 .51085 L
s
.52025 .50064 m
.52041 .51337 L
s
.44053 .79741 m .42687 .80249 L .42979 .80455 L 0 1 .512 r
F
0 g
.42366 .80656 m
.42979 .80455 L
s
.32416 .88579 m .32471 .89488 L .32766 .893 L 0 1 .492 r
F
.32416 .88579 m .31655 .8904 L .32471 .89488 L F
0 g
.32471 .89488 m
.32904 .9018 L
s
.51561 .71891 m .50879 .73239 L .51176 .73364 L 0 1 .414 r
F
0 g
.5085 .73928 m
.51176 .73364 L
s
.31655 .8904 m .2969 .87974 L .30068 .88704 L 0 1 .496 r
F
0 g
.49834 .89415 m
.50451 .89464 L
s
.43064 .90836 m .41439 .9161 L .41251 .9188 L 0 1 .441 r
F
0 g
.40969 .92284 m
.41778 .9186 L
s
.43064 .90836 m .42217 .91162 L .41439 .9161 L 0 1 .441 r
F
0 g
.43064 .90836 m
.43587 .90818 L
s
.28926 .86454 m .26991 .85686 L .27311 .86279 L 0 1 .526 r
F
.28926 .86454 m .27345 .85519 L .26991 .85686 L F
.28926 .86454 m .28176 .85849 L .27345 .85519 L F
.29763 .86002 m .28176 .85849 L .28926 .86454 L 0 1 .525 r
F
0 g
.28926 .86454 m
.29731 .86768 L
s
.28926 .86454 m
.29243 .87046 L
s
.6091 .37678 m
.60933 .37809 L
s
.60933 .37809 m
.61053 .38494 L
s
.43064 1.0463 m .41891 1.04338 L .40901 1.04273 L 0 1 .539 r
F
.43354 1.04095 m .43064 1.0463 L .44021 1.04687 L F
.43354 1.04095 m .41891 1.04338 L .43064 1.0463 L F
0 g
.43064 1.0463 m
.43866 1.0501 L
s
.50218 .49138 m .49866 .47811 L .49989 .48852 L 0 1 .266 r
F
.49769 .50766 m .49866 .47811 L .49607 .4765 L 0 1 .273 r
F
.49769 .50766 m .49989 .48852 L .49866 .47811 L F
0 g
.49866 .47811 m
.49946 .46372 L
s
.42635 .93762 m .40773 .93086 L .41322 .93668 L 0 1 .498 r
F
0 g
.40493 .93384 m
.41322 .93668 L
s
.52547 .68267 m .52523 .69248 L .52651 .69479 L 0 1 .36 r
F
0 g
.5263 .69928 m
.52651 .69479 L
s
.46144 .8746 m .4652 .88081 L .46619 .87847 L 0 1 .517 r
F
.48009 .88151 m .46619 .87847 L .4652 .88081 L F
0 g
.4652 .88081 m
.4704 .88456 L
s
.45867 .88047 m
.4652 .88081 L
s
.4789 .76863 m .46779 .77709 L .47067 .77894 L 0 1 .482 r
F
0 g
.46559 .78232 m
.47067 .77894 L
s
.48009 .88151 m .48471 .88752 L .48529 .88526 L 0 1 .517 r
F
0 g
.48471 .88752 m
.4903 .89133 L
s
.47833 .88722 m
.48471 .88752 L
s
.26229 .84898 m .26129 .85522 L .26482 .85352 L 0 1 .538 r
F
0 g
.26482 .85352 m
.26554 .85366 L
s
.26229 .84898 m .25325 .85306 L .26129 .85522 L 0 1 .538 r
F
0 g
.26129 .85522 m
.26459 .85935 L
s
.41539 .81089 m .40295 .81191 L .40047 .81436 L 0 1 .52 r
F
.41539 .81089 m .40936 .81042 L .40295 .81191 L F
.42101 .80432 m .40936 .81042 L .41539 .81089 L 0 1 .517 r
F
0 g
.41539 .81089 m
.42152 .80923 L
s
.41539 .81089 m
.41831 .8132 L
s
.44526 .79005 m .4461 .79505 L .44788 .79206 L 0 1 .506 r
F
.44526 .79005 m .44053 .79741 L .4461 .79505 L F
0 g
.4461 .79505 m
.4492 .79697 L
s
.41806 .97376 m .42277 .97838 L .42423 .97585 L 0 1 .533 r
F
.41806 .97376 m .4141 .97993 L .42277 .97838 L F
0 g
.42277 .97838 m
.42951 .98023 L
s
.53141 .91549 m
.53154 .91564 L
s
.52501 .9082 m
.52575 .90904 L
s
.78801 .59578 m .79782 .61115 L .79947 .60671 L 0 .362 .354 r
F
0 g
.79782 .61115 m
.79997 .61757 L
s
.79319 .61106 m
.79782 .61115 L
s
.53085 .67407 m .52675 .68499 L .5276 .68933 L 0 1 .354 r
F
0 g
.5276 .68933 m
.53061 .68924 L
s
.53085 .67407 m .52814 .67845 L .52675 .68499 L 0 1 .354 r
F
.52792 .66524 m .53085 .67407 L .5319 .6682 L 0 1 .328 r
F
.52792 .66524 m .52814 .67845 L .53085 .67407 L F
0 g
.53085 .67407 m
.53385 .67398 L
s
.54796 .50237 m
.54798 .50214 L
s
.54798 .50214 m
.54806 .50098 L
s
.54834 .49705 m
.54834 .49705 L
s
.54806 .50098 m
.54834 .49705 L
s
.54834 .49705 m
.54867 .49233 L
s
.54867 .49233 m
.54913 .48586 L
s
.54913 .48586 m
.5492 .48494 L
s
.37826 .91171 m .35924 .90342 L .36375 .90994 L 0 1 .493 r
F
0 g
.35532 .90636 m
.36375 .90994 L
s
.3655 .86508 m .3504 .85896 L .34743 .86104 L 0 1 .522 r
F
.3655 .86508 m .35815 .86069 L .3504 .85896 L F
0 g
.34298 .86414 m
.35099 .86599 L
s
.37233 .8596 m .35815 .86069 L .3655 .86508 L 0 1 .52 r
F
0 g
.3655 .86508 m
.36903 .87001 L
s
.3655 .86508 m
.37297 .86669 L
s
.70112 .97419 m .69105 .97745 L .68534 .98144 L 0 1 .54 r
F
0 g
.68528 .97932 m
.68782 .97742 L
s
.67733 .982 m
.68534 .98144 L
s
.33229 .86394 m .31364 .85832 L .31697 .86368 L 0 1 .524 r
F
.33229 .86394 m .31692 .85643 L .31364 .85832 L F
.33229 .86394 m .32492 .85884 L .31692 .85643 L F
.33993 .8589 m .32492 .85884 L .33229 .86394 L 0 1 .523 r
F
0 g
.33229 .86394 m
.34002 .8662 L
s
.33229 .86394 m
.33559 .86928 L
s
.52547 .68267 m .5276 .68933 L .52675 .685 L 0 1 .36 r
F
0 g
.5275 .69353 m
.5276 .68933 L
s
.36004 .95117 m .33867 .9561 L .3442 .95733 L 0 1 .479 r
F
.36004 .95117 m .34128 .954 L .33867 .9561 L F
.36004 .95117 m .35045 .95189 L .34128 .954 L F
.36594 .94543 m .35045 .95189 L .36004 .95117 L 0 1 .465 r
F
0 g
.36004 .95117 m
.36889 .94886 L
s
.36004 .95117 m
.36552 .95241 L
s
.49395 .43609 m .48932 .44253 L .49059 .4437 L 0 1 .139 r
F
.49395 .43609 m .49114 .43296 L .48932 .44253 L F
.49395 .43609 m .49482 .42142 L .49114 .43296 L F
0 g
.74401 .81794 m
.74461 .81786 L
s
.74419 .81694 m
.74519 .81414 L
s
.52792 .66524 m .5319 .6682 L .5306 .66474 L 0 1 .328 r
F
.53344 .65411 m .5306 .66474 L .5319 .6682 L 0 1 .323 r
F
0 g
.5319 .6682 m
.53484 .66707 L
s
.53085 .67407 m
.5319 .6682 L
s
.5049 .52894 m .50218 .49138 L .50172 .50703 L 0 1 .277 r
F
.70112 .97419 m .69736 .98252 L .70779 .97913 L 0 1 .54 r
F
0 g
.68775 .98351 m
.69736 .98252 L
s
.53403 .6385 m
.53533 .63735 L
s
.53368 .6388 m
.53403 .6385 L
s
.53621 .63326 m
.53632 .63429 L
s
.43354 1.04095 m .44021 1.04687 L .44124 1.04469 L 0 1 .539 r
F
.46229 1.04725 m .44124 1.04469 L .44021 1.04687 L 0 1 .538 r
F
0 g
.44021 1.04687 m
.44844 1.05035 L
s
.43064 1.0463 m
.44021 1.04687 L
s
.31655 .8904 m .30016 .87797 L .2969 .87974 L 0 1 .496 r
F
.31655 .8904 m .30859 .88255 L .30016 .87797 L F
0 g
.29201 .88237 m
.30068 .88704 L
s
.32416 .88579 m .30859 .88255 L .31655 .8904 L 0 1 .492 r
F
0 g
.31655 .8904 m
.32471 .89488 L
s
.31655 .8904 m
.3203 .89768 L
s
.40125 .86739 m
.40897 .86777 L
s
.55119 .56864 m .5567 .52095 L .55313 .54593 L 0 1 .264 r
F
.55119 .56864 m .55582 .56162 L .55965 .54036 L F
.55119 .56864 m .55219 .57379 L .55582 .56162 L F
.54893 .64214 m .54998 .62682 L .55358 .61177 L 0 .209 .16 r
F
.54893 .64214 m .55444 .67136 L .55083 .66125 L F
.546 .67804 m .55083 .66125 L .55444 .67136 L 0 .32 .184 r
F
.546 .67804 m .54722 .6641 L .55083 .66125 L F
.54986 .6692 m .55591 .47748 L .55254 .52191 L 0 .831 .236 r
F
0 g
.55501 .50599 m
.55622 .50033 L
s
.54986 .6692 m .55811 .49067 L .55591 .47748 L 0 .831 .236 r
F
0 g
.55591 .47287 m
.55591 .47748 L
s
.55255 .4896 m
.55256 .48232 L
s
.5492 .48494 m
.55028 .4696 L
s
.55255 .50132 m
.55308 .49849 L
s
.55705 .51638 m
.5583 .50014 L
s
.55673 .52059 m
.55705 .51638 L
s
.55671 .52091 m
.5603 .50897 L
s
.39805 .86242 m .38 .86071 L .38322 .86569 L 0 1 .519 r
F
0 g
.38322 .86569 m
.38322 .86569 L
s
.3756 .86446 m
.38322 .86569 L
s
.47202 .96436 m .47016 .96821 L .47795 .97067 L 0 .987 .496 r
F
0 g
.47016 .96821 m
.47703 .97289 L
s
.40159 1.0386 m .37848 1.03598 L .38592 1.04011 L 0 1 .539 r
F
0 g
.27443 .84937 m
.28204 .85071 L
s
.52563 .5792 m .52909 .52191 L .52679 .55303 L 0 .813 .261 r
F
.5236 .57199 m .52679 .55303 L .52909 .52191 L 0 .831 .262 r
F
0 g
.52909 .52191 m
.52915 .52001 L
s
.52909 .52191 m
.53168 .50229 L
s
.63414 .48081 m
.63612 .48968 L
s
.63414 .48081 m
.63424 .48402 L
s
.63424 .48402 m
.63441 .48918 L
s
.63441 .48918 m
.63471 .49861 L
s
.63471 .49861 m
.63476 .50014 L
s
.63476 .50014 m
.63522 .51452 L
s
.63522 .51452 m
.63527 .51615 L
s
.63596 .53731 m
.63597 .53759 L
s
.63585 .53415 m
.63588 .53498 L
s
.35129 .89949 m .33209 .89018 L .33615 .89706 L 0 1 .493 r
F
0 g
.32766 .893 m
.33615 .89706 L
s
.43954 .8733 m .43208 .87026 L .42516 .8697 L 0 1 .519 r
F
.44329 .8674 m .43954 .8733 L .44618 .87381 L 0 1 .516 r
F
.44329 .8674 m .43208 .87026 L .43954 .8733 L F
0 g
.43954 .8733 m
.4441 .8773 L
s
.81092 .61661 m .81577 .63148 L .82052 .6306 L 0 .49 .397 r
F
0 g
.81577 .63148 m
.81686 .63916 L
s
.56096 .52498 m
.56144 .51931 L
s
.56007 .53544 m
.56096 .52498 L
s
.55965 .54036 m
.56007 .53544 L
s
.30602 .85547 m .30547 .86302 L .30874 .86114 L 0 1 .524 r
F
0 g
.30874 .86114 m
.31697 .86368 L
s
.30602 .85547 m .29763 .86002 L .30547 .86302 L 0 1 .524 r
F
0 g
.30547 .86302 m
.30905 .86848 L
s
.44053 .79741 m .42902 .79974 L .42687 .80249 L 0 1 .512 r
F
.44053 .79741 m .43488 .79757 L .42902 .79974 L F
.44526 .79005 m .43488 .79757 L .44053 .79741 L 0 1 .506 r
F
0 g
.44053 .79741 m
.44343 .79948 L
s
.44053 .79741 m
.4461 .79505 L
s
.45222 .96832 m
.46038 .9654 L
s
.48996 .47022 m .49372 .45085 L .49247 .44727 L 0 1 .224 r
F
.48996 .47022 m .49264 .46067 L .49372 .45085 L F
0 g
.49372 .45085 m
.49672 .44573 L
s
.53344 .65411 m .53126 .6587 L .5306 .66474 L 0 1 .323 r
F
.52942 .6494 m .53344 .65411 L .53377 .6494 L 0 1 .285 r
F
.52942 .6494 m .53126 .6587 L .53344 .65411 L F
0 g
.53344 .65411 m
.53523 .65344 L
s
.4141 .97993 m .39498 .98086 L .39311 .98316 L 0 1 .535 r
F
.4141 .97993 m .40398 .97947 L .39498 .98086 L F
.41806 .97376 m .40398 .97947 L .4141 .97993 L 0 1 .533 r
F
0 g
.4141 .97993 m
.42058 .98216 L
s
.4141 .97993 m
.42277 .97838 L
s
.39977 .92767 m .39101 .92142 L .38276 .91823 L 0 1 .498 r
F
.40439 .92303 m .39101 .92142 L .39977 .92767 L 0 1 .494 r
F
.40439 .92303 m .39082 .93117 L .39974 .9291 L 0 1 .436 r
F
.40473 .92258 m .40458 .92267 L .40439 .92303 L F
.40457 .92267 m .39101 .92142 L .40432 .92302 L 0 1 .494 r
F
.40457 .92267 m .38613 .91523 L .39101 .92142 L F
.40473 .92269 m .4046 .92264 L .40457 .92267 L F
.4046 .92264 m .38613 .91523 L .40457 .92267 L F
.40461 .92264 m .38839 .91322 L .38613 .91523 L F
.40473 .92269 m .40462 .92262 L .40461 .92264 L F
.40462 .92262 m .38839 .91322 L .40461 .92264 L F
.40973 .91605 m .40819 .91707 L .40473 .92258 L 0 1 .409 r
F
.40461 .92262 m .39636 .91642 L .38839 .91322 L 0 1 .494 r
F
.40473 .92258 m .4046 .92264 L .40458 .92267 L 0 1 .436 r
F
.40473 .92269 m .40462 .92261 L .40461 .92262 L 0 1 .494 r
F
.40462 .92261 m .39636 .91642 L .40461 .92262 L F
.4046 .92264 m .4046 .92264 L .40459 .92265 L 0 1 .436 r
F
.4046 .92264 m .40459 .92265 L .40458 .92267 L F
.40819 .91707 m .40758 .91747 L .40462 .92261 L 0 1 .409 r
F
.40819 .91707 m .40462 .92261 L .40473 .92258 L F
.40973 .91605 m .40473 .92258 L .41251 .9188 L F
.4097 .91767 m .40758 .91747 L .40473 .92269 L 0 1 .488 r
F
.40758 .91747 m .40751 .91746 L .40443 .92246 L F
.40751 .91746 m .39636 .91642 L .40393 .92209 L F
.40751 .91746 m .40393 .92209 L .40443 .92246 L F
.40751 .91746 m .39178 .9102 L .39636 .91642 L F
.4097 .91767 m .40793 .91693 L .40751 .91746 L F
.40793 .91693 m .39178 .9102 L .40751 .91746 L F
.40793 .91693 m .39404 .90818 L .39178 .9102 L F
.4097 .91767 m .40812 .91671 L .40793 .91693 L F
.40812 .91671 m .39404 .90818 L .40793 .91693 L F
.40973 .91605 m .40812 .91671 L .40793 .91693 L 0 1 .409 r
F
.40812 .91671 m .4081 .91671 L .40793 .91693 L F
.40793 .91693 m .40808 .91672 L .40791 .91694 L F
.4081 .91671 m .40808 .91672 L .40793 .91693 L F
.40791 .91694 m .39377 .92251 L .3915 .92491 L F
.40808 .91672 m .39377 .92251 L .40791 .91694 L F
.40758 .91747 m .3915 .92491 L .3962 .92494 L F
.40809 .91669 m .40173 .91138 L .39404 .90818 L 0 1 .488 r
F
.40973 .91605 m .40793 .91693 L .40758 .91747 L 0 1 .409 r
F
.40812 .91671 m .4016 .91871 L .39377 .92251 L F
.40973 .91605 m .41251 .9188 L .41439 .9161 L F
.41584 .91141 m .41227 .9114 L .4097 .91767 L 0 1 .48 r
F
.41227 .9114 m .40173 .91138 L .40826 .91653 L F
.40973 .91605 m .40826 .91653 L .40813 .9167 L 0 1 .409 r
F
.41227 .9114 m .40826 .91653 L .4097 .91767 L 0 1 .48 r
F
.40813 .9167 m .40826 .91653 L .40812 .91671 L 0 1 .409 r
F
.40812 .91671 m .40823 .91651 L .40809 .91669 L 0 1 .488 r
F
.40826 .91653 m .40823 .91651 L .40812 .91671 L F
.40823 .91651 m .40173 .91138 L .40809 .91669 L F
.40826 .91653 m .4016 .91871 L .40812 .91671 L 0 1 .409 r
F
.4097 .91767 m .40826 .91653 L .40812 .91671 L 0 1 .488 r
F
.40793 .91693 m .40791 .91694 L .40781 .91709 L 0 1 .409 r
F
.40793 .91693 m .40781 .91709 L .40758 .91747 L F
.40791 .91694 m .3915 .92491 L .40758 .91747 L F
.40758 .91747 m .40443 .92246 L .40462 .92261 L 0 1 .488 r
F
.40462 .92262 m .40462 .92261 L .40461 .92262 L 0 1 .436 r
F
.40473 .92258 m .40462 .92261 L .40462 .92262 L F
.40462 .92261 m .40462 .92261 L .40462 .92262 L F
.40473 .92258 m .40461 .92262 L .4046 .92264 L F
.40516 .9219 m .40462 .92261 L .40473 .92269 L 0 1 .488 r
F
.40758 .91747 m .40462 .92261 L .40516 .9219 L F
.40758 .91747 m .3962 .92494 L .40462 .92261 L 0 1 .409 r
F
.40461 .92262 m .3962 .92494 L .38809 .92852 L 0 1 .436 r
F
.40462 .92261 m .3962 .92494 L .40461 .92262 L F
.4046 .92264 m .38809 .92852 L .38582 .93093 L F
.40461 .92262 m .38809 .92852 L .4046 .92264 L F
.40458 .92267 m .40457 .92267 L .40437 .92302 L 0 1 .494 r
F
.40457 .92267 m .40432 .92302 L .40437 .92302 L F
.40458 .92267 m .40437 .92302 L .40439 .92303 L F
.40458 .92267 m .38582 .93093 L .39082 .93117 L 0 1 .436 r
F
.4046 .92264 m .38582 .93093 L .40458 .92267 L F
.40458 .92267 m .39082 .93117 L .40439 .92303 L F
.40473 .92269 m .40458 .92267 L .40439 .92303 L 0 1 .494 r
F
.49652 .94309 m .47957 .95321 L .48622 .95409 L 0 1 .5 r
F
0 g
.47863 .95797 m
.48622 .95409 L
s
.77779 .79425 m .78941 .79163 L .78547 .78946 L 0 1 .491 r
F
.76811 .7886 m .77779 .79425 L .77954 .78616 L 0 1 .487 r
F
.76679 .56512 m .77416 .57655 L .77797 .57944 L 0 .063 .172 r
F
0 g
.77416 .57655 m
.77652 .58362 L
s
.49153 1.05278 m .47978 1.05065 L .47052 1.05074 L 0 1 .536 r
F
.42635 .93762 m .43037 .94535 L .43183 .94344 L 0 1 .498 r
F
.44885 .95152 m .43183 .94344 L .43037 .94535 L 0 1 .5 r
F
0 g
.43037 .94535 m
.43641 .95073 L
s
.42239 .94245 m
.43037 .94535 L
s
.36519 .8236 m .36331 .8298 L .36697 .82698 L 0 1 .528 r
F
.36519 .8236 m .35574 .83048 L .36331 .8298 L F
0 g
.36331 .8298 m
.36586 .83309 L
s
.38772 .82137 m .37182 .82321 L .37469 .82584 L 0 1 .526 r
F
.38772 .82137 m .37462 .82102 L .37182 .82321 L F
.38772 .82137 m .38144 .82023 L .37462 .82102 L F
.39415 .81548 m .38144 .82023 L .38772 .82137 L 0 1 .523 r
F
0 g
.38772 .82137 m
.39427 .82042 L
s
.38772 .82137 m
.39056 .824 L
s
.38276 .91823 m
.39101 .92142 L
s
.42114 .86547 m .40494 .86355 L .40897 .86777 L 0 1 .518 r
F
0 g
.50315 .94398 m
.5101 .93841 L
s
.51881 .92087 m .50347 .93775 L .5101 .93841 L 0 1 .457 r
F
.55044 1.0639 m .53027 1.06362 L .53959 1.06685 L 0 1 .525 r
F
0 g
.53064 1.06687 m
.53959 1.06685 L
s
.28054 .87902 m .26082 .86681 L .26419 .87457 L 0 1 .498 r
F
.28054 .87902 m .26436 .8652 L .26082 .86681 L F
.28054 .87902 m .27282 .87044 L .26436 .8652 L F
.2889 .87473 m .27282 .87044 L .28054 .87902 L 0 1 .495 r
F
0 g
.28054 .87902 m
.28876 .88413 L
s
.28054 .87902 m
.28388 .88675 L
s
.44788 .79206 m
.45337 .78936 L
s
.46286 .78034 m .45062 .78738 L .45337 .78935 L 0 1 .497 r
F
.51227 .5667 m .51184 .5095 L .51102 .52862 L 0 .912 .274 r
F
0 g
.51055 .49738 m
.51184 .5095 L
s
.52099 1.05813 m .50918 1.05599 L .5002 1.0561 L 0 1 .532 r
F
0 g
.36697 .82698 m
.37469 .82584 L
s
.43354 1.04095 m .41119 1.03963 L .41891 1.04338 L 0 1 .539 r
F
0 g
.40901 1.04273 m
.41891 1.04338 L
s
.32296 .96264 m .30617 .96705 L .3162 .96765 L 0 1 .481 r
F
0 g
.3162 .96765 m
.32565 .96654 L
s
.49769 .50766 m .49607 .4765 L .49384 .48478 L 0 1 .273 r
F
0 g
.49607 .4765 m
.49866 .47811 L
s
.49607 .4765 m
.49681 .46528 L
s
.44885 .95152 m .45385 .95865 L .45489 .9569 L 0 1 .5 r
F
0 g
.45385 .95865 m
.45672 .96077 L
s
.44593 .956 m
.45385 .95865 L
s
.52099 1.05813 m .53027 1.06362 L .53003 1.0614 L 0 1 .532 r
F
.55044 1.0639 m .53003 1.0614 L .53027 1.06362 L 0 1 .525 r
F
0 g
.53027 1.06362 m
.53959 1.06685 L
s
.52127 1.06373 m
.53027 1.06362 L
s
.44329 .8674 m .44618 .87381 L .44756 .87144 L 0 1 .516 r
F
.46144 .8746 m .44756 .87144 L .44618 .87381 L 0 1 .517 r
F
0 g
.44618 .87381 m
.45094 .87767 L
s
.43954 .8733 m
.44618 .87381 L
s
.30637 .84491 m .28789 .84233 L .2907 .84622 L 0 1 .536 r
F
.30637 .84491 m .29145 .84058 L .28789 .84233 L F
.30637 .84491 m .29938 .84169 L .29145 .84058 L F
.31477 .8401 m .29938 .84169 L .30637 .84491 L 0 1 .535 r
F
0 g
.30637 .84491 m
.31404 .84582 L
s
.30637 .84491 m
.30914 .84879 L
s
.5333 .63642 m
.53384 .63557 L
s
.52335 .69852 m .51793 .70848 L .51819 .71311 L 0 1 .386 r
F
.52335 .69852 m .52014 .70222 L .51793 .70848 L F
.52191 .68763 m .52335 .69852 L .52522 .69248 L 0 1 .364 r
F
.52191 .68763 m .52014 .70222 L .52335 .69852 L F
0 g
.52335 .69852 m
.5263 .69929 L
s
.49769 .50766 m .49947 .50118 L .49989 .48852 L 0 1 .273 r
F
0 g
.49989 .48852 m
.50218 .49138 L
s
.52547 .68267 m .52451 .68813 L .52523 .69248 L 0 1 .36 r
F
0 g
.52523 .69248 m
.52651 .69479 L
s
.52191 .68763 m .52522 .69248 L .52451 .68813 L 0 1 .364 r
F
0 g
.52335 .69852 m
.52522 .69248 L
s
.50451 .89464 m
.50747 .89685 L
s
.53151 .52924 m .53743 .44097 L .53437 .45813 L 0 1 .229 r
F
.53151 .52924 m .53866 .45311 L .53743 .44097 L F
0 g
.53743 .44097 m
.53762 .43929 L
s
.53204 .52523 m
.53218 .52206 L
s
.53194 .52765 m
.53204 .52523 L
s
.39974 .9291 m .38016 .93693 L .38546 .93738 L 0 1 .457 r
F
.39974 .9291 m .38242 .93453 L .38016 .93693 L F
.39974 .9291 m .39082 .93117 L .38242 .93453 L F
0 g
.39974 .9291 m
.40145 .92834 L
s
.39974 .9291 m
.40106 .92921 L
s
.40145 .92834 m
.40147 .92835 L
s
.51531 .70743 m .51819 .71311 L .51793 .70848 L 0 1 .395 r
F
.51531 .70743 m .51561 .71891 L .51819 .71311 L F
0 g
.51819 .71311 m
.52113 .71387 L
s
.52942 .6494 m .53377 .6494 L .53204 .64769 L 0 1 .285 r
F
0 g
.53344 .65411 m
.53377 .6494 L
s
.53377 .6494 m
.53457 .64869 L
s
.51561 .71891 m .50899 .72781 L .50879 .73239 L 0 1 .414 r
F
.51561 .71891 m .51192 .72203 L .50899 .72781 L F
.51531 .70743 m .51192 .72203 L .51561 .71891 L 0 1 .395 r
F
0 g
.51561 .71891 m
.51858 .72016 L
s
.51561 .71891 m
.51819 .71311 L
s
.51695 .56343 m .51732 .51658 L .51671 .54324 L 0 .876 .268 r
F
.51462 .56432 m .51671 .54324 L .51732 .51658 L 0 .893 .271 r
F
0 g
.51732 .51658 m
.5188 .49529 L
s
.51673 .49878 m
.51732 .51658 L
s
.50217 .98266 m
.50312 .98282 L
s
.50312 .98282 m
.50354 .98289 L
s
.50354 .98289 m
.50979 .98394 L
s
.50638 .72637 m .50879 .73239 L .50899 .72781 L 0 1 .424 r
F
.50638 .72637 m .50554 .73769 L .50879 .73239 L F
0 g
.50879 .73239 m
.51176 .73364 L
s
.32319 .83525 m .32223 .84083 L .32551 .83882 L 0 1 .534 r
F
0 g
.32551 .83882 m
.33331 .83908 L
s
.32319 .83525 m .31477 .8401 L .32223 .84083 L 0 1 .534 r
F
0 g
.32223 .84083 m
.32536 .84426 L
s
.50554 .73769 m .4978 .7453 L .49714 .74966 L 0 1 .44 r
F
.50554 .73769 m .5014 .74017 L .4978 .7453 L F
.50638 .72637 m .5014 .74017 L .50554 .73769 L 0 1 .424 r
F
0 g
.50554 .73769 m
.5085 .73928 L
s
.50554 .73769 m
.50879 .73239 L
s
.49522 .74359 m .49714 .74966 L .4978 .7453 L 0 1 .449 r
F
.49522 .74359 m .49325 .75432 L .49714 .74966 L F
0 g
.49714 .74966 m
.5001 .75124 L
s
.52675 .68499 m
.52675 .68499 L
s
.52792 .66524 m .52546 .67896 L .52814 .67845 L 0 1 .328 r
F
0 g
.52675 .68499 m
.52814 .67845 L
s
.44582 .96662 m .42643 .97203 L .43286 .97373 L 0 1 .528 r
F
0 g
.42423 .97585 m
.43286 .97373 L
s
.49325 .75432 m .48448 .7606 L .48338 .76464 L 0 1 .463 r
F
.49325 .75432 m .48871 .75618 L .48448 .7606 L F
.49522 .74359 m .48871 .75618 L .49325 .75432 L 0 1 .449 r
F
0 g
.49325 .75432 m
.49616 .75614 L
s
.49325 .75432 m
.49714 .74966 L
s
.66812 .47713 m .67998 .47438 L .67876 .50613 L 0 .72 .183 r
F
0 g
.67753 .43754 m
.67998 .47438 L
s
.67998 .47438 m
.68417 .4606 L
s
.40473 .92269 m .40773 .93086 L .40959 .92888 L 0 1 .494 r
F
0 g
.40482 .92259 m
.40969 .92284 L
s
.42635 .93762 m .40959 .92888 L .40773 .93086 L 0 1 .498 r
F
0 g
.40773 .93086 m
.41322 .93668 L
s
.40147 .92835 m
.40773 .93086 L
s
.44329 .8674 m .4278 .86622 L .43208 .87026 L 0 1 .516 r
F
0 g
.42516 .8697 m
.43208 .87026 L
s
.48197 .75871 m .48338 .76464 L .48448 .7606 L 0 1 .471 r
F
.48197 .75871 m .4789 .76863 L .48338 .76464 L F
0 g
.48338 .76464 m
.4863 .76645 L
s
.49564 .97609 m .48493 .97478 L .49486 .97881 L 0 .866 .466 r
F
.49564 .97609 m .47795 .97067 L .48493 .97478 L F
0 g
.47703 .97289 m
.48493 .97478 L
s
.48009 .88151 m .47257 .87877 L .46619 .87847 L 0 1 .517 r
F
.4789 .76863 m .46926 .77355 L .46779 .77709 L 0 1 .482 r
F
.4789 .76863 m .47403 .76992 L .46926 .77355 L F
0 g
.4789 .76863 m
.48177 .77048 L
s
.48197 .75871 m .47403 .76992 L .4789 .76863 L 0 1 .471 r
F
0 g
.4789 .76863 m
.48338 .76464 L
s
.37185 .93966 m .37451 .94292 L .37677 .94053 L 0 1 .447 r
F
0 g
.37677 .94053 m
.38546 .93738 L
s
.37185 .93966 m .36594 .94543 L .37451 .94292 L 0 1 .447 r
F
0 g
.37451 .94292 m
.38012 .94356 L
s
.49114 .43296 m .49697 .41335 L .49617 .41411 L 0 .845 .107 r
F
.49114 .43296 m .49482 .42142 L .49697 .41335 L F
0 g
.49697 .41335 m
.50037 .40304 L
s
.49482 .42142 m
.49616 .41841 L
s
.49482 .42142 m
.49697 .41335 L
s
.76811 .7886 m .77954 .78616 L .77559 .78392 L 0 1 .487 r
F
0 g
.76811 .7886 m
.7695 .78134 L
s
.32974 .95761 m .33215 .96133 L .33475 .95924 L 0 1 .469 r
F
0 g
.33475 .95924 m
.3442 .95733 L
s
.32974 .95761 m .32296 .96264 L .33215 .96133 L 0 1 .469 r
F
0 g
.33215 .96133 m
.33797 .96274 L
s
.35344 .98563 m .35695 .99076 L .35919 .98867 L 0 1 .537 r
F
.35344 .98563 m .34756 .9907 L .35695 .99076 L F
0 g
.35695 .99076 m
.36345 .99352 L
s
.52942 .6494 m .52864 .66042 L .53126 .6587 L 0 1 .285 r
F
0 g
.5306 .66474 m
.53126 .6587 L
s
.49384 .48478 m .49264 .46067 L .48996 .47022 L 0 1 .256 r
F
0 g
.49264 .46067 m
.49372 .45085 L
s
.49264 .46067 m
.49558 .45857 L
s
.77901 .82286 m .77428 .83663 L .7821 .83532 L 0 1 .493 r
F
.77901 .82286 m .77054 .83351 L .77428 .83663 L F
0 g
.77128 .84287 m
.77428 .83663 L
s
.53378 .41905 m .53536 .41226 L .53429 .41544 L 0 .95 .106 r
F
.52833 .45741 m .53429 .41544 L .53021 .43437 L F
.53021 .43437 m .53815 .39855 L .53873 .39658 L 0 0 0 r
F
.53833 .39882 m .53873 .39658 L .53924 .39483 L F
.53021 .43437 m .53873 .39658 L .53833 .39882 L F
.52833 .45741 m .53653 .40878 L .53536 .41226 L 0 .95 .106 r
F
.52833 .45741 m .53547 .41872 L .53653 .40878 L F
.53543 .41513 m .54201 .39271 L .5391 .40536 L 0 0 .046 r
F
.53043 .43341 m .53924 .39483 L .53667 .40566 L 0 0 0 r
F
.53057 .43277 m .53924 .39483 L .53043 .43341 L F
.52833 .45741 m .53536 .41226 L .53378 .41905 L 0 .95 .106 r
F
.53021 .43437 m .53429 .41544 L .53815 .39855 L 0 0 0 r
F
.53021 .43437 m .53667 .40566 L .53213 .42392 L F
.53213 .42392 m .5361 .41139 L .53543 .41513 L 0 0 .046 r
F
.5361 .41139 m .54201 .39271 L .53543 .41513 L F
.53021 .43437 m .53057 .43277 L .53043 .43341 L 0 0 0 r
F
0 g
.53536 .41226 m
.53653 .40878 L
s
.53505 .41319 m
.53536 .41226 L
s
.53548 .42554 m
.53592 .42163 L
s
.53592 .42163 m
.53717 .41049 L
s
.53653 .40878 m
.53714 .40467 L
s
.53714 .40467 m
.53741 .40283 L
s
.53922 .3906 m
.54026 .3836 L
s
.53855 .39517 m
.53922 .3906 L
s
.53786 .39981 m
.53855 .39517 L
s
.46683 .77164 m .46779 .77709 L .46926 .77355 L 0 1 .488 r
F
.46683 .77164 m .46286 .78034 L .46779 .77709 L F
0 g
.46779 .77709 m
.47067 .77894 L
s
.70102 .97075 m .70762 .97375 L .71337 .96948 L 0 1 .536 r
F
.34759 .85382 m .34743 .86104 L .3504 .85896 L 0 1 .521 r
F
.34759 .85382 m .33993 .8589 L .34743 .86104 L F
0 g
.34743 .86104 m
.35099 .86599 L
s
.75513 .55052 m .76637 .56626 L .76679 .56512 L 0 0 .153 r
F
0 g
.76637 .56626 m
.76953 .57115 L
s
.76258 .56253 m
.76637 .56626 L
s
.42664 .79759 m .42687 .80249 L .42902 .79974 L 0 1 .512 r
F
.42664 .79759 m .42101 .80432 L .42687 .80249 L F
0 g
.42687 .80249 m
.42979 .80455 L
s
.51965 .9035 m
.52266 .90539 L
s
.52266 .90539 m
.52478 .90672 L
s
.52478 .90672 m
.52533 .90707 L
s
.52551 .90718 m
.52569 .90729 L
s
.48996 .47022 m .49247 .44727 L .48919 .45225 L 0 1 .224 r
F
0 g
.49247 .44727 m
.49395 .43609 L
s
.26213 .85309 m .26105 .86101 L .26459 .85935 L 0 1 .526 r
F
0 g
.26459 .85935 m
.27311 .86279 L
s
.26213 .85309 m .25308 .85709 L .26105 .86101 L 0 1 .526 r
F
0 g
.26105 .86101 m
.26362 .86553 L
s
.52114 .36142 m .51758 .38137 L .51742 .37556 L 0 .097 .104 r
F
0 g
.52113 .36142 m
.52114 .36142 L
s
.52114 .36142 m .52188 .37752 L .51758 .38137 L 0 .097 .104 r
F
.52114 .36142 m .52746 .36658 L .52188 .37752 L F
.52114 .36142 m .53114 .35247 L .52746 .36658 L F
0 g
.52114 .36142 m
.52114 .36142 L
s
.46229 1.04725 m .45071 1.04486 L .44124 1.04469 L 0 1 .538 r
F
.35809 .89463 m .35924 .90342 L .36186 .90145 L 0 1 .489 r
F
.35809 .89463 m .35129 .89949 L .35924 .90342 L F
.37826 .91171 m .36186 .90145 L .35924 .90342 L 0 1 .493 r
F
0 g
.35924 .90342 m
.36375 .90994 L
s
.49232 1.04686 m .47978 1.05065 L .49153 1.05278 L 0 1 .535 r
F
.49232 1.04686 m .47144 1.04732 L .47978 1.05065 L F
0 g
.47052 1.05074 m
.47978 1.05065 L
s
.38911 .97836 m .39311 .98316 L .39498 .98086 L 0 1 .535 r
F
.38911 .97836 m .38416 .98398 L .39311 .98316 L F
0 g
.39311 .98316 m
.39962 .98539 L
s
.77901 .82286 m .77256 .82761 L .77054 .83351 L 0 1 .493 r
F
0 g
.76215 .835 m
.77054 .83351 L
s
.49232 1.04686 m .49153 1.05278 L .50048 1.05259 L 0 1 .535 r
F
0 g
.49153 1.05278 m
.5002 1.0561 L
s
.35574 .83048 m .33866 .83069 L .34129 .83384 L 0 1 .53 r
F
.35574 .83048 m .34196 .82863 L .33866 .83069 L F
.35574 .83048 m .34928 .82854 L .34196 .82863 L F
0 g
.35574 .83048 m
.35834 .83363 L
s
.36519 .8236 m .34929 .82854 L .35574 .83048 L 0 1 .528 r
F
0 g
.35574 .83048 m
.36331 .8298 L
s
.38416 .98398 m .36255 .98553 L .36875 .98816 L 0 1 .536 r
F
0 g
.35919 .98867 m
.36875 .98816 L
s
.35129 .89949 m .33505 .88829 L .33209 .89018 L 0 1 .493 r
F
.35129 .89949 m .34328 .89229 L .33505 .88829 L F
.35809 .89463 m .34328 .89229 L .35129 .89949 L 0 1 .489 r
F
0 g
.35129 .89949 m
.35924 .90342 L
s
.35129 .89949 m
.35532 .90636 L
s
.52191 .68763 m .51754 .70174 L .52014 .70222 L 0 1 .364 r
F
0 g
.51793 .70848 m
.52014 .70222 L
s
.40061 .80948 m .40047 .81436 L .40295 .81191 L 0 1 .52 r
F
.40061 .80948 m .39415 .81548 L .40047 .81436 L F
0 g
.40047 .81436 m
.40341 .81668 L
s
.53634 .40646 m
.53815 .39855 L
s
.53486 .41294 m
.53634 .40646 L
s
.53483 .41306 m
.53486 .41294 L
s
.53924 .39483 m
.54332 .37528 L
s
.53869 .39469 m
.53885 .39357 L
s
.53815 .39855 m
.53869 .39469 L
s
.27135 .84488 m .27014 .85096 L .27368 .84924 L 0 1 .538 r
F
0 g
.27368 .84924 m
.27443 .84937 L
s
.27135 .84488 m .26229 .84898 L .27014 .85096 L 0 1 .538 r
F
0 g
.27014 .85096 m
.27341 .85517 L
s
.46286 .78034 m .45249 .78415 L .45062 .78738 L 0 1 .497 r
F
.46286 .78034 m .45774 .78113 L .45249 .78415 L F
.46683 .77164 m .45774 .78113 L .46286 .78034 L 0 1 .488 r
F
0 g
.46286 .78034 m
.46559 .78232 L
s
.46286 .78034 m
.46779 .77709 L
s
.52547 .68267 m .52461 .68392 L .52451 .68813 L 0 1 .36 r
F
0 g
.52451 .68813 m
.52451 .68812 L
s
.78801 .59578 m .79725 .60014 L .79264 .59583 L 0 .362 .354 r
F
.78801 .59578 m .79947 .60671 L .79725 .60014 L F
.29727 .87042 m .2969 .87974 L .30016 .87797 L 0 1 .492 r
F
.29727 .87042 m .2889 .87473 L .2969 .87974 L F
0 g
.2969 .87974 m
.30068 .88704 L
s
.52088 .91869 m
.52164 .91788 L
s
.74282 .53959 m .74721 .53832 L .75189 .54496 L 0 .344 0 r
F
.74282 .53959 m .74332 .53601 L .74721 .53832 L F
0 g
.74344 .53368 m
.74721 .53832 L
s
.50875 .38061 m .50465 .39764 L .50498 .39359 L 0 0 .07 r
F
.50875 .38061 m .50828 .39181 L .50465 .39764 L F
.50875 .38061 m .51345 .38002 L .50828 .39181 L F
.50875 .38061 m .51718 .36708 L .51345 .38002 L F
0 g
.51718 .36708 m
.52113 .36142 L
s
.52478 .91069 m
.52575 .90909 L
s
.5253 .90517 m
.52551 .90501 L
s
.51345 .38002 m
.51718 .36708 L
s
.49564 .97609 m .49486 .97881 L .50245 .98114 L 0 .866 .466 r
F
0 g
.49486 .97881 m
.50217 .98266 L
s
.69442 .96914 m .68171 .97831 L .69105 .97745 L 0 1 .539 r
F
0 g
.68169 .97732 m
.6838 .97681 L
s
.69442 .96914 m .67929 .9762 L .68171 .97831 L 0 1 .539 r
F
0 g
.67732 .981 m
.68171 .97831 L
s
.29763 .86002 m .27878 .85267 L .28176 .85849 L 0 1 .525 r
F
.29763 .86002 m .28233 .85099 L .27878 .85267 L F
.29763 .86002 m .29042 .85415 L .28233 .85099 L F
.30602 .85547 m .29042 .85415 L .29763 .86002 L 0 1 .524 r
F
0 g
.29763 .86002 m
.30547 .86302 L
s
.29763 .86002 m
.30057 .86582 L
s
.51531 .70743 m .50929 .72098 L .51192 .72203 L 0 1 .395 r
F
0 g
.50899 .72781 m
.51192 .72203 L
s
.37233 .8596 m .35486 .85582 L .35815 .86069 L 0 1 .52 r
F
0 g
.3504 .85896 m
.35815 .86069 L
s
.47202 .96436 m .47795 .97067 L .47857 .96921 L 0 .987 .496 r
F
.49564 .97609 m .47857 .96921 L .47795 .97067 L 0 .866 .466 r
F
0 g
.47795 .97067 m
.48493 .97478 L
s
.47016 .96821 m
.47795 .97067 L
s
.42101 .80432 m .40669 .80819 L .40936 .81042 L 0 1 .517 r
F
0 g
.40295 .81191 m
.40936 .81042 L
s
.75513 .55052 m .76359 .55995 L .75891 .55423 L 0 0 .153 r
F
.75513 .55052 m .76679 .56512 L .76359 .55995 L F
.46416 1.04155 m .46229 1.04725 L .47144 1.04732 L 0 1 .538 r
F
.46416 1.04155 m .45071 1.04486 L .46229 1.04725 L F
0 g
.46229 1.04725 m
.47052 1.05074 L
s
.50638 .72637 m .49878 .73874 L .5014 .74017 L 0 1 .424 r
F
0 g
.4978 .7453 m
.5014 .74017 L
s
.52005 .90307 m
.52427 .90384 L
s
.52343 .67336 m .52547 .68267 L .52546 .67896 L 0 1 .333 r
F
0 g
.52555 .67894 m
.52814 .67845 L
s
.52343 .67336 m .52461 .68392 L .52547 .68267 L 0 1 .333 r
F
0 g
.52547 .68267 m
.52675 .685 L
s
.44885 .95152 m .43975 .94608 L .43183 .94344 L 0 1 .5 r
F
.76919 .81483 m .76493 .8287 L .77256 .82761 L 0 1 .487 r
F
0 g
.76215 .835 m
.76493 .8287 L
s
.5049 .52894 m .50627 .52478 L .50672 .50909 L 0 1 .277 r
F
.32416 .88579 m .30506 .87532 L .30859 .88255 L 0 1 .492 r
F
.46144 .8746 m .4541 .87178 L .44756 .87144 L 0 1 .517 r
F
.44526 .79005 m .43225 .79557 L .43488 .79757 L 0 1 .506 r
F
0 g
.42902 .79974 m
.43488 .79757 L
s
.49522 .74359 m .48612 .75448 L .48871 .75618 L 0 1 .449 r
F
0 g
.48448 .7606 m
.48871 .75618 L
s
.75841 .78278 m
.76126 .78099 L
s
.75841 .78278 m
.75885 .78012 L
s
.37826 .91171 m .37002 .90501 L .36186 .90145 L 0 1 .493 r
F
.38418 .90671 m .37826 .91171 L .38613 .91523 L 0 1 .489 r
F
.38418 .90671 m .37002 .90501 L .37826 .91171 L F
0 g
.37826 .91171 m
.38276 .91823 L
s
.40363 .85688 m .40494 .86355 L .40707 .8613 L 0 1 .517 r
F
.40363 .85688 m .39805 .86241 L .40494 .86355 L F
.42114 .86547 m .40707 .8613 L .40494 .86355 L 0 1 .518 r
F
0 g
.39805 .86241 m
.40494 .86355 L
s
.40494 .86355 m
.40897 .86777 L
s
.51881 .92087 m .50371 .93321 L .50347 .93775 L 0 1 .457 r
F
.51881 .92087 m .51029 .92597 L .50371 .93321 L F
0 g
.51881 .92087 m
.5189 .92088 L
s
.51854 .91209 m .51029 .92597 L .51881 .92086 L 0 1 .45 r
F
0 g
.51881 .92086 m
.51889 .92078 L
s
.67732 .97632 m
.67791 .97628 L
s
.47396 .94895 m .47957 .95321 L .48019 .95002 L 0 1 .515 r
F
.47396 .94895 m .47207 .95666 L .47957 .95321 L F
.49652 .94309 m .48019 .95002 L .47957 .95321 L 0 1 .5 r
F
0 g
.47957 .95321 m
.48622 .95409 L
s
.53366 .63882 m .53198 .64316 L .53204 .64769 L 0 1 .284 r
F
0 g
.5333 .63642 m
.5336 .63842 L
s
.76919 .81483 m .76299 .81947 L .76118 .8254 L 0 1 .487 r
F
0 g
.761 .82543 m
.76118 .8254 L
s
.79156 .77258 m .78941 .79163 L .79641 .78665 L 0 1 .491 r
F
.79156 .77258 m .78547 .78946 L .78941 .79163 L F
0 g
.78746 .79974 m
.78941 .79163 L
s
.33179 .88114 m .33209 .89018 L .33505 .88829 L 0 1 .489 r
F
.33179 .88114 m .32416 .88579 L .33209 .89018 L F
0 g
.33209 .89018 m
.33615 .89706 L
s
.48187 .87539 m .47257 .87877 L .48009 .88151 L 0 1 .511 r
F
.48187 .87539 m .46768 .87488 L .47257 .87877 L F
0 g
.46619 .87847 m
.47257 .87877 L
s
.49652 .94309 m .48746 .94568 L .48019 .95002 L 0 1 .5 r
F
0 g
.49652 .94309 m
.50315 .94398 L
s
.49751 .93223 m .49652 .94309 L .50347 .93775 L 0 1 .491 r
F
.49751 .93223 m .48746 .94568 L .49652 .94309 L F
.50994 .57034 m .50974 .51492 L .50835 .51877 L 0 .932 .278 r
F
.50994 .57034 m .51102 .52862 L .50974 .51492 L F
0 g
.50974 .51492 m
.51055 .49738 L
s
.47207 .95666 m .46093 .9588 L .46109 .9596 L 0 1 .519 r
F
.47202 .96436 m .46268 .95935 L .46093 .9588 L 0 .987 .496 r
F
.46109 .9596 m .46093 .9588 L .45489 .9569 L F
.47202 .96436 m .46093 .9588 L .46109 .9596 L F
.47207 .95666 m .46269 .95808 L .46093 .9588 L 0 1 .519 r
F
.46109 .9596 m .46093 .9588 L .45485 .96127 L F
.47396 .94895 m .46269 .95808 L .47207 .95666 L 0 1 .515 r
F
0 g
.47207 .95666 m
.47863 .95797 L
s
.47207 .95666 m
.47957 .95321 L
s
.5207 1.05221 m .50918 1.05599 L .52099 1.05813 L 0 1 .53 r
F
.5207 1.05221 m .50048 1.05259 L .50918 1.05599 L F
0 g
.5002 1.0561 m
.50918 1.05599 L
s
.48187 .87539 m .48009 .88151 L .48617 .88173 L 0 1 .511 r
F
0 g
.48009 .88151 m
.48529 .88526 L
s
.52343 .67336 m .52344 .68204 L .52461 .68392 L 0 1 .333 r
F
0 g
.52451 .68812 m
.52461 .68392 L
s
.55044 1.0639 m .53867 1.06152 L .53003 1.0614 L 0 1 .525 r
F
.42101 .80432 m .40918 .80568 L .40669 .80819 L 0 1 .517 r
F
.42101 .80432 m .41532 .80402 L .40918 .80568 L F
.42664 .79759 m .41532 .80402 L .42101 .80432 L 0 1 .512 r
F
0 g
.42101 .80432 m
.42687 .80249 L
s
.42101 .80432 m
.42366 .80656 L
s
.67732 .97629 m
.67929 .97602 L
s
.52833 .45741 m .53196 .43953 L .53547 .41872 L 0 .95 .106 r
F
0 g
.53244 .43666 m
.53341 .43091 L
s
.53341 .43091 m
.53547 .41872 L
s
.53514 .42857 m
.53548 .42554 L
s
.53547 .41872 m
.53701 .41093 L
s
.42114 .86547 m .41401 .86213 L .40707 .8613 L 0 1 .518 r
F
.42583 .85965 m .42114 .86547 L .4278 .86622 L 0 1 .515 r
F
.42583 .85965 m .41401 .86213 L .42114 .86547 L F
0 g
.42114 .86547 m
.42516 .8697 L
s
.39805 .86242 m .38324 .85793 L .38 .86071 L 0 1 .519 r
F
.39805 .86242 m .39098 .85866 L .38324 .85793 L F
0 g
.39805 .86242 m
.40125 .86739 L
s
.40363 .85688 m .39098 .85866 L .39805 .86241 L 0 1 .517 r
F
0 g
.39805 .86241 m
.39805 .86241 L
s
.49751 .93223 m .50347 .93775 L .50371 .93321 L 0 1 .491 r
F
0 g
.49652 .94309 m
.50347 .93775 L
s
.50347 .93775 m
.5101 .93841 L
s
.44877 .95974 m .4538 .9641 L .45485 .96127 L 0 1 .525 r
F
.44877 .95974 m .44582 .96662 L .4538 .9641 L F
0 g
.4538 .9641 m
.46038 .9654 L
s
.38075 .85277 m .38 .86071 L .38324 .85793 L 0 1 .518 r
F
.38075 .85277 m .37233 .8596 L .38 .86071 L F
0 g
.38 .86071 m
.38322 .86569 L
s
.37233 .8596 m
.38 .86071 L
s
.71436 .51923 m .72065 .50657 L .72642 .51709 L 0 .601 .094 r
F
.71436 .51923 m .7155 .50746 L .72065 .50657 L F
0 g
.71668 .49454 m
.72065 .50657 L
s
.7155 .50746 m
.72065 .50657 L
s
.46926 .77355 m
.47403 .76992 L
s
.48197 .75871 m .47152 .76804 L .47403 .76992 L 0 1 .471 r
F
.33993 .8589 m .32184 .85359 L .32492 .85884 L 0 1 .523 r
F
.45023 .78212 m .45062 .78738 L .45249 .78415 L 0 1 .499 r
F
.45023 .78212 m .44527 .79005 L .45062 .78738 L F
0 g
.45062 .78738 m
.45337 .78935 L
s
.75934 .80628 m .75555 .82033 L .76299 .81947 L 0 .979 .479 r
F
.75934 .80628 m .75179 .81684 L .75555 .82033 L F
0 g
.75512 .8214 m
.75555 .82033 L
s
.46416 1.04155 m .4428 1.04141 L .45071 1.04486 L 0 1 .538 r
F
0 g
.44124 1.04469 m
.45071 1.04486 L
s
.46422 .86847 m .46144 .8746 L .46768 .87488 L 0 1 .512 r
F
.46422 .86847 m .4541 .87178 L .46144 .8746 L F
0 g
.46144 .8746 m
.46619 .87847 L
s
.49872 .40519 m .50548 .38833 L .50173 .39942 L 0 0 0 r
F
0 g
.50364 .39378 m
.50548 .38833 L
s
.50548 .38833 m
.50875 .38061 L
s
.26229 .84898 m .24604 .84845 L .25325 .85306 L 0 1 .538 r
F
0 g
.25325 .85306 m
.25882 .85456 L
s
.38418 .90671 m .38613 .91523 L .38839 .91322 L 0 1 .489 r
F
0 g
.37826 .91171 m
.38613 .91523 L
s
.38613 .91523 m
.39101 .92142 L
s
.37357 1.02956 m .37848 1.03598 L .38032 1.03403 L 0 1 .539 r
F
.37357 1.02956 m .36866 1.03434 L .37848 1.03598 L F
.40159 1.0386 m .38032 1.03403 L .37848 1.03598 L F
0 g
.37848 1.03598 m
.38592 1.04011 L
s
.41806 .97376 m .39777 .97738 L .40398 .97947 L 0 1 .533 r
F
0 g
.39498 .98086 m
.40398 .97947 L
s
.40492 .92249 m
.41251 .9188 L
s
.41251 .9188 m
.41778 .9186 L
s
.41439 .9161 m
.42217 .91162 L
s
.33993 .8589 m .32512 .85168 L .32184 .85359 L 0 1 .523 r
F
.33993 .8589 m .33288 .85396 L .32512 .85168 L F
.34759 .85382 m .33288 .85396 L .33993 .8589 L 0 1 .521 r
F
0 g
.33993 .8589 m
.34743 .86104 L
s
.33993 .8589 m
.34298 .86414 L
s
.40159 1.0386 m .39024 1.03515 L .38032 1.03403 L 0 1 .539 r
F
.40552 1.03351 m .40159 1.0386 L .41119 1.03963 L F
.40552 1.03351 m .39024 1.03515 L .40159 1.0386 L F
0 g
.40159 1.0386 m
.40901 1.04273 L
s
.42635 .93762 m .41758 .93177 L .40959 .92888 L 0 1 .498 r
F
.42583 .85965 m .4278 .86622 L .42957 .86388 L 0 1 .515 r
F
.44329 .8674 m .42957 .86388 L .4278 .86622 L 0 1 .516 r
F
0 g
.4278 .86622 m
.43208 .87026 L
s
.42114 .86547 m
.4278 .86622 L
s
.34756 .9907 m .32495 .99021 L .33103 .99339 L 0 1 .538 r
F
0 g
.49947 .88893 m
.49947 .88893 L
s
.50215 .89076 m
.50468 .89248 L
s
.50468 .89248 m
.50695 .89289 L
s
.40552 1.03351 m .41119 1.03963 L .41264 1.03756 L 0 1 .539 r
F
.43354 1.04095 m .41264 1.03756 L .41119 1.03963 L F
0 g
.41119 1.03963 m
.41891 1.04338 L
s
.40159 1.0386 m
.41119 1.03963 L
s
.38416 .98398 m .3648 .98343 L .36255 .98553 L 0 1 .536 r
F
.38416 .98398 m .37407 .98277 L .3648 .98343 L F
.38911 .97836 m .37407 .98277 L .38416 .98398 L 0 1 .535 r
F
0 g
.38416 .98398 m
.39311 .98316 L
s
.38416 .98398 m
.39032 .98661 L
s
.79156 .77258 m .78638 .78131 L .78547 .78946 L 0 1 .491 r
F
0 g
.77779 .79425 m
.78547 .78946 L
s
.75934 .80628 m .7534 .81083 L .75179 .81684 L 0 .979 .479 r
F
0 g
.75179 .81684 m
.7534 .81083 L
s
.75166 .81686 m
.75179 .81684 L
s
.52965 .64925 m
.53204 .64769 L
s
.53198 .64316 m
.53204 .64769 L
s
.31443 .85089 m .31364 .85832 L .31692 .85643 L 0 1 .523 r
F
0 g
.31692 .85643 m
.32492 .85884 L
s
.31443 .85089 m .30602 .85547 L .31364 .85832 L 0 1 .523 r
F
0 g
.31364 .85832 m
.31697 .86368 L
s
.79947 .60671 m .80918 .62131 L .81092 .61661 L 0 .415 .376 r
F
0 g
.80918 .62131 m
.81126 .62768 L
s
.80449 .62172 m
.80918 .62131 L
s
.34756 .9907 m .32755 .98832 L .32495 .99021 L 0 1 .538 r
F
.34756 .9907 m .33726 .98853 L .32755 .98832 L F
.35344 .98563 m .33726 .98853 L .34756 .9907 L 0 1 .537 r
F
0 g
.34756 .9907 m
.3536 .99388 L
s
.34756 .9907 m
.35695 .99076 L
s
.52792 .66524 m .52461 .67525 L .52546 .67896 L 0 1 .328 r
F
0 g
.52546 .67896 m
.52555 .67894 L
s
.52343 .67336 m .52546 .67896 L .52461 .67526 L 0 1 .333 r
F
0 g
.52546 .67896 m
.52547 .68267 L
s
.44582 .96662 m .4279 .96948 L .42643 .97203 L 0 1 .528 r
F
.44582 .96662 m .43622 .96716 L .4279 .96948 L F
.44877 .95974 m .43622 .96716 L .44582 .96662 L 0 1 .525 r
F
0 g
.44582 .96662 m
.45222 .96832 L
s
.44582 .96662 m
.4538 .9641 L
s
.75079 .81106 m
.7534 .81083 L
s
.5381 .50488 m .53866 .45311 L .53725 .48662 L 0 1 .222 r
F
.53151 .52924 m .53725 .48662 L .53866 .45311 L 0 1 .229 r
F
0 g
.53743 .44097 m
.53866 .45311 L
s
.53866 .45311 m
.54081 .42636 L
s
.53488 .53579 m
.5356 .52303 L
s
.37233 .8596 m .35784 .85372 L .35486 .85582 L 0 1 .52 r
F
.37233 .8596 m .36533 .85534 L .35784 .85372 L F
0 g
.37233 .8596 m
.3756 .86446 L
s
.38075 .85277 m .36533 .85534 L .37233 .8596 L 0 1 .518 r
F
0 g
.37233 .8596 m
.37233 .8596 L
s
.49984 .88249 m .48617 .88173 L .49146 .88575 L 0 1 .507 r
F
0 g
.48529 .88526 m
.49146 .88575 L
s
.32416 .88579 m .30833 .87354 L .30506 .87532 L 0 1 .492 r
F
.32416 .88579 m .31652 .87804 L .30833 .87354 L F
0 g
.30016 .87797 m
.30859 .88255 L
s
.33179 .88114 m .31652 .87804 L .32416 .88579 L 0 1 .489 r
F
0 g
.32416 .88579 m
.32766 .893 L
s
.32416 .88579 m
.33209 .89018 L
s
.46416 1.04155 m .47144 1.04732 L .47206 1.045 L 0 1 .538 r
F
.49232 1.04686 m .47206 1.045 L .47144 1.04732 L 0 1 .535 r
F
0 g
.47144 1.04732 m
.47978 1.05065 L
s
.46229 1.04725 m
.47144 1.04732 L
s
.46422 .86847 m .44964 .86783 L .4541 .87178 L 0 1 .512 r
F
0 g
.44756 .87144 m
.4541 .87178 L
s
.51462 .56432 m .51418 .52183 L .51403 .54629 L 0 .893 .271 r
F
.51227 .5667 m .51403 .54629 L .51418 .52183 L 0 .912 .274 r
F
0 g
.51324 .50611 m
.51418 .52183 L
s
.51418 .52183 m
.51526 .50281 L
s
.2889 .87473 m .26968 .86277 L .27282 .87044 L 0 1 .495 r
F
.2889 .87473 m .27323 .86115 L .26968 .86277 L F
.2889 .87473 m .28147 .86628 L .27323 .86115 L F
.29727 .87042 m .28147 .86628 L .2889 .87473 L 0 1 .492 r
F
0 g
.2889 .87473 m
.2969 .87974 L
s
.2889 .87473 m
.29201 .88237 L
s
.39415 .81548 m .37882 .8177 L .38144 .82023 L 0 1 .523 r
F
.39415 .81548 m .38163 .81547 L .37882 .8177 L F
.39415 .81548 m .3882 .81452 L .38163 .81547 L F
.40061 .80948 m .3882 .81452 L .39415 .81548 L 0 1 .52 r
F
0 g
.39415 .81548 m
.40047 .81436 L
s
.39415 .81548 m
.39675 .81801 L
s
.52406 .91085 m
.52478 .91069 L
s
.37357 1.02956 m .3574 1.03021 L .36866 1.03434 L 0 1 .539 r
F
0 g
.36866 1.03434 m
.37848 1.03598 L
s
.77842 .57787 m .78109 .5842 L .78571 .589 L 0 .142 .189 r
F
.77842 .57787 m .77797 .57944 L .78109 .5842 L F
0 g
.77652 .58362 m
.78109 .5842 L
s
.31477 .8401 m .2968 .83795 L .29938 .84169 L 0 1 .535 r
F
.31477 .8401 m .30037 .8362 L .2968 .83795 L F
.31477 .8401 m .30808 .83712 L .30037 .8362 L F
.32319 .83525 m .30808 .83712 L .31477 .8401 L 0 1 .534 r
F
0 g
.31477 .8401 m
.32223 .84083 L
s
.31477 .8401 m
.31731 .84383 L
s
.44526 .79005 m .4344 .79275 L .43225 .79557 L 0 1 .506 r
F
.44526 .79005 m .43998 .79038 L .4344 .79275 L F
0 g
.44526 .79005 m
.44788 .79206 L
s
.45023 .78212 m .43998 .79038 L .44527 .79005 L 0 1 .499 r
F
0 g
.44527 .79005 m
.45062 .78738 L
s
.5357 .34968 m .53274 .37211 L .5321 .36427 L 0 .237 .13 r
F
.5357 .34968 m .53768 .37134 L .53274 .37211 L F
.5357 .34968 m .5436 .36247 L .53768 .37134 L F
.5357 .34968 m .54716 .34786 L .5436 .36247 L F
0 g
.53114 .35247 m
.5357 .34968 L
s
.50153 .53971 m .49947 .50118 L .49769 .50766 L 0 1 .281 r
F
.50153 .53971 m .50172 .50703 L .49947 .50118 L F
0 g
.49947 .50118 m
.49989 .48852 L
s
.49232 1.04686 m .50048 1.05259 L .50066 1.05019 L 0 1 .535 r
F
.5207 1.05221 m .50066 1.05019 L .50048 1.05259 L 0 1 .53 r
F
0 g
.50048 1.05259 m
.50918 1.05599 L
s
.49153 1.05278 m
.50048 1.05259 L
s
.75163 .77492 m
.75408 .77337 L
s
.52792 .66524 m .52566 .66937 L .52461 .67525 L 0 1 .328 r
F
.52499 .65912 m .52792 .66524 L .52864 .66042 L 0 1 .284 r
F
.52499 .65912 m .52566 .66937 L .52792 .66524 L F
0 g
.52792 .66524 m
.5306 .66474 L
s
.5207 1.05221 m .52099 1.05813 L .52967 1.05797 L 0 1 .53 r
F
0 g
.52099 1.05813 m
.53003 1.0614 L
s
.78131 .76715 m .77954 .78616 L .78638 .78131 L 0 1 .487 r
F
.78131 .76715 m .77559 .78392 L .77954 .78616 L F
0 g
.77779 .79425 m
.77954 .78616 L
s
.36594 .94543 m .34521 .95084 L .35045 .95189 L 0 1 .465 r
F
.36594 .94543 m .34783 .94873 L .34521 .95084 L F
.36594 .94543 m .35673 .94641 L .34783 .94873 L F
.37185 .93966 m .35673 .94641 L .36594 .94543 L 0 1 .447 r
F
0 g
.36594 .94543 m
.37451 .94292 L
s
.36594 .94543 m
.37113 .94649 L
s
.52284 .98773 m
.52291 .98775 L
s
.49384 .48478 m .48921 .48147 L .4909 .48692 L 0 1 .256 r
F
.49384 .48478 m .48996 .47022 L .48921 .48147 L F
.49769 .50766 m .49384 .48478 L .49342 .49745 L 0 1 .273 r
F
0 g
.50301 .98136 m
.50979 .98394 L
s
.69442 .96914 m .68473 .97227 L .67929 .9762 L 0 1 .539 r
F
0 g
.67929 .9762 m
.68473 .97227 L
s
.68183 .97414 m
.68432 .9723 L
s
.67929 .97602 m
.68183 .97414 L
s
.67791 .97628 m
.67929 .9762 L
s
.38418 .90671 m .3658 .89849 L .37002 .90501 L 0 1 .489 r
F
0 g
.36186 .90145 m
.37002 .90501 L
s
.35809 .89463 m .33949 .88545 L .34328 .89229 L 0 1 .489 r
F
0 g
.33505 .88829 m
.34328 .89229 L
s
.69442 .96914 m .69105 .97745 L .70112 .97419 L 0 1 .539 r
F
0 g
.68171 .97831 m
.69105 .97745 L
s
.68534 .98144 m
.69105 .97745 L
s
.33163 .83035 m .33043 .83579 L .33372 .83376 L 0 1 .532 r
F
0 g
.33372 .83376 m
.34129 .83384 L
s
.33163 .83035 m .32319 .83525 L .33043 .83579 L 0 1 .532 r
F
0 g
.33043 .83579 m
.33331 .83908 L
s
.54005 .92409 m
.54005 .92409 L
s
.52943 .64648 m
.53198 .64316 L
s
.70112 .97419 m .70779 .97913 L .71355 .97513 L 0 1 .54 r
F
.49872 .40519 m .49414 .41853 L .49496 .41633 L 0 0 0 r
F
.49872 .40519 m .49705 .41127 L .49414 .41853 L F
.49872 .40519 m .50173 .39942 L .49705 .41127 L F
.55231 .34951 m .55802 .3411 L .56345 .3441 L 0 .362 .147 r
F
.46683 .77164 m .4553 .77923 L .45774 .78113 L 0 1 .488 r
F
0 g
.45249 .78415 m
.45774 .78113 L
s
.37241 .81827 m .37182 .82321 L .37462 .82102 L 0 1 .525 r
F
0 g
.37462 .82102 m
.38144 .82023 L
s
.37241 .81827 m .36519 .8236 L .37182 .82321 L 0 1 .525 r
F
0 g
.37182 .82321 m
.37469 .82584 L
s
.46422 .86847 m .46768 .87488 L .46867 .87242 L 0 1 .512 r
F
.48187 .87539 m .46867 .87242 L .46768 .87488 L 0 1 .511 r
F
0 g
.46768 .87488 m
.47257 .87877 L
s
.46144 .8746 m
.46768 .87488 L
s
.5469 .49418 m
.54695 .50291 L
s
.54677 .47584 m
.54686 .48947 L
s
.54686 .48947 m
.5469 .49418 L
s
.4998 .88871 m
.4998 .88871 L
s
.5042 .88895 m
.50495 .88899 L
s
.42204 .96754 m .42643 .97203 L .4279 .96948 L 0 1 .531 r
F
.42204 .96754 m .41806 .97376 L .42643 .97203 L F
0 g
.42643 .97203 m
.43286 .97373 L
s
.51531 .70743 m .50949 .71647 L .50929 .72098 L 0 1 .395 r
F
.51531 .70743 m .51207 .71066 L .50949 .71647 L F
.515 .69655 m .51531 .70743 L .51754 .70174 L 0 1 .37 r
F
.515 .69655 m .51207 .71066 L .51531 .70743 L F
0 g
.51531 .70743 m
.51793 .70848 L
s
.5049 .52894 m .50172 .50703 L .50295 .52132 L 0 1 .277 r
F
.50153 .53971 m .50295 .52132 L .50172 .50703 L 0 1 .281 r
F
0 g
.49947 .50118 m
.50172 .50703 L
s
.50172 .50703 m
.50218 .49138 L
s
.515 .69655 m .51754 .70174 L .51728 .69738 L 0 1 .37 r
F
.52191 .68763 m .51728 .69738 L .51754 .70174 L 0 1 .364 r
F
0 g
.51754 .70174 m
.52014 .70222 L
s
.51531 .70743 m
.51754 .70174 L
s
.78131 .76715 m .77634 .77579 L .77559 .78392 L 0 1 .487 r
F
0 g
.76811 .7886 m
.77559 .78392 L
s
.52191 .68763 m .51915 .69133 L .51728 .69738 L 0 1 .364 r
F
.52046 .6781 m .52191 .68763 L .52344 .68204 L 0 1 .331 r
F
.52046 .6781 m .51915 .69133 L .52191 .68763 L F
0 g
.52191 .68763 m
.52451 .68813 L
s
.52191 .68763 m
.5228 .68437 L
s
.43032 .93277 m .42635 .93762 L .43403 .94058 L 0 1 .492 r
F
.43032 .93277 m .41758 .93177 L .42635 .93762 L F
0 g
.42635 .93762 m
.43183 .94344 L
s
.50722 .7152 m .50929 .72098 L .50949 .71647 L 0 1 .403 r
F
.50722 .7152 m .50638 .72637 L .50929 .72098 L F
0 g
.50929 .72098 m
.51192 .72203 L
s
.45178 .94703 m .43975 .94608 L .44885 .95152 L 0 1 .493 r
F
.45178 .94703 m .43403 .94058 L .43975 .94608 L F
0 g
.43183 .94344 m
.43975 .94608 L
s
.50638 .72637 m .49943 .73434 L .49878 .73874 L 0 1 .424 r
F
.50638 .72637 m .50269 .72904 L .49943 .73434 L F
.50722 .7152 m .50269 .72904 L .50638 .72637 L 0 1 .403 r
F
0 g
.50638 .72637 m
.50899 .72781 L
s
.50638 .72637 m
.50929 .72098 L
s
.48187 .87539 m .48617 .88173 L .48676 .87929 L 0 1 .511 r
F
.49984 .88249 m .48676 .87929 L .48617 .88173 L 0 1 .507 r
F
0 g
.48617 .88173 m
.49146 .88575 L
s
.48009 .88151 m
.48617 .88173 L
s
.42583 .85965 m .41026 .85791 L .41401 .86213 L 0 1 .515 r
F
0 g
.40707 .8613 m
.41401 .86213 L
s
.52499 .65912 m .52864 .66042 L .52733 .65811 L 0 1 .284 r
F
.52942 .6494 m .52733 .65811 L .52864 .66042 L 0 1 .285 r
F
0 g
.52864 .66042 m
.53126 .6587 L
s
.52792 .66524 m
.52864 .66042 L
s
.26196 .85721 m .26082 .86681 L .26436 .8652 L 0 1 .495 r
F
0 g
.26436 .8652 m
.27282 .87044 L
s
.26196 .85721 m .25291 .86113 L .26082 .86681 L 0 1 .495 r
F
0 g
.26082 .86681 m
.26419 .87457 L
s
.52343 .67336 m .52272 .67827 L .52344 .68204 L 0 1 .333 r
F
0 g
.52344 .68204 m
.52461 .68392 L
s
.52046 .6781 m .52344 .68204 L .52272 .67827 L 0 1 .331 r
F
0 g
.5228 .68437 m
.52344 .68204 L
s
.50994 .57034 m .50835 .51877 L .50788 .53657 L 0 .932 .278 r
F
0 g
.50672 .50909 m
.50835 .51877 L
s
.43032 .93277 m .4124 .92589 L .41758 .93177 L 0 1 .492 r
F
0 g
.40959 .92888 m
.41758 .93177 L
s
.49719 .73276 m .49878 .73874 L .49943 .73434 L 0 1 .432 r
F
.49719 .73276 m .49522 .74359 L .49878 .73874 L F
0 g
.49878 .73874 m
.5014 .74017 L
s
.48019 .95002 m
.48746 .94568 L
s
.43354 1.04095 m .42222 1.03812 L .41264 1.03756 L 0 1 .539 r
F
.43645 1.03552 m .43354 1.04095 L .4428 1.04141 L F
.43645 1.03552 m .42222 1.03812 L .43354 1.04095 L F
0 g
.43354 1.04095 m
.44124 1.04469 L
s
.44329 .8674 m .43621 .86438 L .42957 .86388 L 0 1 .516 r
F
.44706 .86131 m .44329 .8674 L .44964 .86783 L 0 1 .512 r
F
.44706 .86131 m .43621 .86438 L .44329 .8674 L F
0 g
.44329 .8674 m
.44756 .87144 L
s
.49751 .93223 m .48124 .94472 L .48746 .94568 L 0 1 .491 r
F
.45178 .94703 m .44885 .95152 L .45646 .95429 L 0 1 .493 r
F
0 g
.44885 .95152 m
.45489 .9569 L
s
.49522 .74359 m .48723 .75035 L .48612 .75448 L 0 1 .449 r
F
.49522 .74359 m .49113 .74568 L .48723 .75035 L F
.49719 .73276 m .49113 .74568 L .49522 .74359 L 0 1 .432 r
F
0 g
.49522 .74359 m
.4978 .7453 L
s
.49522 .74359 m
.49878 .73874 L
s
.32296 .96264 m .30082 .96523 L .30617 .96705 L 0 1 .481 r
F
.32296 .96264 m .30377 .96341 L .30082 .96523 L F
.32296 .96264 m .31328 .9623 L .30377 .96341 L F
.32974 .95761 m .31328 .9623 L .32296 .96264 L 0 1 .469 r
F
0 g
.32296 .96264 m
.33215 .96133 L
s
.32296 .96264 m
.32824 .96446 L
s
.54986 .6692 m .55786 .56174 L .55811 .49067 L 0 .831 .236 r
F
0 g
.55811 .49067 m
.55891 .46888 L
s
.55255 .49409 m
.55255 .49 L
s
.55255 .50851 m
.55255 .49409 L
s
.27119 .84907 m .26991 .85686 L .27345 .85519 L 0 1 .526 r
F
0 g
.27345 .85519 m
.28176 .85849 L
s
.27119 .84907 m .26213 .85309 L .26991 .85686 L 0 1 .526 r
F
0 g
.26991 .85686 m
.27242 .86151 L
s
.48506 .74855 m .48612 .75448 L .48723 .75035 L 0 1 .456 r
F
.48506 .74855 m .48197 .75871 L .48612 .75448 L F
0 g
.48612 .75448 m
.48871 .75618 L
s
.45485 .96127 m
.46057 .95894 L
s
.46057 .95894 m
.46093 .9588 L
s
.47396 .94895 m .45978 .95548 L .46269 .95808 L 0 1 .515 r
F
.45978 .95548 m .46071 .95774 L .46269 .95808 L F
.47389 .96054 m .45978 .95548 L .46268 .95935 L 0 .916 .485 r
F
.45978 .95548 m .45646 .95429 L .46038 .95748 L F
.45978 .95548 m .45751 .95254 L .45646 .95429 L F
.47396 .94895 m .45954 .95353 L .45978 .95548 L 0 1 .515 r
F
.47389 .96054 m .45954 .95353 L .45978 .95548 L 0 .916 .485 r
F
.45954 .95353 m .45751 .95254 L .45978 .95548 L F
.45954 .95353 m .45923 .95363 L .45978 .95548 L 0 1 .515 r
F
.45978 .95548 m .45749 .95418 L .45644 .95702 L F
.45923 .95363 m .45749 .95418 L .45978 .95548 L F
.45978 .95548 m .46038 .95748 L .46071 .95774 L 0 .916 .485 r
F
.45978 .95548 m .46071 .95774 L .46268 .95935 L F
.45978 .95548 m .45644 .95702 L .46071 .95774 L 0 1 .515 r
F
0 g
.4603 .95768 m
.46071 .95774 L
s
.46093 .9588 m
.46105 .95875 L
s
.46105 .95875 m
.46164 .95851 L
s
.46059 .95869 m
.46093 .9588 L
s
.45489 .9569 m
.45499 .95693 L
s
.45499 .95693 m
.46059 .95869 L
s
.49564 .97609 m .48615 .97154 L .47857 .96921 L 0 .866 .466 r
F
0 g
.41127 .91607 m
.41439 .9161 L
s
.26213 .85309 m .24597 .85018 L .25308 .85709 L 0 1 .526 r
F
0 g
.25308 .85709 m
.25737 .8592 L
s
.28043 .84074 m .279 .84666 L .28256 .84493 L 0 1 .537 r
F
0 g
.28256 .84493 m
.2907 .84622 L
s
.28043 .84074 m .27135 .84488 L .279 .84666 L 0 1 .537 r
F
0 g
.279 .84666 m
.28204 .85071 L
s
.51854 .91209 m .50402 .92739 L .51029 .92597 L 0 1 .45 r
F
0 g
.51029 .92597 m
.51029 .92597 L
s
.51029 .92597 m
.51029 .92597 L
s
.50371 .93321 m
.51029 .92597 L
s
.66812 .47713 m .67469 .52355 L .67053 .51464 L 0 .72 .183 r
F
.66812 .47713 m .67876 .50613 L .67469 .52355 L F
0 g
.66812 .47713 m
.67053 .51464 L
s
.66424 .4984 m
.66812 .47713 L
s
.40363 .85688 m .38753 .85423 L .39098 .85866 L 0 1 .517 r
F
0 g
.39098 .85866 m
.39098 .85866 L
s
.38324 .85793 m
.39098 .85866 L
s
.41806 .97376 m .39964 .97506 L .39777 .97738 L 0 1 .533 r
F
.41806 .97376 m .40835 .97351 L .39964 .97506 L F
.42204 .96754 m .40835 .97351 L .41806 .97376 L 0 1 .531 r
F
0 g
.41806 .97376 m
.42423 .97585 L
s
.41806 .97376 m
.42643 .97203 L
s
.38839 .91322 m
.39636 .91642 L
s
.48197 .75871 m .47305 .76424 L .47152 .76804 L 0 1 .471 r
F
.48197 .75871 m .47754 .76024 L .47305 .76424 L F
.48506 .74855 m .47754 .76024 L .48197 .75871 L 0 1 .456 r
F
0 g
.48197 .75871 m
.48448 .7606 L
s
.48197 .75871 m
.48612 .75448 L
s
.52461 .67525 m
.52461 .67525 L
s
.49564 .97609 m .50245 .98114 L .50263 .98021 L 0 .866 .466 r
F
0 g
.50245 .98114 m
.50301 .98136 L
s
.49486 .97881 m
.50245 .98114 L
s
.40552 1.03351 m .3831 1.03109 L .39024 1.03515 L 0 1 .539 r
F
0 g
.38032 1.03403 m
.39024 1.03515 L
s
.43645 1.03552 m .4428 1.04141 L .44384 1.0392 L 0 1 .539 r
F
.46416 1.04155 m .44384 1.0392 L .4428 1.04141 L 0 1 .538 r
F
0 g
.4428 1.04141 m
.45071 1.04486 L
s
.43354 1.04095 m
.4428 1.04141 L
s
.52233 .98749 m
.52271 .9876 L
s
.52518 .98833 m
.52522 .98834 L
s
.4097 .91767 m .40473 .92269 L .4124 .92589 L 0 1 .488 r
F
0 g
.40473 .92269 m
.40959 .92888 L
s
.52562 .90513 m
.52574 .90525 L
s
.52551 .90501 m
.52562 .90513 L
s
.44706 .86131 m .44964 .86783 L .45103 .86539 L 0 1 .512 r
F
.46422 .86847 m .45103 .86539 L .44964 .86783 L F
0 g
.44964 .86783 m
.4541 .87178 L
s
.44329 .8674 m
.44964 .86783 L
s
.52499 .65912 m .52332 .67039 L .52566 .66937 L 0 1 .284 r
F
0 g
.52461 .67525 m
.52566 .66937 L
s
.76625 .77059 m
.76629 .77006 L
s
.66622 .54236 m
.66651 .54353 L
s
.49114 .43296 m .49617 .41411 L .49246 .42315 L 0 .845 .107 r
F
0 g
.49415 .41903 m
.49617 .41411 L
s
.49617 .41411 m
.49682 .41185 L
s
.30602 .85547 m .28767 .84846 L .29042 .85415 L 0 1 .524 r
F
.30602 .85547 m .29123 .84677 L .28767 .84846 L F
.30602 .85547 m .2991 .84978 L .29123 .84677 L F
.31443 .85089 m .2991 .84978 L .30602 .85547 L 0 1 .523 r
F
0 g
.30602 .85547 m
.31364 .85832 L
s
.30602 .85547 m
.30874 .86114 L
s
.54005 .92409 m
.54012 .92413 L
s
.43228 .79067 m .43225 .79557 L .4344 .79275 L 0 1 .506 r
F
.43228 .79067 m .42664 .79759 L .43225 .79557 L F
0 g
.43225 .79557 m
.43488 .79757 L
s
.48605 .46249 m .49059 .4437 L .48932 .44253 L 0 1 .174 r
F
.48605 .46249 m .48919 .45225 L .49059 .4437 L F
0 g
.49059 .4437 m
.49395 .43609 L
s
.48956 .44995 m
.49059 .4437 L
s
.47389 .96054 m .46268 .95935 L .47202 .96436 L 0 .916 .485 r
F
0 g
.46071 .95774 m
.46268 .95935 L
s
.46093 .9588 m
.46268 .95935 L
s
.35528 .84867 m .35486 .85582 L .35784 .85372 L 0 1 .52 r
F
.35528 .84867 m .34759 .85382 L .35486 .85582 L F
0 g
.35486 .85582 m
.35815 .86069 L
s
.48996 .47022 m .48497 .47236 L .48667 .47524 L 0 1 .224 r
F
.48996 .47022 m .48605 .46249 L .48497 .47236 L F
.48996 .47022 m .48919 .45225 L .48605 .46249 L F
0 g
.48919 .45225 m
.48956 .44995 L
s
.48919 .45225 m
.49247 .44727 L
s
.47099 .76229 m .47152 .76804 L .47305 .76424 L 0 1 .476 r
F
.47099 .76229 m .46683 .77164 L .47152 .76804 L F
0 g
.47152 .76804 m
.47403 .76992 L
s
.40708 .80336 m .40669 .80819 L .40918 .80568 L 0 1 .516 r
F
.40708 .80336 m .40061 .80948 L .40669 .80819 L F
0 g
.40669 .80819 m
.40936 .81042 L
s
.44706 .86131 m .43223 .86031 L .43621 .86438 L 0 1 .512 r
F
0 g
.42957 .86388 m
.43621 .86438 L
s
.30567 .86608 m .30506 .87532 L .30833 .87354 L 0 1 .489 r
F
.30567 .86608 m .29727 .87042 L .30506 .87532 L F
0 g
.30506 .87532 m
.30859 .88255 L
s
.74282 .53959 m .75189 .54496 L .75502 .55198 L 0 .344 0 r
F
0 g
.75189 .54496 m
.75513 .55052 L
s
.55965 .54037 m
.55986 .54005 L
s
.55986 .54005 m
.56057 .53898 L
s
.56057 .53898 m
.56067 .53883 L
s
.37779 .93387 m .38016 .93693 L .38242 .93453 L 0 1 .425 r
F
0 g
.38242 .93453 m
.39082 .93117 L
s
.37779 .93387 m .37185 .93966 L .38016 .93693 L 0 1 .425 r
F
0 g
.38016 .93693 m
.38546 .93738 L
s
.33653 .95256 m .33867 .9561 L .34128 .954 L 0 1 .454 r
F
0 g
.34128 .954 m
.35045 .95189 L
s
.33653 .95256 m .32974 .95761 L .33867 .9561 L 0 1 .454 r
F
0 g
.33867 .9561 m
.3442 .95733 L
s
.515 .69655 m .50979 .70984 L .51207 .71066 L 0 1 .37 r
F
0 g
.50949 .71647 m
.51207 .71066 L
s
.49232 1.04686 m .48101 1.0448 L .47206 1.045 L 0 1 .535 r
F
.42664 .79759 m .41292 .80187 L .41532 .80402 L 0 1 .512 r
F
0 g
.40918 .80568 m
.41532 .80402 L
s
.26229 .84898 m .24347 .8439 L .24604 .84845 L 0 1 .538 r
F
.24391 .84401 m .24735 .84247 L .2436 .84393 L F
.26229 .84898 m .24749 .84253 L .24391 .84401 L F
.24749 .84253 m .24735 .84247 L .24391 .84401 L F
.26229 .84898 m .25535 .84463 L .24727 .84244 L F
.27135 .84488 m .25535 .84463 L .26229 .84898 L F
.27135 .84488 m .25298 .84024 L .25535 .84463 L F
.27119 .84907 m .25301 .84026 L .25528 .84639 L 0 1 .526 r
F
.25301 .84026 m .25299 .84026 L .25528 .84639 L F
.2436 .84393 m .24727 .84244 L .24347 .8439 L 0 1 .538 r
F
.24735 .84247 m .24727 .84244 L .2436 .84393 L F
.24431 .84431 m .24727 .84244 L .24347 .8439 L 0 1 .526 r
F
.26213 .85309 m .24769 .84274 L .24431 .84431 L F
.24769 .84274 m .24727 .84244 L .24431 .84431 L F
.26213 .85309 m .25528 .84639 L .24779 .84269 L F
.24769 .84274 m .24779 .84269 L .24727 .84244 L F
.26213 .85309 m .24779 .84269 L .24769 .84274 L F
.25301 .84026 m .25298 .84024 L .25299 .84026 L F
.253 .84025 m .25299 .84026 L .25299 .84027 L 0 1 .492 r
F
.253 .84027 m .25299 .84027 L .25521 .84815 L F
.253 .84025 m .25299 .84027 L .253 .84027 L F
.27119 .84907 m .25528 .84639 L .26213 .85309 L 0 1 .526 r
F
.27103 .85327 m .25301 .84026 L .25521 .84815 L 0 1 .492 r
F
.25301 .84026 m .253 .84025 L .253 .84027 L F
.25301 .84026 m .253 .84027 L .25521 .84815 L F
.253 .84025 m .25298 .84024 L .25299 .84026 L F
.52046 .6781 m .51689 .69117 L .51915 .69133 L 0 1 .331 r
F
0 g
.51728 .69738 m
.51915 .69133 L
s
.77842 .57787 m .78571 .589 L .78955 .59112 L 0 .142 .189 r
F
0 g
.78571 .589 m
.78801 .59578 L
s
.43032 .93277 m .43403 .94058 L .43549 .93866 L 0 1 .492 r
F
.45178 .94703 m .43549 .93866 L .43403 .94058 L 0 1 .493 r
F
0 g
.43403 .94058 m
.43975 .94608 L
s
.42635 .93762 m
.43403 .94058 L
s
.46683 .77164 m .45717 .7759 L .4553 .77923 L 0 1 .488 r
F
.46683 .77164 m .46212 .77264 L .45717 .7759 L F
0 g
.46683 .77164 m
.46926 .77355 L
s
.47099 .76229 m .46212 .77264 L .46683 .77164 L 0 1 .476 r
F
0 g
.46683 .77164 m
.47152 .76804 L
s
.57946 .34572 m
.58354 .35496 L
s
.58354 .35496 m
.58363 .35517 L
s
.58363 .35517 m
.58523 .35878 L
s
.44877 .95974 m .43011 .96564 L .43622 .96716 L 0 1 .525 r
F
0 g
.4279 .96948 m
.43622 .96716 L
s
.76565 .77051 m
.76629 .77006 L
s
.50722 .7152 m .50041 .72777 L .50269 .72904 L 0 1 .403 r
F
0 g
.49943 .73434 m
.50269 .72904 L
s
.43645 1.03552 m .41482 1.03444 L .42222 1.03812 L 0 1 .539 r
F
0 g
.41264 1.03756 m
.42222 1.03812 L
s
.5207 1.05221 m .50933 1.05003 L .50066 1.05019 L 0 1 .53 r
F
0 g
.54701 .51238 m
.5474 .51033 L
s
.50495 .88899 m
.50675 .89045 L
s
.50687 .89055 m
.50821 .89163 L
s
.33179 .88114 m .31324 .87087 L .31652 .87804 L 0 1 .489 r
F
0 g
.30833 .87354 m
.31652 .87804 L
s
.4344 .79275 m
.43998 .79038 L
s
.45023 .78212 m .43771 .78835 L .43998 .79038 L 0 1 .499 r
F
.38075 .85277 m .36282 .85018 L .36533 .85534 L 0 1 .518 r
F
0 g
.36533 .85534 m
.36533 .85534 L
s
.35784 .85372 m
.36533 .85534 L
s
.54908 1.05858 m .53867 1.06152 L .55044 1.0639 L 0 1 .52 r
F
.54908 1.05858 m .52967 1.05797 L .53867 1.06152 L F
0 g
.53003 1.0614 m
.53867 1.06152 L
s
.62638 .45908 m
.62713 .46513 L
s
.73112 .52165 m .73892 .53709 L .73425 .53018 L 0 .405 .016 r
F
.73112 .52165 m .74282 .53959 L .73892 .53709 L F
.73112 .52165 m .74332 .53601 L .74282 .53959 L F
0 g
.74017 .52749 m
.74332 .53601 L
s
.74332 .53601 m
.74721 .53832 L
s
.48187 .87539 m .47476 .87264 L .46867 .87242 L 0 1 .511 r
F
.70102 .97075 m .71337 .96948 L .71062 .96835 L 0 1 .536 r
F
.72476 .95821 m .71337 .96948 L .72262 .96618 L 0 1 .534 r
F
.72476 .95821 m .71062 .96835 L .71337 .96948 L F
0 g
.70762 .97375 m
.71337 .96948 L
s
.51826 .90493 m .52443 .90584 L .5242 .903 L 0 1 .448 r
F
.51826 .90493 m .51854 .91209 L .52443 .90584 L F
0 g
.52443 .90584 m
.52498 .90541 L
s
.52942 .6494 m .52767 .65338 L .52733 .65811 L 0 1 .285 r
F
0 g
.52942 .6494 m
.52965 .64925 L
s
.52942 .6494 m
.52943 .64648 L
s
.36519 .8236 m .34747 .82516 L .34929 .82854 L 0 1 .528 r
F
.36519 .8236 m .35153 .8226 L .34747 .82516 L F
.36519 .8236 m .35913 .82193 L .35153 .8226 L F
0 g
.36519 .8236 m
.36697 .82698 L
s
.37241 .81827 m .35913 .82193 L .36519 .8236 L 0 1 .525 r
F
0 g
.36519 .8236 m
.37182 .82321 L
s
.35933 .98053 m .36255 .98553 L .3648 .98343 L 0 1 .535 r
F
.35933 .98053 m .35344 .98563 L .36255 .98553 L F
0 g
.36255 .98553 m
.36875 .98816 L
s
.52343 .67336 m .52272 .67455 L .52272 .67827 L 0 1 .333 r
F
0 g
.52272 .67827 m
.52272 .67827 L
s
.49719 .73276 m .48888 .7441 L .49113 .74568 L 0 1 .432 r
F
0 g
.48723 .75035 m
.49113 .74568 L
s
.5207 1.05221 m .52967 1.05797 L .52942 1.05561 L 0 1 .53 r
F
.54908 1.05858 m .52942 1.05561 L .52967 1.05797 L 0 1 .52 r
F
0 g
.52967 1.05797 m
.53867 1.06152 L
s
.52099 1.05813 m
.52967 1.05797 L
s
.47389 .96054 m .47202 .96436 L .47949 .96705 L 0 .916 .485 r
F
0 g
.47202 .96436 m
.47857 .96921 L
s
.79156 .77258 m .79641 .78665 L .80181 .77781 L 0 1 .491 r
F
0 g
.78941 .79163 m
.79641 .78665 L
s
.77901 .82286 m .7821 .83532 L .78882 .83043 L 0 1 .493 r
F
0 g
.77428 .83663 m
.7821 .83532 L
s
.4097 .91767 m .4124 .92589 L .41427 .92389 L 0 1 .488 r
F
.43032 .93277 m .41427 .92389 L .4124 .92589 L 0 1 .492 r
F
0 g
.40473 .92269 m
.4124 .92589 L
s
.4124 .92589 m
.41758 .93177 L
s
.36492 .88972 m .3658 .89849 L .36842 .89651 L 0 1 .485 r
F
.36492 .88972 m .35809 .89463 L .3658 .89849 L F
.38418 .90671 m .36842 .89651 L .3658 .89849 L 0 1 .489 r
F
0 g
.3658 .89849 m
.37002 .90501 L
s
.35809 .89463 m .34246 .88355 L .33949 .88545 L 0 1 .489 r
F
.35809 .89463 m .35043 .88749 L .34246 .88355 L F
.36492 .88972 m .35043 .88749 L .35809 .89463 L 0 1 .485 r
F
0 g
.35809 .89463 m
.3658 .89849 L
s
.35809 .89463 m
.36186 .90145 L
s
.49769 .50766 m .49342 .49745 L .49509 .50607 L 0 1 .273 r
F
.50153 .53971 m .49769 .50766 L .4976 .52165 L 0 1 .281 r
F
.37357 1.02956 m .35062 1.02574 L .3574 1.03021 L 0 1 .539 r
F
.42664 .79759 m .41542 .7993 L .41292 .80187 L 0 1 .512 r
F
.42664 .79759 m .4213 .79747 L .41542 .7993 L F
.43228 .79067 m .4213 .79747 L .42664 .79759 L 0 1 .506 r
F
0 g
.42664 .79759 m
.43225 .79557 L
s
.42664 .79759 m
.42902 .79974 L
s
.49984 .88249 m .49262 .87961 L .48676 .87929 L 0 1 .507 r
F
.34759 .85382 m .33005 .84881 L .33288 .85396 L 0 1 .521 r
F
.51854 .91209 m .5042 .92417 L .50402 .92739 L 0 1 .45 r
F
.51854 .91209 m .51043 .91761 L .5042 .92417 L F
0 g
.51854 .91209 m
.52443 .90584 L
s
.51854 .91209 m
.52341 .911 L
s
.68347 .97237 m
.68473 .97227 L
s
.68335 .97238 m
.68347 .97237 L
s
.68304 .9724 m
.68335 .97238 L
s
.54646 .37834 m .54475 .39743 L .54366 .39489 L 0 .083 .108 r
F
0 g
.54646 .37834 m
.54646 .37834 L
s
.54646 .37834 m .54953 .38706 L .54475 .39743 L 0 .083 .108 r
F
.54646 .37834 m .55477 .3708 L .54953 .38706 L F
0 g
.54645 .37836 m
.54646 .37834 L
s
.59081 .35182 m
.5967 .35486 L
s
.59076 .35179 m
.59081 .35182 L
s
.32285 .84626 m .32184 .85359 L .32512 .85168 L 0 1 .522 r
F
.32285 .84626 m .31443 .85089 L .32184 .85359 L F
0 g
.32184 .85359 m
.32492 .85884 L
s
.33945 .87647 m .33949 .88545 L .34246 .88355 L 0 1 .485 r
F
.33945 .87647 m .33179 .88114 L .33949 .88545 L F
0 g
.33949 .88545 m
.34328 .89229 L
s
.45178 .94703 m .45646 .95429 L .45751 .95254 L 0 1 .493 r
F
0 g
.45646 .95429 m
.45722 .95491 L
s
.44885 .95152 m
.45646 .95429 L
s
.34759 .85382 m .33334 .84688 L .33005 .84881 L 0 1 .521 r
F
0 g
.32512 .85168 m
.33288 .85396 L
s
.34759 .85382 m .34087 .84903 L .33334 .84688 L 0 1 .521 r
F
.35528 .84867 m .34087 .84903 L .34759 .85382 L 0 1 .52 r
F
0 g
.34759 .85382 m
.35486 .85582 L
s
.34759 .85382 m
.3504 .85896 L
s
.26196 .85721 m .24589 .85191 L .25291 .86113 L 0 1 .495 r
F
0 g
.25291 .86113 m
.26082 .86681 L
s
.51227 .5667 m .51102 .52862 L .51133 .55082 L 0 .912 .274 r
F
.50994 .57034 m .51133 .55082 L .51102 .52862 L 0 .932 .278 r
F
0 g
.51102 .52862 m
.51184 .5095 L
s
.50974 .51492 m
.51102 .52862 L
s
.32319 .83525 m .30572 .83354 L .30808 .83712 L 0 1 .534 r
F
.32319 .83525 m .3093 .83176 L .30572 .83354 L F
.32319 .83525 m .31679 .8325 L .3093 .83176 L F
.33163 .83035 m .31679 .8325 L .32319 .83525 L 0 1 .532 r
F
0 g
.32319 .83525 m
.33043 .83579 L
s
.32319 .83525 m
.32551 .83882 L
s
.52139 .66633 m .52343 .67336 L .52332 .67039 L 0 1 .289 r
F
.52139 .66633 m .52272 .67455 L .52343 .67336 L F
0 g
.52343 .67336 m
.52461 .67526 L
s
.52733 .65811 m
.52767 .65338 L
s
.79947 .60671 m .80878 .61015 L .80417 .60627 L 0 .415 .376 r
F
.79947 .60671 m .81092 .61661 L .80878 .61015 L F
.45521 .77394 m .4553 .77923 L .45717 .7759 L 0 1 .49 r
F
.45521 .77394 m .45023 .78212 L .4553 .77923 L F
0 g
.4553 .77923 m
.45774 .78113 L
s
.38911 .97836 m .36817 .98027 L .37407 .98277 L 0 1 .535 r
F
0 g
.3648 .98343 m
.37407 .98277 L
s
.40923 .85123 m .41026 .85791 L .4124 .85562 L 0 1 .514 r
F
.40923 .85123 m .40363 .85688 L .41026 .85791 L F
.42583 .85965 m .4124 .85562 L .41026 .85791 L 0 1 .515 r
F
0 g
.41026 .85791 m
.41401 .86213 L
s
.39408 .97271 m .39777 .97738 L .39964 .97506 L 0 1 .533 r
F
.39408 .97271 m .38911 .97836 L .39777 .97738 L F
0 g
.39777 .97738 m
.40398 .97947 L
s
.48506 .74855 m .47536 .75845 L .47754 .76024 L 0 1 .456 r
F
0 g
.47305 .76424 m
.47754 .76024 L
s
.81092 .61661 m .82052 .6306 L .82236 .62561 L 0 .49 .397 r
F
0 g
.81577 .63148 m
.82052 .6306 L
s
.29727 .87042 m .27855 .8587 L .28147 .86628 L 0 1 .492 r
F
.29727 .87042 m .28211 .85707 L .27855 .8587 L F
.29727 .87042 m .29014 .8621 L .28211 .85707 L F
.30567 .86608 m .29014 .8621 L .29727 .87042 L 0 1 .489 r
F
0 g
.29727 .87042 m
.30506 .87532 L
s
.29727 .87042 m
.30016 .87797 L
s
.55231 .34951 m .56345 .3441 L .56502 .35655 L 0 .362 .147 r
F
0 g
.56345 .3441 m
.56637 .32949 L
s
.55802 .3411 m
.56345 .3441 L
s
.76919 .81483 m .77256 .82761 L .77901 .82286 L 0 1 .487 r
F
0 g
.77054 .83351 m
.77256 .82761 L
s
.76493 .8287 m
.77256 .82761 L
s
.49114 .43296 m .48614 .44259 L .48742 .44205 L 0 .845 .107 r
F
.49114 .43296 m .48831 .43448 L .48614 .44259 L F
.49114 .43296 m .49246 .42315 L .48831 .43448 L F
.49335 .52362 m .49342 .49745 L .49055 .49686 L 0 1 .281 r
F
.49335 .52362 m .49509 .50607 L .49342 .49745 L F
0 g
.49342 .49745 m
.49384 .48478 L
s
.40061 .80948 m .38584 .8121 L .3882 .81452 L 0 1 .52 r
F
.40061 .80948 m .38865 .80983 L .38584 .8121 L F
.40061 .80948 m .39499 .80871 L .38865 .80983 L F
.40708 .80336 m .39499 .80871 L .40061 .80948 L 0 1 .516 r
F
0 g
.40061 .80948 m
.40669 .80819 L
s
.40061 .80948 m
.40295 .81191 L
s
.40363 .85688 m .39001 .85208 L .38753 .85423 L 0 1 .517 r
F
.40363 .85688 m .39691 .85321 L .39001 .85208 L F
.40923 .85123 m .39691 .85321 L .40363 .85688 L 0 1 .514 r
F
0 g
.40363 .85688 m
.41026 .85791 L
s
.40363 .85688 m
.40707 .8613 L
s
.4884 .50469 m .4909 .48692 L .48921 .48147 L 0 1 .27 r
F
.4884 .50469 m .49055 .49686 L .4909 .48692 L F
0 g
.4909 .48692 m
.49384 .48478 L
s
.50763 .57503 m .50627 .52478 L .5049 .52894 L 0 .951 .281 r
F
.50763 .57503 m .50788 .53657 L .50627 .52478 L F
0 g
.50627 .52478 m
.50672 .50909 L
s
.67731 .97376 m
.68289 .97244 L
s
.68289 .97244 m
.68292 .97243 L
s
.68292 .97243 m
.68299 .97241 L
s
.68299 .97241 m
.68304 .9724 L
s
.46422 .86847 m .45728 .86566 L .45103 .86539 L 0 1 .512 r
F
.52139 .66633 m .52165 .67327 L .52272 .67455 L 0 1 .289 r
F
0 g
.52272 .67455 m
.52272 .67827 L
s
.34009 .82538 m .33866 .83069 L .34196 .82863 L 0 1 .53 r
F
0 g
.34196 .82863 m
.34928 .82854 L
s
.34009 .82538 m .33163 .83035 L .33866 .83069 L 0 1 .53 r
F
0 g
.33866 .83069 m
.34129 .83384 L
s
.78131 .76715 m .78638 .78131 L .79156 .77258 L 0 1 .487 r
F
0 g
.77954 .78616 m
.78638 .78131 L
s
.78547 .78946 m
.78638 .78131 L
s
.33179 .88114 m .31652 .86909 L .31324 .87087 L 0 1 .489 r
F
.33179 .88114 m .32448 .87349 L .31652 .86909 L F
.33945 .87647 m .32448 .87349 L .33179 .88114 L 0 1 .485 r
F
0 g
.33179 .88114 m
.33505 .88829 L
s
.33179 .88114 m
.33949 .88545 L
s
.42583 .85965 m .41908 .85637 L .4124 .85562 L 0 1 .515 r
F
.43055 .85368 m .42583 .85965 L .43223 .86031 L 0 1 .511 r
F
.43055 .85368 m .41908 .85637 L .42583 .85965 L F
0 g
.42583 .85965 m
.42957 .86388 L
s
.38418 .90671 m .37631 .90004 L .36842 .89651 L 0 1 .489 r
F
.39012 .90167 m .38418 .90671 L .39178 .9102 L 0 1 .484 r
F
.39012 .90167 m .37631 .90004 L .38418 .90671 L F
0 g
.38418 .90671 m
.38839 .91322 L
s
.5191 .89777 m
.51974 .89824 L
s
.52263 .9004 m
.52417 .90155 L
s
.52504 .90183 m
.52582 .90207 L
s
.52661 .90231 m
.52808 .90277 L
s
.52495 .9018 m
.52504 .90183 L
s
.62175 .44901 m
.62265 .46022 L
s
.62434 .4815 m
.62639 .50709 L
s
.62644 .50779 m
.62717 .51693 L
s
.62717 .51693 m
.62731 .5186 L
s
.62731 .5186 m
.62731 .51865 L
s
.62731 .51865 m
.62739 .51965 L
s
.62739 .51965 m
.62759 .52215 L
s
.62759 .52215 m
.62769 .52338 L
s
.62781 .5249 m
.62797 .52695 L
s
.62809 .5284 m
.6281 .5286 L
s
.62811 .52864 m
.62819 .52966 L
s
.62824 .53029 m
.62836 .53186 L
s
.62153 .45351 m
.62158 .44801 L
s
.62149 .45729 m
.6215 .45616 L
s
.62151 .45544 m
.62153 .45351 L
s
.37965 .81285 m .37882 .8177 L .38163 .81547 L 0 1 .522 r
F
0 g
.38163 .81547 m
.3882 .81452 L
s
.37965 .81285 m .37241 .81827 L .37882 .8177 L 0 1 .522 r
F
0 g
.37882 .8177 m
.38144 .82023 L
s
.5242 .903 m
.52441 .90271 L
s
.52496 .90194 m
.52504 .90183 L
s
.52504 .90183 m
.52585 .90071 L
s
.52619 .90024 m
.52633 .90005 L
s
.52418 .89891 m
.52474 .89855 L
s
.54716 .34786 m
.55231 .3495 L
s
.5436 .36247 m
.54716 .34786 L
s
.75934 .80628 m .76299 .81947 L .76919 .81483 L 0 .979 .479 r
F
0 g
.75555 .82033 m
.76299 .81947 L
s
.76118 .8254 m
.76299 .81947 L
s
.46416 1.04155 m .453 1.03926 L .44384 1.0392 L 0 1 .538 r
F
.45023 .78212 m .43997 .78532 L .43771 .78835 L 0 1 .499 r
F
.45023 .78212 m .44533 .78264 L .43997 .78532 L F
.45521 .77394 m .44533 .78264 L .45023 .78212 L 0 1 .49 r
F
0 g
.45023 .78212 m
.45249 .78415 L
s
.45023 .78212 m
.4553 .77923 L
s
.27103 .85327 m .26968 .86277 L .27323 .86115 L 0 1 .492 r
F
0 g
.27323 .86115 m
.28147 .86628 L
s
.27103 .85327 m .26196 .85721 L .26968 .86277 L 0 1 .492 r
F
0 g
.26968 .86277 m
.27282 .87044 L
s
.26446 .85901 m
.26459 .85935 L
s
.49311 1.04066 m .48101 1.0448 L .49232 1.04686 L 0 1 .534 r
F
.49311 1.04066 m .47298 1.04148 L .48101 1.0448 L F
0 g
.47206 1.045 m
.48101 1.0448 L
s
.52537 .65581 m
.52767 .65338 L
s
.43055 .85368 m .43223 .86031 L .434 .8579 L 0 1 .511 r
F
.44706 .86131 m .434 .8579 L .43223 .86031 L 0 1 .512 r
F
0 g
.43223 .86031 m
.43621 .86438 L
s
.42583 .85965 m
.43223 .86031 L
s
.49311 1.04066 m .49232 1.04686 L .50095 1.04651 L 0 1 .534 r
F
0 g
.49232 1.04686 m
.50066 1.05019 L
s
.47396 .94895 m .4595 .95326 L .45954 .95353 L 0 1 .515 r
F
.47389 .96054 m .46498 .95522 L .4595 .95326 L 0 .916 .485 r
F
.45954 .95353 m .4595 .95326 L .45751 .95254 L F
.47389 .96054 m .4595 .95326 L .45954 .95353 L F
.47396 .94895 m .46501 .95072 L .4595 .95326 L 0 1 .515 r
F
.45954 .95353 m .4595 .95326 L .45749 .95418 L F
0 g
.47396 .94895 m
.48019 .95002 L
s
.47629 .93956 m .47396 .94895 L .48124 .94472 L 0 1 .507 r
F
.47629 .93956 m .46501 .95072 L .47396 .94895 L F
.50153 .53971 m .50287 .53534 L .50295 .52132 L 0 1 .281 r
F
.28027 .84502 m .27878 .85267 L .28233 .85099 L 0 1 .525 r
F
0 g
.28233 .85099 m
.29042 .85415 L
s
.28027 .84502 m .27119 .84907 L .27878 .85267 L 0 1 .525 r
F
0 g
.27878 .85267 m
.28124 .85747 L
s
.26213 .85309 m .24347 .8439 L .24597 .85018 L 0 1 .526 r
F
0 g
.26213 .85309 m
.26349 .85655 L
s
.26213 .85309 m
.26653 .85522 L
s
.35344 .98563 m .33146 .98549 L .33726 .98853 L 0 1 .537 r
F
.38719 .84748 m .38753 .85423 L .39001 .85208 L 0 1 .516 r
F
.38719 .84748 m .38075 .85277 L .38753 .85423 L F
0 g
.38753 .85423 m
.39098 .85866 L
s
.5566 .47093 m .559 .49276 L .55653 .48832 L 0 .182 .142 r
F
.5566 .47093 m .56303 .48172 L .559 .49276 L F
.5566 .47093 m .56592 .46267 L .56303 .48172 L F
.5504 .48839 m .5566 .47093 L .55291 .48884 L 0 0 .018 r
F
0 g
.51958 .89728 m
.52174 .8975 L
s
.48365 .86884 m .47476 .87264 L .48187 .87539 L 0 1 .506 r
F
.48365 .86884 m .47017 .86864 L .47476 .87264 L F
0 g
.46867 .87242 m
.47476 .87264 L
s
.53437 .45813 m .53389 .43961 L .53285 .45756 L 0 1 .152 r
F
.52648 .49674 m .53389 .43961 L .53196 .43953 L 0 1 .182 r
F
0 g
.53215 .43953 m
.53236 .43954 L
s
.52648 .49674 m .53285 .45756 L .53389 .43961 L 0 1 .182 r
F
0 g
.53389 .43961 m
.53514 .42857 L
s
.53236 .43954 m
.53389 .43961 L
s
.47629 .93956 m .48124 .94472 L .48202 .94083 L 0 1 .507 r
F
.49751 .93223 m .48202 .94083 L .48124 .94472 L 0 1 .491 r
F
0 g
.48124 .94472 m
.48746 .94568 L
s
.47396 .94895 m
.48124 .94472 L
s
.54669 .52013 m
.54698 .51861 L
s
.28953 .83657 m .28789 .84233 L .29145 .84058 L 0 1 .536 r
F
0 g
.29145 .84058 m
.29938 .84169 L
s
.28953 .83657 m .28043 .84074 L .28789 .84233 L 0 1 .536 r
F
0 g
.28789 .84233 m
.2907 .84622 L
s
.49335 .52362 m .49507 .51728 L .49509 .50607 L 0 1 .281 r
F
0 g
.49509 .50607 m
.49769 .50766 L
s
.4884 .50469 m .48921 .48147 L .48601 .48402 L 0 1 .27 r
F
0 g
.48921 .48147 m
.48996 .47022 L
s
.3223 .98487 m .32495 .99021 L .32755 .98832 L 0 1 .537 r
F
0 g
.32755 .98832 m
.33726 .98853 L
s
.3223 .98487 m .31553 .98943 L .32495 .99021 L 0 1 .537 r
F
0 g
.32495 .99021 m
.33103 .99339 L
s
.55044 1.0639 m
.5506 1.06396 L
s
.72476 .95821 m .72262 .96618 L .73222 .96062 L 0 1 .534 r
F
0 g
.71337 .96948 m
.72262 .96618 L
s
.63708 .77404 m
.63737 .772 L
s
.48365 .86884 m .48187 .87539 L .48765 .87548 L 0 1 .506 r
F
0 g
.48187 .87539 m
.48676 .87929 L
s
.68929 .52783 m .69511 .4909 L .69945 .50088 L 0 .631 .154 r
F
.68929 .52783 m .69077 .50234 L .69511 .4909 L F
0 g
.69255 .471 m
.69511 .4909 L
s
.49827 .92445 m .50402 .92739 L .5042 .92417 L 0 1 .484 r
F
.49827 .92445 m .49751 .93223 L .50402 .92739 L F
0 g
.50402 .92739 m
.51029 .92597 L
s
.45717 .7759 m
.46212 .77264 L
s
.47099 .76229 m .46005 .7707 L .46212 .77264 L 0 1 .476 r
F
.46701 .86204 m .46422 .86847 L .47017 .86864 L 0 1 .507 r
F
.46701 .86204 m .45728 .86566 L .46422 .86847 L F
0 g
.46422 .86847 m
.46867 .87242 L
s
.49644 .97354 m .48615 .97154 L .49564 .97609 L 0 .744 .445 r
F
.49644 .97354 m .47949 .96705 L .48615 .97154 L F
0 g
.47857 .96921 m
.48615 .97154 L
s
.45173 .95285 m .45644 .95702 L .45749 .95418 L 0 1 .521 r
F
.45173 .95285 m .44877 .95974 L .45644 .95702 L F
0 g
.45644 .95702 m
.4603 .95768 L
s
.46602 1.0357 m .46416 1.04155 L .47298 1.04148 L 0 1 .538 r
F
.46602 1.0357 m .453 1.03926 L .46416 1.04155 L F
0 g
.46416 1.04155 m
.47206 1.045 L
s
.70349 .49786 m .71549 .50746 L .71436 .51922 L 0 .689 .104 r
F
0 g
.71301 .49113 m
.71549 .50746 L
s
.39012 .90167 m .39178 .9102 L .39404 .90818 L 0 1 .484 r
F
0 g
.38418 .90671 m
.39178 .9102 L
s
.39178 .9102 m
.39636 .91642 L
s
.35344 .98563 m .33407 .98359 L .33146 .98549 L 0 1 .537 r
F
.35344 .98563 m .3435 .98366 L .33407 .98359 L F
.35933 .98053 m .3435 .98366 L .35344 .98563 L 0 1 .535 r
F
0 g
.35344 .98563 m
.36255 .98553 L
s
.35344 .98563 m
.35919 .98867 L
s
.50806 .70442 m .50979 .70984 L .50999 .70552 L 0 1 .373 r
F
.50806 .70442 m .50722 .7152 L .50979 .70984 L F
.515 .69655 m .50999 .70552 L .50979 .70984 L 0 1 .37 r
F
0 g
.50979 .70984 m
.51207 .71066 L
s
.42204 .96754 m .40245 .97157 L .40835 .97351 L 0 1 .531 r
F
0 g
.39964 .97506 m
.40835 .97351 L
s
.51826 .90493 m
.5242 .903 L
s
.70349 .49786 m .71025 .52218 L .70594 .5143 L 0 .689 .104 r
F
.70349 .49786 m .71436 .51922 L .71025 .52218 L F
.50722 .7152 m .50107 .7234 L .50041 .72777 L 0 1 .403 r
F
.50722 .7152 m .50399 .71801 L .50107 .7234 L F
.50806 .70442 m .50399 .71801 L .50722 .7152 L 0 1 .373 r
F
0 g
.50722 .7152 m
.50979 .70984 L
s
.50722 .7152 m
.50949 .71647 L
s
.38911 .97836 m .37043 .97817 L .36817 .98027 L 0 1 .535 r
F
.38911 .97836 m .37941 .97735 L .37043 .97817 L F
.39408 .97271 m .37941 .97735 L .38911 .97836 L 0 1 .533 r
F
0 g
.38911 .97836 m
.39498 .98086 L
s
.38911 .97836 m
.39777 .97738 L
s
.515 .69655 m .51223 .69981 L .50999 .70552 L 0 1 .37 r
F
.5147 .6867 m .515 .69655 L .51689 .69117 L 0 1 .331 r
F
.5147 .6867 m .51223 .69981 L .515 .69655 L F
0 g
.515 .69655 m
.51728 .69738 L
s
.50263 .98021 m
.50302 .98033 L
s
.50302 .98033 m
.50994 .98236 L
s
.52499 .65912 m .52246 .66762 L .52332 .67039 L 0 1 .284 r
F
0 g
.52332 .67039 m
.52566 .66937 L
s
.52139 .66633 m .52332 .67039 L .52246 .66762 L 0 1 .289 r
F
0 g
.52332 .67039 m
.52343 .67336 L
s
.53213 .42392 m .54089 .39233 L .54201 .39271 L 0 0 .046 r
F
0 g
.54201 .39271 m
.54646 .37834 L
s
.53213 .42392 m .53667 .40566 L .54089 .39233 L 0 0 .046 r
F
0 g
.54089 .39233 m
.54332 .37528 L
s
.53667 .40566 m
.53924 .39483 L
s
.53667 .40566 m
.53836 .40031 L
s
.53836 .40031 m
.54089 .39233 L
s
.76679 .56512 m .77797 .57944 L .77842 .57787 L 0 .063 .172 r
F
0 g
.77797 .57944 m
.78109 .5842 L
s
.77416 .57655 m
.77797 .57944 L
s
.55044 1.0639 m
.55061 1.06391 L
s
.36492 .88972 m .34691 .88069 L .35043 .88749 L 0 1 .485 r
F
0 g
.34246 .88355 m
.35043 .88749 L
s
.77104 .7615 m .77634 .77579 L .78131 .76715 L 0 1 .482 r
F
0 g
.77212 .77877 m
.77634 .77579 L
s
.77559 .78392 m
.77634 .77579 L
s
.45178 .94703 m .4431 .94142 L .43549 .93866 L 0 1 .493 r
F
0 g
.43549 .93866 m
.4431 .94142 L
s
.72476 .95821 m .71549 .96352 L .71062 .96835 L 0 1 .534 r
F
0 g
.70102 .97075 m
.71062 .96835 L
s
.62467 .51218 m
.6248 .51452 L
s
.6248 .51452 m
.6249 .51625 L
s
.6249 .51625 m
.62507 .51919 L
s
.62507 .51919 m
.6251 .51972 L
s
.62516 .5207 m
.62533 .52367 L
s
.62539 .52476 m
.62554 .52735 L
s
.6258 .53182 m
.62768 .5644 L
s
.62558 .52807 m
.6258 .53182 L
s
.49751 .93223 m .48899 .93548 L .48202 .94083 L 0 1 .491 r
F
0 g
.49751 .93223 m
.50371 .93321 L
s
.49827 .92445 m .48899 .93548 L .49751 .93223 L 0 1 .484 r
F
0 g
.49751 .93223 m
.50402 .92739 L
s
.49917 .72195 m .50041 .72777 L .50107 .7234 L 0 1 .407 r
F
.49917 .72195 m .49719 .73276 L .50041 .72777 L F
0 g
.50041 .72777 m
.50269 .72904 L
s
.54953 .38706 m .55986 .36357 L .56144 .37014 L 0 .14 .11 r
F
.54953 .38706 m .55477 .3708 L .55986 .36357 L F
0 g
.55986 .36357 m
.56112 .35439 L
s
.5147 .6867 m .51689 .69117 L .51663 .68725 L 0 1 .331 r
F
.52046 .6781 m .51663 .68725 L .51689 .69117 L F
0 g
.51689 .69117 m
.51915 .69133 L
s
.515 .69655 m
.51689 .69117 L
s
.37185 .93966 m .35177 .94556 L .35673 .94641 L 0 1 .447 r
F
.37185 .93966 m .3544 .94344 L .35177 .94556 L F
.37185 .93966 m .36302 .94091 L .3544 .94344 L F
.37779 .93387 m .36302 .94091 L .37185 .93966 L 0 1 .425 r
F
0 g
.37185 .93966 m
.38016 .93693 L
s
.37185 .93966 m
.37677 .94053 L
s
.55973 .54063 m
.56023 .5424 L
s
.55965 .54037 m
.55973 .54063 L
s
.46701 .86204 m .45312 .86164 L .45728 .86566 L 0 1 .507 r
F
0 g
.45103 .86539 m
.45728 .86566 L
s
.49719 .73276 m .48998 .73991 L .48888 .7441 L 0 1 .432 r
F
.49719 .73276 m .49355 .73504 L .48998 .73991 L F
.49917 .72195 m .49355 .73504 L .49719 .73276 L 0 1 .407 r
F
0 g
.49719 .73276 m
.49943 .73434 L
s
.49719 .73276 m
.50041 .72777 L
s
.44877 .95974 m .43158 .96307 L .43011 .96564 L 0 1 .525 r
F
.44877 .95974 m .43959 .96054 L .43158 .96307 L F
.45173 .95285 m .43959 .96054 L .44877 .95974 L 0 1 .521 r
F
0 g
.44877 .95974 m
.45485 .96127 L
s
.44877 .95974 m
.45644 .95702 L
s
.70112 .97419 m .71355 .97513 L .71077 .97319 L 0 1 .54 r
F
.69442 .96914 m .70112 .97419 L .70659 .97025 L 0 1 .539 r
F
.3785 1.02476 m .3831 1.03109 L .38495 1.02914 L F
0 g
.37948 1.03347 m
.38032 1.03403 L
s
.3785 1.02476 m .37357 1.02956 L .3831 1.03109 L 0 1 .539 r
F
.40552 1.03351 m .38495 1.02914 L .3831 1.03109 L F
0 g
.3831 1.03109 m
.39024 1.03515 L
s
.50677 .88668 m
.50882 .88688 L
s
.38075 .85277 m .36649 .84755 L .36282 .85018 L 0 1 .518 r
F
.38075 .85277 m .37418 .84867 L .36649 .84755 L F
0 g
.38075 .85277 m
.38324 .85793 L
s
.38719 .84748 m .37418 .84867 L .38075 .85277 L 0 1 .516 r
F
0 g
.38075 .85277 m
.38753 .85423 L
s
.43032 .93277 m .42195 .92684 L .41427 .92389 L 0 1 .492 r
F
0 g
.41427 .92389 m
.42195 .92684 L
s
.4097 .91767 m
.41427 .92389 L
s
.43032 .93277 m
.43549 .93866 L
s
.52041 1.04585 m .50933 1.05003 L .5207 1.05221 L 0 1 .527 r
F
.52041 1.04585 m .50095 1.04651 L .50933 1.05003 L F
0 g
.50066 1.05019 m
.50933 1.05003 L
s
.48605 .46249 m .48932 .44253 L .48569 .44948 L 0 1 .174 r
F
0 g
.48713 .44672 m
.48932 .44253 L
s
.48932 .44253 m
.49114 .43296 L
s
.5504 .48839 m .55291 .48884 L .55053 .49396 L 0 0 .018 r
F
0 g
.5504 .48839 m
.55053 .49396 L
s
.54952 .49312 m
.5504 .48839 L
s
.54827 .49983 m
.54952 .49312 L
s
.54806 .50098 m
.54827 .49983 L
s
.54755 .50372 m
.54806 .50098 L
s
.25342 .84035 m .25687 .83881 L .25312 .84028 L 0 1 .538 r
F
.27135 .84488 m .25701 .83887 L .25342 .84035 L F
.25701 .83887 m .25687 .83881 L .25342 .84035 L F
.27135 .84488 m .26468 .84077 L .25679 .83878 L F
.28043 .84074 m .26468 .84077 L .27135 .84488 L 0 1 .537 r
F
.28043 .84074 m .26252 .83656 L .26468 .84077 L F
.28027 .84502 m .26255 .83658 L .26461 .84257 L 0 1 .525 r
F
.26255 .83658 m .26252 .83659 L .26461 .84257 L F
.25312 .84028 m .25679 .83878 L .25298 .84024 L 0 1 .538 r
F
.25687 .83881 m .25679 .83878 L .25312 .84028 L F
.25383 .84065 m .25679 .83878 L .25298 .84024 L 0 1 .526 r
F
.27119 .84907 m .25721 .83907 L .25383 .84065 L F
.25721 .83907 m .25679 .83878 L .25383 .84065 L F
.27119 .84907 m .26461 .84257 L .25731 .83903 L F
.25721 .83907 m .25731 .83903 L .25679 .83878 L F
.27119 .84907 m .25731 .83903 L .25721 .83907 L F
.26255 .83658 m .26252 .83656 L .26252 .83659 L 0 1 .525 r
F
.26253 .83657 m .26252 .83658 L .26252 .83659 L 0 1 .49 r
F
.26254 .83659 m .26252 .83659 L .26454 .84437 L F
.26253 .83657 m .26252 .83659 L .26254 .83659 L F
.28027 .84502 m .26461 .84257 L .27119 .84907 L 0 1 .525 r
F
.28012 .8493 m .26255 .83658 L .26454 .84437 L 0 1 .49 r
F
.26255 .83658 m .26253 .83657 L .26254 .83659 L F
.26255 .83658 m .26254 .83659 L .26454 .84437 L F
.26253 .83657 m .26252 .83656 L .26252 .83658 L F
.40552 1.03351 m .39457 1.03017 L .38495 1.02914 L 0 1 .539 r
F
.40947 1.02838 m .40552 1.03351 L .41482 1.03444 L F
.40947 1.02838 m .39457 1.03017 L .40552 1.03351 L F
0 g
.40552 1.03351 m
.41264 1.03756 L
s
.54908 1.05858 m .53773 1.05587 L .52942 1.05561 L 0 1 .52 r
F
0 g
.61281 .36548 m
.61383 .36857 L
s
.61253 .36709 m
.61281 .36548 L
s
.39012 .90167 m .37237 .89353 L .37631 .90004 L 0 1 .484 r
F
0 g
.36842 .89651 m
.37631 .90004 L
s
.5006 .87566 m .49262 .87961 L .49984 .88249 L 0 1 .501 r
F
0 g
.49984 .88249 m
.50016 .88273 L
s
.5006 .87566 m .48765 .87548 L .49262 .87961 L 0 1 .501 r
F
0 g
.48676 .87929 m
.49262 .87961 L
s
.48815 .73821 m .48888 .7441 L .48998 .73991 L 0 1 .436 r
F
.48815 .73821 m .48506 .74855 L .48888 .7441 L F
0 g
.48888 .7441 m
.49113 .74568 L
s
.31443 .85089 m .29658 .84421 L .2991 .84978 L 0 1 .523 r
F
.31443 .85089 m .30015 .8425 L .29658 .84421 L F
.31443 .85089 m .30781 .84537 L .30015 .8425 L F
.32285 .84626 m .30781 .84537 L .31443 .85089 L 0 1 .522 r
F
0 g
.31443 .85089 m
.32184 .85359 L
s
.31443 .85089 m
.31692 .85643 L
s
.46602 1.0357 m .44541 1.03587 L .453 1.03926 L 0 1 .538 r
F
0 g
.44384 1.0392 m
.453 1.03926 L
s
.40947 1.02838 m .41482 1.03444 L .41627 1.03235 L 0 1 .539 r
F
.43645 1.03552 m .41627 1.03235 L .41482 1.03444 L F
0 g
.41482 1.03444 m
.42222 1.03812 L
s
.40552 1.03351 m
.41482 1.03444 L
s
.52046 .6781 m .51816 .68165 L .51663 .68725 L 0 1 .331 r
F
.51901 .67062 m .52046 .6781 L .52165 .67328 L 0 1 .279 r
F
.51901 .67062 m .51816 .68165 L .52046 .6781 L F
0 g
.52046 .6781 m
.52272 .67827 L
s
.52046 .6781 m
.52124 .67493 L
s
.68872 .73495 m
.68872 .73495 L
s
.68852 .73381 m
.68852 .73381 L
s
.725 .96553 m .71355 .97513 L .72287 .97379 L 0 1 .54 r
F
.725 .96553 m .71077 .97319 L .71355 .97513 L F
0 g
.70779 .97913 m
.71355 .97513 L
s
.49335 .52362 m .49055 .49686 L .4884 .50469 L 0 1 .281 r
F
0 g
.49055 .49686 m
.4909 .48692 L
s
.49055 .49686 m
.49342 .49745 L
s
.43055 .85368 m .41561 .85216 L .41908 .85637 L 0 1 .511 r
F
0 g
.4124 .85562 m
.41908 .85637 L
s
.37357 1.02956 m .35285 1.02391 L .35062 1.02574 L 0 1 .539 r
F
.37357 1.02956 m .3627 1.02555 L .35285 1.02391 L F
.3785 1.02476 m .3627 1.02555 L .37357 1.02956 L F
0 g
.37357 1.02956 m
.3831 1.03109 L
s
.37357 1.02956 m
.37948 1.03347 L
s
.51924 .56426 m .52014 .56513 L .52193 .54296 L 0 .86 .265 r
F
0 g
.54216 .51248 m
.5425 .5079 L
s
.5425 .5079 m
.54374 .49137 L
s
.54374 .49137 m
.54423 .48482 L
s
.54423 .48482 m
.54437 .48304 L
s
.48506 .74855 m .4769 .75454 L .47536 .75845 L 0 1 .456 r
F
.48506 .74855 m .48106 .75029 L .4769 .75454 L F
.48815 .73821 m .48106 .75029 L .48506 .74855 L 0 1 .436 r
F
0 g
.48506 .74855 m
.48723 .75035 L
s
.48506 .74855 m
.48888 .7441 L
s
.32974 .95761 m .3082 .96066 L .31328 .9623 L 0 1 .469 r
F
.32974 .95761 m .31116 .95883 L .3082 .96066 L F
.32974 .95761 m .3204 .95752 L .31116 .95883 L F
.33653 .95256 m .3204 .95752 L .32974 .95761 L 0 1 .454 r
F
0 g
.32974 .95761 m
.33867 .9561 L
s
.32974 .95761 m
.33475 .95924 L
s
.50763 .57503 m .5049 .52894 L .50479 .54536 L 0 .951 .281 r
F
0 g
.50295 .52132 m
.5049 .52894 L
s
.71436 .51923 m .72642 .51709 L .72981 .53197 L 0 .601 .094 r
F
0 g
.72642 .51709 m
.73112 .52165 L
s
.47389 .96054 m .47949 .96705 L .48011 .96561 L 0 .916 .485 r
F
.49644 .97354 m .48011 .96561 L .47949 .96705 L 0 .744 .445 r
F
0 g
.47949 .96705 m
.48615 .97154 L
s
.47202 .96436 m
.47949 .96705 L
s
.40923 .85123 m .39373 .84882 L .39691 .85321 L 0 1 .514 r
F
0 g
.39001 .85208 m
.39691 .85321 L
s
.6347 .77244 m
.63644 .77089 L
s
.79003 .58912 m .79264 .59583 L .79725 .60014 L 0 .217 .206 r
F
.79003 .58912 m .78955 .59112 L .79264 .59583 L F
0 g
.78801 .59578 m
.79264 .59583 L
s
.41357 .79708 m .41292 .80187 L .41542 .7993 L 0 1 .51 r
F
.41357 .79708 m .40708 .80336 L .41292 .80187 L F
0 g
.41292 .80187 m
.41532 .80402 L
s
.51695 .56343 m .51787 .56353 L .51936 .542 L 0 .876 .268 r
F
.4382 .78324 m .43771 .78835 L .43997 .78532 L 0 1 .498 r
F
.4382 .78324 m .43229 .79067 L .43771 .78835 L F
0 g
.43771 .78835 m
.43998 .79038 L
s
.5042 .92417 m
.51043 .91761 L
s
.46701 .86204 m .47017 .86864 L .47117 .86606 L 0 1 .507 r
F
.48365 .86884 m .47117 .86606 L .47017 .86864 L 0 1 .506 r
F
0 g
.47017 .86864 m
.47476 .87264 L
s
.46422 .86847 m
.47017 .86864 L
s
.31408 .86171 m .31324 .87087 L .31652 .86909 L 0 1 .486 r
F
.31408 .86171 m .30567 .86608 L .31324 .87087 L F
0 g
.31324 .87087 m
.31652 .87804 L
s
.46602 1.0357 m .47298 1.04148 L .4736 1.0391 L 0 1 .538 r
F
.49311 1.04066 m .4736 1.0391 L .47298 1.04148 L 0 1 .534 r
F
0 g
.47298 1.04148 m
.48101 1.0448 L
s
.46416 1.04155 m
.47298 1.04148 L
s
.45178 .94703 m
.45751 .95254 L
s
.4595 .95326 m
.46498 .95522 L
s
.45751 .95254 m
.4595 .95326 L
s
.44706 .86131 m .44036 .85833 L .434 .8579 L 0 1 .512 r
F
.45083 .855 m .44706 .86131 L .45312 .86164 L 0 1 .507 r
F
.45083 .855 m .44036 .85833 L .44706 .86131 L F
0 g
.44706 .86131 m
.45103 .86539 L
s
.52139 .66633 m .52093 .67038 L .52165 .67327 L 0 1 .289 r
F
0 g
.52165 .67327 m
.52272 .67455 L
s
.51901 .67062 m .52165 .67328 L .52093 .67038 L 0 1 .279 r
F
0 g
.52124 .67493 m
.52165 .67328 L
s
.42603 .96129 m .43011 .96564 L .43158 .96307 L 0 1 .527 r
F
.42603 .96129 m .42204 .96754 L .43011 .96564 L F
0 g
.43011 .96564 m
.43622 .96716 L
s
.49644 .97354 m .49564 .97609 L .50291 .97888 L 0 .744 .445 r
F
0 g
.49564 .97609 m
.50263 .98021 L
s
.43228 .79067 m .41917 .7954 L .4213 .79747 L 0 1 .506 r
F
0 g
.41542 .7993 m
.4213 .79747 L
s
.49311 1.04066 m .50095 1.04651 L .50113 1.04399 L 0 1 .534 r
F
.52041 1.04585 m .50113 1.04399 L .50095 1.04651 L 0 1 .527 r
F
0 g
.50095 1.04651 m
.50933 1.05003 L
s
.49232 1.04686 m
.50095 1.04651 L
s
.47516 .75268 m .47536 .75845 L .4769 .75454 L 0 1 .459 r
F
.47516 .75268 m .47099 .76229 L .47536 .75845 L F
0 g
.47536 .75845 m
.47754 .76024 L
s
.49984 .88249 m
.50009 .88249 L
s
.6257 .38585 m
.62676 .39087 L
s
.62676 .39087 m
.62741 .39393 L
s
.62561 .38626 m
.6257 .38585 L
s
.62489 .38976 m
.62561 .38626 L
s
.37241 .81827 m .3569 .81918 L .35913 .82193 L 0 1 .525 r
F
.37241 .81827 m .36001 .81719 L .3569 .81918 L F
.37241 .81827 m .36666 .8168 L .36001 .81719 L F
.37965 .81285 m .36666 .8168 L .37241 .81827 L 0 1 .522 r
F
0 g
.37241 .81827 m
.37882 .8177 L
s
.37241 .81827 m
.37462 .82102 L
s
.48365 .86884 m .48765 .87548 L .48824 .87284 L 0 1 .506 r
F
.5006 .87566 m .48824 .87284 L .48765 .87548 L 0 1 .501 r
F
0 g
.48765 .87548 m
.49262 .87961 L
s
.48187 .87539 m
.48765 .87548 L
s
.36475 .84226 m .36282 .85018 L .36649 .84755 L 0 1 .518 r
F
.36475 .84226 m .35528 .84867 L .36282 .85018 L F
0 g
.36282 .85018 m
.36533 .85534 L
s
.52041 1.04585 m .5207 1.05221 L .52905 1.05193 L 0 1 .527 r
F
0 g
.5207 1.05221 m
.52942 1.05561 L
s
.26196 .85721 m .24347 .8439 L .24589 .85191 L 0 1 .495 r
F
.26196 .85721 m .24727 .84244 L .24347 .8439 L F
.26196 .85721 m .25521 .84815 L .24727 .84244 L F
.27103 .85327 m .25521 .84815 L .26196 .85721 L 0 1 .492 r
F
0 g
.26196 .85721 m
.26968 .86277 L
s
.26196 .85721 m
.26436 .8652 L
s
.5147 .6867 m .51029 .69927 L .51223 .69981 L 0 1 .331 r
F
0 g
.50999 .70552 m
.51223 .69981 L
s
.52499 .65912 m .52318 .66278 L .52246 .66762 L 0 1 .284 r
F
0 g
.52499 .65912 m
.52733 .65811 L
s
.52499 .65912 m
.52537 .65581 L
s
.50806 .70442 m .50205 .71693 L .50399 .71801 L 0 1 .373 r
F
0 g
.50107 .7234 m
.50399 .71801 L
s
.56303 .48172 m .56592 .46267 L .57031 .46237 L 0 .399 .184 r
F
0 g
.56592 .46267 m
.56594 .44545 L
s
.52146 .56705 m .52233 .56875 L .52442 .54652 L 0 .846 .263 r
F
0 g
.52044 .56143 m
.52193 .54296 L
s
.33945 .87647 m .32145 .8664 L .32448 .87349 L 0 1 .485 r
F
0 g
.31652 .86909 m
.32448 .87349 L
s
.47099 .76229 m .46201 .76712 L .46005 .7707 L 0 1 .476 r
F
.47099 .76229 m .4667 .76351 L .46201 .76712 L F
.47516 .75268 m .4667 .76351 L .47099 .76229 L 0 1 .459 r
F
0 g
.47099 .76229 m
.47305 .76424 L
s
.47099 .76229 m
.47536 .75845 L
s
.76679 .56512 m .77526 .57296 L .77059 .56798 L 0 .063 .172 r
F
.76679 .56512 m .77842 .57787 L .77526 .57296 L F
.55231 .34951 m .54993 .37226 L .54884 .36285 L 0 .362 .147 r
F
.55231 .34951 m .55541 .37531 L .54993 .37226 L F
.55231 .34951 m .56159 .36995 L .55541 .37531 L F
0 g
.55671 .3592 m
.55751 .35439 L
s
.55915 .36458 m
.55986 .36357 L
s
.55231 .34951 m .56502 .35655 L .56159 .36995 L 0 .362 .147 r
F
0 g
.45749 .95418 m
.4595 .95326 L
s
.4595 .95326 m
.46501 .95072 L
s
.47629 .93956 m .45927 .94946 L .46501 .95072 L 0 1 .507 r
F
0 g
.465 .95072 m
.46501 .95072 L
s
.45521 .77394 m .44336 .78069 L .44533 .78264 L 0 1 .49 r
F
0 g
.43997 .78532 m
.44533 .78264 L
s
.33163 .83035 m .31467 .82908 L .31679 .8325 L 0 1 .532 r
F
.33163 .83035 m .31825 .82728 L .31467 .82908 L F
.33163 .83035 m .32553 .82783 L .31825 .82728 L F
.34009 .82538 m .32553 .82783 L .33163 .83035 L 0 1 .53 r
F
0 g
.33163 .83035 m
.33866 .83069 L
s
.33163 .83035 m
.33372 .83376 L
s
.53151 .52924 m .53437 .45813 L .5313 .49064 L 0 1 .229 r
F
0 g
.53386 .46358 m
.53437 .45813 L
s
.53334 .46904 m
.53386 .46358 L
s
.53328 .45772 m
.53437 .45813 L
s
.39404 .90818 m
.40173 .91138 L
s
.43522 .92672 m .43032 .93277 L .43795 .93543 L 0 1 .483 r
F
.43522 .92672 m .42196 .92683 L .43032 .93277 L F
.35528 .84867 m .33829 .84397 L .34087 .84903 L 0 1 .52 r
F
.48343 .49288 m .48667 .47524 L .48497 .47236 L 0 1 .252 r
F
.48343 .49288 m .48601 .48402 L .48667 .47524 L F
0 g
.48667 .47524 m
.48996 .47022 L
s
.45083 .855 m .45312 .86164 L .45452 .8591 L 0 1 .507 r
F
.46701 .86204 m .45452 .8591 L .45312 .86164 L F
0 g
.45312 .86164 m
.45728 .86566 L
s
.44706 .86131 m
.45312 .86164 L
s
.43228 .79067 m .42167 .79276 L .41917 .7954 L 0 1 .506 r
F
.43228 .79067 m .4273 .79074 L .42167 .79276 L F
0 g
.43228 .79067 m
.4344 .79275 L
s
.4382 .78324 m .4273 .79073 L .43229 .79067 L 0 1 .498 r
F
0 g
.43229 .79067 m
.43771 .78835 L
s
.49917 .72195 m .49164 .7336 L .49355 .73504 L 0 1 .407 r
F
0 g
.48998 .73991 m
.49355 .73504 L
s
.43522 .92672 m .41741 .92052 L .42196 .92683 L 0 1 .483 r
F
.42204 .96754 m .40433 .96924 L .40245 .97157 L 0 1 .531 r
F
.42204 .96754 m .41273 .96751 L .40433 .96924 L F
.42603 .96129 m .41273 .96751 L .42204 .96754 L 0 1 .527 r
F
0 g
.42204 .96754 m
.4279 .96948 L
s
.42204 .96754 m
.43011 .96564 L
s
.51462 .56432 m .51556 .56376 L .51671 .54324 L 0 .893 .271 r
F
.3313 .84157 m .33005 .84881 L .33334 .84688 L 0 1 .521 r
F
.3313 .84157 m .32285 .84626 L .33005 .84881 L F
0 g
.33005 .84881 m
.33288 .85396 L
s
.34335 .94748 m .34521 .95084 L .34783 .94873 L 0 1 .435 r
F
0 g
.34783 .94873 m
.35673 .94641 L
s
.34335 .94748 m .33653 .95256 L .34521 .95084 L 0 1 .435 r
F
0 g
.34521 .95084 m
.35045 .95189 L
s
.34683 1.01911 m .35062 1.02574 L .35285 1.02391 L 0 1 .539 r
F
.34683 1.01911 m .34097 1.02358 L .35062 1.02574 L F
0 g
.35062 1.02574 m
.3574 1.03021 L
s
.45083 .855 m .43667 .85423 L .44036 .85833 L 0 1 .507 r
F
0 g
.434 .8579 m
.44036 .85833 L
s
.48202 .94083 m
.48899 .93548 L
s
.30567 .86608 m .28745 .85461 L .29014 .8621 L 0 1 .489 r
F
.43645 1.03552 m .42555 1.03281 L .41627 1.03235 L 0 1 .539 r
F
.43938 1.03002 m .43645 1.03552 L .44541 1.03587 L F
.43938 1.03002 m .42555 1.03281 L .43645 1.03552 L F
0 g
.43645 1.03552 m
.44384 1.0392 L
s
.49828 .55085 m .49507 .51728 L .49335 .52362 L 0 1 .286 r
F
0 g
.49762 .51852 m
.49769 .50766 L
s
.49828 .55085 m .4976 .52165 L .49507 .51728 L 0 1 .286 r
F
0 g
.49507 .51728 m
.49509 .50607 L
s
.51901 .67062 m .51624 .6819 L .51816 .68165 L 0 1 .279 r
F
0 g
.51663 .68725 m
.51816 .68165 L
s
.6304 .44183 m
.63046 .44596 L
s
.63046 .44596 m
.6306 .45697 L
s
.38375 .92807 m .38582 .93093 L .38809 .92852 L 0 1 .397 r
F
0 g
.38809 .92852 m
.3962 .92494 L
s
.38375 .92807 m .37779 .93387 L .38582 .93093 L 0 1 .397 r
F
0 g
.38582 .93093 m
.39082 .93117 L
s
.6304 .44184 m
.63132 .44954 L
s
.63132 .44954 m
.63499 .48018 L
s
.50153 .53971 m .4976 .52165 L .49927 .53384 L 0 1 .281 r
F
.49828 .55085 m .49927 .53384 L .4976 .52165 L 0 1 .286 r
F
0 g
.4976 .52165 m
.49762 .51852 L
s
.49507 .51728 m
.4976 .52165 L
s
.4554 .94141 m .4431 .94142 L .45178 .94703 L 0 .941 .482 r
F
.4554 .94141 m .43795 .93543 L .4431 .94142 L F
0 g
.44309 .94141 m
.4431 .94142 L
s
.30567 .86608 m .29101 .85297 L .28745 .85461 L 0 1 .489 r
F
.30567 .86608 m .29883 .85789 L .29101 .85297 L F
.31408 .86171 m .29883 .85789 L .30567 .86608 L 0 1 .486 r
F
0 g
.30567 .86608 m
.31324 .87087 L
s
.30567 .86608 m
.30833 .87354 L
s
.3223 .98487 m .30554 .9865 L .31553 .98943 L 0 1 .537 r
F
0 g
.31553 .98943 m
.32495 .99021 L
s
.50994 .57034 m .50788 .53657 L .50865 .55652 L 0 .932 .278 r
F
.50763 .57503 m .50865 .55652 L .50788 .53657 L 0 .951 .281 r
F
0 g
.50788 .53657 m
.50835 .51877 L
s
.50627 .52478 m
.50788 .53657 L
s
.49827 .92445 m .48304 .93577 L .48899 .93548 L 0 1 .484 r
F
0 g
.52246 .66762 m
.52247 .66761 L
s
.52247 .66761 m
.52318 .66278 L
s
.725 .96553 m .71566 .96908 L .71077 .97319 L 0 1 .54 r
F
0 g
.70112 .97419 m
.71077 .97319 L
s
.35528 .84867 m .34159 .84202 L .33829 .84397 L 0 1 .52 r
F
0 g
.33334 .84688 m
.34087 .84903 L
s
.35528 .84867 m .34888 .84404 L .34159 .84202 L 0 1 .52 r
F
0 g
.35528 .84867 m
.35784 .85372 L
s
.36475 .84226 m .34888 .84404 L .35528 .84867 L 0 1 .518 r
F
0 g
.35528 .84867 m
.36282 .85018 L
s
.40708 .80336 m .39288 .80639 L .39499 .80871 L 0 1 .516 r
F
.40708 .80336 m .3957 .80407 L .39288 .80639 L F
.40708 .80336 m .40179 .80277 L .3957 .80407 L F
.41357 .79708 m .40179 .80277 L .40708 .80336 L 0 1 .51 r
F
0 g
.40708 .80336 m
.41292 .80187 L
s
.40708 .80336 m
.40918 .80568 L
s
.52479 .8986 m
.52588 .89963 L
s
.52612 .89985 m
.52813 .90175 L
s
.52474 .89855 m
.52479 .8986 L
s
.56303 .48172 m .57031 .46237 L .57331 .48103 L 0 .399 .184 r
F
0 g
.56993 .42497 m
.57031 .46237 L
s
.56518 .52899 m
.56667 .48147 L
s
.56592 .46267 m
.57031 .46237 L
s
.60366 .83791 m
.60372 .84297 L
s
.60389 .85692 m
.60392 .86005 L
s
.60334 .81049 m
.60346 .82056 L
s
.60356 .82939 m
.60366 .83791 L
s
.6025 .73903 m
.60334 .81049 L
s
.60229 .72081 m
.6025 .73903 L
s
.60153 .65659 m
.60159 .66159 L
s
.60162 .66423 m
.60229 .72081 L
s
.60071 .58661 m
.60076 .59103 L
s
.60135 .64106 m
.60139 .6446 L
s
.6015 .65426 m
.60153 .65659 L
s
.48605 .46249 m .48068 .46853 L .4824 .46949 L 0 1 .174 r
F
.48605 .46249 m .48209 .45995 L .48068 .46853 L F
.48605 .46249 m .48569 .44948 L .48209 .45995 L F
.28012 .8493 m .27855 .8587 L .28211 .85707 L 0 1 .49 r
F
0 g
.28211 .85707 m
.29014 .8621 L
s
.28012 .8493 m .27103 .85327 L .27855 .8587 L 0 1 .49 r
F
0 g
.27855 .8587 m
.28147 .86628 L
s
.27119 .84907 m
.27572 .85122 L
s
.27119 .84907 m
.27251 .85262 L
s
.27337 .85496 m
.27345 .85519 L
s
.41584 .91141 m .4097 .91767 L .41741 .92052 L 0 1 .48 r
F
.75448 .5547 m .75891 .55423 L .76359 .55995 L 0 .272 0 r
F
.75448 .5547 m .75502 .55198 L .75891 .55423 L F
0 g
.75513 .55052 m
.75891 .55423 L
s
.60749 .38495 m
.60819 .38738 L
s
.60509 .3766 m
.60749 .38495 L
s
.6049 .37595 m
.60509 .3766 L
s
.60819 .38738 m
.60877 .38939 L
s
.40947 1.02838 m .38774 1.02619 L .39457 1.03017 L 0 1 .539 r
F
0 g
.38495 1.02914 m
.39457 1.03017 L
s
.46041 .76513 m .46005 .7707 L .46201 .76712 L 0 1 .476 r
F
.46041 .76513 m .45521 .77393 L .46005 .7707 L F
0 g
.46005 .7707 m
.46212 .77264 L
s
.28938 .84093 m .28767 .84846 L .29123 .84677 L 0 1 .524 r
F
0 g
.29123 .84677 m
.2991 .84978 L
s
.28938 .84093 m .28027 .84502 L .28767 .84846 L 0 1 .524 r
F
0 g
.28767 .84846 m
.29006 .85341 L
s
.29865 .83236 m .2968 .83795 L .30037 .8362 L 0 1 .535 r
F
0 g
.30037 .8362 m
.30808 .83712 L
s
.29865 .83236 m .28953 .83657 L .2968 .83795 L 0 1 .535 r
F
0 g
.2968 .83795 m
.29938 .84169 L
s
.48815 .73821 m .47921 .74861 L .48106 .75029 L 0 1 .436 r
F
0 g
.4769 .75454 m
.48106 .75029 L
s
.35051 .81918 m .34747 .82516 L .35153 .8226 L 0 1 .526 r
F
0 g
.35153 .8226 m
.35913 .82193 L
s
.35051 .81918 m .34009 .82538 L .34747 .82516 L 0 1 .526 r
F
0 g
.34747 .82516 m
.34929 .82854 L
s
.38691 .80733 m .38584 .8121 L .38865 .80983 L 0 1 .518 r
F
0 g
.38865 .80983 m
.39499 .80871 L
s
.38691 .80733 m .37965 .81285 L .38584 .8121 L 0 1 .518 r
F
0 g
.38584 .8121 m
.3882 .81452 L
s
.36492 .88972 m .34989 .87877 L .34691 .88069 L 0 1 .485 r
F
.36492 .88972 m .35761 .88265 L .34989 .87877 L F
.37176 .88477 m .36492 .88972 L .37237 .89353 L 0 1 .48 r
F
.37176 .88477 m .35761 .88265 L .36492 .88972 L F
0 g
.36492 .88972 m
.36842 .89651 L
s
.34712 .87175 m .34691 .88069 L .34989 .87877 L 0 1 .481 r
F
.34712 .87175 m .33945 .87647 L .34691 .88069 L F
0 g
.34691 .88069 m
.35043 .88749 L
s
.45905 .94554 m .45927 .94946 L .46057 .94599 L 0 1 .514 r
F
.4554 .94141 m .45178 .94703 L .45909 .94954 L 0 .941 .482 r
F
.45909 .94923 m .45909 .94954 L .45927 .94946 L 0 1 .514 r
F
.45909 .94952 m .45909 .94954 L .4591 .94954 L 0 .941 .482 r
F
.4554 .94141 m .45909 .94954 L .45909 .94952 L F
.45538 .94444 m .45173 .95285 L .45909 .94954 L 0 1 .514 r
F
.4554 .94141 m .4591 .94954 L .45909 .94923 L 0 .941 .482 r
F
.45538 .94444 m .45909 .94954 L .45909 .94923 L 0 1 .514 r
F
.45909 .94923 m .45927 .94946 L .45905 .94554 L F
.47629 .93956 m .46057 .94599 L .45927 .94946 L 0 1 .507 r
F
.45891 .9455 m .45926 .9496 L .46056 .94741 L 0 .941 .482 r
F
.4554 .94141 m .45909 .94923 L .45891 .9455 L F
.45891 .9455 m .45909 .94923 L .45905 .94554 L 0 1 .514 r
F
.45909 .94923 m .45926 .9496 L .45891 .9455 L 0 .941 .482 r
F
.45538 .94444 m .45909 .94923 L .45891 .9455 L 0 1 .514 r
F
.45909 .94923 m .4591 .94954 L .45926 .9496 L 0 .941 .482 r
F
0 g
.45909 .94954 m
.4591 .94954 L
s
.45178 .94703 m
.45393 .94776 L
s
.37176 .88477 m .37237 .89353 L .375 .89153 L 0 1 .48 r
F
.39012 .90167 m .375 .89153 L .37237 .89353 L 0 1 .484 r
F
0 g
.37237 .89353 m
.37631 .90004 L
s
.36492 .88972 m
.37237 .89353 L
s
.43938 1.03002 m .44541 1.03587 L .44645 1.03363 L 0 1 .539 r
F
.46602 1.0357 m .44645 1.03363 L .44541 1.03587 L 0 1 .538 r
F
0 g
.44541 1.03587 m
.453 1.03926 L
s
.43645 1.03552 m
.44541 1.03587 L
s
.38719 .84748 m .37135 .84406 L .37418 .84867 L 0 1 .516 r
F
0 g
.37418 .84867 m
.37418 .84867 L
s
.36649 .84755 m
.37418 .84867 L
s
.52648 .49674 m .53196 .43953 L .52833 .45741 L 0 1 .182 r
F
0 g
.53196 .43953 m
.53244 .43666 L
s
.53196 .43953 m
.53215 .43953 L
s
.45173 .95285 m .4338 .95922 L .43959 .96054 L 0 1 .521 r
F
0 g
.43158 .96307 m
.43959 .96054 L
s
.65621 .52812 m
.66002 .48568 L
s
.4884 .50469 m .48601 .48402 L .48343 .49288 L 0 1 .27 r
F
0 g
.48601 .48402 m
.48667 .47524 L
s
.48601 .48402 m
.48921 .48147 L
s
.52118 .66443 m
.52318 .66278 L
s
.79003 .58912 m .79725 .60014 L .80111 .60154 L 0 .217 .206 r
F
0 g
.79725 .60014 m
.79947 .60671 L
s
.48365 .86884 m .47695 .86614 L .47117 .86606 L 0 1 .506 r
F
.41485 .84546 m .41561 .85216 L .41775 .84982 L 0 1 .511 r
F
.41485 .84546 m .40923 .85123 L .41561 .85216 L F
.43055 .85368 m .41775 .84982 L .41561 .85216 L F
0 g
.41561 .85216 m
.41908 .85637 L
s
.41584 .91141 m .39784 .90477 L .40173 .91138 L 0 1 .48 r
F
.36524 .97542 m .36817 .98027 L .37043 .97817 L 0 1 .533 r
F
.36524 .97542 m .35933 .98053 L .36817 .98027 L F
0 g
.36817 .98027 m
.37407 .98277 L
s
.49705 .41127 m .50173 .39942 L .50498 .39359 L 0 0 .025 r
F
0 g
.50173 .39942 m
.50364 .39378 L
s
.51826 .90493 m
.52369 .89929 L
s
.81092 .61661 m .82029 .61921 L .81569 .6157 L 0 .49 .397 r
F
.81092 .61661 m .82236 .62561 L .82029 .61921 L F
0 g
.50756 .8844 m
.50764 .88447 L
s
.50661 .88359 m
.50756 .8844 L
s
.50887 .88551 m
.50957 .88611 L
s
.63674 .75397 m
.63781 .75301 L
s
.40923 .85123 m .39621 .84663 L .39373 .84882 L 0 1 .514 r
F
.40923 .85123 m .40286 .84766 L .39621 .84663 L F
.41485 .84546 m .40286 .84766 L .40923 .85123 L 0 1 .511 r
F
0 g
.40923 .85123 m
.41561 .85216 L
s
.40923 .85123 m
.4124 .85562 L
s
.34683 1.01911 m .33031 1.01886 L .34097 1.02358 L 0 1 .539 r
F
0 g
.34097 1.02358 m
.35062 1.02574 L
s
.33945 .87647 m .32473 .86459 L .32145 .8664 L 0 1 .485 r
F
.33945 .87647 m .33245 .86891 L .32473 .86459 L F
.34712 .87175 m .33245 .86891 L .33945 .87647 L 0 1 .481 r
F
0 g
.33945 .87647 m
.34246 .88355 L
s
.33945 .87647 m
.34691 .88069 L
s
.45521 .77394 m .44562 .77756 L .44336 .78069 L 0 1 .49 r
F
.45521 .77394 m .4507 .77466 L .44562 .77756 L F
0 g
.45521 .77394 m
.45717 .7759 L
s
.46041 .76513 m .4507 .77466 L .45521 .77393 L 0 1 .476 r
F
0 g
.45521 .77393 m
.46005 .7707 L
s
.26296 .83667 m .26641 .83511 L .26264 .83659 L 0 1 .537 r
F
.28043 .84074 m .26655 .83517 L .26296 .83667 L F
.26655 .83517 m .26641 .83511 L .26296 .83667 L F
.28043 .84074 m .27402 .83688 L .26634 .83508 L F
.28953 .83657 m .27402 .83688 L .28043 .84074 L 0 1 .536 r
F
.28953 .83657 m .27207 .83285 L .27402 .83688 L F
.28938 .84093 m .2721 .83287 L .27395 .83871 L 0 1 .524 r
F
.2721 .83287 m .27208 .83288 L .27395 .83871 L F
.26264 .83659 m .26634 .83508 L .26252 .83656 L 0 1 .537 r
F
.26641 .83511 m .26634 .83508 L .26264 .83659 L F
.26336 .83696 m .26634 .83508 L .26252 .83656 L 0 1 .525 r
F
.28027 .84502 m .26675 .83538 L .26336 .83696 L F
.26675 .83538 m .26634 .83508 L .26336 .83696 L F
.28027 .84502 m .27395 .83871 L .26685 .83533 L F
.26675 .83538 m .26685 .83533 L .26634 .83508 L F
.28027 .84502 m .26685 .83533 L .26675 .83538 L F
.2721 .83287 m .27207 .83285 L .27208 .83288 L 0 1 .524 r
F
.27208 .83287 m .27207 .83287 L .27208 .83289 L 0 1 .486 r
F
.27209 .83288 m .27208 .83289 L .27388 .84055 L F
.27208 .83287 m .27208 .83289 L .27209 .83288 L F
.28938 .84093 m .27395 .83871 L .28027 .84502 L 0 1 .524 r
F
.28922 .8453 m .2721 .83288 L .27388 .84055 L 0 1 .486 r
F
.2721 .83288 m .27208 .83287 L .27209 .83288 L F
.2721 .83288 m .27209 .83288 L .27388 .84055 L F
.27208 .83287 m .27207 .83285 L .27207 .83287 L F
.71727 .956 m .70649 .96671 L .71549 .96352 L 0 1 .531 r
F
.71727 .956 m .70373 .96566 L .70649 .96671 L F
0 g
.70222 .96985 m
.70649 .96671 L
s
.71062 .96835 m
.71348 .96552 L
s
.725 .96553 m .72287 .97379 L .73255 .97007 L 0 1 .54 r
F
0 g
.71355 .97513 m
.72287 .97379 L
s
.49705 .41127 m .50498 .39359 L .50465 .39764 L 0 0 .025 r
F
0 g
.50498 .39359 m
.50875 .38061 L
s
.50173 .39942 m
.50498 .39359 L
s
.50828 .39181 m .51345 .38002 L .51742 .37556 L 0 0 .079 r
F
.49311 1.04066 m .48223 1.03875 L .4736 1.0391 L 0 1 .534 r
F
.52139 .66633 m .52082 .6674 L .52093 .67038 L 0 1 .289 r
F
0 g
.52082 .6674 m
.52093 .67038 L
s
.52139 .66633 m
.52246 .66762 L
s
.5006 .87566 m .49379 .87292 L .48824 .87284 L 0 1 .501 r
F
.50538 .58058 m .50287 .53534 L .50153 .53971 L 0 .969 .284 r
F
0 g
.50485 .53647 m
.5049 .52894 L
s
.50538 .58058 m .50479 .54536 L .50287 .53534 L 0 .969 .284 r
F
0 g
.50287 .53534 m
.50295 .52132 L
s
.43938 1.03002 m .41846 1.0292 L .42555 1.03281 L 0 1 .539 r
F
0 g
.41627 1.03235 m
.42555 1.03281 L
s
.52041 1.04585 m .50948 1.04371 L .50113 1.04399 L 0 1 .527 r
F
.3785 1.02476 m .35621 1.02116 L .3627 1.02555 L 0 1 .539 r
F
0 g
.35285 1.02391 m
.3627 1.02555 L
s
.79156 .77258 m .80181 .77781 L .80275 .76962 L 0 1 .491 r
F
.39365 .84209 m .39373 .84882 L .39621 .84663 L 0 1 .514 r
F
.39365 .84209 m .38719 .84748 L .39373 .84882 L F
0 g
.39373 .84882 m
.39691 .85321 L
s
.49644 .97354 m .48737 .96839 L .48011 .96561 L 0 .744 .445 r
F
0 g
.48011 .96561 m
.48737 .96839 L
s
.47389 .96054 m
.48011 .96561 L
s
.39408 .97271 m .37381 .975 L .37941 .97735 L 0 1 .533 r
F
0 g
.37043 .97817 m
.37941 .97735 L
s
.43055 .85368 m .42416 .85047 L .41775 .84982 L 0 1 .511 r
F
.43527 .84753 m .43055 .85368 L .43667 .85423 L 0 1 .507 r
F
.43527 .84753 m .42416 .85047 L .43055 .85368 L F
0 g
.43055 .85368 m
.434 .8579 L
s
.51227 .5667 m .51321 .56558 L .51403 .54629 L 0 .912 .274 r
F
.4884 .50469 m .48308 .50285 L .4852 .50727 L 0 1 .27 r
F
.4884 .50469 m .48343 .49288 L .48308 .50285 L F
.49335 .52362 m .4884 .50469 L .48837 .51592 L 0 1 .281 r
F
.47516 .75268 m .46495 .76166 L .4667 .76351 L 0 1 .459 r
F
0 g
.46201 .76712 m
.4667 .76351 L
s
.5236 .57199 m .52443 .57459 L .52679 .55303 L 0 .831 .262 r
F
0 g
.52575 .56257 m
.52679 .55303 L
s
.5265 .55956 m
.52679 .55303 L
s
.52584 .57448 m
.5265 .55956 L
s
.52291 .56255 m
.52442 .54652 L
s
.39906 .96704 m .40245 .97157 L .40433 .96924 L 0 1 .53 r
F
.39906 .96704 m .39408 .97271 L .40245 .97157 L F
0 g
.40245 .97157 m
.40835 .97351 L
s
.46701 .86204 m .46047 .85927 L .45452 .8591 L 0 1 .507 r
F
.4762 .95573 m .46498 .95522 L .47389 .96054 L 0 .831 .471 r
F
.4762 .95573 m .45926 .9496 L .46498 .95522 L F
0 g
.46496 .9552 m
.46498 .95522 L
s
.45934 .94947 m
.465 .95072 L
s
.32285 .84626 m .30551 .83993 L .30781 .84537 L 0 1 .522 r
F
.32285 .84626 m .30909 .8382 L .30551 .83993 L F
.32285 .84626 m .31653 .84092 L .30909 .8382 L F
.3313 .84157 m .31653 .84092 L .32285 .84626 L 0 1 .521 r
F
0 g
.32285 .84626 m
.33005 .84881 L
s
.32285 .84626 m
.32512 .85168 L
s
.54771 1.05283 m .53773 1.05587 L .54908 1.05858 L 0 1 .512 r
F
.54771 1.05283 m .52905 1.05193 L .53773 1.05587 L F
0 g
.52942 1.05561 m
.53773 1.05587 L
s
.50828 .39181 m .51742 .37556 L .51758 .38137 L 0 0 .079 r
F
0 g
.51742 .37556 m
.52114 .36142 L
s
.51345 .38002 m
.51742 .37556 L
s
.52041 1.04585 m .52905 1.05193 L .52881 1.04938 L 0 1 .527 r
F
.54771 1.05283 m .52881 1.04938 L .52905 1.05193 L 0 1 .512 r
F
0 g
.52905 1.05193 m
.53773 1.05587 L
s
.5207 1.05221 m
.52905 1.05193 L
s
.50806 .70442 m .50271 .71267 L .50205 .71693 L 0 1 .373 r
F
.50806 .70442 m .50529 .7073 L .50271 .71267 L F
.50891 .69439 m .50806 .70442 L .51029 .69927 L 0 1 .327 r
F
.50891 .69439 m .50529 .7073 L .50806 .70442 L F
0 g
.50806 .70442 m
.50999 .70552 L
s
.24736 .84246 m
.24754 .84251 L
s
.24754 .84251 m
.24787 .8426 L
s
.50115 .71136 m .50205 .71693 L .50271 .71267 L 0 1 .372 r
F
.50115 .71136 m .49917 .72195 L .50205 .71693 L F
0 g
.50205 .71693 m
.50399 .71801 L
s
.53325 .62063 m
.53327 .62055 L
s
.53327 .62055 m
.53334 .62031 L
s
.53334 .62031 m
.53335 .62028 L
s
.5335 .61978 m
.53377 .61889 L
s
.53335 .62028 m
.5335 .61978 L
s
.50891 .69439 m .51029 .69927 L .51049 .69527 L 0 1 .327 r
F
.5147 .6867 m .51049 .69527 L .51029 .69927 L 0 1 .331 r
F
0 g
.51029 .69927 m
.51223 .69981 L
s
.50806 .70442 m
.51029 .69927 L
s
.48343 .49288 m .48497 .47236 L .48143 .47725 L 0 1 .252 r
F
0 g
.48497 .47236 m
.48605 .46249 L
s
.41584 .91141 m .41741 .92052 L .41972 .91802 L 0 1 .48 r
F
.43522 .92672 m .41972 .91802 L .41741 .92052 L 0 1 .483 r
F
0 g
.4097 .91767 m
.41741 .92052 L
s
.41741 .92052 m
.42196 .92683 L
s
.43522 .92672 m .43795 .93543 L .43976 .93304 L 0 1 .483 r
F
.4554 .94141 m .43976 .93304 L .43795 .93543 L 0 .941 .482 r
F
0 g
.43795 .93543 m
.44309 .94141 L
s
.43032 .93277 m
.43795 .93543 L
s
.43527 .84753 m .43667 .85423 L .43845 .85174 L 0 1 .507 r
F
.45083 .855 m .43845 .85174 L .43667 .85423 L F
0 g
.43667 .85423 m
.44036 .85833 L
s
.43055 .85368 m
.43667 .85423 L
s
.48831 .43448 m .49246 .42315 L .49496 .41633 L 0 .743 .069 r
F
0 g
.49246 .42315 m
.49427 .41822 L
s
.49246 .42315 m
.49415 .41903 L
s
.48831 .43448 m .49496 .41633 L .49414 .41853 L 0 .743 .069 r
F
.49917 .72195 m .49275 .72939 L .49164 .7336 L 0 1 .407 r
F
.49917 .72195 m .49598 .72439 L .49275 .72939 L F
.50115 .71136 m .49598 .72439 L .49917 .72195 L 0 1 .372 r
F
0 g
.49917 .72195 m
.50107 .7234 L
s
.49917 .72195 m
.50205 .71693 L
s
.38719 .84748 m .37415 .84203 L .37135 .84406 L 0 1 .516 r
F
.38719 .84748 m .38095 .84349 L .37415 .84203 L F
.39365 .84209 m .38095 .84349 L .38719 .84748 L 0 1 .514 r
F
0 g
.38719 .84748 m
.39001 .85208 L
s
.38719 .84748 m
.39373 .84882 L
s
.52083 .98667 m
.52209 .98715 L
s
.52517 .98832 m
.52522 .98834 L
s
.5796 .35831 m
.58499 .35966 L
s
.39012 .90167 m .38261 .89502 L .375 .89153 L 0 1 .484 r
F
0 g
.39012 .90167 m
.39404 .90818 L
s
.39744 .89539 m .39012 .90167 L .39784 .90477 L 0 1 .477 r
F
.39744 .89539 m .38262 .89502 L .39012 .90167 L F
.72476 .95821 m .73222 .96062 L .73713 .95578 L 0 1 .534 r
F
.79156 .77258 m .80275 .76962 L .79859 .76756 L 0 1 .491 r
F
.78131 .76715 m .79156 .77258 L .79234 .76441 L 0 1 .487 r
F
.37176 .88477 m .35435 .87588 L .35761 .88265 L 0 1 .48 r
F
0 g
.34989 .87877 m
.35761 .88265 L
s
.49903 .91729 m .50447 .91956 L .50465 .91664 L 0 1 .476 r
F
.49903 .91729 m .49827 .92445 L .50447 .91956 L F
0 g
.50447 .91956 m
.51043 .91761 L
s
.35933 .98053 m .33799 .98075 L .3435 .98366 L 0 1 .535 r
F
0 g
.52279 .89421 m
.52362 .89488 L
s
.5259 .89509 m
.52616 .89511 L
s
.52419 .89493 m
.52445 .89495 L
s
.52362 .89488 m
.52419 .89493 L
s
.52118 .66443 m
.52139 .66633 L
s
.29931 .96139 m .30082 .96523 L .30377 .96341 L 0 1 .459 r
F
0 g
.30377 .96341 m
.31328 .9623 L
s
.29931 .96139 m .29169 .96575 L .30082 .96523 L 0 1 .459 r
F
0 g
.30082 .96523 m
.30617 .96705 L
s
.49125 .7278 m .49164 .7336 L .49275 .72939 L 0 1 .407 r
F
.49125 .7278 m .48815 .73821 L .49164 .7336 L F
0 g
.49164 .7336 m
.49355 .73504 L
s
.32908 .98029 m .33146 .98549 L .33407 .98359 L 0 1 .535 r
F
0 g
.33407 .98359 m
.3435 .98366 L
s
.32908 .98029 m .3223 .98487 L .33146 .98549 L 0 1 .535 r
F
0 g
.33146 .98549 m
.33726 .98853 L
s
.27103 .85327 m .25679 .83878 L .25298 .84024 L 0 1 .492 r
F
0 g
.24787 .8426 m
.25412 .84429 L
s
.27103 .85327 m .26454 .84437 L .25679 .83878 L 0 1 .492 r
F
.28012 .8493 m .26454 .84437 L .27103 .85327 L 0 1 .49 r
F
0 g
.27103 .85327 m
.27323 .86115 L
s
.27103 .85327 m
.27855 .8587 L
s
.5147 .6867 m .51238 .68988 L .51049 .69527 L 0 1 .331 r
F
.51439 .67846 m .5147 .6867 L .51624 .6819 L 0 1 .27 r
F
.51439 .67846 m .51238 .68988 L .5147 .6867 L F
0 g
.5147 .6867 m
.51663 .68725 L
s
.53286 .62187 m
.53356 .61972 L
s
.53308 .62118 m
.53373 .61919 L
s
.42008 .79064 m .41917 .7954 L .42167 .79276 L 0 1 .503 r
F
.42008 .79064 m .41357 .79708 L .41917 .7954 L F
0 g
.41917 .7954 m
.4213 .79747 L
s
.49644 .97354 m .50291 .97888 L .5031 .97804 L 0 .744 .445 r
F
0 g
.50291 .97888 m
.50994 .98236 L
s
.49564 .97609 m
.50291 .97888 L
s
.37965 .81285 m .36466 .81417 L .36666 .8168 L 0 1 .522 r
F
.37965 .81285 m .36777 .81215 L .36466 .81417 L F
.37965 .81285 m .3742 .81158 L .36777 .81215 L F
.38691 .80733 m .3742 .81158 L .37965 .81285 L 0 1 .518 r
F
0 g
.37965 .81285 m
.38584 .8121 L
s
.37965 .81285 m
.38163 .81547 L
s
.32252 .8573 m .32145 .8664 L .32473 .86459 L 0 1 .482 r
F
.32252 .8573 m .31408 .86171 L .32145 .8664 L F
0 g
.32145 .8664 m
.32448 .87349 L
s
.48815 .73821 m .48075 .74461 L .47921 .74861 L 0 1 .436 r
F
.48815 .73821 m .48459 .74016 L .48075 .74461 L F
.49125 .7278 m .48459 .74016 L .48815 .73821 L 0 1 .407 r
F
0 g
.48815 .73821 m
.48998 .73991 L
s
.48815 .73821 m
.49164 .7336 L
s
.48545 .86183 m .47695 .86614 L .48365 .86884 L 0 1 .5 r
F
.48545 .86183 m .47267 .86207 L .47695 .86614 L F
0 g
.47117 .86606 m
.47695 .86614 L
s
.375 .89153 m
.38261 .89502 L
s
.49827 .92445 m .48363 .93291 L .48304 .93577 L 0 1 .484 r
F
.49827 .92445 m .49016 .92806 L .48363 .93291 L F
.49903 .91729 m .49016 .92806 L .49827 .92445 L 0 1 .476 r
F
0 g
.49827 .92445 m
.5042 .92417 L
s
.49827 .92445 m
.50447 .91956 L
s
.52326 .89039 m
.52326 .89039 L
s
.49335 .52362 m .48837 .51592 L .49048 .52304 L 0 1 .281 r
F
.49828 .55085 m .49335 .52362 L .49363 .53613 L 0 1 .286 r
F
0 g
.73957 .78738 m
.74449 .78708 L
s
.73957 .78738 m
.7404 .7822 L
s
.69442 .96914 m .70659 .97025 L .70381 .96827 L 0 1 .539 r
F
.46982 .85526 m .46701 .86204 L .47267 .86207 L 0 1 .502 r
F
.46982 .85526 m .46047 .85927 L .46701 .86204 L F
0 g
.46701 .86204 m
.47117 .86606 L
s
.44414 .77556 m .44336 .78069 L .44562 .77756 L 0 1 .487 r
F
.44414 .77556 m .4382 .78324 L .44336 .78069 L F
0 g
.44336 .78069 m
.44533 .78264 L
s
.37779 .93387 m .35835 .94026 L .36302 .94091 L 0 1 .425 r
F
.37779 .93387 m .36098 .93814 L .35835 .94026 L F
.37779 .93387 m .36933 .9354 L .36098 .93814 L F
.38375 .92807 m .36933 .9354 L .37779 .93387 L 0 1 .397 r
F
0 g
.37779 .93387 m
.38582 .93093 L
s
.37779 .93387 m
.38242 .93453 L
s
.49828 .55085 m .49956 .54636 L .49927 .53384 L 0 1 .286 r
F
0 g
.42167 .79276 m
.4273 .79074 L
s
.4382 .78324 m .42552 .78866 L .4273 .79073 L 0 1 .498 r
F
.35933 .98053 m .34061 .97886 L .33799 .98075 L 0 1 .535 r
F
.35933 .98053 m .34977 .97876 L .34061 .97886 L F
.36524 .97542 m .34977 .97876 L .35933 .98053 L 0 1 .533 r
F
0 g
.35933 .98053 m
.36817 .98027 L
s
.35933 .98053 m
.3648 .98343 L
s
.54975 .56184 m
.55075 .55712 L
s
.55075 .55712 m
.55201 .55123 L
s
.51986 .66695 m
.52082 .6674 L
s
.52512 .64823 m
.52559 .64736 L
s
.48545 .86183 m .48365 .86884 L .48913 .86874 L 0 1 .5 r
F
0 g
.48365 .86884 m
.48824 .87284 L
s
.24762 .84261 m
.24779 .84269 L
s
.24779 .84269 m
.25462 .84606 L
s
.58455 .36126 m
.58523 .35878 L
s
.57782 .48209 m .58078 .46481 L .58572 .48114 L 0 .721 .193 r
F
0 g
.58078 .46481 m
.58088 .46515 L
s
.58088 .46515 m
.58572 .48114 L
s
.58488 .43405 m
.58572 .48114 L
s
.5807 .45878 m
.58078 .46481 L
s
.51439 .67846 m .51624 .6819 L .51598 .67868 L 0 1 .27 r
F
.51901 .67062 m .51598 .67868 L .51624 .6819 L 0 1 .279 r
F
0 g
.51624 .6819 m
.51816 .68165 L
s
.5147 .6867 m
.51624 .6819 L
s
.78131 .76715 m .79234 .76441 L .78817 .76227 L 0 1 .487 r
F
.77104 .7615 m .78131 .76715 L .78192 .75898 L 0 1 .482 r
F
.71727 .956 m .71549 .96352 L .72476 .95821 L 0 1 .531 r
F
0 g
.70649 .96671 m
.71549 .96352 L
s
.71348 .96552 m
.71549 .96352 L
s
.4762 .95573 m .47389 .96054 L .48115 .96318 L 0 .831 .471 r
F
.71743 .9609 m .70659 .97025 L .71566 .96908 L 0 1 .539 r
F
.71743 .9609 m .70381 .96827 L .70659 .97025 L F
0 g
.70112 .97419 m
.70659 .97025 L
s
.77901 .82286 m .78882 .83043 L .79088 .82452 L 0 1 .493 r
F
.41485 .84546 m .39995 .8433 L .40286 .84766 L 0 1 .511 r
F
0 g
.39621 .84663 m
.40286 .84766 L
s
.52648 .49674 m .52968 .48204 L .53285 .45756 L 0 1 .182 r
F
0 g
.53074 .47384 m
.53285 .45756 L
s
.53285 .45756 m
.53328 .45772 L
s
.34009 .82538 m .32363 .82456 L .32553 .82783 L 0 1 .53 r
F
.34009 .82538 m .32722 .82274 L .32363 .82456 L F
.34009 .82538 m .33428 .82309 L .32722 .82274 L F
0 g
.34009 .82538 m
.34196 .82863 L
s
.35051 .81918 m .33428 .82309 L .34009 .82538 L 0 1 .526 r
F
0 g
.34009 .82538 m
.34747 .82516 L
s
.43527 .84753 m .42097 .84626 L .42416 .85047 L 0 1 .507 r
F
0 g
.41775 .84982 m
.42416 .85047 L
s
.39408 .97271 m .37607 .97289 L .37381 .975 L 0 1 .533 r
F
.39408 .97271 m .38477 .97191 L .37607 .97289 L F
.39906 .96704 m .38477 .97191 L .39408 .97271 L 0 1 .53 r
F
0 g
.39408 .97271 m
.39964 .97506 L
s
.39408 .97271 m
.40245 .97157 L
s
.61865 .40602 m
.61869 .40572 L
s
.46982 .85526 m .45661 .8552 L .46047 .85927 L 0 1 .502 r
F
0 g
.45452 .8591 m
.46047 .85927 L
s
.42603 .96129 m .40715 .96574 L .41273 .96751 L 0 1 .527 r
F
0 g
.40433 .96924 m
.41273 .96751 L
s
.46602 1.0357 m .45529 1.03356 L .44645 1.03363 L 0 1 .538 r
F
.33653 .95256 m .3156 .95608 L .3204 .95752 L 0 1 .454 r
F
.33653 .95256 m .31857 .95425 L .3156 .95608 L F
.33653 .95256 m .32755 .95274 L .31857 .95425 L F
.34335 .94748 m .32755 .95274 L .33653 .95256 L 0 1 .435 r
F
0 g
.33653 .95256 m
.34521 .95084 L
s
.33653 .95256 m
.34128 .954 L
s
.52362 .8968 m
.52434 .89591 L
s
.5259 .89399 m
.52604 .89381 L
s
.52327 .89353 m
.52434 .89291 L
s
.52188 .37752 m .52746 .36658 L .5321 .36427 L 0 .137 .104 r
F
0 g
.52746 .36658 m
.53114 .35247 L
s
.47934 .74284 m .47921 .74861 L .48075 .74461 L 0 1 .435 r
F
.47934 .74284 m .47516 .75268 L .47921 .74861 L F
0 g
.47921 .74861 m
.48106 .75029 L
s
.49391 1.03416 m .48223 1.03875 L .49311 1.04066 L 0 1 .534 r
F
.49391 1.03416 m .47454 1.03548 L .48223 1.03875 L F
0 g
.4736 1.0391 m
.48223 1.03875 L
s
.6306 .45697 m
.63074 .45905 L
s
.63074 .45905 m
.63109 .46436 L
s
.6328 .4902 m
.63299 .49311 L
s
.63109 .46436 m
.6328 .4902 L
s
.63299 .49311 m
.63347 .50042 L
s
.63347 .50042 m
.63406 .50935 L
s
.63767 .56401 m
.63771 .56459 L
s
.63766 .56377 m
.63767 .56401 L
s
.63693 .55272 m
.63766 .56377 L
s
.63646 .54565 m
.63693 .55272 L
s
.63616 .54117 m
.63646 .54565 L
s
.63406 .50935 m
.63411 .51009 L
s
.6359 .53725 m
.63592 .53753 L
s
.63601 .53883 m
.63616 .54117 L
s
.63567 .53376 m
.63574 .53478 L
s
.49391 1.03416 m .49311 1.04066 L .50142 1.0401 L 0 1 .534 r
F
0 g
.49311 1.04066 m
.50113 1.04399 L
s
.39744 .89539 m .37942 .88816 L .38262 .89502 L 0 1 .477 r
F
0 g
.51799 .89889 m
.5232 .89695 L
s
.52356 .89682 m
.52362 .8968 L
s
.39744 .89539 m .39784 .90477 L .40063 .90225 L 0 1 .477 r
F
.41584 .91141 m .40063 .90225 L .39784 .90477 L 0 1 .48 r
F
0 g
.39784 .90477 m
.40173 .91138 L
s
.39012 .90167 m
.39784 .90477 L
s
.28027 .84502 m
.28233 .85099 L
s
.28027 .84502 m
.28767 .84846 L
s
.5313 .62685 m
.53136 .62669 L
s
.53221 .62432 m
.53237 .62385 L
s
.53342 .62092 m
.53354 .62058 L
s
.53182 .6252 m
.53189 .625 L
s
.53249 .6234 m
.53266 .62293 L
s
.53348 .62071 m
.53355 .62054 L
s
.50538 .58058 m .50153 .53971 L .50178 .55476 L 0 .969 .284 r
F
0 g
.49927 .53384 m
.50153 .53971 L
s
.31408 .86171 m .29636 .85049 L .29883 .85789 L 0 1 .486 r
F
.47807 .93261 m .48304 .93577 L .48363 .93291 L 0 1 .5 r
F
.47807 .93261 m .47629 .93956 L .48304 .93577 L F
0 g
.48304 .93577 m
.48899 .93548 L
s
.50249 .87723 m
.50281 .8775 L
s
.77901 .82286 m .79088 .82452 L .78687 .82153 L 0 1 .493 r
F
.76919 .81483 m .77901 .82286 L .78087 .8169 L 0 1 .487 r
F
.34712 .87175 m .32967 .86188 L .33245 .86891 L 0 1 .481 r
F
0 g
.32473 .86459 m
.33245 .86891 L
s
.77104 .7615 m .78192 .75898 L .77774 .75674 L 0 1 .482 r
F
.76076 .7556 m .77104 .7615 L .77148 .7533 L 0 1 .477 r
F
.4762 .95573 m .46056 .94741 L .45926 .9496 L 0 .831 .471 r
F
0 g
.4591 .94954 m
.45926 .9496 L
s
.45926 .9496 m
.46496 .9552 L
s
.45173 .95285 m .43527 .95665 L .4338 .95922 L 0 1 .521 r
F
.45173 .95285 m .44297 .95392 L .43527 .95665 L F
0 g
.45173 .95285 m
.45749 .95418 L
s
.45538 .94444 m .44297 .95392 L .45173 .95285 L 0 1 .514 r
F
0 g
.45173 .95285 m
.45909 .94954 L
s
.71727 .956 m .70834 .96107 L .70373 .96566 L 0 1 .531 r
F
0 g
.69684 .96734 m
.70373 .96566 L
s
.33977 .83683 m .33829 .84397 L .34159 .84202 L 0 1 .52 r
F
.33977 .83683 m .3313 .84157 L .33829 .84397 L F
0 g
.33829 .84397 m
.34087 .84903 L
s
.52108 .9869 m
.52295 .98778 L
s
.5667 .36487 m .56529 .38597 L .56376 .37974 L 0 .285 .141 r
F
.5667 .36487 m .57085 .38313 L .56529 .38597 L F
0 g
.5667 .36486 m
.5667 .36486 L
s
.36475 .84226 m .34711 .83874 L .34888 .84404 L 0 1 .518 r
F
0 g
.34888 .84404 m
.34888 .84404 L
s
.34159 .84202 m
.34888 .84404 L
s
.34888 .84404 m
.34888 .84404 L
s
.28922 .8453 m .28745 .85461 L .29101 .85297 L 0 1 .486 r
F
.28922 .8453 m .28012 .8493 L .28745 .85461 L F
0 g
.28745 .85461 m
.29014 .8621 L
s
.30778 .82811 m .30572 .83354 L .3093 .83176 L 0 1 .533 r
F
0 g
.3093 .83176 m
.31679 .8325 L
s
.30778 .82811 m .29865 .83236 L .30572 .83354 L 0 1 .533 r
F
0 g
.30572 .83354 m
.30808 .83712 L
s
.44562 .77756 m
.4507 .77466 L
s
.46041 .76513 m .44909 .77268 L .4507 .77466 L 0 1 .476 r
F
.50137 .86827 m .49379 .87292 L .5006 .87566 L 0 1 .495 r
F
0 g
.5006 .87566 m
.50249 .87723 L
s
.50137 .86827 m .48913 .86874 L .49379 .87292 L 0 1 .495 r
F
0 g
.48824 .87284 m
.49379 .87292 L
s
.47516 .75268 m .46691 .75796 L .46495 .76166 L 0 1 .459 r
F
.47516 .75268 m .47129 .75411 L .46691 .75796 L F
.47934 .74284 m .47129 .75411 L .47516 .75268 L 0 1 .435 r
F
0 g
.47516 .75268 m
.4769 .75454 L
s
.47516 .75268 m
.47921 .74861 L
s
.50891 .69439 m .5037 .70644 L .50529 .7073 L 0 1 .327 r
F
0 g
.50271 .71267 m
.50529 .7073 L
s
.2985 .83681 m .29658 .84421 L .30015 .8425 L 0 1 .523 r
F
0 g
.30015 .8425 m
.30781 .84537 L
s
.2985 .83681 m .28938 .84093 L .29658 .84421 L 0 1 .523 r
F
0 g
.29658 .84421 m
.2991 .84978 L
s
.75934 .80628 m .77084 .8088 L .76682 .8054 L 0 .979 .479 r
F
.75934 .80628 m .76919 .81483 L .77084 .8088 L F
.76919 .81483 m .78087 .8169 L .77686 .81372 L 0 1 .487 r
F
.75448 .5547 m .76359 .55995 L .76668 .56568 L 0 .272 0 r
F
0 g
.76359 .55995 m
.76679 .56512 L
s
.4679 1.02972 m .46602 1.0357 L .47454 1.03548 L 0 1 .538 r
F
.4679 1.02972 m .45529 1.03356 L .46602 1.0357 L F
0 g
.46602 1.0357 m
.4736 1.0391 L
s
.4382 .78324 m .42815 .78582 L .42552 .78866 L 0 1 .498 r
F
.4382 .78324 m .43358 .7835 L .42815 .78582 L F
.44414 .77556 m .43358 .7835 L .4382 .78324 L 0 1 .487 r
F
0 g
.4382 .78324 m
.44336 .78069 L
s
.4382 .78324 m
.43997 .78532 L
s
.24745 .84257 m
.25521 .84815 L
s
.25304 .84046 m
.25521 .84815 L
s
.25299 .84027 m
.25304 .84046 L
s
.25299 .84026 m
.25299 .84027 L
s
.31408 .86171 m .29994 .84883 L .29636 .85049 L 0 1 .486 r
F
0 g
.29101 .85297 m
.29883 .85789 L
s
.31408 .86171 m .30753 .85364 L .29994 .84883 L 0 1 .486 r
F
.32252 .8573 m .30753 .85364 L .31408 .86171 L 0 1 .482 r
F
0 g
.31408 .86171 m
.32145 .8664 L
s
.31408 .86171 m
.31652 .86909 L
s
.47629 .93956 m .46787 .94175 L .46057 .94599 L 0 1 .507 r
F
0 g
.47629 .93956 m
.48202 .94083 L
s
.47807 .93261 m .46787 .94175 L .47629 .93956 L 0 1 .5 r
F
0 g
.47629 .93956 m
.48304 .93577 L
s
.48209 .45995 m .48742 .44205 L .48614 .44259 L 0 1 .144 r
F
.48209 .45995 m .48569 .44948 L .48742 .44205 L F
0 g
.48569 .44948 m
.48713 .44672 L
s
.48742 .44205 m
.49114 .43296 L
s
.48569 .44948 m
.48742 .44205 L
s
.41357 .79708 m .39993 .80055 L .40179 .80277 L 0 1 .51 r
F
.38344 1.01994 m .38774 1.02619 L .3896 1.02423 L 0 1 .539 r
F
0 g
.38426 1.02867 m
.38495 1.02914 L
s
.38344 1.01994 m .3785 1.02476 L .38774 1.02619 L 0 1 .539 r
F
.40947 1.02838 m .3896 1.02423 L .38774 1.02619 L F
0 g
.38774 1.02619 m
.39457 1.03017 L
s
.50115 .71136 m .49441 .7231 L .49598 .72439 L 0 1 .372 r
F
0 g
.49275 .72939 m
.49598 .72439 L
s
.50465 .91664 m
.51057 .91036 L
s
.68929 .52783 m .69945 .50088 L .70146 .52387 L 0 .631 .154 r
F
0 g
.69945 .50088 m
.70349 .49786 L
s
.76076 .7556 m .77148 .7533 L .7673 .75096 L 0 1 .477 r
F
.41357 .79708 m .40276 .79817 L .39993 .80055 L 0 1 .51 r
F
.41357 .79708 m .40861 .79669 L .40276 .79817 L F
.42008 .79064 m .40861 .79669 L .41357 .79708 L 0 1 .503 r
F
0 g
.41357 .79708 m
.41917 .7954 L
s
.41357 .79708 m
.41542 .7993 L
s
.37198 .83728 m .37135 .84406 L .37415 .84203 L 0 1 .516 r
F
.37198 .83728 m .36475 .84226 L .37135 .84406 L F
0 g
.37135 .84406 m
.37418 .84867 L
s
.45083 .855 m .44452 .85207 L .43845 .85174 L 0 1 .507 r
F
.45462 .84841 m .45083 .855 L .45661 .8552 L 0 1 .503 r
F
.45462 .84841 m .44452 .85207 L .45083 .855 L F
0 g
.45083 .855 m
.45452 .8591 L
s
.68108 .96301 m .67844 .96917 L .68775 .96534 L 0 1 .518 r
F
0 g
.67713 .96947 m
.67844 .96917 L
s
.67718 .97009 m
.67844 .96917 L
s
.80163 .59909 m .80417 .60627 L .80878 .61015 L 0 .286 .225 r
F
.80163 .59909 m .80111 .60154 L .80417 .60627 L F
0 g
.79947 .60671 m
.80417 .60627 L
s
.77842 .57787 m .78955 .59112 L .79003 .58912 L 0 .142 .189 r
F
0 g
.78955 .59112 m
.79264 .59583 L
s
.78571 .589 m
.78955 .59112 L
s
.46982 .85526 m .47267 .86207 L .47367 .85933 L 0 1 .502 r
F
.48545 .86183 m .47367 .85933 L .47267 .86207 L 0 1 .5 r
F
0 g
.47267 .86207 m
.47695 .86614 L
s
.46701 .86204 m
.47267 .86207 L
s
.50994 .57034 m .51087 .56874 L .51133 .55082 L 0 .932 .278 r
F
0 g
.54908 1.05858 m
.55139 1.05949 L
s
.39418 .80169 m .39288 .80639 L .3957 .80407 L 0 1 .512 r
F
0 g
.3957 .80407 m
.40179 .80277 L
s
.39418 .80169 m .38691 .80733 L .39288 .80639 L 0 1 .512 r
F
0 g
.39288 .80639 m
.39499 .80871 L
s
.51439 .67846 m .51079 .68967 L .51238 .68988 L 0 1 .27 r
F
0 g
.51049 .69527 m
.51238 .68988 L
s
.52013 1.03889 m .50948 1.04371 L .52041 1.04585 L 0 1 .524 r
F
.52013 1.03889 m .50142 1.0401 L .50948 1.04371 L F
0 g
.50113 1.04399 m
.50948 1.04371 L
s
.50763 .57503 m .50479 .54536 L .50602 .56315 L 0 .951 .281 r
F
.50538 .58058 m .50602 .56315 L .50479 .54536 L 0 .969 .284 r
F
0 g
.50287 .53534 m
.50479 .54536 L
s
.50479 .54536 m
.50485 .53647 L
s
.27251 .83295 m .27596 .83139 L .27219 .83288 L 0 1 .536 r
F
.28953 .83657 m .27611 .83144 L .27251 .83295 L F
.27611 .83144 m .27596 .83139 L .27251 .83295 L F
.28953 .83657 m .28339 .83296 L .27589 .83136 L F
.29865 .83236 m .28339 .83296 L .28953 .83657 L 0 1 .535 r
F
.29865 .83236 m .28164 .82911 L .28339 .83296 L F
.2985 .83681 m .28167 .82913 L .28332 .83483 L 0 1 .523 r
F
.28167 .82913 m .28164 .82914 L .28332 .83483 L F
.27219 .83288 m .27589 .83136 L .27207 .83285 L 0 1 .536 r
F
.27596 .83139 m .27589 .83136 L .27219 .83288 L F
.2729 .83325 m .27589 .83136 L .27207 .83285 L 0 1 .524 r
F
.28938 .84093 m .2763 .83165 L .2729 .83325 L F
.2763 .83165 m .27589 .83136 L .2729 .83325 L F
.28938 .84093 m .28332 .83483 L .27641 .8316 L F
.2763 .83165 m .27641 .8316 L .27589 .83136 L F
.28938 .84093 m .27641 .8316 L .2763 .83165 L F
.28167 .82913 m .28164 .82911 L .28164 .82914 L 0 1 .523 r
F
.28165 .82912 m .28164 .82913 L .28164 .82915 L 0 1 .483 r
F
.28166 .82914 m .28164 .82915 L .28325 .8367 L F
.28165 .82912 m .28164 .82915 L .28166 .82914 L F
.2985 .83681 m .28332 .83483 L .28938 .84093 L 0 1 .523 r
F
.29834 .84126 m .28167 .82914 L .28325 .8367 L 0 1 .483 r
F
.28167 .82914 m .28165 .82912 L .28166 .82914 L F
.28167 .82914 m .28166 .82914 L .28325 .8367 L F
.28165 .82912 m .28164 .82911 L .28164 .82913 L F
0 g
.52224 .65653 m
.52281 .65607 L
s
.52315 .65579 m
.52341 .65558 L
s
.52213 .65662 m
.52224 .65653 L
s
.52206 .65668 m
.52213 .65662 L
s
.52407 .65348 m
.52407 .65345 L
s
.52407 .65299 m
.52407 .65212 L
s
.40947 1.02838 m .39892 1.02516 L .3896 1.02423 L 0 1 .539 r
F
.41343 1.02321 m .40947 1.02838 L .41846 1.0292 L F
.41343 1.02321 m .39892 1.02516 L .40947 1.02838 L F
0 g
.40947 1.02838 m
.41627 1.03235 L
s
.54908 1.05858 m
.55153 1.0587 L
s
.3785 1.02476 m .35845 1.01933 L .35621 1.02116 L 0 1 .539 r
F
.3785 1.02476 m .36801 1.02087 L .35845 1.01933 L F
.38344 1.01994 m .36801 1.02087 L .3785 1.02476 L F
0 g
.3785 1.02476 m
.38774 1.02619 L
s
.3785 1.02476 m
.38426 1.02867 L
s
.51901 .67062 m .51717 .67384 L .51598 .67868 L 0 1 .279 r
F
0 g
.51901 .67062 m
.52093 .67038 L
s
.51964 .6679 m
.51986 .66695 L
s
.51901 .67062 m
.51964 .6679 L
s
.48921 .53919 m .48837 .51592 L .48526 .51615 L 0 1 .288 r
F
.48921 .53919 m .49048 .52304 L .48837 .51592 L F
0 g
.48837 .51592 m
.4884 .50469 L
s
.54771 1.05283 m .5368 1.04976 L .52881 1.04938 L 0 1 .512 r
F
.41343 1.02321 m .41846 1.0292 L .41993 1.0271 L 0 1 .539 r
F
.43938 1.03002 m .41993 1.0271 L .41846 1.0292 L F
0 g
.41846 1.0292 m
.42555 1.03281 L
s
.40947 1.02838 m
.41846 1.0292 L
s
.5006 .87566 m
.50458 .87551 L
s
.4679 1.02972 m .44802 1.03025 L .45529 1.03356 L 0 1 .538 r
F
0 g
.44645 1.03363 m
.45529 1.03356 L
s
.35847 .81437 m .3569 .81918 L .36001 .81719 L 0 1 .523 r
F
0 g
.36001 .81719 m
.36666 .8168 L
s
.35847 .81437 m .35051 .81918 L .3569 .81918 L 0 1 .523 r
F
0 g
.3569 .81918 m
.35913 .82193 L
s
.48343 .49288 m .47774 .49549 L .47988 .4978 L 0 1 .252 r
F
.48343 .49288 m .47841 .48668 L .47774 .49549 L F
.48343 .49288 m .48143 .47725 L .47841 .48668 L F
.48921 .53919 m .49084 .53301 L .49048 .52304 L 0 1 .288 r
F
0 g
.49048 .52304 m
.49335 .52362 L
s
.43003 .95505 m .4338 .95922 L .43527 .95665 L 0 1 .523 r
F
.43003 .95505 m .42603 .96129 L .4338 .95922 L F
0 g
.4338 .95922 m
.43959 .96054 L
s
.48545 .86183 m .48913 .86874 L .48973 .86591 L 0 1 .5 r
F
.50137 .86827 m .48973 .86591 L .48913 .86874 L 0 1 .495 r
F
0 g
.48913 .86874 m
.49379 .87292 L
s
.48365 .86884 m
.48913 .86874 L
s
.35018 .94239 m .35177 .94556 L .3544 .94344 L 0 1 .412 r
F
0 g
.3544 .94344 m
.36302 .94091 L
s
.35018 .94239 m .34335 .94748 L .35177 .94556 L 0 1 .412 r
F
0 g
.35177 .94556 m
.35673 .94641 L
s
.46562 .75605 m .46495 .76166 L .46691 .75796 L 0 1 .456 r
F
.46562 .75605 m .46041 .76513 L .46495 .76166 L F
0 g
.46495 .76166 m
.4667 .76351 L
s
.49125 .7278 m .48307 .73858 L .48459 .74016 L 0 1 .407 r
F
0 g
.48075 .74461 m
.48459 .74016 L
s
.52188 .37752 m .5321 .36427 L .53274 .37211 L 0 .137 .104 r
F
0 g
.5321 .36427 m
.5357 .34968 L
s
.52746 .36658 m
.5321 .36427 L
s
.52508 .64834 m
.52523 .64864 L
s
.52528 .64875 m
.52531 .64881 L
s
.39365 .84209 m .37836 .83895 L .38095 .84349 L 0 1 .514 r
F
0 g
.37415 .84203 m
.38095 .84349 L
s
.25689 .8388 m
.25706 .83884 L
s
.25706 .83884 m
.25742 .83893 L
s
.45462 .84841 m .44112 .84794 L .44452 .85207 L 0 1 .503 r
F
0 g
.43845 .85174 m
.44452 .85207 L
s
.71743 .9609 m .70844 .96427 L .70381 .96827 L 0 1 .539 r
F
0 g
.69442 .96914 m
.70381 .96827 L
s
.34683 1.01911 m .32425 1.01405 L .33031 1.01886 L 0 1 .539 r
F
.45462 .84841 m .45661 .8552 L .45801 .85254 L 0 1 .503 r
F
.46982 .85526 m .45801 .85254 L .45661 .8552 L 0 1 .502 r
F
0 g
.45661 .8552 m
.46047 .85927 L
s
.45083 .855 m
.45661 .8552 L
s
.43522 .92672 m .42736 .92068 L .41972 .91802 L 0 1 .483 r
F
0 g
.41972 .91802 m
.42736 .92068 L
s
.35482 .86698 m .35435 .87588 L .35734 .87395 L 0 1 .476 r
F
.35482 .86698 m .34712 .87175 L .35435 .87588 L F
.37176 .88477 m .35734 .87395 L .35435 .87588 L 0 1 .48 r
F
0 g
.35435 .87588 m
.35761 .88265 L
s
.38972 .92227 m .3915 .92491 L .39377 .92251 L 0 1 .362 r
F
0 g
.39377 .92251 m
.4016 .91871 L
s
.38972 .92227 m .38375 .92807 L .3915 .92491 L 0 1 .362 r
F
0 g
.3915 .92491 m
.3962 .92494 L
s
.3223 .98487 m .30023 .98304 L .30554 .9865 L 0 1 .537 r
F
.3223 .98487 m .30318 .98135 L .30023 .98304 L F
.3223 .98487 m .31265 .98214 L .30318 .98135 L F
.32908 .98029 m .31265 .98214 L .3223 .98487 L 0 1 .535 r
F
0 g
.3223 .98487 m
.33146 .98549 L
s
.3223 .98487 m
.32755 .98832 L
s
.4679 1.02972 m .47454 1.03548 L .47516 1.03303 L 0 1 .538 r
F
.49391 1.03416 m .47516 1.03303 L .47454 1.03548 L 0 1 .534 r
F
0 g
.47454 1.03548 m
.48223 1.03875 L
s
.46602 1.0357 m
.47454 1.03548 L
s
.48322 .52359 m .4852 .50727 L .48308 .50285 L 0 1 .283 r
F
.48322 .52359 m .48526 .51615 L .4852 .50727 L F
0 g
.4852 .50727 m
.4884 .50469 L
s
.36475 .84226 m .35118 .83631 L .34711 .83874 L 0 1 .518 r
F
.36475 .84226 m .35874 .83782 L .35118 .83631 L F
0 g
.36475 .84226 m
.36649 .84755 L
s
.37198 .83728 m .35874 .83782 L .36475 .84226 L 0 1 .516 r
F
0 g
.36475 .84226 m
.37135 .84406 L
s
.49903 .91729 m .48452 .92872 L .49016 .92806 L 0 1 .476 r
F
0 g
.48363 .93291 m
.49016 .92806 L
s
.49391 1.03416 m .50142 1.0401 L .50161 1.03744 L 0 1 .534 r
F
.52013 1.03889 m .50161 1.03744 L .50142 1.0401 L 0 1 .524 r
F
0 g
.50142 1.0401 m
.50948 1.04371 L
s
.49311 1.04066 m
.50142 1.0401 L
s
.4554 .94141 m .44724 .9356 L .43976 .93304 L 0 .941 .482 r
F
0 g
.43976 .93304 m
.44724 .9356 L
s
.43522 .92672 m
.43976 .93304 L
s
.5438 .56201 m
.54386 .56116 L
s
.54358 .5621 m
.54386 .56116 L
s
.24726 .84235 m .24347 .8439 L .24727 .84244 L 0 1 .493 r
F
.24585 .83425 m .24351 .84373 L .24726 .84235 L F
.24351 .84373 m .24347 .8439 L .24726 .84235 L F
.24724 .8423 m .24347 .8439 L .24727 .84244 L 0 1 .526 r
F
.24578 .83602 m .24355 .84363 L .24724 .8423 L F
.24355 .84363 m .24347 .8439 L .24724 .8423 L F
.25678 .83868 m .25298 .84024 L .25679 .83878 L 0 1 .49 r
F
.25555 .83071 m .25303 .84008 L .25678 .83868 L F
.25303 .84008 m .25298 .84024 L .25678 .83868 L F
.25677 .83863 m .25298 .84024 L .25679 .83878 L 0 1 .526 r
F
.25548 .83251 m .25307 .83998 L .25677 .83863 L F
.25307 .83998 m .25298 .84024 L .25677 .83863 L F
.26632 .83499 m .26252 .83656 L .26634 .83508 L 0 1 .488 r
F
.26527 .82714 m .26257 .8364 L .26632 .83499 L F
.26257 .8364 m .26252 .83656 L .26632 .83499 L F
.26631 .83495 m .26252 .83656 L .26634 .83508 L 0 1 .525 r
F
.26519 .82898 m .26261 .8363 L .26631 .83495 L F
.26261 .8363 m .26252 .83656 L .26631 .83495 L F
.27588 .83127 m .27207 .83285 L .27589 .83136 L 0 1 .485 r
F
.275 .82354 m .27212 .83269 L .27588 .83127 L F
.27212 .83269 m .27207 .83285 L .27588 .83127 L F
.27587 .83122 m .27207 .83285 L .27589 .83136 L 0 1 .524 r
F
.27493 .82541 m .27217 .83259 L .27587 .83122 L F
.27217 .83259 m .27207 .83285 L .27587 .83122 L F
.28546 .82751 m .28164 .82911 L .28547 .8276 L 0 1 .481 r
F
.28474 .8199 m .28169 .82895 L .28546 .82751 L F
.28169 .82895 m .28164 .82911 L .28546 .82751 L F
.28545 .82747 m .28164 .82911 L .28547 .8276 L 0 1 .524 r
F
.28467 .82181 m .28174 .82886 L .28545 .82747 L F
.28174 .82886 m .28164 .82911 L .28545 .82747 L F
.29505 .82372 m .29122 .82533 L .29506 .82381 L 0 1 .478 r
F
.29451 .81622 m .29128 .82517 L .29505 .82372 L F
.29128 .82517 m .29122 .82533 L .29505 .82372 L F
.29504 .82367 m .29122 .82533 L .29506 .82381 L 0 1 .523 r
F
.29444 .81816 m .29133 .82508 L .29504 .82367 L F
.29133 .82508 m .29122 .82533 L .29504 .82367 L F
.30466 .81987 m .30082 .8215 L .30467 .81996 L 0 1 .474 r
F
.30429 .81249 m .30088 .82135 L .30466 .81987 L F
.30088 .82135 m .30082 .8215 L .30466 .81987 L F
.30466 .81983 m .30082 .8215 L .30467 .81996 L 0 1 .522 r
F
.30422 .81447 m .30094 .82126 L .30466 .81983 L F
.30094 .82126 m .30082 .8215 L .30466 .81983 L F
.31429 .81597 m .31044 .81763 L .31429 .81606 L 0 1 .469 r
F
.31408 .8087 m .31051 .81747 L .31429 .81597 L F
.31051 .81747 m .31044 .81763 L .31429 .81597 L F
.31429 .81592 m .31044 .81763 L .31429 .81606 L 0 1 .521 r
F
.31402 .81073 m .31056 .81739 L .31429 .81592 L F
.31056 .81739 m .31044 .81763 L .31429 .81592 L F
.32614 .80396 m .32074 .81342 L .32548 .81146 L 0 1 .464 r
F
.32614 .80396 m .31409 .8087 L .32074 .81342 L F
.32608 .80603 m .32074 .81342 L .32548 .81146 L 0 1 .519 r
F
.32608 .80603 m .31402 .81073 L .32074 .81342 L F
.32602 .80811 m .31396 .81275 L .32066 .81341 L 0 1 .518 r
F
.32073 .81338 m .32066 .81341 L .3207 .81342 L F
.32602 .80811 m .32066 .81341 L .32073 .81338 L F
.32077 .81339 m .3207 .81342 L .32074 .81342 L F
.32602 .80811 m .3207 .81342 L .32077 .81339 L F
.31408 .8087 m .30429 .81249 L .31044 .81763 L 0 1 .469 r
F
.31402 .81073 m .30422 .81447 L .31044 .81763 L 0 1 .521 r
F
.31396 .81275 m .30415 .81646 L .31039 .81762 L 0 1 .525 r
F
.31043 .81761 m .31039 .81762 L .31042 .81762 L F
.31396 .81275 m .31039 .81762 L .31043 .81761 L F
.31045 .81761 m .31042 .81762 L .31044 .81763 L F
.31396 .81275 m .31042 .81762 L .31045 .81761 L F
.30429 .81249 m .29451 .81622 L .30082 .8215 L 0 1 .474 r
F
.30422 .81447 m .29444 .81816 L .30082 .8215 L 0 1 .522 r
F
.30415 .81646 m .29437 .82011 L .30078 .8215 L 0 1 .529 r
F
.30081 .82148 m .30078 .8215 L .3008 .8215 L F
.30415 .81646 m .30078 .8215 L .30081 .82148 L F
.30083 .82149 m .3008 .8215 L .30082 .8215 L F
.30415 .81646 m .3008 .8215 L .30083 .82149 L F
.29451 .81622 m .28474 .8199 L .29122 .82533 L 0 1 .478 r
F
.29444 .81816 m .28467 .82181 L .29122 .82533 L 0 1 .523 r
F
.29437 .82011 m .2846 .82372 L .29118 .82532 L 0 1 .532 r
F
.29121 .82531 m .29118 .82532 L .2912 .82533 L F
.29437 .82011 m .29118 .82532 L .29121 .82531 L F
.29123 .82531 m .2912 .82533 L .29122 .82533 L F
.29437 .82011 m .2912 .82533 L .29123 .82531 L F
.28474 .8199 m .275 .82354 L .28164 .82911 L 0 1 .481 r
F
.28467 .82181 m .27493 .82541 L .28164 .82911 L 0 1 .524 r
F
.2846 .82372 m .27485 .82728 L .2816 .8291 L 0 1 .534 r
F
.28163 .82909 m .2816 .8291 L .28162 .82911 L F
.2846 .82372 m .2816 .8291 L .28163 .82909 L F
.28164 .8291 m .28162 .82911 L .28164 .82911 L F
.2846 .82372 m .28162 .82911 L .28164 .8291 L F
.275 .82354 m .26527 .82714 L .27207 .83285 L 0 1 .485 r
F
.27493 .82541 m .26519 .82898 L .27207 .83285 L 0 1 .524 r
F
.27485 .82728 m .26512 .83081 L .27204 .83285 L 0 1 .536 r
F
.27206 .83284 m .27204 .83285 L .27205 .83285 L F
.27485 .82728 m .27204 .83285 L .27206 .83284 L F
.27207 .83284 m .27205 .83285 L .27207 .83285 L F
.27485 .82728 m .27205 .83285 L .27207 .83284 L F
.26527 .82714 m .25555 .83071 L .26252 .83656 L 0 1 .488 r
F
.26519 .82898 m .25548 .83251 L .26252 .83656 L 0 1 .525 r
F
.26512 .83081 m .2554 .83431 L .26249 .83656 L 0 1 .537 r
F
.26251 .83655 m .26249 .83656 L .2625 .83656 L F
.26512 .83081 m .26249 .83656 L .26251 .83655 L F
.26252 .83655 m .2625 .83656 L .26252 .83656 L F
.26512 .83081 m .2625 .83656 L .26252 .83655 L F
.25555 .83071 m .24585 .83425 L .25298 .84024 L 0 1 .49 r
F
.25548 .83251 m .24578 .83602 L .25298 .84024 L 0 1 .526 r
F
.2554 .83431 m .2457 .83778 L .25296 .84023 L 0 1 .538 r
F
.25297 .84023 m .25296 .84023 L .25297 .84024 L F
.2554 .83431 m .25296 .84023 L .25297 .84023 L F
.25299 .84023 m .25297 .84024 L .25298 .84024 L F
.2554 .83431 m .25297 .84024 L .25299 .84023 L F
.2457 .83778 m .24347 .8439 L .24727 .84244 L 0 1 .539 r
F
0 g
.24727 .84244 m
.24745 .84257 L
s
.24727 .84244 m
.24762 .84261 L
s
.24727 .84244 m
.24736 .84246 L
s
.24585 .83425 m .23617 .83777 L .24347 .8439 L 0 1 .493 r
F
.24578 .83602 m .23609 .8395 L .24347 .8439 L 0 1 .526 r
F
.2457 .83778 m .23602 .84123 L .24347 .8439 L 0 1 .539 r
F
0 g
.24347 .8439 m
.24589 .85191 L
s
.49742 .9702 m .48737 .96839 L .49644 .97354 L 0 .619 .423 r
F
.49742 .9702 m .48115 .96318 L .48737 .96839 L F
0 g
.48735 .96838 m
.48737 .96839 L
s
.46041 .76513 m .45145 .76931 L .44909 .77268 L 0 1 .476 r
F
.46041 .76513 m .45631 .76608 L .45145 .76931 L F
.46562 .75605 m .45631 .76608 L .46041 .76513 L 0 1 .456 r
F
0 g
.46041 .76513 m
.46201 .76712 L
s
.46041 .76513 m
.46495 .76166 L
s
.51598 .67868 m
.51717 .67384 L
s
.54953 .38706 m .56144 .37014 L .55836 .38495 L 0 .14 .11 r
F
0 g
.56144 .37014 m
.5667 .36486 L
s
.34712 .87175 m .33297 .86006 L .32967 .86188 L 0 1 .481 r
F
.34712 .87175 m .34045 .86429 L .33297 .86006 L F
.35482 .86698 m .34045 .86429 L .34712 .87175 L 0 1 .476 r
F
0 g
.34712 .87175 m
.35435 .87588 L
s
.34712 .87175 m
.34989 .87877 L
s
.37176 .88477 m .3648 .87776 L .35734 .87395 L 0 1 .48 r
F
0 g
.37176 .88477 m
.375 .89153 L
s
.38021 .8786 m .37177 .88477 L .37942 .88816 L 0 1 .473 r
F
.38021 .8786 m .3648 .87776 L .37177 .88477 L F
.52013 1.03889 m .52041 1.04585 L .52844 1.04534 L 0 1 .524 r
F
0 g
.52041 1.04585 m
.52881 1.04938 L
s
.42603 .96129 m .40903 .9634 L .40715 .96574 L 0 1 .527 r
F
.42603 .96129 m .41713 .96149 L .40903 .9634 L F
.43003 .95505 m .41713 .96149 L .42603 .96129 L 0 1 .523 r
F
0 g
.42603 .96129 m
.43158 .96307 L
s
.42603 .96129 m
.4338 .95922 L
s
.3313 .84157 m .31446 .8356 L .31653 .84092 L 0 1 .521 r
F
.3313 .84157 m .31804 .83385 L .31446 .8356 L F
.3313 .84157 m .32527 .83642 L .31804 .83385 L F
.33977 .83683 m .32527 .83642 L .3313 .84157 L 0 1 .52 r
F
0 g
.3313 .84157 m
.33829 .84397 L
s
.3313 .84157 m
.33334 .84688 L
s
.52326 .89039 m
.52367 .89075 L
s
.63496 .4362 m
.63515 .4409 L
s
.63462 .42752 m
.63479 .43182 L
s
.63487 .43373 m
.63496 .4362 L
s
.63457 .42623 m
.63462 .42752 L
s
.35271 1.01464 m .35621 1.02116 L .35845 1.01933 L 0 1 .539 r
F
.35271 1.01464 m .34683 1.01911 L .35621 1.02116 L F
0 g
.35621 1.02116 m
.3627 1.02555 L
s
.42048 .83953 m .42097 .84626 L .42312 .84385 L 0 1 .507 r
F
.42048 .83953 m .41485 .84546 L .42097 .84626 L F
.43527 .84753 m .42312 .84385 L .42097 .84626 L F
0 g
.42097 .84626 m
.42416 .85047 L
s
.41485 .84546 m .40244 .84106 L .39995 .8433 L 0 1 .511 r
F
.41485 .84546 m .40883 .84199 L .40244 .84106 L F
.42048 .83953 m .40883 .84199 L .41485 .84546 L 0 1 .507 r
F
0 g
.41485 .84546 m
.42097 .84626 L
s
.41485 .84546 m
.41775 .84982 L
s
.28012 .8493 m .26634 .83508 L .26252 .83656 L 0 1 .49 r
F
0 g
.25742 .83893 m
.26353 .84048 L
s
.28012 .8493 m .27388 .84055 L .26634 .83508 L 0 1 .49 r
F
.28922 .8453 m .27388 .84055 L .28012 .8493 L 0 1 .486 r
F
0 g
.28012 .8493 m
.28211 .85707 L
s
.28012 .8493 m
.28745 .85461 L
s
.52765 .58683 m
.52805 .57982 L
s
.52746 .57474 m
.52872 .56515 L
s
.54454 .51629 m .55291 .48884 L .55261 .49508 L 0 0 .046 r
F
0 g
.54695 .5057 m
.54789 .50261 L
s
.54789 .50261 m
.55053 .49396 L
s
.55291 .48884 m
.5566 .47093 L
s
.54695 .50291 m
.54696 .50369 L
s
.54696 .50369 m
.54697 .50562 L
s
.25715 .83895 m
.25731 .83903 L
s
.25731 .83903 m
.26399 .84227 L
s
.25686 .83881 m
.25715 .83895 L
s
.74282 .53959 m .75502 .55198 L .75448 .5547 L 0 .344 0 r
F
0 g
.75189 .54496 m
.75502 .55198 L
s
.75502 .55198 m
.75891 .55423 L
s
.71743 .9609 m .71566 .96908 L .725 .96553 L 0 1 .539 r
F
0 g
.70659 .97025 m
.71566 .96908 L
s
.71077 .97319 m
.71566 .96908 L
s
.40012 .83658 m .39995 .8433 L .40244 .84106 L 0 1 .511 r
F
.40012 .83658 m .39365 .84209 L .39995 .8433 L F
0 g
.39995 .8433 m
.40286 .84766 L
s
.47934 .74284 m .46986 .75234 L .47129 .75411 L 0 1 .435 r
F
0 g
.46691 .75796 m
.47129 .75411 L
s
.51564 .67458 m
.51564 .67458 L
s
.51575 .67452 m
.51717 .67384 L
s
.52216 .65524 m
.52392 .65236 L
s
.52392 .65236 m
.52407 .65212 L
s
.5221 .65535 m
.52216 .65524 L
s
.49644 .97354 m
.5031 .97804 L
s
.5031 .97804 m
.51008 .98132 L
s
.38021 .8786 m .37942 .88816 L .38266 .88567 L 0 1 .473 r
F
.39744 .89539 m .38266 .88567 L .37942 .88816 L 0 1 .477 r
F
0 g
.37942 .88816 m
.38262 .89502 L
s
.37177 .88477 m
.37942 .88816 L
s
.80163 .59909 m .80878 .61015 L .81266 .6109 L 0 .286 .225 r
F
0 g
.80878 .61015 m
.81092 .61661 L
s
.54561 .55265 m
.54658 .53974 L
s
.41584 .91141 m .40835 .90509 L .40063 .90225 L 0 1 .48 r
F
0 g
.40063 .90225 m
.40835 .90509 L
s
.41584 .91141 m
.41972 .91802 L
s
.38691 .80733 m .37244 .80908 L .3742 .81158 L 0 1 .518 r
F
.38691 .80733 m .37555 .80702 L .37244 .80908 L F
.38691 .80733 m .38176 .80627 L .37555 .80702 L F
.39418 .80169 m .38176 .80627 L .38691 .80733 L 0 1 .512 r
F
0 g
.38691 .80733 m
.39288 .80639 L
s
.38691 .80733 m
.38865 .80983 L
s
.80252 .75074 m .80275 .76962 L .80902 .76453 L 0 1 .494 r
F
.80252 .75074 m .79859 .76756 L .80275 .76962 L F
0 g
.80181 .77781 m
.80275 .76962 L
s
.48545 .86183 m .47915 .85923 L .47367 .85933 L 0 1 .5 r
F
.49828 .55085 m .49363 .53613 L .49574 .54647 L 0 1 .286 r
F
.49518 .56221 m .49363 .53613 L .49084 .53301 L 0 1 .29 r
F
.49518 .56221 m .49574 .54647 L .49363 .53613 L F
0 g
.49335 .52362 m
.49363 .53613 L
s
.43938 1.03002 m .42889 1.02745 L .41993 1.0271 L 0 1 .539 r
F
.44232 1.02446 m .43938 1.03002 L .44802 1.03025 L F
.44232 1.02446 m .42889 1.02745 L .43938 1.03002 L F
0 g
.43938 1.03002 m
.44645 1.03363 L
s
.45891 .9455 m
.45905 .94554 L
s
.45905 .94554 m
.45915 .94557 L
s
.45915 .94557 m
.46057 .94599 L
s
.46057 .94599 m
.46787 .94175 L
s
.4269 .78371 m .42552 .78866 L .42815 .78582 L 0 1 .493 r
F
.4269 .78371 m .42008 .79064 L .42552 .78866 L F
0 g
.42552 .78866 m
.4273 .79073 L
s
.37117 .97029 m .37381 .975 L .37607 .97289 L 0 1 .531 r
F
.37117 .97029 m .36524 .97542 L .37381 .975 L F
0 g
.37381 .975 m
.37941 .97735 L
s
.61232 .3951 m .6137 .41725 L .6107 .39611 L 0 .771 .071 r
F
0 g
.61095 .39596 m
.61139 .39568 L
s
.6107 .39611 m
.61095 .39596 L
s
.60877 .38939 m
.6107 .39611 L
s
.61232 .3951 m .62015 .44971 L .6137 .41725 L 0 .771 .071 r
F
.61232 .3951 m .62574 .47178 L .62015 .44971 L F
0 g
.62149 .45729 m
.62467 .51218 L
s
.62282 .46244 m
.62434 .4815 L
s
.62545 .45167 m
.62638 .45908 L
s
.62516 .44937 m
.62545 .45167 L
s
.61232 .3951 m .61747 .4148 L .6239 .44711 L 0 .771 .071 r
F
0 g
.6207 .41377 m
.62332 .43469 L
s
.62332 .43469 m
.62516 .44937 L
s
.61053 .38494 m
.61232 .3951 L
s
.61139 .39568 m
.61232 .3951 L
s
.61747 .4148 m
.61865 .40602 L
s
.47841 .48668 m .4824 .46949 L .48068 .46853 L 0 1 .224 r
F
.47841 .48668 m .48143 .47725 L .4824 .46949 L F
0 g
.4824 .46949 m
.48605 .46249 L
s
.48143 .47725 m
.48497 .47236 L
s
.48143 .47725 m
.4824 .46949 L
s
.50321 .58681 m .49956 .54636 L .49828 .55085 L 0 .984 .287 r
F
0 g
.50153 .53971 m
.50167 .54801 L
s
.50321 .58681 m .50178 .55476 L .49956 .54636 L 0 .984 .287 r
F
0 g
.49927 .53384 m
.49956 .54636 L
s
.24724 .84233 m
.24727 .84244 L
s
.24726 .84235 m
.24727 .84244 L
s
.2462 .83627 m
.24642 .83753 L
s
.24651 .83806 m
.24726 .84235 L
s
.24724 .8423 m
.24727 .84244 L
s
.24623 .83796 m
.24721 .84216 L
s
.24721 .84216 m
.24724 .8423 L
s
.80252 .75074 m .79848 .75948 L .79859 .76756 L 0 1 .494 r
F
0 g
.79156 .77258 m
.79859 .76756 L
s
.39365 .84209 m .38117 .83688 L .37836 .83895 L 0 1 .514 r
F
.39365 .84209 m .38773 .83823 L .38117 .83688 L F
.40012 .83658 m .38773 .83823 L .39365 .84209 L 0 1 .511 r
F
0 g
.39365 .84209 m
.39621 .84663 L
s
.39365 .84209 m
.39995 .8433 L
s
.50115 .71136 m .49552 .71893 L .49441 .7231 L 0 1 .372 r
F
.50115 .71136 m .49841 .7139 L .49552 .71893 L F
.50314 .70127 m .50115 .71136 L .5037 .70644 L 0 1 .317 r
F
.50314 .70127 m .49841 .7139 L .50115 .71136 L F
0 g
.50115 .71136 m
.50271 .71267 L
s
.47807 .93261 m .4623 .94145 L .46787 .94175 L 0 1 .5 r
F
.50314 .70127 m .5037 .70644 L .50436 .7024 L 0 1 .317 r
F
.50891 .69439 m .50436 .7024 L .5037 .70644 L 0 1 .327 r
F
0 g
.5037 .70644 m
.50529 .7073 L
s
.50115 .71136 m
.5037 .70644 L
s
.43527 .95665 m
.44297 .95392 L
s
.45538 .94444 m .43775 .95237 L .44297 .95392 L 0 1 .514 r
F
0 g
.44296 .95391 m
.44297 .95392 L
s
.48921 .53919 m .48526 .51615 L .48322 .52359 L 0 1 .288 r
F
0 g
.48526 .51615 m
.48837 .51592 L
s
.4852 .50727 m
.48526 .51615 L
s
.48322 .52359 m .48308 .50285 L .47965 .50574 L 0 1 .283 r
F
0 g
.48308 .50285 m
.48343 .49288 L
s
.41343 1.02321 m .3924 1.02127 L .39892 1.02516 L 0 1 .539 r
F
0 g
.3896 1.02423 m
.39892 1.02516 L
s
.43527 .84753 m .42925 .8444 L .42312 .84385 L 0 1 .507 r
F
.44002 .84116 m .43527 .84753 L .44112 .84794 L 0 1 .503 r
F
.44002 .84116 m .42925 .8444 L .43527 .84753 L F
0 g
.43527 .84753 m
.43845 .85174 L
s
.28938 .84093 m
.29123 .84677 L
s
.28938 .84093 m
.29658 .84421 L
s
.33097 .85284 m .32967 .86188 L .33297 .86006 L 0 1 .478 r
F
.33097 .85284 m .32252 .8573 L .32967 .86188 L F
0 g
.32967 .86188 m
.33245 .86891 L
s
.29931 .96139 m .28242 .96462 L .29169 .96575 L 0 1 .459 r
F
0 g
.29169 .96575 m
.30082 .96523 L
s
.49518 .56221 m .49084 .53301 L .48921 .53919 L 0 1 .29 r
F
0 g
.49084 .53301 m
.49363 .53613 L
s
.49048 .52304 m
.49084 .53301 L
s
.49435 .71746 m .49441 .7231 L .49552 .71893 L 0 1 .365 r
F
.49435 .71746 m .49125 .7278 L .49441 .7231 L F
0 g
.49441 .7231 m
.49598 .72439 L
s
.34683 1.01911 m .32685 1.01236 L .32425 1.01405 L 0 1 .539 r
F
.34683 1.01911 m .33654 1.01453 L .32685 1.01236 L F
.35271 1.01464 m .33654 1.01453 L .34683 1.01911 L F
0 g
.34683 1.01911 m
.35621 1.02116 L
s
.34683 1.01911 m
.35285 1.02391 L
s
.4762 .95573 m .48115 .96318 L .48192 .96136 L 0 .831 .471 r
F
.49742 .9702 m .48192 .96136 L .48115 .96318 L 0 .619 .423 r
F
0 g
.48115 .96318 m
.48735 .96838 L
s
.47389 .96054 m
.48115 .96318 L
s
.79179 .74559 m .79234 .76441 L .79848 .75948 L 0 1 .49 r
F
.79179 .74559 m .78817 .76227 L .79234 .76441 L F
0 g
.79156 .77258 m
.79234 .76441 L
s
.50891 .69439 m .50659 .69724 L .50436 .7024 L 0 1 .327 r
F
.50975 .6856 m .50891 .69439 L .51079 .68967 L 0 1 .256 r
F
.50975 .6856 m .50659 .69724 L .50891 .69439 L F
0 g
.50891 .69439 m
.51049 .69527 L
s
.25697 .8389 m
.26454 .84437 L
s
.25687 .83883 m
.25697 .8389 L
s
.26257 .83678 m
.26454 .84437 L
s
.50137 .86827 m .49497 .86571 L .48973 .86591 L 0 1 .495 r
F
.74282 .53959 m .75058 .5524 L .74592 .54661 L 0 .344 0 r
F
.74282 .53959 m .75448 .5547 L .75058 .5524 L F
.44414 .77556 m .43209 .78151 L .43358 .7835 L 0 1 .487 r
F
0 g
.42815 .78582 m
.43358 .7835 L
s
.35734 .87395 m
.3648 .87776 L
s
.49125 .7278 m .48462 .73453 L .48307 .73858 L 0 1 .407 r
F
.49125 .7278 m .48813 .72991 L .48462 .73453 L F
.49435 .71746 m .48813 .72991 L .49125 .7278 L 0 1 .365 r
F
0 g
.49125 .7278 m
.49275 .72939 L
s
.49125 .7278 m
.49441 .7231 L
s
.45033 .7673 m .44909 .77268 L .45145 .76931 L 0 1 .471 r
F
.45033 .7673 m .44414 .77556 L .44909 .77268 L F
0 g
.44909 .77268 m
.4507 .77466 L
s
.31694 .8238 m .31467 .82908 L .31825 .82728 L 0 1 .531 r
F
0 g
.31825 .82728 m
.32553 .82783 L
s
.31694 .8238 m .30778 .82811 L .31467 .82908 L 0 1 .531 r
F
0 g
.31467 .82908 m
.31679 .8325 L
s
.79179 .74559 m .78793 .75421 L .78817 .76227 L 0 1 .49 r
F
0 g
.78131 .76715 m
.78817 .76227 L
s
.53151 .52924 m .53418 .51935 L .53725 .48662 L 0 1 .229 r
F
0 g
.53418 .51935 m
.53489 .5118 L
s
.53489 .5118 m
.53725 .48662 L
s
.53725 .48662 m
.5381 .50488 L
s
.50763 .57503 m .50855 .57304 L .50865 .55652 L 0 .951 .281 r
F
.30695 .95702 m .3082 .96066 L .31116 .95883 L 0 1 .443 r
F
0 g
.31116 .95883 m
.3204 .95752 L
s
.30695 .95702 m .29931 .96139 L .3082 .96066 L 0 1 .443 r
F
0 g
.3082 .96066 m
.31328 .9623 L
s
.46982 .85526 m .46367 .85256 L .45801 .85254 L 0 1 .502 r
F
.77842 .57787 m .7869 .58433 L .78225 .57997 L 0 .142 .189 r
F
.77842 .57787 m .79003 .58912 L .7869 .58433 L F
.32252 .8573 m .3053 .84633 L .30753 .85364 L 0 1 .482 r
F
.44002 .84116 m .44112 .84794 L .44291 .84537 L 0 1 .503 r
F
.45462 .84841 m .44291 .84537 L .44112 .84794 L F
0 g
.44112 .84794 m
.44452 .85207 L
s
.43527 .84753 m
.44112 .84794 L
s
.72854 .54133 m .73425 .53018 L .73892 .53709 L 0 .492 .079 r
F
.72854 .54133 m .72981 .53198 L .73425 .53018 L F
0 g
.73112 .52165 m
.73425 .53018 L
s
.72981 .53198 m
.73425 .53018 L
s
.29834 .84126 m .29636 .85049 L .29994 .84883 L 0 1 .483 r
F
.29834 .84126 m .28922 .8453 L .29636 .85049 L F
0 g
.29636 .85049 m
.29883 .85789 L
s
.38021 .8786 m .36233 .87068 L .3648 .87776 L 0 1 .473 r
F
.30763 .83264 m .30551 .83993 L .30909 .8382 L 0 1 .522 r
F
0 g
.30909 .8382 m
.31653 .84092 L
s
.30763 .83264 m .2985 .83681 L .30551 .83993 L 0 1 .522 r
F
0 g
.30551 .83993 m
.30781 .84537 L
s
.45891 .9455 m
.45901 .94561 L
s
.4554 .94141 m
.45891 .9455 L
s
.4762 .95573 m .46781 .95004 L .46056 .94741 L 0 .831 .471 r
F
0 g
.46056 .94741 m
.46781 .95004 L
s
.45901 .94561 m
.46056 .94741 L
s
.49705 .41127 m .49209 .42547 L .49291 .42244 L 0 0 .025 r
F
.49705 .41127 m .49536 .41961 L .49209 .42547 L F
.49705 .41127 m .50053 .40878 L .49536 .41961 L F
.49705 .41127 m .50465 .39764 L .50053 .40878 L F
.44232 1.02446 m .44802 1.03025 L .44907 1.02798 L 0 1 .539 r
F
.4679 1.02972 m .44907 1.02798 L .44802 1.03025 L 0 1 .538 r
F
0 g
.44802 1.03025 m
.45529 1.03356 L
s
.43938 1.03002 m
.44802 1.03025 L
s
.54065 .49548 m
.54094 .51031 L
s
.725 .96553 m .73255 .97007 L .73749 .96594 L 0 1 .54 r
F
.78105 .74015 m .78192 .75898 L .78793 .75421 L 0 1 .485 r
F
.78105 .74015 m .77774 .75674 L .78192 .75898 L F
0 g
.78131 .76715 m
.78192 .75898 L
s
.50975 .6856 m .51079 .68967 L .51099 .6862 L 0 1 .256 r
F
.51439 .67846 m .51099 .6862 L .51079 .68967 L 0 1 .27 r
F
0 g
.51079 .68967 m
.51238 .68988 L
s
.50891 .69439 m
.51079 .68967 L
s
.39906 .96704 m .37947 .96971 L .38477 .97191 L 0 1 .53 r
F
0 g
.37607 .97289 m
.38477 .97191 L
s
.51799 .89889 m
.52262 .89419 L
s
.52274 .89406 m
.52327 .89353 L
s
.70977 .95402 m .69959 .96415 L .70834 .96107 L 0 1 .527 r
F
.70977 .95402 m .69682 .96319 L .69959 .96415 L F
0 g
.69884 .96469 m
.69959 .96415 L
s
.70373 .96566 m
.70646 .96294 L
s
.49742 .9702 m .49644 .97354 L .50342 .97656 L 0 .619 .423 r
F
.78105 .74015 m .77737 .74868 L .77774 .75674 L 0 1 .485 r
F
0 g
.77104 .7615 m
.77774 .75674 L
s
.28207 .82919 m .28553 .82763 L .28175 .82913 L 0 1 .535 r
F
.29865 .83236 m .28568 .82768 L .28207 .82919 L F
.28568 .82768 m .28553 .82763 L .28207 .82919 L F
.29865 .83236 m .29277 .829 L .28547 .8276 L F
.30778 .82811 m .29277 .829 L .29865 .83236 L 0 1 .533 r
F
.30778 .82811 m .29122 .82533 L .29277 .829 L F
.30763 .83264 m .29126 .82535 L .2927 .83091 L 0 1 .522 r
F
.29126 .82535 m .29123 .82536 L .2927 .83091 L F
.28175 .82913 m .28547 .8276 L .28164 .82911 L 0 1 .535 r
F
.28553 .82763 m .28547 .8276 L .28175 .82913 L F
.28247 .82949 m .28547 .8276 L .28164 .82911 L 0 1 .523 r
F
.2985 .83681 m .28587 .82789 L .28247 .82949 L F
.28587 .82789 m .28547 .8276 L .28247 .82949 L F
.2985 .83681 m .2927 .83091 L .28598 .82784 L F
.28587 .82789 m .28598 .82784 L .28547 .8276 L F
.2985 .83681 m .28598 .82784 L .28587 .82789 L F
.29126 .82535 m .29122 .82533 L .29123 .82536 L 0 1 .522 r
F
.29124 .82534 m .29122 .82535 L .29123 .82537 L 0 1 .479 r
F
.29124 .82536 m .29123 .82537 L .29263 .83282 L F
.29124 .82534 m .29123 .82537 L .29124 .82536 L F
.30763 .83264 m .2927 .83091 L .2985 .83681 L 0 1 .522 r
F
.30748 .83718 m .29126 .82536 L .29263 .83282 L 0 1 .479 r
F
.29126 .82536 m .29124 .82534 L .29124 .82536 L F
.29126 .82536 m .29124 .82536 L .29263 .83282 L F
.29124 .82534 m .29122 .82533 L .29122 .82535 L F
.35051 .81918 m .33323 .81967 L .33428 .82309 L 0 1 .526 r
F
.35051 .81918 m .33765 .81739 L .33323 .81967 L F
.35051 .81918 m .34506 .81718 L .33765 .81739 L F
0 g
.35051 .81918 m
.35153 .8226 L
s
.35847 .81437 m .34506 .81718 L .35051 .81918 L 0 1 .523 r
F
0 g
.35051 .81918 m
.3569 .81918 L
s
.38344 1.01994 m .36182 1.01658 L .36801 1.02087 L 0 1 .539 r
F
0 g
.35845 1.01933 m
.36801 1.02087 L
s
.7703 .7344 m .77148 .7533 L .77737 .74868 L 0 1 .479 r
F
.7703 .7344 m .7673 .75096 L .77148 .7533 L F
0 g
.77104 .7615 m
.77148 .7533 L
s
.43897 .92199 m .42736 .92068 L .43522 .92672 L 0 .973 .475 r
F
.43897 .92199 m .42278 .9147 L .42736 .92068 L F
0 g
.42735 .92067 m
.42736 .92068 L
s
.40406 .96137 m .40715 .96574 L .40903 .9634 L 0 1 .526 r
F
.40406 .96137 m .39906 .96704 L .40715 .96574 L F
0 g
.40715 .96574 m
.41273 .96751 L
s
.7703 .7344 m .76679 .74286 L .7673 .75096 L 0 1 .479 r
F
0 g
.76076 .7556 m
.7673 .75096 L
s
.74876 .72177 m .75057 .74108 L .7562 .73672 L 0 1 .464 r
F
0 g
.7505 .7468 m
.75057 .74108 L
s
.48353 .73284 m .48307 .73858 L .48462 .73453 L 0 1 .401 r
F
.48353 .73284 m .47934 .74284 L .48307 .73858 L F
0 g
.48307 .73858 m
.48459 .74016 L
s
.42048 .83953 m .40618 .83766 L .40883 .84199 L 0 1 .507 r
F
0 g
.40244 .84106 m
.40883 .84199 L
s
.75954 .72829 m .76103 .74735 L .76679 .74286 L 0 1 .472 r
F
.75954 .72829 m .75685 .74488 L .76103 .74735 L F
0 g
.76076 .7556 m
.76103 .74735 L
s
.75954 .72829 m .7562 .73672 L .75685 .74488 L 0 1 .472 r
F
0 g
.75216 .74822 m
.75685 .74488 L
s
.51839 .88331 m
.51842 .88334 L
s
.48831 .43448 m .48293 .44589 L .48422 .44423 L 0 .743 .069 r
F
.48831 .43448 m .48544 .43902 L .48293 .44589 L F
.48831 .43448 m .49007 .42824 L .48544 .43902 L F
.48831 .43448 m .49414 .41853 L .49007 .42824 L F
0 g
.49414 .41853 m
.49705 .41127 L
s
.51507 .62604 m .51787 .56353 L .51695 .56343 L 0 .779 .274 r
F
0 g
.51562 .56256 m
.51671 .54324 L
s
.51507 .62604 m .51776 .58253 L .51787 .56353 L 0 .779 .274 r
F
0 g
.51787 .56353 m
.51936 .542 L
s
.49214 .4233 m
.49414 .41853 L
s
.69658 .96325 m
.69664 .96324 L
s
.69624 .96327 m
.69658 .96325 L
s
.72476 .95821 m .73713 .95578 L .73405 .95488 L 0 1 .534 r
F
.74643 .9432 m .73713 .95578 L .74597 .95156 L 0 1 .532 r
F
.74643 .9432 m .73405 .95488 L .73713 .95578 L F
0 g
.73222 .96062 m
.73713 .95578 L
s
.42008 .79064 m .407 .79457 L .40861 .79669 L 0 1 .503 r
F
.42054 .90655 m .41584 .91141 L .42278 .9147 L 0 1 .474 r
F
.42054 .90655 m .40835 .90509 L .41584 .91141 L F
.43897 .92199 m .43522 .92672 L .44216 .92985 L 0 .973 .475 r
F
.33589 .97571 m .33799 .98075 L .34061 .97886 L 0 1 .533 r
F
.33589 .97571 m .32908 .98029 L .33799 .98075 L F
0 g
.33799 .98075 m
.3435 .98366 L
s
.36524 .97542 m .34454 .97601 L .34977 .97876 L 0 1 .533 r
F
0 g
.34061 .97886 m
.34977 .97876 L
s
.51622 .62761 m .51924 .56426 L .51776 .58253 L 0 .776 .272 r
F
.51622 .62761 m .52014 .56513 L .51924 .56426 L F
0 g
.51924 .56426 m
.51936 .542 L
s
.3502 .83092 m .34711 .83874 L .35118 .83631 L 0 1 .518 r
F
.3502 .83092 m .33977 .83683 L .34711 .83874 L F
0 g
.34711 .83874 m
.34888 .84404 L
s
.32252 .8573 m .30888 .84465 L .3053 .84633 L 0 1 .482 r
F
0 g
.29994 .84883 m
.30753 .85364 L
s
.32252 .8573 m .31626 .84936 L .30888 .84465 L 0 1 .482 r
F
.33097 .85284 m .31626 .84936 L .32252 .8573 L 0 1 .478 r
F
0 g
.32252 .8573 m
.32967 .86188 L
s
.32252 .8573 m
.32473 .86459 L
s
.51507 .62604 m .51695 .56343 L .5158 .58194 L 0 .779 .274 r
F
0 g
.51691 .5641 m
.51695 .56343 L
s
.51671 .54324 m
.51695 .56343 L
s
.49391 1.03416 m .48346 1.03246 L .47516 1.03303 L 0 1 .534 r
F
.35482 .86698 m .33792 .85731 L .34045 .86429 L 0 1 .476 r
F
0 g
.33297 .86006 m
.34045 .86429 L
s
.52013 1.03889 m .50962 1.03691 L .50161 1.03744 L 0 1 .524 r
F
0 g
.52033 .66286 m
.52033 .66286 L
s
.52044 .66192 m
.5207 .65963 L
s
.51935 .6625 m
.52007 .66284 L
s
.52029 .66294 m
.52029 .66294 L
s
.42008 .79064 m .40983 .79213 L .407 .79457 L 0 1 .503 r
F
.42008 .79064 m .41545 .79045 L .40983 .79213 L F
0 g
.42008 .79064 m
.42167 .79276 L
s
.4269 .78371 m .41545 .79045 L .42008 .79064 L 0 1 .493 r
F
0 g
.42008 .79064 m
.42552 .78866 L
s
.61895 .38402 m .61999 .39845 L .61713 .38636 L 0 .683 .07 r
F
.61895 .38402 m .6264 .41503 L .61999 .39845 L F
.61895 .38402 m .63206 .42499 L .6264 .41503 L F
0 g
.62741 .39393 m
.62779 .39574 L
s
.61895 .38402 m .63386 .42256 L .63206 .42499 L 0 .683 .07 r
F
0 g
.62061 .42107 m
.62085 .42301 L
s
.62105 .4246 m
.62379 .44653 L
s
.62085 .42301 m
.62105 .4246 L
s
.61895 .38402 m .62423 .39294 L .63061 .40942 L 0 .683 .07 r
F
0 g
.62423 .39294 m
.62489 .38976 L
s
.61869 .40572 m
.62061 .42107 L
s
.61383 .36857 m
.61895 .38402 L
s
.62779 .39574 m
.63122 .41189 L
s
.40148 .79591 m .39993 .80055 L .40276 .79817 L 0 1 .505 r
F
0 g
.40276 .79817 m
.40861 .79669 L
s
.40148 .79591 m .39418 .80169 L .39993 .80055 L 0 1 .505 r
F
0 g
.39993 .80055 m
.40179 .80277 L
s
.70977 .95402 m .70834 .96107 L .71727 .956 L 0 1 .527 r
F
.70984 .95614 m .69962 .96526 L .70844 .96427 L 0 1 .539 r
F
0 g
.69959 .96415 m
.70169 .96341 L
s
.70984 .95614 m .69682 .96323 L .69962 .96526 L 0 1 .539 r
F
0 g
.69442 .96914 m
.69962 .96526 L
s
.44232 1.02446 m .42212 1.02393 L .42889 1.02745 L 0 1 .539 r
F
0 g
.41993 1.0271 m
.42889 1.02745 L
s
.49978 .91078 m .50492 .91248 L .5051 .90986 L 0 1 .465 r
F
.49978 .91078 m .49903 .91729 L .50492 .91248 L F
0 g
.50492 .91248 m
.51057 .91036 L
s
.71727 .956 m .72476 .95821 L .72941 .9536 L 0 1 .531 r
F
0 g
.26643 .83511 m
.26661 .83515 L
s
.26661 .83515 m
.267 .83524 L
s
.44414 .77556 m .43472 .77858 L .43209 .78151 L 0 1 .487 r
F
.44414 .77556 m .43989 .77603 L .43472 .77858 L F
0 g
.44414 .77556 m
.44562 .77756 L
s
.45033 .7673 m .43989 .77603 L .44414 .77556 L 0 1 .471 r
F
0 g
.44414 .77556 m
.44909 .77268 L
s
.50465 .39764 m
.50828 .39181 L
s
.50828 .39181 m .50383 .40826 L .50415 .40393 L 0 0 .079 r
F
0 g
.50053 .40878 m
.50281 .4026 L
s
.50828 .39181 m .50783 .40377 L .50383 .40826 L 0 0 .079 r
F
0 g
.50281 .4026 m
.50465 .39764 L
s
.50828 .39181 m .51347 .39346 L .50783 .40377 L 0 0 .079 r
F
.50828 .39181 m .51758 .38137 L .51347 .39346 L F
.51622 .62761 m .51968 .58466 L .52014 .56513 L 0 .776 .272 r
F
0 g
.51581 .5818 m
.51691 .5641 L
s
.52014 .56513 m
.52044 .56143 L
s
.38375 .92807 m .36494 .93495 L .36933 .9354 L 0 1 .397 r
F
.38375 .92807 m .36759 .93283 L .36494 .93495 L F
.38375 .92807 m .37566 .92987 L .36759 .93283 L F
.38972 .92227 m .37566 .92987 L .38375 .92807 L 0 1 .362 r
F
0 g
.38375 .92807 m
.3915 .92491 L
s
.38375 .92807 m
.38809 .92852 L
s
.44002 .84116 m .42635 .84019 L .42925 .8444 L 0 1 .503 r
F
0 g
.42312 .84385 m
.42925 .8444 L
s
.46562 .75605 m .45501 .76418 L .45631 .76608 L 0 1 .456 r
F
0 g
.45145 .76931 m
.45631 .76608 L
s
.47934 .74284 m .47183 .74855 L .46986 .75234 L 0 1 .435 r
F
.47934 .74284 m .4759 .74447 L .47183 .74855 L F
.48353 .73284 m .4759 .74447 L .47934 .74284 L 0 1 .401 r
F
0 g
.47934 .74284 m
.48075 .74461 L
s
.47934 .74284 m
.48307 .73858 L
s
.52206 .65668 m
.5221 .65535 L
s
.57066 .36358 m .57658 .36044 L .58254 .36859 L 0 .55 .143 r
F
0 g
.57658 .36044 m
.58254 .36859 L
s
.58254 .36859 m
.58455 .36126 L
s
.57864 .36326 m
.5796 .35831 L
s
.57658 .36044 m
.57946 .34572 L
s
.36644 .80947 m .36466 .81417 L .36777 .81215 L 0 1 .519 r
F
0 g
.36777 .81215 m
.3742 .81158 L
s
.36644 .80947 m .35847 .81437 L .36466 .81417 L 0 1 .519 r
F
0 g
.36466 .81417 m
.36666 .8168 L
s
.42054 .90655 m .40433 .89889 L .40835 .90509 L 0 1 .474 r
F
.37924 .83222 m .37836 .83895 L .38117 .83688 L 0 1 .514 r
F
.37924 .83222 m .37198 .83728 L .37836 .83895 L F
0 g
.37836 .83895 m
.38095 .84349 L
s
.5139 .6252 m .51556 .56376 L .51462 .56432 L 0 .784 .276 r
F
.5139 .6252 m .5158 .58194 L .51556 .56376 L F
0 g
.51328 .56409 m
.51403 .54629 L
s
.51556 .56376 m
.51562 .56256 L
s
.51556 .56376 m
.51567 .57218 L
s
.48725 .85438 m .47915 .85923 L .48545 .86183 L 0 1 .493 r
F
.48725 .85438 m .47518 .85512 L .47915 .85923 L F
0 g
.47367 .85933 m
.47915 .85923 L
s
.49903 .91729 m .48511 .92599 L .48452 .92872 L 0 1 .476 r
F
.49903 .91729 m .49133 .92109 L .48511 .92599 L F
.49978 .91078 m .49133 .92109 L .49903 .91729 L 0 1 .465 r
F
0 g
.49903 .91729 m
.50465 .91664 L
s
.49903 .91729 m
.50492 .91248 L
s
.67876 .50613 m .69077 .50234 L .68929 .52783 L 0 .678 .17 r
F
0 g
.68856 .47362 m
.69077 .50234 L
s
.69077 .50234 m
.69511 .4909 L
s
.47263 .84811 m .46982 .85526 L .47518 .85512 L 0 1 .496 r
F
.47263 .84811 m .46367 .85256 L .46982 .85526 L F
0 g
.46982 .85526 m
.47367 .85933 L
s
.52013 1.03889 m .52844 1.04534 L .52819 1.0425 L 0 1 .524 r
F
.54633 1.04642 m .52844 1.04534 L .5368 1.04976 L 0 1 .501 r
F
.54633 1.04642 m .52819 1.0425 L .52844 1.04534 L F
0 g
.52041 1.04585 m
.52844 1.04534 L
s
.25296 .84023 m
.25297 .84024 L
s
.2554 .83431 m .25298 .84024 L .25679 .83878 L 0 1 .538 r
F
0 g
.25297 .84024 m
.25298 .84024 L
s
.25679 .83878 m
.25687 .83883 L
s
.25679 .83878 m
.25686 .83881 L
s
.25679 .83878 m
.25689 .8388 L
s
.25298 .84024 m
.25299 .84026 L
s
.34335 .94748 m .32302 .95149 L .32755 .95274 L 0 1 .435 r
F
.34335 .94748 m .32599 .94965 L .32302 .95149 L F
.34335 .94748 m .33472 .94793 L .32599 .94965 L F
.35018 .94239 m .33472 .94793 L .34335 .94748 L 0 1 .412 r
F
0 g
.34335 .94748 m
.35177 .94556 L
s
.34335 .94748 m
.34783 .94873 L
s
.36524 .97542 m .34717 .97411 L .34454 .97601 L 0 1 .533 r
F
.36524 .97542 m .35605 .97386 L .34717 .97411 L F
.37117 .97029 m .35605 .97386 L .36524 .97542 L 0 1 .531 r
F
0 g
.36524 .97542 m
.37381 .975 L
s
.36524 .97542 m
.37043 .97817 L
s
.59914 .36691 m
.6042 .37484 L
s
.59728 .37576 m
.59914 .36691 L
s
.54633 1.04642 m .5368 1.04976 L .54771 1.05283 L 0 1 .501 r
F
0 g
.52844 1.04534 m
.5368 1.04976 L
s
.52881 1.04938 m
.5368 1.04976 L
s
.48725 .85438 m .48545 .86183 L .49062 .86152 L 0 1 .493 r
F
0 g
.48545 .86183 m
.48973 .86591 L
s
.49518 .56221 m .4964 .55765 L .49574 .54647 L 0 1 .29 r
F
0 g
.69621 .96333 m
.69658 .96325 L
s
.68108 .96301 m .68775 .96534 L .69267 .96182 L 0 1 .518 r
F
0 g
.68775 .96534 m
.69621 .96333 L
s
.68994 .96377 m
.69624 .96327 L
s
.45818 .93699 m .44724 .9356 L .4554 .94141 L 0 .896 .473 r
F
.45818 .93699 m .44216 .92985 L .44724 .9356 L F
0 g
.44723 .93559 m
.44724 .9356 L
s
.51439 .67846 m .51254 .68139 L .51099 .6862 L 0 1 .27 r
F
0 g
.51439 .67846 m
.51598 .67868 L
s
.51439 .67846 m
.5153 .67555 L
s
.5155 .6749 m
.5155 .6749 L
s
.50321 .58681 m .49828 .55085 L .49888 .56456 L 0 .984 .287 r
F
0 g
.49574 .54647 m
.49828 .55085 L
s
.50314 .70127 m .49719 .71278 L .49841 .7139 L 0 1 .317 r
F
0 g
.49552 .71893 m
.49841 .7139 L
s
.48209 .45995 m .48614 .44259 L .48215 .45072 L 0 1 .144 r
F
0 g
.48397 .44702 m
.48614 .44259 L
s
.48614 .44259 m
.48831 .43448 L
s
.47263 .84811 m .46012 .84846 L .46367 .85256 L 0 1 .496 r
F
0 g
.45801 .85254 m
.46367 .85256 L
s
.76203 .78714 m .75676 .7965 L .76078 .80014 L 0 .827 .466 r
F
.76203 .78714 m .75728 .79094 L .75676 .7965 L F
0 g
.75343 .7968 m
.75676 .7965 L
s
.24585 .83425 m .23022 .82811 L .23617 .83777 L 0 1 .493 r
F
0 g
.23617 .83777 m
.23759 .83896 L
s
.5139 .6252 m .51462 .56432 L .51381 .58273 L 0 .784 .276 r
F
0 g
.51458 .56516 m
.51462 .56432 L
s
.51403 .54629 m
.51462 .56432 L
s
.5366 .89929 m
.5367 .89938 L
s
.37198 .83728 m .35656 .83306 L .35874 .83782 L 0 1 .516 r
F
0 g
.35874 .83782 m
.35874 .83782 L
s
.35874 .83782 m
.35874 .83782 L
s
.51734 .62993 m .52146 .56705 L .51968 .58466 L 0 .773 .272 r
F
.51734 .62993 m .52233 .56875 L .52146 .56705 L F
0 g
.52146 .56705 m
.52193 .54296 L
s
.62423 .39294 m
.62591 .39728 L
s
.62914 .40563 m
.62929 .40602 L
s
.62591 .39728 m
.62914 .40563 L
s
.63059 .40938 m
.63061 .40942 L
s
.62929 .40602 m
.63059 .40938 L
s
.50975 .6856 m .50535 .69665 L .50659 .69724 L 0 1 .256 r
F
0 g
.50436 .7024 m
.50659 .69724 L
s
.50538 .58058 m .50178 .55476 L .50345 .57049 L 0 .969 .284 r
F
.50321 .58681 m .50345 .57049 L .50178 .55476 L 0 .984 .287 r
F
0 g
.49956 .54636 m
.50178 .55476 L
s
.50167 .54801 m
.50178 .55476 L
s
.39744 .89539 m .39039 .88876 L .38266 .88567 L 0 1 .477 r
F
0 g
.38266 .88567 m
.39039 .88876 L
s
.39744 .89539 m
.40063 .90225 L
s
.76203 .78714 m .76078 .80014 L .76752 .79994 L 0 .827 .466 r
F
0 g
.75934 .80628 m
.76078 .80014 L
s
.76612 .56758 m .77059 .56798 L .77526 .57296 L 0 .189 0 r
F
.76612 .56758 m .76668 .56568 L .77059 .56798 L F
0 g
.76679 .56512 m
.77059 .56798 L
s
.39906 .96704 m .38174 .9676 L .37947 .96971 L 0 1 .53 r
F
.39906 .96704 m .39014 .96645 L .38174 .9676 L F
.40406 .96137 m .39014 .96645 L .39906 .96704 L 0 1 .526 r
F
0 g
.39906 .96704 m
.40433 .96924 L
s
.39906 .96704 m
.40715 .96574 L
s
.26669 .83525 m
.26685 .83533 L
s
.51892 .66338 m
.51913 .66522 L
s
.51772 .66597 m
.5191 .66531 L
s
.79334 .81193 m .79088 .82452 L .79809 .82348 L 0 .959 .49 r
F
.79334 .81193 m .78687 .82153 L .79088 .82452 L F
0 g
.78882 .83043 m
.79088 .82452 L
s
.47986 .92595 m .48452 .92872 L .48511 .92599 L 0 1 .49 r
F
.47986 .92595 m .47807 .93261 L .48452 .92872 L F
0 g
.48452 .92872 m
.49016 .92806 L
s
.48209 .45995 m .47636 .46851 L .47809 .46811 L 0 1 .144 r
F
.48209 .45995 m .4781 .46104 L .47636 .46851 L F
.48209 .45995 m .48215 .45072 L .4781 .46104 L F
.77248 .79603 m .76682 .8054 L .77084 .8088 L 0 .872 .475 r
F
.77248 .79603 m .76752 .79994 L .76682 .8054 L F
0 g
.75934 .80628 m
.76682 .8054 L
s
.50906 .87223 m
.51099 .87209 L
s
.47085 .74672 m .46986 .75234 L .47183 .74855 L 0 1 .428 r
F
.47085 .74672 m .46562 .75605 L .46986 .75234 L F
0 g
.46986 .75234 m
.47129 .75411 L
s
.43003 .95505 m .41186 .9599 L .41713 .96149 L 0 1 .523 r
F
0 g
.40903 .9634 m
.41713 .96149 L
s
.28922 .8453 m .27589 .83136 L .27207 .83285 L 0 1 .486 r
F
0 g
.26685 .83533 m
.27339 .83844 L
s
.267 .83524 m
.27296 .83663 L
s
.28922 .8453 m .28325 .8367 L .27589 .83136 L 0 1 .486 r
F
.29834 .84126 m .28325 .8367 L .28922 .8453 L 0 1 .483 r
F
0 g
.28922 .8453 m
.29101 .85297 L
s
.28922 .8453 m
.29636 .85049 L
s
.52961 .63192 m
.53037 .62955 L
s
.53037 .62955 m
.53181 .6251 L
s
.53181 .6251 m
.53203 .62441 L
s
.53203 .62441 m
.5322 .62389 L
s
.5322 .62389 m
.53238 .62332 L
s
.53238 .62332 m
.53263 .62256 L
s
.53263 .62256 m
.5328 .62201 L
s
.49435 .71746 m .48695 .72845 L .48813 .72991 L 0 1 .365 r
F
0 g
.48462 .73453 m
.48813 .72991 L
s
.40304 .89051 m .39744 .89539 L .40433 .89889 L 0 1 .471 r
F
.40304 .89051 m .39039 .88876 L .39744 .89539 L F
0 g
.53068 .62885 m
.53149 .62624 L
s
.53055 .62924 m
.53068 .62885 L
s
.53149 .62624 m
.53262 .62264 L
s
.53262 .62264 m
.53266 .6225 L
s
.53266 .6225 m
.53281 .62203 L
s
.53281 .62203 m
.53295 .62158 L
s
.53295 .62158 m
.53315 .62095 L
s
.53315 .62095 m
.53325 .62063 L
s
.40012 .83658 m .3854 .83374 L .38773 .83823 L 0 1 .511 r
F
0 g
.38117 .83688 m
.38773 .83823 L
s
.79334 .81193 m .78792 .81614 L .78687 .82153 L 0 .959 .49 r
F
0 g
.77901 .82286 m
.78687 .82153 L
s
.77248 .79603 m .77084 .8088 L .77773 .80832 L 0 .872 .475 r
F
0 g
.76919 .81483 m
.77084 .8088 L
s
.81322 .608 m .81569 .6157 L .82029 .61921 L 0 .348 .265 r
F
.81322 .608 m .81266 .6109 L .81569 .6157 L F
0 g
.81092 .61661 m
.81569 .6157 L
s
.45462 .84841 m .4487 .84557 L .44291 .84537 L 0 1 .503 r
F
.42054 .90655 m .42278 .9147 L .42455 .91276 L 0 1 .474 r
F
.43897 .92199 m .42455 .91276 L .42278 .9147 L 0 .973 .475 r
F
0 g
.42278 .9147 m
.42735 .92067 L
s
.41584 .91141 m
.42278 .9147 L
s
.53768 .37135 m .5436 .36247 L .54884 .36285 L 0 .257 .124 r
F
.78292 .80427 m .78087 .8169 L .78792 .81614 L 0 .917 .483 r
F
.78292 .80427 m .77686 .81372 L .78087 .8169 L F
0 g
.77901 .82286 m
.78087 .8169 L
s
.78292 .80427 m .77773 .80832 L .77686 .81372 L 0 .917 .483 r
F
0 g
.76919 .81483 m
.77686 .81372 L
s
.50213 .86037 m .49497 .86571 L .50137 .86827 L 0 1 .489 r
F
.50213 .86037 m .49062 .86152 L .49497 .86571 L F
0 g
.48973 .86591 m
.49497 .86571 L
s
.53021 .43437 m .52823 .44099 L .5276 .44537 L 0 0 0 r
F
.53021 .43437 m .53213 .42392 L .52823 .44099 L F
.52833 .45741 m .53021 .43437 L .52667 .45533 L 0 .95 .106 r
F
0 g
.5297 .43654 m
.53021 .43437 L
s
.51734 .62993 m .52153 .5885 L .52233 .56875 L 0 .773 .272 r
F
0 g
.52233 .56875 m
.52291 .56255 L
s
.5178 .57564 m
.51787 .56353 L
s
.53066 .62891 m
.53226 .62383 L
s
.53055 .62924 m
.53066 .62891 L
s
.53226 .62383 m
.53313 .62106 L
s
.53313 .62106 m
.53322 .62078 L
s
.53322 .62078 m
.53362 .61951 L
s
.53362 .61951 m
.53373 .61919 L
s
.37198 .83728 m .35966 .83118 L .35656 .83306 L 0 1 .516 r
F
0 g
.35118 .83631 m
.35874 .83782 L
s
.37198 .83728 m .36628 .83299 L .35966 .83118 L 0 1 .516 r
F
.37924 .83222 m .36628 .83299 L .37198 .83728 L 0 1 .514 r
F
0 g
.37198 .83728 m
.37836 .83895 L
s
.37198 .83728 m
.37415 .84203 L
s
.45937 .93831 m .4623 .94145 L .46329 .93887 L 0 1 .506 r
F
.45818 .93699 m .4589 .94246 L .45931 .93906 L 0 .896 .473 r
F
.45931 .93906 m .45884 .94295 L .45902 .94287 L 0 1 .506 r
F
.45931 .93906 m .45902 .94287 L .4623 .94145 L F
.45931 .93906 m .4623 .94145 L .45937 .93831 L F
.45936 .93833 m .46227 .94448 L .46326 .94275 L 0 .896 .473 r
F
.45818 .93699 m .45931 .93906 L .45936 .93833 L F
.45931 .93906 m .46227 .94448 L .45936 .93833 L F
.4589 .94246 m .45897 .943 L .45931 .93906 L F
.45818 .93699 m .4554 .94141 L .45897 .943 L F
.45817 .93814 m .45538 .94444 L .45884 .94295 L 0 1 .506 r
F
.45817 .93814 m .45884 .94295 L .45931 .93906 L F
.45817 .93814 m .45931 .93906 L .45937 .93831 L F
.45931 .93906 m .45897 .943 L .46227 .94448 L 0 .896 .473 r
F
0 g
.45884 .94295 m
.45898 .94301 L
s
.4554 .94141 m
.4565 .9419 L
s
.4587 .94543 m
.45891 .9455 L
s
.45843 .84153 m .45462 .84841 L .46012 .84846 L 0 1 .497 r
F
.45843 .84153 m .4487 .84557 L .45462 .84841 L F
0 g
.45462 .84841 m
.45801 .85254 L
s
.33977 .83683 m .32343 .83121 L .32527 .83642 L 0 1 .52 r
F
.33977 .83683 m .32702 .82944 L .32343 .83121 L F
.33977 .83683 m .33403 .83186 L .32702 .82944 L F
0 g
.33977 .83683 m
.34159 .84202 L
s
.3502 .83092 m .33403 .83185 L .33977 .83683 L 0 1 .518 r
F
0 g
.33977 .83683 m
.34711 .83874 L
s
.51272 .62507 m .51321 .56558 L .51227 .5667 L 0 .791 .278 r
F
.51272 .62507 m .51381 .58273 L .51321 .56558 L F
0 g
.51321 .56558 m
.51328 .56409 L
s
.47807 .93261 m .46329 .93887 L .4623 .94145 L 0 1 .5 r
F
0 g
.4623 .94145 m
.46787 .94175 L
s
.47807 .93261 m .47006 .93507 L .46329 .93887 L 0 1 .5 r
F
.47986 .92595 m .47006 .93507 L .47807 .93261 L 0 1 .49 r
F
0 g
.47807 .93261 m
.48363 .93291 L
s
.47807 .93261 m
.48452 .92872 L
s
.25676 .83867 m
.25679 .83878 L
s
.25678 .83868 m
.25679 .83878 L
s
.25586 .83273 m
.25607 .83407 L
s
.25614 .83455 m
.25678 .83868 L
s
.25677 .83863 m
.25679 .83878 L
s
.25589 .83447 m
.25674 .83849 L
s
.25674 .83849 m
.25677 .83863 L
s
.48921 .53919 m .48358 .53358 L .4861 .53944 L 0 1 .288 r
F
.48921 .53919 m .48322 .52359 L .48358 .53358 L F
.49518 .56221 m .48921 .53919 L .48987 .55037 L 0 1 .29 r
F
0 g
.52967 .6316 m
.53069 .62852 L
s
.53069 .62852 m
.53079 .62822 L
s
.53079 .62822 m
.53091 .62784 L
s
.53091 .62784 m
.5311 .62727 L
s
.51903 .66203 m
.5207 .65963 L
s
.24578 .83602 m .23004 .83215 L .23609 .8395 L 0 1 .526 r
F
0 g
.23609 .8395 m
.23788 .84057 L
s
.53225 .62417 m
.53326 .62086 L
s
.53326 .62086 m
.53369 .61943 L
s
.532 .62499 m
.53225 .62417 L
s
.53132 .62725 m
.53133 .62719 L
s
.53133 .62719 m
.532 .62499 L
s
.47719 .51403 m .47988 .4978 L .47774 .49549 L 0 1 .276 r
F
.47719 .51403 m .47965 .50574 L .47988 .4978 L F
0 g
.47988 .4978 m
.48343 .49288 L
s
.66424 .4984 m
.66633 .54484 L
s
.47263 .84811 m .47518 .85512 L .47618 .85223 L 0 1 .496 r
F
.48725 .85438 m .47618 .85223 L .47518 .85512 L 0 1 .493 r
F
0 g
.47518 .85512 m
.47915 .85923 L
s
.46982 .85526 m
.47518 .85512 L
s
.53409 .42193 m .54366 .39489 L .54475 .39743 L 0 0 .071 r
F
.53409 .42193 m .5391 .40536 L .54366 .39489 L F
0 g
.54366 .39489 m
.54645 .37836 L
s
.5391 .40536 m
.54194 .39885 L
s
.54194 .39885 m
.54366 .39489 L
s
.46562 .75605 m .45738 .76069 L .45501 .76418 L 0 1 .456 r
F
.46562 .75605 m .46193 .75721 L .45738 .76069 L F
.47085 .74672 m .46193 .75721 L .46562 .75605 L 0 1 .428 r
F
0 g
.46562 .75605 m
.46691 .75796 L
s
.46562 .75605 m
.46986 .75234 L
s
.48322 .52359 m .47725 .52293 L .47979 .5265 L 0 1 .283 r
F
.48322 .52359 m .47719 .51403 L .47725 .52293 L F
.48322 .52359 m .47965 .50574 L .47719 .51403 L F
0 g
.47965 .50574 m
.47988 .4978 L
s
.47965 .50574 m
.48308 .50285 L
s
.32163 1.00725 m .32425 1.01405 L .32685 1.01236 L 0 1 .538 r
F
.32163 1.00725 m .31485 1.01136 L .32425 1.01405 L F
0 g
.32425 1.01405 m
.33031 1.01886 L
s
.43897 .92199 m .44216 .92985 L .44355 .92798 L 0 .973 .475 r
F
.45818 .93699 m .44355 .92798 L .44216 .92985 L 0 .896 .473 r
F
0 g
.44216 .92985 m
.44723 .93559 L
s
.43522 .92672 m
.44216 .92985 L
s
.49472 1.02732 m .49391 1.03416 L .50189 1.03331 L 0 1 .534 r
F
.49472 1.02732 m .48346 1.03246 L .49391 1.03416 L F
0 g
.49391 1.03416 m
.50161 1.03744 L
s
.49472 1.02732 m .4761 1.02931 L .48346 1.03246 L 0 1 .534 r
F
0 g
.47516 1.03303 m
.48346 1.03246 L
s
.35704 .9373 m .35835 .94026 L .36098 .93814 L 0 1 .383 r
F
0 g
.36098 .93814 m
.36933 .9354 L
s
.35704 .9373 m .35018 .94239 L .35835 .94026 L 0 1 .383 r
F
0 g
.35835 .94026 m
.36302 .94091 L
s
.70977 .95402 m .70117 .95885 L .69682 .96319 L 0 1 .527 r
F
0 g
.69658 .96325 m
.69682 .96319 L
s
.4679 1.02972 m .4576 1.02775 L .44907 1.02798 L 0 1 .538 r
F
.70984 .95614 m .70119 .95932 L .69682 .96323 L 0 1 .539 r
F
0 g
.69664 .96324 m
.69682 .96323 L
s
.39418 .80169 m .38023 .80389 L .38176 .80627 L 0 1 .512 r
F
.39418 .80169 m .38335 .80178 L .38023 .80389 L F
.39418 .80169 m .38934 .80084 L .38335 .80178 L F
.40148 .79591 m .38934 .80084 L .39418 .80169 L 0 1 .505 r
F
0 g
.39418 .80169 m
.39993 .80055 L
s
.39418 .80169 m
.3957 .80407 L
s
.2985 .83681 m
.30015 .8425 L
s
.2985 .83681 m
.30551 .83993 L
s
.26652 .83522 m
.27388 .84055 L
s
.26641 .83514 m
.26652 .83522 L
s
.27212 .83308 m
.27388 .84055 L
s
.51272 .62507 m .51227 .5667 L .51181 .58473 L 0 .791 .278 r
F
0 g
.51133 .55082 m
.51227 .5667 L
s
.52251 .8917 m
.52304 .89149 L
s
.52304 .89149 m
.52394 .89044 L
s
.74643 .9432 m .73802 .9495 L .73405 .95488 L 0 1 .532 r
F
0 g
.72476 .95821 m
.73405 .95488 L
s
.40304 .89051 m .38697 .88234 L .39039 .88876 L 0 1 .471 r
F
.35482 .86698 m .34122 .85547 L .33792 .85731 L 0 1 .476 r
F
.35482 .86698 m .34847 .85962 L .34122 .85547 L F
0 g
.35482 .86698 m
.35734 .87395 L
s
.3643 .86103 m .35482 .86698 L .36233 .87068 L 0 1 .47 r
F
.3643 .86103 m .34847 .85962 L .35482 .86698 L F
.40304 .89051 m .40433 .89889 L .40646 .89693 L 0 1 .471 r
F
.42054 .90655 m .40646 .89693 L .40433 .89889 L 0 1 .474 r
F
0 g
.40433 .89889 m
.40835 .90509 L
s
.39744 .89539 m
.40433 .89889 L
s
.47841 .48668 m .48068 .46853 L .4768 .47501 L 0 1 .224 r
F
0 g
.48068 .46853 m
.48209 .45995 L
s
.5051 .90986 m
.5103 .90445 L
s
.5103 .90445 m
.51071 .90403 L
s
.50213 .86037 m .50137 .86827 L .5063 .86778 L 0 1 .489 r
F
0 g
.50137 .86827 m
.50589 .87233 L
s
.60519 .3764 m .61079 .37694 L .61713 .38636 L 0 .644 .107 r
F
0 g
.61079 .37694 m
.61253 .36709 L
s
.53235 .62394 m
.53365 .61974 L
s
.53213 .62463 m
.53235 .62394 L
s
.53132 .62725 m
.53135 .62712 L
s
.53135 .62712 m
.53213 .62463 L
s
.79003 .58912 m .80111 .60154 L .80163 .59909 L 0 .217 .206 r
F
0 g
.80111 .60154 m
.80417 .60627 L
s
.79725 .60014 m
.80111 .60154 L
s
.74643 .9432 m .74597 .95156 L .75469 .94502 L 0 1 .532 r
F
0 g
.73713 .95578 m
.74597 .95156 L
s
.51409 .67261 m .51129 .68162 L .51254 .68139 L 0 1 .178 r
F
0 g
.51099 .6862 m
.51254 .68139 L
s
.45843 .84153 m .4456 .84142 L .4487 .84557 L 0 1 .497 r
F
0 g
.44291 .84537 m
.4487 .84557 L
s
.3643 .86103 m .36233 .87068 L .36601 .86827 L 0 1 .47 r
F
.38021 .8786 m .36601 .86827 L .36233 .87068 L 0 1 .473 r
F
0 g
.36233 .87068 m
.3648 .87776 L
s
.35482 .86698 m
.36233 .87068 L
s
.52188 .37752 m .51797 .39599 L .51781 .39013 L 0 .137 .104 r
F
.52188 .37752 m .52264 .39367 L .51797 .39599 L F
.52188 .37752 m .5287 .38472 L .52264 .39367 L F
.52188 .37752 m .53274 .37211 L .5287 .38472 L F
0 g
.51758 .38137 m
.52188 .37752 L
s
.48725 .85438 m .49062 .86152 L .49122 .8585 L 0 1 .493 r
F
.50213 .86037 m .49122 .8585 L .49062 .86152 L 0 1 .489 r
F
0 g
.49062 .86152 m
.49497 .86571 L
s
.48545 .86183 m
.49062 .86152 L
s
.52367 .88806 m
.52367 .88806 L
s
.52529 .88719 m
.52529 .88719 L
s
.50538 .58058 m .50627 .57826 L .50602 .56315 L 0 .969 .284 r
F
.3884 1.01511 m .3924 1.02127 L .39426 1.0193 L 0 1 .539 r
F
.3884 1.01511 m .38344 1.01994 L .3924 1.02127 L F
.41343 1.02321 m .39426 1.0193 L .3924 1.02127 L F
0 g
.3924 1.02127 m
.39892 1.02516 L
s
.45843 .84153 m .46012 .84846 L .46153 .84567 L 0 1 .497 r
F
.47263 .84811 m .46153 .84567 L .46012 .84846 L 0 1 .496 r
F
0 g
.46012 .84846 m
.46367 .85256 L
s
.45462 .84841 m
.46012 .84846 L
s
.46217 .94151 m
.4623 .94145 L
s
.48353 .73284 m .47479 .7428 L .4759 .74447 L 0 1 .401 r
F
0 g
.47183 .74855 m
.4759 .74447 L
s
.32611 .81943 m .32363 .82456 L .32722 .82274 L 0 1 .528 r
F
0 g
.32722 .82274 m
.33428 .82309 L
s
.32611 .81943 m .31694 .8238 L .32363 .82456 L 0 1 .528 r
F
0 g
.32363 .82456 m
.32553 .82783 L
s
.32908 .98029 m .30762 .97883 L .31265 .98214 L 0 1 .535 r
F
.32908 .98029 m .31058 .97715 L .30762 .97883 L F
.32908 .98029 m .31979 .97778 L .31058 .97715 L F
.33589 .97571 m .31979 .97778 L .32908 .98029 L 0 1 .533 r
F
0 g
.32908 .98029 m
.33799 .98075 L
s
.32908 .98029 m
.33407 .98359 L
s
.42048 .83953 m .40868 .83537 L .40618 .83766 L 0 1 .507 r
F
.42048 .83953 m .41481 .83617 L .40868 .83537 L F
.42614 .83342 m .42048 .83953 L .42635 .84019 L 0 1 .504 r
F
.42614 .83342 m .41481 .83617 L .42048 .83953 L F
0 g
.42048 .83953 m
.42312 .84385 L
s
.46979 1.0236 m .4679 1.02972 L .4761 1.02931 L 0 1 .538 r
F
.46979 1.0236 m .4576 1.02775 L .4679 1.02972 L F
0 g
.4679 1.02972 m
.47516 1.03303 L
s
.2457 .83778 m .22986 .8362 L .23602 .84123 L 0 1 .539 r
F
0 g
.23602 .84123 m
.24347 .8439 L
s
.40661 .83094 m .40618 .83766 L .40868 .83537 L 0 1 .508 r
F
.40661 .83094 m .40012 .83658 L .40618 .83766 L F
0 g
.40618 .83766 m
.40883 .84199 L
s
.43374 .77657 m .43209 .78151 L .43472 .77858 L 0 1 .479 r
F
.43374 .77657 m .4269 .78371 L .43209 .78151 L F
0 g
.43209 .78151 m
.43358 .7835 L
s
.42614 .83342 m .42635 .84019 L .42851 .83771 L 0 1 .504 r
F
.44002 .84116 m .42851 .83771 L .42635 .84019 L 0 1 .503 r
F
0 g
.42635 .84019 m
.42925 .8444 L
s
.42048 .83953 m
.42635 .84019 L
s
.51842 .63301 m .5236 .57199 L .52153 .5885 L 0 .769 .271 r
F
.51842 .63301 m .52443 .57459 L .5236 .57199 L F
0 g
.5236 .57199 m
.52442 .54652 L
s
.53188 .62608 m
.53342 .62092 L
s
.53342 .62092 m
.53356 .62046 L
s
.31679 .82843 m .31446 .8356 L .31804 .83385 L 0 1 .521 r
F
0 g
.31804 .83385 m
.32527 .83642 L
s
.31679 .82843 m .30763 .83264 L .31446 .8356 L 0 1 .521 r
F
0 g
.31446 .8356 m
.31653 .84092 L
s
.51983 1.03107 m .50962 1.03691 L .52013 1.03889 L 0 1 .521 r
F
.51983 1.03107 m .50189 1.03331 L .50962 1.03691 L F
0 g
.50161 1.03744 m
.50962 1.03691 L
s
.52359 .64837 m
.5236 .64836 L
s
.5236 .64836 m
.5236 .64835 L
s
.52381 .64796 m
.52387 .64787 L
s
.52403 .64756 m
.52406 .64751 L
s
.52406 .64751 m
.52409 .64745 L
s
.5253 .64522 m
.52541 .64503 L
s
.52485 .64606 m
.52486 .64603 L
s
.52485 .6453 m
.52487 .64528 L
s
.52549 .64467 m
.52553 .64463 L
s
.38344 1.01994 m .36407 1.01475 L .36182 1.01658 L 0 1 .539 r
F
.38344 1.01994 m .37334 1.01619 L .36407 1.01475 L F
.3884 1.01511 m .37334 1.01619 L .38344 1.01994 L F
0 g
.38344 1.01994 m
.3924 1.02127 L
s
.38344 1.01994 m
.3896 1.02423 L
s
.30748 .83718 m .3053 .84633 L .30888 .84465 L 0 1 .479 r
F
.30748 .83718 m .29834 .84126 L .3053 .84633 L F
0 g
.3053 .84633 m
.30753 .85364 L
s
.29165 .8254 m .29512 .82383 L .29132 .82535 L 0 1 .533 r
F
.30778 .82811 m .29527 .82388 L .29165 .8254 L F
.29527 .82388 m .29512 .82383 L .29165 .8254 L F
.30778 .82811 m .30217 .825 L .29506 .82381 L F
.31694 .8238 m .30217 .825 L .30778 .82811 L 0 1 .531 r
F
.31694 .8238 m .30082 .8215 L .30217 .825 L F
.31679 .82843 m .30087 .82152 L .3021 .82694 L 0 1 .521 r
F
.30087 .82152 m .30083 .82154 L .3021 .82694 L F
.29132 .82535 m .29506 .82381 L .29122 .82533 L 0 1 .533 r
F
.29512 .82383 m .29506 .82381 L .29132 .82535 L F
.29205 .8257 m .29506 .82381 L .29122 .82533 L 0 1 .522 r
F
.30763 .83264 m .29546 .82409 L .29205 .8257 L F
.29546 .82409 m .29506 .82381 L .29205 .8257 L F
.30763 .83264 m .3021 .82694 L .29557 .82403 L F
.29546 .82409 m .29557 .82403 L .29506 .82381 L F
.30763 .83264 m .29557 .82403 L .29546 .82409 L F
.30087 .82152 m .30082 .8215 L .30083 .82154 L 0 1 .521 r
F
.30084 .82152 m .30083 .82153 L .30083 .82155 L 0 1 .475 r
F
.30085 .82154 m .30083 .82155 L .30203 .82889 L F
.30084 .82152 m .30083 .82155 L .30085 .82154 L F
.31679 .82843 m .3021 .82694 L .30763 .83264 L 0 1 .521 r
F
.31664 .83306 m .30086 .82154 L .30203 .82889 L 0 1 .475 r
F
.30086 .82154 m .30084 .82152 L .30085 .82154 L F
.30086 .82154 m .30085 .82154 L .30203 .82889 L F
.30084 .82152 m .30082 .8215 L .30083 .82153 L F
.54633 1.04642 m .53585 1.04296 L .52819 1.0425 L 0 1 .501 r
F
0 g
.52819 1.0425 m
.52832 1.04251 L
s
.35271 1.01464 m .33077 1.00982 L .33654 1.01453 L 0 1 .539 r
F
0 g
.32685 1.01236 m
.33654 1.01453 L
s
.51903 .66203 m
.51935 .6625 L
s
.49742 .9702 m .48888 .96437 L .48192 .96136 L 0 .619 .423 r
F
0 g
.48192 .96136 m
.48888 .96437 L
s
.4762 .95573 m
.48192 .96136 L
s
.70984 .95614 m .70844 .96427 L .71743 .9609 L 0 1 .539 r
F
0 g
.69962 .96526 m
.70844 .96427 L
s
.70381 .96827 m
.70844 .96427 L
s
.41343 1.02321 m .40328 1.02013 L .39426 1.0193 L 0 1 .539 r
F
.4174 1.01802 m .41343 1.02321 L .42212 1.02393 L F
.4174 1.01802 m .40328 1.02013 L .41343 1.02321 L F
0 g
.41343 1.02321 m
.41993 1.0271 L
s
.33097 .85284 m .31425 .84212 L .31626 .84936 L 0 1 .478 r
F
.35847 .81437 m .3435 .81436 L .34506 .81718 L 0 1 .523 r
F
.35847 .81437 m .34688 .81259 L .3435 .81436 L F
.35847 .81437 m .3533 .81259 L .34688 .81259 L F
.36644 .80947 m .3533 .81259 L .35847 .81437 L 0 1 .519 r
F
0 g
.35847 .81437 m
.36466 .81417 L
s
.35847 .81437 m
.36001 .81719 L
s
.33945 .84833 m .33792 .85731 L .34122 .85547 L 0 1 .473 r
F
.33945 .84833 m .33097 .85284 L .33792 .85731 L F
0 g
.33792 .85731 m
.34045 .86429 L
s
.40012 .83658 m .38822 .83163 L .3854 .83374 L 0 1 .511 r
F
.40012 .83658 m .39453 .83285 L .38822 .83163 L F
.40661 .83094 m .39453 .83285 L .40012 .83658 L 0 1 .508 r
F
0 g
.40012 .83658 m
.40244 .84106 L
s
.40012 .83658 m
.40618 .83766 L
s
.45538 .94444 m .43957 .94923 L .43775 .95237 L 0 1 .514 r
F
.45538 .94444 m .44714 .94583 L .43957 .94923 L F
0 g
.45538 .94444 m
.4587 .94543 L
s
.45817 .93814 m .44714 .94583 L .45538 .94444 L 0 1 .506 r
F
0 g
.45538 .94444 m
.45884 .94295 L
s
.49978 .91078 m .486 .92202 L .49133 .92109 L 0 1 .465 r
F
0 g
.48511 .92599 m
.49133 .92109 L
s
.51006 .98131 m
.51008 .98132 L
s
.27598 .83138 m
.27616 .83142 L
s
.27616 .83142 m
.2766 .83151 L
s
.43472 .77858 m
.43989 .77603 L
s
.45033 .7673 m .43875 .77403 L .43989 .77603 L 0 1 .471 r
F
.47841 .48668 m .47236 .49243 L .47452 .49319 L 0 1 .224 r
F
.47841 .48668 m .47334 .48463 L .47236 .49243 L F
.47841 .48668 m .4768 .47501 L .47334 .48463 L F
.47797 .95182 m .46781 .95004 L .4762 .95573 L 0 .776 .46 r
F
.47797 .95182 m .46227 .94448 L .46781 .95004 L F
0 g
.46781 .95003 m
.46781 .95004 L
s
.51154 .62561 m .51087 .56874 L .50994 .57034 L 0 .801 .28 r
F
.51154 .62561 m .51181 .58473 L .51087 .56874 L F
0 g
.51087 .56874 m
.51133 .55082 L
s
.81322 .608 m .82029 .61921 L .82419 .61935 L 0 .348 .265 r
F
0 g
.82029 .61921 m
.82236 .62561 L
s
.4174 1.01802 m .42212 1.02393 L .42359 1.02181 L 0 1 .539 r
F
.44232 1.02446 m .42359 1.02181 L .42212 1.02393 L F
0 g
.42212 1.02393 m
.42889 1.02745 L
s
.41343 1.02321 m
.42212 1.02393 L
s
.54771 1.05283 m
.55261 1.05506 L
s
.43497 .94742 m .43775 .95237 L .43957 .94923 L 0 1 .515 r
F
.43497 .94742 m .43003 .95505 L .43775 .95237 L F
0 g
.43775 .95237 m
.44296 .95391 L
s
.54771 1.05283 m
.55229 1.05311 L
s
.26249 .83656 m
.2625 .83656 L
s
.26512 .83081 m .26252 .83656 L .26634 .83508 L 0 1 .537 r
F
0 g
.2625 .83656 m
.26252 .83656 L
s
.26634 .83508 m
.26641 .83514 L
s
.26634 .83508 m
.26669 .83525 L
s
.26634 .83508 m
.26643 .83511 L
s
.26252 .83656 m
.26257 .83678 L
s
.54953 .38706 m .5475 .40548 L .5464 .40196 L 0 .14 .11 r
F
.54953 .38706 m .55264 .39817 L .5475 .40548 L F
.54953 .38706 m .55836 .38495 L .55264 .39817 L F
0 g
.51806 .66402 m
.51892 .66338 L
s
.80252 .75074 m .80902 .76453 L .81324 .75565 L 0 1 .494 r
F
0 g
.80275 .76962 m
.80902 .76453 L
s
.54983 .50859 m .55653 .48832 L .559 .49276 L 0 .15 .122 r
F
0 g
.55466 .49399 m
.55591 .47748 L
s
.54983 .50859 m .55261 .49508 L .55653 .48832 L 0 .15 .122 r
F
0 g
.55653 .48832 m
.5566 .47093 L
s
.46979 1.0236 m .45065 1.02456 L .4576 1.02775 L 0 1 .538 r
F
0 g
.44907 1.02798 m
.4576 1.02775 L
s
.24585 .83425 m .22878 .81989 L .23022 .82811 L 0 1 .493 r
F
.24585 .83425 m .23281 .81861 L .22878 .81989 L F
.24585 .83425 m .24014 .82477 L .23281 .81861 L F
.25555 .83071 m .24014 .82477 L .24585 .83425 L 0 1 .49 r
F
0 g
.24585 .83425 m
.2473 .83547 L
s
.24585 .83425 m
.24614 .83589 L
s
.45655 .75877 m .45501 .76418 L .45738 .76069 L 0 1 .447 r
F
.45655 .75877 m .45033 .7673 L .45501 .76418 L F
0 g
.45501 .76418 m
.45631 .76608 L
s
.74876 .72177 m .7562 .73672 L .75954 .72829 L 0 1 .464 r
F
0 g
.75057 .74108 m
.7562 .73672 L
s
.7562 .73672 m
.75685 .74488 L
s
.49747 .70741 m .49719 .71278 L .4983 .70874 L 0 1 .3 r
F
.49747 .70741 m .49435 .71746 L .49719 .71278 L F
.50314 .70127 m .4983 .70874 L .49719 .71278 L 0 1 .317 r
F
0 g
.49719 .71278 m
.49841 .7139 L
s
.63522 .44258 m .64915 .51126 L .64434 .47734 L 0 .243 .228 r
F
.63522 .44258 m .64999 .53155 L .64915 .51126 L F
.63522 .44258 m .64626 .52448 L .64999 .53155 L F
.63522 .44258 m .63992 .48617 L .64626 .52448 L F
0 g
.63505 .44117 m
.63522 .44258 L
s
.63499 .48018 m
.63677 .49512 L
s
.63517 .44142 m
.63522 .44258 L
s
.50314 .70127 m .50085 .70381 L .4983 .70874 L 0 1 .317 r
F
.50513 .69209 m .50314 .70127 L .50535 .69665 L 0 1 .236 r
F
.50513 .69209 m .50085 .70381 L .50314 .70127 L F
0 g
.50314 .70127 m
.50436 .7024 L
s
.50114 .5936 m .4964 .55765 L .49518 .56221 L 0 .994 .29 r
F
.50114 .5936 m .49888 .56456 L .4964 .55765 L F
0 g
.49574 .54647 m
.4964 .55765 L
s
.49828 .55085 m
.49868 .55984 L
s
.4269 .78371 m .41419 .78834 L .41545 .79045 L 0 1 .493 r
F
.29931 .96139 m .2779 .9626 L .28242 .96462 L 0 1 .459 r
F
.29931 .96139 m .28118 .96104 L .2779 .9626 L F
.29931 .96139 m .29037 .96052 L .28118 .96104 L F
.30695 .95702 m .29037 .96052 L .29931 .96139 L 0 1 .443 r
F
0 g
.29931 .96139 m
.3082 .96066 L
s
.29931 .96139 m
.30377 .96341 L
s
.49435 .71746 m .4885 .72439 L .48695 .72845 L 0 1 .365 r
F
.49435 .71746 m .49168 .71968 L .4885 .72439 L F
.49747 .70741 m .49168 .71968 L .49435 .71746 L 0 1 .3 r
F
0 g
.49435 .71746 m
.49719 .71278 L
s
.49435 .71746 m
.49552 .71893 L
s
.79179 .74559 m .79848 .75948 L .80252 .75074 L 0 1 .49 r
F
0 g
.79234 .76441 m
.79848 .75948 L
s
.79848 .75948 m
.79859 .76756 L
s
.43003 .95505 m .41375 .95756 L .41186 .9599 L 0 1 .523 r
F
.43003 .95505 m .42154 .95548 L .41375 .95756 L F
0 g
.43003 .95505 m
.43527 .95665 L
s
.43497 .94742 m .42154 .95548 L .43003 .95505 L 0 1 .515 r
F
0 g
.43003 .95505 m
.43775 .95237 L
s
.53188 .62608 m
.53277 .62324 L
s
.53277 .62324 m
.5335 .62088 L
s
.37443 .80448 m .37244 .80908 L .37555 .80702 L 0 1 .513 r
F
0 g
.37555 .80702 m
.38176 .80627 L
s
.37443 .80448 m .36644 .80947 L .37244 .80908 L 0 1 .513 r
F
0 g
.37244 .80908 m
.3742 .81158 L
s
.43897 .92199 m .43149 .91588 L .42455 .91276 L 0 .973 .475 r
F
.48532 .55437 m .4861 .53944 L .48358 .53358 L 0 1 .295 r
F
.48532 .55437 m .48684 .54835 L .4861 .53944 L F
0 g
.4861 .53944 m
.48921 .53919 L
s
.40879 .78998 m .407 .79457 L .40983 .79213 L 0 1 .496 r
F
0 g
.40983 .79213 m
.41545 .79045 L
s
.40879 .78998 m .40148 .79591 L .407 .79457 L 0 1 .496 r
F
0 g
.407 .79457 m
.40861 .79669 L
s
.51842 .63301 m .52329 .59416 L .52443 .57459 L 0 .769 .271 r
F
0 g
.52443 .57459 m
.52575 .56257 L
s
.32163 1.00725 m .3049 1.00607 L .31485 1.01136 L 0 1 .538 r
F
0 g
.31485 1.01136 m
.32425 1.01405 L
s
.53768 .37135 m .54884 .36285 L .54993 .37226 L 0 .257 .124 r
F
0 g
.54884 .36285 m
.55231 .34951 L
s
.5436 .36247 m
.54884 .36285 L
s
.75954 .72829 m .76679 .74286 L .7703 .7344 L 0 1 .472 r
F
0 g
.76103 .74735 m
.76679 .74286 L
s
.76679 .74286 m
.7673 .75096 L
s
.44002 .84116 m .43437 .83812 L .42851 .83771 L 0 1 .503 r
F
.44478 .83454 m .44002 .84116 L .4456 .84142 L 0 1 .498 r
F
.44478 .83454 m .43437 .83812 L .44002 .84116 L F
0 g
.44002 .84116 m
.44291 .84537 L
s
.49472 1.02732 m .50189 1.03331 L .50208 1.03048 L 0 1 .534 r
F
.51983 1.03107 m .50208 1.03048 L .50189 1.03331 L 0 1 .521 r
F
0 g
.50189 1.03331 m
.50962 1.03691 L
s
.49391 1.03416 m
.50189 1.03331 L
s
.50513 .69209 m .50535 .69665 L .50601 .69301 L 0 1 .236 r
F
.50975 .6856 m .50601 .69301 L .50535 .69665 L 0 1 .256 r
F
0 g
.50535 .69665 m
.50659 .69724 L
s
.50314 .70127 m
.50535 .69665 L
s
.35862 1.01016 m .36182 1.01658 L .36407 1.01475 L 0 1 .539 r
F
.35862 1.01016 m .35271 1.01464 L .36182 1.01658 L F
0 g
.36182 1.01658 m
.36801 1.02087 L
s
.78105 .74015 m .78793 .75421 L .79179 .74559 L 0 1 .485 r
F
0 g
.78192 .75898 m
.78793 .75421 L
s
.78793 .75421 m
.78817 .76227 L
s
.33097 .85284 m .31784 .84043 L .31425 .84212 L 0 1 .478 r
F
0 g
.30888 .84465 m
.31626 .84936 L
s
.33097 .85284 m .32501 .84503 L .31784 .84043 L 0 1 .478 r
F
.33945 .84833 m .32501 .84503 L .33097 .85284 L 0 1 .473 r
F
0 g
.33097 .85284 m
.33297 .86006 L
s
.33097 .85284 m
.33792 .85731 L
s
.51983 1.03107 m .52013 1.03889 L .52782 1.03793 L 0 1 .521 r
F
0 g
.52013 1.03889 m
.52819 1.0425 L
s
.48725 .85438 m .48136 .85191 L .47618 .85223 L 0 1 .493 r
F
0 g
.47618 .85223 m
.48136 .85191 L
s
.7703 .7344 m .77737 .74868 L .78105 .74015 L 0 1 .479 r
F
0 g
.77148 .7533 m
.77737 .74868 L
s
.77737 .74868 m
.77774 .75674 L
s
.52833 .45741 m .52667 .45533 L .52605 .46423 L 0 .95 .106 r
F
.52648 .49674 m .52833 .45741 L .52513 .48195 L 0 1 .182 r
F
.38021 .8786 m .37367 .87166 L .36601 .86827 L 0 1 .473 r
F
0 g
.38021 .8786 m
.38266 .88567 L
s
.38666 .87381 m .38021 .8786 L .38697 .88234 L 0 1 .467 r
F
.38666 .87381 m .37367 .87166 L .38021 .8786 L F
.46979 1.0236 m .4761 1.02931 L .47672 1.0268 L 0 1 .538 r
F
.49472 1.02732 m .47672 1.0268 L .4761 1.02931 L 0 1 .534 r
F
0 g
.4761 1.02931 m
.48346 1.03246 L
s
.4679 1.02972 m
.4761 1.02931 L
s
.50696 .86839 m
.50736 .86875 L
s
.50849 .86979 m
.51099 .87209 L
s
.54487 .63158 m .54703 .51542 L .54495 .57634 L 0 .881 .237 r
F
.53967 .61485 m .54495 .57634 L .54703 .51542 L 0 .92 .24 r
F
0 g
.547 .50983 m
.54703 .51542 L
s
.54703 .51542 m
.54753 .50844 L
s
.54094 .51031 m
.54115 .52052 L
s
.54115 .52052 m
.54123 .52489 L
s
.54123 .52489 m
.54123 .5249 L
s
.54171 .51847 m
.54216 .51248 L
s
.54123 .52489 m
.54171 .51847 L
s
.54123 .5249 m
.54123 .52489 L
s
.54986 .6692 m .55254 .52191 L .5502 .59574 L 0 .831 .236 r
F
.54487 .63158 m .5502 .59574 L .55254 .52191 L 0 .881 .237 r
F
0 g
.55254 .52191 m
.55411 .50119 L
s
.55254 .52191 m
.55255 .50851 L
s
.4269 .78371 m .41715 .78572 L .41419 .78834 L 0 1 .493 r
F
.4269 .78371 m .42261 .78374 L .41715 .78572 L F
.43374 .77657 m .42261 .78374 L .4269 .78371 L 0 1 .479 r
F
0 g
.4269 .78371 m
.43209 .78151 L
s
.4269 .78371 m
.42815 .78582 L
s
.51154 .62561 m .50994 .57034 L .50982 .58776 L 0 .801 .28 r
F
0 g
.50865 .55652 m
.50994 .57034 L
s
.48532 .55437 m .48358 .53358 L .48026 .53449 L 0 1 .295 r
F
0 g
.48322 .52359 m
.48358 .53358 L
s
.29876 .97766 m .30023 .98304 L .30318 .98135 L 0 1 .535 r
F
0 g
.30318 .98135 m
.31265 .98214 L
s
.29876 .97766 m .29114 .9817 L .30023 .98304 L 0 1 .535 r
F
0 g
.30023 .98304 m
.30554 .9865 L
s
.725 .96553 m .73749 .96594 L .73437 .96419 L 0 1 .54 r
F
.71743 .9609 m .725 .96553 L .72968 .96152 L 0 1 .539 r
F
.72854 .54133 m .73892 .53709 L .74141 .54801 L 0 .492 .079 r
F
0 g
.73892 .53709 m
.74282 .53959 L
s
.3146 .95263 m .3156 .95608 L .31857 .95425 L 0 1 .423 r
F
0 g
.31857 .95425 m
.32755 .95274 L
s
.3146 .95263 m .30695 .95702 L .3156 .95608 L 0 1 .423 r
F
0 g
.3156 .95608 m
.3204 .95752 L
s
.47797 .95182 m .46326 .94275 L .46227 .94448 L 0 .776 .46 r
F
0 g
.45898 .94301 m
.46227 .94448 L
s
.46227 .94448 m
.46781 .95003 L
s
.48773 .7228 m .48695 .72845 L .4885 .72439 L 0 1 .35 r
F
.48773 .7228 m .48353 .73284 L .48695 .72845 L F
0 g
.48695 .72845 m
.48813 .72991 L
s
.27625 .83153 m
.27641 .8316 L
s
.49742 .9702 m .50342 .97656 L .50365 .97543 L 0 .619 .423 r
F
.51887 .98648 m .50365 .97543 L .50342 .97656 L 0 .324 .248 r
F
0 g
.49644 .97354 m
.50342 .97656 L
s
.50342 .97656 m
.51006 .98131 L
s
.76612 .56758 m .77526 .57296 L .77832 .57754 L 0 .189 0 r
F
0 g
.77808 .57735 m
.77842 .57787 L
s
.37712 .96516 m .37947 .96971 L .38174 .9676 L 0 1 .527 r
F
.37712 .96516 m .37117 .97029 L .37947 .96971 L F
0 g
.37947 .96971 m
.38477 .97191 L
s
.47719 .51403 m .47774 .49549 L .47399 .50032 L 0 1 .276 r
F
0 g
.47774 .49549 m
.47841 .48668 L
s
.6129 .49308 m
.61382 .50967 L
s
.61382 .50967 m
.61426 .51762 L
s
.61428 .51804 m
.61501 .53128 L
s
.61501 .53128 m
.61593 .54778 L
s
.61593 .54778 m
.61658 .5596 L
s
.61658 .5596 m
.6169 .5653 L
s
.6169 .5653 m
.61698 .56672 L
s
.61368 .52295 m
.61391 .53148 L
s
.61391 .53148 m
.61454 .55557 L
s
.61299 .49648 m
.61332 .5093 L
s
.61332 .5093 m
.61353 .517 L
s
.61353 .51726 m
.61368 .52295 L
s
.6129 .49308 m
.61299 .49648 L
s
.3643 .86103 m .34675 .85237 L .34847 .85962 L 0 1 .47 r
F
0 g
.34847 .85961 m
.34847 .85962 L
s
.34122 .85547 m
.34847 .85962 L
s
.38666 .87381 m .38697 .88234 L .38945 .88041 L 0 1 .467 r
F
.40304 .89051 m .38945 .88041 L .38697 .88234 L 0 1 .471 r
F
0 g
.38697 .88234 m
.39039 .88876 L
s
.38021 .8786 m
.38697 .88234 L
s
.45033 .7673 m .4415 .77088 L .43875 .77403 L 0 1 .471 r
F
.45033 .7673 m .44647 .76799 L .4415 .77088 L F
.45655 .75877 m .44647 .76799 L .45033 .7673 L 0 1 .447 r
F
0 g
.45033 .7673 m
.45145 .76931 L
s
.45033 .7673 m
.45501 .76418 L
s
.71436 .51923 m .72334 .5423 L .71771 .53419 L 0 .601 .094 r
F
.71436 .51923 m .72854 .54133 L .72334 .5423 L F
.71436 .51923 m .72981 .53197 L .72854 .54133 L F
0 g
.72642 .51709 m
.72981 .53197 L
s
.72981 .53197 m
.72981 .53197 L
s
.47986 .92595 m .46479 .93504 L .47006 .93507 L 0 1 .49 r
F
0 g
.46329 .93887 m
.47006 .93507 L
s
.44478 .83454 m .4456 .84142 L .44739 .83874 L 0 1 .498 r
F
.45843 .84153 m .44739 .83874 L .4456 .84142 L 0 1 .497 r
F
0 g
.4456 .84142 m
.4487 .84557 L
s
.44002 .84116 m
.4456 .84142 L
s
.24578 .83602 m .22851 .8257 L .23004 .83215 L 0 1 .526 r
F
.24578 .83602 m .23255 .82446 L .22851 .8257 L F
.24578 .83602 m .23996 .82889 L .23255 .82446 L F
.25548 .83251 m .23996 .82889 L .24578 .83602 L F
0 g
.24578 .83602 m
.24615 .83762 L
s
.24578 .83602 m
.24762 .8371 L
s
.42054 .90655 m .41341 .90021 L .40646 .89693 L 0 1 .474 r
F
.42614 .83342 m .41243 .83187 L .41481 .83617 L 0 1 .504 r
F
0 g
.40868 .83537 m
.41481 .83617 L
s
.38651 .82705 m .3854 .83374 L .38822 .83163 L 0 1 .511 r
F
.38651 .82705 m .37924 .83222 L .3854 .83374 L F
0 g
.3854 .83374 m
.38773 .83823 L
s
.50213 .86037 m .5063 .86778 L .50649 .86457 L 0 1 .489 r
F
0 g
.5063 .86778 m
.50696 .86839 L
s
.50137 .86827 m
.5063 .86778 L
s
.35817 .82633 m .35656 .83306 L .35966 .83118 L 0 1 .516 r
F
.35817 .82633 m .3502 .83092 L .35656 .83306 L F
0 g
.35656 .83306 m
.35874 .83782 L
s
.47085 .74672 m .46094 .75539 L .46193 .75721 L 0 1 .428 r
F
0 g
.45738 .76069 m
.46193 .75721 L
s
.26632 .83499 m
.26634 .83508 L
s
.26554 .82917 m
.26573 .83059 L
s
.26579 .83101 m
.26632 .83499 L
s
.26631 .83498 m
.26634 .83508 L
s
.26631 .83495 m
.26634 .83508 L
s
.26556 .83094 m
.26628 .8348 L
s
.26628 .8348 m
.26631 .83495 L
s
.53287 .62379 m
.53325 .62249 L
s
.53258 .62476 m
.53287 .62379 L
s
.53225 .62588 m
.53258 .62476 L
s
.53325 .62249 m
.53332 .62224 L
s
.48353 .73284 m .47677 .73892 L .47479 .7428 L 0 1 .401 r
F
.48353 .73284 m .48051 .73465 L .47677 .73892 L F
.48773 .7228 m .48051 .73465 L .48353 .73284 L 0 1 .35 r
F
0 g
.48353 .73284 m
.48462 .73453 L
s
.48353 .73284 m
.48695 .72845 L
s
.45818 .93699 m .45041 .93104 L .44355 .92798 L 0 .896 .473 r
F
.50213 .86037 m .49615 .85801 L .49122 .8585 L 0 1 .489 r
F
0 g
.49122 .8585 m
.49615 .85801 L
s
.48725 .85438 m
.49122 .8585 L
s
.56303 .48172 m .5653 .51699 L .56275 .50502 L 0 .399 .184 r
F
.56303 .48172 m .56975 .51671 L .5653 .51699 L F
.56303 .48172 m .57309 .50435 L .56975 .51671 L F
.56303 .48172 m .57331 .48103 L .57309 .50435 L F
.47263 .84811 m .46689 .84552 L .46153 .84567 L 0 1 .496 r
F
0 g
.46153 .84567 m
.46689 .84552 L
s
.47263 .84811 m
.47618 .85223 L
s
.29834 .84126 m .28547 .8276 L .28164 .82911 L 0 1 .483 r
F
0 g
.27641 .8316 m
.2828 .83459 L
s
.2766 .83151 m
.28241 .83275 L
s
.29834 .84126 m .29263 .83282 L .28547 .8276 L 0 1 .483 r
F
.30748 .83718 m .29263 .83282 L .29834 .84126 L 0 1 .479 r
F
0 g
.29834 .84126 m
.29994 .84883 L
s
.29834 .84126 m
.3053 .84633 L
s
.49518 .56221 m .48987 .55037 L .49238 .5591 L 0 1 .29 r
F
.49227 .57368 m .48987 .55037 L .48684 .54835 L 0 1 .294 r
F
.49227 .57368 m .49238 .5591 L .48987 .55037 L F
0 g
.48921 .53919 m
.48987 .55037 L
s
.37924 .83222 m .36432 .82832 L .36628 .83299 L 0 1 .514 r
F
0 g
.36601 .86827 m
.37367 .87166 L
s
.57066 .36358 m .56897 .38514 L .56739 .37414 L 0 .55 .143 r
F
.57085 .38313 m .56912 .40067 L .56758 .39494 L 0 .292 .126 r
F
.57066 .36358 m .57497 .3934 L .56897 .38514 L 0 .55 .143 r
F
0 g
.56502 .35655 m
.57066 .36358 L
s
.51756 .66605 m .51618 .66873 L .51533 .6724 L 0 1 .193 r
F
0 g
.51756 .66605 m
.51772 .66597 L
s
.51756 .66605 m
.51806 .66403 L
s
.47797 .95182 m .4762 .95573 L .48293 .95888 L 0 .776 .46 r
F
0 g
.45934 .93831 m
.45937 .93831 L
s
.45937 .93831 m
.4594 .93832 L
s
.4594 .93832 m
.46329 .93887 L
s
.50975 .6856 m .5079 .68827 L .50601 .69301 L 0 1 .256 r
F
.5106 .67873 m .50975 .6856 L .51129 .68162 L 0 1 .172 r
F
.5106 .67873 m .5079 .68827 L .50975 .6856 L F
0 g
.50975 .6856 m
.51099 .6862 L
s
.68097 .95859 m .69262 .96013 L .68981 .95803 L 0 1 .537 r
F
.35271 1.01464 m .33338 1.00813 L .33077 1.00982 L 0 1 .539 r
F
.35271 1.01464 m .3428 1.0102 L .33338 1.00813 L F
.35862 1.01016 m .3428 1.0102 L .35271 1.01464 L F
0 g
.35271 1.01464 m
.35845 1.01933 L
s
.35271 1.01464 m
.36182 1.01658 L
s
.52235 .9881 m
.52436 .98909 L
s
.53127 .99382 m
.53148 .99397 L
s
.5244 .87869 m
.52459 .87866 L
s
.70222 .95124 m .69262 .96013 L .69933 .9595 L 0 1 .538 r
F
.70222 .95124 m .69933 .9595 L .7015 .95686 L F
.70478 .95289 m .70117 .95885 L .70977 .95402 L 0 1 .519 r
F
.70656 .95081 m .71391 .94993 L .7108 .94933 L F
.70222 .95124 m .70156 .95644 L .70474 .95286 L 0 1 .538 r
F
.70588 .95157 m .70977 .95402 L .71391 .94993 L 0 1 .519 r
F
.70478 .95289 m .70977 .95402 L .70588 .95157 L F
.70977 .95402 m .71727 .956 L .72167 .95164 L 0 1 .527 r
F
.70977 .95402 m .72167 .95164 L .71856 .95093 L F
.70586 .95158 m .70984 .95614 L .71398 .95233 L 0 1 .538 r
F
.70222 .95124 m .70474 .95286 L .70586 .95158 L F
.70474 .95286 m .70984 .95614 L .70586 .95158 L F
.70652 .95082 m .70588 .95157 L .70656 .95081 L 0 1 .519 r
F
.70588 .95157 m .71391 .94993 L .70656 .95081 L F
.70647 .95084 m .71398 .95233 L .71083 .95043 L 0 1 .538 r
F
.70222 .95124 m .70586 .95158 L .70647 .95084 L F
.70647 .95084 m .70586 .95158 L .70652 .95082 L 0 1 .519 r
F
.70586 .95158 m .70588 .95157 L .70652 .95082 L F
.70586 .95158 m .71398 .95233 L .70647 .95084 L 0 1 .538 r
F
.70225 .95231 m .70586 .95158 L .70647 .95084 L 0 1 .519 r
F
.70474 .95286 m .70151 .95679 L .70478 .95289 L 0 1 .538 r
F
.70156 .95644 m .70151 .95679 L .70474 .95286 L F
.70151 .95679 m .7015 .95686 L .70478 .95289 L F
.70225 .95231 m .70478 .95289 L .70588 .95157 L 0 1 .519 r
F
.70225 .95231 m .7015 .95686 L .70478 .95289 L F
.7015 .95686 m .70117 .95885 L .70478 .95289 L F
.70478 .95289 m .7015 .95686 L .70481 .95291 L 0 1 .538 r
F
.70481 .95291 m .70119 .95932 L .70984 .95614 L F
.7015 .95686 m .70119 .95932 L .70481 .95291 L F
.70225 .95231 m .69267 .96182 L .69929 .95951 L 0 1 .519 r
F
.69935 .95944 m .69929 .95951 L .69933 .9595 L F
.70225 .95231 m .69929 .95951 L .69935 .95944 L F
.7015 .95686 m .69933 .9595 L .70117 .95885 L F
.70225 .95231 m .69933 .9595 L .7015 .95686 L F
.7015 .95686 m .69933 .9595 L .70119 .95932 L 0 1 .538 r
F
.70222 .95124 m .68981 .95803 L .69262 .96013 L F
0 g
.6901 .96209 m
.69262 .96013 L
s
.69262 .96013 m
.69456 .95995 L
s
.44478 .83454 m .43175 .83392 L .43437 .83812 L 0 1 .498 r
F
0 g
.42851 .83771 m
.43437 .83812 L
s
.52134 .65378 m
.52144 .65362 L
s
.52144 .65362 m
.52147 .65359 L
s
.52147 .65359 m
.5215 .65353 L
s
.5215 .65353 m
.52154 .65346 L
s
.52304 .65101 m
.52309 .65093 L
s
.52182 .653 m
.52183 .653 L
s
.52183 .653 m
.52183 .653 L
s
.52183 .653 m
.52191 .65285 L
s
.52209 .65257 m
.5222 .65238 L
s
.5222 .65238 m
.52233 .65217 L
s
.52241 .65205 m
.52253 .65184 L
s
.52253 .65184 m
.52257 .65179 L
s
.52285 .65132 m
.52304 .65101 L
s
.52329 .65059 m
.52332 .65055 L
s
.52319 .65057 m
.5232 .65057 L
s
.52272 .65065 m
.52272 .65065 L
s
.52272 .65065 m
.52273 .65065 L
s
.52281 .65064 m
.52284 .65063 L
s
.52284 .65063 m
.52288 .65062 L
s
.52292 .65062 m
.52296 .65061 L
s
.52311 .65059 m
.52319 .65057 L
s
.52331 .65055 m
.52332 .65055 L
s
.44232 1.02446 m .43225 1.02204 L .42359 1.02181 L 0 1 .539 r
F
.44527 1.01885 m .44232 1.02446 L .45065 1.02456 L 0 1 .54 r
F
.44527 1.01885 m .43225 1.02204 L .44232 1.02446 L F
0 g
.44232 1.02446 m
.44907 1.02798 L
s
.50321 .58681 m .49888 .56456 L .50099 .57837 L 0 .984 .287 r
F
.50114 .5936 m .50099 .57837 L .49888 .56456 L 0 .994 .29 r
F
0 g
.49868 .55984 m
.49888 .56456 L
s
.4964 .55765 m
.49888 .56456 L
s
.27608 .83149 m
.28325 .8367 L
s
.27597 .83142 m
.27608 .83149 L
s
.28168 .82934 m
.28325 .8367 L
s
.40406 .96137 m .38515 .96442 L .39014 .96645 L 0 1 .526 r
F
0 g
.38174 .9676 m
.39014 .96645 L
s
.4174 1.01802 m .39707 1.01634 L .40328 1.02013 L 0 1 .539 r
F
0 g
.39426 1.0193 m
.40328 1.02013 L
s
.34272 .97112 m .34454 .97601 L .34717 .97411 L 0 1 .531 r
F
.34272 .97112 m .33589 .97571 L .34454 .97601 L F
0 g
.34454 .97601 m
.34977 .97876 L
s
.49227 .57368 m .48684 .54835 L .48532 .55437 L 0 1 .294 r
F
0 g
.48684 .54835 m
.48987 .55037 L
s
.4861 .53944 m
.48684 .54835 L
s
.38666 .87381 m .37087 .86505 L .37367 .87166 L 0 1 .467 r
F
.51038 .62676 m .50855 .57304 L .50763 .57503 L 0 .812 .282 r
F
0 g
.50992 .57335 m
.50994 .57034 L
s
.51038 .62676 m .50982 .58776 L .50855 .57304 L 0 .812 .282 r
F
0 g
.50855 .57304 m
.50865 .55652 L
s
.2457 .83778 m .22825 .83152 L .22986 .8362 L 0 1 .539 r
F
.2457 .83778 m .23228 .83033 L .22825 .83152 L F
.2457 .83778 m .23978 .83302 L .23228 .83033 L F
.2554 .83431 m .23978 .83302 L .2457 .83778 L 0 1 .538 r
F
0 g
.2457 .83778 m
.24724 .84233 L
s
.2457 .83778 m
.25296 .84023 L
s
.7469 .95618 m .73749 .96594 L .74643 .96424 L 0 1 .539 r
F
.7469 .95618 m .73437 .96419 L .73749 .96594 L F
0 g
.73255 .97007 m
.73749 .96594 L
s
.30763 .83264 m
.30909 .8382 L
s
.30763 .83264 m
.31446 .8356 L
s
.37924 .83222 m .36744 .8264 L .36432 .82832 L 0 1 .514 r
F
0 g
.35966 .83118 m
.36628 .83299 L
s
.37924 .83222 m .37383 .82807 L .36744 .8264 L 0 1 .514 r
F
.38651 .82705 m .37383 .82807 L .37924 .83222 L 0 1 .511 r
F
0 g
.37924 .83222 m
.3854 .83374 L
s
.37924 .83222 m
.38117 .83688 L
s
.37117 .97029 m .35111 .97126 L .35605 .97386 L 0 1 .531 r
F
0 g
.34717 .97411 m
.35605 .97386 L
s
.47835 .54159 m .47979 .5265 L .47725 .52293 L 0 1 .295 r
F
.47835 .54159 m .48026 .53449 L .47979 .5265 L F
0 g
.47979 .5265 m
.48322 .52359 L
s
.50513 .69209 m .49997 .70291 L .50085 .70381 L 0 1 .236 r
F
0 g
.4983 .70874 m
.50085 .70381 L
s
.35018 .94239 m .33046 .94689 L .33472 .94793 L 0 1 .412 r
F
.35018 .94239 m .33344 .94505 L .33046 .94689 L F
.35018 .94239 m .34191 .94312 L .33344 .94505 L F
.35704 .9373 m .34191 .94312 L .35018 .94239 L 0 1 .383 r
F
0 g
.35018 .94239 m
.35835 .94026 L
s
.35018 .94239 m
.3544 .94344 L
s
.40661 .83094 m .39245 .82842 L .39453 .83285 L 0 1 .508 r
F
0 g
.38822 .83163 m
.39453 .83285 L
s
.4761 .73717 m .47479 .7428 L .47677 .73892 L 0 1 .387 r
F
.4761 .73717 m .47085 .74672 L .47479 .7428 L F
0 g
.47479 .7428 m
.4759 .74447 L
s
.38972 .92227 m .37156 .92965 L .37566 .92987 L 0 1 .362 r
F
.38972 .92227 m .37421 .92753 L .37156 .92965 L F
.38972 .92227 m .38201 .92436 L .37421 .92753 L F
0 g
.38972 .92227 m
.39377 .92251 L
s
.50114 .5936 m .49518 .56221 L .49614 .57464 L 0 .994 .29 r
F
.3502 .83092 m .33303 .82646 L .33403 .83185 L 0 1 .518 r
F
0 g
.33403 .83185 m
.33403 .83185 L
s
.33403 .83186 m
.33403 .83186 L
s
.53213 .42392 m .5391 .40536 L .53409 .42193 L 0 0 .046 r
F
0 g
.5391 .40536 m
.54201 .39271 L
s
.54454 .51629 m .55261 .49508 L .54983 .50859 L 0 0 .046 r
F
0 g
.55261 .49508 m
.55653 .48832 L
s
.55261 .49508 m
.55291 .48884 L
s
.71727 .956 m .72941 .9536 L .72631 .95279 L 0 1 .531 r
F
.73815 .9416 m .72941 .9536 L .73802 .9495 L 0 1 .53 r
F
.73815 .9416 m .72631 .95279 L .72941 .9536 L F
0 g
.73405 .95488 m
.73714 .95068 L
s
.72476 .95821 m
.72941 .9536 L
s
.72941 .9536 m
.73656 .95019 L
s
.5106 .67873 m .51129 .68162 L .51149 .67897 L 0 1 .172 r
F
.51409 .67261 m .51149 .67897 L .51129 .68162 L 0 1 .178 r
F
0 g
.51129 .68162 m
.51254 .68139 L
s
.50975 .6856 m
.51129 .68162 L
s
.42525 .90157 m .42054 .90655 L .42721 .90981 L 0 .997 .466 r
F
.42525 .90157 m .41341 .90021 L .42054 .90655 L F
0 g
.42054 .90655 m
.42455 .91276 L
s
.49747 .70741 m .49083 .71836 L .49168 .71968 L 0 1 .3 r
F
0 g
.4885 .72439 m
.49168 .71968 L
s
.69977 .5447 m .70594 .5143 L .71025 .52218 L 0 .578 .137 r
F
.69977 .5447 m .70146 .52387 L .70594 .5143 L F
0 g
.70349 .49786 m
.70594 .5143 L
s
.40908 .9557 m .41186 .9599 L .41375 .95756 L 0 1 .521 r
F
.40908 .9557 m .40406 .96137 L .41186 .9599 L F
0 g
.41186 .9599 m
.41713 .96149 L
s
.51944 .63683 m .52563 .5792 L .52329 .59416 L 0 .762 .271 r
F
0 g
.5216 .5868 m
.52233 .56875 L
s
.51978 .58039 m
.52014 .56513 L
s
.5235 .5906 m
.52443 .57459 L
s
.52563 .5792 m
.52584 .57448 L
s
.40148 .79591 m .38804 .79857 L .38934 .80084 L 0 1 .505 r
F
.40148 .79591 m .39117 .79641 L .38804 .79857 L F
.40148 .79591 m .39693 .79527 L .39117 .79641 L F
.40879 .78998 m .39693 .79527 L .40148 .79591 L 0 1 .496 r
F
0 g
.40148 .79591 m
.407 .79457 L
s
.40148 .79591 m
.40276 .79817 L
s
.47559 .84023 m .47263 .84811 L .47773 .84766 L 0 1 .49 r
F
.47559 .84023 m .46689 .84552 L .47263 .84811 L F
.48914 .84611 m .48136 .85191 L .48725 .85438 L 0 1 .487 r
F
.48914 .84611 m .47773 .84766 L .48136 .85191 L F
.47719 .51403 m .47088 .51704 L .47343 .51888 L 0 1 .276 r
F
.47719 .51403 m .47112 .50908 L .47088 .51704 L F
.47719 .51403 m .47399 .50032 L .47112 .50908 L F
0 g
.69165 .61348 m
.69194 .61431 L
s
.44274 .91712 m .43149 .91588 L .43897 .92199 L 0 .936 .467 r
F
.44274 .91712 m .42721 .90981 L .43149 .91588 L F
0 g
.42455 .91276 m
.43149 .91588 L
s
.50321 .58681 m .50407 .58424 L .50345 .57049 L 0 .984 .287 r
F
0 g
.50345 .57049 m
.505 .57862 L
s
.3884 1.01511 m .36745 1.012 L .37334 1.01619 L 0 1 .539 r
F
0 g
.36407 1.01475 m
.37334 1.01619 L
s
.68108 .96301 m .69267 .96182 L .68989 .96097 L 0 1 .518 r
F
.70225 .95231 m .68989 .96097 L .69267 .96182 L 0 1 .519 r
F
0 g
.69929 .95951 m
.69933 .9595 L
s
.69914 .95956 m
.69929 .95951 L
s
.69909 .95958 m
.69914 .95956 L
s
.69301 .9617 m
.69909 .95958 L
s
.69267 .96182 m
.69301 .9617 L
s
.68775 .96534 m
.69267 .96182 L
s
.69933 .9595 m
.69943 .95949 L
s
.6995 .95948 m
.70119 .95932 L
s
.69943 .95949 m
.6995 .95948 L
s
.69682 .96319 m
.69944 .96058 L
s
.69944 .96058 m
.70065 .95937 L
s
.69682 .96323 m
.70119 .95932 L
s
.42525 .90157 m .40967 .89396 L .41341 .90021 L 0 .997 .466 r
F
0 g
.40646 .89693 m
.41341 .90021 L
s
.53274 .37211 m
.53768 .37134 L
s
.5287 .38472 m
.53274 .37211 L
s
.60519 .3764 m .60525 .39311 L .60281 .38332 L 0 .644 .107 r
F
.60519 .3764 m .61162 .40262 L .60525 .39311 L F
.60519 .3764 m .61764 .40544 L .61162 .40262 L F
0 g
.61809 .38513 m
.61895 .38402 L
s
.60519 .3764 m .61999 .39845 L .61764 .40544 L 0 .644 .107 r
F
.60519 .3764 m .61713 .38636 L .61999 .39845 L F
0 g
.61079 .37694 m
.61553 .38399 L
s
.6042 .37484 m
.60519 .3764 L
s
.61746 .38594 m
.61809 .38513 L
s
.61713 .38636 m
.61746 .38594 L
s
.61553 .38399 m
.61713 .38636 L
s
.53512 .54149 m
.5357 .53434 L
s
.5357 .53434 m
.53735 .51409 L
s
.53735 .51409 m
.5381 .50488 L
s
.53225 .62588 m
.53244 .62528 L
s
.53286 .62394 m
.53327 .62266 L
s
.53244 .62528 m
.53286 .62394 L
s
.49227 .57368 m .49341 .56908 L .49238 .5591 L 0 1 .294 r
F
0 g
.49238 .5591 m
.49518 .56221 L
s
.47559 .84023 m .46369 .84129 L .46689 .84552 L 0 1 .49 r
F
.48914 .84611 m .48725 .85438 L .49213 .85372 L 0 1 .487 r
F
0 g
.5239 .98955 m
.52446 .98991 L
s
.5255 .99058 m
.52586 .99081 L
s
.44527 1.01885 m .45065 1.02456 L .45171 1.02226 L 0 1 .54 r
F
.46979 1.0236 m .45171 1.02226 L .45065 1.02456 L 0 1 .538 r
F
0 g
.45065 1.02456 m
.4576 1.02775 L
s
.44232 1.02446 m
.45065 1.02456 L
s
.62296 .44238 m
.6239 .44711 L
s
.62237 .43942 m
.62296 .44238 L
s
.62216 .43837 m
.62237 .43942 L
s
.61747 .4148 m
.62216 .43837 L
s
.51611 .66548 m .51494 .67016 L .51618 .66873 L 0 .922 .137 r
F
.51611 .66547 m .5161 .66548 L .51611 .66548 L F
.5161 .66548 m .51494 .67016 L .51611 .66548 L F
.5173 .66293 m .51713 .66329 L .51734 .66401 L 0 .989 .142 r
F
.51713 .66329 m .51701 .66354 L .51702 .66354 L F
.51713 .66329 m .51702 .66354 L .51734 .66401 L F
.51615 .6667 m .51687 .66424 L .51817 .66102 L 0 0 0 r
F
.51819 .66099 m .51817 .66102 L .5182 .66095 L F
.51615 .6667 m .51817 .66102 L .51819 .66099 L F
.51725 .66307 m .51701 .66354 L .5173 .66293 L F
.51524 .66864 m .51698 .66363 L .51725 .66307 L F
.51698 .66363 m .51701 .66354 L .51725 .66307 L F
.51524 .66864 m .51725 .66307 L .51687 .66424 L F
.51725 .66307 m .5173 .66293 L .51727 .66304 L F
.51725 .66307 m .51727 .66304 L .51687 .66424 L F
.5161 .66544 m .51609 .66551 L .51611 .66547 L 0 .922 .137 r
F
.51609 .66551 m .51494 .67016 L .51611 .66547 L F
0 g
.51533 .6724 m
.51618 .66873 L
s
.3374 .81398 m .33323 .81967 L .33765 .81739 L 0 1 .523 r
F
0 g
.33765 .81739 m
.34506 .81718 L
s
.3374 .81398 m .32611 .81943 L .33323 .81967 L 0 1 .523 r
F
0 g
.33323 .81967 m
.33428 .82309 L
s
.32611 .81943 m
.33323 .81967 L
s
.32611 .81943 m
.32722 .82274 L
s
.30125 .82157 m .30473 .81998 L .30091 .82152 L 0 1 .531 r
F
.31694 .8238 m .30487 .82003 L .30125 .82157 L F
.30487 .82003 m .30473 .81998 L .30125 .82157 L F
.31694 .8238 m .31158 .82095 L .30467 .81996 L F
.32611 .81943 m .31158 .82095 L .31694 .8238 L 0 1 .528 r
F
.32611 .81943 m .31044 .81763 L .31158 .82095 L F
.32597 .82416 m .31049 .81765 L .31152 .82293 L 0 1 .52 r
F
.31049 .81765 m .31045 .81767 L .31152 .82293 L F
.32597 .82416 m .32343 .83121 L .32702 .82944 L F
.32597 .82416 m .31679 .82843 L .32343 .83121 L F
.30091 .82152 m .30467 .81996 L .30082 .8215 L 0 1 .531 r
F
.30473 .81998 m .30467 .81996 L .30091 .82152 L F
.30164 .82186 m .30467 .81996 L .30082 .8215 L 0 1 .521 r
F
.31679 .82843 m .30506 .82024 L .30164 .82186 L F
.30506 .82024 m .30467 .81996 L .30164 .82186 L F
.31679 .82843 m .31152 .82293 L .30518 .82018 L F
.30506 .82024 m .30518 .82018 L .30467 .81996 L F
.31679 .82843 m .30518 .82018 L .30506 .82024 L F
.31049 .81765 m .31044 .81763 L .31045 .81767 L 0 1 .52 r
F
.31047 .81765 m .31044 .81766 L .31045 .81768 L 0 1 .471 r
F
.31047 .81767 m .31045 .81768 L .31145 .82492 L F
.31047 .81765 m .31045 .81768 L .31047 .81767 L F
.32597 .82416 m .31152 .82293 L .31679 .82843 L 0 1 .52 r
F
.32582 .82888 m .31049 .81766 L .31145 .82492 L 0 1 .471 r
F
.31049 .81766 m .31047 .81765 L .31047 .81767 L F
.31049 .81766 m .31047 .81767 L .31145 .82492 L F
.31047 .81765 m .31044 .81763 L .31044 .81766 L F
.47085 .74672 m .46332 .7518 L .46094 .75539 L 0 1 .428 r
F
.47085 .74672 m .46757 .74808 L .46332 .7518 L F
.4761 .73717 m .46757 .74808 L .47085 .74672 L 0 1 .387 r
F
0 g
.47085 .74672 m
.47183 .74855 L
s
.47085 .74672 m
.47479 .7428 L
s
.25555 .83071 m .23887 .81668 L .24014 .82477 L 0 1 .49 r
F
.25555 .83071 m .24291 .81538 L .23887 .81668 L F
.25555 .83071 m .25006 .82141 L .24291 .81538 L F
.26527 .82714 m .25006 .82141 L .25555 .83071 L 0 1 .488 r
F
0 g
.25555 .83071 m
.25702 .83195 L
s
.25555 .83071 m
.25581 .83239 L
s
.3502 .83092 m .33746 .82425 L .33303 .82646 L 0 1 .518 r
F
0 g
.32702 .82944 m
.33403 .83186 L
s
.3502 .83092 m .34482 .82616 L .33746 .82425 L 0 1 .518 r
F
0 g
.3502 .83092 m
.35118 .83631 L
s
.35817 .82633 m .34482 .82616 L .3502 .83092 L 0 1 .516 r
F
0 g
.3502 .83092 m
.35656 .83306 L
s
.75155 .7775 m .75728 .79094 L .76203 .78714 L 0 .781 .456 r
F
0 g
.75676 .7965 m
.75728 .79094 L
s
.75338 .79089 m
.75728 .79094 L
s
.44274 .91712 m .43897 .92199 L .44563 .92513 L 0 .936 .467 r
F
0 g
.43897 .92199 m
.44355 .92798 L
s
.28555 .82762 m
.28574 .82766 L
s
.28574 .82766 m
.28622 .82775 L
s
.37117 .97029 m .35375 .96936 L .35111 .97126 L 0 1 .531 r
F
.37117 .97029 m .36235 .96894 L .35375 .96936 L F
.37712 .96516 m .36235 .96894 L .37117 .97029 L 0 1 .527 r
F
0 g
.37117 .97029 m
.37947 .96971 L
s
.37117 .97029 m
.37607 .97289 L
s
.43957 .94923 m
.44714 .94583 L
s
.45817 .93814 m .44199 .94511 L .44714 .94583 L 0 1 .506 r
F
0 g
.44713 .94583 m
.44714 .94583 L
s
.31679 .82843 m
.32343 .83121 L
s
.32343 .83121 m
.32527 .83642 L
s
.27204 .83285 m
.27205 .83285 L
s
.27485 .82728 m .27207 .83285 L .27589 .83136 L 0 1 .536 r
F
0 g
.27205 .83285 m
.27207 .83285 L
s
.27589 .83136 m
.27597 .83142 L
s
.27589 .83136 m
.27625 .83153 L
s
.27589 .83136 m
.27598 .83138 L
s
.27207 .83285 m
.27212 .83308 L
s
.50055 .90488 m .50537 .90613 L .50555 .90378 L 0 1 .451 r
F
.50055 .90488 m .49978 .91078 L .50537 .90613 L F
0 g
.50537 .90613 m
.51071 .90403 L
s
.67876 .50613 m .68506 .54208 L .68092 .53531 L 0 .678 .17 r
F
.67876 .50613 m .68929 .52783 L .68506 .54208 L F
0 g
.67876 .50613 m
.68092 .53531 L
s
.67469 .52355 m
.67876 .50613 L
s
.55581 1.05368 m
.55656 1.05434 L
s
.79003 .58912 m .79853 .59435 L .79388 .5905 L 0 .217 .206 r
F
.79003 .58912 m .80163 .59909 L .79853 .59435 L F
.51038 .62676 m .50763 .57503 L .50786 .59166 L 0 .812 .282 r
F
0 g
.50602 .56315 m
.50763 .57503 L
s
.48532 .55437 m .48026 .53449 L .47835 .54159 L 0 1 .295 r
F
0 g
.48026 .53449 m
.48358 .53358 L
s
.47979 .5265 m
.48026 .53449 L
s
.51983 1.03107 m .50977 1.02952 L .50208 1.03048 L 0 1 .521 r
F
.40304 .89051 m .39634 .88391 L .38945 .88041 L 0 1 .471 r
F
.49978 .91078 m .48659 .91946 L .486 .92202 L 0 1 .465 r
F
.49978 .91078 m .49251 .91464 L .48659 .91946 L F
.50055 .90488 m .49251 .91464 L .49978 .91078 L 0 1 .451 r
F
0 g
.49978 .91078 m
.5051 .90986 L
s
.49978 .91078 m
.50537 .90613 L
s
.31664 .83306 m .31425 .84212 L .31784 .84043 L 0 1 .475 r
F
0 g
.31679 .82843 m
.31804 .83385 L
s
.31664 .83306 m .30748 .83718 L .31425 .84212 L 0 1 .475 r
F
0 g
.31425 .84212 m
.31626 .84936 L
s
.53213 .42392 m .52983 .43541 L .52919 .43672 L 0 0 .046 r
F
.53213 .42392 m .53409 .42193 L .52983 .43541 L F
.36644 .80947 m .35194 .80991 L .3533 .81259 L 0 1 .519 r
F
.36644 .80947 m .35533 .80811 L .35194 .80991 L F
.36644 .80947 m .36155 .80793 L .35533 .80811 L F
.37443 .80448 m .36155 .80793 L .36644 .80947 L 0 1 .513 r
F
0 g
.36644 .80947 m
.37244 .80908 L
s
.36644 .80947 m
.36777 .81215 L
s
.45843 .84153 m .45289 .83878 L .44739 .83874 L 0 1 .497 r
F
0 g
.44739 .83874 m
.45289 .83878 L
s
.45843 .84153 m
.46153 .84567 L
s
.51983 1.03107 m .52782 1.03793 L .52757 1.03467 L 0 1 .521 r
F
.54494 1.03887 m .52782 1.03793 L .53585 1.04296 L 0 1 .485 r
F
.54494 1.03887 m .52757 1.03467 L .52782 1.03793 L F
0 g
.52013 1.03889 m
.52782 1.03793 L
s
.5106 .67873 m .507 .68803 L .5079 .68827 L 0 1 .172 r
F
0 g
.50601 .69301 m
.5079 .68827 L
s
.50213 .86037 m
.50649 .86457 L
s
.50649 .86457 m
.51113 .86383 L
s
.40866 .88553 m .40304 .89051 L .40967 .89396 L 0 1 .464 r
F
.40866 .88553 m .39634 .88391 L .40304 .89051 L F
0 g
.40304 .89051 m
.40646 .89693 L
s
.49472 1.02732 m .4847 1.02594 L .47672 1.0268 L 0 1 .534 r
F
0 g
.52358 .64841 m
.52359 .64838 L
s
.52359 .64838 m
.52367 .64816 L
s
.44088 .76887 m .43875 .77403 L .4415 .77088 L 0 1 .459 r
F
.44088 .76887 m .43374 .77657 L .43875 .77403 L F
0 g
.43875 .77403 m
.43989 .77603 L
s
.57317 .49584 m
.57331 .48103 L
s
.46242 .83398 m .45843 .84152 L .46369 .84129 L 0 1 .492 r
F
.46242 .83398 m .45289 .83878 L .45843 .84152 L F
.33945 .84833 m .32323 .83787 L .32501 .84503 L 0 1 .473 r
F
0 g
.31784 .84043 m
.32501 .84503 L
s
.52465 .55362 m .52968 .48204 L .52648 .49674 L 0 1 .238 r
F
.52465 .55362 m .5313 .49064 L .52968 .48204 L F
0 g
.52968 .48204 m
.53074 .47384 L
s
.44527 1.01885 m .4258 1.01863 L .43225 1.02204 L 0 1 .54 r
F
0 g
.42359 1.02181 m
.43225 1.02204 L
s
.48773 .7228 m .47974 .73307 L .48051 .73465 L 0 1 .35 r
F
0 g
.47677 .73892 m
.48051 .73465 L
s
.50294 .85163 m .49615 .858 L .50213 .86037 L 0 1 .483 r
F
.50294 .85163 m .49213 .85372 L .49615 .858 L F
0 g
.45934 .93831 m
.45936 .93833 L
s
.47797 .95182 m .46999 .9459 L .46326 .94275 L 0 .776 .46 r
F
0 g
.45936 .93833 m
.46326 .94275 L
s
.70222 .95124 m .69391 .95422 L .68981 .95803 L 0 1 .538 r
F
0 g
.68097 .95859 m
.68981 .95803 L
s
.54494 1.03887 m .53585 1.04296 L .54633 1.04642 L 0 1 .485 r
F
0 g
.52782 1.03793 m
.53585 1.04296 L
s
.52832 1.04251 m
.53585 1.04296 L
s
.40406 .96137 m .38742 .9623 L .38515 .96442 L 0 1 .526 r
F
.40406 .96137 m .39554 .96099 L .38742 .9623 L F
.40908 .9557 m .39554 .96099 L .40406 .96137 L 0 1 .521 r
F
0 g
.40406 .96137 m
.40903 .9634 L
s
.40406 .96137 m
.41186 .9599 L
s
.48165 .91966 m .486 .92202 L .48659 .91946 L 0 1 .477 r
F
.48165 .91966 m .47986 .92595 L .486 .92202 L F
0 g
.486 .92202 m
.49133 .92109 L
s
.76203 .78714 m .76752 .79994 L .77248 .79603 L 0 .827 .466 r
F
0 g
.76682 .8054 m
.76752 .79994 L
s
.76078 .80014 m
.76752 .79994 L
s
.53242 .62676 m
.53264 .626 L
s
.53264 .626 m
.53298 .62484 L
s
.47835 .54159 m .47725 .52293 L .47363 .52611 L 0 1 .295 r
F
0 g
.47719 .51403 m
.47725 .52293 L
s
.41312 .82514 m .41243 .83187 L .41494 .82951 L 0 1 .504 r
F
.41312 .82514 m .40661 .83094 L .41243 .83187 L F
.42614 .83342 m .41494 .82951 L .41243 .83187 L F
0 g
.41243 .83187 m
.41481 .83617 L
s
.25548 .83251 m .23861 .8226 L .23996 .82889 L 0 1 .526 r
F
.25548 .83251 m .24265 .82135 L .23861 .8226 L F
.25548 .83251 m .24989 .82561 L .24265 .82135 L F
.26519 .82898 m .24989 .82561 L .25548 .83251 L 0 1 .525 r
F
0 g
.25548 .83251 m
.25582 .83416 L
s
.25548 .83251 m
.25737 .8336 L
s
.36392 .9322 m .36494 .93495 L .36759 .93283 L 0 1 .348 r
F
0 g
.36759 .93283 m
.37566 .92987 L
s
.36392 .9322 m .35704 .9373 L .36494 .93495 L 0 1 .348 r
F
0 g
.36494 .93495 m
.36933 .9354 L
s
.38244 .79938 m .38023 .80389 L .38335 .80178 L 0 1 .506 r
F
0 g
.38335 .80178 m
.38934 .80084 L
s
.38244 .79938 m .37443 .80448 L .38023 .80389 L 0 1 .506 r
F
0 g
.38023 .80389 m
.38176 .80627 L
s
.47559 .84023 m .47773 .84766 L .47879 .84447 L 0 1 .49 r
F
.48914 .84611 m .47879 .84447 L .47773 .84766 L 0 1 .487 r
F
0 g
.47773 .84766 m
.48136 .85191 L
s
.47263 .84811 m
.47773 .84766 L
s
.75448 .5547 m .76668 .56568 L .76612 .56758 L 0 .272 0 r
F
0 g
.76668 .56568 m
.77059 .56798 L
s
.76359 .55995 m
.76668 .56568 L
s
.7469 .95618 m .73839 .96001 L .73437 .96419 L 0 1 .539 r
F
0 g
.725 .96553 m
.73437 .96419 L
s
.46096 .93202 m .46032 .93343 L .46479 .93504 L 0 1 .495 r
F
.46032 .93343 m .45942 .93756 L .46479 .93504 L F
.46096 .93236 m .46032 .93343 L .46475 .94009 L 0 .853 .464 r
F
.46032 .93343 m .45818 .93699 L .4594 .93757 L F
.46032 .93343 m .4594 .93757 L .45942 .93756 L 0 1 .495 r
F
.46032 .93343 m .4594 .93757 L .46475 .94009 L 0 .853 .464 r
F
.46032 .93343 m .45817 .93814 L .4594 .93757 L 0 1 .495 r
F
.46025 .93355 m .45041 .93104 L .45818 .93699 L 0 .853 .464 r
F
.46028 .93342 m .45041 .93104 L .46025 .93355 L F
.46096 .93202 m .46056 .93231 L .46032 .93343 L 0 1 .495 r
F
.46056 .93231 m .46056 .93231 L .46032 .93343 L 0 .853 .464 r
F
.46056 .93231 m .45041 .93104 L .46032 .93343 L F
.46032 .93343 m .46028 .93342 L .46025 .93355 L F
.46032 .93343 m .45032 .93977 L .45817 .93814 L 0 1 .495 r
F
.46056 .93231 m .45032 .93977 L .46032 .93343 L F
.46056 .93231 m .44548 .93926 L .45032 .93977 L F
.46061 .93213 m .45359 .9263 L .44702 .9232 L 0 .853 .464 r
F
.46096 .93202 m .46059 .93219 L .46056 .93231 L 0 1 .495 r
F
.46096 .93236 m .46063 .93209 L .46061 .93213 L 0 .853 .464 r
F
.46063 .93209 m .45359 .9263 L .46061 .93213 L F
.46055 .93231 m .44563 .92513 L .45041 .93104 L F
.46096 .93236 m .46059 .93219 L .46055 .93231 L F
.46059 .93219 m .44563 .92513 L .46055 .93231 L F
.46059 .93219 m .44688 .93696 L .44548 .93926 L 0 1 .495 r
F
.46096 .93202 m .46479 .93504 L .46579 .93253 L F
.46377 .92611 m .46096 .93202 L .46729 .92884 L 0 1 .48 r
F
.46377 .92611 m .46729 .92884 L .46829 .92642 L F
.46658 .92049 m .46377 .92611 L .4698 .9229 L 0 1 .459 r
F
.46658 .92049 m .4698 .9229 L .4708 .9206 L F
.4694 .91519 m .46658 .92049 L .47231 .91727 L 0 1 .43 r
F
.4694 .91519 m .47231 .91727 L .47332 .91512 L F
.47223 .91024 m .4694 .91519 L .47483 .912 L 0 1 .392 r
F
.47223 .91024 m .47172 .91065 L .4694 .91519 L F
.47172 .91065 m .47127 .91064 L .47092 .91176 L 0 .715 .425 r
F
.47172 .91065 m .47092 .91176 L .4709 .91183 L F
.47127 .91064 m .46322 .91047 L .46827 .91555 L F
.47172 .91065 m .4683 .91558 L .4694 .91519 L 0 1 .392 r
F
.4694 .91519 m .46766 .91656 L .46658 .92049 L 0 1 .43 r
F
.47127 .91064 m .46827 .91555 L .46829 .91557 L 0 .715 .425 r
F
.46728 .91654 m .45999 .91607 L .4651 .92087 L 0 .745 .435 r
F
.46536 .92042 m .4651 .92087 L .46513 .9209 L F
.46728 .91654 m .4651 .92087 L .46536 .92042 L F
.46765 .91656 m .46517 .92095 L .46658 .92049 L 0 1 .43 r
F
.46658 .92049 m .46456 .92206 L .46377 .92611 L 0 1 .459 r
F
.46728 .91654 m .46513 .9209 L .46515 .92092 L 0 .745 .435 r
F
.46421 .92204 m .45678 .92133 L .4625 .92637 L 0 .778 .445 r
F
.46284 .92565 m .4625 .92637 L .46255 .92641 L F
.46421 .92204 m .4625 .92637 L .46284 .92565 L F
.46454 .92207 m .4626 .92645 L .46377 .92611 L 0 1 .459 r
F
.46377 .92611 m .46223 .92728 L .46096 .93202 L 0 1 .48 r
F
.46421 .92204 m .46255 .92641 L .46257 .92643 L 0 .778 .445 r
F
.46221 .92729 m .45359 .9263 L .46051 .93199 L 0 .814 .455 r
F
.46221 .92729 m .46051 .93199 L .46064 .9321 L F
.46059 .93219 m .44702 .9232 L .44563 .92513 L 0 .853 .464 r
F
.4606 .93218 m .46061 .93216 L .46059 .93219 L 0 1 .495 r
F
.46062 .93214 m .46061 .93214 L .4606 .93218 L F
.46096 .93236 m .46062 .93214 L .46059 .93219 L 0 .853 .464 r
F
.46062 .93214 m .44702 .9232 L .46059 .93219 L F
.46061 .93216 m .46061 .93214 L .46059 .93219 L 0 1 .495 r
F
.46221 .92729 m .44898 .93355 L .45352 .93385 L 0 1 .48 r
F
.46221 .92729 m .44911 .92024 L .45359 .9263 L 0 .814 .455 r
F
.46223 .92728 m .46221 .92729 L .46221 .92729 L 0 1 .48 r
F
.46376 .92747 m .4624 .9268 L .46221 .92729 L 0 .814 .455 r
F
.4624 .9268 m .44911 .92024 L .46217 .92728 L F
.4624 .9268 m .45038 .93131 L .44898 .93355 L 0 1 .48 r
F
.4624 .9268 m .45051 .91823 L .44911 .92024 L 0 .814 .455 r
F
.46243 .92679 m .4624 .9268 L .4624 .9268 L 0 1 .48 r
F
.46376 .92747 m .46251 .9266 L .4624 .9268 L 0 .814 .455 r
F
.46251 .9266 m .45051 .91823 L .4624 .9268 L F
.4624 .9268 m .45038 .93131 L .4624 .9268 L 0 1 .48 r
F
.4624 .9268 m .46217 .92728 L .46221 .92729 L 0 .814 .455 r
F
.46221 .92729 m .44898 .93355 L .46221 .92729 L 0 1 .48 r
F
.46377 .92611 m .46252 .9266 L .46243 .92679 L F
.46251 .9266 m .45678 .92133 L .45051 .91823 L 0 .814 .455 r
F
.46377 .92611 m .46243 .92679 L .46223 .92728 L 0 1 .48 r
F
.4626 .92645 m .45678 .92133 L .46251 .9266 L 0 .814 .455 r
F
.46377 .92611 m .45672 .92812 L .45038 .93131 L 0 1 .48 r
F
.46376 .92747 m .4626 .92645 L .46251 .9266 L 0 .814 .455 r
F
.46252 .9266 m .46251 .9266 L .46243 .92679 L 0 1 .48 r
F
.46251 .9266 m .45038 .93131 L .4624 .9268 L F
.46251 .9266 m .4624 .9268 L .46243 .92679 L F
.46417 .92255 m .46257 .92643 L .4626 .92645 L 0 .778 .445 r
F
.46409 .92341 m .4626 .92645 L .46376 .92747 L F
.46417 .92255 m .4626 .92645 L .46409 .92341 L F
.46421 .92204 m .46257 .92643 L .46417 .92255 L F
.46243 .92679 m .44898 .93355 L .46223 .92728 L 0 1 .48 r
F
.46454 .92207 m .45249 .92802 L .45672 .92812 L 0 1 .459 r
F
.46454 .92207 m .45261 .91513 L .45678 .92133 L 0 .778 .445 r
F
.46456 .92206 m .46455 .92206 L .46454 .92207 L 0 1 .459 r
F
.46657 .92226 m .46488 .9214 L .46454 .92207 L 0 .778 .445 r
F
.46488 .9214 m .45261 .91513 L .4645 .92205 L F
.46488 .9214 m .45389 .92587 L .45249 .92802 L 0 1 .459 r
F
.46488 .9214 m .45401 .91302 L .45261 .91513 L 0 .778 .445 r
F
.46491 .92138 m .46488 .92139 L .46488 .9214 L 0 1 .459 r
F
.46657 .92226 m .46505 .92114 L .46488 .9214 L 0 .778 .445 r
F
.46505 .92114 m .45401 .91302 L .46488 .9214 L F
.46488 .92139 m .45389 .92587 L .46488 .9214 L 0 1 .459 r
F
.46488 .9214 m .4645 .92205 L .46454 .92207 L 0 .778 .445 r
F
.46455 .92206 m .45249 .92802 L .46454 .92207 L 0 1 .459 r
F
.46658 .92049 m .46506 .92114 L .46491 .92138 L F
.46505 .92114 m .45999 .91607 L .45401 .91302 L 0 .778 .445 r
F
.46658 .92049 m .46491 .92138 L .46456 .92206 L 0 1 .459 r
F
.46517 .92095 m .45999 .91607 L .46505 .92114 L 0 .778 .445 r
F
.46658 .92049 m .45994 .92264 L .45389 .92587 L 0 1 .459 r
F
.46657 .92226 m .46517 .92095 L .46505 .92114 L 0 .778 .445 r
F
.46506 .92114 m .46505 .92114 L .46491 .92138 L 0 1 .459 r
F
.46505 .92114 m .45389 .92587 L .46488 .92139 L F
.46505 .92114 m .46488 .92139 L .46491 .92138 L F
.46723 .91694 m .46515 .92092 L .46517 .92095 L 0 .745 .435 r
F
.46714 .91766 m .46517 .92095 L .46657 .92226 L F
.46723 .91694 m .46517 .92095 L .46714 .91766 L F
.46728 .91654 m .46515 .92092 L .46723 .91694 L F
.46491 .92138 m .45249 .92802 L .46456 .92206 L 0 1 .459 r
F
.46765 .91656 m .456 .92272 L .45994 .92264 L 0 1 .43 r
F
.46761 .91656 m .45612 .90975 L .45999 .91607 L 0 .745 .435 r
F
.46939 .91668 m .46802 .91596 L .46761 .91656 L F
.46802 .91596 m .45612 .90975 L .46761 .91656 L F
.46802 .91596 m .45741 .92067 L .456 .92272 L 0 1 .43 r
F
.46802 .91596 m .45753 .90751 L .45612 .90975 L 0 .745 .435 r
F
.46805 .91595 m .46803 .91596 L .46802 .91596 L 0 1 .43 r
F
.4694 .91519 m .46805 .91595 L .46766 .91656 L F
.46939 .91668 m .46819 .91574 L .46802 .91596 L 0 .745 .435 r
F
.46819 .91574 m .45753 .90751 L .46802 .91596 L F
.46803 .91596 m .45741 .92067 L .46802 .91596 L 0 1 .43 r
F
.4694 .91519 m .46819 .91574 L .46805 .91595 L F
.46819 .91574 m .46322 .91047 L .45753 .90751 L 0 .745 .435 r
F
.4683 .91558 m .46322 .91047 L .46819 .91574 L F
.4694 .91519 m .46316 .91744 L .45741 .92067 L 0 1 .43 r
F
.46939 .91668 m .4683 .91558 L .46819 .91574 L 0 .745 .435 r
F
.46819 .91574 m .46819 .91574 L .46805 .91595 L 0 1 .43 r
F
.46819 .91574 m .45741 .92067 L .46803 .91596 L F
.46819 .91574 m .46803 .91596 L .46805 .91595 L F
.47113 .91111 m .46829 .91557 L .4683 .91558 L 0 .715 .425 r
F
.47085 .91199 m .4683 .91558 L .46939 .91668 L F
.47113 .91111 m .4683 .91558 L .47085 .91199 L F
.47127 .91064 m .46829 .91557 L .47113 .91111 L F
.46805 .91595 m .456 .92272 L .46766 .91656 L 0 1 .43 r
F
.47172 .91065 m .45953 .91769 L .46316 .91744 L 0 1 .392 r
F
.47185 .91047 m .46106 .90164 L .45965 .90403 L 0 .715 .425 r
F
.4719 .9104 m .46106 .90164 L .47185 .91047 L F
.4717 .91065 m .45965 .90403 L .46322 .91047 L F
.47223 .91066 m .47185 .91047 L .4717 .91065 L F
.47185 .91047 m .45965 .90403 L .4717 .91065 L F
.47191 .9104 m .46645 .90448 L .46106 .90164 L F
.47223 .91066 m .47194 .91036 L .47191 .9104 L F
.47194 .91036 m .46645 .90448 L .47191 .9104 L F
.47185 .91047 m .46095 .91577 L .45953 .91769 L 0 1 .392 r
F
.4752 .90387 m .46645 .90448 L .47194 .91036 L 0 .685 .415 r
F
.47223 .91024 m .47191 .9104 L .47186 .91046 L 0 1 .392 r
F
.47276 .90939 m .47194 .91036 L .47223 .91024 L 0 1 .339 r
F
.47566 .90584 m .47223 .91024 L .47739 .90707 L F
.48524 .90831 m .47332 .91512 L .47231 .91727 L 0 1 .435 r
F
.48524 .90831 m .47886 .91128 L .47332 .91512 L F
.48704 .9033 m .47483 .912 L .47886 .91128 L 0 1 .401 r
F
.48704 .9033 m .47584 .91 L .47483 .912 L F
.48704 .9033 m .48108 .90627 L .47584 .91 L F
.47223 .91024 m .47483 .912 L .47584 .91 L 0 1 .392 r
F
.47565 .90583 m .47223 .91066 L .47736 .91325 L 0 .685 .415 r
F
.4752 .90387 m .47283 .90928 L .47565 .90583 L F
.47565 .90583 m .47283 .90928 L .47566 .90584 L 0 1 .339 r
F
.47283 .90928 m .47223 .91024 L .47566 .90584 L F
.47283 .90928 m .47223 .91066 L .47565 .90583 L 0 .685 .415 r
F
.47519 .90551 m .47283 .90928 L .47565 .90583 L 0 1 .339 r
F
.47283 .90928 m .47194 .91036 L .47276 .90939 L F
.47283 .90928 m .47201 .91027 L .47272 .90941 L 0 .685 .415 r
F
.47519 .90551 m .47194 .91036 L .47283 .90928 L 0 1 .339 r
F
.47194 .91036 m .47194 .91036 L .47283 .90928 L F
.47272 .90941 m .47194 .91036 L .47195 .91036 L 0 .685 .415 r
F
.47201 .91027 m .47194 .91036 L .47272 .90941 L F
.47283 .90928 m .47195 .91036 L .47223 .91066 L F
.47283 .90928 m .47195 .91036 L .47283 .90928 L F
.4752 .90387 m .47194 .91036 L .47283 .90928 L F
.47197 .91032 m .47194 .91036 L .47194 .91036 L 0 1 .339 r
F
.47194 .91036 m .47194 .91036 L .47201 .91027 L 0 .685 .415 r
F
.47194 .91036 m .47201 .91027 L .47283 .90928 L F
.47186 .91046 m .47191 .9104 L .47185 .91047 L 0 1 .392 r
F
.47191 .9104 m .47191 .9104 L .47186 .91046 L F
.47191 .9104 m .46095 .91577 L .47185 .91047 L F
.47519 .90551 m .46639 .91257 L .47194 .91036 L 0 1 .339 r
F
.47519 .90551 m .47194 .91036 L .47197 .91032 L F
.47223 .91024 m .47185 .91047 L .47172 .91065 L 0 1 .392 r
F
.47223 .91066 m .4719 .9104 L .47185 .91047 L 0 .715 .425 r
F
.47185 .91047 m .47185 .91047 L .47181 .91052 L 0 1 .392 r
F
.47185 .91047 m .47181 .91052 L .47172 .91065 L F
.47185 .91047 m .45953 .91769 L .47172 .91065 L F
.47172 .91065 m .46316 .91744 L .4683 .91558 L F
.47223 .91066 m .47172 .91065 L .46939 .91668 L 0 .715 .425 r
F
.47172 .91065 m .4709 .91183 L .46939 .91668 L F
.46766 .91656 m .46765 .91656 L .46765 .91657 L 0 1 .43 r
F
.46766 .91656 m .46765 .91657 L .46658 .92049 L F
.46765 .91656 m .46728 .91654 L .46717 .91742 L 0 .745 .435 r
F
.46765 .91656 m .45994 .92264 L .46517 .92095 L 0 1 .43 r
F
.46939 .91668 m .46765 .91656 L .46657 .92226 L 0 .745 .435 r
F
.46765 .91656 m .46717 .91742 L .46657 .92226 L F
.46456 .92206 m .46454 .92207 L .46454 .9221 L 0 1 .459 r
F
.46456 .92206 m .46454 .9221 L .46377 .92611 L F
.46454 .92207 m .46421 .92204 L .46413 .923 L 0 .778 .445 r
F
.46454 .92207 m .45672 .92812 L .4626 .92645 L 0 1 .459 r
F
.46657 .92226 m .46454 .92207 L .46376 .92747 L 0 .778 .445 r
F
.46454 .92207 m .46413 .923 L .46376 .92747 L F
.46223 .92728 m .46221 .92729 L .46217 .92743 L 0 1 .48 r
F
.46223 .92728 m .46217 .92743 L .46096 .93202 L F
.46221 .92729 m .45352 .93385 L .46064 .9321 L F
.46221 .92729 m .46064 .9321 L .46096 .93202 L F
.4625 .92733 m .46221 .92729 L .46064 .9321 L 0 .814 .455 r
F
.46376 .92747 m .4625 .92733 L .46096 .93236 L F
.46096 .93202 m .46062 .93214 L .4606 .93218 L 0 1 .495 r
F
.4625 .92733 m .46064 .9321 L .46096 .93236 L 0 .814 .455 r
F
.46061 .93214 m .44688 .93696 L .46059 .93219 L 0 1 .495 r
F
.46059 .93219 m .46059 .93219 L .46058 .93223 L F
.46059 .93219 m .46058 .93223 L .46056 .93231 L F
.46059 .93219 m .44548 .93926 L .46056 .93231 L F
.46096 .93236 m .46056 .93231 L .46032 .93343 L 0 .853 .464 r
F
0 g
.45037 .93099 m
.45041 .93104 L
s
.45931 .93828 m
.45934 .93831 L
s
.4593 .93826 m
.45931 .93828 L
s
.45914 .93807 m
.4593 .93826 L
s
.45889 .9378 m
.45914 .93807 L
s
.44355 .92798 m
.45041 .93104 L
s
.41375 .95756 m
.42154 .95548 L
s
.43497 .94742 m .41691 .95367 L .42154 .95548 L 0 1 .515 r
F
0 g
.42154 .95548 m
.42154 .95548 L
s
.28583 .82777 m
.28598 .82784 L
s
.42614 .83342 m .42082 .83017 L .41494 .82951 L 0 1 .504 r
F
.43181 .82709 m .42614 .83342 L .43175 .83392 L 0 1 .499 r
F
.43181 .82709 m .42082 .83017 L .42614 .83342 L F
0 g
.42614 .83342 m
.42851 .83771 L
s
.45655 .75877 m .44563 .76607 L .44647 .76799 L 0 1 .447 r
F
0 g
.4415 .77088 m
.44647 .76799 L
s
.40866 .88553 m .39318 .87748 L .39634 .88391 L 0 1 .464 r
F
0 g
.38945 .88041 m
.39634 .88391 L
s
.42525 .90157 m .42721 .90981 L .42899 .90782 L 0 .997 .466 r
F
.44274 .91712 m .42899 .90782 L .42721 .90981 L 0 .936 .467 r
F
0 g
.42721 .90981 m
.43149 .91588 L
s
.42054 .90655 m
.42721 .90981 L
s
.47986 .92595 m .46579 .93253 L .46479 .93504 L 0 1 .49 r
F
0 g
.46479 .93504 m
.47006 .93507 L
s
.47986 .92595 m .47225 .92863 L .46579 .93253 L 0 1 .49 r
F
.48165 .91966 m .47225 .92863 L .47986 .92595 L 0 1 .477 r
F
0 g
.47986 .92595 m
.48511 .92599 L
s
.47986 .92595 m
.486 .92202 L
s
.27588 .83127 m
.27589 .83136 L
s
.27523 .82558 m
.2754 .82708 L
s
.27544 .82744 m
.27588 .83127 L
s
.27587 .83126 m
.27589 .83136 L
s
.27587 .83122 m
.27589 .83136 L
s
.27525 .82739 m
.27585 .83107 L
s
.27585 .83107 m
.27587 .83122 L
s
.46242 .83398 m .45014 .83453 L .45289 .83878 L 0 1 .492 r
F
.43181 .82709 m .43175 .83392 L .43391 .83135 L 0 1 .499 r
F
.44478 .83454 m .43391 .83135 L .43175 .83392 L 0 1 .498 r
F
0 g
.43175 .83392 m
.43437 .83812 L
s
.42614 .83342 m
.43175 .83392 L
s
.40661 .83094 m .39528 .82626 L .39245 .82842 L 0 1 .508 r
F
.40661 .83094 m .40135 .82734 L .39528 .82626 L F
.41312 .82514 m .40135 .82734 L .40661 .83094 L 0 1 .504 r
F
0 g
.40661 .83094 m
.41243 .83187 L
s
.40661 .83094 m
.40868 .83537 L
s
.41644 .7836 m .41419 .78834 L .41715 .78572 L 0 1 .483 r
F
.41644 .7836 m .40879 .78998 L .41419 .78834 L F
0 g
.41419 .78834 m
.41545 .79045 L
s
.51622 .62761 m .51776 .58253 L .51669 .60787 L 0 .776 .272 r
F
.51507 .62604 m .51669 .60787 L .51776 .58253 L 0 .779 .274 r
F
0 g
.51776 .58253 m
.5178 .57564 L
s
.51776 .58253 m
.51924 .56426 L
s
.34989 .8427 m .34675 .85237 L .35082 .85007 L 0 1 .467 r
F
.34989 .8427 m .33945 .84833 L .34675 .85237 L F
.3643 .86103 m .35082 .85007 L .34675 .85237 L 0 1 .47 r
F
0 g
.34675 .85237 m
.34847 .85961 L
s
.43374 .77657 m .42161 .78172 L .42261 .78374 L 0 1 .479 r
F
0 g
.41715 .78572 m
.42261 .78374 L
s
.51507 .62604 m .5158 .58194 L .51518 .60685 L 0 .779 .274 r
F
.5139 .6252 m .51518 .60685 L .5158 .58194 L 0 .784 .276 r
F
0 g
.51567 .57218 m
.5158 .58194 L
s
.5158 .58194 m
.51581 .5818 L
s
.50294 .85163 m .50213 .86037 L .50677 .85948 L 0 1 .483 r
F
.53409 .42193 m .54475 .39743 L .54148 .41019 L 0 0 .071 r
F
0 g
.54475 .39743 m
.54953 .38706 L
s
.29876 .97766 m .28193 .97822 L .29114 .9817 L 0 1 .535 r
F
0 g
.29114 .9817 m
.30023 .98304 L
s
.77248 .79603 m .77773 .80832 L .78292 .80427 L 0 .872 .475 r
F
0 g
.77084 .8088 m
.77773 .80832 L
s
.77686 .81372 m
.77773 .80832 L
s
.74876 .72177 m .75877 .71999 L .75441 .71738 L 0 1 .464 r
F
.74876 .72177 m .75954 .72829 L .75877 .71999 L F
0 g
.74876 .72177 m
.75441 .71738 L
s
.74835 .71789 m
.74876 .72177 L
s
.32842 1.00314 m .33077 1.00982 L .33338 1.00813 L 0 1 .538 r
F
.32842 1.00314 m .32163 1.00725 L .33077 1.00982 L F
0 g
.33077 1.00982 m
.33654 1.01453 L
s
.46278 .74995 m .46094 .75539 L .46332 .7518 L 0 1 .413 r
F
.46278 .74995 m .45655 .75877 L .46094 .75539 L F
0 g
.46094 .75539 m
.46193 .75721 L
s
.70864 .65507 m
.70865 .65507 L
s
.40866 .88553 m .40967 .89396 L .41182 .89196 L 0 1 .464 r
F
.42525 .90157 m .41182 .89196 L .40967 .89396 L 0 .997 .466 r
F
0 g
.40967 .89396 m
.41341 .90021 L
s
.40304 .89051 m
.40967 .89396 L
s
.79334 .81193 m .79809 .82348 L .80373 .81909 L 0 .959 .49 r
F
0 g
.79088 .82452 m
.79809 .82348 L
s
.51911 .65892 m
.51912 .65892 L
s
.51912 .65892 m
.51913 .65891 L
s
.51913 .65891 m
.5192 .6588 L
s
.5192 .6588 m
.51923 .65876 L
s
.51923 .65876 m
.51933 .65861 L
s
.51976 .658 m
.51989 .65781 L
s
.52006 .65756 m
.5201 .65751 L
s
.5201 .65751 m
.52013 .65746 L
s
.52013 .65746 m
.52034 .65717 L
s
.52039 .65709 m
.52077 .65655 L
s
.52078 .65653 m
.52079 .65652 L
s
.52061 .65615 m
.52061 .65617 L
s
.52061 .65617 m
.52062 .65618 L
s
.52062 .65618 m
.52066 .65627 L
s
.52068 .65631 m
.52078 .65651 L
s
.52079 .65652 m
.52079 .65652 L
s
.4781 .46104 m .48215 .45072 L .48422 .44423 L 0 .882 .124 r
F
0 g
.48215 .45072 m
.48397 .44702 L
s
.49817 .96714 m .48888 .96437 L .49742 .9702 L 0 .562 .414 r
F
.49817 .96714 m .48293 .95888 L .48888 .96437 L F
0 g
.48888 .96436 m
.48888 .96437 L
s
.37155 .85641 m .37087 .86505 L .37368 .86318 L 0 1 .465 r
F
.37155 .85641 m .3643 .86103 L .37087 .86505 L F
.38666 .87381 m .37368 .86318 L .37087 .86505 L 0 1 .467 r
F
0 g
.37087 .86505 m
.37367 .87166 L
s
.48532 .55437 m .47909 .55051 L .482 .5553 L 0 1 .295 r
F
.48532 .55437 m .47835 .54159 L .47909 .55051 L F
.49227 .57368 m .48532 .55437 L .48634 .56436 L 0 1 .294 r
F
.80163 .59909 m .81266 .6109 L .81322 .608 L 0 .286 .225 r
F
0 g
.81266 .6109 m
.81569 .6157 L
s
.80878 .61015 m
.81266 .6109 L
s
.46242 .83398 m .46369 .84129 L .46516 .83823 L 0 1 .492 r
F
.47559 .84023 m .46516 .83823 L .46369 .84129 L 0 1 .49 r
F
0 g
.46369 .84129 m
.46689 .84552 L
s
.45843 .84152 m
.46369 .84129 L
s
.78292 .80427 m .78792 .81614 L .79334 .81193 L 0 .917 .483 r
F
0 g
.78087 .8169 m
.78792 .81614 L
s
.78687 .82153 m
.78792 .81614 L
s
.3643 .86103 m .35835 .85379 L .35082 .85007 L 0 1 .47 r
F
0 g
.3643 .86103 m
.36601 .86827 L
s
.37155 .85641 m .35835 .85379 L .3643 .86103 L 0 1 .465 r
F
0 g
.3643 .86103 m
.37087 .86505 L
s
.50925 .62848 m .50627 .57826 L .50538 .58058 L 0 .825 .285 r
F
0 g
.50855 .57304 m
.50902 .57854 L
s
.50925 .62848 m .50786 .59166 L .50627 .57826 L 0 .825 .285 r
F
0 g
.50602 .56315 m
.50627 .57826 L
s
.50763 .57503 m
.50769 .5797 L
s
.48914 .84611 m .49213 .85372 L .49276 .85036 L 0 1 .487 r
F
.50294 .85163 m .49276 .85036 L .49213 .85372 L 0 1 .483 r
F
0 g
.49213 .85372 m
.49615 .858 L
s
.48725 .85438 m
.49213 .85372 L
s
.74643 .9432 m .75469 .94502 L .7587 .93961 L 0 1 .532 r
F
.53768 .37135 m .53432 .39043 L .5337 .38333 L 0 .257 .124 r
F
.53768 .37135 m .53959 .39083 L .53432 .39043 L F
.53768 .37135 m .54598 .38426 L .53959 .39083 L F
.53768 .37135 m .54993 .37226 L .54598 .38426 L F
.33945 .84833 m .32682 .83616 L .32323 .83787 L 0 1 .473 r
F
.33945 .84833 m .33378 .84064 L .32682 .83616 L F
0 g
.33945 .84833 m
.34122 .85547 L
s
.34989 .8427 m .33378 .84064 L .33945 .84833 L 0 1 .467 r
F
0 g
.33945 .84833 m
.34675 .85237 L
s
.57782 .48209 m .58102 .5351 L .5779 .51218 L 0 .721 .193 r
F
.57782 .48209 m .58604 .55189 L .58102 .5351 L F
0 g
.57998 .52749 m
.5804 .57259 L
s
.57331 .48103 m
.57782 .48209 L
s
.33589 .97571 m .31503 .97462 L .31979 .97778 L 0 1 .533 r
F
.33589 .97571 m .31799 .97294 L .31503 .97462 L F
.33589 .97571 m .32695 .97341 L .31799 .97294 L F
.34272 .97112 m .32695 .97341 L .33589 .97571 L 0 1 .531 r
F
0 g
.33589 .97571 m
.34454 .97601 L
s
.33589 .97571 m
.34061 .97886 L
s
.73815 .9416 m .73802 .9495 L .74643 .9432 L 0 1 .53 r
F
0 g
.73656 .95019 m
.73802 .9495 L
s
.73714 .95068 m
.73802 .9495 L
s
.30748 .83718 m .29506 .82381 L .29122 .82533 L 0 1 .479 r
F
0 g
.28598 .82784 m
.29223 .83069 L
s
.28622 .82775 m
.29188 .82883 L
s
.30748 .83718 m .30203 .82889 L .29506 .82381 L 0 1 .479 r
F
.31664 .83306 m .30203 .82889 L .30748 .83718 L 0 1 .475 r
F
0 g
.30748 .83718 m
.30888 .84465 L
s
.30748 .83718 m
.31425 .84212 L
s
.43374 .77657 m .42459 .77902 L .42161 .78172 L 0 1 .479 r
F
.43374 .77657 m .42979 .77681 L .42459 .77902 L F
0 g
.43374 .77657 m
.43472 .77858 L
s
.44088 .76887 m .42979 .77681 L .43374 .77657 L 0 1 .459 r
F
0 g
.43374 .77657 m
.43875 .77403 L
s
.47334 .48463 m .4768 .47501 L .47809 .46811 L 0 1 .187 r
F
0 g
.4768 .47501 m
.48068 .46853 L
s
.73815 .9416 m .73005 .94765 L .72631 .95279 L 0 1 .53 r
F
0 g
.71727 .956 m
.72631 .95279 L
s
.53151 .52924 m .5313 .49064 L .53027 .51689 L 0 1 .229 r
F
.52465 .55362 m .53027 .51689 L .5313 .49064 L 0 1 .238 r
F
0 g
.52968 .48204 m
.5313 .49064 L
s
.5313 .49064 m
.53334 .46904 L
s
.36615 .82165 m .36432 .82832 L .36744 .8264 L 0 1 .514 r
F
.36615 .82165 m .35817 .82633 L .36432 .82832 L F
0 g
.36432 .82832 m
.36628 .83299 L
s
.2554 .83431 m .23835 .82853 L .23978 .83302 L 0 1 .538 r
F
.2554 .83431 m .24239 .82733 L .23835 .82853 L F
.2554 .83431 m .24971 .82982 L .24239 .82733 L F
.26512 .83081 m .24971 .82982 L .2554 .83431 L 0 1 .537 r
F
0 g
.2554 .83431 m
.25676 .83867 L
s
.2554 .83431 m
.26249 .83656 L
s
.47797 .95182 m .48293 .95888 L .48352 .95739 L 0 .776 .46 r
F
.49817 .96714 m .48352 .95739 L .48293 .95888 L 0 .562 .414 r
F
0 g
.48293 .95888 m
.48888 .96436 L
s
.4762 .95573 m
.48293 .95888 L
s
.5139 .6252 m .51381 .58273 L .51366 .60685 L 0 .784 .276 r
F
.51272 .62507 m .51366 .60685 L .51381 .58273 L 0 .791 .278 r
F
0 g
.51321 .56558 m
.51381 .58273 L
s
.51381 .58273 m
.51458 .56516 L
s
.51734 .62993 m .51968 .58466 L .51816 .60998 L 0 .773 .272 r
F
.51622 .62761 m .51816 .60998 L .51968 .58466 L 0 .776 .272 r
F
0 g
.51968 .58466 m
.52146 .56705 L
s
.51968 .58466 m
.51978 .58039 L
s
.4781 .46104 m .48422 .44423 L .48293 .44589 L 0 .882 .124 r
F
0 g
.48422 .44423 m
.48831 .43448 L
s
.48215 .45072 m
.48422 .44423 L
s
.48544 .43902 m .49007 .42824 L .49291 .42244 L 0 0 0 r
F
0 g
.49007 .42824 m
.49214 .4233 L
s
.51409 .67261 m .51269 .67511 L .51149 .67897 L 0 1 .178 r
F
.51378 .67018 m .51409 .67261 L .51494 .67016 L 0 .892 .132 r
F
.51378 .67018 m .51269 .67511 L .51409 .67261 L F
0 g
.51409 .67261 m
.51533 .6724 L
s
.47334 .48463 m .47809 .46811 L .47636 .46851 L 0 1 .187 r
F
0 g
.47809 .46811 m
.48209 .45995 L
s
.4768 .47501 m
.47809 .46811 L
s
.45941 .93757 m
.45943 .93758 L
s
.4594 .93757 m
.45941 .93757 L
s
.45929 .9383 m
.45934 .93831 L
s
.46274 .936 m
.46479 .93504 L
s
.28565 .82774 m
.29263 .83282 L
s
.28555 .82766 m
.28565 .82774 L
s
.29127 .82557 m
.29263 .83282 L
s
.49552 1.02019 m .49472 1.02732 L .50237 1.02613 L 0 1 .535 r
F
.49552 1.02019 m .4847 1.02594 L .49472 1.02732 L F
0 g
.49472 1.02732 m
.50208 1.03048 L
s
.49747 .70741 m .49239 .71437 L .49083 .71836 L 0 1 .3 r
F
.49747 .70741 m .49523 .70967 L .49239 .71437 L F
.50059 .69798 m .49747 .70741 L .49997 .70291 L 0 1 .21 r
F
.50059 .69798 m .49523 .70967 L .49747 .70741 L F
0 g
.49747 .70741 m
.4983 .70874 L
s
.4992 .60081 m .49341 .56908 L .49227 .57368 L 0 1 .293 r
F
.4992 .60081 m .49614 .57464 L .49341 .56908 L F
0 g
.49518 .56221 m
.49593 .57193 L
s
.49238 .5591 m
.49341 .56908 L
s
.44274 .91712 m .44563 .92513 L .44702 .9232 L 0 .936 .467 r
F
0 g
.43897 .92199 m
.44563 .92513 L
s
.44563 .92513 m
.45037 .93099 L
s
.30695 .95702 m .2861 .9587 L .29037 .96052 L 0 1 .443 r
F
.30695 .95702 m .28938 .95715 L .2861 .9587 L F
.30695 .95702 m .29833 .95642 L .28938 .95715 L F
.3146 .95263 m .29833 .95642 L .30695 .95702 L 0 1 .423 r
F
0 g
.30695 .95702 m
.3156 .95608 L
s
.30695 .95702 m
.31116 .95883 L
s
.38651 .82705 m .37211 .82349 L .37383 .82807 L 0 1 .511 r
F
.50059 .69798 m .49997 .70291 L .50109 .69915 L 0 1 .21 r
F
.50513 .69209 m .50109 .69915 L .49997 .70291 L 0 1 .236 r
F
0 g
.49997 .70291 m
.50085 .70381 L
s
.49747 .70741 m
.49997 .70291 L
s
.49552 1.02019 m .47766 1.02299 L .4847 1.02594 L 0 1 .535 r
F
0 g
.47672 1.0268 m
.4847 1.02594 L
s
.45655 .75877 m .44839 .76281 L .44563 .76607 L 0 1 .447 r
F
.45655 .75877 m .45307 .75968 L .44839 .76281 L F
.46278 .74995 m .45307 .75968 L .45655 .75877 L 0 1 .413 r
F
0 g
.45655 .75877 m
.45738 .76069 L
s
.45655 .75877 m
.46094 .75539 L
s
.70225 .95231 m .69399 .95689 L .68989 .96097 L 0 1 .519 r
F
0 g
.68108 .96301 m
.68989 .96097 L
s
.75954 .72829 m .76967 .72621 L .76531 .72377 L 0 1 .472 r
F
.75954 .72829 m .7703 .7344 L .76967 .72621 L F
0 g
.75954 .72829 m
.76531 .72377 L
s
.75877 .71999 m
.75954 .72829 L
s
.3938 .82176 m .39245 .82842 L .39528 .82626 L 0 1 .508 r
F
.3938 .82176 m .38651 .82705 L .39245 .82842 L F
0 g
.39245 .82842 m
.39453 .83285 L
s
.32163 1.00725 m .29963 1.00094 L .3049 1.00607 L 0 1 .538 r
F
.49194 .71288 m .49083 .71836 L .49239 .71437 L 0 1 .276 r
F
.49194 .71288 m .48773 .7228 L .49083 .71836 L F
0 g
.49083 .71836 m
.49168 .71968 L
s
.4761 .73717 m .46689 .74634 L .46757 .74808 L 0 1 .387 r
F
0 g
.46332 .7518 m
.46757 .74808 L
s
.51887 .98648 m .51026 .97968 L .50365 .97543 L 0 .324 .248 r
F
0 g
.49742 .9702 m
.50365 .97543 L
s
.46979 1.0236 m .45991 1.02185 L .45171 1.02226 L 0 1 .538 r
F
.35862 1.01016 m .33731 1.0056 L .3428 1.0102 L 0 1 .539 r
F
0 g
.33338 1.00813 m
.3428 1.0102 L
s
.38666 .87381 m .38045 .86693 L .37368 .86318 L 0 1 .467 r
F
.39313 .86892 m .38666 .87381 L .39318 .87748 L 0 1 .461 r
F
.39313 .86892 m .38045 .86693 L .38666 .87381 L F
0 g
.38666 .87381 m
.38945 .88041 L
s
.54494 1.03887 m .5349 1.03507 L .52757 1.03467 L 0 1 .485 r
F
0 g
.52757 1.03467 m
.52795 1.03469 L
s
.44478 .83454 m .4395 .83162 L .43391 .83135 L 0 1 .498 r
F
0 g
.44478 .83454 m
.44739 .83874 L
s
.44977 .82731 m .44478 .83454 L .45014 .83453 L 0 1 .493 r
F
.44977 .82731 m .4395 .83161 L .44478 .83454 L F
0 g
.50555 .90378 m
.51012 .89914 L
s
.71743 .9609 m .72968 .96152 L .72655 .95972 L 0 1 .539 r
F
.70984 .95614 m .71743 .9609 L .72184 .95698 L F
.26527 .82714 m .24897 .81343 L .25006 .82141 L 0 1 .488 r
F
.26527 .82714 m .25302 .81213 L .24897 .81343 L F
.26527 .82714 m .26001 .81801 L .25302 .81213 L F
.275 .82354 m .26001 .81801 L .26527 .82714 L 0 1 .485 r
F
0 g
.26527 .82714 m
.2655 .82887 L
s
.26527 .82714 m
.26676 .8284 L
s
.50925 .62848 m .50538 .58058 L .50597 .59629 L 0 .825 .285 r
F
0 g
.505 .57862 m
.50538 .58058 L
s
.48773 .7228 m .48172 .72915 L .47974 .73307 L 0 1 .35 r
F
.48773 .7228 m .48514 .72475 L .48172 .72915 L F
.49194 .71288 m .48514 .72475 L .48773 .7228 L 0 1 .276 r
F
0 g
.48773 .7228 m
.4885 .72439 L
s
.48773 .7228 m
.49083 .71836 L
s
.45817 .93814 m .44338 .94276 L .44199 .94511 L 0 1 .506 r
F
.45817 .93814 m .45032 .93977 L .44338 .94276 L F
0 g
.45817 .93814 m
.45929 .9383 L
s
.45817 .93814 m
.4594 .93757 L
s
.77773 .57868 m .78225 .57997 L .7869 .58433 L 0 .096 0 r
F
.77773 .57868 m .77832 .57754 L .78225 .57997 L F
.48544 .43902 m .49291 .42244 L .49209 .42547 L 0 0 0 r
F
0 g
.49291 .42244 m
.49705 .41127 L
s
.49007 .42824 m
.49291 .42244 L
s
.47112 .50908 m .47399 .50032 L .47452 .49319 L 0 1 .263 r
F
0 g
.47399 .50032 m
.47774 .49549 L
s
.39338 1.01028 m .39707 1.01634 L .39894 1.01436 L 0 1 .539 r
F
0 g
.39141 1.01726 m
.39426 1.0193 L
s
.39338 1.01028 m .3884 1.01511 L .39707 1.01634 L 0 1 .539 r
F
.4174 1.01802 m .39894 1.01436 L .39707 1.01634 L F
0 g
.39707 1.01634 m
.40328 1.02013 L
s
.51954 1.02217 m .50977 1.02952 L .51983 1.03107 L 0 1 .52 r
F
.51954 1.02217 m .50237 1.02613 L .50977 1.02952 L F
0 g
.50208 1.03048 m
.50977 1.02952 L
s
.47112 .50908 m .47452 .49319 L .47236 .49243 L 0 1 .263 r
F
0 g
.47452 .49319 m
.47841 .48668 L
s
.47399 .50032 m
.47452 .49319 L
s
.69974 .62385 m
.70098 .62368 L
s
.43181 .82709 m .41871 .82591 L .42082 .83017 L 0 1 .499 r
F
0 g
.41494 .82951 m
.42082 .83017 L
s
.53242 .62676 m
.53294 .62516 L
s
.32228 .94825 m .32302 .95149 L .32599 .94965 L 0 1 .399 r
F
0 g
.32599 .94965 m
.33472 .94793 L
s
.32228 .94825 m .3146 .95263 L .32302 .95149 L 0 1 .399 r
F
0 g
.32302 .95149 m
.32755 .95274 L
s
.50513 .69209 m .5033 .69452 L .50109 .69915 L 0 1 .236 r
F
.50713 .68441 m .50513 .69209 L .507 .68803 L 0 1 .167 r
F
.50713 .68441 m .5033 .69452 L .50513 .69209 L F
0 g
.50513 .69209 m
.50601 .69301 L
s
.47835 .54159 m .4718 .54193 L .47472 .54479 L 0 1 .295 r
F
.47835 .54159 m .47133 .53392 L .4718 .54193 L F
.47835 .54159 m .47363 .52611 L .47133 .53392 L F
0 g
.2816 .8291 m
.28162 .82911 L
s
.2846 .82372 m .28164 .82911 L .28547 .8276 L 0 1 .534 r
F
0 g
.28162 .82911 m
.28164 .82911 L
s
.28547 .8276 m
.28555 .82766 L
s
.28547 .8276 m
.28583 .82777 L
s
.28547 .8276 m
.28555 .82762 L
s
.28164 .82911 m
.28168 .82934 L
s
.30641 .97362 m .30762 .97883 L .31058 .97715 L 0 1 .533 r
F
0 g
.31058 .97715 m
.31979 .97778 L
s
.30641 .97362 m .29876 .97766 L .30762 .97883 L 0 1 .533 r
F
0 g
.30762 .97883 m
.31265 .98214 L
s
.50055 .90488 m .48749 .91575 L .49251 .91464 L 0 1 .451 r
F
0 g
.48659 .91946 m
.49251 .91464 L
s
.3884 1.01511 m .36971 1.01016 L .36745 1.012 L 0 1 .539 r
F
.3884 1.01511 m .3787 1.0115 L .36971 1.01016 L F
.39338 1.01028 m .3787 1.0115 L .3884 1.01511 L F
0 g
.3884 1.01511 m
.39707 1.01634 L
s
.3884 1.01511 m
.39141 1.01726 L
s
.7469 .95618 m .74643 .96424 L .75526 .9602 L 0 1 .539 r
F
0 g
.73749 .96594 m
.74643 .96424 L
s
.52346 .8856 m
.52346 .8856 L
s
.52493 .88392 m
.52526 .88356 L
s
.7703 .7344 m .78056 .73202 L .7762 .72974 L 0 1 .479 r
F
.7703 .7344 m .78105 .74015 L .78056 .73202 L F
0 g
.76967 .72621 m
.7703 .7344 L
s
.29514 .82382 m
.29533 .82385 L
s
.47168 1.01739 m .46979 1.0236 L .47766 1.02299 L 0 1 .539 r
F
.47168 1.01739 m .45991 1.02185 L .46979 1.0236 L F
0 g
.46979 1.0236 m
.47672 1.0268 L
s
.51272 .62507 m .51181 .58473 L .51212 .60775 L 0 .791 .278 r
F
.51154 .62561 m .51212 .60775 L .51181 .58473 L 0 .801 .28 r
F
0 g
.51181 .58473 m
.51227 .5667 L
s
.51087 .56874 m
.51181 .58473 L
s
.40879 .78998 m .39587 .79313 L .39693 .79527 L 0 1 .496 r
F
.40879 .78998 m .39901 .79091 L .39587 .79313 L F
.40879 .78998 m .40455 .78956 L .39901 .79091 L F
0 g
.40879 .78998 m
.40983 .79213 L
s
.41644 .7836 m .40455 .78956 L .40879 .78998 L 0 1 .483 r
F
0 g
.40879 .78998 m
.41419 .78834 L
s
.31089 .81768 m .31435 .81608 L .31052 .81764 L 0 1 .528 r
F
.32611 .81943 m .31452 .81613 L .31089 .81768 L F
.31452 .81613 m .31435 .81608 L .31089 .81768 L F
.32611 .81943 m .32102 .81684 L .31429 .81606 L F
.3374 .81398 m .32102 .81684 L .32611 .81943 L 0 1 .523 r
F
.3374 .81398 m .32074 .81342 L .32102 .81684 L F
.33726 .81882 m .32083 .81345 L .32095 .81886 L 0 1 .518 r
F
.32083 .81345 m .32074 .81348 L .32095 .81886 L F
.33726 .81882 m .33303 .82646 L .33746 .82425 L F
.33726 .81882 m .32597 .82415 L .33303 .82646 L F
.31052 .81764 m .31429 .81606 L .31044 .81763 L 0 1 .528 r
F
.31435 .81608 m .31429 .81606 L .31052 .81764 L F
.3113 .81799 m .31429 .81606 L .31044 .81763 L 0 1 .52 r
F
.32597 .82416 m .31472 .81636 L .3113 .81799 L F
.31472 .81636 m .31429 .81606 L .3113 .81799 L F
.32597 .82416 m .32095 .81886 L .31486 .8163 L F
.31472 .81636 m .31486 .8163 L .31429 .81606 L F
.32597 .82416 m .31486 .8163 L .31472 .81636 L F
.32083 .81345 m .32074 .81342 L .32074 .81348 L 0 1 .518 r
F
.32078 .81345 m .32074 .81346 L .32074 .81351 L 0 1 .465 r
F
.32078 .81349 m .32074 .81351 L .32089 .82089 L F
.32078 .81345 m .32074 .81351 L .32078 .81349 L F
.33726 .81882 m .32095 .81886 L .32597 .82415 L 0 1 .518 r
F
.33713 .82366 m .32082 .81347 L .32089 .82089 L 0 1 .465 r
F
.32082 .81347 m .32078 .81345 L .32078 .81349 L F
.32082 .81347 m .32078 .81349 L .32089 .82089 L F
.32078 .81345 m .32074 .81342 L .32074 .81346 L F
.50114 .5936 m .50195 .59082 L .50099 .57837 L 0 .994 .29 r
F
0 g
.43391 .83135 m
.4395 .83162 L
s
.39313 .86892 m .39318 .87748 L .39567 .87551 L 0 1 .461 r
F
.40866 .88553 m .39567 .87551 L .39318 .87748 L 0 1 .464 r
F
0 g
.39318 .87748 m
.39634 .88391 L
s
.38666 .87381 m
.39318 .87748 L
s
.32163 1.00725 m .30259 .9994 L .29963 1.00094 L 0 1 .538 r
F
.32163 1.00725 m .31203 1.00211 L .30259 .9994 L F
.32842 1.00314 m .31203 1.00211 L .32163 1.00725 L F
0 g
.32163 1.00725 m
.33077 1.00982 L
s
.32163 1.00725 m
.32685 1.01236 L
s
.55264 .39817 m .56376 .37974 L .56529 .38597 L 0 .168 .107 r
F
.55264 .39817 m .55836 .38495 L .56376 .37974 L F
0 g
.56376 .37974 m
.5667 .36487 L
s
.55836 .38495 m
.55837 .38489 L
s
.55837 .38489 m
.56144 .37014 L
s
.55836 .38495 m
.56376 .37974 L
s
.48914 .84611 m .48367 .8438 L .47879 .84447 L 0 1 .487 r
F
.38651 .82705 m .37523 .82153 L .37211 .82349 L 0 1 .511 r
F
0 g
.36744 .8264 m
.37383 .82807 L
s
.38651 .82705 m .38141 .82306 L .37523 .82153 L 0 1 .511 r
F
.3938 .82176 m .38141 .82306 L .38651 .82705 L 0 1 .508 r
F
0 g
.38651 .82705 m
.38822 .83163 L
s
.38651 .82705 m
.39245 .82842 L
s
.44977 .82731 m .45014 .83453 L .45202 .8316 L 0 1 .493 r
F
.46242 .83398 m .45202 .8316 L .45014 .83453 L 0 1 .492 r
F
0 g
.45014 .83453 m
.45289 .83878 L
s
.44478 .83454 m
.45014 .83453 L
s
.50114 .5936 m .49614 .57464 L .49865 .58665 L 0 .994 .29 r
F
0 g
.50099 .57837 m
.50181 .58899 L
s
.4992 .60081 m .49865 .58665 L .49614 .57464 L 0 1 .293 r
F
0 g
.49593 .57193 m
.49614 .57464 L
s
.49341 .56908 m
.49614 .57464 L
s
.35082 .85007 m
.35835 .85379 L
s
.75448 .5547 m .7622 .56534 L .75755 .56043 L 0 .272 0 r
F
.75448 .5547 m .76612 .56758 L .7622 .56534 L F
.4174 1.01802 m .40766 1.01508 L .39894 1.01436 L 0 1 .539 r
F
.42139 1.01281 m .4174 1.01802 L .4258 1.01863 L 0 1 .54 r
F
.42139 1.01281 m .40766 1.01508 L .4174 1.01802 L F
0 g
.4174 1.01802 m
.42359 1.02181 L
s
.51378 .67018 m .51179 .67592 L .51269 .67511 L 0 .892 .132 r
F
0 g
.51149 .67897 m
.51269 .67511 L
s
.51842 .63301 m .52153 .5885 L .51958 .61326 L 0 .769 .271 r
F
.51734 .62993 m .51958 .61326 L .52153 .5885 L 0 .773 .272 r
F
0 g
.52153 .5885 m
.5216 .5868 L
s
.52153 .5885 m
.5236 .57199 L
s
.37155 .85641 m .35621 .84701 L .35835 .85379 L 0 1 .465 r
F
.41312 .82514 m .39952 .82297 L .40135 .82734 L 0 1 .504 r
F
0 g
.39528 .82626 m
.40135 .82734 L
s
.50294 .85163 m .50677 .85948 L .50696 .85593 L 0 1 .483 r
F
0 g
.50677 .85948 m
.51113 .86383 L
s
.50213 .86037 m
.50677 .85948 L
s
.52328 .88349 m
.52328 .88348 L
s
.52474 .88271 m
.52569 .88221 L
s
.44274 .91712 m .43564 .91096 L .42899 .90782 L 0 .936 .467 r
F
.78105 .74015 m .79143 .73749 L .78708 .73534 L 0 1 .485 r
F
.78105 .74015 m .79179 .74559 L .79143 .73749 L F
.35817 .82633 m .34331 .8213 L .34482 .82616 L 0 1 .516 r
F
.35817 .82633 m .34669 .81959 L .34331 .8213 L F
.35817 .82633 m .35306 .82174 L .34669 .81959 L F
.36615 .82165 m .35306 .82174 L .35817 .82633 L 0 1 .514 r
F
0 g
.35817 .82633 m
.36432 .82832 L
s
.35817 .82633 m
.35966 .83118 L
s
.48135 .72747 m .47974 .73307 L .48172 .72915 L 0 1 .326 r
F
.48135 .72747 m .4761 .73717 L .47974 .73307 L F
0 g
.47974 .73307 m
.48051 .73465 L
s
.37443 .80448 m .36041 .80538 L .36155 .80793 L 0 1 .513 r
F
.37443 .80448 m .3638 .80355 L .36041 .80538 L F
.37443 .80448 m .36981 .80316 L .3638 .80355 L F
.38244 .79938 m .36981 .80316 L .37443 .80448 L 0 1 .506 r
F
0 g
.37443 .80448 m
.38023 .80389 L
s
.37443 .80448 m
.37555 .80702 L
s
.50713 .68441 m .507 .68803 L .50766 .68504 L 0 1 .167 r
F
.5106 .67873 m .50766 .68504 L .507 .68803 L 0 1 .172 r
F
0 g
.507 .68803 m
.5079 .68827 L
s
.50513 .69209 m
.507 .68803 L
s
.54454 .51629 m .54623 .52042 L .54423 .52261 L 0 0 .046 r
F
.54454 .51629 m .54983 .50859 L .54623 .52042 L F
0 g
.54126 .53009 m
.54454 .51629 L
s
.49536 .41961 m .50053 .40878 L .50415 .40393 L 0 0 .04 r
F
0 g
.67957 .95279 m
.68187 .95269 L
s
.54983 .50859 m .559 .49276 L .55846 .50577 L 0 .15 .122 r
F
0 g
.559 .49276 m
.56303 .48172 L
s
.51954 1.02217 m .51983 1.03107 L .5272 1.02938 L 0 1 .52 r
F
0 g
.51983 1.03107 m
.52757 1.03467 L
s
.69458 .94617 m .68559 .95482 L .69391 .95422 L 0 1 .536 r
F
0 g
.68097 .95859 m
.68559 .95482 L
s
.52032 .6578 m .52576 .6428 L .52282 .65102 L 0 0 0 r
F
0 g
.52126 .65402 m
.52134 .65378 L
s
.52303 .64979 m
.52311 .64959 L
s
.52054 .65601 m
.52055 .65603 L
s
.52336 .649 m
.52358 .64841 L
s
.52328 .6492 m
.52336 .649 L
s
.52307 .64976 m
.52328 .6492 L
s
.5243 .64666 m
.52463 .64575 L
s
.52428 .64671 m
.5243 .64666 L
s
.52437 .64647 m
.52468 .64563 L
s
.52435 .64652 m
.52437 .64647 L
s
.26519 .82898 m .24872 .81947 L .24989 .82561 L 0 1 .525 r
F
.26519 .82898 m .25276 .81821 L .24872 .81947 L F
.26519 .82898 m .25983 .8223 L .25276 .81821 L F
.27493 .82541 m .25983 .8223 L .26519 .82898 L 0 1 .524 r
F
0 g
.26519 .82898 m
.26715 .83008 L
s
.26519 .82898 m
.26551 .83067 L
s
.51801 .86685 m
.51809 .86693 L
s
.54633 1.04642 m
.54764 1.04711 L
s
.54764 1.04711 m
.55166 1.04924 L
s
.54633 1.04642 m
.5475 1.04648 L
s
.5475 1.04648 m
.55125 1.0467 L
s
.42525 .90157 m .41849 .89522 L .41182 .89196 L 0 .997 .466 r
F
.34602 .80974 m .3435 .81436 L .34688 .81259 L 0 1 .519 r
F
0 g
.34688 .81259 m
.3533 .81259 L
s
.34602 .80974 m .3374 .81398 L .3435 .81436 L 0 1 .519 r
F
0 g
.3435 .81436 m
.34506 .81718 L
s
.3374 .81398 m
.3435 .81436 L
s
.3374 .81398 m
.33765 .81739 L
s
.32597 .82415 m
.33303 .82646 L
s
.33303 .82646 m
.33403 .83185 L
s
.5252 .60041 m
.52712 .59086 L
s
.47559 .84023 m .47026 .83778 L .46516 .83823 L 0 1 .49 r
F
.44977 .82731 m .43723 .82733 L .4395 .83161 L 0 1 .493 r
F
.42139 1.01281 m .4258 1.01863 L .42727 1.0165 L 0 1 .54 r
F
.44527 1.01885 m .42727 1.0165 L .4258 1.01863 L F
0 g
.4258 1.01863 m
.43225 1.02204 L
s
.4174 1.01802 m
.4258 1.01863 L
s
.32582 .82888 m .32323 .83787 L .32682 .83616 L 0 1 .471 r
F
0 g
.32597 .82416 m
.32702 .82944 L
s
.32582 .82888 m .31664 .83306 L .32323 .83787 L 0 1 .471 r
F
0 g
.32323 .83787 m
.32501 .84503 L
s
.39313 .86892 m .3779 .86034 L .38045 .86693 L 0 1 .461 r
F
0 g
.37368 .86318 m
.38045 .86693 L
s
.33746 .82425 m
.34482 .82616 L
s
.34482 .82616 m
.34482 .82616 L
s
.34482 .82616 m
.34482 .82616 L
s
.73852 .95207 m .72968 .96152 L .73839 .96001 L 0 1 .539 r
F
.73852 .95207 m .72655 .95972 L .72968 .96152 L F
0 g
.725 .96553 m
.72968 .96152 L
s
.36454 1.00568 m .36745 1.012 L .36971 1.01016 L 0 1 .539 r
F
.36454 1.00568 m .35862 1.01016 L .36745 1.012 L F
0 g
.36745 1.012 m
.37334 1.01619 L
s
.50294 .85163 m .49739 .84947 L .49276 .85036 L 0 1 .483 r
F
.79179 .74559 m .8023 .74264 L .79795 .74061 L 0 1 .49 r
F
.79179 .74559 m .80252 .75074 L .8023 .74264 L F
.48172 .56914 m .482 .5553 L .47909 .55051 L 0 1 .301 r
F
.48172 .56914 m .48312 .56328 L .482 .5553 L F
0 g
.482 .5553 m
.48532 .55437 L
s
.55509 1.05072 m
.55665 1.05014 L
s
.51378 .67018 m .51494 .67016 L .51468 .66938 L 0 .892 .132 r
F
.5161 .66544 m .51468 .66938 L .51494 .67016 L 0 .922 .137 r
F
0 g
.51494 .67016 m
.51618 .66873 L
s
.51409 .67261 m
.51494 .67016 L
s
.49552 1.02019 m .50237 1.02613 L .50256 1.02315 L 0 1 .535 r
F
.51954 1.02217 m .50256 1.02315 L .50237 1.02613 L 0 1 .52 r
F
0 g
.50237 1.02613 m
.50977 1.02952 L
s
.49472 1.02732 m
.50237 1.02613 L
s
.47168 1.01739 m .45329 1.01881 L .45991 1.02185 L 0 1 .539 r
F
0 g
.45171 1.02226 m
.45991 1.02185 L
s
.38309 .96003 m .38515 .96442 L .38742 .9623 L 0 1 .522 r
F
.38309 .96003 m .37712 .96516 L .38515 .96442 L F
0 g
.38515 .96442 m
.39014 .96645 L
s
.49817 .96714 m .49742 .9702 L .50395 .97375 L 0 .562 .414 r
F
.80252 .75074 m .81315 .74752 L .80881 .7456 L 0 1 .494 r
F
.80252 .75074 m .81324 .75565 L .81315 .74752 L F
.49227 .57368 m .48634 .56436 L .48924 .57165 L 0 1 .294 r
F
.48957 .58516 m .48634 .56436 L .48312 .56328 L 0 1 .298 r
F
.48957 .58516 m .48924 .57165 L .48634 .56436 L F
0 g
.48532 .55437 m
.48634 .56436 L
s
.48622 .56432 m
.48634 .56436 L
s
.4992 .60081 m .49227 .57368 L .49357 .58488 L 0 1 .293 r
F
0 g
.46579 .93253 m
.46923 .93045 L
s
.48165 .91966 m .46729 .92884 L .47225 .92863 L 0 1 .477 r
F
0 g
.46923 .93045 m
.47225 .92863 L
s
.4761 .73717 m .46927 .74265 L .46689 .74634 L 0 1 .387 r
F
.4761 .73717 m .47322 .73872 L .46927 .74265 L F
.48135 .72747 m .47322 .73872 L .4761 .73717 L 0 1 .326 r
F
0 g
.4761 .73717 m
.47677 .73892 L
s
.4761 .73717 m
.47974 .73307 L
s
.28546 .82751 m
.28547 .8276 L
s
.28494 .82195 m
.28509 .82354 L
s
.28511 .82384 m
.28546 .82751 L
s
.28544 .8275 m
.28545 .82755 L
s
.28545 .82755 m
.28547 .8276 L
s
.28545 .82747 m
.28547 .8276 L
s
.28495 .8238 m
.28543 .82731 L
s
.28543 .82731 m
.28545 .82747 L
s
.43874 .94169 m .44199 .94511 L .44338 .94276 L 0 1 .506 r
F
.43874 .94169 m .43497 .94742 L .44199 .94511 L F
0 g
.44199 .94511 m
.44713 .94583 L
s
.50059 .69798 m .49473 .70851 L .49523 .70967 L 0 1 .21 r
F
0 g
.49239 .71437 m
.49523 .70967 L
s
.47975 .9476 m .46999 .9459 L .47797 .95182 L 0 .73 .45 r
F
.47975 .9476 m .46475 .94009 L .46999 .9459 L F
0 g
.46326 .94275 m
.46999 .9459 L
s
.47133 .53392 m .47343 .51888 L .47088 .51704 L 0 1 .294 r
F
.47133 .53392 m .47363 .52611 L .47343 .51888 L F
0 g
.47343 .51888 m
.47719 .51403 L
s
.47343 .51888 m
.47363 .52611 L
s
.47363 .52611 m
.47725 .52293 L
s
.29543 .82397 m
.29557 .82403 L
s
.64059 .45479 m
.64219 .46441 L
s
.64219 .46441 m
.64293 .46884 L
s
.64004 .45146 m
.64059 .45479 L
s
.6384 .44165 m
.63952 .44835 L
s
.51816 .66228 m
.51816 .66228 L
s
.51816 .66228 m
.51817 .66203 L
s
.51818 .66175 m
.51818 .66155 L
s
.5173 .66293 m
.51731 .66292 L
s
.51731 .66292 m
.51738 .66287 L
s
.51738 .66287 m
.51741 .66284 L
s
.51741 .66284 m
.51744 .66282 L
s
.51779 .66256 m
.51793 .66246 L
s
.51803 .66238 m
.51816 .66228 L
s
.51802 .86583 m
.51817 .86578 L
s
.34989 .8427 m .33284 .83326 L .33378 .84064 L 0 1 .467 r
F
0 g
.33378 .84063 m
.33378 .84064 L
s
.32682 .83616 m
.33378 .84064 L
s
.50816 .63071 m .50407 .58424 L .50321 .58681 L 0 .838 .287 r
F
.50816 .63071 m .50597 .59629 L .50407 .58424 L F
0 g
.50345 .57049 m
.50407 .58424 L
s
.50538 .58058 m
.5056 .58646 L
s
.50627 .57826 m
.50719 .58603 L
s
.50769 .5797 m
.50781 .58749 L
s
.53238 .62878 m
.53252 .62829 L
s
.39047 .79415 m .38804 .79857 L .39117 .79641 L 0 1 .496 r
F
0 g
.39117 .79641 m
.39693 .79527 L
s
.39047 .79415 m .38244 .79938 L .38804 .79857 L 0 1 .496 r
F
0 g
.38804 .79857 m
.38934 .80084 L
s
.47168 1.01739 m .47766 1.02299 L .47829 1.02043 L 0 1 .539 r
F
.49552 1.02019 m .47829 1.02043 L .47766 1.02299 L 0 1 .535 r
F
0 g
.47766 1.02299 m
.4847 1.02594 L
s
.46979 1.0236 m
.47766 1.02299 L
s
.35704 .9373 m .33792 .94229 L .34191 .94312 L 0 1 .383 r
F
.35704 .9373 m .34091 .94045 L .33792 .94229 L F
.35704 .9373 m .34912 .93831 L .34091 .94045 L F
.36392 .9322 m .34912 .93831 L .35704 .9373 L 0 1 .348 r
F
0 g
.35704 .9373 m
.36494 .93495 L
s
.35704 .9373 m
.36098 .93814 L
s
.49536 .41961 m .50415 .40393 L .50383 .40826 L 0 0 .04 r
F
0 g
.50415 .40393 m
.50828 .39181 L
s
.50053 .40878 m
.50415 .40393 L
s
.48172 .56914 m .47909 .55051 L .4756 .55202 L 0 1 .301 r
F
0 g
.47835 .54159 m
.47909 .55051 L
s
.44803 .76088 m .44563 .76607 L .44839 .76281 L 0 1 .429 r
F
.44803 .76088 m .44088 .76887 L .44563 .76607 L F
0 g
.44563 .76607 m
.44647 .76799 L
s
.52037 .65609 m
.52041 .65599 L
s
.52041 .65599 m
.52046 .65585 L
s
.51154 .62561 m .50982 .58776 L .5106 .60948 L 0 .801 .28 r
F
.51038 .62676 m .5106 .60948 L .50982 .58776 L 0 .812 .282 r
F
0 g
.50982 .58776 m
.50992 .57335 L
s
.50902 .57854 m
.50982 .58776 L
s
.50713 .68441 m .50276 .69389 L .5033 .69452 L 0 1 .167 r
F
0 g
.50109 .69915 m
.5033 .69452 L
s
.34956 .96653 m .35111 .97126 L .35375 .96936 L 0 1 .528 r
F
.34956 .96653 m .34272 .97112 L .35111 .97126 L F
0 g
.35111 .97126 m
.35605 .97386 L
s
.74004 .5557 m .74592 .54661 L .75058 .5524 L 0 .391 .063 r
F
.74004 .5557 m .74141 .54801 L .74592 .54661 L F
0 g
.74282 .53959 m
.74592 .54661 L
s
.26512 .83081 m .24846 .82552 L .24971 .82982 L 0 1 .537 r
F
.26512 .83081 m .25251 .82431 L .24846 .82552 L F
.26512 .83081 m .25966 .82659 L .25251 .82431 L F
.27485 .82728 m .25966 .82659 L .26512 .83081 L 0 1 .536 r
F
0 g
.26512 .83081 m
.26631 .83498 L
s
.26512 .83081 m
.27204 .83285 L
s
.35862 1.01016 m .33993 1.00391 L .33731 1.0056 L 0 1 .539 r
F
.35862 1.01016 m .34907 1.00587 L .33993 1.00391 L F
.36454 1.00568 m .34907 1.00587 L .35862 1.01016 L F
0 g
.35862 1.01016 m
.36407 1.01475 L
s
.35862 1.01016 m
.36745 1.012 L
s
.44702 .9232 m
.45359 .9263 L
s
.2324 .81028 m .22878 .81989 L .23281 .81861 L 0 1 .492 r
F
0 g
.23281 .81861 m
.23884 .82368 L
s
.2324 .81028 m .22217 .81334 L .22878 .81989 L 0 1 .492 r
F
0 g
.22878 .81989 m
.22973 .82532 L
s
.48957 .58516 m .49062 .58057 L .48924 .57165 L 0 1 .298 r
F
0 g
.48924 .57165 m
.49227 .57368 L
s
.49194 .71288 m .48469 .72327 L .48514 .72475 L 0 1 .276 r
F
0 g
.48172 .72915 m
.48514 .72475 L
s
.37712 .96516 m .3577 .9665 L .36235 .96894 L 0 1 .527 r
F
0 g
.35375 .96936 m
.36235 .96894 L
s
.46096 .93236 m .46475 .94009 L .46575 .93828 L 0 .853 .464 r
F
0 g
.46115 .93204 m
.46579 .93253 L
s
.47975 .9476 m .46575 .93828 L .46475 .94009 L 0 .73 .45 r
F
0 g
.46475 .94009 m
.46999 .9459 L
s
.45943 .93758 m
.46475 .94009 L
s
.51937 .65982 m .52418 .64698 L .52161 .65394 L 0 0 0 r
F
0 g
.51933 .65861 m
.51939 .65853 L
s
.52032 .6578 m .52161 .65394 L .52418 .64698 L 0 0 0 r
F
0 g
.52162 .65325 m
.5221 .65203 L
s
.5227 .6507 m
.52303 .64979 L
s
.52291 .65017 m
.52307 .64976 L
s
.52418 .64698 m
.52428 .64671 L
s
.52418 .64698 m
.52435 .64652 L
s
.5203 .65626 m
.52034 .65616 L
s
.52034 .65616 m
.52037 .65609 L
s
.24394 .81625 m
.2489 .82043 L
s
.51904 .49714 m .52667 .45533 L .52399 .46045 L 0 1 .139 r
F
0 g
.52652 .47133 m
.52833 .45741 L
s
.51904 .49714 m .52605 .46423 L .52667 .45533 L 0 1 .139 r
F
0 g
.52667 .45533 m
.53021 .43437 L
s
.40908 .9557 m .39084 .95913 L .39554 .96099 L 0 1 .521 r
F
0 g
.38742 .9623 m
.39554 .96099 L
s
.49817 .96714 m .49004 .96093 L .48352 .95739 L 0 .562 .414 r
F
.47855 .8319 m .47559 .84023 L .48037 .83954 L 0 1 .483 r
F
.47855 .8319 m .47026 .83778 L .47559 .84023 L F
0 g
.47559 .84023 m
.47879 .84447 L
s
.48957 .58516 m .48312 .56328 L .48172 .56914 L 0 1 .298 r
F
0 g
.482 .5553 m
.48312 .56328 L
s
.48312 .56328 m
.48622 .56432 L
s
.49103 .83736 m .48367 .8438 L .48914 .84611 L 0 1 .481 r
F
.49103 .83736 m .48037 .83954 L .48367 .8438 L F
0 g
.47879 .84447 m
.48367 .8438 L
s
.43497 .94742 m .41924 .95083 L .41691 .95367 L 0 1 .515 r
F
.43497 .94742 m .42698 .94814 L .41924 .95083 L F
0 g
.43497 .94742 m
.43957 .94923 L
s
.43874 .94169 m .42699 .94814 L .43497 .94742 L 0 1 .506 r
F
0 g
.43497 .94742 m
.44199 .94511 L
s
.51707 .66362 m
.5171 .66367 L
s
.51726 .66389 m
.51734 .66401 L
s
.51666 .66479 m
.51673 .66472 L
s
.51711 .66428 m
.51734 .66401 L
s
.42412 .77701 m .42161 .78172 L .42459 .77902 L 0 1 .465 r
F
.42412 .77701 m .41644 .7836 L .42161 .78172 L F
0 g
.42161 .78172 m
.42261 .78374 L
s
.31664 .83306 m .30467 .81996 L .30082 .8215 L 0 1 .475 r
F
0 g
.29557 .82403 m
.30168 .82676 L
s
.29533 .82385 m
.30137 .82487 L
s
.31664 .83306 m .31145 .82492 L .30467 .81996 L 0 1 .475 r
F
.32582 .82888 m .31145 .82492 L .31664 .83306 L 0 1 .471 r
F
0 g
.31664 .83306 m
.31784 .84043 L
s
.31664 .83306 m
.32323 .83787 L
s
.42459 .77902 m
.42979 .77681 L
s
.44088 .76887 m .42915 .7748 L .42979 .77681 L 0 1 .459 r
F
.46278 .74995 m .45252 .75783 L .45307 .75968 L 0 1 .413 r
F
0 g
.44839 .76281 m
.45307 .75968 L
s
.40866 .88553 m .40231 .87896 L .39567 .87551 L 0 1 .464 r
F
.47855 .8319 m .46738 .83352 L .47026 .83778 L 0 1 .483 r
F
0 g
.46516 .83823 m
.47026 .83778 L
s
.75413 .71603 m
.75441 .71738 L
s
.29525 .82394 m
.30203 .82889 L
s
.29514 .82386 m
.29525 .82394 L
s
.30086 .82176 m
.30203 .82889 L
s
.52586 .99081 m
.52593 .99085 L
s
.53102 .99396 m
.53136 .99417 L
s
.49103 .83736 m .48914 .84611 L .4937 .84518 L 0 1 .481 r
F
0 g
.48914 .84611 m
.49276 .85036 L
s
.53108 .61251 m
.53118 .61138 L
s
.53118 .61138 m
.53193 .60356 L
s
.53033 .60423 m
.53086 .60191 L
s
.53086 .60191 m
.53224 .59578 L
s
.42998 .89643 m .42525 .90157 L .43165 .90479 L 0 .964 .458 r
F
.42998 .89643 m .41849 .89522 L .42525 .90157 L F
0 g
.42525 .90157 m
.42899 .90782 L
s
.46242 .83398 m .45729 .83136 L .45202 .8316 L 0 1 .492 r
F
.69977 .5447 m .71025 .52218 L .7121 .54092 L 0 .578 .137 r
F
0 g
.71025 .52218 m
.71436 .51922 L
s
.42998 .89643 m .41504 .88892 L .41849 .89522 L 0 .964 .458 r
F
0 g
.41182 .89196 m
.41849 .89522 L
s
.41965 .81915 m .41871 .82591 L .42122 .82347 L 0 1 .5 r
F
.41965 .81915 m .41312 .82514 L .41871 .82591 L F
.43181 .82709 m .42122 .82347 L .41871 .82591 L 0 1 .499 r
F
0 g
.41871 .82591 m
.42082 .83017 L
s
.275 .82354 m .25909 .81016 L .26001 .81801 L 0 1 .485 r
F
.275 .82354 m .26314 .80884 L .25909 .81016 L F
.275 .82354 m .26996 .81458 L .26314 .80884 L F
.28474 .8199 m .26996 .81458 L .275 .82354 L 0 1 .481 r
F
0 g
.275 .82354 m
.2752 .82531 L
s
.275 .82354 m
.27652 .82482 L
s
.50816 .63071 m .50321 .58681 L .50414 .60151 L 0 .838 .287 r
F
0 g
.50099 .57837 m
.50321 .58681 L
s
.72985 .94025 m .72167 .95164 L .73005 .94765 L 0 1 .526 r
F
.72985 .94025 m .71856 .95093 L .72167 .95164 L F
0 g
.71727 .956 m
.72167 .95164 L
s
.72167 .95164 m
.72824 .94851 L
s
.46903 .74086 m .46689 .74634 L .46927 .74265 L 0 1 .363 r
F
.46903 .74086 m .46278 .74995 L .46689 .74634 L F
0 g
.46689 .74634 m
.46757 .74808 L
s
.5106 .67873 m .50921 .68105 L .50766 .68504 L 0 1 .172 r
F
.51145 .67473 m .5106 .67873 L .51179 .67592 L 0 .872 .124 r
F
.51145 .67473 m .50921 .68105 L .5106 .67873 L F
0 g
.5106 .67873 m
.51149 .67897 L
s
.41312 .82514 m .40235 .82075 L .39952 .82297 L 0 1 .504 r
F
.41312 .82514 m .40819 .82168 L .40235 .82075 L F
.41965 .81915 m .40819 .82168 L .41312 .82514 L 0 1 .5 r
F
0 g
.41312 .82514 m
.41871 .82591 L
s
.41312 .82514 m
.41494 .82951 L
s
.77773 .57868 m .7869 .58433 L .78994 .58791 L 0 .096 0 r
F
0 g
.78856 .58686 m
.79003 .58912 L
s
.42139 1.01281 m .40176 1.01139 L .40766 1.01508 L 0 1 .54 r
F
0 g
.39894 1.01436 m
.40766 1.01508 L
s
.37416 .81688 m .37211 .82349 L .37523 .82153 L 0 1 .512 r
F
.37416 .81688 m .36615 .82165 L .37211 .82349 L F
0 g
.37211 .82349 m
.37383 .82807 L
s
.73852 .95207 m .73032 .95567 L .72655 .95972 L 0 1 .539 r
F
0 g
.72631 .95279 m
.72913 .94891 L
s
.71743 .9609 m
.72655 .95972 L
s
.50696 .85593 m
.51128 .85474 L
s
.51904 .49714 m .52279 .48212 L .52605 .46423 L 0 1 .139 r
F
0 g
.52605 .46423 m
.52833 .45741 L
s
.52653 .61052 m
.52748 .60105 L
s
.44088 .76887 m .43225 .77188 L .42915 .7748 L 0 1 .459 r
F
.44088 .76887 m .43728 .76933 L .43225 .77188 L F
.44803 .76088 m .43728 .76933 L .44088 .76887 L 0 1 .429 r
F
0 g
.44088 .76887 m
.44563 .76607 L
s
.44088 .76887 m
.4415 .77088 L
s
.55541 .37531 m .56159 .36995 L .56739 .37414 L 0 .384 .133 r
F
0 g
.56159 .36995 m
.56502 .35655 L
s
.43181 .82709 m .42684 .82397 L .42122 .82347 L 0 1 .499 r
F
0 g
.43181 .82709 m
.43391 .83135 L
s
.43775 .82021 m .43181 .82709 L .43723 .82733 L 0 1 .495 r
F
.43775 .82021 m .42684 .82397 L .43181 .82709 L F
.4143 .88042 m .40866 .88553 L .41504 .88892 L 0 1 .457 r
F
.4143 .88042 m .40231 .87896 L .40866 .88553 L F
0 g
.40866 .88553 m
.41182 .89196 L
s
.75877 .71999 m
.76377 .71589 L
s
.44652 .91206 m .43564 .91096 L .44274 .91712 L 0 .899 .459 r
F
.44652 .91206 m .43165 .90479 L .43564 .91096 L F
0 g
.42899 .90782 m
.43564 .91096 L
s
.44527 1.01885 m .43562 1.01659 L .42727 1.0165 L 0 1 .54 r
F
.44823 1.01321 m .44527 1.01885 L .45329 1.01881 L F
.44823 1.01321 m .43562 1.01659 L .44527 1.01885 L F
0 g
.44527 1.01885 m
.45171 1.02226 L
s
.37712 .96516 m .36035 .9646 L .3577 .9665 L 0 1 .527 r
F
.37712 .96516 m .36868 .96403 L .36035 .9646 L F
.38309 .96003 m .36868 .96403 L .37712 .96516 L 0 1 .522 r
F
0 g
.37712 .96516 m
.38515 .96442 L
s
.37712 .96516 m
.38174 .9676 L
s
.51977 .47625 m .5276 .44537 L .52823 .44099 L 0 .816 .094 r
F
.51977 .47625 m .52399 .46045 L .5276 .44537 L F
0 g
.5276 .44537 m
.5297 .43654 L
s
.51944 .63683 m .52329 .59416 L .52093 .61775 L 0 .762 .271 r
F
.51842 .63301 m .52093 .61775 L .52329 .59416 L 0 .769 .271 r
F
0 g
.52329 .59416 m
.52563 .5792 L
s
.52329 .59416 m
.5235 .5906 L
s
.46643 .82603 m .46242 .83398 L .46738 .83352 L 0 1 .486 r
F
.46643 .82603 m .45729 .83136 L .46242 .83398 L F
0 g
.46242 .83398 m
.46516 .83823 L
s
.51954 1.02217 m .5272 1.02938 L .52695 1.02556 L 0 1 .52 r
F
.54354 1.02912 m .5272 1.02938 L .5349 1.03507 L 0 .994 .467 r
F
.54354 1.02912 m .52695 1.02556 L .5272 1.02938 L F
0 g
.51983 1.03107 m
.5272 1.02938 L
s
.29118 .82532 m
.2912 .82533 L
s
.29437 .82011 m .29122 .82533 L .29506 .82381 L 0 1 .532 r
F
0 g
.2912 .82533 m
.29122 .82533 L
s
.29506 .82381 m
.29514 .82386 L
s
.29506 .82381 m
.29543 .82397 L
s
.29506 .82381 m
.29514 .82382 L
s
.29122 .82533 m
.29127 .82557 L
s
.44338 .94276 m
.45032 .93977 L
s
.47975 .9476 m .47797 .95182 L .4844 .95505 L 0 .73 .45 r
F
0 g
.47797 .95182 m
.48352 .95739 L
s
.37155 .85641 m .35932 .84523 L .35621 .84701 L 0 1 .465 r
F
.37155 .85641 m .3659 .84926 L .35932 .84523 L F
.37882 .85171 m .37155 .85641 L .3779 .86034 L 0 1 .459 r
F
.37882 .85171 m .3659 .84926 L .37155 .85641 L F
0 g
.37155 .85641 m
.37368 .86318 L
s
.47334 .48463 m .46693 .4924 L .46911 .49209 L 0 1 .187 r
F
.47334 .48463 m .46822 .48547 L .46693 .4924 L F
.47334 .48463 m .47213 .47594 L .46822 .48547 L F
.47334 .48463 m .47636 .46851 L .47213 .47594 L F
.39338 1.01028 m .3731 1.00741 L .3787 1.0115 L 0 1 .539 r
F
0 g
.36971 1.01016 m
.3787 1.0115 L
s
.50375 .8424 m .49739 .84947 L .50294 .85163 L 0 1 .477 r
F
.50375 .8424 m .4937 .84518 L .49739 .84947 L F
0 g
.49276 .85036 m
.49739 .84947 L
s
.41526 .94878 m .41691 .95367 L .41924 .95083 L 0 1 .511 r
F
.41526 .94878 m .40908 .9557 L .41691 .95367 L F
0 g
.41691 .95367 m
.42154 .95548 L
s
.37882 .85171 m .3779 .86034 L .38072 .85843 L 0 1 .459 r
F
.39313 .86892 m .38072 .85843 L .3779 .86034 L 0 1 .461 r
F
0 g
.3779 .86034 m
.38045 .86693 L
s
.37155 .85641 m
.3779 .86034 L
s
.75155 .7775 m .76203 .78714 L .7624 .7814 L 0 .781 .456 r
F
0 g
.75155 .7775 m
.75605 .77754 L
s
.75155 .7775 m
.75169 .77313 L
s
.43775 .82021 m .43723 .82733 L .4395 .82453 L 0 1 .495 r
F
.44977 .82731 m .4395 .82453 L .43723 .82733 L 0 1 .493 r
F
0 g
.43723 .82733 m
.4395 .83161 L
s
.43181 .82709 m
.43723 .82733 L
s
.3938 .82176 m .37992 .81855 L .38141 .82306 L 0 1 .508 r
F
0 g
.37523 .82153 m
.38141 .82306 L
s
.50783 .40377 m .51347 .39346 L .51781 .39013 L 0 .002 .082 r
F
0 g
.51347 .39346 m
.51758 .38137 L
s
.35787 .83834 m .35621 .84701 L .35932 .84523 L 0 1 .462 r
F
.35787 .83834 m .34989 .8427 L .35621 .84701 L F
0 g
.35621 .84701 m
.35835 .85379 L
s
.30474 .81997 m
.30493 .82 L
s
.47112 .50908 m .46446 .51463 L .46703 .51522 L 0 1 .263 r
F
.47112 .50908 m .46499 .50748 L .46446 .51463 L F
.47112 .50908 m .46828 .49854 L .46499 .50748 L F
.47112 .50908 m .47236 .49243 L .46828 .49854 L F
0 g
.47236 .49243 m
.47334 .48463 L
s
.37081 .92713 m .37156 .92965 L .37421 .92753 L 0 1 .306 r
F
0 g
.37421 .92753 m
.38201 .92436 L
s
.37081 .92713 m .36392 .9322 L .37156 .92965 L 0 1 .306 r
F
0 g
.37156 .92965 m
.37566 .92987 L
s
.4143 .88042 m .39942 .87252 L .40231 .87896 L 0 1 .457 r
F
0 g
.39567 .87551 m
.40231 .87896 L
s
.4781 .46104 m .47198 .47103 L .47374 .46976 L 0 .882 .124 r
F
.4781 .46104 m .47406 .46452 L .47198 .47103 L F
.4781 .46104 m .47858 .45457 L .47406 .46452 L F
.4781 .46104 m .48293 .44589 L .47858 .45457 L F
0 g
.47636 .46851 m
.4781 .46104 L
s
.44652 .91206 m .44274 .91712 L .44911 .92024 L 0 .899 .459 r
F
0 g
.44274 .91712 m
.44702 .9232 L
s
.47384 .55882 m .47472 .54479 L .4718 .54193 L 0 1 .305 r
F
.47384 .55882 m .4756 .55202 L .47472 .54479 L F
0 g
.47472 .54479 m
.47835 .54159 L
s
.46278 .74995 m .45529 .75445 L .45252 .75783 L 0 1 .413 r
F
.46278 .74995 m .45969 .75107 L .45529 .75445 L F
.46903 .74086 m .45969 .75107 L .46278 .74995 L 0 1 .363 r
F
0 g
.46278 .74995 m
.46332 .7518 L
s
.46278 .74995 m
.46689 .74634 L
s
.51835 .662 m .52249 .65128 L .52031 .65701 L 0 0 0 r
F
.51937 .65982 m .52031 .65701 L .52249 .65128 L F
0 g
.52104 .65474 m
.52162 .65325 L
s
.52249 .65128 m
.5227 .6507 L
s
.52249 .65128 m
.52291 .65017 L
s
.69458 .94617 m .69391 .95422 L .70222 .95124 L 0 1 .536 r
F
0 g
.68981 .95803 m
.69391 .95422 L
s
.68559 .95482 m
.69391 .95422 L
s
.29876 .97766 m .27746 .97451 L .28193 .97822 L 0 1 .535 r
F
.29876 .97766 m .28074 .97305 L .27746 .97451 L F
.29876 .97766 m .28988 .9744 L .28074 .97305 L F
.30641 .97362 m .28988 .9744 L .29876 .97766 L 0 1 .533 r
F
0 g
.29876 .97766 m
.30762 .97883 L
s
.29876 .97766 m
.30318 .98135 L
s
.69471 .95091 m .68573 .95977 L .69399 .95689 L 0 1 .508 r
F
.69471 .95091 m .68295 .95903 L .68573 .95977 L F
0 g
.68108 .96301 m
.68573 .95977 L
s
.68989 .96097 m
.6924 .95847 L
s
.68573 .95977 m
.68672 .95942 L
s
.51954 1.02217 m .50992 1.02145 L .50256 1.02315 L 0 1 .52 r
F
.40111 .81632 m .39952 .82297 L .40235 .82075 L 0 1 .505 r
F
.40111 .81632 m .3938 .82176 L .39952 .82297 L F
0 g
.39952 .82297 m
.40135 .82734 L
s
.27493 .82541 m .25884 .81632 L .25983 .8223 L 0 1 .524 r
F
.27493 .82541 m .26289 .81505 L .25884 .81632 L F
.27493 .82541 m .26979 .81895 L .26289 .81505 L F
.28467 .82181 m .26979 .81895 L .27493 .82541 L F
0 g
.27493 .82541 m
.27694 .82652 L
s
.27493 .82541 m
.27521 .82715 L
s
.76377 .71589 m
.76531 .72377 L
s
.46643 .82603 m .45485 .8271 L .45729 .83136 L 0 1 .486 r
F
0 g
.45202 .8316 m
.45729 .83136 L
s
.47855 .8319 m .48037 .83954 L .48143 .83616 L 0 1 .483 r
F
.49103 .83736 m .48143 .83616 L .48037 .83954 L 0 1 .481 r
F
0 g
.48037 .83954 m
.48367 .8438 L
s
.47559 .84023 m
.48037 .83954 L
s
.59292 .73697 m
.59403 .83894 L
s
.59404 .83991 m
.59405 .84095 L
s
.59735 1.14495 m
.59782 1.18806 L
s
.59782 1.18806 m
.59791 1.1967 L
s
.59791 1.1967 m
.59792 1.19731 L
s
.59792 1.19731 m
.59801 1.20591 L
s
.59801 1.20591 m
.59817 1.22023 L
s
.59715 1.12683 m
.59735 1.14495 L
s
.59498 .92694 m
.59504 .93246 L
s
.59594 1.01484 m
.59609 1.02892 L
s
.59611 1.03097 m
.59654 1.07076 L
s
.59817 1.22023 m
.59817 1.22078 L
s
.59817 1.22078 m
.59823 1.22658 L
s
.59823 1.22658 m
.59853 1.25413 L
s
.59203 .65451 m
.59204 .65572 L
s
.59205 .65651 m
.59207 .65802 L
s
.59207 .65802 m
.59273 .71895 L
s
.59273 .71895 m
.59292 .73697 L
s
.59171 .62512 m
.59174 .62767 L
s
.5887 .73677 m
.58919 .6878 L
s
.58919 .6878 m
.58938 .66788 L
s
.58938 .66788 m
.58943 .66337 L
s
.58943 .66337 m
.58951 .65533 L
s
.58953 .65311 m
.58954 .65151 L
s
.5897 .6355 m
.58975 .63038 L
s
.51038 .62676 m .50786 .59166 L .5091 .61192 L 0 .812 .282 r
F
.50925 .62848 m .5091 .61192 L .50786 .59166 L 0 .825 .285 r
F
0 g
.50781 .58749 m
.50786 .59166 L
s
.50719 .58603 m
.50786 .59166 L
s
.80163 .59909 m .81015 .60324 L .8055 .59981 L 0 .286 .225 r
F
.80163 .59909 m .81322 .608 L .81015 .60324 L F
.48135 .72747 m .47285 .73705 L .47322 .73872 L 0 1 .326 r
F
0 g
.46927 .74265 m
.47322 .73872 L
s
.47405 .47256 m
.47636 .46851 L
s
.81322 .608 m .82419 .61935 L .82479 .616 L 0 .348 .265 r
F
0 g
.82029 .61921 m
.82419 .61935 L
s
.34989 .8427 m .33726 .83112 L .33284 .83326 L 0 1 .467 r
F
.34989 .8427 m .34458 .83517 L .33726 .83112 L F
0 g
.34989 .8427 m
.35082 .85007 L
s
.35787 .83834 m .34458 .83517 L .34989 .8427 L 0 1 .462 r
F
0 g
.34989 .8427 m
.35621 .84701 L
s
.4992 .60081 m .49996 .59787 L .49865 .58665 L 0 1 .293 r
F
.50131 .89953 m .50582 .90043 L .506 .89832 L 0 1 .431 r
F
.50131 .89953 m .50055 .90488 L .50582 .90043 L F
0 g
.50582 .90043 m
.50999 .89875 L
s
.50055 .90488 m .48808 .91337 L .48749 .91575 L 0 1 .451 r
F
.50055 .90488 m .49368 .90871 L .48808 .91337 L F
.50131 .89953 m .49368 .90871 L .50055 .90488 L 0 1 .431 r
F
0 g
.50055 .90488 m
.50555 .90378 L
s
.50055 .90488 m
.50582 .90043 L
s
.54354 1.02912 m .5349 1.03507 L .54494 1.03887 L 0 .994 .467 r
F
0 g
.5272 1.02938 m
.5349 1.03507 L
s
.52795 1.03469 m
.5349 1.03507 L
s
.44823 1.01321 m .45329 1.01881 L .45435 1.01649 L 0 1 .54 r
F
.47168 1.01739 m .45435 1.01649 L .45329 1.01881 L 0 1 .539 r
F
0 g
.45329 1.01881 m
.45991 1.02185 L
s
.44527 1.01885 m
.45329 1.01881 L
s
.50375 .8424 m .50294 .85163 L .50724 .85044 L 0 1 .477 r
F
0 g
.50294 .85163 m
.50696 .85593 L
s
.49741 .60834 m .49062 .58057 L .48957 .58516 L 0 1 .295 r
F
.49741 .60834 m .49357 .58488 L .49062 .58057 L F
0 g
.49227 .57368 m
.49351 .58434 L
s
.48924 .57165 m
.49062 .58057 L
s
.49062 .58057 m
.49157 .58196 L
s
.53238 .62878 m
.53251 .6284 L
s
.41644 .7836 m .40382 .78745 L .40455 .78956 L 0 1 .483 r
F
.41644 .7836 m .4071 .78505 L .40382 .78745 L F
.41644 .7836 m .41252 .78341 L .4071 .78505 L F
.42412 .77701 m .41252 .78341 L .41644 .7836 L 0 1 .465 r
F
0 g
.41644 .7836 m
.42161 .78172 L
s
.41644 .7836 m
.41715 .78572 L
s
.48172 .56914 m .4756 .55202 L .47384 .55882 L 0 1 .301 r
F
0 g
.4756 .55202 m
.47909 .55051 L
s
.47472 .54479 m
.4756 .55202 L
s
.35466 .80542 m .35194 .80991 L .35533 .80811 L 0 1 .513 r
F
0 g
.35533 .80811 m
.36155 .80793 L
s
.35466 .80542 m .34602 .80974 L .35194 .80991 L 0 1 .513 r
F
0 g
.35194 .80991 m
.3533 .81259 L
s
.40908 .9557 m .39312 .95702 L .39084 .95913 L 0 1 .521 r
F
.40908 .9557 m .40095 .95555 L .39312 .95702 L F
0 g
.40908 .9557 m
.41375 .95756 L
s
.41526 .94878 m .40095 .95555 L .40908 .9557 L 0 1 .511 r
F
0 g
.40908 .9557 m
.41691 .95367 L
s
.47133 .53392 m .47088 .51704 L .46695 .52182 L 0 1 .294 r
F
0 g
.47088 .51704 m
.47112 .50908 L
s
.51794 .66159 m
.5181 .66119 L
s
.5181 .66119 m
.51812 .66115 L
s
.51812 .66115 m
.5182 .66095 L
s
.38244 .79938 m .36888 .80076 L .36981 .80316 L 0 1 .506 r
F
.38244 .79938 m .37228 .79888 L .36888 .80076 L F
.38244 .79938 m .3781 .79829 L .37228 .79888 L F
.39047 .79415 m .3781 .79829 L .38244 .79938 L 0 1 .496 r
F
0 g
.38244 .79938 m
.38804 .79857 L
s
.38244 .79938 m
.38335 .80178 L
s
.46643 .82603 m .46738 .83352 L .46886 .83029 L 0 1 .486 r
F
.47855 .8319 m .46886 .83029 L .46738 .83352 L 0 1 .483 r
F
0 g
.46738 .83352 m
.47026 .83778 L
s
.46242 .83398 m
.46738 .83352 L
s
.5543 1.04752 m
.55665 1.05014 L
s
.48344 .91377 m .48749 .91575 L .48808 .91337 L 0 1 .459 r
F
.48344 .91377 m .48165 .91966 L .48749 .91575 L F
0 g
.48749 .91575 m
.49251 .91464 L
s
.4143 .88042 m .41504 .88892 L .41719 .88686 L 0 1 .457 r
F
.42998 .89643 m .41719 .88686 L .41504 .88892 L 0 .964 .458 r
F
0 g
.41504 .88892 m
.41849 .89522 L
s
.40866 .88553 m
.41504 .88892 L
s
.29504 .82371 m
.29506 .82381 L
s
.29505 .82372 m
.29506 .82381 L
s
.29466 .81828 m
.29478 .81996 L
s
.2948 .8202 m
.29505 .82372 L
s
.29504 .82367 m
.29506 .82381 L
s
.29466 .82018 m
.29503 .82351 L
s
.29503 .82351 m
.29504 .82367 L
s
.49103 .83736 m .4937 .84518 L .49433 .84163 L 0 1 .481 r
F
.50375 .8424 m .49433 .84163 L .4937 .84518 L 0 1 .477 r
F
0 g
.4937 .84518 m
.49739 .84947 L
s
.48914 .84611 m
.4937 .84518 L
s
.32125 .81344 m .32552 .81147 L .32079 .81342 L 0 1 .523 r
F
.3374 .81398 m .3257 .81151 L .32125 .81344 L F
.3257 .81151 m .32552 .81147 L .32125 .81344 L F
.3374 .81398 m .33263 .8117 L .32548 .81146 L F
.34602 .80974 m .33263 .8117 L .3374 .81398 L 0 1 .519 r
F
.34602 .80974 m .33176 .80885 L .33263 .8117 L F
.34589 .81467 m .33182 .80887 L .33257 .81378 L 0 1 .517 r
F
.33182 .80887 m .33176 .8089 L .33257 .81378 L F
.34589 .81467 m .34331 .8213 L .34669 .81959 L F
.34589 .81467 m .33726 .81882 L .34331 .8213 L F
.33726 .81882 m .33257 .81378 L .32606 .81165 L 0 1 .518 r
F
.32591 .81172 m .32606 .81165 L .32548 .81146 L F
.33726 .81882 m .32606 .81165 L .32591 .81172 L F
.34589 .81467 m .33257 .81378 L .33726 .81882 L 0 1 .517 r
F
.34576 .81961 m .33182 .80889 L .33251 .81585 L 0 1 .46 r
F
.33182 .80889 m .33179 .80887 L .33179 .80891 L F
.33182 .80889 m .33179 .80891 L .33251 .81585 L F
.33182 .80887 m .33176 .80885 L .33176 .8089 L 0 1 .517 r
F
.33179 .80887 m .33176 .80885 L .33176 .80888 L 0 1 .46 r
F
.33179 .80887 m .33176 .80888 L .33251 .81585 L F
.32079 .81342 m .32548 .81146 L .32074 .81342 L 0 1 .523 r
F
.32552 .81147 m .32548 .81146 L .32079 .81342 L F
.3146 .95263 m .29432 .95481 L .29833 .95642 L 0 1 .423 r
F
.3146 .95263 m .29761 .95325 L .29432 .95481 L F
.3146 .95263 m .30632 .95232 L .29761 .95325 L F
.32228 .94825 m .30632 .95232 L .3146 .95263 L 0 1 .399 r
F
0 g
.3146 .95263 m
.32302 .95149 L
s
.3146 .95263 m
.31857 .95425 L
s
.5183 .88791 m
.51928 .88693 L
s
.49552 1.02019 m .48594 1.01923 L .47829 1.02043 L 0 1 .535 r
F
.36615 .82165 m .35176 .81699 L .35306 .82174 L 0 1 .514 r
F
.36615 .82165 m .35515 .81524 L .35176 .81699 L F
.36615 .82165 m .36132 .81724 L .35515 .81524 L F
.37416 .81688 m .36132 .81724 L .36615 .82165 L 0 1 .512 r
F
0 g
.36615 .82165 m
.37211 .82349 L
s
.36615 .82165 m
.36744 .8264 L
s
.24264 .80719 m .23887 .81668 L .24291 .81538 L 0 1 .489 r
F
0 g
.24291 .81538 m
.24394 .81625 L
s
.24264 .80719 m .2324 .81028 L .23887 .81668 L 0 1 .489 r
F
0 g
.23887 .81668 m
.23974 .82225 L
s
.51145 .67473 m .50866 .6813 L .50921 .68105 L 0 .872 .124 r
F
0 g
.50766 .68504 m
.50921 .68105 L
s
.49616 .70332 m .49473 .70851 L .49629 .7047 L 0 1 .19 r
F
.49616 .70332 m .49194 .71288 L .49473 .70851 L F
.50059 .69798 m .49629 .7047 L .49473 .70851 L 0 1 .21 r
F
0 g
.49473 .70851 m
.49523 .70967 L
s
.23275 .83049 m
.23978 .83302 L
s
.50713 .63339 m .50195 .59082 L .50114 .5936 L 0 .851 .289 r
F
.50713 .63339 m .50414 .60151 L .50195 .59082 L F
0 g
.50181 .58899 m
.50195 .59082 L
s
.50321 .58681 m
.50364 .59366 L
s
.50407 .58424 m
.50569 .59456 L
s
.5056 .58646 m
.50592 .59518 L
s
.59056 .3838 m .59652 .37934 L .60281 .38332 L 0 .457 .118 r
F
0 g
.59652 .37934 m
.59728 .37576 L
s
.42998 .89643 m .43165 .90479 L .43344 .90274 L 0 .964 .458 r
F
.44652 .91206 m .43344 .90274 L .43165 .90479 L 0 .899 .459 r
F
0 g
.43165 .90479 m
.43564 .91096 L
s
.42525 .90157 m
.43165 .90479 L
s
.42122 .82347 m
.42684 .82397 L
s
.34669 .81959 m
.35306 .82174 L
s
.34272 .97112 m .32245 .97041 L .32695 .97341 L 0 1 .531 r
F
.34272 .97112 m .32543 .96873 L .32245 .97041 L F
.34272 .97112 m .33413 .96903 L .32543 .96873 L F
.34956 .96653 m .33413 .96903 L .34272 .97112 L 0 1 .528 r
F
0 g
.34272 .97112 m
.35111 .97126 L
s
.34272 .97112 m
.34717 .97411 L
s
.49194 .71288 m .48668 .71934 L .48469 .72327 L 0 1 .276 r
F
.49194 .71288 m .48978 .71489 L .48668 .71934 L F
.49616 .70332 m .48978 .71489 L .49194 .71288 L 0 1 .19 r
F
0 g
.49194 .71288 m
.49473 .70851 L
s
.49194 .71288 m
.49239 .71437 L
s
.70098 .62368 m
.70298 .6288 L
s
.48172 .56914 m .47497 .56681 L .47823 .57066 L 0 1 .301 r
F
.48172 .56914 m .47384 .55882 L .47497 .56681 L F
.48957 .58516 m .48172 .56914 L .4831 .57807 L 0 1 .298 r
F
0 g
.47823 .57066 m
.48172 .56914 L
s
.74643 .9432 m .7587 .93961 L .7553 .93896 L 0 1 .532 r
F
.73815 .9416 m .74643 .9432 L .7502 .93804 L 0 1 .53 r
F
.3938 .82176 m .38304 .81654 L .37992 .81855 L 0 1 .508 r
F
.3938 .82176 m .389 .81792 L .38304 .81654 L F
.40111 .81632 m .389 .81792 L .3938 .82176 L 0 1 .505 r
F
0 g
.3938 .82176 m
.39528 .82626 L
s
.3938 .82176 m
.39952 .82297 L
s
.51145 .67473 m .51179 .67592 L .512 .67448 L 0 .872 .124 r
F
.51378 .67018 m .512 .67448 L .51179 .67592 L 0 .892 .132 r
F
0 g
.51179 .67592 m
.51269 .67511 L
s
.5106 .67873 m
.51179 .67592 L
s
.33524 .99903 m .33731 1.0056 L .33993 1.00391 L 0 1 .538 r
F
.33524 .99903 m .32842 1.00314 L .33731 1.0056 L F
0 g
.33731 1.0056 m
.3428 1.0102 L
s
.30504 .82012 m
.30518 .82018 L
s
.47133 .53392 m .46446 .53729 L .4674 .53872 L 0 1 .294 r
F
.47133 .53392 m .46427 .53005 L .46446 .53729 L F
.47133 .53392 m .46695 .52182 L .46427 .53005 L F
.48165 .91966 m .46829 .92642 L .46729 .92884 L 0 1 .477 r
F
0 g
.46729 .92884 m
.47225 .92863 L
s
.48165 .91966 m .47445 .92249 L .46829 .92642 L 0 1 .477 r
F
.48344 .91377 m .47445 .92249 L .48165 .91966 L 0 1 .459 r
F
0 g
.48165 .91966 m
.48659 .91946 L
s
.48165 .91966 m
.48749 .91575 L
s
.24865 .82488 m
.24931 .82527 L
s
.43775 .82021 m .42508 .81965 L .42684 .82397 L 0 1 .495 r
F
.70984 .95614 m .72184 .95698 L .7187 .95514 L 0 1 .539 r
F
.44823 1.01321 m .42948 1.01331 L .43562 1.01659 L 0 1 .54 r
F
0 g
.42727 1.0165 m
.43562 1.01659 L
s
.50059 .69798 m .4988 .70018 L .49629 .7047 L 0 1 .21 r
F
.50372 .68966 m .50059 .69798 L .50276 .69389 L 0 .989 .159 r
F
.50372 .68966 m .4988 .70018 L .50059 .69798 L F
0 g
.50059 .69798 m
.50109 .69915 L
s
.2541 .81304 m
.25898 .81715 L
s
.7772 .71375 m .7762 .72974 L .78056 .73202 L 0 1 .484 r
F
.7772 .71375 m .77476 .72192 L .7762 .72974 L F
0 g
.7703 .7344 m
.7762 .72974 L
s
.77476 .72192 m
.7762 .72974 L
s
.76967 .72621 m
.77476 .72192 L
s
.48544 .43902 m .47967 .45117 L .48098 .44886 L 0 0 0 r
F
.48544 .43902 m .48253 .44534 L .47967 .45117 L F
0 g
.48079 .45016 m
.48293 .44589 L
s
.48544 .43902 m .48764 .43528 L .48253 .44534 L 0 0 0 r
F
0 g
.48293 .44589 m
.48465 .44117 L
s
.48544 .43902 m .49209 .42547 L .48764 .43528 L 0 0 0 r
F
.39313 .86892 m .38725 .86211 L .38072 .85843 L 0 1 .461 r
F
.39963 .86392 m .39313 .86892 L .39942 .87252 L 0 1 .455 r
F
.39963 .86392 m .38725 .86211 L .39313 .86892 L F
0 g
.39313 .86892 m
.39567 .87551 L
s
.4992 .60081 m .49357 .58488 L .49646 .59523 L 0 1 .293 r
F
0 g
.49865 .58665 m
.49968 .59548 L
s
.49741 .60834 m .49646 .59523 L .49357 .58488 L 0 1 .295 r
F
0 g
.49351 .58434 m
.49357 .58488 L
s
.49157 .58196 m
.49357 .58488 L
s
.50783 .40377 m .51781 .39013 L .51797 .39599 L 0 .002 .082 r
F
0 g
.51781 .39013 m
.52188 .37752 L
s
.51347 .39346 m
.51781 .39013 L
s
.27485 .82728 m .25859 .82249 L .25966 .82659 L 0 1 .536 r
F
.27485 .82728 m .26264 .82126 L .25859 .82249 L F
.27485 .82728 m .26962 .82333 L .26264 .82126 L F
.2846 .82372 m .26962 .82333 L .27485 .82728 L 0 1 .534 r
F
0 g
.27485 .82728 m
.27587 .83126 L
s
.27485 .82728 m
.2816 .8291 L
s
.76577 .92577 m .7587 .93961 L .76702 .9345 L 0 1 .528 r
F
.76577 .92577 m .7553 .93896 L .7587 .93961 L F
0 g
.75469 .94502 m
.7587 .93961 L
s
.73852 .95207 m .73839 .96001 L .7469 .95618 L 0 1 .539 r
F
0 g
.72968 .96152 m
.73839 .96001 L
s
.73437 .96419 m
.73839 .96001 L
s
.66633 .54484 m
.67053 .51464 L
s
.33713 .82366 m .33284 .83326 L .33726 .83112 L 0 1 .465 r
F
.33713 .82366 m .32583 .82888 L .33284 .83326 L F
0 g
.33284 .83326 m
.33378 .84063 L
s
.37882 .85171 m .36399 .84253 L .3659 .84926 L 0 1 .459 r
F
0 g
.35932 .84523 m
.3659 .84926 L
s
.72985 .94025 m .73005 .94765 L .73815 .9416 L 0 1 .526 r
F
0 g
.72824 .94851 m
.73005 .94765 L
s
.72913 .94891 m
.73005 .94765 L
s
.33726 .81882 m
.34331 .8213 L
s
.34331 .8213 m
.34482 .82616 L
s
.4529 .92536 m
.45359 .9263 L
s
.29821 .99401 m .29963 1.00094 L .30259 .9994 L 0 1 .538 r
F
.29821 .99401 m .29058 .99773 L .29963 1.00094 L F
0 g
.29963 1.00094 m
.3049 1.00607 L
s
.44977 .82731 m .44488 .82453 L .4395 .82453 L 0 1 .493 r
F
.45478 .81974 m .44977 .82731 L .45485 .8271 L 0 1 .487 r
F
.45478 .81974 m .44488 .82453 L .44977 .82731 L F
0 g
.44977 .82731 m
.45202 .8316 L
s
.47975 .9476 m .47217 .94149 L .46575 .93828 L 0 .73 .45 r
F
.76203 .78714 m .77304 .79045 L .76879 .78692 L 0 .827 .466 r
F
.76203 .78714 m .77248 .79603 L .77304 .79045 L F
0 g
.76203 .78714 m
.7624 .78147 L
s
.7624 .78147 m
.7624 .7814 L
s
.41965 .81915 m .40661 .81736 L .40819 .82168 L 0 1 .5 r
F
0 g
.40235 .82075 m
.40819 .82168 L
s
.7772 .71375 m .78056 .73202 L .78575 .72754 L 0 1 .484 r
F
0 g
.78056 .73202 m
.78105 .74015 L
s
.52445 .45301 m .52823 .44099 L .52521 .44924 L 0 .816 .094 r
F
.51977 .47625 m .52521 .44924 L .52052 .4647 L F
.52052 .4647 m .52919 .43672 L .52983 .43541 L 0 0 0 r
F
.52052 .4647 m .52521 .44924 L .52919 .43672 L F
.52116 .46259 m .52983 .43541 L .52644 .44518 L F
.52052 .4647 m .52156 .46143 L .52116 .46259 L F
.52156 .46143 m .52983 .43541 L .52116 .46259 L F
.51977 .47625 m .52744 .44429 L .52445 .45301 L 0 .816 .094 r
F
.52744 .44429 m .52823 .44099 L .52445 .45301 L F
0 g
.52688 .44468 m
.52823 .44099 L
s
.52465 .45767 m
.5276 .44537 L
s
.52398 .47561 m
.52605 .46423 L
s
.52536 .45782 m
.52667 .45533 L
s
.52823 .44099 m
.5287 .43896 L
s
.39852 .78877 m .39587 .79313 L .39901 .79091 L 0 1 .484 r
F
0 g
.39901 .79091 m
.40455 .78956 L
s
.39852 .78877 m .39047 .79415 L .39587 .79313 L 0 1 .484 r
F
0 g
.39587 .79313 m
.39693 .79527 L
s
.50372 .68966 m .50276 .69389 L .50388 .69063 L 0 .989 .159 r
F
.50713 .68441 m .50388 .69063 L .50276 .69389 L 0 1 .167 r
F
0 g
.50276 .69389 m
.5033 .69452 L
s
.50059 .69798 m
.50276 .69389 L
s
.48662 .71774 m .48469 .72327 L .48668 .71934 L 0 1 .243 r
F
.48662 .71774 m .48135 .72747 L .48469 .72327 L F
0 g
.48469 .72327 m
.48514 .72475 L
s
.32998 .94386 m .33046 .94689 L .33344 .94505 L 0 1 .37 r
F
0 g
.33344 .94505 m
.34191 .94312 L
s
.32998 .94386 m .32228 .94825 L .33046 .94689 L 0 1 .37 r
F
0 g
.33046 .94689 m
.33472 .94793 L
s
.69471 .95091 m .69399 .95689 L .70225 .95231 L 0 1 .508 r
F
0 g
.68672 .95942 m
.69399 .95689 L
s
.6924 .95847 m
.69399 .95689 L
s
.54354 1.02912 m .53394 1.02545 L .52695 1.02556 L 0 .994 .467 r
F
0 g
.52695 1.02556 m
.52767 1.02555 L
s
.52767 1.02555 m
.53394 1.02545 L
s
.5161 .66544 m .51518 .66736 L .51468 .66938 L 0 .922 .137 r
F
.32842 1.00314 m .30703 .9971 L .31203 1.00211 L 0 1 .538 r
F
.72985 .94025 m .72206 .94605 L .71856 .95093 L 0 1 .526 r
F
0 g
.71361 .95267 m
.71856 .95093 L
s
.51727 .66431 m .52069 .65563 L .51893 .66017 L 0 0 0 r
F
0 g
.51726 .66306 m
.5173 .66293 L
s
.51835 .662 m .51893 .66017 L .52069 .65563 L 0 0 0 r
F
0 g
.51896 .65958 m
.5203 .65626 L
s
.52069 .65563 m
.52126 .65402 L
s
.52069 .65563 m
.52104 .65474 L
s
.28474 .8199 m .26922 .80685 L .26996 .81458 L 0 1 .481 r
F
.28474 .8199 m .27328 .80552 L .26922 .80685 L F
.28474 .8199 m .27994 .81112 L .27328 .80552 L F
.29451 .81622 m .27994 .81112 L .28474 .8199 L 0 1 .478 r
F
0 g
.28474 .8199 m
.28491 .82172 L
s
.28474 .8199 m
.2863 .8212 L
s
.5669 .61494 m
.56718 .61077 L
s
.27759 .95887 m .2779 .9626 L .28118 .96104 L 0 1 .434 r
F
0 g
.28118 .96104 m
.29037 .96052 L
s
.27759 .95887 m .26917 .96255 L .2779 .9626 L 0 1 .434 r
F
0 g
.2779 .9626 m
.28242 .96462 L
s
.51524 .66864 m .51626 .66555 L .51701 .66354 L 0 0 0 r
F
0 g
.51696 .66368 m
.51701 .66354 L
s
.51695 .66371 m
.51696 .66368 L
s
.51614 .6654 m
.51614 .6654 L
s
.51623 .66529 m
.51645 .66504 L
s
.5162 .66533 m
.51623 .66529 L
s
.51619 .66535 m
.5162 .66533 L
s
.51615 .66539 m
.51619 .66535 L
s
.51614 .6654 m
.51615 .66539 L
s
.23205 .81794 m .22851 .8257 L .23255 .82446 L 0 1 .527 r
F
0 g
.23255 .82446 m
.23902 .82833 L
s
.23205 .81794 m .22182 .82085 L .22851 .8257 L 0 1 .527 r
F
0 g
.22851 .8257 m
.22978 .83106 L
s
.78832 .71926 m .78708 .73534 L .79143 .73749 L 0 1 .49 r
F
.78832 .71926 m .78575 .72754 L .78708 .73534 L F
0 g
.78105 .74015 m
.78708 .73534 L
s
.31407 .96957 m .31503 .97462 L .31799 .97294 L 0 1 .531 r
F
0 g
.31799 .97294 m
.32695 .97341 L
s
.31407 .96957 m .30641 .97362 L .31503 .97462 L 0 1 .531 r
F
0 g
.31503 .97462 m
.31979 .97778 L
s
.46124 .93188 m
.46729 .92884 L
s
.47384 .55882 m .4718 .54193 L .46803 .54536 L 0 1 .305 r
F
0 g
.47133 .53392 m
.4718 .54193 L
s
.39963 .86392 m .39942 .87252 L .40192 .8705 L 0 1 .455 r
F
.4143 .88042 m .40192 .8705 L .39942 .87252 L 0 1 .457 r
F
0 g
.39942 .87252 m
.40231 .87896 L
s
.39313 .86892 m
.39942 .87252 L
s
.64221 .45596 m
.64259 .45738 L
s
.64049 .44949 m
.64084 .4508 L
s
.63833 .44138 m
.63868 .44268 L
s
.63868 .44268 m
.64049 .44949 L
s
.48135 .72747 m .47524 .73328 L .47285 .73705 L 0 1 .326 r
F
.48135 .72747 m .47889 .72917 L .47524 .73328 L F
.48662 .71774 m .47889 .72917 L .48135 .72747 L 0 1 .243 r
F
0 g
.48135 .72747 m
.48172 .72915 L
s
.48135 .72747 m
.48469 .72327 L
s
.50713 .63339 m .50114 .5936 L .50241 .60721 L 0 .851 .289 r
F
0 g
.49865 .58665 m
.50114 .5936 L
s
.49817 .96714 m .50395 .97375 L .50413 .97264 L 0 .562 .414 r
F
.5186 .98457 m .50395 .97375 L .51026 .97968 L 0 .311 .272 r
F
.5186 .98457 m .50413 .97264 L .50395 .97375 L F
0 g
.51026 .97968 m
.51026 .97968 L
s
.50365 .97543 m
.51026 .97968 L
s
.49742 .9702 m
.50395 .97375 L
s
.50395 .97375 m
.51026 .97967 L
s
.78832 .71926 m .79143 .73749 L .79672 .7328 L 0 1 .49 r
F
0 g
.79143 .73749 m
.79179 .74559 L
s
.30475 .82002 m
.30486 .8201 L
s
.45478 .81974 m .45485 .8271 L .45674 .82402 L 0 1 .487 r
F
.46643 .82603 m .45674 .82402 L .45485 .8271 L 0 1 .486 r
F
0 g
.45485 .8271 m
.45729 .83136 L
s
.44977 .82731 m
.45485 .8271 L
s
.39963 .86392 m .38495 .85554 L .38725 .86211 L 0 1 .455 r
F
0 g
.38072 .85843 m
.38725 .86211 L
s
.73011 .94786 m .72184 .95698 L .73032 .95567 L 0 1 .538 r
F
.73011 .94786 m .7187 .95514 L .72184 .95698 L F
0 g
.71743 .9609 m
.72184 .95698 L
s
.67502 .94707 m
.67572 .94706 L
s
.45521 .7526 m .45252 .75783 L .45529 .75445 L 0 1 .387 r
F
.45521 .7526 m .44803 .76088 L .45252 .75783 L F
0 g
.45252 .75783 m
.45307 .75968 L
s
.32582 .82888 m .31429 .81606 L .31044 .81763 L 0 1 .471 r
F
0 g
.31048 .81789 m
.31145 .82492 L
s
.30486 .8201 m
.31145 .82492 L
s
.30518 .82018 m
.31116 .82278 L
s
.30493 .82 m
.31089 .82085 L
s
.32582 .82888 m .32089 .82089 L .31429 .81606 L 0 1 .471 r
F
0 g
.32582 .82888 m
.32682 .83616 L
s
.33713 .82366 m .32089 .82089 L .32583 .82888 L 0 1 .465 r
F
0 g
.32583 .82888 m
.33284 .83326 L
s
.49633 1.01292 m .49552 1.02019 L .50285 1.01862 L 0 1 .536 r
F
.49633 1.01292 m .48594 1.01923 L .49552 1.02019 L F
0 g
.49552 1.02019 m
.50256 1.02315 L
s
.36454 1.00568 m .34387 1.00138 L .34907 1.00587 L 0 1 .539 r
F
0 g
.33993 1.00391 m
.34907 1.00587 L
s
.48957 .58516 m .4831 .57807 L .48635 .58409 L 0 1 .298 r
F
0 g
.48172 .56914 m
.4831 .57807 L
s
.49741 .60834 m .48957 .58516 L .49121 .59521 L 0 1 .295 r
F
.50925 .62848 m .50597 .59629 L .50765 .61498 L 0 .825 .285 r
F
.50816 .63071 m .50765 .61498 L .50597 .59629 L 0 .838 .287 r
F
0 g
.50592 .59518 m
.50597 .59629 L
s
.50569 .59456 m
.50597 .59629 L
s
.49103 .83736 m .486 .83522 L .48143 .83616 L 0 1 .481 r
F
0 g
.48143 .83616 m
.486 .83522 L
s
.2324 .81028 m .21737 .8033 L .22217 .81334 L 0 1 .492 r
F
0 g
.22217 .81334 m
.22798 .8191 L
s
.51925 1.01235 m .50992 1.02145 L .51954 1.02217 L 0 1 .519 r
F
.51925 1.01235 m .50285 1.01862 L .50992 1.02145 L F
0 g
.50256 1.02315 m
.50992 1.02145 L
s
.41924 .95083 m
.42698 .94814 L
s
.43874 .94169 m .42232 .94708 L .42699 .94814 L 0 1 .506 r
F
0 g
.42698 .94814 m
.42699 .94814 L
s
.52155 .86095 m
.52155 .86094 L
s
.79942 .72438 m .79795 .74061 L .8023 .74264 L 0 1 .495 r
F
.79942 .72438 m .79672 .7328 L .79795 .74061 L F
0 g
.79179 .74559 m
.79795 .74061 L
s
.46096 .93202 m .45352 .93385 L .44688 .93696 L 0 1 .495 r
F
.5186 .98457 m .51026 .97968 L .51887 .98648 L 0 .311 .272 r
F
0 g
.51026 .97967 m
.51026 .97968 L
s
.44652 .91206 m .44911 .92024 L .45051 .91823 L 0 .899 .459 r
F
0 g
.44911 .92024 m
.4529 .92536 L
s
.44274 .91712 m
.44911 .92024 L
s
.45478 .81974 m .44291 .82025 L .44488 .82453 L 0 1 .487 r
F
0 g
.4395 .82453 m
.44488 .82453 L
s
.43213 .76989 m .42915 .7748 L .43225 .77188 L 0 1 .438 r
F
.43213 .76989 m .42412 .77701 L .42915 .7748 L F
0 g
.42915 .7748 m
.42979 .77681 L
s
.30078 .8215 m
.3008 .8215 L
s
.30415 .81646 m .30082 .8215 L .30467 .81996 L 0 1 .529 r
F
0 g
.3008 .8215 m
.30082 .8215 L
s
.30467 .81996 m
.30475 .82002 L
s
.30467 .81996 m
.30504 .82012 L
s
.30467 .81996 m
.30474 .81997 L
s
.30082 .8215 m
.30086 .82176 L
s
.50375 .8424 m .50724 .85044 L .50743 .84669 L 0 1 .477 r
F
0 g
.50724 .85044 m
.51128 .85474 L
s
.50294 .85163 m
.50724 .85044 L
s
.79942 .72438 m .8023 .74264 L .80768 .73775 L 0 1 .495 r
F
0 g
.8023 .74264 m
.80252 .75074 L
s
.49633 1.01292 m .47923 1.01659 L .48594 1.01923 L 0 1 .536 r
F
0 g
.47829 1.02043 m
.48594 1.01923 L
s
.46376 .92747 m .46096 .93236 L .46724 .93547 L 0 .814 .455 r
F
0 g
.46096 .93236 m
.46575 .93828 L
s
.32842 1.00314 m .30999 .99557 L .30703 .9971 L 0 1 .538 r
F
0 g
.30259 .9994 m
.30497 1.00009 L
s
.32842 1.00314 m .31917 .99816 L .30999 .99557 L 0 1 .538 r
F
0 g
.30497 1.00009 m
.31203 1.00211 L
s
.33524 .99903 m .31917 .99816 L .32842 1.00314 L 0 1 .538 r
F
0 g
.32842 1.00314 m
.33731 1.0056 L
s
.32842 1.00314 m
.33338 1.00813 L
s
.35787 .83834 m .34312 .82826 L .34458 .83517 L 0 1 .462 r
F
0 g
.34458 .83516 m
.34458 .83517 L
s
.33726 .83112 m
.34458 .83517 L
s
.77248 .79603 m .78365 .79878 L .77941 .79553 L 0 .872 .475 r
F
.77248 .79603 m .78292 .80427 L .78365 .79878 L F
.44803 .76088 m .43692 .76741 L .43728 .76933 L 0 1 .429 r
F
0 g
.43225 .77188 m
.43728 .76933 L
s
.74004 .5557 m .75058 .5524 L .75298 .5614 L 0 .391 .063 r
F
0 g
.75058 .5524 m
.75448 .5547 L
s
.60381 .40617 m
.60487 .40987 L
s
.47855 .8319 m .47365 .8296 L .46886 .83029 L 0 1 .483 r
F
0 g
.46886 .83029 m
.47365 .8296 L
s
.47855 .8319 m
.48143 .83616 L
s
.81052 .72918 m .80881 .7456 L .81315 .74752 L 0 1 .5 r
F
.81052 .72918 m .80768 .73775 L .80881 .7456 L F
0 g
.80252 .75074 m
.80881 .7456 L
s
.51925 1.01235 m .51954 1.02217 L .52657 1.01948 L 0 1 .519 r
F
0 g
.51954 1.02217 m
.52695 1.02556 L
s
.46903 .74086 m .45944 .74929 L .45969 .75107 L 0 1 .363 r
F
0 g
.45529 .75445 m
.45969 .75107 L
s
.54983 .50859 m .55131 .52556 L .54926 .52168 L 0 .15 .122 r
F
.54983 .50859 m .55526 .51872 L .55131 .52556 L F
.54983 .50859 m .55846 .50577 L .55526 .51872 L F
.5204 .64134 m .52495 .60166 L .5222 .62344 L 0 .751 .271 r
F
.51944 .63683 m .5222 .62344 L .52495 .60166 L 0 .762 .271 r
F
0 g
.52495 .60166 m
.52626 .58466 L
s
.52495 .60166 m
.5252 .60041 L
s
.51464 .66991 m .5161 .66544 L .51626 .66555 L 0 0 0 r
F
.51464 .66991 m .51518 .66736 L .5161 .66544 L F
0 g
.51468 .66938 m
.51518 .66737 L
s
.5161 .66544 m
.51614 .6654 L
s
.49209 .42547 m
.49536 .41961 L
s
.48825 .59109 m .4831 .57807 L .48037 .57489 L 0 1 .3 r
F
.48825 .59109 m .48635 .58409 L .4831 .57807 L F
.69471 .95091 m .68679 .95524 L .68295 .95903 L 0 1 .508 r
F
0 g
.68295 .95903 m
.68535 .95666 L
s
.67629 .96055 m
.68295 .95903 L
s
.81052 .72918 m .81315 .74752 L .81863 .74243 L 0 1 .5 r
F
0 g
.81315 .74752 m
.81324 .75565 L
s
.50372 .68966 m .49863 .69923 L .4988 .70018 L 0 .989 .159 r
F
0 g
.49629 .7047 m
.4988 .70018 L
s
.31437 .81607 m
.31459 .8161 L
s
.50375 .8424 m .49864 .84043 L .49433 .84163 L 0 1 .477 r
F
0 g
.49433 .84163 m
.49864 .84043 L
s
.49103 .83736 m
.49433 .84163 L
s
.28467 .82181 m .26898 .81313 L .26979 .81895 L 0 1 .524 r
F
.28467 .82181 m .27304 .81185 L .26898 .81313 L F
.28467 .82181 m .27977 .81557 L .27304 .81185 L F
.29444 .81816 m .27977 .81557 L .28467 .82181 L 0 1 .523 r
F
0 g
.28467 .82181 m
.28675 .82293 L
s
.28467 .82181 m
.28492 .8236 L
s
.42998 .89643 m .42359 .89008 L .41719 .88686 L 0 .964 .458 r
F
.47384 .55882 m .46679 .56003 L .47007 .56225 L 0 1 .305 r
F
.47384 .55882 m .46591 .55278 L .46679 .56003 L F
.47384 .55882 m .46803 .54536 L .46591 .55278 L F
.49616 .70332 m .48966 .71352 L .48978 .71489 L 0 1 .19 r
F
0 g
.48668 .71934 m
.48978 .71489 L
s
.76612 .56758 m .77832 .57754 L .77773 .57868 L 0 .189 0 r
F
0 g
.77832 .57754 m
.78225 .57997 L
s
.77526 .57296 m
.77832 .57754 L
s
.39838 1.00544 m .40176 1.01139 L .40364 1.00942 L 0 1 .539 r
F
0 g
.39631 1.01242 m
.39894 1.01436 L
s
.39838 1.00544 m .39338 1.01028 L .40176 1.01139 L 0 1 .539 r
F
.42139 1.01281 m .40364 1.00942 L .40176 1.01139 L 0 1 .54 r
F
0 g
.40176 1.01139 m
.40766 1.01508 L
s
.38218 .812 m .37992 .81855 L .38304 .81654 L 0 1 .509 r
F
.38218 .812 m .37416 .81688 L .37992 .81855 L F
0 g
.37992 .81855 m
.38141 .82306 L
s
.49892 .96342 m .49004 .96093 L .49817 .96714 L 0 .531 .409 r
F
.49892 .96342 m .4844 .95505 L .49004 .96093 L F
0 g
.48352 .95739 m
.49004 .96093 L
s
.47996 .57667 m .48037 .57489 L .47823 .57066 L 0 1 .305 r
F
.48825 .59109 m .48037 .57489 L .47996 .57667 L 0 1 .3 r
F
0 g
.48037 .57489 m
.4831 .57807 L
s
.48635 .58409 m
.48957 .58516 L
s
.48635 .58409 m
.48635 .58409 L
s
.50713 .68441 m .50575 .68656 L .50388 .69063 L 0 1 .167 r
F
.50913 .67906 m .50713 .68441 L .50866 .6813 L 0 .843 .114 r
F
.50913 .67906 m .50575 .68656 L .50713 .68441 L F
0 g
.50713 .68441 m
.50766 .68504 L
s
.25289 .80407 m .24897 .81343 L .25302 .81213 L 0 1 .486 r
F
0 g
.25302 .81213 m
.2541 .81304 L
s
.25289 .80407 m .24264 .80719 L .24897 .81343 L 0 1 .486 r
F
0 g
.24897 .81343 m
.24975 .81915 L
s
.506 .89832 m
.50923 .89508 L
s
.47168 1.01739 m .46223 1.01589 L .45435 1.01649 L 0 1 .539 r
F
.50131 .89953 m .48897 .90994 L .49368 .90871 L 0 1 .431 r
F
0 g
.48808 .91337 m
.49368 .90871 L
s
.39338 1.01028 m .37537 1.00558 L .3731 1.00741 L 0 1 .539 r
F
.39338 1.01028 m .38407 1.00681 L .37537 1.00558 L F
.39838 1.00544 m .38407 1.00681 L .39338 1.01028 L F
0 g
.39338 1.01028 m
.40176 1.01139 L
s
.39338 1.01028 m
.39631 1.01242 L
s
.49536 .41961 m .49007 .43347 L .49087 .4302 L 0 0 .04 r
F
.49536 .41961 m .49371 .4286 L .49007 .43347 L F
0 g
.49012 .42982 m
.49209 .42547 L
s
.48764 .43528 m
.49012 .42982 L
s
.49536 .41961 m .49936 .41883 L .49371 .4286 L 0 0 .04 r
F
.49536 .41961 m .50383 .40826 L .49936 .41883 L F
.47975 .9476 m .4844 .95505 L .48499 .95341 L 0 .73 .45 r
F
.49892 .96342 m .48499 .95341 L .4844 .95505 L 0 .531 .409 r
F
0 g
.4844 .95505 m
.49004 .96093 L
s
.47797 .95182 m
.4844 .95505 L
s
.47996 .57667 m .47823 .57066 L .47497 .56682 L 0 1 .305 r
F
0 g
.47823 .57066 m
.48037 .57489 L
s
.47529 .73155 m .47285 .73705 L .47524 .73328 L 0 1 .292 r
F
.47529 .73155 m .46903 .74086 L .47285 .73705 L F
0 g
.47285 .73705 m
.47322 .73872 L
s
.44652 .91206 m .43981 .90585 L .43344 .90274 L 0 .899 .459 r
F
.52648 .49674 m .52513 .48195 L .52452 .49672 L 0 1 .182 r
F
.51832 .53018 m .52513 .48195 L .52279 .48212 L 0 1 .213 r
F
.51832 .53018 m .52452 .49672 L .52513 .48195 L F
0 g
.52513 .48195 m
.52652 .47133 L
s
.48825 .59109 m .48856 .58968 L .48635 .58409 L 0 1 .3 r
F
.44803 .76088 m .44003 .76437 L .43692 .76741 L 0 1 .429 r
F
.44803 .76088 m .4448 .76157 L .44003 .76437 L F
.45521 .7526 m .4448 .76157 L .44803 .76088 L 0 1 .387 r
F
0 g
.44803 .76088 m
.45252 .75783 L
s
.44803 .76088 m
.44839 .76281 L
s
.36392 .9322 m .3454 .93769 L .34912 .93831 L 0 1 .348 r
F
.36392 .9322 m .3484 .93586 L .3454 .93769 L F
.36392 .9322 m .35635 .9335 L .3484 .93586 L F
.37081 .92713 m .35635 .9335 L .36392 .9322 L 0 1 .306 r
F
0 g
.36392 .9322 m
.37156 .92965 L
s
.36392 .9322 m
.36759 .93283 L
s
.24289 .8275 m
.24971 .82982 L
s
.76577 .92577 m .75832 .93303 L .7553 .93896 L 0 1 .528 r
F
0 g
.74643 .9432 m
.7553 .93896 L
s
.59056 .3838 m .60281 .38332 L .60525 .39311 L 0 .457 .118 r
F
0 g
.59885 .39353 m
.5995 .39111 L
s
.60281 .38332 m
.60519 .3764 L
s
.59652 .37934 m
.60281 .38332 L
s
.78292 .80427 m .79424 .8065 L .79001 .80349 L 0 .917 .483 r
F
.78292 .80427 m .79334 .81193 L .79424 .8065 L F
0 g
.54494 1.03887 m
.54583 1.03943 L
s
.54583 1.03943 m
.55054 1.04238 L
s
.54494 1.03887 m
.54569 1.03886 L
s
.54569 1.03886 m
.54996 1.0388 L
s
.78933 .58831 m .79388 .5905 L .79853 .59435 L 0 0 0 r
F
0 g
.79003 .58912 m
.79119 .58953 L
s
.78933 .58831 m .78994 .58791 L .79388 .5905 L 0 0 0 r
F
0 g
.5349 .53643 m
.53512 .54149 L
s
.53418 .51935 m
.5349 .53643 L
s
.25936 .82202 m
.25962 .82217 L
s
.47358 1.01116 m .47168 1.01739 L .47923 1.01659 L 0 1 .54 r
F
.47358 1.01116 m .46223 1.01589 L .47168 1.01739 L F
0 g
.47168 1.01739 m
.47829 1.02043 L
s
.4265 .81265 m .42508 .81965 L .42772 .817 L 0 1 .496 r
F
.4265 .81265 m .41966 .81915 L .42508 .81965 L F
.43775 .82021 m .42772 .817 L .42508 .81965 L 0 1 .495 r
F
0 g
.42508 .81965 m
.42684 .82397 L
s
.26428 .8098 m
.26908 .81384 L
s
.33726 .81882 m .32548 .81146 L .32074 .81342 L 0 1 .518 r
F
0 g
.33726 .81882 m
.33746 .82425 L
s
.40111 .81632 m .38774 .81349 L .389 .81792 L 0 1 .505 r
F
0 g
.38304 .81654 m
.389 .81792 L
s
.38908 .95493 m .39084 .95913 L .39312 .95702 L 0 1 .516 r
F
.38908 .95493 m .38309 .96003 L .39084 .95913 L F
0 g
.39084 .95913 m
.39554 .96099 L
s
.55541 .37531 m .56739 .37414 L .56897 .38514 L 0 .384 .133 r
F
0 g
.56739 .37414 m
.57066 .36358 L
s
.56159 .36995 m
.56739 .37414 L
s
.51615 .6667 m .51881 .65997 L .51749 .66339 L 0 0 0 r
F
0 g
.51687 .66424 m
.51687 .66424 L
s
.51687 .66424 m
.51726 .66306 L
s
.51727 .66431 m .51749 .66339 L .51881 .65997 L 0 0 0 r
F
0 g
.51881 .65997 m
.51911 .65892 L
s
.51881 .65997 m
.51896 .65958 L
s
.51689 .6642 m
.51794 .66159 L
s
.41965 .81915 m .40945 .81507 L .40661 .81736 L 0 1 .5 r
F
.41965 .81915 m .41505 .81583 L .40945 .81507 L F
0 g
.41965 .81915 m
.42122 .82347 L
s
.4265 .81265 m .41505 .81583 L .41966 .81915 L 0 1 .496 r
F
0 g
.41966 .81915 m
.42508 .81965 L
s
.36332 .80101 m .36041 .80538 L .3638 .80355 L 0 1 .505 r
F
0 g
.3638 .80355 m
.36981 .80316 L
s
.36332 .80101 m .35466 .80542 L .36041 .80538 L 0 1 .505 r
F
0 g
.36041 .80538 m
.36155 .80793 L
s
.47996 .57667 m .47377 .57173 L .47714 .57532 L 0 1 .305 r
F
.47996 .57667 m .47163 .56751 L .47377 .57173 L F
.47996 .57667 m .47214 .56546 L .47163 .56751 L F
.47996 .57667 m .47497 .56682 L .47214 .56546 L F
0 g
.47496 .56677 m
.47497 .56681 L
s
.47384 .55882 m
.47496 .56677 L
s
.48825 .59109 m .47996 .57667 L .48217 .58225 L 0 1 .3 r
F
0 g
.47714 .57532 m
.47996 .57667 L
s
.30465 .81986 m
.30467 .81996 L
s
.30466 .81987 m
.30467 .81996 L
s
.30439 .81456 m
.30448 .81634 L
s
.30449 .81652 m
.30466 .81987 L
s
.30466 .81983 m
.30467 .81996 L
s
.30439 .8165 m
.30464 .81966 L
s
.30464 .81966 m
.30466 .81983 L
s
.52465 .55362 m .52648 .49674 L .52362 .52368 L 0 1 .238 r
F
0 g
.52576 .50346 m
.52648 .49674 L
s
.52552 .50576 m
.52576 .50346 L
s
.52476 .49672 m
.52648 .49674 L
s
.36586 .83389 m .36399 .84253 L .3671 .84072 L 0 1 .456 r
F
.36586 .83389 m .35787 .83834 L .36399 .84253 L F
.37882 .85171 m .3671 .84072 L .36399 .84253 L 0 1 .459 r
F
0 g
.36399 .84253 m
.3659 .84926 L
s
.50616 .63647 m .49996 .59787 L .4992 .60081 L 0 .862 .291 r
F
.50616 .63647 m .50241 .60721 L .49996 .59787 L F
0 g
.49968 .59548 m
.49996 .59787 L
s
.50114 .5936 m
.50186 .60128 L
s
.62752 .47865 m
.62758 .481 L
s
.62772 .48573 m
.62779 .48811 L
s
.62742 .4752 m
.62752 .47865 L
s
.62737 .47364 m
.62742 .4752 L
s
.33213 .80887 m .33542 .80733 L .3318 .80885 L 0 1 .519 r
F
.34602 .80974 m .33556 .80736 L .33213 .80887 L F
.33556 .80736 m .33542 .80733 L .33213 .80887 L F
.34602 .80974 m .3415 .80771 L .33538 .80732 L F
.35466 .80542 m .3415 .80771 L .34602 .80974 L 0 1 .513 r
F
.35466 .80542 m .34081 .80501 L .3415 .80771 L F
.35453 .81044 m .34087 .80504 L .34144 .80982 L 0 1 .515 r
F
.34087 .80504 m .34082 .80506 L .34144 .80982 L F
.35453 .81044 m .35176 .81699 L .35515 .81524 L F
.35453 .81044 m .34589 .81467 L .35176 .81699 L F
.3318 .80885 m .33538 .80732 L .33176 .80885 L 0 1 .519 r
F
.33542 .80733 m .33538 .80732 L .3318 .80885 L F
.33248 .80914 m .33538 .80732 L .33176 .80885 L 0 1 .517 r
F
.34589 .81467 m .33572 .80757 L .33248 .80914 L F
.33572 .80757 m .33538 .80732 L .33248 .80914 L F
.34589 .81467 m .34144 .80982 L .33583 .80751 L F
.33572 .80757 m .33583 .80751 L .33538 .80732 L F
.34589 .81467 m .33583 .80751 L .33572 .80757 L F
.34087 .80504 m .34081 .80501 L .34082 .80506 L 0 1 .515 r
F
.34084 .80504 m .34081 .80505 L .34082 .80509 L 0 1 .455 r
F
.34084 .80507 m .34082 .80509 L .34138 .81194 L F
.34084 .80504 m .34082 .80509 L .34084 .80507 L F
.35453 .81044 m .34144 .80982 L .34589 .81467 L 0 1 .515 r
F
.35441 .81547 m .34087 .80506 L .34138 .81194 L 0 1 .455 r
F
.34087 .80506 m .34084 .80504 L .34084 .80507 L F
.34087 .80506 m .34084 .80507 L .34138 .81194 L F
.34084 .80504 m .34081 .80501 L .34081 .80505 L F
.49741 .60834 m .49811 .60529 L .49646 .59523 L 0 1 .295 r
F
0 g
.49748 .5973 m
.49815 .59867 L
s
.49716 .59665 m
.49748 .5973 L
s
.44253 .93608 m .44548 .93926 L .44688 .93696 L 0 1 .493 r
F
.44253 .93608 m .43874 .94169 L .44548 .93926 L F
0 g
.44548 .93926 m
.45032 .93977 L
s
.7469 .95618 m .75526 .9602 L .75933 .95601 L 0 1 .539 r
F
.37048 1.00121 m .3731 1.00741 L .37537 1.00558 L F
.37048 1.00121 m .36454 1.00568 L .3731 1.00741 L F
0 g
.3731 1.00741 m
.3787 1.0115 L
s
.42139 1.01281 m .41206 1.01003 L .40364 1.00942 L 0 1 .54 r
F
.42539 1.00761 m .42139 1.01281 L .42948 1.01331 L F
.42539 1.00761 m .41206 1.01003 L .42139 1.01281 L F
0 g
.42139 1.01281 m
.42727 1.0165 L
s
.49633 1.01292 m .50285 1.01862 L .50304 1.01557 L 0 1 .536 r
F
.51925 1.01235 m .50304 1.01557 L .50285 1.01862 L 0 1 .519 r
F
0 g
.50285 1.01862 m
.50992 1.02145 L
s
.49552 1.02019 m
.50285 1.01862 L
s
.39047 .79415 m .37738 .79602 L .3781 .79829 L 0 1 .496 r
F
.39047 .79415 m .38078 .79409 L .37738 .79602 L F
.39047 .79415 m .3864 .79328 L .38078 .79409 L F
.39852 .78877 m .3864 .79328 L .39047 .79415 L 0 1 .484 r
F
0 g
.39047 .79415 m
.39587 .79313 L
s
.39047 .79415 m
.39117 .79641 L
s
.51464 .66991 m .51429 .66964 L .51518 .66736 L 0 0 0 r
F
0 g
.51515 .66743 m
.51518 .66736 L
s
.51384 .67013 m
.51384 .67013 L
s
.51384 .67013 m
.51434 .66968 L
s
.68929 .52783 m .70146 .52387 L .69977 .5447 L 0 .631 .154 r
F
0 g
.69945 .50088 m
.70146 .52387 L
s
.70146 .52387 m
.70594 .5143 L
s
.4143 .88042 m .4083 .87388 L .40192 .8705 L 0 1 .457 r
F
.59459 .54799 m .60212 .50137 L .60612 .53099 L 0 .547 .201 r
F
.59459 .54799 m .59721 .50856 L .60212 .50137 L F
0 g
.60064 .44004 m
.60212 .50137 L
s
.59647 .47551 m
.59721 .50856 L
s
.59721 .50856 m
.59917 .5057 L
s
.59917 .5057 m
.59924 .50558 L
s
.59924 .50558 m
.59924 .50558 L
s
.59924 .50558 m
.59924 .50558 L
s
.59924 .50558 m
.59955 .50513 L
s
.59955 .50513 m
.60212 .50137 L
s
.29821 .99401 m .28144 .99189 L .29058 .99773 L 0 1 .538 r
F
0 g
.29058 .99773 m
.29963 1.00094 L
s
.37882 .85171 m .37346 .84465 L .3671 .84072 L 0 1 .459 r
F
.38611 .8469 m .37882 .85171 L .38495 .85554 L 0 1 .452 r
F
.38611 .8469 m .37346 .84465 L .37882 .85171 L F
0 g
.37882 .85171 m
.38072 .85843 L
s
.49653 .61231 m .48856 .58968 L .48825 .59109 L 0 1 .296 r
F
.49653 .61231 m .49121 .59521 L .48856 .58968 L F
0 g
.48635 .58409 m
.48856 .58968 L
s
.49646 .59523 m
.49716 .59665 L
s
.46829 .92642 m
.47143 .92441 L
s
.48344 .91377 m .4698 .9229 L .47445 .92249 L 0 1 .459 r
F
0 g
.47143 .92441 m
.47445 .92249 L
s
.55338 1.04378 m
.55357 1.04371 L
s
.35643 .96195 m .3577 .9665 L .36035 .9646 L 0 1 .523 r
F
.35643 .96195 m .34956 .96653 L .3577 .9665 L F
0 g
.3577 .9665 m
.36235 .96894 L
s
.73011 .94786 m .72223 .95123 L .7187 .95514 L 0 1 .538 r
F
0 g
.70984 .95614 m
.7187 .95514 L
s
.2846 .82372 m .26873 .81942 L .26962 .82333 L 0 1 .534 r
F
.2846 .82372 m .27279 .81819 L .26873 .81942 L F
.2846 .82372 m .2796 .82003 L .27279 .81819 L F
.29437 .82011 m .2796 .82003 L .2846 .82372 L 0 1 .532 r
F
0 g
.2846 .82372 m
.28544 .8275 L
s
.2846 .82372 m
.29118 .82532 L
s
.79334 .81193 m .80481 .81367 L .80059 .81087 L 0 .959 .49 r
F
.79334 .81193 m .80373 .81909 L .80481 .81367 L F
.46903 .74086 m .46221 .74579 L .45944 .74929 L 0 1 .363 r
F
.46903 .74086 m .46632 .74218 L .46221 .74579 L F
.47529 .73155 m .46632 .74218 L .46903 .74086 L 0 1 .292 r
F
0 g
.46903 .74086 m
.46927 .74265 L
s
.46903 .74086 m
.47285 .73705 L
s
.48165 .8227 m .47855 .8319 L .48306 .83083 L 0 1 .477 r
F
.48165 .8227 m .47365 .8296 L .47855 .8319 L F
0 g
.31472 .81624 m
.31486 .8163 L
s
.35787 .83834 m .3465 .8266 L .34312 .82826 L 0 1 .462 r
F
.35787 .83834 m .35283 .83092 L .3465 .8266 L F
.36586 .83389 m .35283 .83092 L .35787 .83834 L 0 1 .456 r
F
0 g
.35787 .83834 m
.36399 .84253 L
s
.35787 .83834 m
.35932 .84523 L
s
.49301 .8277 m .486 .83522 L .49103 .83736 L 0 1 .474 r
F
.49301 .8277 m .48306 .83083 L .486 .83522 L F
.76577 .92577 m .76702 .9345 L .77475 .92699 L 0 1 .528 r
F
0 g
.7587 .93961 m
.76702 .9345 L
s
.42412 .77701 m .41204 .7814 L .41252 .78341 L 0 1 .465 r
F
.42412 .77701 m .41533 .77892 L .41204 .7814 L F
.42412 .77701 m .42051 .77704 L .41533 .77892 L F
0 g
.42412 .77701 m
.42459 .77902 L
s
.43213 .76989 m .42051 .77704 L .42412 .77701 L 0 1 .438 r
F
0 g
.42412 .77701 m
.42915 .7748 L
s
.53409 .42193 m .5314 .4353 L .53077 .4348 L 0 0 .071 r
F
0 g
.53409 .42193 m
.53409 .42193 L
s
.53409 .42193 m .536 .42472 L .5314 .4353 L 0 0 .071 r
F
0 g
.52919 .43672 m
.53213 .42392 L
s
.52983 .43541 m
.53409 .42193 L
s
.53409 .42193 m .54148 .41019 L .536 .42472 L 0 0 .071 r
F
0 g
.53408 .42197 m
.53409 .42193 L
s
.67572 .94706 m
.67793 .94482 L
s
.46643 .82603 m .4617 .82356 L .45674 .82402 L 0 1 .486 r
F
0 g
.45674 .82402 m
.4617 .82356 L
s
.46643 .82603 m
.46886 .83029 L
s
.48165 .8227 m .47113 .82521 L .47365 .8296 L 0 1 .477 r
F
.2423 .815 m .23861 .8226 L .24265 .82135 L 0 1 .526 r
F
0 g
.24265 .82135 m
.24865 .82488 L
s
.2423 .815 m .23205 .81794 L .23861 .8226 L 0 1 .526 r
F
0 g
.23861 .8226 m
.23979 .8281 L
s
.23281 .81847 m
.23281 .81861 L
s
.40844 .81071 m .40661 .81736 L .40945 .81507 L 0 1 .501 r
F
.40844 .81071 m .40111 .81632 L .40661 .81736 L F
0 g
.40661 .81736 m
.40819 .82168 L
s
.51832 .8839 m
.51854 .88381 L
s
.52426 .87969 m
.52484 .87903 L
s
.38611 .8469 m .38495 .85554 L .38778 .85358 L 0 1 .452 r
F
.39963 .86392 m .38778 .85358 L .38495 .85554 L 0 1 .455 r
F
0 g
.38495 .85554 m
.38725 .86211 L
s
.37882 .85171 m
.38495 .85554 L
s
.37416 .81688 m .36023 .81259 L .36132 .81724 L 0 1 .512 r
F
.43775 .82021 m .43315 .81724 L .42772 .817 L 0 1 .495 r
F
.44372 .81302 m .43775 .82021 L .44291 .82025 L 0 1 .489 r
F
.44372 .81302 m .43315 .81724 L .43775 .82021 L F
0 g
.43775 .82021 m
.4395 .82453 L
s
.42539 1.00761 m .42948 1.01331 L .43096 1.01118 L 0 1 .54 r
F
.44823 1.01321 m .43096 1.01118 L .42948 1.01331 L F
0 g
.42948 1.01331 m
.43562 1.01659 L
s
.42139 1.01281 m
.42948 1.01331 L
s
.48662 .71774 m .47883 .72757 L .47889 .72917 L 0 1 .243 r
F
0 g
.47524 .73328 m
.47889 .72917 L
s
.54247 .6047 m
.54265 .60346 L
s
.54265 .60346 m
.54319 .59985 L
s
.54319 .59985 m
.54358 .59724 L
s
.54358 .59724 m
.54403 .59416 L
s
.54128 .60311 m
.54144 .60258 L
s
.54144 .60258 m
.54232 .59973 L
s
.54232 .59973 m
.5437 .59523 L
s
.5437 .59523 m
.54403 .59416 L
s
.38309 .96003 m .36432 .96176 L .36868 .96403 L 0 1 .522 r
F
0 g
.36035 .9646 m
.36868 .96403 L
s
.49301 .8277 m .49103 .83736 L .4953 .83602 L 0 1 .474 r
F
.37416 .81688 m .36362 .8108 L .36023 .81259 L 0 1 .512 r
F
0 g
.35515 .81524 m
.36132 .81724 L
s
.37416 .81688 m .36959 .81264 L .36362 .8108 L 0 1 .512 r
F
.38218 .812 m .36959 .81264 L .37416 .81688 L 0 1 .509 r
F
0 g
.37416 .81688 m
.37992 .81855 L
s
.37416 .81688 m
.37523 .82153 L
s
.46447 .92616 m
.46829 .92642 L
s
.48825 .59109 m .48217 .58225 L .48551 .58791 L 0 1 .3 r
F
0 g
.47996 .57667 m
.48217 .58225 L
s
.48645 .60005 m .48217 .58225 L .47875 .58221 L 0 1 .303 r
F
.48645 .60005 m .48551 .58791 L .48217 .58225 L F
0 g
.48188 .58225 m
.48217 .58225 L
s
.536 .42472 m .5464 .40196 L .5475 .40548 L 0 0 .08 r
F
.536 .42472 m .54148 .41019 L .5464 .40196 L F
0 g
.5464 .40196 m
.54953 .38706 L
s
.54148 .41019 m
.54475 .39743 L
s
.54148 .41019 m
.5464 .40196 L
s
.2324 .81028 m .21693 .79493 L .21737 .8033 L 0 1 .492 r
F
.2324 .81028 m .22116 .79384 L .21693 .79493 L F
.2324 .81028 m .22779 .80043 L .22116 .79384 L F
.24264 .80719 m .22779 .80043 L .2324 .81028 L 0 1 .489 r
F
0 g
.2324 .81028 m
.23832 .81614 L
s
.2324 .81028 m
.23277 .81773 L
s
.50913 .67906 m .50866 .6813 L .50932 .67931 L 0 .843 .114 r
F
.51145 .67473 m .50932 .67931 L .50866 .6813 L 0 .872 .124 r
F
0 g
.50866 .6813 m
.50921 .68105 L
s
.50713 .68441 m
.50866 .6813 L
s
.67797 1.07974 m .67243 1.08271 L .68372 1.08182 L 0 1 .379 r
F
0 g
.66643 1.08266 m
.67243 1.08271 L
s
.51925 1.01235 m .52657 1.01948 L .52632 1.01518 L 0 1 .519 r
F
0 g
.51954 1.02217 m
.52657 1.01948 L
s
.52657 1.01948 m
.53394 1.02545 L
s
.49653 .61231 m .48825 .59109 L .49053 .59841 L 0 1 .296 r
F
0 g
.48551 .58791 m
.48825 .59109 L
s
.48856 .58968 m
.49006 .59281 L
s
.47358 1.01116 m .45594 1.01303 L .46223 1.01589 L 0 1 .54 r
F
0 g
.45435 1.01649 m
.46223 1.01589 L
s
.50816 .63071 m .50414 .60151 L .50625 .61858 L 0 .838 .287 r
F
.50713 .63339 m .50625 .61858 L .50414 .60151 L 0 .851 .289 r
F
0 g
.50195 .59082 m
.50414 .60151 L
s
.50364 .59366 m
.50414 .60151 L
s
.29451 .81622 m .27937 .8035 L .27994 .81112 L 0 1 .478 r
F
.29451 .81622 m .28343 .80215 L .27937 .8035 L F
.29451 .81622 m .28992 .80761 L .28343 .80215 L F
.30429 .81249 m .28992 .80761 L .29451 .81622 L 0 1 .474 r
F
0 g
.29451 .81622 m
.29464 .81809 L
s
.29451 .81622 m
.29609 .81754 L
s
.50375 .8424 m
.50743 .84669 L
s
.50743 .84669 m
.51143 .84519 L
s
.51378 .67018 m .51285 .67202 L .512 .67448 L 0 .892 .132 r
F
0 g
.34589 .81467 m
.35176 .81699 L
s
.35176 .81699 m
.35306 .82174 L
s
.34589 .81467 m
.34669 .81959 L
s
.75201 .77159 m
.75336 .77185 L
s
.50913 .67906 m .50556 .68632 L .50575 .68656 L 0 .843 .114 r
F
0 g
.50388 .69063 m
.50575 .68656 L
s
.44372 .81302 m .44291 .82025 L .44518 .81732 L 0 1 .489 r
F
.45478 .81974 m .44518 .81732 L .44291 .82025 L 0 1 .487 r
F
0 g
.44291 .82025 m
.44488 .82453 L
s
.43775 .82021 m
.44291 .82025 L
s
.36454 1.00568 m .3465 .99969 L .34387 1.00138 L 0 1 .539 r
F
.36454 1.00568 m .35537 1.00154 L .3465 .99969 L F
.37048 1.00121 m .35537 1.00154 L .36454 1.00568 L F
0 g
.36454 1.00568 m
.36971 1.01016 L
s
.36454 1.00568 m
.3731 1.00741 L
s
.48645 .60005 m .48735 .59554 L .48551 .58791 L 0 1 .303 r
F
.43874 .94169 m .4241 .94494 L .42232 .94708 L 0 1 .506 r
F
.43874 .94169 m .43115 .94263 L .4241 .94494 L F
.44253 .93608 m .43115 .94263 L .43874 .94169 L 0 1 .493 r
F
0 g
.43874 .94169 m
.44338 .94276 L
s
.43874 .94169 m
.44548 .93926 L
s
.39312 .95702 m
.40095 .95555 L
s
.41526 .94878 m .39695 .95351 L .40095 .95555 L 0 1 .511 r
F
.47061 .81728 m .46643 .82602 L .47113 .82521 L 0 1 .479 r
F
.47061 .81728 m .4617 .82356 L .46643 .82602 L F
.55541 .37531 m .55269 .39417 L .55159 .38569 L 0 .384 .133 r
F
.55264 .39817 m .56529 .38597 L .56183 .39859 L 0 .168 .107 r
F
.55541 .37531 m .55853 .39843 L .55269 .39417 L 0 .384 .133 r
F
.55541 .37531 m .56518 .39557 L .55853 .39843 L F
.55541 .37531 m .56897 .38514 L .56518 .39557 L F
0 g
.54993 .37226 m
.55541 .37531 L
s
.43473 .8911 m .42359 .89008 L .42998 .89643 L 0 .932 .45 r
F
.43473 .8911 m .42042 .88373 L .42359 .89008 L F
0 g
.41719 .88686 m
.42359 .89008 L
s
.46427 .53005 m .46695 .52182 L .46703 .51522 L 0 1 .292 r
F
0 g
.46695 .52182 m
.47088 .51704 L
s
.52268 .65313 m .52242 .6536 L .52491 .64588 L 0 0 .01 r
F
.40111 .81632 m .39087 .81143 L .38774 .81349 L 0 1 .505 r
F
.40111 .81632 m .39661 .81264 L .39087 .81143 L F
.40844 .81071 m .39661 .81264 L .40111 .81632 L 0 1 .501 r
F
0 g
.40111 .81632 m
.40235 .82075 L
s
.40111 .81632 m
.40661 .81736 L
s
.41996 .87514 m .4143 .88042 L .42042 .88373 L 0 .988 .449 r
F
.41996 .87514 m .4083 .87388 L .4143 .88042 L F
0 g
.4143 .88042 m
.41719 .88686 L
s
.58286 .38695 m
.58457 .38069 L
s
.58135 .39249 m
.58286 .38695 L
s
.52264 .39367 m .5287 .38472 L .5337 .38333 L 0 .161 .102 r
F
.47755 .58781 m .47713 .57532 L .47377 .57174 L 0 1 .308 r
F
.47755 .58781 m .47875 .58221 L .47713 .57532 L F
.47358 1.01116 m .47923 1.01659 L .47986 1.01402 L 0 1 .54 r
F
.49633 1.01292 m .47986 1.01402 L .47923 1.01659 L 0 1 .536 r
F
0 g
.47923 1.01659 m
.48594 1.01923 L
s
.47168 1.01739 m
.47923 1.01659 L
s
.40694 .78297 m .40382 .78745 L .4071 .78505 L 0 1 .466 r
F
0 g
.4071 .78505 m
.41252 .78341 L
s
.40694 .78297 m .39852 .78877 L .40382 .78745 L 0 1 .466 r
F
0 g
.40382 .78745 m
.40455 .78956 L
s
.52327 .65217 m .52305 .65251 L .52577 .64381 L 0 0 .021 r
F
0 g
.52484 .64608 m
.52491 .64588 L
s
.52477 .64631 m
.52484 .64609 L
s
.52484 .64609 m
.52491 .64588 L
s
.68691 .9409 m .68662 .94894 L .69458 .94617 L 0 1 .534 r
F
0 g
.68381 .95165 m
.68662 .94894 L
s
.67958 .94927 m
.68662 .94894 L
s
.5227 .87933 m
.52284 .87925 L
s
.50616 .63647 m .4992 .60081 L .5008 .61331 L 0 .862 .291 r
F
0 g
.49815 .59867 m
.4992 .60081 L
s
.43473 .8911 m .42998 .89643 L .43611 .89959 L 0 .932 .45 r
F
0 g
.42998 .89643 m
.43344 .90274 L
s
.50459 .83224 m .49864 .84043 L .50375 .84239 L 0 1 .47 r
F
.50459 .83224 m .4953 .83602 L .49864 .84043 L F
.48153 .94296 m .47217 .94149 L .47975 .9476 L 0 .693 .441 r
F
.48153 .94296 m .46724 .93547 L .47217 .94149 L F
0 g
.46575 .93828 m
.47217 .94149 L
s
.45051 .91823 m
.45678 .92133 L
s
.52115 .85551 m
.52117 .85553 L
s
.52199 .65441 m .52168 .655 L .52392 .64831 L 0 0 0 r
F
0 g
.52326 .65184 m
.52332 .65165 L
s
.52322 .65196 m
.52326 .65184 L
s
.52321 .65199 m
.52322 .65196 L
s
.52319 .65206 m
.52321 .65199 L
s
.52319 .65207 m
.52319 .65206 L
s
.52317 .65213 m
.52319 .65207 L
s
.52311 .65233 m
.52317 .65213 L
s
.46591 .55278 m .46803 .54536 L .4674 .53872 L 0 1 .309 r
F
0 g
.46803 .54536 m
.4718 .54193 L
s
.51887 .98648 m
.51888 .98648 L
s
.52551 .99122 m
.52556 .99126 L
s
.52556 .99126 m
.52565 .99139 L
s
.49741 .60834 m .49121 .59521 L .49445 .60402 L 0 1 .295 r
F
0 g
.48957 .58516 m
.49121 .59521 L
s
.49653 .61231 m .49445 .60402 L .49121 .59521 L 0 1 .296 r
F
0 g
.49646 .59523 m
.49755 .60186 L
s
.49006 .59281 m
.49121 .59521 L
s
.2317 .82561 m .22825 .83152 L .23228 .83033 L 0 1 .539 r
F
0 g
.23228 .83033 m
.23275 .83049 L
s
.2317 .82561 m .22146 .82838 L .22825 .83152 L 0 1 .539 r
F
0 g
.22825 .83152 m
.22986 .8362 L
s
.41996 .87514 m .40567 .86742 L .4083 .87388 L 0 .988 .449 r
F
0 g
.40192 .8705 m
.4083 .87388 L
s
.30641 .97362 m .28566 .97086 L .28988 .9744 L 0 1 .533 r
F
.30641 .97362 m .28895 .96939 L .28566 .97086 L F
.30641 .97362 m .29786 .97058 L .28895 .96939 L F
.31407 .96957 m .29786 .97058 L .30641 .97362 L 0 1 .531 r
F
0 g
.30641 .97362 m
.31503 .97462 L
s
.30641 .97362 m
.31058 .97715 L
s
.53825 .53962 m .54423 .52261 L .54623 .52042 L 0 0 .045 r
F
.53825 .53962 m .54081 .53083 L .54423 .52261 L F
0 g
.54423 .52261 m
.54454 .51629 L
s
.54081 .53083 m
.54423 .52261 L
s
.31437 .81612 m
.31451 .81622 L
s
.32089 .82088 m
.32089 .82089 L
s
.46427 .53005 m .46703 .51522 L .46446 .51463 L 0 1 .292 r
F
0 g
.46703 .51522 m
.47112 .50908 L
s
.46695 .52182 m
.46703 .51522 L
s
.46591 .55278 m .4674 .53872 L .46446 .53729 L 0 1 .309 r
F
0 g
.4674 .53872 m
.47133 .53392 L
s
.4674 .53872 m
.46803 .54536 L
s
.53773 .59682 m
.53853 .58987 L
s
.53853 .58987 m
.539 .58573 L
s
.53627 .59688 m
.53739 .59232 L
s
.53739 .59232 m
.539 .58573 L
s
.52353 .65136 m
.52356 .65129 L
s
.52351 .65145 m
.52353 .65136 L
s
.52346 .6516 m
.52351 .65145 L
s
.52341 .65176 m
.52346 .6516 L
s
.52335 .65192 m
.52341 .65176 L
s
.52376 .65159 m .52358 .65178 L .5265 .64217 L 0 0 .031 r
F
0 g
.52648 .64224 m
.5265 .64217 L
s
.52382 .65097 m
.52388 .65079 L
s
.52388 .65079 m
.52393 .65063 L
s
.52393 .65063 m
.52396 .65052 L
s
.52396 .65052 m
.52398 .65046 L
s
.52648 .64224 m
.5265 .64217 L
s
.52356 .65129 m
.52364 .65103 L
s
.52351 .64995 m
.52398 .64859 L
s
.52319 .65037 m
.52392 .64831 L
s
.5234 .64986 m
.52392 .64831 L
s
.52456 .64696 m
.52477 .64631 L
s
.52454 .64695 m
.52472 .64643 L
s
.52472 .64643 m
.52484 .64608 L
s
.52552 .64457 m
.52577 .64381 L
s
.52546 .64474 m
.52552 .64457 L
s
.52558 .64442 m
.52577 .64381 L
s
.52547 .64478 m
.52558 .64442 L
s
.5139 .6252 m .51437 .62545 L .51518 .60685 L 0 .784 .276 r
F
.47061 .81728 m .45963 .81918 L .4617 .82356 L 0 1 .479 r
F
.47163 .56751 m .47214 .56546 L .47007 .56226 L 0 1 .311 r
F
0 g
.47214 .56546 m
.47497 .56682 L
s
.5186 .98457 m .5104 .97727 L .50413 .97264 L 0 .311 .272 r
F
.46499 .50748 m .46828 .49854 L .46911 .49209 L 0 1 .247 r
F
0 g
.46828 .49854 m
.47236 .49243 L
s
.34576 .81961 m .34312 .82826 L .3465 .8266 L 0 1 .46 r
F
.34576 .81961 m .33713 .82366 L .34312 .82826 L F
0 g
.34312 .82826 m
.34458 .83516 L
s
.38309 .96003 m .36697 .95986 L .36432 .96176 L 0 1 .522 r
F
.38309 .96003 m .37502 .95912 L .36697 .95986 L F
.38908 .95493 m .37502 .95912 L .38309 .96003 L 0 1 .516 r
F
0 g
.38309 .96003 m
.39084 .95913 L
s
.38309 .96003 m
.38742 .9623 L
s
.26316 .80092 m .25909 .81016 L .26314 .80884 L 0 1 .483 r
F
.26316 .80092 m .25289 .80407 L .25909 .81016 L F
0 g
.25909 .81016 m
.25977 .81602 L
s
.26314 .80884 m
.26428 .8098 L
s
.38611 .8469 m .37178 .83796 L .37346 .84465 L 0 1 .452 r
F
0 g
.3671 .84072 m
.37346 .84465 L
s
.51272 .62507 m .51319 .62504 L .51366 .60685 L 0 .791 .278 r
F
.72154 .93918 m .71391 .94993 L .72206 .94605 L 0 1 .52 r
F
.72154 .93918 m .7108 .94933 L .71391 .94993 L F
0 g
.71243 .95139 m
.71391 .94993 L
s
.71856 .95093 m
.72113 .94735 L
s
.31039 .81762 m
.31042 .81762 L
s
.31396 .81275 m .31044 .81763 L .31429 .81606 L 0 1 .525 r
F
0 g
.31042 .81762 m
.31044 .81763 L
s
.31429 .81606 m
.31437 .81612 L
s
.31429 .81606 m
.31472 .81624 L
s
.31429 .81606 m
.31437 .81607 L
s
.31044 .81763 m
.31048 .81789 L
s
.51347 .67235 m .51378 .67018 L .51429 .66964 L 0 0 0 r
F
.51347 .67235 m .51285 .67202 L .51378 .67018 L F
.51904 .49714 m .52399 .46045 L .51977 .47625 L 0 1 .139 r
F
0 g
.52346 .48207 m
.52513 .48195 L
s
.5231 .4821 m
.52346 .48207 L
s
.52399 .46045 m
.52536 .45782 L
s
.52399 .46045 m
.52465 .45767 L
s
.48165 .8227 m .48306 .83083 L .48417 .8271 L 0 1 .477 r
F
.49301 .8277 m .48417 .8271 L .48306 .83083 L 0 1 .474 r
F
0 g
.48306 .83083 m
.486 .83522 L
s
.47855 .8319 m
.48306 .83083 L
s
.4265 .81265 m .41382 .81148 L .41505 .81583 L 0 1 .496 r
F
0 g
.40945 .81507 m
.41505 .81583 L
s
.48645 .60005 m .47875 .58221 L .47755 .58781 L 0 1 .303 r
F
0 g
.47875 .58221 m
.48188 .58225 L
s
.47713 .57532 m
.47875 .58221 L
s
.51507 .62604 m .51554 .62658 L .51669 .60787 L 0 .779 .274 r
F
.46376 .92747 m .46724 .93547 L .46824 .93354 L 0 .814 .455 r
F
.48153 .94296 m .46824 .93354 L .46724 .93547 L 0 .693 .441 r
F
0 g
.46724 .93547 m
.47217 .94149 L
s
.46096 .93236 m
.46724 .93547 L
s
.5212 .65598 m .52086 .65668 L .52282 .65102 L 0 0 0 r
F
0 g
.5222 .65279 m
.52252 .65186 L
s
.52252 .65186 m
.52282 .65102 L
s
.52193 .65342 m
.52235 .65228 L
s
.52235 .65228 m
.5225 .65189 L
s
.5225 .65189 m
.52282 .65102 L
s
.52254 .65321 m
.52363 .64984 L
s
.52199 .6544 m
.522 .65436 L
s
.522 .65436 m
.52201 .65433 L
s
.52206 .65421 m
.52206 .65418 L
s
.52202 .6543 m
.52206 .65421 L
s
.52201 .65433 m
.52202 .6543 L
s
.52242 .6536 m
.52245 .65351 L
s
.52245 .65351 m
.52246 .65348 L
s
.52246 .65348 m
.52246 .65347 L
s
.52246 .65347 m
.52246 .65346 L
s
.52246 .65346 m
.52251 .65332 L
s
.52251 .65332 m
.52254 .65321 L
s
.52281 .65274 m
.52286 .65258 L
s
.52276 .65288 m
.52281 .65274 L
s
.52276 .65289 m
.52276 .65288 L
s
.52274 .65294 m
.52276 .65289 L
s
.52272 .65301 m
.52274 .65295 L
s
.52274 .65295 m
.52274 .65294 L
s
.52268 .65312 m
.52272 .65301 L
s
.52206 .65418 m
.52351 .64995 L
s
.52171 .65493 m
.52171 .65491 L
s
.5217 .65496 m
.52171 .65493 L
s
.52173 .65488 m
.52173 .65486 L
s
.52172 .65488 m
.52173 .65488 L
s
.52171 .65491 m
.52172 .65488 L
s
.52173 .65486 m
.5234 .64986 L
s
.50459 .83224 m .50375 .84239 L .50773 .84078 L 0 1 .47 r
F
0 g
.44688 .93696 m
.45352 .93385 L
s
.45032 .90675 m .43981 .90585 L .44652 .91206 L 0 .864 .449 r
F
.45032 .90675 m .43611 .89959 L .43981 .90585 L F
0 g
.43344 .90274 m
.43981 .90585 L
s
.51615 .6667 m .516 .66662 L .51687 .66424 L 0 0 0 r
F
0 g
.51687 .66424 m
.51689 .6642 L
s
.51524 .66864 m .51687 .66424 L .516 .66662 L 0 0 0 r
F
0 g
.5161 .66544 m
.5162 .66551 L
s
.5162 .66551 m
.51625 .66554 L
s
.51687 .66424 m
.51687 .66424 L
s
.44372 .81302 m .43168 .81295 L .43315 .81724 L 0 1 .489 r
F
0 g
.42772 .817 m
.43315 .81724 L
s
.49616 .70332 m .49165 .70968 L .48966 .71352 L 0 1 .19 r
F
.49616 .70332 m .49444 .70531 L .49165 .70968 L F
.50039 .69452 m .49616 .70332 L .49863 .69923 L 0 .913 .15 r
F
.50039 .69452 m .49444 .70531 L .49616 .70332 L F
0 g
.49616 .70332 m
.49629 .7047 L
s
.29444 .81816 m .27913 .80991 L .27977 .81557 L 0 1 .523 r
F
.29444 .81816 m .28319 .80861 L .27913 .80991 L F
.29444 .81816 m .28976 .81215 L .28319 .80861 L F
.30422 .81447 m .28976 .81215 L .29444 .81816 L 0 1 .522 r
F
0 g
.29444 .81816 m
.29658 .81929 L
s
.29444 .81816 m
.29464 .82001 L
s
.61993 .39865 m
.61999 .39845 L
s
.32228 .94825 m .30256 .95091 L .30632 .95232 L 0 1 .399 r
F
.32228 .94825 m .30586 .94935 L .30256 .95091 L F
.32228 .94825 m .31433 .94821 L .30586 .94935 L F
.32998 .94386 m .31433 .94821 L .32228 .94825 L 0 1 .37 r
F
0 g
.32228 .94825 m
.33046 .94689 L
s
.32228 .94825 m
.32599 .94965 L
s
.70643 .95084 m
.70647 .95084 L
s
.70633 .95085 m
.70643 .95084 L
s
.69458 .94617 m .70222 .95124 L .7061 .94752 L 0 1 .536 r
F
.49892 .96342 m .49817 .96714 L .5044 .97074 L 0 .531 .409 r
F
0 g
.49817 .96714 m
.50413 .97264 L
s
.52708 .44334 m
.52919 .43672 L
s
.52521 .44924 m
.52533 .44885 L
s
.73011 .94786 m .73032 .95567 L .73852 .95207 L 0 1 .538 r
F
0 g
.72184 .95698 m
.73032 .95567 L
s
.72655 .95972 m
.73032 .95567 L
s
.47755 .58781 m .47377 .57174 L .47012 .57385 L 0 1 .308 r
F
0 g
.47329 .57202 m
.47377 .57174 L
s
.72854 .54133 m .74141 .54801 L .74004 .5557 L 0 .492 .079 r
F
0 g
.74141 .54801 m
.74592 .54661 L
s
.73892 .53709 m
.74141 .54801 L
s
.49191 .70815 m .48966 .71352 L .49165 .70968 L 0 1 .183 r
F
.49191 .70815 m .48662 .71774 L .48966 .71352 L F
0 g
.48966 .71352 m
.48978 .71489 L
s
.47061 .81728 m .47113 .82521 L .47268 .82166 L 0 1 .479 r
F
.48165 .8227 m .47268 .82166 L .47113 .82521 L 0 1 .477 r
F
0 g
.47113 .82521 m
.47365 .8296 L
s
.46643 .82602 m
.47113 .82521 L
s
.50039 .69452 m .49863 .69923 L .50019 .69575 L 0 .913 .15 r
F
.50372 .68966 m .50019 .69575 L .49863 .69923 L 0 .989 .159 r
F
0 g
.49863 .69923 m
.4988 .70018 L
s
.49616 .70332 m
.49863 .69923 L
s
.51154 .62561 m .51201 .62532 L .51212 .60775 L 0 .801 .28 r
F
.4624 .744 m .45944 .74929 L .46221 .74579 L 0 1 .328 r
F
.4624 .744 m .45521 .7526 L .45944 .74929 L F
0 g
.45944 .74929 m
.45969 .75107 L
s
.39963 .86392 m .39407 .85718 L .38778 .85358 L 0 1 .455 r
F
.40614 .85878 m .39963 .86392 L .40567 .86742 L 0 1 .447 r
F
.40614 .85878 m .39407 .85718 L .39963 .86392 L F
0 g
.39963 .86392 m
.40192 .8705 L
s
.25304 .82448 m
.25966 .82659 L
s
.47163 .56751 m .46534 .56546 L .46872 .56751 L 0 1 .311 r
F
.47163 .56751 m .46326 .56225 L .46534 .56546 L F
.47163 .56751 m .46387 .56003 L .46326 .56225 L F
.47163 .56751 m .46679 .56003 L .46387 .56003 L F
.47163 .56751 m .47007 .56226 L .46679 .56003 L F
0 g
.47007 .56225 m
.47007 .56225 L
s
.47007 .56225 m
.47384 .55882 L
s
.46872 .56751 m
.47163 .56751 L
s
.47163 .56751 m
.47377 .57173 L
s
.47007 .56226 m
.47214 .56546 L
s
.46499 .50748 m .46911 .49209 L .46693 .4924 L 0 1 .247 r
F
0 g
.46911 .49209 m
.47334 .48463 L
s
.46828 .49854 m
.46911 .49209 L
s
.52413 .6514 m .52399 .65143 L .52708 .64105 L 0 0 .038 r
F
0 g
.52677 .64211 m
.52708 .64105 L
s
.5268 .64195 m
.52708 .64105 L
s
.52423 .6501 m
.52428 .64993 L
s
.52483 .64665 m
.52546 .64474 L
s
.52398 .64859 m
.52454 .64695 L
s
.52363 .64984 m
.52405 .64856 L
s
.52573 .64454 m
.52648 .64224 L
s
.52398 .65046 m
.52406 .65019 L
s
.50783 .40377 m .50301 .41923 L .50333 .41482 L 0 .002 .082 r
F
.50783 .40377 m .50737 .41588 L .50301 .41923 L F
0 g
.50181 .41303 m
.50383 .40826 L
s
.50783 .40377 m .5135 .40703 L .50737 .41588 L 0 .002 .082 r
F
.50783 .40377 m .51797 .39599 L .5135 .40703 L F
0 g
.50383 .40826 m
.50783 .40377 L
s
.27449 .80654 m
.27919 .81049 L
s
.81322 .608 m .82176 .61118 L .81712 .60811 L 0 .348 .265 r
F
.81322 .608 m .82479 .616 L .82176 .61118 L F
.42539 1.00761 m .40647 1.00645 L .41206 1.01003 L 0 1 .54 r
F
0 g
.40364 1.00942 m
.41206 1.01003 L
s
.5846 .38267 m
.58623 .38639 L
s
.58162 .39249 m
.5846 .38267 L
s
.49533 .6185 m .48735 .59554 L .48645 .60005 L 0 .997 .298 r
F
.49533 .6185 m .49053 .59841 L .48735 .59554 L F
0 g
.48825 .59109 m
.49053 .59839 L
s
.48551 .58791 m
.48735 .59554 L
s
.48735 .59554 m
.49046 .59835 L
s
.49301 .8277 m .4953 .83602 L .49596 .8321 L 0 1 .474 r
F
.50459 .83224 m .49596 .8321 L .4953 .83602 L 0 1 .47 r
F
0 g
.4953 .83602 m
.49864 .84043 L
s
.49103 .83736 m
.4953 .83602 L
s
.39838 1.00544 m .37878 1.00283 L .38407 1.00681 L 0 1 .539 r
F
0 g
.37537 1.00558 m
.38407 1.00681 L
s
.70098 .61744 m
.70216 .6171 L
s
.70077 .61686 m
.70098 .61744 L
s
.36586 .83389 m .35158 .82408 L .35283 .83092 L 0 1 .456 r
F
0 g
.3465 .8266 m
.35283 .83092 L
s
.48662 .71774 m .48123 .72374 L .47883 .72757 L 0 1 .243 r
F
.48662 .71774 m .48457 .71953 L .48123 .72374 L F
.49191 .70815 m .48457 .71953 L .48662 .71774 L 0 1 .183 r
F
0 g
.48662 .71774 m
.48668 .71934 L
s
.48662 .71774 m
.48966 .71352 L
s
.78933 .58831 m .79853 .59435 L .80155 .59703 L 0 0 0 r
F
0 g
.79917 .59533 m
.80163 .59909 L
s
.49892 .96342 m .49121 .95699 L .48499 .95341 L 0 .531 .409 r
F
.44016 .76247 m .43692 .76741 L .44003 .76437 L 0 1 .401 r
F
.44016 .76247 m .43213 .76989 L .43692 .76741 L F
0 g
.43692 .76741 m
.43728 .76933 L
s
.41996 .87514 m .42042 .88373 L .42258 .8816 L 0 .988 .449 r
F
.43473 .8911 m .42258 .8816 L .42042 .88373 L 0 .932 .45 r
F
0 g
.42042 .88373 m
.42359 .89008 L
s
.4143 .88042 m
.42042 .88373 L
s
.54152 .61202 m
.54188 .60926 L
s
.51887 .98648 m
.51937 .98685 L
s
.51937 .98685 m
.52455 .99068 L
s
.52483 .99089 m
.52516 .99113 L
s
.52632 1.01518 m
.53297 1.0102 L
s
.49653 .61231 m .49053 .59841 L .49387 .60677 L 0 1 .296 r
F
0 g
.49053 .59839 m
.49053 .59841 L
s
.49533 .6185 m .49387 .60677 L .49053 .59841 L 0 .997 .298 r
F
0 g
.49046 .59835 m
.49053 .59841 L
s
.51524 .66864 m .51553 .66761 L .51626 .66555 L 0 0 0 r
F
0 g
.51626 .66555 m
.51695 .66371 L
s
.51625 .66554 m
.51626 .66555 L
s
.51464 .66991 m .51626 .66555 L .51553 .66762 L 0 0 0 r
F
0 g
.51626 .66555 m
.51626 .66555 L
s
.70631 .9509 m
.70647 .95084 L
s
.70647 .95084 m
.70652 .95082 L
s
.69471 .95091 m .70225 .95231 L .70613 .94851 L 0 1 .508 r
F
0 g
.70225 .95231 m
.70631 .9509 L
s
.70346 .95112 m
.70633 .95085 L
s
.33713 .82366 m .32548 .81146 L .32074 .81342 L 0 1 .465 r
F
0 g
.32075 .81374 m
.32089 .82088 L
s
.31451 .81622 m
.32089 .82089 L
s
.31486 .8163 m
.32085 .81882 L
s
.31459 .8161 m
.32081 .81682 L
s
.33713 .82366 m .33251 .81585 L .32548 .81146 L 0 1 .465 r
F
0 g
.33713 .82366 m
.33726 .83112 L
s
.34576 .81961 m .33251 .81585 L .33713 .82366 L 0 1 .46 r
F
0 g
.33713 .82366 m
.34312 .82826 L
s
.51925 1.01235 m .51007 1.01288 L .50304 1.01557 L 0 1 .519 r
F
0 g
.50304 1.01557 m
.51007 1.01288 L
s
.51925 1.01235 m
.52632 1.01518 L
s
.54308 .61075 m
.54405 .60832 L
s
.54405 .60832 m
.54409 .60822 L
s
.54409 .60822 m
.54415 .60808 L
s
.54415 .60808 m
.54471 .60667 L
s
.54471 .60667 m
.5449 .60619 L
s
.54367 .61475 m
.5449 .60888 L
s
.54297 .61808 m
.54367 .61475 L
s
.45478 .81974 m .45027 .8171 L .44518 .81732 L 0 1 .487 r
F
0 g
.45478 .81974 m
.45674 .82402 L
s
.46001 .81142 m .45478 .81974 L .45963 .81918 L 0 1 .481 r
F
.46001 .81142 m .45027 .8171 L .45478 .81974 L F
.44823 1.01321 m .439 1.01113 L .43096 1.01118 L 0 1 .54 r
F
.4512 1.00758 m .44823 1.01321 L .45594 1.01303 L 0 1 .541 r
F
.4512 1.00758 m .439 1.01113 L .44823 1.01321 L F
0 g
.44823 1.01321 m
.45435 1.01649 L
s
.51622 .62761 m .51668 .62845 L .51816 .60998 L 0 .776 .272 r
F
0 g
.51559 .62564 m
.51669 .60787 L
s
.45032 .90675 m .44652 .91206 L .45261 .91513 L 0 .864 .449 r
F
0 g
.44652 .91206 m
.45051 .91823 L
s
.52032 .6578 m .51995 .65858 L .52161 .65394 L 0 0 0 r
F
0 g
.52097 .65572 m
.52157 .65405 L
s
.52157 .65405 m
.52161 .65394 L
s
.52062 .65653 m
.52118 .65507 L
s
.52118 .65507 m
.52152 .65416 L
s
.52152 .65416 m
.52161 .65394 L
s
.52126 .65581 m
.5213 .65571 L
s
.5213 .65571 m
.52133 .65561 L
s
.52133 .65561 m
.52319 .65037 L
s
.34956 .96653 m .32991 .96621 L .33413 .96903 L 0 1 .528 r
F
.34956 .96653 m .33289 .96453 L .32991 .96621 L F
.34956 .96653 m .34133 .96467 L .33289 .96453 L F
.35643 .96195 m .34133 .96467 L .34956 .96653 L 0 1 .523 r
F
0 g
.34956 .96653 m
.3577 .9665 L
s
.34956 .96653 m
.35375 .96936 L
s
.45521 .7526 m .44471 .75973 L .4448 .76157 L 0 1 .387 r
F
0 g
.44003 .76437 m
.4448 .76157 L
s
.24264 .80719 m .2275 .7922 L .22779 .80043 L 0 1 .489 r
F
.24264 .80719 m .23174 .7911 L .2275 .7922 L F
.24264 .80719 m .23823 .79754 L .23174 .7911 L F
.25289 .80407 m .23823 .79754 L .24264 .80719 L 0 1 .486 r
F
0 g
.24264 .80719 m
.24291 .81538 L
s
.24264 .80719 m
.24897 .81343 L
s
.76612 .56758 m .7738 .57638 L .76916 .57217 L 0 .189 0 r
F
.76612 .56758 m .77773 .57868 L .7738 .57638 L F
.28602 .95518 m .2861 .9587 L .28938 .95715 L 0 1 .413 r
F
0 g
.28938 .95715 m
.29833 .95642 L
s
.28602 .95518 m .27759 .95887 L .2861 .9587 L 0 1 .413 r
F
0 g
.2861 .9587 m
.29037 .96052 L
s
.7772 .71375 m .78575 .72754 L .78832 .71926 L 0 1 .484 r
F
0 g
.78056 .73202 m
.78575 .72754 L
s
.78575 .72754 m
.78708 .73534 L
s
.51347 .67235 m .5123 .67361 L .51285 .67202 L 0 0 0 r
F
0 g
.512 .67448 m
.5123 .6736 L
s
.44518 .81732 m
.45027 .8171 L
s
.25256 .81203 m .24872 .81947 L .25276 .81821 L 0 1 .526 r
F
0 g
.25276 .81821 m
.25936 .82202 L
s
.25256 .81203 m .2423 .815 L .24872 .81947 L 0 1 .526 r
F
0 g
.24872 .81947 m
.24979 .82512 L
s
.3377 .93948 m .33792 .94229 L .34091 .94045 L 0 1 .335 r
F
0 g
.34091 .94045 m
.34912 .93831 L
s
.3377 .93948 m .32998 .94386 L .33792 .94229 L 0 1 .335 r
F
0 g
.33792 .94229 m
.34191 .94312 L
s
.31429 .81597 m
.31429 .81606 L
s
.31414 .81077 m
.3142 .81266 L
s
.3142 .81278 m
.31429 .81597 L
s
.31428 .81595 m
.31429 .81606 L
s
.31429 .81592 m
.31429 .81606 L
s
.31412 .81277 m
.31428 .81572 L
s
.31428 .81572 m
.31429 .81592 L
s
.23205 .81794 m .2169 .81313 L .22182 .82085 L 0 1 .527 r
F
0 g
.22182 .82085 m
.22851 .8257 L
s
.46822 .48547 m .47213 .47594 L .47374 .46976 L 0 1 .16 r
F
0 g
.47213 .47594 m
.47405 .47256 L
s
.47529 .73155 m .46637 .74046 L .46632 .74218 L 0 1 .292 r
F
.39022 .80697 m .38774 .81349 L .39087 .81143 L 0 1 .506 r
F
.39022 .80697 m .38218 .812 L .38774 .81349 L F
0 g
.38774 .81349 m
.389 .81792 L
s
.73815 .9416 m .7502 .93804 L .7468 .93747 L 0 1 .53 r
F
.72985 .94025 m .73815 .9416 L .74168 .9367 L 0 1 .526 r
F
.50526 .6399 m .49811 .60529 L .49741 .60834 L 0 .87 .292 r
F
.50526 .6399 m .5008 .61331 L .49811 .60529 L F
0 g
.49755 .60186 m
.49811 .60529 L
s
.37199 .7965 m .36888 .80076 L .37228 .79888 L 0 1 .495 r
F
0 g
.37228 .79888 m
.3781 .79829 L
s
.37199 .7965 m .36332 .80101 L .36888 .80076 L 0 1 .495 r
F
0 g
.36888 .80076 m
.36981 .80316 L
s
.51038 .62676 m .51084 .62623 L .5106 .60948 L 0 .812 .282 r
F
.75677 .92478 m .7502 .93804 L .75832 .93303 L 0 1 .526 r
F
.75677 .92478 m .7468 .93747 L .7502 .93804 L F
0 g
.74643 .9432 m
.7502 .93804 L
s
.72168 .94352 m .71398 .95233 L .72223 .95123 L 0 1 .537 r
F
0 g
.71391 .94993 m
.71762 .94816 L
s
.72168 .94352 m .71083 .95043 L .71398 .95233 L 0 1 .537 r
F
0 g
.70984 .95614 m
.71398 .95233 L
s
.34118 .80503 m .34447 .80347 L .34084 .80502 L 0 1 .513 r
F
.35466 .80542 m .34461 .80349 L .34118 .80503 L F
.34461 .80349 m .34447 .80347 L .34118 .80503 L F
.35466 .80542 m .35038 .80364 L .34444 .80346 L F
.36332 .80101 m .35038 .80364 L .35466 .80542 L 0 1 .505 r
F
.36332 .80101 m .34988 .8011 L .35038 .80364 L F
.36319 .80612 m .34995 .80113 L .35032 .80579 L 0 1 .513 r
F
.34995 .80113 m .34988 .80115 L .35032 .80579 L F
.36319 .80612 m .36023 .81259 L .36362 .8108 L F
.36319 .80612 m .35453 .81044 L .36023 .81259 L F
.34084 .80502 m .34444 .80346 L .34081 .80501 L F
.34447 .80347 m .34444 .80346 L .34084 .80502 L F
.34152 .80529 m .34444 .80346 L .34081 .80501 L 0 1 .515 r
F
.35453 .81044 m .34477 .80369 L .34152 .80529 L F
.34477 .80369 m .34444 .80346 L .34152 .80529 L F
.35453 .81044 m .35032 .80579 L .34489 .80364 L F
.34477 .80369 m .34489 .80364 L .34444 .80346 L F
.35453 .81044 m .34489 .80364 L .34477 .80369 L F
.34995 .80113 m .34988 .8011 L .34988 .80115 L 0 1 .513 r
F
.34991 .80113 m .34988 .80114 L .34988 .80118 L 0 1 .449 r
F
.34992 .80116 m .34988 .80118 L .35026 .80794 L F
.34991 .80113 m .34988 .80118 L .34992 .80116 L F
.36319 .80612 m .35032 .80579 L .35453 .81044 L 0 1 .513 r
F
.36307 .81124 m .34995 .80115 L .35026 .80794 L 0 1 .449 r
F
.34995 .80115 m .34991 .80113 L .34992 .80116 L F
.34995 .80115 m .34992 .80116 L .35026 .80794 L F
.34991 .80113 m .34988 .8011 L .34988 .80114 L F
.40614 .85878 m .39202 .85062 L .39407 .85718 L 0 1 .447 r
F
0 g
.38778 .85358 m
.39407 .85718 L
s
.29437 .82011 m .27889 .81632 L .2796 .82003 L 0 1 .532 r
F
.29437 .82011 m .28295 .81507 L .27889 .81632 L F
.29437 .82011 m .2896 .8167 L .28295 .81507 L F
.30415 .81646 m .2896 .8167 L .29437 .82011 L 0 1 .529 r
F
0 g
.29437 .82011 m
.29504 .82371 L
s
.29437 .82011 m
.30078 .8215 L
s
.52264 .39367 m .5337 .38333 L .53432 .39043 L 0 .161 .102 r
F
0 g
.5337 .38333 m
.53768 .37135 L
s
.5287 .38472 m
.5337 .38333 L
s
.30587 .9903 m .30703 .9971 L .30999 .99557 L 0 1 .538 r
F
.30587 .9903 m .29821 .99401 L .30703 .9971 L F
0 g
.30703 .9971 m
.31203 1.00211 L
s
.41999 .94358 m .42232 .94708 L .4241 .94494 L 0 1 .501 r
F
.41999 .94358 m .41527 .94878 L .42232 .94708 L F
0 g
.42232 .94708 m
.42698 .94814 L
s
.43473 .8911 m .43611 .89959 L .4379 .89746 L 0 .932 .45 r
F
.45032 .90675 m .4379 .89746 L .43611 .89959 L 0 .864 .449 r
F
0 g
.43611 .89959 m
.43981 .90585 L
s
.42998 .89643 m
.43611 .89959 L
s
.34208 .99494 m .34387 1.00138 L .3465 .99969 L 0 1 .538 r
F
.34208 .99494 m .33524 .99903 L .34387 1.00138 L F
0 g
.34387 1.00138 m
.34907 1.00587 L
s
.52465 .55362 m .52742 .54393 L .53027 .51689 L 0 1 .238 r
F
0 g
.53027 .51689 m
.53151 .52924 L
s
.50713 .63339 m .50241 .60721 L .50493 .62264 L 0 .851 .289 r
F
.50616 .63647 m .50493 .62264 L .50241 .60721 L 0 .862 .291 r
F
0 g
.49996 .59787 m
.50241 .60721 L
s
.50186 .60128 m
.50241 .60721 L
s
.40614 .85878 m .40567 .86742 L .40818 .86534 L 0 1 .447 r
F
.41996 .87514 m .40818 .86534 L .40567 .86742 L 0 .988 .449 r
F
0 g
.40567 .86742 m
.4083 .87388 L
s
.39963 .86392 m
.40567 .86742 L
s
.50372 .68966 m .50237 .69165 L .50019 .69575 L 0 .989 .159 r
F
.50685 .68318 m .50372 .68966 L .50556 .68632 L 0 .803 .102 r
F
.50685 .68318 m .50237 .69165 L .50372 .68966 L F
0 g
.50372 .68966 m
.50388 .69063 L
s
.48153 .94296 m .47975 .9476 L .48588 .95082 L 0 .693 .441 r
F
0 g
.47975 .9476 m
.48499 .95341 L
s
.54809 1.0127 m
.5481 1.01272 L
s
.27759 .95887 m .26077 .96092 L .26917 .96255 L 0 1 .434 r
F
0 g
.26917 .96255 m
.2779 .9626 L
s
.52128 .6465 m .52648 .61099 L .52337 .63029 L 0 .733 .272 r
F
.51832 .53018 m .52279 .48212 L .51904 .49714 L 0 1 .213 r
F
0 g
.52279 .48212 m
.52398 .47561 L
s
.52279 .48212 m
.5231 .4821 L
s
.45521 .7526 m .44783 .75656 L .44471 .75973 L 0 1 .387 r
F
.45521 .7526 m .45234 .75351 L .44783 .75656 L F
.4624 .744 m .45234 .75351 L .45521 .7526 L 0 1 .328 r
F
0 g
.45521 .7526 m
.45944 .74929 L
s
.45521 .7526 m
.45529 .75445 L
s
.46221 .74579 m
.46632 .74218 L
s
.39852 .78877 m .38589 .79114 L .3864 .79328 L 0 1 .484 r
F
.39852 .78877 m .3893 .78916 L .38589 .79114 L F
.39852 .78877 m .39472 .78814 L .3893 .78916 L F
0 g
.39852 .78877 m
.39901 .79091 L
s
.40694 .78297 m .39472 .78814 L .39852 .78877 L 0 1 .466 r
F
0 g
.39852 .78877 m
.40382 .78745 L
s
.59056 .3838 m .58957 .39991 L .58757 .39261 L 0 .457 .118 r
F
0 g
.58623 .38639 m
.58818 .39082 L
s
.59073 .39664 m .59684 .40108 L .6033 .41517 L 0 .714 .111 r
F
.59073 .39664 m .59624 .42829 L .58975 .41409 L F
.59073 .39664 m .60281 .43526 L .59624 .42829 L F
.59073 .39664 m .60583 .42959 L .60281 .43526 L F
.59073 .39664 m .6033 .41517 L .60583 .42959 L F
.59056 .3838 m .59589 .40392 L .58957 .39991 L 0 .457 .118 r
F
.59056 .3838 m .6023 .40196 L .59589 .40392 L F
0 g
.5995 .39111 m
.60118 .39698 L
s
.60292 .40306 m
.60381 .40617 L
s
.59056 .3838 m .60525 .39311 L .6023 .40196 L 0 .457 .118 r
F
0 g
.60246 .40146 m
.60292 .40306 L
s
.58457 .38069 m
.59056 .3838 L
s
.58757 .39261 m
.59056 .3838 L
s
.68715 .94986 m .67877 .95802 L .68679 .95524 L 0 1 .492 r
F
0 g
.67877 .95802 m
.68038 .95747 L
s
.67621 .95976 m
.67877 .95802 L
s
.32176 .96554 m .32245 .97041 L .32543 .96873 L 0 1 .528 r
F
0 g
.32543 .96873 m
.33413 .96903 L
s
.32176 .96554 m .31407 .96957 L .32245 .97041 L 0 1 .528 r
F
0 g
.32245 .97041 m
.32695 .97341 L
s
.52438 .65165 m .52429 .6515 L .52752 .64051 L 0 0 .043 r
F
0 g
.52606 .64449 m
.52677 .64211 L
s
.52466 .64919 m
.52606 .64449 L
s
.52611 .64412 m
.5268 .64195 L
s
.52428 .64993 m
.52611 .64412 L
s
.52486 .64672 m
.52547 .64478 L
s
.52364 .65103 m
.52514 .64638 L
s
.52514 .64638 m
.52573 .64454 L
s
.52516 .64656 m
.52572 .64472 L
s
.52572 .64472 m
.52648 .64224 L
s
.52406 .65019 m
.52516 .64656 L
s
.52332 .65165 m
.52439 .64823 L
s
.52286 .65258 m
.52431 .64822 L
s
.52405 .64856 m
.52456 .64696 L
s
.52431 .64822 m
.52483 .64665 L
s
.52439 .64823 m
.52486 .64672 L
s
.52461 .64937 m
.52466 .64919 L
s
.49653 .61231 m .49674 .61135 L .49445 .60402 L 0 1 .296 r
F
0 g
.49445 .60402 m
.49513 .605 L
s
.33524 .99903 m .31445 .99327 L .31917 .99816 L 0 1 .538 r
F
.46001 .81142 m .45963 .81918 L .4616 .8158 L 0 1 .481 r
F
.47061 .81728 m .4616 .8158 L .45963 .81918 L 0 1 .479 r
F
0 g
.45963 .81918 m
.4617 .82356 L
s
.45478 .81974 m
.45963 .81918 L
s
.48157 .72206 m .47883 .72757 L .48123 .72374 L 0 1 .208 r
F
.48157 .72206 m .47529 .73155 L .47883 .72757 L F
0 g
.47883 .72757 m
.47889 .72917 L
s
.50131 .89953 m .48957 .90774 L .48897 .90994 L 0 1 .431 r
F
.50131 .89953 m .49486 .90328 L .48957 .90774 L F
.50207 .89468 m .50131 .89953 L .50627 .89529 L 0 1 .403 r
F
.50207 .89468 m .49486 .90328 L .50131 .89953 L F
0 g
.50131 .89953 m
.506 .89832 L
s
.30429 .81249 m .28953 .80011 L .28992 .80761 L 0 1 .474 r
F
.30429 .81249 m .2936 .79874 L .28953 .80011 L F
.30429 .81249 m .29993 .80405 L .2936 .79874 L F
.31408 .8087 m .29993 .80405 L .30429 .81249 L 0 1 .469 r
F
0 g
.30429 .81249 m
.30439 .81441 L
s
.30429 .81249 m
.3059 .81383 L
s
.52178 .85066 m
.52195 .85057 L
s
.48524 .90831 m .48897 .90994 L .48957 .90774 L 0 1 .435 r
F
.48524 .90831 m .48344 .91377 L .48897 .90994 L F
0 g
.48897 .90994 m
.49368 .90871 L
s
.46001 .81142 m .44867 .81273 L .45027 .8171 L 0 1 .481 r
F
.4512 1.00758 m .45594 1.01303 L .457 1.01072 L 0 1 .541 r
F
.47358 1.01116 m .457 1.01072 L .45594 1.01303 L 0 1 .54 r
F
0 g
.45594 1.01303 m
.46223 1.01589 L
s
.44823 1.01321 m
.45594 1.01303 L
s
.40844 .81071 m .39558 .80829 L .39661 .81264 L 0 1 .501 r
F
0 g
.39087 .81143 m
.39661 .81264 L
s
.53161 1.00977 m
.53297 1.01014 L
s
.78832 .71926 m .79672 .7328 L .79942 .72438 L 0 1 .49 r
F
0 g
.79143 .73749 m
.79672 .7328 L
s
.79672 .7328 m
.79795 .74061 L
s
.54332 .61022 m
.54337 .61002 L
s
.72154 .93918 m .72206 .94605 L .72985 .94025 L 0 1 .52 r
F
0 g
.72188 .9463 m
.72206 .94605 L
s
.72187 .94614 m
.72206 .94605 L
s
.51937 .65982 m .51897 .66067 L .52031 .65701 L 0 0 0 r
F
0 g
.51945 .65937 m
.52005 .65773 L
s
.52005 .65773 m
.52031 .65701 L
s
.51898 .66039 m
.51977 .65837 L
s
.51977 .65837 m
.52031 .65701 L
s
.50207 .89468 m .50627 .89529 L .50646 .89338 L 0 1 .403 r
F
0 g
.50131 .89953 m
.50627 .89529 L
s
.50627 .89529 m
.50927 .89404 L
s
.47755 .58781 m .47023 .58715 L .4739 .58993 L 0 1 .308 r
F
.47755 .58781 m .46861 .58025 L .47023 .58715 L F
.47755 .58781 m .47012 .57385 L .46861 .58025 L F
.48645 .60005 m .47755 .58781 L .47938 .59545 L 0 1 .303 r
F
.48344 .91377 m .4708 .9206 L .4698 .9229 L 0 1 .459 r
F
0 g
.4698 .9229 m
.47445 .92249 L
s
.48344 .91377 m .47665 .91669 L .4708 .9206 L 0 1 .459 r
F
.48524 .90831 m .47665 .91669 L .48344 .91377 L 0 1 .435 r
F
0 g
.48344 .91377 m
.48808 .91337 L
s
.48344 .91377 m
.48897 .90994 L
s
.46822 .48547 m .47374 .46976 L .47198 .47103 L 0 1 .16 r
F
0 g
.47374 .46976 m
.4781 .46104 L
s
.47213 .47594 m
.47374 .46976 L
s
.50039 .69452 m .49463 .70408 L .49444 .70531 L 0 .913 .15 r
F
0 g
.49165 .70968 m
.49444 .70531 L
s
.38218 .812 m .36871 .80809 L .36959 .81264 L 0 1 .509 r
F
.49633 1.01292 m .48719 1.01244 L .47986 1.01402 L 0 1 .536 r
F
0 g
.47986 1.01402 m
.48719 1.01244 L
s
.49633 1.01292 m
.50304 1.01557 L
s
.46591 .55278 m .45856 .55649 L .46186 .55755 L 0 1 .309 r
F
.46591 .55278 m .45794 .54984 L .45856 .55649 L F
.46591 .55278 m .4604 .54205 L .45794 .54984 L F
.46591 .55278 m .46446 .53729 L .4604 .54205 L F
0 g
.46591 .55278 m
.46679 .56003 L
s
.24196 .82282 m .23835 .82853 L .24239 .82733 L 0 1 .538 r
F
0 g
.24239 .82733 m
.24289 .8275 L
s
.24196 .82282 m .2317 .82561 L .23835 .82853 L 0 1 .538 r
F
0 g
.23835 .82853 m
.23978 .83302 L
s
.27344 .79773 m .26922 .80685 L .27328 .80552 L 0 1 .48 r
F
.27344 .79773 m .26316 .80092 L .26922 .80685 L F
0 g
.26922 .80685 m
.2698 .81287 L
s
.27328 .80552 m
.27449 .80654 L
s
.51832 .53018 m .52161 .51738 L .52452 .49672 L 0 1 .213 r
F
0 g
.52213 .51368 m
.52452 .49672 L
s
.52452 .49672 m
.52476 .49672 L
s
.37388 .82933 m .37178 .83796 L .37491 .83611 L 0 1 .45 r
F
.37388 .82933 m .36586 .83389 L .37178 .83796 L F
.38611 .8469 m .37491 .83611 L .37178 .83796 L 0 1 .452 r
F
0 g
.37178 .83796 m
.37346 .84465 L
s
.49301 .8277 m .48843 .82575 L .48417 .8271 L 0 1 .474 r
F
.50459 .83224 m .50773 .84078 L .50793 .83665 L 0 1 .47 r
F
0 g
.50773 .84078 m
.51143 .84518 L
s
.50375 .84239 m
.50773 .84078 L
s
.75495 .70131 m
.75573 .70066 L
s
.75438 .69865 m
.75495 .70131 L
s
.51145 .67473 m .51052 .67649 L .50932 .67931 L 0 .872 .124 r
F
.48645 .60005 m .47938 .59545 L .48303 .60002 L 0 1 .303 r
F
.49533 .6185 m .48645 .60005 L .4885 .60866 L 0 .997 .298 r
F
.46427 .53005 m .45707 .53548 L .46003 .5359 L 0 1 .292 r
F
.46427 .53005 m .45715 .52886 L .45707 .53548 L F
.46427 .53005 m .46022 .52047 L .45715 .52886 L F
.46427 .53005 m .46446 .51463 L .46022 .52047 L F
0 g
.46427 .53005 m
.46446 .53729 L
s
.51734 .62993 m .51778 .63107 L .51958 .61326 L 0 .773 .272 r
F
0 g
.51738 .62909 m
.51748 .62664 L
s
.51748 .62664 m
.51816 .60998 L
s
.51679 .62709 m
.51816 .60998 L
s
.77218 .77932 m .76879 .78692 L .77304 .79045 L 0 .651 .435 r
F
.77218 .77932 m .76841 .78216 L .76879 .78692 L F
0 g
.76203 .78714 m
.76879 .78692 L
s
.76841 .78216 m
.76879 .78692 L
s
.7624 .7814 m
.76841 .78216 L
s
.43213 .76989 m .42037 .77505 L .42051 .77704 L 0 1 .438 r
F
.43213 .76989 m .42381 .77237 L .42037 .77505 L F
.43213 .76989 m .42885 .77016 L .42381 .77237 L F
.44016 .76247 m .42885 .77016 L .43213 .76989 L 0 1 .401 r
F
0 g
.43213 .76989 m
.43692 .76741 L
s
.43213 .76989 m
.43225 .77188 L
s
.35453 .81044 m
.36023 .81259 L
s
.36023 .81259 m
.36132 .81724 L
s
.35453 .81044 m
.35515 .81524 L
s
.51888 1.00092 m .51925 1.01235 L .52589 1.00823 L 0 1 .517 r
F
.51888 1.00092 m .51007 1.01288 L .51925 1.01235 L F
.36586 .83389 m .35496 .82238 L .35158 .82408 L 0 1 .456 r
F
.36586 .83389 m .36109 .82659 L .35496 .82238 L F
.37388 .82933 m .36109 .82659 L .36586 .83389 L 0 1 .45 r
F
0 g
.36586 .83389 m
.37178 .83796 L
s
.36586 .83389 m
.3671 .84072 L
s
.38218 .812 m .37211 .80626 L .36871 .80809 L 0 1 .509 r
F
0 g
.36362 .8108 m
.36959 .81264 L
s
.38218 .812 m .37789 .80793 L .37211 .80626 L 0 1 .509 r
F
.39022 .80697 m .37789 .80793 L .38218 .812 L 0 1 .506 r
F
0 g
.38218 .812 m
.38774 .81349 L
s
.38218 .812 m
.38304 .81654 L
s
.50925 .62848 m .5097 .62773 L .5091 .61192 L 0 .825 .285 r
F
0 g
.5091 .61192 m
.51037 .62662 L
s
.50526 .6399 m .49741 .60834 L .49932 .61971 L 0 .87 .292 r
F
0 g
.49513 .605 m
.49741 .60834 L
s
.4992 .60081 m
.50029 .60932 L
s
.47529 .73155 m .46914 .73684 L .46637 .74046 L 0 1 .292 r
F
.47529 .73155 m .47297 .73302 L .46914 .73684 L F
.48157 .72206 m .47297 .73302 L .47529 .73155 L 0 1 .208 r
F
0 g
.47524 .73328 m
.47529 .73155 L
s
.47529 .73155 m
.47883 .72757 L
s
.4512 1.00758 m .43319 1.00799 L .439 1.01113 L 0 1 .541 r
F
0 g
.43096 1.01118 m
.439 1.01113 L
s
.46861 .58025 m .46872 .56751 L .46534 .56546 L 0 1 .315 r
F
.46861 .58025 m .47012 .57385 L .46872 .56751 L F
0 g
.46872 .56751 m
.47012 .57385 L
s
.47012 .57385 m
.47329 .57202 L
s
.50685 .68318 m .50556 .68632 L .50668 .68385 L 0 .803 .102 r
F
.50913 .67906 m .50668 .68385 L .50556 .68632 L 0 .843 .114 r
F
0 g
.50556 .68632 m
.50575 .68656 L
s
.50372 .68966 m
.50556 .68632 L
s
.53345 .59701 m
.5338 .59555 L
s
.5338 .59555 m
.53395 .59492 L
s
.48165 .8227 m .47719 .82058 L .47268 .82166 L 0 1 .477 r
F
.72154 .93918 m .71406 .94472 L .7108 .94933 L 0 1 .52 r
F
0 g
.70652 .95082 m
.7108 .94933 L
s
.45557 .91953 m
.45678 .92133 L
s
.4265 .81265 m .41679 .809 L .41382 .81148 L 0 1 .496 r
F
.4265 .81265 m .42223 .8095 L .41679 .809 L F
.43336 .80588 m .4265 .81265 L .43168 .81295 L 0 1 .491 r
F
.43336 .80588 m .42223 .8095 L .4265 .81265 L F
0 g
.4265 .81265 m
.42772 .817 L
s
.43336 .80588 m .43168 .81295 L .43432 .81019 L 0 1 .491 r
F
.44372 .81302 m .43432 .81019 L .43168 .81295 L 0 1 .489 r
F
0 g
.43168 .81295 m
.43315 .81724 L
s
.4265 .81265 m
.43168 .81295 L
s
.51888 1.00092 m .50336 1.01055 L .51007 1.01288 L 0 1 .517 r
F
.79942 .72438 m .80768 .73775 L .81052 .72918 L 0 1 .495 r
F
0 g
.8023 .74264 m
.80768 .73775 L
s
.80768 .73775 m
.80881 .7456 L
s
.53825 .53962 m .54623 .52042 L .54549 .52638 L 0 0 .045 r
F
0 g
.54623 .52042 m
.54983 .50859 L
s
.41526 .94878 m .39976 .95094 L .39695 .95351 L 0 1 .511 r
F
.41526 .94878 m .40762 .94891 L .39976 .95094 L F
0 g
.41526 .94878 m
.41924 .95083 L
s
.41999 .94358 m .40762 .94891 L .41527 .94878 L 0 1 .501 r
F
0 g
.41527 .94878 m
.42232 .94708 L
s
.46478 .92557 m
.4698 .9229 L
s
.5123 .6748 m .51145 .67473 L .5123 .67361 L 0 0 0 r
F
.5123 .6748 m .51052 .67649 L .51145 .67473 L F
0 g
.63386 .42256 m
.63548 .42863 L
s
.63372 .42275 m
.63386 .42256 L
s
.63258 .42429 m
.63372 .42275 L
s
.50459 .83224 m .49994 .83048 L .49596 .8321 L 0 1 .47 r
F
.49533 .6185 m .49593 .61538 L .49387 .60677 L 0 .997 .298 r
F
0 g
.49434 .60871 m
.49499 .61143 L
s
.49387 .60677 m
.49434 .60871 L
s
.49445 .60402 m
.49589 .60863 L
s
.7469 .95618 m .75933 .95601 L .75589 .95446 L 0 1 .539 r
F
.73852 .95207 m .7469 .95618 L .75073 .95212 L F
.41611 .80464 m .41382 .81148 L .41679 .809 L 0 1 .497 r
F
.41611 .80464 m .40844 .81071 L .41382 .81148 L F
0 g
.41382 .81148 m
.41505 .81583 L
s
.41538 .77696 m .41204 .7814 L .41533 .77892 L 0 1 .442 r
F
.41538 .77696 m .40694 .78297 L .41204 .7814 L F
0 g
.41204 .7814 m
.41252 .78341 L
s
.41533 .77892 m
.42051 .77704 L
s
.38611 .8469 m .38105 .83994 L .37491 .83611 L 0 1 .452 r
F
.39341 .84196 m .38611 .8469 L .39202 .85062 L 0 1 .446 r
F
.39341 .84196 m .38105 .83994 L .38611 .8469 L F
0 g
.38611 .8469 m
.38778 .85358 L
s
.67469 .52355 m
.67644 .55845 L
s
.44253 .93608 m .42678 .94175 L .43115 .94263 L 0 1 .493 r
F
0 g
.4241 .94494 m
.43115 .94263 L
s
.37048 1.00121 m .35046 .99717 L .35537 1.00154 L 0 1 .539 r
F
0 g
.3465 .99969 m
.35537 1.00154 L
s
.49191 .70815 m .48482 .718 L .48457 .71953 L 0 1 .183 r
F
0 g
.48123 .72374 m
.48457 .71953 L
s
.53401 .61366 m
.5347 .61178 L
s
.77218 .77932 m .77304 .79045 L .77918 .79084 L 0 .651 .435 r
F
0 g
.77248 .79603 m
.77304 .79045 L
s
.48153 .94296 m .47436 .93675 L .46824 .93354 L 0 .693 .441 r
F
.71022 .55816 m .71771 .53419 L .72334 .5423 L 0 .509 .118 r
F
.71022 .55816 m .7121 .54093 L .71771 .53419 L F
0 g
.71436 .51923 m
.71771 .53419 L
s
.71025 .52218 m
.7121 .54092 L
s
.7121 .54093 m
.71771 .53419 L
s
.55264 .39817 m .5502 .41447 L .54913 .41085 L 0 .168 .107 r
F
.55264 .39817 m .55566 .40921 L .5502 .41447 L F
0 g
.55264 .39817 m
.55264 .39817 L
s
.55263 .39819 m
.55264 .39817 L
s
.55264 .39817 m .56183 .39859 L .55566 .40921 L 0 .168 .107 r
F
0 g
.55264 .39817 m
.55264 .39817 L
s
.33524 .99903 m .31742 .99174 L .31445 .99327 L 0 1 .538 r
F
0 g
.30999 .99557 m
.31264 .99631 L
s
.33524 .99903 m .32634 .99421 L .31742 .99174 L 0 1 .538 r
F
0 g
.31264 .99631 m
.31917 .99816 L
s
.34208 .99494 m .32634 .99421 L .33524 .99903 L 0 1 .538 r
F
0 g
.33524 .99903 m
.34387 1.00138 L
s
.33524 .99903 m
.33993 1.00391 L
s
.30422 .81447 m .28929 .80664 L .28976 .81215 L 0 1 .522 r
F
.30422 .81447 m .29337 .80532 L .28929 .80664 L F
.30422 .81447 m .29977 .80868 L .29337 .80532 L F
.31402 .81073 m .29977 .80868 L .30422 .81447 L 0 1 .521 r
F
0 g
.30422 .81447 m
.30644 .8156 L
s
.30422 .81447 m
.30438 .81638 L
s
.31396 .81275 m
.31428 .81595 L
s
.68715 .94986 m .68679 .95524 L .69471 .95091 L 0 1 .492 r
F
0 g
.68535 .95666 m
.68679 .95524 L
s
.68038 .95747 m
.68679 .95524 L
s
.43473 .8911 m .42871 .88476 L .42258 .8816 L 0 .932 .45 r
F
0 g
.54354 1.02912 m
.54904 1.03318 L
s
.54354 1.02912 m
.54785 1.02589 L
s
.28473 .80324 m
.28933 .80711 L
s
.25289 .80407 m .23808 .78944 L .23823 .79754 L 0 1 .486 r
F
.25289 .80407 m .24232 .78833 L .23808 .78944 L F
.25289 .80407 m .24867 .79461 L .24232 .78833 L F
.26316 .80092 m .24867 .79461 L .25289 .80407 L 0 1 .483 r
F
0 g
.25289 .80407 m
.25302 .81213 L
s
.25289 .80407 m
.25909 .81016 L
s
.27721 .96915 m .27746 .97451 L .28074 .97305 L 0 1 .533 r
F
0 g
.28074 .97305 m
.28988 .9744 L
s
.27721 .96915 m .26878 .97263 L .27746 .97451 L 0 1 .533 r
F
0 g
.27746 .97451 m
.28193 .97822 L
s
.51347 .67235 m .51429 .66964 L .51402 .67077 L 0 0 0 r
F
.51464 .66991 m .51402 .67077 L .51429 .66964 L F
0 g
.51378 .67018 m
.51429 .66964 L
s
.51429 .66964 m
.51515 .66743 L
s
.31396 .81275 m
.32066 .81341 L
s
.32066 .81341 m
.3207 .81342 L
s
.32602 .80811 m .32074 .81342 L .32548 .81146 L 0 1 .518 r
F
0 g
.3207 .81342 m
.32074 .81342 L
s
.32548 .81146 m
.32567 .81152 L
s
.32583 .81157 m
.32596 .81162 L
s
.32596 .81162 m
.32606 .81165 L
s
.32567 .81152 m
.32583 .81157 L
s
.32564 .81147 m
.32579 .81147 L
s
.32554 .81146 m
.32564 .81147 L
s
.32548 .81146 m
.32554 .81146 L
s
.32074 .81342 m
.32075 .81374 L
s
.50685 .68318 m .50254 .69099 L .50237 .69165 L 0 .803 .102 r
F
0 g
.50019 .69575 m
.50237 .69165 L
s
.72854 .54133 m .73556 .55757 L .731 .55233 L 0 .492 .079 r
F
.72854 .54133 m .74004 .5557 L .73556 .55757 L F
.81052 .72918 m .81863 .74243 L .82161 .73368 L 0 1 .5 r
F
0 g
.81315 .74752 m
.81863 .74243 L
s
.26322 .82144 m
.26962 .82333 L
s
.72168 .94352 m .71412 .94665 L .71083 .95043 L 0 1 .537 r
F
0 g
.70647 .95084 m
.71083 .95043 L
s
.51835 .662 m .51792 .66291 L .51893 .66017 L 0 0 0 r
F
0 g
.51836 .66171 m
.51858 .66113 L
s
.51858 .66113 m
.5188 .66053 L
s
.5188 .66053 m
.51893 .66017 L
s
.51822 .66196 m
.51864 .66091 L
s
.51864 .66091 m
.51893 .66017 L
s
.47406 .46452 m .47858 .45457 L .48098 .44886 L 0 .828 .103 r
F
0 g
.47858 .45457 m
.48079 .45016 L
s
.49733 1.00423 m .49633 1.01292 L .50336 1.01055 L 0 1 .537 r
F
.49733 1.00423 m .48719 1.01244 L .49633 1.01292 L F
.35441 .81547 m .35158 .82408 L .35496 .82238 L 0 1 .455 r
F
.35441 .81547 m .34576 .81961 L .35158 .82408 L F
0 g
.35158 .82408 m
.35283 .83092 L
s
.6137 .41725 m
.61588 .42821 L
s
.61364 .41748 m
.6137 .41725 L
s
.61344 .41815 m
.61364 .41748 L
s
.39341 .84196 m .39202 .85062 L .39485 .84861 L 0 1 .446 r
F
.40614 .85878 m .39485 .84861 L .39202 .85062 L 0 1 .447 r
F
0 g
.39202 .85062 m
.39407 .85718 L
s
.38611 .8469 m
.39202 .85062 L
s
.37081 .92713 m .35291 .93311 L .35635 .9335 L 0 1 .306 r
F
.37081 .92713 m .35591 .93128 L .35291 .93311 L F
.37081 .92713 m .3636 .92872 L .35591 .93128 L F
0 g
.37081 .92713 m
.37421 .92753 L
s
.40844 .81071 m .39872 .80616 L .39558 .80829 L 0 1 .501 r
F
.40844 .81071 m .40424 .8072 L .39872 .80616 L F
0 g
.40844 .81071 m
.40945 .81507 L
s
.41611 .80464 m .40424 .8072 L .40844 .81071 L 0 1 .497 r
F
0 g
.40844 .81071 m
.41382 .81148 L
s
.75151 .56763 m .75755 .56043 L .7622 .56534 L 0 .328 .044 r
F
.75151 .56763 m .75298 .5614 L .75755 .56043 L F
0 g
.75448 .5547 m
.75755 .56043 L
s
.46499 .50748 m .45798 .51466 L .46058 .51439 L 0 1 .247 r
F
.46499 .50748 m .45881 .50819 L .45798 .51466 L F
0 g
.4619 .51817 m
.46446 .51463 L
s
.46499 .50748 m .46252 .49929 L .45881 .50819 L 0 1 .247 r
F
.46499 .50748 m .46693 .4924 L .46252 .49929 L F
0 g
.46446 .51463 m
.46499 .50748 L
s
.23205 .81794 m .21638 .80656 L .2169 .81313 L 0 1 .527 r
F
.23205 .81794 m .22061 .80556 L .21638 .80656 L F
.23205 .81794 m .22733 .81045 L .22061 .80556 L F
.2423 .815 m .22733 .81045 L .23205 .81794 L 0 1 .526 r
F
0 g
.23205 .81794 m
.23861 .8226 L
s
.23205 .81794 m
.23255 .82446 L
s
.45032 .90675 m .45261 .91513 L .45401 .91302 L 0 .864 .449 r
F
0 g
.45261 .91513 m
.45557 .91953 L
s
.44652 .91206 m
.45261 .91513 L
s
.4844 .61127 m .47938 .59545 L .47586 .59613 L 0 1 .306 r
F
.4844 .61127 m .48303 .60002 L .47938 .59545 L F
0 g
.47755 .58781 m
.47938 .59545 L
s
.4844 .61127 m .48518 .60679 L .48303 .60002 L 0 1 .306 r
F
0 g
.48303 .60002 m
.48645 .60005 L
s
.41996 .87514 m .4143 .86865 L .40818 .86534 L 0 .988 .449 r
F
.26284 .80904 m .25884 .81632 L .26289 .81505 L 0 1 .525 r
F
0 g
.26289 .81505 m
.26979 .81895 L
s
.26284 .80904 m .25256 .81203 L .25884 .81632 L 0 1 .525 r
F
0 g
.25884 .81632 m
.2598 .82212 L
s
.44372 .81302 m .43948 .81022 L .43432 .81019 L 0 1 .489 r
F
0 g
.44372 .81302 m
.44518 .81732 L
s
.44995 .80515 m .44372 .81302 L .44867 .81273 L 0 1 .483 r
F
.44995 .80515 m .43948 .81022 L .44372 .81302 L F
.50483 .64177 m .49674 .61135 L .49653 .61231 L 0 .876 .293 r
F
.50483 .64177 m .49932 .61971 L .49674 .61135 L F
0 g
.49589 .60863 m
.49674 .61135 L
s
.75677 .92478 m .7496 .9318 L .7468 .93747 L 0 1 .526 r
F
0 g
.73815 .9416 m
.7468 .93747 L
s
.32558 .81152 m
.32573 .81161 L
s
.32548 .81146 m
.32558 .81152 L
s
.33251 .81584 m
.33251 .81585 L
s
.78313 .78783 m .77941 .79553 L .78365 .79878 L 0 .714 .447 r
F
.78313 .78783 m .77918 .79084 L .77941 .79553 L F
0 g
.77248 .79603 m
.77941 .79553 L
s
.50816 .63071 m .50859 .62976 L .50765 .61498 L 0 .838 .287 r
F
0 g
.50765 .61498 m
.50857 .6294 L
s
.50765 .61498 m
.50925 .62843 L
s
.49733 1.00423 m .48092 1.00976 L .48719 1.01244 L 0 1 .537 r
F
.47061 .81728 m .46631 .81498 L .4616 .8158 L 0 1 .479 r
F
.29821 .99401 m .27702 .98647 L .28144 .99189 L 0 1 .538 r
F
.29821 .99401 m .2803 .9851 L .27702 .98647 L F
.29821 .99401 m .28939 .98834 L .2803 .9851 L F
.30587 .9903 m .28939 .98834 L .29821 .99401 L F
0 g
.29821 .99401 m
.30703 .9971 L
s
.29821 .99401 m
.30259 .9994 L
s
.45032 .90675 m .44399 .90052 L .4379 .89746 L 0 .864 .449 r
F
0 g
.63677 .49512 m
.63684 .49987 L
s
.63684 .49987 m
.63689 .50296 L
s
.63689 .50296 m
.63698 .50846 L
s
.63705 .51323 m
.63708 .51527 L
s
.63698 .50846 m
.63705 .51323 L
s
.63708 .51527 m
.63722 .52441 L
s
.63722 .52441 m
.63722 .52447 L
s
.63722 .52447 m
.63723 .52506 L
s
.63723 .52506 m
.63727 .52727 L
s
.63785 .56523 m
.63786 .56572 L
s
.5123 .6748 m .51032 .67742 L .51052 .67649 L 0 0 0 r
F
0 g
.50932 .67931 m
.51052 .67649 L
s
.50616 .63647 m .5008 .61331 L .5037 .62708 L 0 .862 .291 r
F
.50526 .6399 m .5037 .62708 L .5008 .61331 L 0 .87 .292 r
F
0 g
.49811 .60529 m
.5008 .61331 L
s
.50029 .60932 m
.5008 .61331 L
s
.48476 .81294 m .48165 .8227 L .48583 .82133 L 0 1 .469 r
F
.48476 .81294 m .47719 .82058 L .48165 .8227 L F
0 g
.48165 .8227 m
.48417 .8271 L
s
.51797 .39599 m
.52264 .39367 L
s
.5135 .40703 m
.51797 .39599 L
s
.50483 .64177 m .49653 .61231 L .49889 .62174 L 0 .876 .293 r
F
0 g
.49387 .60677 m
.49653 .61231 L
s
.495 .81745 m .48843 .82575 L .49301 .8277 L 0 1 .466 r
F
.495 .81745 m .48583 .82133 L .48843 .82575 L F
0 g
.48417 .8271 m
.48843 .82575 L
s
.46657 .92226 m .46376 .92747 L .46974 .93054 L 0 .778 .445 r
F
0 g
.46376 .92747 m
.46824 .93354 L
s
.44995 .80515 m .44867 .81273 L .45105 .80953 L 0 1 .483 r
F
.46001 .81142 m .45105 .80953 L .44867 .81273 L 0 1 .481 r
F
0 g
.44867 .81273 m
.45027 .8171 L
s
.44372 .81302 m
.44867 .81273 L
s
.75677 .92478 m .75832 .93303 L .76577 .92577 L 0 1 .526 r
F
0 g
.7553 .93896 m
.75832 .93303 L
s
.7502 .93804 m
.75832 .93303 L
s
.51888 1.00092 m .52589 1.00823 L .52558 1.00326 L 0 1 .517 r
F
0 g
.51925 1.01235 m
.52589 1.00823 L
s
.52589 1.00823 m
.53161 1.00977 L
s
.39341 .84196 m .3796 .83329 L .38105 .83994 L 0 1 .446 r
F
0 g
.37491 .83611 m
.38105 .83994 L
s
.48476 .81294 m .475 .81617 L .47719 .82058 L 0 1 .469 r
F
0 g
.47268 .82166 m
.47719 .82058 L
s
.34576 .81961 m .33538 .80732 L .33176 .80885 L 0 1 .46 r
F
0 g
.33176 .80888 m
.33176 .80892 L
s
.33176 .80892 m
.33251 .81584 L
s
.32573 .81161 m
.33251 .81585 L
s
.32579 .81147 m
.33206 .81168 L
s
.32606 .81165 m
.33228 .81368 L
s
.34576 .81961 m .34138 .81194 L .33538 .80732 L 0 1 .46 r
F
0 g
.33543 .80733 m
.33561 .80734 L
s
.35441 .81547 m .34138 .81194 L .34576 .81961 L 0 1 .455 r
F
0 g
.34576 .81961 m
.3465 .8266 L
s
.34576 .81961 m
.35158 .82408 L
s
.55526 .51872 m .55846 .50577 L .56275 .50502 L 0 .295 .159 r
F
0 g
.55846 .50577 m
.559 .49276 L
s
.30415 .81646 m .28906 .81319 L .2896 .8167 L 0 1 .529 r
F
.30415 .81646 m .29313 .81192 L .28906 .81319 L F
.30415 .81646 m .29961 .81333 L .29313 .81192 L F
.31396 .81275 m .29961 .81333 L .30415 .81646 L 0 1 .525 r
F
0 g
.30415 .81646 m
.30465 .81986 L
s
.30415 .81646 m
.31039 .81762 L
s
.78313 .78783 m .78365 .79878 L .78992 .79882 L 0 .714 .447 r
F
0 g
.78292 .80427 m
.78365 .79878 L
s
.495 .81745 m .49301 .8277 L .49694 .82604 L 0 1 .466 r
F
0 g
.49301 .8277 m
.49596 .8321 L
s
.37388 .82933 m .36005 .81981 L .36109 .82659 L 0 1 .45 r
F
0 g
.35496 .82238 m
.36109 .82659 L
s
.46961 .73509 m .46637 .74046 L .46914 .73684 L 0 1 .25 r
F
.46961 .73509 m .4624 .744 L .46637 .74046 L F
0 g
.46632 .74218 m
.46637 .74046 L
s
.51842 .63301 m .51884 .63445 L .52093 .61775 L 0 .769 .271 r
F
0 g
.52059 .62044 m
.52093 .61775 L
s
.51849 .63188 m
.51871 .62804 L
s
.36332 .95738 m .36432 .96176 L .36697 .95986 L 0 1 .518 r
F
.36332 .95738 m .35643 .96195 L .36432 .96176 L F
0 g
.36432 .96176 m
.36868 .96403 L
s
.47481 .6016 m .4739 .58993 L .47023 .58715 L 0 1 .313 r
F
.47481 .6016 m .47586 .59613 L .4739 .58993 L F
0 g
.4739 .58993 m
.47755 .58781 L
s
.50793 .83665 m
.51159 .83472 L
s
.40339 1.00063 m .40647 1.00645 L .40836 1.00448 L 0 1 .54 r
F
0 g
.40086 1.00732 m
.40364 1.00942 L
s
.40339 1.00063 m .39838 1.00544 L .40647 1.00645 L 0 1 .54 r
F
.42539 1.00761 m .40836 1.00448 L .40647 1.00645 L F
0 g
.40647 1.00645 m
.41206 1.01003 L
s
.47406 .46452 m .48098 .44886 L .47967 .45117 L 0 .828 .103 r
F
0 g
.48098 .44886 m
.48291 .4446 L
s
.47858 .45457 m
.48098 .44886 L
s
.35024 .8011 m .35354 .79951 L .34989 .8011 L 0 1 .505 r
F
.36332 .80101 m .35368 .79953 L .35024 .8011 L F
.35368 .79953 m .35354 .79951 L .35024 .8011 L F
.36332 .80101 m .35928 .79947 L .35351 .79951 L F
.37199 .7965 m .35928 .79947 L .36332 .80101 L 0 1 .495 r
F
.37199 .7965 m .35896 .79709 L .35928 .79947 L F
.37187 .80169 m .35905 .79712 L .35922 .80166 L 0 1 .51 r
F
.35905 .79712 m .35897 .79715 L .35922 .80166 L F
.37187 .80169 m .36871 .80809 L .37211 .80626 L F
.37187 .80169 m .36319 .80612 L .36871 .80809 L F
.34989 .8011 m .35351 .79951 L .34988 .8011 L 0 1 .505 r
F
.35354 .79951 m .35351 .79951 L .34989 .8011 L F
.35057 .80136 m .35351 .79951 L .34988 .8011 L 0 1 .513 r
F
.36319 .80612 m .35384 .79973 L .35057 .80136 L F
.35384 .79973 m .35351 .79951 L .35057 .80136 L F
.36319 .80612 m .35922 .80166 L .35396 .79968 L F
.35384 .79973 m .35396 .79968 L .35351 .79951 L F
.36319 .80612 m .35396 .79968 L .35384 .79973 L F
.35905 .79712 m .35896 .79709 L .35897 .79715 L 0 1 .51 r
F
.359 .79712 m .35897 .79713 L .35897 .79718 L 0 1 .443 r
F
.359 .79716 m .35897 .79718 L .35917 .80385 L F
.359 .79712 m .35897 .79718 L .359 .79716 L F
.37187 .80169 m .35922 .80166 L .36319 .80612 L 0 1 .51 r
F
.37175 .8069 m .35904 .79714 L .35917 .80385 L 0 1 .443 r
F
.35904 .79714 m .359 .79712 L .359 .79716 L F
.35904 .79714 m .359 .79716 L .35917 .80385 L F
.359 .79712 m .35896 .79709 L .35897 .79713 L F
0 g
.76633 .70758 m
.77118 .70347 L
s
.76445 .69976 m
.76584 .70661 L
s
.38067 .79185 m .37738 .79602 L .38078 .79409 L 0 1 .482 r
F
0 g
.38078 .79409 m
.3864 .79328 L
s
.38067 .79185 m .37199 .7965 L .37738 .79602 L 0 1 .482 r
F
0 g
.37738 .79602 m
.3781 .79829 L
s
.39838 1.00544 m .38105 1.001 L .37878 1.00283 L 0 1 .539 r
F
.39838 1.00544 m .38946 1.00212 L .38105 1.001 L F
.40339 1.00063 m .38946 1.00212 L .39838 1.00544 L 0 1 .54 r
F
0 g
.39838 1.00544 m
.40647 1.00645 L
s
.39838 1.00544 m
.40086 1.00732 L
s
.43336 .80588 m .42126 .8052 L .42223 .8095 L 0 1 .491 r
F
0 g
.41679 .809 m
.42223 .8095 L
s
.46861 .58025 m .46534 .56546 L .46144 .56912 L 0 1 .315 r
F
0 g
.46465 .5661 m
.46534 .56546 L
s
.43432 .81019 m
.43948 .81022 L
s
.44821 .75474 m .44471 .75973 L .44783 .75656 L 0 1 .35 r
F
.44821 .75474 m .44016 .76247 L .44471 .75973 L F
0 g
.44471 .75973 m
.4448 .76157 L
s
.28374 .79449 m .27937 .8035 L .28343 .80215 L 0 1 .476 r
F
.28374 .79449 m .27344 .79773 L .27937 .8035 L F
0 g
.27937 .8035 m
.27983 .80968 L
s
.28343 .80215 m
.28473 .80324 L
s
.52939 .63276 m .53839 .60072 L .53742 .59956 L 0 1 .307 r
F
0 g
.53742 .59956 m
.53773 .59682 L
s
.52939 .63276 m .53654 .61139 L .53839 .60072 L 0 1 .307 r
F
0 g
.53839 .60072 m
.53957 .59625 L
s
.52931 .61839 m
.53058 .61518 L
s
.5371 .60814 m
.53839 .60072 L
s
.47482 .80799 m .47061 .81728 L .475 .81617 L 0 1 .472 r
F
.47482 .80799 m .46631 .81498 L .47061 .81728 L F
0 g
.47061 .81728 m
.47268 .82166 L
s
.44632 .93062 m .44898 .93355 L .45038 .93131 L 0 1 .476 r
F
.44632 .93062 m .44253 .93608 L .44898 .93355 L F
0 g
.44898 .93355 m
.45352 .93385 L
s
.49533 .6185 m .4885 .60866 L .49215 .61562 L 0 .997 .298 r
F
.49397 .62641 m .4885 .60866 L .48518 .60679 L 0 .989 .3 r
F
.49397 .62641 m .49215 .61562 L .4885 .60866 L F
0 g
.48645 .60005 m
.4885 .60866 L
s
.48815 .60846 m
.4885 .60866 L
s
.31408 .8087 m .29971 .79667 L .29993 .80405 L 0 1 .469 r
F
.31408 .8087 m .30378 .79527 L .29971 .79667 L F
.31408 .8087 m .30995 .80043 L .30378 .79527 L F
0 g
.31408 .8087 m
.31414 .81068 L
s
.32614 .80396 m .30995 .80043 L .31409 .8087 L 0 1 .464 r
F
0 g
.31409 .8087 m
.31591 .80999 L
s
.67599 .95741 m
.67826 .9552 L
s
.51727 .66431 m .51683 .66526 L .51749 .66339 L 0 0 0 r
F
.80092 .59673 m .8055 .59981 L .81015 .60324 L F
0 g
.80163 .59909 m
.80521 .59976 L
s
.80092 .59673 m .80155 .59703 L .8055 .59981 L 0 0 0 r
F
.50207 .89468 m .49046 .90459 L .49486 .90328 L 0 1 .403 r
F
0 g
.48957 .90774 m
.49486 .90328 L
s
.49397 .62641 m .48518 .60679 L .4844 .61127 L 0 .989 .3 r
F
0 g
.48303 .60002 m
.48518 .60679 L
s
.48518 .60679 m
.48815 .60846 L
s
.46326 .56225 m .46387 .56003 L .46186 .55756 L 0 1 .318 r
F
0 g
.46387 .56003 m
.46679 .56003 L
s
.4624 .744 m .45252 .75172 L .45234 .75351 L 0 1 .328 r
F
0 g
.44783 .75656 m
.45234 .75351 L
s
.46861 .58025 m .46104 .5824 L .46472 .58392 L 0 1 .315 r
F
.46861 .58025 m .45963 .57605 L .46104 .5824 L F
.46861 .58025 m .46144 .56912 L .45963 .57605 L F
.25223 .82001 m .24846 .82552 L .25251 .82431 L 0 1 .536 r
F
0 g
.25251 .82431 m
.25304 .82448 L
s
.25223 .82001 m .24196 .82282 L .24846 .82552 L 0 1 .536 r
F
0 g
.24846 .82552 m
.24971 .82982 L
s
.39646 .9487 m .39695 .95351 L .39976 .95094 L 0 1 .505 r
F
.39646 .9487 m .38908 .95493 L .39695 .95351 L F
0 g
.39695 .95351 m
.40095 .95555 L
s
.47358 1.01116 m .46456 1.00992 L .457 1.01072 L 0 1 .54 r
F
0 g
.457 1.01072 m
.46456 1.00992 L
s
.47358 1.01116 m
.47986 1.01402 L
s
.38908 .95493 m .37095 .95703 L .37502 .95912 L 0 1 .516 r
F
0 g
.36697 .95986 m
.37502 .95912 L
s
.76577 .92577 m .77475 .92699 L .77781 .92103 L 0 1 .528 r
F
.79406 .7956 m .79001 .80349 L .79424 .8065 L 0 .775 .458 r
F
.79406 .7956 m .78992 .79882 L .79001 .80349 L F
0 g
.78292 .80427 m
.79001 .80349 L
s
.4844 .61127 m .47586 .59613 L .47481 .6016 L 0 1 .306 r
F
0 g
.47586 .59613 m
.47938 .59545 L
s
.4739 .58993 m
.47586 .59613 L
s
.44995 .80515 m .43837 .80585 L .43948 .81022 L 0 1 .483 r
F
.42563 .86966 m .41996 .87514 L .42582 .87835 L 0 .958 .441 r
F
.42563 .86966 m .4143 .86865 L .41996 .87514 L F
0 g
.41996 .87514 m
.42258 .8816 L
s
.37645 .99676 m .37878 1.00283 L .38105 1.001 L 0 1 .539 r
F
.37645 .99676 m .37048 1.00121 L .37878 1.00283 L F
0 g
.37878 1.00283 m
.38407 1.00681 L
s
.49892 .96342 m .5044 .97074 L .50458 .96932 L 0 .531 .409 r
F
.51832 .98099 m .5044 .97074 L .5104 .97727 L 0 .328 .31 r
F
.51832 .98099 m .50458 .96932 L .5044 .97074 L F
0 g
.50413 .97264 m
.51035 .97723 L
s
.49817 .96714 m
.5044 .97074 L
s
.50544 .82149 m .49994 .83048 L .50459 .83224 L 0 1 .463 r
F
.50544 .82149 m .49694 .82604 L .49994 .83048 L F
0 g
.49596 .8321 m
.49994 .83048 L
s
.39827 .80179 m .39558 .80829 L .39872 .80616 L 0 1 .503 r
F
.39827 .80179 m .39022 .80697 L .39558 .80829 L F
0 g
.39558 .80829 m
.39661 .81264 L
s
.53482 .60729 m
.53742 .59956 L
s
.42563 .86966 m .41195 .86217 L .4143 .86865 L 0 .958 .441 r
F
0 g
.40818 .86534 m
.4143 .86865 L
s
.31407 .96957 m .29389 .96721 L .29786 .97058 L 0 1 .531 r
F
.31407 .96957 m .29719 .96575 L .29389 .96721 L F
.31407 .96957 m .30585 .96677 L .29719 .96575 L F
.32176 .96554 m .30585 .96677 L .31407 .96957 L 0 1 .528 r
F
0 g
.31407 .96957 m
.32245 .97041 L
s
.31407 .96957 m
.31799 .97294 L
s
.72168 .94352 m .72223 .95123 L .73011 .94786 L 0 1 .537 r
F
0 g
.71398 .95233 m
.72223 .95123 L
s
.7187 .95514 m
.72223 .95123 L
s
.53233 .63869 m .54257 .61203 L .54183 .60905 L 0 1 .311 r
F
0 g
.54183 .60905 m
.54247 .6047 L
s
.48157 .72206 m .47331 .73134 L .47297 .73302 L 0 1 .208 r
F
.67797 1.07974 m .68372 1.08182 L .6904 1.08058 L 0 1 .379 r
F
0 g
.52913 .55622 m
.5302 .54409 L
s
.5302 .54409 m
.53078 .5375 L
s
.53078 .5375 m
.53151 .52924 L
s
.50646 .89338 m
.51113 .8887 L
s
.69458 .94617 m .7061 .94752 L .70294 .94556 L 0 1 .536 r
F
.68691 .9409 m .69458 .94617 L .69819 .94255 L 0 1 .534 r
F
.40694 .78297 m .39454 .78605 L .39472 .78814 L 0 1 .466 r
F
.40694 .78297 m .39811 .7839 L .39454 .78605 L F
.40694 .78297 m .40342 .78258 L .39811 .7839 L F
.41538 .77696 m .40342 .78258 L .40694 .78297 L 0 1 .442 r
F
0 g
.40694 .78297 m
.41204 .7814 L
s
.40694 .78297 m
.4071 .78505 L
s
.4395 .88553 m .42871 .88476 L .43473 .8911 L 0 .9 .441 r
F
.4395 .88553 m .42582 .87835 L .42871 .88476 L F
0 g
.42258 .8816 m
.42871 .88476 L
s
.47482 .80799 m .46457 .81058 L .46631 .81498 L 0 1 .472 r
F
0 g
.4616 .8158 m
.46631 .81498 L
s
.47592 1.00364 m .47358 1.01116 L .48092 1.00976 L 0 1 .541 r
F
.47592 1.00364 m .46456 1.00992 L .47358 1.01116 L F
.77773 .57868 m .78994 .58791 L .78933 .58831 L 0 .096 0 r
F
0 g
.78994 .58791 m
.79388 .5905 L
s
.7869 .58433 m
.78994 .58791 L
s
.4972 .69899 m .49463 .70408 L .49663 .70045 L 0 .875 .137 r
F
.4972 .69899 m .49191 .70815 L .49463 .70408 L F
.50039 .69452 m .49663 .70045 L .49463 .70408 L 0 .913 .15 r
F
0 g
.49223 .70767 m
.49463 .70408 L
s
.49444 .70531 m
.49463 .70408 L
s
.4708 .9206 m
.47378 .91861 L
s
.48524 .90831 m .47231 .91727 L .47665 .91669 L 0 1 .435 r
F
0 g
.47231 .91727 m
.47665 .91669 L
s
.47378 .91861 m
.47665 .91669 L
s
.79406 .7956 m .79424 .8065 L .80064 .80619 L 0 .775 .458 r
F
0 g
.79334 .81193 m
.79424 .8065 L
s
.49191 .70815 m .48722 .71417 L .48482 .718 L 0 1 .183 r
F
.49191 .70815 m .49026 .70994 L .48722 .71417 L F
.4972 .69899 m .49026 .70994 L .49191 .70815 L 0 .875 .137 r
F
0 g
.49165 .70968 m
.49191 .70815 L
s
.49191 .70815 m
.49223 .70767 L
s
.40614 .85878 m .40091 .85211 L .39485 .84861 L 0 1 .447 r
F
.76659 .94618 m .75933 .95601 L .7678 .95393 L 0 1 .538 r
F
.76659 .94618 m .75589 .95446 L .75933 .95601 L F
0 g
.75526 .9602 m
.75933 .95601 L
s
.50423 .64481 m .49593 .61538 L .49533 .6185 L 0 .875 .293 r
F
.50423 .64481 m .49889 .62175 L .49593 .61538 L F
0 g
.49653 .61231 m
.49801 .61821 L
s
.49741 .60834 m
.49909 .61834 L
s
.49499 .61143 m
.49593 .61538 L
s
.49593 .61538 m
.49609 .61571 L
s
.68929 .52783 m .69539 .55648 L .69126 .55115 L 0 .631 .154 r
F
.68929 .52783 m .69977 .5447 L .69539 .55648 L F
0 g
.68929 .52783 m
.69126 .55115 L
s
.68506 .54208 m
.68929 .52783 L
s
.26316 .80092 m .24868 .78665 L .24867 .79461 L 0 1 .483 r
F
.26316 .80092 m .25292 .78553 L .24868 .78665 L F
.26316 .80092 m .25913 .79165 L .25292 .78553 L F
.27344 .79773 m .25913 .79165 L .26316 .80092 L 0 1 .48 r
F
0 g
.26314 .80884 m
.26316 .80092 L
s
.26316 .80092 m
.26922 .80685 L
s
.49733 1.00423 m .50336 1.01055 L .5036 1.00692 L 0 1 .537 r
F
.51888 1.00092 m .5036 1.00692 L .50336 1.01055 L 0 1 .517 r
F
0 g
.50336 1.01055 m
.51007 1.01288 L
s
.49633 1.01292 m
.50336 1.01055 L
s
.46822 .48547 m .46145 .49441 L .46365 .49339 L 0 1 .16 r
F
.46822 .48547 m .46306 .48821 L .46145 .49441 L F
0 g
.46452 .49616 m
.46693 .4924 L
s
.46822 .48547 m .46741 .47893 L .46306 .48821 L 0 1 .16 r
F
.46822 .48547 m .47198 .47103 L .46741 .47893 L F
0 g
.46693 .4924 m
.46822 .48547 L
s
.33574 .80747 m
.33583 .80751 L
s
.49968 .959 m .49121 .95699 L .49892 .96342 L 0 .518 .407 r
F
.49968 .959 m .48588 .95082 L .49121 .95699 L F
0 g
.48499 .95341 m
.49121 .95699 L
s
.50713 .63339 m .50754 .63226 L .50625 .61858 L 0 .851 .289 r
F
.55526 .51872 m .56275 .50502 L .5653 .51699 L 0 .295 .159 r
F
0 g
.56275 .50502 m
.56303 .48172 L
s
.55846 .50577 m
.56275 .50502 L
s
.48153 .94296 m .48588 .95082 L .48647 .949 L 0 .693 .441 r
F
.49968 .959 m .48647 .949 L .48588 .95082 L 0 .518 .407 r
F
0 g
.48588 .95082 m
.49121 .95699 L
s
.47975 .9476 m
.48588 .95082 L
s
.4624 .744 m .45565 .74842 L .45252 .75172 L 0 1 .328 r
F
.4624 .744 m .45989 .74511 L .45565 .74842 L F
.46961 .73509 m .45989 .74511 L .4624 .744 L 0 1 .25 r
F
0 g
.4624 .744 m
.46637 .74046 L
s
.46221 .74579 m
.4624 .744 L
s
.46914 .73684 m
.47297 .73302 L
s
.32998 .94386 m .31082 .94702 L .31433 .94821 L 0 1 .37 r
F
.32998 .94386 m .31413 .94547 L .31082 .94702 L F
.32998 .94386 m .32236 .94411 L .31413 .94547 L F
.3377 .93948 m .32236 .94411 L .32998 .94386 L 0 1 .335 r
F
0 g
.32998 .94386 m
.33792 .94229 L
s
.32998 .94386 m
.33344 .94505 L
s
.42539 1.00761 m .41647 1.00498 L .40836 1.00448 L 0 1 .54 r
F
.42941 1.00243 m .42539 1.00761 L .43319 1.00799 L F
.42941 1.00243 m .41647 1.00498 L .42539 1.00761 L F
0 g
.42539 1.00761 m
.43096 1.01118 L
s
.46326 .56225 m .45686 .56224 L .46026 .5632 L 0 1 .318 r
F
.46326 .56225 m .45484 .55977 L .45686 .56224 L F
.46326 .56225 m .45555 .55744 L .45484 .55977 L F
.46326 .56225 m .45856 .55649 L .45555 .55744 L F
.46326 .56225 m .46186 .55756 L .45856 .55649 L F
0 g
.46186 .55756 m
.46387 .56003 L
s
.46026 .5632 m
.46326 .56225 L
s
.46326 .56225 m
.46534 .56546 L
s
.46186 .55755 m
.46186 .55755 L
s
.46186 .55755 m
.46591 .55278 L
s
.46745 .92051 m
.4708 .9206 L
s
.48476 .81294 m .48583 .82133 L .48694 .81736 L 0 1 .469 r
F
.495 .81745 m .48694 .81736 L .48583 .82133 L 0 1 .466 r
F
0 g
.48583 .82133 m
.48843 .82575 L
s
.48165 .8227 m
.48583 .82133 L
s
.47481 .6016 m .47023 .58715 L .46649 .58969 L 0 1 .313 r
F
0 g
.46861 .58025 m
.47023 .58715 L
s
.44253 .93608 m .42856 .93965 L .42678 .94175 L 0 1 .493 r
F
.44253 .93608 m .43532 .93721 L .42856 .93965 L F
.44632 .93062 m .43532 .93721 L .44253 .93608 L 0 1 .476 r
F
0 g
.44253 .93608 m
.44688 .93696 L
s
.44253 .93608 m
.44898 .93355 L
s
.4395 .88553 m .43473 .8911 L .44059 .89418 L 0 .9 .441 r
F
0 g
.43473 .8911 m
.4379 .89746 L
s
.50544 .82149 m .50459 .83224 L .50823 .83029 L 0 1 .463 r
F
0 g
.50459 .83224 m
.50793 .83665 L
s
.80496 .80274 m .80059 .81087 L .80481 .81367 L 0 .834 .469 r
F
.80496 .80274 m .80064 .80619 L .80059 .81087 L F
0 g
.79334 .81193 m
.80059 .81087 L
s
.41267 .85346 m .40614 .85878 L .41195 .86217 L 0 1 .44 r
F
.41267 .85346 m .40091 .85211 L .40614 .85878 L F
0 g
.40614 .85878 m
.40818 .86534 L
s
.54986 .6692 m .55527 .64513 L .55786 .56174 L 0 .831 .236 r
F
0 g
.55786 .56174 m
.55802 .51825 L
s
.55786 .56174 m
.56145 .53244 L
s
.5123 .6748 m .5123 .67361 L .5125 .67387 L 0 0 0 r
F
.51347 .67235 m .5125 .67387 L .5123 .67361 L F
0 g
.5123 .67361 m
.51285 .67202 L
s
.51145 .67473 m
.5123 .67361 L
s
.39022 .80697 m .37722 .80347 L .37789 .80793 L 0 1 .506 r
F
.53233 .63869 m .54016 .62242 L .54257 .61203 L 0 1 .311 r
F
0 g
.54033 .62167 m
.54047 .62109 L
s
.54047 .62109 m
.54048 .62105 L
s
.54048 .62105 m
.54048 .62102 L
s
.54048 .62102 m
.54078 .61974 L
s
.54078 .61974 m
.54141 .61701 L
s
.54141 .61701 m
.54167 .61593 L
s
.54167 .61593 m
.54205 .61425 L
s
.54205 .61425 m
.54235 .613 L
s
.54235 .613 m
.54257 .61203 L
s
.54257 .61203 m
.54308 .61075 L
s
.54016 .62242 m
.54021 .62221 L
s
.54021 .62221 m
.54054 .62093 L
s
.54054 .62093 m
.54068 .62042 L
s
.54068 .62042 m
.54104 .619 L
s
.54104 .619 m
.54332 .61022 L
s
.53901 .61489 m
.53966 .61354 L
s
.53993 .613 m
.54183 .60905 L
s
.50913 .67906 m .50821 .68074 L .50668 .68385 L 0 .843 .114 r
F
.37048 1.00121 m .35309 .99548 L .35046 .99717 L 0 1 .539 r
F
.37048 1.00121 m .36169 .99722 L .35309 .99548 L F
.37645 .99676 m .36169 .99722 L .37048 1.00121 L F
0 g
.37048 1.00121 m
.37537 1.00558 L
s
.37048 1.00121 m
.37878 1.00283 L
s
.52987 .99651 m
.52993 .99641 L
s
.5313 .99427 m
.53177 .99352 L
s
.52558 1.00326 m
.52783 .99972 L
s
.52783 .99972 m
.52814 .99923 L
s
.52814 .99923 m
.52888 .99806 L
s
.52888 .99806 m
.52918 .9976 L
s
.52918 .9976 m
.5294 .99725 L
s
.36319 .80612 m
.36871 .80809 L
s
.36871 .80809 m
.36959 .81264 L
s
.36319 .80612 m
.36362 .8108 L
s
.52806 .99571 m
.52826 .99559 L
s
.52883 .99525 m
.52902 .99514 L
s
.53102 .99396 m
.53177 .99352 L
s
.52684 .99643 m
.52783 .99584 L
s
.52783 .99584 m
.52806 .99571 L
s
.52264 .39367 m .51835 .40977 L .5182 .40441 L 0 .161 .102 r
F
.52264 .39367 m .52337 .40838 L .51835 .40977 L F
.52264 .39367 m .5299 .40117 L .52337 .40838 L F
.52264 .39367 m .53432 .39043 L .5299 .40117 L F
.51832 .98099 m .5104 .97727 L .5186 .98457 L 0 .328 .31 r
F
0 g
.5044 .97074 m
.5104 .97727 L
s
.51035 .97723 m
.5104 .97727 L
s
.50039 .69452 m .4991 .69635 L .49663 .70045 L 0 .913 .15 r
F
.50464 .68706 m .50039 .69452 L .50254 .69099 L 0 0 0 r
F
.50464 .68706 m .4991 .69635 L .50039 .69452 L F
0 g
.50019 .69575 m
.50039 .69452 L
s
.50039 .69452 m
.50095 .69361 L
s
.2423 .815 m .22696 .80406 L .22733 .81045 L 0 1 .526 r
F
.2423 .815 m .23119 .80305 L .22696 .80406 L F
.2423 .815 m .23777 .80775 L .23119 .80305 L F
.25256 .81203 m .23777 .80775 L .2423 .815 L F
0 g
.2423 .815 m
.24872 .81947 L
s
.2423 .815 m
.24265 .82135 L
s
.2317 .82561 m .21643 .82299 L .22146 .82838 L 0 1 .539 r
F
0 g
.22146 .82838 m
.22825 .83152 L
s
.536 .42472 m .5475 .40548 L .54389 .41743 L 0 0 .08 r
F
0 g
.5475 .40548 m
.55263 .39819 L
s
.80496 .80274 m .80481 .81367 L .81135 .81302 L 0 .834 .469 r
F
0 g
.80373 .81909 m
.80481 .81367 L
s
.41611 .80464 m .40355 .80284 L .40424 .8072 L 0 1 .497 r
F
0 g
.39872 .80616 m
.40419 .80719 L
s
.40419 .80719 m
.40424 .8072 L
s
.51114 .67721 m .50913 .67906 L .51032 .67742 L 0 0 0 r
F
.51114 .67721 m .50821 .68074 L .50913 .67906 L F
.47482 .80799 m .475 .81617 L .47656 .8124 L 0 1 .472 r
F
.48476 .81294 m .47656 .8124 L .475 .81617 L 0 1 .469 r
F
0 g
.475 .81617 m
.47719 .82058 L
s
.47061 .81728 m
.475 .81617 L
s
.48786 .71251 m .48482 .718 L .48722 .71417 L 0 .941 .173 r
F
.48786 .71251 m .48157 .72206 L .48482 .718 L F
0 g
.48457 .71953 m
.48482 .718 L
s
.31402 .81073 m .29948 .80333 L .29977 .80868 L 0 1 .521 r
F
.31402 .81073 m .30355 .80199 L .29948 .80333 L F
.31402 .81073 m .30979 .80516 L .30355 .80199 L F
0 g
.31402 .81073 m
.31412 .81269 L
s
.32608 .80603 m .30979 .80516 L .31402 .81073 L 0 1 .519 r
F
0 g
.31402 .81073 m
.31657 .81175 L
s
.29448 .9515 m .29432 .95481 L .29761 .95325 L 0 1 .389 r
F
0 g
.29761 .95325 m
.30632 .95232 L
s
.29448 .9515 m .28602 .95518 L .29432 .95481 L 0 1 .389 r
F
0 g
.29432 .95481 m
.29833 .95642 L
s
.27342 .81836 m
.2796 .82003 L
s
.42941 1.00243 m .43319 1.00799 L .43467 1.00587 L 0 1 .54 r
F
.4512 1.00758 m .43467 1.00587 L .43319 1.00799 L 0 1 .541 r
F
0 g
.43319 1.00799 m
.439 1.01113 L
s
.42539 1.00761 m
.43319 1.00799 L
s
.27312 .80601 m .26898 .81313 L .27304 .81185 L 0 1 .524 r
F
.27312 .80601 m .26284 .80904 L .26898 .81313 L F
0 g
.26898 .81313 m
.26979 .81895 L
s
.27304 .81185 m
.27977 .81557 L
s
.44016 .76247 m .42897 .76826 L .42885 .77016 L 0 1 .401 r
F
.44016 .76247 m .43241 .76546 L .42897 .76826 L F
.44016 .76247 m .43721 .76298 L .43241 .76546 L F
.44821 .75474 m .43721 .76298 L .44016 .76247 L 0 1 .35 r
F
0 g
.44016 .76247 m
.44471 .75973 L
s
.44003 .76437 m
.44016 .76247 L
s
.495 .81745 m .49694 .82604 L .4976 .82189 L 0 1 .466 r
F
.50544 .82149 m .4976 .82189 L .49694 .82604 L 0 1 .463 r
F
0 g
.49694 .82604 m
.49994 .83048 L
s
.49301 .8277 m
.49694 .82604 L
s
.39022 .80697 m .38062 .80159 L .37722 .80347 L 0 1 .506 r
F
0 g
.37211 .80626 m
.37789 .80793 L
s
.39022 .80697 m .3862 .80309 L .38062 .80159 L 0 1 .506 r
F
.39827 .80179 m .3862 .80309 L .39022 .80697 L 0 1 .503 r
F
0 g
.39022 .80697 m
.39558 .80829 L
s
.39022 .80697 m
.39087 .81143 L
s
.38908 .95493 m .37361 .95514 L .37095 .95703 L 0 1 .516 r
F
.38908 .95493 m .38139 .95424 L .37361 .95514 L F
0 g
.38908 .95493 m
.39312 .95702 L
s
.39646 .9487 m .38139 .95424 L .38908 .95493 L 0 1 .505 r
F
0 g
.38908 .95493 m
.39695 .95351 L
s
.46001 .81142 m .45591 .80897 L .45105 .80953 L 0 1 .481 r
F
.70475 .93437 m .70598 .94192 L .71142 .93975 L 0 1 .533 r
F
.71142 .93974 m .71142 .93975 L .71143 .93975 L F
.70475 .93437 m .71142 .93975 L .71142 .93974 L F
.71354 .93524 m .71321 .93844 L .71603 .93443 L 0 1 .5 r
F
.70475 .93437 m .71143 .93975 L .71144 .93973 L 0 1 .533 r
F
.70475 .93437 m .71145 .93974 L .71194 .93832 L F
.70475 .93437 m .69819 .94255 L .70598 .94192 L F
.71321 .93844 m .71063 .94211 L .71406 .94472 L 0 1 .512 r
F
.71321 .93844 m .71406 .94472 L .72154 .93918 L F
.71321 .93844 m .72154 .93918 L .7246 .93485 L F
.71321 .93844 m .7246 .93485 L .72117 .93464 L F
.71348 .93526 m .71323 .93903 L .71607 .93552 L 0 1 .533 r
F
.70475 .93437 m .71198 .93835 L .71348 .93526 L F
.71378 .93464 m .71603 .93443 L .71391 .93439 L 0 1 .5 r
F
.71348 .93526 m .71362 .93521 L .71378 .93464 L F
.71362 .93521 m .71603 .93443 L .71378 .93464 L F
.72062 .92397 m .71603 .93443 L .72334 .92983 L 0 1 .505 r
F
.72062 .92397 m .71383 .93276 L .71603 .93443 L F
.71376 .93285 m .71258 .93373 L .71385 .93439 L 0 1 .528 r
F
.70475 .93437 m .71379 .93529 L .71258 .93373 L 0 1 .533 r
F
.71379 .93529 m .71607 .93552 L .71385 .93439 L F
.71348 .93526 m .71391 .93439 L .71385 .93439 L 0 1 .5 r
F
.71358 .93502 m .71385 .93439 L .71258 .93373 L 0 1 .533 r
F
.71348 .93526 m .71385 .93439 L .7126 .93436 L 0 1 .5 r
F
.71379 .93529 m .71385 .93439 L .71358 .93502 L 0 1 .533 r
F
.72062 .92397 m .71456 .92988 L .71408 .93097 L 0 1 .505 r
F
.72062 .92397 m .71408 .93097 L .71397 .93258 L F
.72074 .92766 m .71457 .93037 L .71371 .93183 L 0 1 .528 r
F
.71376 .93285 m .71371 .93183 L .71258 .93373 L F
.71397 .93258 m .71408 .93097 L .71371 .93183 L 0 1 .505 r
F
.71397 .93258 m .71371 .93183 L .71376 .93285 L F
.72074 .92766 m .71371 .93183 L .71376 .93285 L 0 1 .528 r
F
.71376 .93285 m .71371 .93183 L .7126 .93436 L 0 1 .505 r
F
.7115 .92353 m .71381 .92456 L .71385 .92372 L 0 1 .524 r
F
.71381 .92456 m .71383 .92457 L .71385 .92372 L F
.71386 .9233 m .72239 .91983 L .71868 .92025 L 0 1 .492 r
F
.7115 .92353 m .70734 .931 L .71364 .93045 L 0 1 .524 r
F
.7115 .92353 m .71364 .93045 L .71365 .93037 L F
.7115 .92353 m .71367 .93045 L .71371 .92846 L F
.7115 .92353 m .71335 .92764 L .71302 .92421 L F
.71154 .92477 m .71385 .92372 L .71386 .9233 L 0 1 .492 r
F
.71385 .92372 m .72239 .91983 L .71386 .9233 L F
.71379 .92457 m .7139 .92456 L .71381 .92374 L F
.7139 .92456 m .72062 .92397 L .71385 .92374 L F
.7139 .92456 m .71385 .92374 L .71381 .92374 L F
.71385 .92372 m .72062 .92397 L .72239 .91983 L F
.71384 .92374 m .72062 .92397 L .71385 .92372 L F
.72062 .92397 m .72334 .92983 L .72968 .92361 L 0 1 .505 r
F
.72062 .92397 m .72968 .92361 L .73167 .91912 L F
.71383 .92457 m .71456 .92988 L .72062 .92397 L 0 1 .492 r
F
.71302 .92421 m .71375 .92712 L .71383 .92457 L 0 1 .524 r
F
.71371 .92846 m .71456 .92988 L .71383 .92457 L 0 1 .492 r
F
.71335 .92764 m .71457 .93037 L .71302 .92421 L 0 1 .524 r
F
.71154 .92477 m .71371 .92846 L .71383 .92457 L 0 1 .492 r
F
.71383 .92457 m .71376 .92714 L .71384 .92458 L 0 1 .524 r
F
.71375 .92712 m .71376 .92714 L .71383 .92457 L F
.72062 .92397 m .73167 .91912 L .72796 .91934 L 0 1 .505 r
F
.71382 .92332 m .72254 .92445 L .71876 .92289 L 0 1 .524 r
F
.7115 .92353 m .71385 .92372 L .71382 .92332 L F
.71385 .92372 m .72254 .92445 L .71382 .92332 L F
.71385 .92372 m .72074 .92766 L .72254 .92445 L F
.71383 .92457 m .72074 .92766 L .71385 .92372 L F
.71381 .92374 m .71384 .92374 L .71385 .92372 L 0 1 .492 r
F
.71154 .92477 m .71379 .92457 L .71381 .92374 L F
.71365 .93037 m .71364 .93045 L .71367 .93045 L 0 1 .524 r
F
.71371 .92846 m .71367 .93045 L .71456 .92988 L 0 1 .492 r
F
.71371 .92846 m .71367 .93045 L .71457 .93037 L 0 1 .524 r
F
.71371 .92846 m .71365 .93046 L .71367 .93045 L 0 1 .492 r
F
.71154 .92477 m .70744 .93439 L .71365 .93046 L F
.71154 .92477 m .71365 .93046 L .71371 .92846 L F
.71384 .92458 m .71457 .93037 L .72074 .92766 L 0 1 .524 r
F
.71376 .92714 m .71457 .93037 L .71384 .92458 L F
.71383 .93276 m .71376 .93285 L .71385 .93291 L 0 1 .505 r
F
.71383 .93276 m .71385 .93291 L .71603 .93443 L F
.71376 .93285 m .7126 .93436 L .71385 .93439 L F
.71376 .93285 m .71385 .93439 L .71603 .93443 L F
.71441 .93237 m .71376 .93285 L .71385 .93439 L 0 1 .528 r
F
.72074 .92766 m .71441 .93237 L .71607 .93552 L F
.71441 .93237 m .71385 .93439 L .71607 .93552 L F
.70486 .93807 m .71348 .93526 L .7126 .93436 L 0 1 .5 r
F
.71198 .93835 m .71206 .93839 L .71348 .93526 L 0 1 .533 r
F
.71348 .93526 m .71206 .93839 L .71354 .93524 L 0 1 .5 r
F
.71206 .93839 m .71321 .93844 L .71354 .93524 L F
.71055 .94222 m .7061 .94752 L .7088 .94723 L 0 1 .535 r
F
.71055 .94222 m .70294 .94556 L .7061 .94752 L F
.71055 .94222 m .70301 .94802 L .70613 .94851 L 0 1 .512 r
F
.71321 .93844 m .71124 .94029 L .71055 .94222 L F
.71124 .94029 m .70294 .94556 L .71055 .94222 L 0 1 .535 r
F
.71124 .94029 m .70301 .94802 L .71055 .94222 L 0 1 .512 r
F
.71323 .93903 m .71124 .94029 L .71055 .94222 L 0 1 .535 r
F
.71124 .94029 m .70604 .94371 L .70301 .94802 L 0 1 .512 r
F
.71321 .93844 m .71143 .93975 L .71124 .94029 L F
.71124 .94029 m .70598 .94192 L .70294 .94556 L 0 1 .535 r
F
.71143 .93975 m .70598 .94192 L .71124 .94029 L F
.71143 .93975 m .70604 .94371 L .71124 .94029 L 0 1 .512 r
F
.71323 .93903 m .71143 .93975 L .71124 .94029 L 0 1 .535 r
F
.71206 .93839 m .71323 .93903 L .71348 .93526 L 0 1 .533 r
F
.70486 .93807 m .71206 .93839 L .71348 .93526 L 0 1 .5 r
F
.70486 .93807 m .70604 .94371 L .71143 .93975 L F
.71206 .93839 m .71143 .93975 L .71321 .93844 L F
.70486 .93807 m .71143 .93975 L .71206 .93839 L F
.71144 .93973 m .71143 .93975 L .71145 .93974 L 0 1 .533 r
F
.71194 .93832 m .71145 .93974 L .71323 .93903 L F
.71063 .94211 m .71055 .94222 L .71058 .94224 L 0 1 .512 r
F
.71063 .94211 m .71058 .94224 L .71406 .94472 L F
.71055 .94222 m .70613 .94851 L .7088 .94723 L F
.71055 .94222 m .7088 .94723 L .71406 .94472 L F
.71323 .93903 m .71055 .94222 L .71412 .94665 L 0 1 .535 r
F
.71055 .94222 m .7088 .94723 L .71412 .94665 L F
0 g
.7088 .94723 m
.70884 .94723 L
s
.70477 .94879 m
.70522 .94837 L
s
.7108 .94933 m
.71257 .94682 L
s
.71392 .94492 m
.71406 .94472 L
s
.69458 .94617 m
.70294 .94556 L
s
.46526 .80262 m .46001 .81142 L .46457 .81058 L 0 1 .474 r
F
.46526 .80262 m .45591 .80897 L .46001 .81142 L F
0 g
.46001 .81142 m
.4616 .8158 L
s
.41267 .85346 m .39911 .84555 L .40091 .85211 L 0 1 .44 r
F
0 g
.39485 .84861 m
.40091 .85211 L
s
.49397 .62641 m .49449 .62323 L .49215 .61562 L 0 .989 .3 r
F
.48253 .44534 m .48764 .43528 L .49087 .4302 L 0 0 0 r
F
.47592 1.00364 m .45878 1.0069 L .46456 1.00992 L 0 1 .541 r
F
0 g
.45401 .91302 m
.45999 .91607 L
s
.7772 .71375 m .78689 .7114 L .7824 .70922 L 0 1 .484 r
F
.7772 .71375 m .78832 .71926 L .78689 .7114 L F
0 g
.77567 .70583 m
.7772 .71375 L
s
.38191 .82466 m .3796 .83329 L .38273 .83138 L 0 1 .444 r
F
.38191 .82466 m .37388 .82933 L .3796 .83329 L F
.39341 .84196 m .38273 .83138 L .3796 .83329 L 0 1 .446 r
F
0 g
.3796 .83329 m
.38105 .83994 L
s
.4844 .61127 m .47695 .60838 L .48087 .61195 L 0 1 .306 r
F
.4844 .61127 m .47481 .6016 L .47695 .60838 L F
.49397 .62641 m .4844 .61127 L .48674 .61888 L 0 .989 .3 r
F
.37388 .82933 m .36345 .81807 L .36005 .81981 L 0 1 .45 r
F
.37388 .82933 m .36937 .82216 L .36345 .81807 L F
.38191 .82466 m .36937 .82216 L .37388 .82933 L 0 1 .444 r
F
0 g
.37388 .82933 m
.3796 .83329 L
s
.37388 .82933 m
.37491 .83611 L
s
.51615 .6667 m .51569 .66768 L .516 .66662 L 0 0 0 r
F
0 g
.516 .66662 m
.516 .66662 L
s
.516 .66662 m
.516 .66662 L
s
.27759 .95887 m .25712 .95874 L .26077 .96092 L 0 1 .434 r
F
.27759 .95887 m .2607 .95747 L .25712 .95874 L F
.27759 .95887 m .26949 .95752 L .2607 .95747 L F
.28602 .95518 m .26949 .95752 L .27759 .95887 L 0 1 .413 r
F
0 g
.27759 .95887 m
.28118 .96104 L
s
.27759 .95887 m
.2861 .9587 L
s
.42419 .77043 m .42037 .77505 L .42381 .77237 L 0 1 .408 r
F
.42419 .77043 m .41538 .77695 L .42037 .77505 L F
0 g
.42037 .77505 m
.42051 .77704 L
s
.42381 .77237 m
.42885 .77016 L
s
.50423 .64481 m .49533 .6185 L .49762 .62837 L 0 .875 .293 r
F
0 g
.49215 .61562 m
.49533 .6185 L
s
.49609 .61571 m
.49764 .61906 L
s
.49674 .61135 m
.49931 .6197 L
s
.50464 .68706 m .50254 .69099 L .50411 .68811 L 0 0 0 r
F
.50685 .68318 m .50411 .68811 L .50254 .69099 L 0 .803 .102 r
F
0 g
.50237 .69165 m
.50254 .69099 L
s
.50095 .69361 m
.50254 .69099 L
s
.50668 .68385 m
.50804 .68108 L
s
.48157 .72206 m .47609 .72763 L .47331 .73134 L 0 1 .208 r
F
.48157 .72206 m .47964 .72364 L .47609 .72763 L F
.48786 .71251 m .47964 .72364 L .48157 .72206 L 0 .941 .173 r
F
0 g
.48123 .72374 m
.48157 .72206 L
s
.48157 .72206 m
.48482 .718 L
s
.51316 .68035 m .52168 .655 L .52199 .65441 L 0 0 .056 r
F
0 g
.52123 .6559 m
.52126 .65581 L
s
.51316 .68035 m .51898 .66289 L .52168 .655 L 0 0 .056 r
F
0 g
.52168 .655 m
.5217 .65496 L
s
.52123 .6559 m
.52123 .6559 L
s
.51316 .68035 m .52199 .65441 L .51951 .66184 L 0 0 .056 r
F
0 g
.52196 .65449 m
.52198 .65443 L
s
.52198 .65443 m
.52199 .65441 L
s
.52166 .65507 m
.52168 .655 L
s
.5212 .65596 m
.52121 .65594 L
s
.52121 .65594 m
.52123 .6559 L
s
.52199 .65441 m
.52199 .6544 L
s
.34545 .93511 m .3454 .93769 L .3484 .93586 L 0 1 .295 r
F
0 g
.3484 .93586 m
.35635 .9335 L
s
.34545 .93511 m .3377 .93948 L .3454 .93769 L 0 1 .295 r
F
0 g
.3454 .93769 m
.34912 .93831 L
s
.51316 .68035 m .5212 .65598 L .51898 .66289 L 0 0 .052 r
F
.51316 .68035 m .52086 .65668 L .5212 .65598 L F
0 g
.52088 .65661 m
.5222 .65279 L
s
.52088 .65663 m
.52088 .65663 L
s
.52088 .65663 m
.52088 .65663 L
s
.52088 .65663 m
.52088 .65661 L
s
.5212 .65598 m
.5212 .65596 L
s
.42563 .86966 m .42582 .87835 L .42798 .87614 L 0 .958 .441 r
F
.4395 .88553 m .42798 .87614 L .42582 .87835 L 0 .9 .441 r
F
0 g
.42582 .87835 m
.42871 .88476 L
s
.41996 .87514 m
.42582 .87835 L
s
.53221 .59136 m
.53289 .58852 L
s
.45413 .90115 m .44399 .90052 L .45032 .90675 L 0 .831 .44 r
F
.45413 .90115 m .44059 .89418 L .44399 .90052 L F
0 g
.4379 .89746 m
.44399 .90052 L
s
.51316 .68035 m .52242 .6536 L .52268 .65313 L 0 0 .058 r
F
.51316 .68035 m .51951 .66184 L .52242 .6536 L F
0 g
.52242 .6536 m
.52242 .6536 L
s
.52192 .65462 m
.52196 .65449 L
s
.52163 .65515 m
.52166 .65507 L
s
.52087 .65666 m
.52088 .65663 L
s
.52118 .65603 m
.5212 .65598 L
s
.52115 .65613 m
.52118 .65603 L
s
.52241 .65361 m
.52242 .6536 L
s
.50526 .6399 m .49932 .61971 L .50256 .63185 L 0 .87 .292 r
F
0 g
.49909 .61834 m
.49932 .61971 L
s
.50483 .64177 m .50256 .63185 L .49932 .61971 L 0 .876 .293 r
F
0 g
.49931 .6197 m
.49932 .61971 L
s
.45794 .54984 m .4604 .54205 L .46003 .5359 L 0 1 .313 r
F
0 g
.4604 .54205 m
.46446 .53729 L
s
.51316 .68035 m .51838 .66412 L .52086 .65668 L 0 0 .052 r
F
0 g
.52085 .65671 m
.52085 .65669 L
s
.52085 .65669 m
.52086 .65668 L
s
.5204 .65759 m
.52193 .65342 L
s
.5204 .65759 m
.5204 .65759 L
s
.5204 .65759 m
.5204 .65759 L
s
.52086 .65668 m
.52087 .65666 L
s
.33537 .80725 m .33176 .80885 L .33538 .80732 L 0 1 .459 r
F
.33535 .80027 m .33181 .80872 L .33537 .80725 L F
.33181 .80872 m .33176 .80885 L .33537 .80725 L F
.33537 .80721 m .33176 .80885 L .33538 .80732 L 0 1 .518 r
F
.33529 .80238 m .33186 .80866 L .33537 .80721 L F
.33186 .80866 m .33176 .80885 L .33537 .80721 L F
.34444 .80338 m .34081 .80501 L .34444 .80346 L 0 1 .453 r
F
.34456 .7965 m .34086 .80489 L .34444 .80338 L F
.34086 .80489 m .34081 .80501 L .34444 .80338 L F
.3538 .79264 m .34988 .8011 L .35351 .79951 L 0 1 .448 r
F
.35374 .79483 m .34988 .8011 L .35351 .79951 L 0 1 .514 r
F
.3538 .79264 m .34456 .7965 L .34988 .8011 L 0 1 .448 r
F
.35374 .79483 m .3445 .79865 L .34988 .8011 L 0 1 .514 r
F
.35368 .79703 m .34445 .80081 L .34985 .8011 L 0 1 .494 r
F
.3499 .80107 m .34985 .8011 L .34988 .8011 L F
.35368 .79703 m .34985 .8011 L .3499 .80107 L F
.3445 .79865 m .34081 .80501 L .34444 .80346 L 0 1 .516 r
F
.34456 .7965 m .33535 .80027 L .34081 .80501 L 0 1 .453 r
F
.3445 .79865 m .33529 .80238 L .34081 .80501 L 0 1 .516 r
F
.34445 .80081 m .33523 .8045 L .34075 .80501 L 0 1 .504 r
F
.3408 .80499 m .34075 .80501 L .34078 .80501 L F
.34445 .80081 m .34075 .80501 L .3408 .80499 L F
.34083 .80499 m .34078 .80501 L .34081 .80501 L F
.34445 .80081 m .34078 .80501 L .34083 .80499 L F
.33535 .80027 m .32614 .80396 L .33176 .80885 L 0 1 .459 r
F
.33529 .80238 m .32608 .80603 L .33176 .80885 L 0 1 .518 r
F
.33523 .8045 m .33176 .80885 L .33538 .80732 L 0 1 .512 r
F
0 g
.33538 .80732 m
.33543 .80733 L
s
.33538 .80732 m
.33574 .80747 L
s
.33523 .8045 m .32602 .80811 L .33176 .80885 L 0 1 .512 r
F
0 g
.33176 .80885 m
.33176 .80888 L
s
.33173 .80884 m
.33176 .80885 L
s
.3317 .80884 m
.33173 .80884 L
s
.53323 .60348 m
.53405 .60072 L
s
.64784 1.07876 m
.64861 1.07881 L
s
.64783 1.07833 m
.64848 1.07826 L
s
.47481 .6016 m .46714 .60209 L .47107 .60416 L 0 1 .313 r
F
.47481 .6016 m .46518 .59589 L .46714 .60209 L F
.47481 .6016 m .46649 .58969 L .46518 .59589 L F
0 g
.2328 .79216 m
.23823 .79754 L
s
.51316 .68035 m .52268 .65313 L .51998 .66101 L 0 0 .058 r
F
0 g
.52267 .65316 m
.52268 .65313 L
s
.52001 .65841 m
.52001 .65841 L
s
.52001 .65841 m
.52001 .65841 L
s
.52001 .65841 m
.52097 .65572 L
s
.52036 .6577 m
.52036 .6577 L
s
.52036 .6577 m
.52036 .65769 L
s
.52036 .6577 m
.52036 .6577 L
s
.52036 .65769 m
.5204 .65759 L
s
.52081 .65681 m
.52085 .65671 L
s
.52076 .65696 m
.52081 .65681 L
s
.52232 .65387 m
.52241 .65361 L
s
.52111 .65626 m
.52115 .65613 L
s
.52158 .6553 m
.52163 .65515 L
s
.52184 .65485 m
.52192 .65462 L
s
.52268 .65313 m
.52268 .65312 L
s
.45038 .93131 m
.45672 .92812 L
s
.41267 .85346 m .41195 .86217 L .41446 .86001 L 0 1 .44 r
F
.42563 .86966 m .41446 .86001 L .41195 .86217 L 0 .958 .441 r
F
0 g
.41195 .86217 m
.4143 .86865 L
s
.40614 .85878 m
.41195 .86217 L
s
.33538 .80732 m
.33556 .80747 L
s
.52516 .99113 m
.52643 .99296 L
s
.52826 .99559 m
.52861 .9961 L
s
.69471 .95091 m .70613 .94851 L .70301 .94802 L 0 1 .508 r
F
0 g
.70225 .95231 m
.70613 .94851 L
s
.70613 .94851 m
.70872 .94727 L
s
.70872 .94727 m
.70872 .94727 L
s
.70872 .94727 m
.7088 .94723 L
s
.7139 .9448 m
.71406 .94472 L
s
.36307 .81124 m .36005 .81981 L .36345 .81807 L 0 1 .449 r
F
.36307 .81124 m .35441 .81547 L .36005 .81981 L F
0 g
.36005 .81981 m
.36109 .82659 L
s
.35643 .96195 m .33738 .96201 L .34133 .96467 L 0 1 .523 r
F
.51316 .68035 m .52032 .6578 L .51838 .66412 L 0 0 .048 r
F
.51316 .68035 m .51995 .65858 L .52032 .6578 L F
0 g
.51788 .6628 m
.51822 .66196 L
s
.51999 .65848 m
.51999 .65848 L
s
.51999 .65848 m
.52001 .65841 L
s
.51999 .65848 m
.51999 .65848 L
s
.51998 .65851 m
.51999 .65848 L
s
.51954 .65938 m
.51954 .65938 L
s
.51954 .65938 m
.51954 .65938 L
s
.51954 .65938 m
.52062 .65653 L
s
.52032 .6578 m
.52036 .6577 L
s
.52032 .65781 m
.52032 .6578 L
s
.5203 .65786 m
.52032 .65781 L
s
.52029 .65789 m
.5203 .65786 L
s
.35643 .96195 m .34037 .96033 L .33738 .96201 L 0 1 .523 r
F
.35643 .96195 m .34855 .96031 L .34037 .96033 L F
.36332 .95738 m .34855 .96031 L .35643 .96195 L 0 1 .518 r
F
0 g
.35643 .96195 m
.36432 .96176 L
s
.35643 .96195 m
.36035 .9646 L
s
.54028 .62222 m
.54107 .621 L
s
.54153 .62029 m
.54298 .61803 L
s
.54107 .621 m
.54153 .62029 L
s
.51524 .66864 m .5151 .66894 L .51553 .66761 L 0 0 0 r
F
0 g
.51553 .66762 m
.51553 .66762 L
s
.48333 .93787 m .47436 .93675 L .48153 .94296 L 0 .663 .432 r
F
.48333 .93787 m .46974 .93054 L .47436 .93675 L F
0 g
.46824 .93354 m
.47436 .93675 L
s
.29405 .7912 m .28953 .80011 L .2936 .79874 L 0 1 .472 r
F
.29405 .7912 m .28374 .79449 L .28953 .80011 L F
0 g
.28953 .80011 m
.28986 .80646 L
s
.2936 .79874 m
.2995 .80369 L
s
.51316 .68035 m .52305 .65251 L .52327 .65217 L 0 0 .059 r
F
.51316 .68035 m .51998 .66101 L .52305 .65251 L F
0 g
.52305 .65251 m
.52311 .65233 L
s
.52069 .65719 m
.52076 .65696 L
s
.52104 .65648 m
.52111 .65626 L
s
.5215 .65554 m
.52158 .6553 L
s
.51949 .65949 m
.51949 .65949 L
s
.51949 .65949 m
.51954 .65938 L
s
.51949 .65949 m
.51949 .65949 L
s
.52026 .65799 m
.52029 .65789 L
s
.63992 .48617 m
.64319 .5059 L
s
.63992 .48617 m
.64039 .50204 L
s
.64039 .50204 m
.6406 .50885 L
s
.52207 .65222 m .52788 .62199 L .52444 .6382 L 0 .709 .272 r
F
0 g
.52788 .62199 m
.52931 .61839 L
s
.52546 .64817 m
.52558 .64778 L
s
.52508 .64941 m
.52546 .64817 L
s
.52474 .65047 m
.52508 .64941 L
s
.52411 .65104 m
.52435 .65022 L
s
.52435 .65022 m
.52444 .64993 L
s
.52444 .64993 m
.52453 .64963 L
s
.52453 .64963 m
.52461 .64937 L
s
.525 .64861 m
.52746 .64071 L
s
.52482 .64918 m
.525 .64861 L
s
.52469 .64959 m
.52482 .64918 L
s
.52456 .65001 m
.52469 .64959 L
s
.52443 .65042 m
.52456 .65001 L
s
.52434 .65132 m
.52449 .65084 L
s
.52449 .65084 m
.52465 .65029 L
s
.52533 .64797 m
.52743 .64083 L
s
.52516 .64854 m
.52533 .64797 L
s
.52503 .64897 m
.52516 .64854 L
s
.52491 .6494 m
.52503 .64897 L
s
.52465 .65029 m
.52491 .6494 L
s
.52415 .65035 m
.52423 .6501 L
s
.52406 .65064 m
.52415 .65035 L
s
.52397 .65092 m
.52406 .65064 L
s
.52383 .65136 m
.52397 .65092 L
s
.52788 .62199 m
.52811 .62022 L
s
.52378 .65111 m
.52382 .65097 L
s
.52365 .65153 m
.52378 .65111 L
s
.5236 .65171 m
.52365 .65153 L
s
.52328 .65215 m
.52335 .65192 L
s
.46526 .80262 m .45462 .80458 L .45591 .80897 L 0 1 .474 r
F
0 g
.45105 .80953 m
.45591 .80897 L
s
.51316 .68035 m .51773 .6655 L .51995 .65858 L 0 0 .048 r
F
0 g
.5199 .65874 m
.51992 .65866 L
s
.51992 .65866 m
.51994 .65861 L
s
.51994 .65861 m
.51995 .65859 L
s
.51995 .65859 m
.51995 .65858 L
s
.51909 .66033 m
.51945 .65937 L
s
.51909 .66034 m
.51909 .66033 L
s
.51909 .66034 m
.51909 .66034 L
s
.51995 .65858 m
.51998 .65851 L
s
.76659 .94618 m .75899 .95026 L .75589 .95446 L 0 1 .538 r
F
0 g
.7469 .95618 m
.75589 .95446 L
s
.51944 .63683 m .51983 .63855 L .5222 .62344 L 0 .762 .271 r
F
0 g
.52012 .63672 m
.52037 .63512 L
s
.518 .62889 m
.51958 .61326 L
s
.51871 .62804 m
.51958 .61326 L
s
.51962 .63453 m
.51977 .63263 L
s
.51977 .63263 m
.52028 .62607 L
s
.52028 .62607 m
.52047 .62365 L
s
.52047 .62365 m
.52093 .61775 L
s
.51934 .63042 m
.51958 .62855 L
s
.51958 .62855 m
.51959 .62847 L
s
.51959 .62847 m
.52059 .62044 L
s
.47592 1.00364 m .48092 1.00976 L .4817 1.00667 L 0 1 .541 r
F
.49733 1.00423 m .4817 1.00667 L .48092 1.00976 L 0 1 .537 r
F
0 g
.48092 1.00976 m
.48719 1.01244 L
s
.47358 1.01116 m
.48092 1.00976 L
s
.46526 .80262 m .46457 .81058 L .46655 .807 L 0 1 .474 r
F
.47482 .80799 m .46655 .807 L .46457 .81058 L 0 1 .472 r
F
0 g
.46457 .81058 m
.46631 .81498 L
s
.46001 .81142 m
.46457 .81058 L
s
.51114 .67721 m .50837 .68106 L .50821 .68074 L 0 0 0 r
F
0 g
.50804 .68108 m
.50821 .68074 L
s
.39976 .95094 m
.40762 .94891 L
s
.41999 .94358 m .40349 .94756 L .40762 .94891 L 0 1 .501 r
F
0 g
.40762 .94891 m
.40762 .94891 L
s
.58151 .71594 m
.58178 .72301 L
s
.58087 .69898 m
.58151 .71594 L
s
.58085 .69856 m
.58087 .69898 L
s
.57797 .623 m
.578 .62366 L
s
.578 .62366 m
.57862 .63994 L
s
.57597 .5705 m
.57797 .623 L
s
.52221 .87725 m
.52304 .87627 L
s
.50616 .63647 m .50654 .63519 L .50493 .62264 L 0 .862 .291 r
F
0 g
.50493 .62264 m
.50495 .62277 L
s
.50493 .62264 m
.50495 .62272 L
s
.50625 .61858 m
.50811 .63036 L
s
.50625 .61858 m
.50745 .63139 L
s
.42381 .79831 m .42126 .8052 L .42425 .80261 L 0 1 .492 r
F
.42381 .79831 m .41611 .80464 L .42126 .8052 L F
.43336 .80588 m .42425 .80261 L .42126 .8052 L 0 1 .491 r
F
0 g
.42126 .8052 m
.42223 .8095 L
s
.31354 .9866 m .31445 .99327 L .31742 .99174 L 0 1 .538 r
F
.31354 .9866 m .30587 .9903 L .31445 .99327 L F
0 g
.31445 .99327 m
.31917 .99816 L
s
.31396 .81275 m .29925 .81 L .29961 .81333 L 0 1 .525 r
F
.31396 .81275 m .30333 .80872 L .29925 .81 L F
.31396 .81275 m .30964 .8099 L .30333 .80872 L F
0 g
.31396 .81275 m
.31396 .81275 L
s
.32602 .80811 m .30964 .8099 L .31396 .81275 L 0 1 .518 r
F
0 g
.31396 .81275 m
.31396 .81275 L
s
.43336 .80588 m .42943 .8029 L .42425 .80261 L 0 1 .491 r
F
0 g
.43336 .80588 m
.43432 .81019 L
s
.44053 .79847 m .43336 .80588 L .43837 .80585 L 0 1 .485 r
F
.44053 .79847 m .42944 .8029 L .43336 .80588 L F
.51316 .68035 m .52327 .65217 L .52037 .66041 L 0 0 .059 r
F
0 g
.51863 .66128 m
.51863 .66128 L
s
.51863 .66128 m
.51863 .66128 L
s
.51859 .66139 m
.51859 .66139 L
s
.51859 .66139 m
.51863 .66128 L
s
.51859 .66139 m
.51859 .66139 L
s
.51863 .66128 m
.51898 .66039 L
s
.51942 .65969 m
.51942 .65968 L
s
.5194 .65973 m
.5194 .65973 L
s
.5194 .65973 m
.51942 .65969 L
s
.5194 .65973 m
.5194 .65973 L
s
.51942 .65969 m
.51942 .65969 L
s
.51942 .65969 m
.51942 .65969 L
s
.51942 .65968 m
.51949 .65949 L
s
.51907 .66041 m
.51907 .66041 L
s
.51907 .66041 m
.51909 .66034 L
s
.51907 .66041 m
.51907 .66041 L
s
.51984 .65893 m
.5199 .65874 L
s
.52327 .65217 m
.52328 .65215 L
s
.52012 .65845 m
.52021 .65817 L
s
.52021 .65817 m
.52026 .65799 L
s
.52057 .65753 m
.52069 .65719 L
s
.80092 .59673 m .81015 .60324 L .81315 .6051 L 0 0 0 r
F
0 g
.81015 .60324 m
.81322 .608 L
s
.32947 .96151 m .32991 .96621 L .33289 .96453 L 0 1 .524 r
F
0 g
.33289 .96453 m
.34133 .96467 L
s
.32947 .96151 m .32176 .96554 L .32991 .96621 L 0 1 .524 r
F
0 g
.32991 .96621 m
.33413 .96903 L
s
.4972 .69899 m .49083 .70849 L .49026 .70994 L 0 .875 .137 r
F
0 g
.48722 .71417 m
.49026 .70994 L
s
.45794 .54984 m .46003 .5359 L .45707 .53548 L 0 1 .313 r
F
0 g
.46003 .5359 m
.46427 .53005 L
s
.46003 .5359 m
.4604 .54205 L
s
.72985 .94025 m .74168 .9367 L .73827 .93623 L 0 1 .526 r
F
.74776 .92407 m .74168 .9367 L .7496 .9318 L 0 1 .523 r
F
.74776 .92407 m .73827 .93623 L .74168 .9367 L F
0 g
.73815 .9416 m
.74168 .9367 L
s
.44053 .79847 m .43837 .80585 L .44113 .80283 L 0 1 .485 r
F
.44995 .80515 m .44113 .80283 L .43837 .80585 L 0 1 .483 r
F
0 g
.43837 .80585 m
.43948 .81022 L
s
.43336 .80588 m
.43837 .80585 L
s
.26251 .81718 m .25859 .82249 L .26264 .82126 L 0 1 .535 r
F
0 g
.26264 .82126 m
.26322 .82144 L
s
.26251 .81718 m .25223 .82001 L .25859 .82249 L 0 1 .535 r
F
0 g
.25859 .82249 m
.25966 .82659 L
s
.46657 .92226 m .46974 .93054 L .47075 .92847 L 0 .778 .445 r
F
.48333 .93787 m .47075 .92847 L .46974 .93054 L 0 .663 .432 r
F
0 g
.46974 .93054 m
.47436 .93675 L
s
.46376 .92747 m
.46974 .93054 L
s
.51316 .68035 m .51937 .65982 L .51773 .6655 L 0 0 .043 r
F
.51316 .68035 m .51897 .66067 L .51937 .65982 L F
0 g
.51769 .66328 m
.51769 .66328 L
s
.51769 .66328 m
.51769 .66327 L
s
.51769 .66327 m
.51788 .6628 L
s
.51853 .66155 m
.51859 .66139 L
s
.51853 .66155 m
.51853 .66155 L
s
.51853 .66155 m
.51853 .66155 L
s
.51811 .66241 m
.51811 .66241 L
s
.51811 .66241 m
.51811 .66241 L
s
.51811 .66241 m
.51836 .66171 L
s
.51937 .65982 m
.5194 .65973 L
s
.51903 .66052 m
.51907 .66041 L
s
.51901 .66057 m
.51901 .66057 L
s
.51901 .66057 m
.51903 .66052 L
s
.51901 .66057 m
.51901 .66057 L
s
.51903 .66052 m
.51903 .66052 L
s
.51903 .66052 m
.51903 .66052 L
s
.51936 .65985 m
.51937 .65982 L
s
.51935 .65988 m
.51936 .65985 L
s
.51931 .66002 m
.51935 .65988 L
s
.50483 .64177 m .49889 .62174 L .50223 .63338 L 0 .876 .293 r
F
0 g
.49801 .61821 m
.49889 .62174 L
s
.50423 .64481 m .50223 .63338 L .49889 .62175 L 0 .875 .293 r
F
0 g
.49764 .61906 m
.49889 .62175 L
s
.39341 .84196 m .38865 .8351 L .38273 .83138 L 0 1 .446 r
F
.40074 .83686 m .39341 .84196 L .39911 .84555 L 0 1 .438 r
F
.40074 .83686 m .38865 .8351 L .39341 .84196 L F
0 g
.39341 .84196 m
.39485 .84861 L
s
.75151 .56763 m .7622 .56534 L .76452 .57271 L 0 .328 .044 r
F
0 g
.7622 .56534 m
.76612 .56758 L
s
.27344 .79773 m .25928 .78383 L .25913 .79165 L 0 1 .48 r
F
.27344 .79773 m .26352 .78268 L .25928 .78383 L F
.27344 .79773 m .2696 .78865 L .26352 .78268 L F
.28374 .79449 m .2696 .78865 L .27344 .79773 L 0 1 .476 r
F
0 g
.27328 .80552 m
.27344 .79773 L
s
.27344 .79773 m
.27937 .8035 L
s
.35441 .81547 m .34444 .80346 L .34081 .80501 L 0 1 .455 r
F
0 g
.34081 .80505 m
.34082 .80509 L
s
.34082 .80509 m
.34138 .81194 L
s
.33556 .80747 m
.34138 .81194 L
s
.33583 .80751 m
.3412 .80972 L
s
.33561 .80734 m
.34103 .80768 L
s
.35441 .81547 m .35026 .80794 L .34444 .80346 L 0 1 .455 r
F
0 g
.34448 .80346 m
.34448 .80346 L
s
.34448 .80346 m
.34455 .80346 L
s
.34455 .80346 m
.34467 .80347 L
s
.34467 .80347 m
.35002 .80363 L
s
.36307 .81124 m .35026 .80794 L .35441 .81547 L 0 1 .449 r
F
0 g
.35441 .81547 m
.35496 .82238 L
s
.35441 .81547 m
.36005 .81981 L
s
.48253 .44534 m .49087 .4302 L .49007 .43347 L 0 0 0 r
F
0 g
.49087 .4302 m
.49536 .41961 L
s
.48764 .43528 m
.49087 .4302 L
s
.50464 .68706 m .49962 .69531 L .49991 .69498 L 0 0 0 r
F
.50251 .69072 m .49962 .69531 L .50162 .69209 L F
.50464 .68706 m .50162 .69209 L .49962 .69531 L F
.50251 .69072 m .49939 .69557 L .49962 .69531 L F
.49939 .69557 m .4972 .69899 L .49962 .69531 L F
.49991 .69498 m .49962 .69531 L .4991 .69635 L F
0 g
.49663 .70045 m
.4991 .69635 L
s
.40339 1.00063 m .38447 .99827 L .38946 1.00212 L 0 1 .54 r
F
0 g
.38105 1.001 m
.38946 1.00212 L
s
.73852 .95207 m .75073 .95212 L .74728 .95055 L 0 1 .539 r
F
.73011 .94786 m .73852 .95207 L .7421 .94815 L 0 1 .538 r
F
.35932 .79707 m .36262 .79545 L .35896 .79709 L 0 1 .495 r
F
.37199 .7965 m .36277 .79547 L .35932 .79707 L F
.36277 .79547 m .36262 .79545 L .35932 .79707 L F
.37199 .7965 m .36819 .7952 L .3626 .79545 L F
.38067 .79185 m .36819 .7952 L .37199 .7965 L 0 1 .482 r
F
.38067 .79185 m .36806 .79296 L .36819 .7952 L F
.38056 .79713 m .36816 .79299 L .36814 .79743 L 0 1 .508 r
F
.36816 .79299 m .36807 .79303 L .36814 .79743 L F
.38056 .79713 m .37722 .80347 L .38062 .80159 L F
.38056 .79713 m .37187 .80169 L .37722 .80347 L F
.36262 .79545 m .3626 .79545 L .36014 .79656 L 0 1 .495 r
F
.36262 .79545 m .36014 .79656 L .35896 .79709 L F
.35964 .79733 m .3626 .79545 L .35896 .79709 L 0 1 .51 r
F
.37187 .80169 m .36292 .79567 L .35964 .79733 L F
.36292 .79567 m .3626 .79545 L .35964 .79733 L F
.37187 .80169 m .36814 .79743 L .36304 .79561 L F
.36292 .79567 m .36304 .79561 L .3626 .79545 L F
.37187 .80169 m .36304 .79561 L .36292 .79567 L F
.36816 .79299 m .36806 .79296 L .36807 .79303 L 0 1 .508 r
F
.36811 .793 m .36806 .79302 L .36807 .79307 L 0 1 .436 r
F
.36811 .79305 m .36807 .79307 L .36808 .79966 L F
.36811 .793 m .36807 .79307 L .36811 .79305 L F
.38056 .79713 m .36814 .79743 L .37187 .80169 L 0 1 .508 r
F
.38045 .80242 m .36815 .79303 L .36808 .79966 L 0 1 .436 r
F
.36815 .79303 m .36811 .793 L .36811 .79305 L F
.36815 .79303 m .36811 .79305 L .36808 .79966 L F
.36811 .793 m .36806 .79296 L .36806 .79302 L F
0 g
.37725 .79603 m
.37738 .79602 L
s
.72154 .93918 m .72985 .94025 L .73315 .93562 L 0 1 .52 r
F
.50544 .82149 m .50823 .83029 L .50843 .82593 L 0 1 .463 r
F
0 g
.50823 .83029 m
.51159 .83472 L
s
.50459 .83224 m
.50823 .83029 L
s
.41611 .80464 m .40684 .80053 L .40355 .80284 L 0 1 .497 r
F
.41611 .80464 m .41223 .80131 L .40684 .80053 L F
.42381 .79831 m .41223 .80131 L .41611 .80464 L 0 1 .492 r
F
0 g
.41611 .80464 m
.42126 .8052 L
s
.41611 .80464 m
.41679 .809 L
s
.38938 .78706 m .38589 .79114 L .3893 .78916 L 0 1 .465 r
F
.38938 .78706 m .38067 .79185 L .38589 .79114 L F
0 g
.38589 .79114 m
.3864 .79328 L
s
.3893 .78916 m
.39472 .78814 L
s
.45413 .90115 m .45032 .90675 L .45612 .90975 L 0 .831 .44 r
F
0 g
.45032 .90675 m
.45401 .91302 L
s
.45963 .57605 m .46144 .56912 L .46026 .5632 L 0 1 .323 r
F
0 g
.46144 .56912 m
.46465 .5661 L
s
.27721 .96915 m .26046 .96865 L .26878 .97263 L 0 1 .533 r
F
0 g
.26878 .97263 m
.27746 .97451 L
s
.51316 .68035 m .52358 .65178 L .52376 .65159 L 0 0 .059 r
F
.51316 .68035 m .52037 .66041 L .52358 .65178 L F
0 g
.52358 .65178 m
.5236 .65171 L
s
.51975 .65921 m
.51984 .65893 L
s
.51809 .66247 m
.51809 .66247 L
s
.51809 .66247 m
.51811 .66241 L
s
.51809 .66247 m
.51809 .66247 L
s
.51925 .66023 m
.51931 .66002 L
s
.53959 .39083 m .54598 .38426 L .55159 .38569 L 0 .268 .113 r
F
0 g
.54598 .38426 m
.54993 .37226 L
s
.495 .81745 m .49087 .8157 L .48694 .81736 L 0 1 .466 r
F
.51316 .68035 m .51702 .667 L .51897 .66067 L 0 0 .043 r
F
0 g
.51888 .66096 m
.5189 .6609 L
s
.5189 .6609 m
.51892 .66083 L
s
.51892 .66083 m
.51896 .6607 L
s
.51896 .6607 m
.51896 .66069 L
s
.51896 .66069 m
.51897 .66067 L
s
.51897 .66067 m
.51901 .66057 L
s
.51805 .66257 m
.51805 .66257 L
s
.51805 .66257 m
.51805 .66257 L
s
.51802 .66265 m
.51802 .66265 L
s
.51802 .66265 m
.51805 .66257 L
s
.51802 .66265 m
.51802 .66265 L
s
.51805 .66257 m
.51809 .66247 L
s
.51848 .66167 m
.51848 .66167 L
s
.51848 .66167 m
.51853 .66155 L
s
.51848 .66167 m
.51848 .66167 L
s
.51705 .66464 m
.51749 .66339 L
s
.51705 .66464 m
.51705 .66464 L
s
.51705 .66464 m
.51705 .66464 L
s
.51669 .66537 m
.51749 .66339 L
s
.51669 .66537 m
.51669 .66537 L
s
.51669 .66537 m
.51669 .66537 L
s
.51759 .66352 m
.51759 .66352 L
s
.51759 .66352 m
.51759 .66352 L
s
.51759 .66352 m
.51764 .66338 L
s
.51764 .66338 m
.51764 .66338 L
s
.51764 .66338 m
.51769 .66328 L
s
.51764 .66338 m
.51764 .66338 L
s
.48265 .62238 m .48087 .61195 L .47695 .60838 L 0 1 .309 r
F
.48265 .62238 m .48331 .61795 L .48087 .61195 L F
0 g
.48087 .61195 m
.4844 .61127 L
s
.51347 .67235 m .513 .67333 L .5125 .67387 L 0 0 0 r
F
.51316 .68036 m .513 .67333 L .51347 .67235 L 0 0 .025 r
F
.51316 .68035 m .51319 .62504 L .51272 .62507 L 0 .691 .281 r
F
.51316 .68035 m .51343 .64155 L .51319 .62504 L F
0 g
.51319 .62504 m
.51366 .60685 L
s
.42474 .93847 m .42678 .94175 L .42856 .93965 L 0 1 .486 r
F
.42474 .93847 m .41999 .94358 L .42678 .94175 L F
0 g
.42678 .94175 m
.43115 .94263 L
s
.4395 .88553 m .44059 .89418 L .44239 .89194 L 0 .9 .441 r
F
.45413 .90115 m .44239 .89194 L .44059 .89418 L 0 .831 .44 r
F
0 g
.44059 .89418 m
.44399 .90052 L
s
.43473 .8911 m
.44059 .89418 L
s
.51316 .68035 m .51272 .62507 L .5126 .6416 L 0 .691 .281 r
F
0 g
.51212 .60775 m
.51272 .62507 L
s
.42941 1.00243 m .4112 1.00153 L .41647 1.00498 L 0 1 .54 r
F
0 g
.40836 1.00448 m
.41647 1.00498 L
s
.34208 .99494 m .32189 .98945 L .32634 .99421 L 0 1 .538 r
F
.46518 .59589 m .46649 .58969 L .46472 .58392 L 0 1 .321 r
F
0 g
.46649 .58969 m
.47023 .58715 L
s
.56975 .51671 m .57309 .50435 L .5779 .51218 L 0 .573 .181 r
F
0 g
.57309 .50435 m
.57317 .49584 L
s
.34894 .99086 m .35046 .99717 L .35309 .99548 L 0 1 .538 r
F
.34894 .99086 m .34208 .99494 L .35046 .99717 L F
0 g
.35046 .99717 m
.35537 1.00154 L
s
.51316 .68035 m .5139 .6252 L .51343 .64155 L 0 .696 .28 r
F
.51316 .68035 m .51437 .62545 L .5139 .6252 L F
0 g
.51366 .60685 m
.5139 .6252 L
s
.33537 .80721 m
.33538 .80732 L
s
.33532 .80451 m
.33537 .80703 L
s
.33537 .80703 m
.33537 .80721 L
s
.33537 .80724 m
.33537 .80727 L
s
.33537 .80727 m
.33538 .80732 L
s
.33537 .80725 m
.33538 .80732 L
s
.33536 .80242 m
.33536 .80444 L
s
.33536 .80451 m
.33537 .80725 L
s
.51316 .68036 m .51281 .67595 L .513 .67333 L 0 0 .025 r
F
.51316 .68035 m .51201 .62532 L .51154 .62561 L 0 .688 .281 r
F
.51316 .68035 m .5126 .6416 L .51201 .62532 L F
0 g
.51201 .62532 m
.51212 .60775 L
s
.46518 .59589 m .46472 .58392 L .46104 .5824 L 0 1 .321 r
F
0 g
.46472 .58392 m
.46861 .58025 L
s
.46472 .58392 m
.46649 .58969 L
s
.78832 .71926 m .7981 .71654 L .79362 .71453 L 0 1 .49 r
F
.78832 .71926 m .79942 .72438 L .7981 .71654 L F
.48265 .62238 m .47695 .60838 L .47335 .60972 L 0 1 .309 r
F
0 g
.47481 .6016 m
.47695 .60838 L
s
.51316 .68035 m .51426 .64198 L .51437 .62545 L 0 .696 .28 r
F
0 g
.51437 .62545 m
.51518 .60685 L
s
.51316 .68035 m .51154 .62561 L .51178 .64212 L 0 .688 .281 r
F
0 g
.5106 .60948 m
.51154 .62561 L
s
.48476 .81294 m .48074 .81102 L .47656 .8124 L 0 1 .469 r
F
.68715 .94986 m .69471 .95091 L .69833 .9474 L 0 1 .492 r
F
0 g
.69471 .95091 m
.70301 .94802 L
s
.51316 .68035 m .52376 .65159 L .52069 .66008 L 0 0 .059 r
F
0 g
.51703 .6647 m
.51703 .6647 L
s
.51703 .6647 m
.51705 .66464 L
s
.51703 .6647 m
.51703 .6647 L
s
.51838 .66192 m
.51838 .66192 L
s
.51838 .66192 m
.51848 .66167 L
s
.51838 .66192 m
.51838 .66192 L
s
.51886 .66104 m
.51888 .66096 L
s
.52376 .65159 m
.52383 .65136 L
s
.38191 .82466 m .36854 .81544 L .36937 .82216 L 0 1 .444 r
F
0 g
.36345 .81807 m
.36937 .82216 L
s
.25256 .81203 m .23755 .80154 L .23777 .80775 L 0 1 .526 r
F
.25256 .81203 m .24179 .80052 L .23755 .80154 L F
.25256 .81203 m .24823 .80503 L .24179 .80052 L F
.26284 .80904 m .24823 .80503 L .25256 .81203 L 0 1 .525 r
F
0 g
.25256 .81203 m
.25884 .81632 L
s
.25256 .81203 m
.25276 .81821 L
s
.40074 .83686 m .39911 .84555 L .40195 .84348 L 0 1 .438 r
F
.41267 .85346 m .40195 .84348 L .39911 .84555 L 0 1 .44 r
F
0 g
.39911 .84555 m
.40091 .85211 L
s
.39341 .84196 m
.39911 .84555 L
s
.47406 .46452 m .46757 .47514 L .46934 .47334 L 0 .828 .103 r
F
.47406 .46452 m .46998 .46941 L .46757 .47514 L F
0 g
.46973 .47492 m
.47198 .47103 L
s
.47406 .46452 m .47496 .45997 L .46998 .46941 L 0 .828 .103 r
F
.47406 .46452 m .47967 .45117 L .47496 .45997 L F
0 g
.47198 .47103 m
.47406 .46452 L
s
.45963 .57605 m .46026 .5632 L .45686 .56224 L 0 1 .323 r
F
0 g
.46026 .5632 m
.46144 .56912 L
s
.52181 .8756 m
.523 .87494 L
s
.51316 .68035 m .51835 .662 L .51702 .667 L 0 0 .038 r
F
.51316 .68035 m .51792 .66291 L .51835 .662 L F
0 g
.5157 .66742 m
.5157 .66742 L
s
.5157 .66742 m
.5157 .66742 L
s
.51567 .6675 m
.51567 .6675 L
s
.51567 .6675 m
.5157 .66742 L
s
.51567 .6675 m
.51567 .6675 L
s
.5157 .66742 m
.516 .66662 L
s
.51587 .66708 m
.51587 .66708 L
s
.51587 .66708 m
.51587 .66708 L
s
.51585 .66712 m
.51585 .66712 L
s
.51585 .66712 m
.51587 .66708 L
s
.51585 .66712 m
.51585 .66712 L
s
.51587 .66708 m
.516 .66662 L
s
.51753 .66368 m
.51753 .66368 L
s
.51753 .66368 m
.51759 .66352 L
s
.51753 .66368 m
.51753 .66368 L
s
.51665 .66547 m
.51665 .66547 L
s
.51665 .66547 m
.51669 .66537 L
s
.51665 .66547 m
.51665 .66547 L
s
.5166 .66559 m
.51665 .66547 L
s
.5166 .6656 m
.5166 .6656 L
s
.5166 .6656 m
.5166 .66559 L
s
.517 .66477 m
.51703 .6647 L
s
.51697 .66486 m
.51697 .66486 L
s
.51697 .66486 m
.517 .66477 L
s
.51697 .66486 m
.51697 .66486 L
s
.517 .66477 m
.517 .66477 L
s
.517 .66477 m
.517 .66477 L
s
.51835 .662 m
.51838 .66192 L
s
.51796 .66282 m
.51796 .66282 L
s
.51796 .66282 m
.51802 .66265 L
s
.51796 .66282 m
.51796 .66282 L
s
.51834 .66205 m
.51835 .662 L
s
.51833 .66206 m
.51834 .66205 L
s
.51832 .66211 m
.51833 .66206 L
s
.51831 .66215 m
.51832 .66211 L
s
.5183 .6622 m
.51831 .66215 L
s
.47684 .72589 m .47331 .73134 L .47609 .72763 L 0 1 .199 r
F
.47684 .72589 m .46961 .73509 L .47331 .73134 L F
0 g
.47297 .73302 m
.47331 .73134 L
s
.2317 .82561 m .21582 .81824 L .21643 .82299 L 0 1 .539 r
F
.2317 .82561 m .22005 .81734 L .21582 .81824 L F
.2317 .82561 m .22687 .8205 L .22005 .81734 L F
.24196 .82282 m .22687 .8205 L .2317 .82561 L 0 1 .538 r
F
0 g
.2317 .82561 m
.23228 .83033 L
s
.2317 .82561 m
.23835 .82853 L
s
.45628 .74665 m .45252 .75172 L .45565 .74842 L 0 1 .282 r
F
.45628 .74665 m .44821 .75474 L .45252 .75172 L F
0 g
.45234 .75351 m
.45252 .75172 L
s
.52574 .63053 m .53194 .60779 L .53314 .5983 L 0 1 .31 r
F
0 g
.53222 .6056 m
.53232 .6048 L
s
.53232 .6048 m
.53277 .60126 L
s
.53277 .60126 m
.53314 .5983 L
s
.53235 .60642 m
.53323 .60348 L
s
.53198 .59876 m
.53229 .59521 L
s
.53229 .59521 m
.53289 .58852 L
s
.53314 .5983 m
.53345 .59701 L
s
.6043 .39595 m
.60525 .39311 L
s
.51316 .68035 m .51507 .62604 L .51426 .64198 L 0 .702 .28 r
F
.51316 .68036 m .51347 .67235 L .51363 .67423 L 0 0 .025 r
F
.51316 .68035 m .51554 .62658 L .51507 .62604 L 0 .702 .28 r
F
0 g
.51507 .62604 m
.51518 .60685 L
s
.51528 .66827 m
.51553 .66762 L
s
.51528 .66827 m
.51528 .66827 L
s
.51528 .66827 m
.51528 .66827 L
s
.51539 .66804 m
.51539 .66804 L
s
.51539 .66804 m
.51539 .66804 L
s
.51539 .66804 m
.51553 .66761 L
s
.32614 .80396 m .31059 .79292 L .30995 .80043 L 0 1 .464 r
F
.32614 .80396 m .31561 .79117 L .31059 .79292 L F
.32614 .80396 m .32227 .7959 L .31561 .79117 L F
0 g
.32596 .80603 m
.32614 .80396 L
s
.33535 .80027 m .32227 .7959 L .32614 .80396 L 0 1 .459 r
F
0 g
.32614 .80396 m
.32776 .80537 L
s
.76445 .69976 m
.76808 .69666 L
s
.53096 .63527 m .53654 .61139 L .53311 .62448 L 0 1 .308 r
F
.52939 .63276 m .53311 .62448 L .53654 .61139 L 0 1 .307 r
F
0 g
.53654 .61139 m
.5371 .60814 L
s
.53654 .61139 m
.53961 .60355 L
s
.52927 .63359 m
.52942 .63269 L
s
.50544 .82149 m .50124 .81993 L .4976 .82189 L 0 1 .463 r
F
.51316 .68035 m .51084 .62623 L .51038 .62676 L 0 .689 .283 r
F
.51316 .68035 m .51178 .64212 L .51084 .62623 L F
0 g
.5106 .60948 m
.51084 .62623 L
s
.74072 .74855 m
.74207 .74889 L
s
.22177 .78542 m .21693 .79493 L .22116 .79384 L 0 1 .491 r
F
.22177 .78542 m .21109 .78799 L .21693 .79493 L F
0 g
.21693 .79493 m
.21737 .8033 L
s
.22116 .79384 m
.22779 .80043 L
s
.51114 .67721 m .51032 .67742 L .51099 .67689 L 0 0 0 r
F
.5123 .6748 m .51099 .67689 L .51032 .67742 L F
0 g
.50913 .67906 m
.51032 .67742 L
s
.51032 .67742 m
.51052 .67649 L
s
.50355 .64882 m .49449 .62323 L .49397 .62641 L 0 .876 .294 r
F
.50355 .64882 m .49762 .62837 L .49449 .62323 L F
0 g
.49215 .61562 m
.49449 .62323 L
s
.30995 .80043 m
.30995 .80043 L
s
.28565 .96567 m .28566 .97086 L .28895 .96939 L 0 1 .531 r
F
0 g
.28895 .96939 m
.29786 .97058 L
s
.28565 .96567 m .27721 .96915 L .28566 .97086 L 0 1 .531 r
F
0 g
.28566 .97086 m
.28988 .9744 L
s
.4512 1.00758 m .44239 1.00569 L .43467 1.00587 L 0 1 .541 r
F
0 g
.4512 1.00758 m
.457 1.01072 L
s
.45486 1.00076 m .4512 1.00758 L .45878 1.0069 L 0 1 .541 r
F
.45486 1.00076 m .4424 1.00569 L .4512 1.00758 L F
.51832 .98099 m .51054 .9737 L .50458 .96932 L 0 .328 .31 r
F
.49397 .62641 m .48674 .61888 L .49064 .62454 L 0 .989 .3 r
F
.49281 .63441 m .48674 .61888 L .48331 .61795 L 0 .977 .301 r
F
.49281 .63441 m .49064 .62454 L .48674 .61888 L F
0 g
.4844 .61127 m
.48674 .61888 L
s
.48607 .6187 m
.48674 .61888 L
s
.45715 .52886 m .46022 .52047 L .46058 .51439 L 0 1 .289 r
F
0 g
.46022 .52047 m
.4619 .51817 L
s
.46961 .73509 m .46035 .74337 L .45989 .74511 L 0 1 .25 r
F
0 g
.45565 .74842 m
.45989 .74511 L
s
.53233 .63869 m .53848 .61599 L .53476 .62826 L 0 1 .311 r
F
.53096 .63527 m .53476 .62826 L .53848 .61599 L 0 1 .308 r
F
0 g
.53848 .61599 m
.53965 .61015 L
s
.53848 .61599 m
.53901 .61489 L
s
.53017 .62822 m
.53119 .62217 L
s
.51316 .68035 m .51507 .64293 L .51554 .62658 L 0 .702 .28 r
F
0 g
.51554 .62658 m
.51559 .62564 L
s
.34481 .80361 m
.34489 .80364 L
s
.34489 .80364 m
.35014 .80572 L
s
.34456 .80351 m
.34481 .80361 L
s
.40074 .83686 m .38744 .82848 L .38865 .8351 L 0 1 .438 r
F
0 g
.38273 .83138 m
.38865 .8351 L
s
.51316 .68035 m .51038 .62676 L .51097 .64305 L 0 .689 .283 r
F
0 g
.51037 .62662 m
.51038 .62676 L
s
.54795 .62058 m
.55013 .61015 L
s
.51316 .68035 m .51628 .6686 L .51792 .66291 L 0 0 .038 r
F
0 g
.5179 .66298 m
.51792 .66294 L
s
.51792 .66294 m
.51792 .66293 L
s
.51792 .66293 m
.51792 .66291 L
s
.51524 .66836 m
.51528 .66827 L
s
.51524 .66836 m
.51524 .66836 L
s
.51524 .66836 m
.51524 .66836 L
s
.51537 .6681 m
.51537 .6681 L
s
.51537 .6681 m
.51537 .6681 L
s
.51537 .6681 m
.51539 .66804 L
s
.51792 .66291 m
.51796 .66282 L
s
.41538 .77696 m .40346 .78061 L .40342 .78258 L 0 1 .442 r
F
.41538 .77696 m .40704 .77837 L .40346 .78061 L F
.41538 .77696 m .41215 .77681 L .40704 .77837 L F
0 g
.41533 .77892 m
.41538 .77696 L
s
.42419 .77043 m .41215 .77681 L .41538 .77695 L 0 1 .408 r
F
0 g
.41538 .77695 m
.42037 .77505 L
s
.28343 .80294 m .27913 .80991 L .28319 .80861 L 0 1 .524 r
F
.28343 .80294 m .27312 .80601 L .27913 .80991 L F
0 g
.27913 .80991 m
.27977 .81557 L
s
.28319 .80861 m
.28976 .81215 L
s
.49968 .959 m .49892 .96342 L .50485 .96694 L 0 .518 .407 r
F
0 g
.49892 .96342 m
.50458 .96932 L
s
.49968 .959 m .49238 .9525 L .48647 .949 L 0 .518 .407 r
F
.44995 .80515 m .4461 .80253 L .44113 .80283 L 0 1 .483 r
F
.4562 .79683 m .44995 .80515 L .45462 .80458 L 0 1 .476 r
F
.4562 .79683 m .4461 .80253 L .44995 .80515 L F
0 g
.44995 .80515 m
.45105 .80953 L
s
.24343 .78943 m
.24867 .79461 L
s
.51316 .68035 m .52399 .65143 L .52413 .6514 L 0 0 .058 r
F
.51316 .68035 m .52069 .66008 L .52399 .65143 L F
0 g
.52399 .65143 m
.52411 .65104 L
s
.51784 .6632 m
.51788 .66306 L
s
.51788 .66306 m
.51788 .66305 L
s
.51788 .66305 m
.51789 .66302 L
s
.51789 .66302 m
.5179 .66298 L
s
.5152 .66847 m
.51524 .66836 L
s
.5152 .66847 m
.5152 .66847 L
s
.5152 .66847 m
.5152 .66847 L
s
.51535 .66817 m
.51535 .66817 L
s
.51535 .66817 m
.51535 .66817 L
s
.51535 .66817 m
.51537 .6681 L
s
.5169 .66505 m
.5169 .66505 L
s
.5169 .66505 m
.51697 .66486 L
s
.5169 .66505 m
.5169 .66505 L
s
.51653 .66577 m
.51653 .66577 L
s
.51653 .66577 m
.5166 .6656 L
s
.51653 .66577 m
.51653 .66577 L
s
.5173 .66423 m
.51731 .66423 L
s
.5173 .66423 m
.5173 .66423 L
s
.5173 .66424 m
.5173 .66424 L
s
.5173 .66424 m
.5173 .66423 L
s
.5173 .66424 m
.5173 .66424 L
s
.51731 .66423 m
.5174 .664 L
s
.5174 .664 m
.5174 .664 L
s
.5174 .664 m
.51753 .66368 L
s
.5174 .664 m
.5174 .664 L
s
.51584 .66718 m
.51584 .66717 L
s
.51584 .66718 m
.51584 .66718 L
s
.51584 .66717 m
.51585 .66712 L
s
.51563 .66759 m
.51563 .66759 L
s
.51563 .66759 m
.51563 .66759 L
s
.51563 .66759 m
.51567 .6675 L
s
.49281 .63441 m .48331 .61795 L .48265 .62238 L 0 .977 .301 r
F
0 g
.48087 .61195 m
.48331 .61795 L
s
.48331 .61795 m
.48607 .6187 L
s
.28364 .81524 m
.2896 .8167 L
s
.51401 .6708 m
.51401 .6708 L
s
.51401 .6708 m
.51401 .6708 L
s
.51464 .66991 m .51417 .67089 L .51402 .67077 L 0 0 0 r
F
0 g
.51402 .67077 m
.51403 .67077 L
s
.51403 .67077 m
.51403 .67077 L
s
.51403 .67077 m
.51403 .67077 L
s
.51401 .6708 m
.51402 .67077 L
s
.51888 1.00092 m .51025 1.00279 L .5036 1.00692 L 0 1 .517 r
F
0 g
.5036 1.00692 m
.51025 1.00279 L
s
.51888 1.00092 m
.52558 1.00326 L
s
.40671 .79618 m .40355 .80284 L .40684 .80053 L 0 1 .499 r
F
.40671 .79618 m .39828 .80179 L .40355 .80284 L F
0 g
.40355 .80284 m
.40424 .8072 L
s
.42563 .86966 m .42033 .86322 L .41446 .86001 L 0 .958 .441 r
F
.51316 .68035 m .5097 .62773 L .50925 .62848 L 0 .692 .284 r
F
.51316 .68035 m .51097 .64305 L .5097 .62773 L F
0 g
.5091 .61192 m
.5097 .62773 L
s
.42425 .80261 m
.42943 .8029 L
s
.44053 .79847 m .42883 .79855 L .42944 .8029 L 0 1 .485 r
F
.4395 .88553 m .43385 .87922 L .42798 .87614 L 0 .9 .441 r
F
.51316 .68035 m .51622 .62761 L .51507 .64293 L 0 .709 .28 r
F
.51316 .68035 m .51668 .62845 L .51622 .62761 L F
0 g
.51622 .62761 m
.51669 .60787 L
s
.51558 .66774 m
.51558 .66774 L
s
.51582 .66725 m
.51582 .66725 L
s
.51582 .66725 m
.51584 .66718 L
s
.51582 .66725 m
.51582 .66725 L
s
.51558 .66774 m
.51563 .66759 L
s
.51558 .66774 m
.51558 .66774 L
s
.48786 .71251 m .48027 .72199 L .47964 .72364 L 0 .941 .173 r
F
.47247 .61506 m .47107 .60416 L .46714 .60209 L 0 1 .317 r
F
.47247 .61506 m .47335 .60972 L .47107 .60416 L F
0 g
.47107 .60416 m
.47481 .6016 L
s
.43467 1.00587 m
.44239 1.00569 L
s
.7141 .62881 m
.71471 .62855 L
s
.71471 .62855 m
.71487 .62848 L
s
.71487 .62848 m
.71493 .62845 L
s
.71493 .62845 m
.71508 .62839 L
s
.50685 .68318 m .50596 .68476 L .50411 .68811 L 0 .803 .102 r
F
.51 .67958 m .50685 .68318 L .50837 .68106 L 0 0 0 r
F
.51 .67958 m .50596 .68476 L .50685 .68318 L F
0 g
.50668 .68385 m
.50669 .68382 L
s
.50526 .6399 m .50561 .63849 L .5037 .62708 L 0 .87 .292 r
F
0 g
.50522 .63613 m
.50551 .6379 L
s
.5037 .62708 m
.50374 .62734 L
s
.5037 .62708 m
.50373 .62722 L
s
.50373 .62722 m
.50429 .62936 L
s
.50495 .62272 m
.50698 .63268 L
s
.50495 .62277 m
.50634 .63365 L
s
.41999 .94358 m .40564 .94563 L .40349 .94756 L 0 1 .501 r
F
.41999 .94358 m .41272 .94392 L .40564 .94563 L F
.42474 .93847 m .41272 .94392 L .41999 .94358 L 0 1 .486 r
F
0 g
.41999 .94358 m
.4241 .94494 L
s
.41999 .94358 m
.42678 .94175 L
s
.37187 .80169 m
.37722 .80347 L
s
.37722 .80347 m
.37789 .80793 L
s
.37187 .80169 m
.37211 .80626 L
s
.39827 .80179 m .38574 .79872 L .3862 .80309 L 0 1 .503 r
F
.51316 .68036 m .51727 .66431 L .51628 .6686 L 0 0 .033 r
F
.51316 .68036 m .51683 .66526 L .51727 .66431 L F
0 g
.51727 .66431 m
.5173 .66424 L
s
.51316 .68035 m .52413 .6514 L .52092 .66004 L 0 0 .058 r
F
0 g
.51724 .66444 m
.51726 .66436 L
s
.51726 .66436 m
.51726 .66436 L
s
.51726 .66436 m
.51727 .66434 L
s
.51727 .66434 m
.51727 .66432 L
s
.51727 .66432 m
.51727 .66431 L
s
.51639 .66612 m
.51639 .66612 L
s
.51639 .66612 m
.51653 .66577 L
s
.51639 .66612 m
.51639 .66612 L
s
.51532 .66827 m
.51535 .66817 L
s
.51532 .66827 m
.51532 .66827 L
s
.51532 .66827 m
.51532 .66827 L
s
.51513 .66865 m
.51513 .66865 L
s
.51513 .66865 m
.51513 .66865 L
s
.51513 .66865 m
.51513 .66865 L
s
.51513 .66865 m
.5152 .66847 L
s
.51688 .66512 m
.5169 .66505 L
s
.51687 .66513 m
.51688 .66512 L
s
.51685 .66519 m
.51685 .66519 L
s
.51685 .66519 m
.51687 .66513 L
s
.51685 .66519 m
.51685 .66519 L
s
.51687 .66513 m
.51687 .66513 L
s
.51687 .66513 m
.51687 .66513 L
s
.52413 .6514 m
.52443 .65042 L
s
.46961 .73509 m .46349 .73992 L .46035 .74337 L 0 1 .25 r
F
.46961 .73509 m .46746 .73638 L .46349 .73992 L F
.47684 .72589 m .46746 .73638 L .46961 .73509 L 0 1 .199 r
F
0 g
.46961 .73509 m
.47331 .73134 L
s
.46914 .73684 m
.46961 .73509 L
s
.47609 .72763 m
.47964 .72364 L
s
.47482 .80799 m .47094 .80589 L .46655 .807 L 0 1 .472 r
F
.4562 .79683 m .45462 .80458 L .45701 .8012 L 0 1 .476 r
F
.46526 .80262 m .45701 .8012 L .45462 .80458 L 0 1 .474 r
F
0 g
.45462 .80458 m
.45591 .80897 L
s
.44995 .80515 m
.45462 .80458 L
s
.51316 .68036 m .51281 .67595 L .51301 .67846 L 0 0 .026 r
F
.51316 .68036 m .51301 .67846 L .51281 .67595 L 0 0 .025 r
F
.51316 .68036 m .51316 .68036 L .51301 .67846 L F
.51316 .68035 m .50925 .62848 L .51018 .64438 L 0 .692 .284 r
F
0 g
.50925 .62843 m
.50925 .62848 L
s
.45794 .54984 m .45029 .55523 L .45361 .55549 L 0 1 .313 r
F
.45794 .54984 m .44991 .54906 L .45029 .55523 L F
.45794 .54984 m .45273 .54111 L .44991 .54906 L F
.45794 .54984 m .45707 .53548 L .45273 .54111 L F
0 g
.45794 .54984 m
.45856 .55649 L
s
.48704 .9033 m .49046 .90459 L .49106 .90258 L 0 1 .401 r
F
.48704 .9033 m .48524 .90831 L .49046 .90459 L F
.50207 .89468 m .49106 .90258 L .49046 .90459 L 0 1 .403 r
F
0 g
.49046 .90459 m
.49486 .90328 L
s
.48333 .93787 m .48153 .94296 L .48736 .94612 L 0 .663 .432 r
F
0 g
.48153 .94296 m
.48647 .949 L
s
.79942 .72438 m .8093 .72132 L .80482 .71945 L 0 1 .495 r
F
.79942 .72438 m .81052 .72918 L .8093 .72132 L F
0 g
.73745 .66622 m
.7391 .66498 L
s
.50411 .68811 m
.50579 .68507 L
s
.48704 .9033 m .47886 .91128 L .48524 .90831 L 0 1 .401 r
F
0 g
.48524 .90831 m
.49046 .90459 L
s
.48524 .90831 m
.48957 .90774 L
s
.34208 .99494 m .32487 .98792 L .32189 .98945 L 0 1 .538 r
F
0 g
.31742 .99174 m
.32036 .99255 L
s
.32036 .99255 m
.32634 .99421 L
s
.34208 .99494 m .33353 .99028 L .32487 .98792 L 0 1 .538 r
F
.34894 .99086 m .33353 .99028 L .34208 .99494 L F
0 g
.34208 .99494 m
.3465 .99969 L
s
.34208 .99494 m
.35046 .99717 L
s
.60059 .58457 m
.60078 .58782 L
s
.60078 .58782 m
.60108 .59306 L
s
.60307 .62729 m
.60324 .63026 L
s
.48265 .62238 m .47335 .60972 L .47247 .61506 L 0 1 .309 r
F
0 g
.47335 .60972 m
.47695 .60838 L
s
.47107 .60416 m
.47335 .60972 L
s
.51316 .68035 m .51587 .6444 L .51668 .62845 L 0 .709 .28 r
F
0 g
.51395 .67097 m
.51395 .67097 L
s
.51395 .67097 m
.51395 .67097 L
s
.51395 .67097 m
.51401 .6708 L
s
.51403 .67077 m
.51405 .67079 L
s
.51405 .67079 m
.51405 .67079 L
s
.51405 .67079 m
.51405 .67079 L
s
.51635 .66622 m
.51639 .66612 L
s
.51634 .66625 m
.51635 .66622 L
s
.51635 .66622 m
.51635 .66622 L
s
.51635 .66622 m
.51635 .66622 L
s
.51668 .62845 m
.51679 .62709 L
s
.51319 .62504 m
.51326 .63011 L
s
.30437 .78786 m .29971 .79667 L .30378 .79527 L 0 1 .468 r
F
.30437 .78786 m .29405 .7912 L .29971 .79667 L F
0 g
.29971 .79667 m
.2999 .80319 L
s
.59951 .40692 m
.60089 .40991 L
s
.59786 .40332 m
.59951 .40692 L
s
.53825 .53962 m .53906 .54482 L .53749 .54563 L 0 0 .045 r
F
.53825 .53962 m .5425 .53655 L .53906 .54482 L F
.53825 .53962 m .54549 .52638 L .5425 .53655 L F
0 g
.53515 .55006 m
.53825 .53962 L
s
.53177 .59954 m
.53198 .59876 L
s
.53015 .60547 m
.53177 .59954 L
s
.44632 .93062 m .43124 .93653 L .43532 .93721 L 0 1 .476 r
F
0 g
.42856 .93965 m
.43532 .93721 L
s
.48789 .80255 m .48476 .81294 L .48862 .81123 L 0 1 .461 r
F
.48789 .80255 m .48074 .81102 L .48476 .81294 L F
0 g
.48476 .81294 m
.48694 .81736 L
s
.51861 .99411 m .51888 1.00092 L .52517 .99741 L 0 1 .521 r
F
.51861 .99411 m .51025 1.00279 L .51888 1.00092 L F
.45715 .52886 m .46058 .51439 L .45798 .51466 L 0 1 .289 r
F
0 g
.46058 .51439 m
.46499 .50748 L
s
.46022 .52047 m
.46058 .51439 L
s
.50355 .64882 m .49397 .62641 L .49651 .63516 L 0 .876 .294 r
F
0 g
.49449 .62323 m
.49694 .62725 L
s
.497 .80655 m .49087 .8157 L .495 .81745 L 0 1 .458 r
F
.497 .80655 m .48862 .81123 L .49087 .8157 L F
0 g
.48694 .81736 m
.49087 .8157 L
s
.37645 .99676 m .35706 .99297 L .36169 .99722 L 0 1 .539 r
F
0 g
.35309 .99548 m
.36169 .99722 L
s
.32608 .80603 m .31037 .79972 L .30979 .80516 L 0 1 .519 r
F
0 g
.30378 .79527 m
.30995 .80043 L
s
.32608 .80603 m .31539 .79804 L .31037 .79972 L 0 1 .519 r
F
.32608 .80603 m .32212 .80075 L .31539 .79804 L F
0 g
.32585 .80813 m
.32608 .80603 L
s
.33529 .80238 m .32213 .80075 L .32608 .80603 L 0 1 .518 r
F
0 g
.32608 .80603 m
.32839 .80718 L
s
.49281 .63441 m .49325 .6312 L .49064 .62454 L 0 .977 .301 r
F
0 g
.49064 .62454 m
.49397 .62641 L
s
.48789 .80255 m .47889 .80656 L .48074 .81102 L 0 1 .461 r
F
0 g
.47656 .8124 m
.48074 .81102 L
s
.34075 .80501 m
.34078 .80501 L
s
.34445 .80081 m .34081 .80501 L .34444 .80346 L 0 1 .504 r
F
0 g
.34078 .80501 m
.34081 .80501 L
s
.34444 .80346 m
.34456 .80351 L
s
.34444 .80346 m
.34448 .80346 L
s
.34081 .80501 m
.34081 .80505 L
s
.51316 .68036 m .5155 .67027 L .51683 .66526 L 0 0 .033 r
F
0 g
.5168 .66536 m
.51682 .66528 L
s
.51682 .66528 m
.51682 .66528 L
s
.51682 .66528 m
.51682 .66528 L
s
.51682 .66528 m
.51683 .66527 L
s
.51683 .66527 m
.51683 .66526 L
s
.51624 .66649 m
.51626 .66644 L
s
.51626 .66644 m
.51626 .66644 L
s
.51626 .66644 m
.51634 .66625 L
s
.51626 .66644 m
.51626 .66644 L
s
.51577 .66741 m
.51577 .66741 L
s
.51577 .66741 m
.51582 .66725 L
s
.51577 .66741 m
.51577 .66741 L
s
.51577 .66742 m
.51577 .66741 L
s
.51577 .66742 m
.51577 .66742 L
s
.51577 .66742 m
.51577 .66742 L
s
.51524 .66849 m
.51525 .66849 L
s
.51525 .66849 m
.51532 .66827 L
s
.51524 .66849 m
.51524 .66849 L
s
.51524 .66849 m
.51524 .66849 L
s
.51524 .6685 m
.51524 .6685 L
s
.51524 .6685 m
.51524 .66849 L
s
.51547 .66803 m
.51547 .66803 L
s
.51547 .66803 m
.51558 .66774 L
s
.51547 .66803 m
.51547 .66803 L
s
.51546 .66805 m
.51547 .66803 L
s
.51546 .66805 m
.51546 .66805 L
s
.51546 .66805 m
.51546 .66805 L
s
.51683 .66526 m
.51685 .66519 L
s
.45839 .91346 m
.45999 .91607 L
s
.52335 .66208 m .53389 .63613 L .5335 .63921 L 0 0 .065 r
F
.52335 .66208 m .53105 .64169 L .53389 .63613 L F
.53233 .63869 m .53619 .63333 L .54016 .62242 L 0 1 .311 r
F
0 g
.54016 .62242 m
.54033 .62167 L
s
.53351 .64296 m .54016 .62242 L .53619 .63333 L 0 1 .315 r
F
0 g
.54016 .62242 m
.54028 .62222 L
s
.50207 .89468 m .49604 .89833 L .49106 .90258 L 0 1 .403 r
F
0 g
.50207 .89468 m
.50646 .89338 L
s
.5287 .6527 m .53392 .64488 L .53351 .64296 L 0 1 .337 r
F
.52336 .6635 m .52676 .6575 L .5287 .6527 L F
.52676 .6575 m .53392 .64488 L .5287 .6527 L F
.52336 .6635 m .53108 .65188 L .53392 .64488 L F
.53352 .64672 m .54016 .62243 L .53619 .63333 L 0 .578 .261 r
F
.53765 .63049 m .53619 .63332 L .54015 .62244 L 0 0 .091 r
F
.53619 .63332 m .53619 .63333 L .54015 .62244 L F
.54015 .62244 m .53619 .63333 L .54016 .62242 L F
.52336 .6635 m .5287 .6527 L .53021 .64793 L 0 1 .337 r
F
.5287 .6527 m .53351 .64296 L .53126 .64634 L F
.5287 .6527 m .53126 .64634 L .53021 .64793 L F
.52336 .6635 m .52687 .6593 L .53108 .65188 L F
.52611 .66 m .53352 .64672 L .53084 .6477 L 0 .641 .273 r
F
.53236 .64747 m .53284 .64407 L .53507 .63692 L 0 0 .091 r
F
.53522 .63655 m .53507 .63692 L .5354 .63585 L F
.53236 .64747 m .53507 .63692 L .53522 .63655 L F
.52336 .6635 m .52356 .66428 L .52687 .6593 L 0 1 .337 r
F
.52336 .66493 m .52611 .66 L .53021 .64793 L 0 .641 .273 r
F
.52611 .66 m .53084 .6477 L .53021 .64793 L F
.53575 .63495 m .5354 .63585 L .53619 .63333 L 0 0 .091 r
F
.53236 .64747 m .5354 .63585 L .53575 .63495 L F
.53236 .64747 m .53554 .63572 L .53765 .63049 L F
.53554 .63572 m .53619 .63333 L .53765 .63049 L F
.53236 .64747 m .54016 .62242 L .54261 .61979 L F
0 g
.54016 .62242 m
.54022 .62236 L
s
.54022 .62236 m
.54027 .6223 L
s
.54027 .6223 m
.54033 .62224 L
s
.54033 .62224 m
.54139 .6211 L
s
.53287 .62566 m
.53299 .62473 L
s
.50288 .89012 m .50207 .89468 L .50673 .8906 L 0 1 .363 r
F
.50288 .89012 m .49604 .89833 L .50207 .89468 L F
.30587 .9903 m .28523 .98305 L .28939 .98834 L 0 1 .538 r
F
.30587 .9903 m .28852 .98169 L .28523 .98305 L F
.30587 .9903 m .29738 .9848 L .28852 .98169 L F
.31354 .9866 m .29738 .9848 L .30587 .9903 L F
0 g
.30587 .9903 m
.31445 .99327 L
s
.30587 .9903 m
.30999 .99557 L
s
.28374 .79449 m .26989 .78096 L .2696 .78865 L 0 1 .476 r
F
.28374 .79449 m .27414 .7798 L .26989 .78096 L F
.28374 .79449 m .28008 .78561 L .27414 .7798 L F
.29405 .7912 m .28008 .78561 L .28374 .79449 L 0 1 .472 r
F
0 g
.28343 .80215 m
.28374 .79449 L
s
.28374 .79449 m
.28953 .80011 L
s
.50843 .82593 m
.51174 .82367 L
s
.44821 .75474 m .43758 .76115 L .43721 .76298 L 0 1 .35 r
F
.44821 .75474 m .44103 .75822 L .43758 .76115 L F
.44821 .75474 m .44559 .75546 L .44103 .75822 L F
.45628 .74665 m .44559 .75546 L .44821 .75474 L 0 1 .282 r
F
0 g
.44821 .75474 m
.45252 .75172 L
s
.44783 .75656 m
.44821 .75474 L
s
.46518 .59589 m .45729 .59873 L .46124 .59976 L 0 1 .321 r
F
.46518 .59589 m .45551 .59294 L .45729 .59873 L F
.46518 .59589 m .45709 .58626 L .45551 .59294 L F
.46518 .59589 m .46104 .5824 L .45709 .58626 L F
0 g
.77013 .70026 m
.77118 .70347 L
s
.497 .80655 m .495 .81745 L .4986 .81545 L 0 1 .458 r
F
0 g
.495 .81745 m
.4976 .82189 L
s
.39827 .80179 m .38915 .79678 L .38574 .79872 L 0 1 .503 r
F
0 g
.38062 .80159 m
.3862 .80309 L
s
.39827 .80179 m .39453 .79809 L .38915 .79678 L 0 1 .503 r
F
0 g
.39827 .80179 m
.39872 .80616 L
s
.40671 .79618 m .39453 .79809 L .39828 .80179 L 0 1 .499 r
F
0 g
.39828 .80179 m
.40355 .80284 L
s
.51316 .68036 m .5123 .6748 L .51281 .67595 L 0 0 .026 r
F
.51316 .68035 m .50859 .62976 L .50816 .63071 L 0 .698 .285 r
F
.51316 .68035 m .51018 .64438 L .50859 .62976 L F
0 g
.50857 .6294 m
.50859 .62976 L
s
.28247 .98587 m
.28939 .98834 L
s
.45963 .57605 m .4518 .58014 L .4555 .58078 L 0 1 .323 r
F
.45963 .57605 m .45061 .57421 L .4518 .58014 L F
.45963 .57605 m .45272 .56696 L .45061 .57421 L F
.45963 .57605 m .45686 .56224 L .45272 .56696 L F
0 g
.45963 .57605 m
.46104 .5824 L
s
.46781 .9198 m
.47231 .91727 L
s
.49371 .4286 m .49936 .41883 L .50333 .41482 L 0 0 .046 r
F
0 g
.49936 .41883 m
.50181 .41303 L
s
.4562 .79683 m .44528 .79817 L .4461 .80253 L 0 1 .476 r
F
0 g
.44113 .80283 m
.4461 .80253 L
s
.34463 .80361 m
.35026 .80794 L
s
.3445 .80351 m
.34463 .80361 L
s
.34444 .80346 m
.3445 .80351 L
s
.75746 .94269 m .75073 .95212 L .75899 .95026 L 0 1 .537 r
F
.75746 .94269 m .74728 .95055 L .75073 .95212 L F
0 g
.7469 .95618 m
.75073 .95212 L
s
.42381 .79831 m .41178 .79701 L .41223 .80131 L 0 1 .492 r
F
0 g
.40684 .80053 m
.41223 .80131 L
s
.6264 .41503 m .62714 .42386 L .62429 .41453 L 0 .484 .025 r
F
.6264 .41503 m .63381 .4386 L .62714 .42386 L F
.6264 .41503 m .63983 .44889 L .63381 .4386 L F
.6264 .41503 m .64193 .44934 L .63983 .44889 L F
.6264 .41503 m .63206 .42499 L .63871 .43968 L F
0 g
.63206 .42499 m
.63218 .42483 L
s
.63218 .42483 m
.63223 .42477 L
s
.6323 .42467 m
.63258 .42429 L
s
.63223 .42477 m
.6323 .42467 L
s
.61999 .39845 m
.6264 .41503 L
s
.63548 .42863 m
.638 .4381 L
s
.74776 .92407 m .74087 .93083 L .73827 .93623 L 0 1 .523 r
F
0 g
.72985 .94025 m
.73827 .93623 L
s
.71323 .93903 m .71412 .94665 L .72168 .94352 L 0 1 .535 r
F
0 g
.71083 .95043 m
.71412 .94665 L
s
.70884 .94723 m
.71412 .94665 L
s
.45486 1.00076 m .45878 1.0069 L .46009 1.00411 L 0 1 .541 r
F
.47592 1.00364 m .46009 1.00411 L .45878 1.0069 L F
0 g
.45878 1.0069 m
.46456 1.00992 L
s
.4512 1.00758 m
.45878 1.0069 L
s
.51316 .68035 m .52429 .6515 L .52438 .65165 L 0 0 .056 r
F
.51316 .68035 m .52092 .66004 L .52429 .6515 L F
0 g
.52429 .6515 m
.52434 .65132 L
s
.51499 .669 m
.51499 .669 L
s
.51499 .669 m
.51499 .669 L
s
.51499 .66901 m
.51499 .66901 L
s
.51499 .66901 m
.51499 .669 L
s
.51499 .66901 m
.51499 .66901 L
s
.51499 .669 m
.51513 .66865 L
s
.47903 .79811 m .47482 .80799 L .47889 .80656 L 0 1 .464 r
F
.47903 .79811 m .47094 .80589 L .47482 .80799 L F
0 g
.47482 .80799 m
.47656 .8124 L
s
.41267 .85346 m .40776 .84687 L .40195 .84348 L 0 1 .44 r
F
.77773 .57868 m .78539 .58589 L .78076 .58225 L 0 .096 0 r
F
.77773 .57868 m .78933 .58831 L .78539 .58589 L F
.23246 .78283 m .2275 .7922 L .23174 .7911 L 0 1 .488 r
F
.23246 .78283 m .22177 .78542 L .2275 .7922 L F
0 g
.2275 .7922 m
.22779 .80043 L
s
.23174 .7911 m
.2328 .79216 L
s
.43302 .76361 m .42897 .76826 L .43241 .76546 L 0 1 .362 r
F
.43302 .76361 m .42419 .77043 L .42897 .76826 L F
0 g
.42885 .77016 m
.42897 .76826 L
s
.43241 .76546 m
.43721 .76298 L
s
.71022 .55816 m .72334 .5423 L .726 .55849 L 0 .509 .118 r
F
0 g
.72334 .5423 m
.72854 .54133 L
s
.2728 .81431 m .26873 .81942 L .27279 .81819 L 0 1 .532 r
F
.2728 .81431 m .26251 .81718 L .26873 .81942 L F
0 g
.26873 .81942 m
.26962 .82333 L
s
.27279 .81819 m
.27342 .81836 L
s
.45486 1.00076 m .43716 1.00235 L .4424 1.00569 L 0 1 .541 r
F
.64434 .47734 m .64695 .47165 L .64341 .46045 L 0 .265 .248 r
F
0 g
.64341 .46045 m
.64347 .46156 L
s
.64347 .46156 m
.64394 .47012 L
s
.64259 .45738 m
.64341 .46045 L
s
.51316 .68036 m .51363 .67423 L .51417 .67089 L 0 0 .025 r
F
.51316 .68036 m .51363 .67423 L .51336 .67773 L F
.51316 .68036 m .51336 .67773 L .51363 .67423 L F
.51316 .68036 m .51316 .68036 L .51336 .67773 L F
.51316 .68035 m .51734 .62993 L .51587 .6444 L 0 .717 .28 r
F
0 g
.51394 .67102 m
.51395 .67097 L
s
.51316 .68035 m .51778 .63107 L .51734 .62993 L 0 .717 .28 r
F
0 g
.51734 .62993 m
.51738 .62909 L
s
.51672 .66566 m
.51673 .66562 L
s
.51673 .66562 m
.5168 .66536 L
s
.51408 .67081 m
.51408 .67081 L
s
.51408 .67081 m
.51408 .67081 L
s
.51406 .6708 m
.51408 .67081 L
s
.51573 .66754 m
.51573 .66754 L
s
.51573 .66754 m
.51577 .66742 L
s
.51573 .66754 m
.51573 .66754 L
s
.51616 .66668 m
.51617 .66665 L
s
.51617 .66665 m
.51617 .66665 L
s
.51617 .66665 m
.51624 .66649 L
s
.51617 .66665 m
.51617 .66665 L
s
.50423 .64481 m .49762 .62837 L .50126 .63842 L 0 .875 .293 r
F
0 g
.50374 .62734 m
.50432 .63077 L
s
.50355 .64882 m .50126 .63842 L .49762 .62837 L 0 .876 .294 r
F
0 g
.49694 .62725 m
.49762 .62837 L
s
.49533 .6185 m
.49762 .62837 L
s
.74776 .92407 m .7496 .9318 L .75677 .92478 L 0 1 .523 r
F
0 g
.7468 .93747 m
.7496 .9318 L
s
.74168 .9367 m
.7496 .9318 L
s
.68691 .9409 m .69819 .94255 L .69502 .94051 L 0 1 .534 r
F
.67922 .9354 m .68691 .9409 L .69025 .93738 L 0 1 .532 r
F
.50288 .89012 m .50673 .8906 L .50692 .88881 L 0 1 .363 r
F
0 g
.50207 .89468 m
.50673 .8906 L
s
.50673 .8906 m
.51113 .8887 L
s
.35375 .79951 m
.35904 .79947 L
s
.53912 1.00805 m .53179 1.00069 L .54043 1.01286 L 0 0 .146 r
F
0 g
.52861 .9961 m
.53179 1.00069 L
s
.51316 .68035 m .50816 .63071 L .50943 .64604 L 0 .698 .285 r
F
0 g
.50811 .63036 m
.50816 .63071 L
s
.48265 .62238 m .47491 .62107 L .47905 .62372 L 0 1 .309 r
F
.48265 .62238 m .47247 .61506 L .47491 .62107 L F
.49281 .63441 m .48265 .62238 L .48525 .62904 L 0 .977 .301 r
F
.47247 .61506 m .46714 .60209 L .46336 .60504 L 0 1 .317 r
F
0 g
.46518 .59589 m
.46714 .60209 L
s
.4972 .69899 m .49323 .70475 L .49083 .70849 L 0 .875 .137 r
F
.4972 .69899 m .49597 .70067 L .49323 .70475 L F
.49707 .69899 m .49597 .70067 L .49846 .69702 L 0 0 0 r
F
.50048 .69416 m .49431 .70289 L .49684 .69931 L F
.49431 .70289 m .49417 .7031 L .49443 .70272 L F
.49431 .70289 m .49443 .70272 L .49684 .69931 L F
.49846 .69702 m .49597 .70067 L .4972 .69899 L F
.50251 .69072 m .49707 .69899 L .49846 .69702 L F
0 g
.4972 .69899 m
.49763 .69833 L
s
.49896 .69631 m
.49962 .69531 L
s
.49763 .69833 m
.49894 .69635 L
s
.49894 .69635 m
.49896 .69631 L
s
.49663 .70045 m
.4972 .69899 L
s
.4995 .69555 m
.49962 .69531 L
s
.4991 .69635 m
.4995 .69556 L
s
.4995 .69556 m
.4995 .69555 L
s
.76659 .94618 m .7678 .95393 L .77569 .9496 L 0 1 .538 r
F
0 g
.75933 .95601 m
.7678 .95393 L
s
.5186 .98457 m
.5206 .98645 L
s
.5206 .98645 m
.52304 .98874 L
s
.52304 .98874 m
.52448 .9901 L
s
.52433 .9888 m
.52449 .98891 L
s
.5186 .98457 m
.52433 .9888 L
s
.5425 .53655 m .54926 .52168 L .55131 .52556 L 0 .092 .104 r
F
.5425 .53655 m .54549 .52638 L .54926 .52168 L F
0 g
.54926 .52168 m
.54983 .50859 L
s
.54549 .52638 m
.54623 .52042 L
s
.54549 .52638 m
.54926 .52168 L
s
.51316 .68036 m .51615 .6667 L .5155 .67027 L 0 0 .029 r
F
.51316 .68036 m .51569 .66768 L .51615 .6667 L F
0 g
.51408 .67082 m
.51408 .67082 L
s
.51408 .67082 m
.51408 .67082 L
s
.51408 .67081 m
.51408 .67082 L
s
.51384 .67128 m
.51384 .67128 L
s
.51615 .6667 m
.51616 .66668 L
s
.51537 .66831 m
.51537 .66831 L
s
.51537 .66831 m
.51546 .66805 L
s
.51537 .66831 m
.51537 .66831 L
s
.51615 .66673 m
.51615 .6667 L
s
.51615 .66673 m
.51615 .66673 L
s
.51614 .66677 m
.51615 .66673 L
s
.51612 .66686 m
.51614 .66677 L
s
.49417 .7031 m .49083 .70849 L .49323 .70475 L 0 .822 .122 r
F
.49417 .7031 m .48786 .71251 L .49083 .70849 L F
0 g
.49026 .70994 m
.49083 .70849 L
s
.50629 .81007 m .50124 .81993 L .50544 .82149 L 0 1 .455 r
F
.50629 .81007 m .4986 .81545 L .50124 .81993 L F
0 g
.4976 .82189 m
.50124 .81993 L
s
.38191 .82466 m .37195 .81365 L .36854 .81544 L 0 1 .444 r
F
.38191 .82466 m .37768 .81761 L .37195 .81365 L F
.38996 .81985 m .38191 .82466 L .38744 .82848 L 0 1 .437 r
F
.38996 .81985 m .37768 .81761 L .38191 .82466 L F
0 g
.38191 .82466 m
.38273 .83138 L
s
.45413 .90115 m .44819 .89493 L .44239 .89194 L 0 .831 .44 r
F
.37175 .8069 m .36854 .81544 L .37195 .81365 L 0 1 .443 r
F
.37175 .8069 m .36307 .81124 L .36854 .81544 L F
0 g
.36854 .81544 m
.36937 .82216 L
s
.48333 .93787 m .47657 .93161 L .47075 .92847 L 0 .663 .432 r
F
.51 .67958 m .50646 .68453 L .50596 .68476 L 0 0 0 r
F
0 g
.50579 .68507 m
.50596 .68476 L
s
.26284 .80904 m .24815 .79898 L .24823 .80503 L 0 1 .525 r
F
.26284 .80904 m .25239 .79795 L .24815 .79898 L F
.26284 .80904 m .25869 .80227 L .25239 .79795 L F
.27312 .80601 m .25869 .80227 L .26284 .80904 L 0 1 .524 r
F
0 g
.26284 .80904 m
.26898 .81313 L
s
.26284 .80904 m
.26289 .81505 L
s
.27682 .97946 m .27702 .98647 L .2803 .9851 L 0 1 .537 r
F
0 g
.2803 .9851 m
.28247 .98587 L
s
.27682 .97946 m .2684 .98274 L .27702 .98647 L 0 1 .537 r
F
0 g
.27702 .98647 m
.28144 .99189 L
s
.81052 .72918 m .82049 .72578 L .81602 .72403 L 0 1 .5 r
F
.81052 .72918 m .82161 .73368 L .82049 .72578 L F
.45413 .90115 m .45612 .90975 L .45753 .90751 L 0 .831 .44 r
F
0 g
.45612 .90975 m
.45839 .91346 L
s
.45032 .90675 m
.45612 .90975 L
s
.47903 .79811 m .46952 .80146 L .47094 .80589 L 0 1 .464 r
F
0 g
.46655 .807 m
.47094 .80589 L
s
.5204 .64134 m .52076 .64334 L .52337 .63029 L 0 .751 .271 r
F
0 g
.52214 .63642 m
.52337 .63029 L
s
.52037 .63512 m
.5222 .62344 L
s
.52059 .63943 m
.52064 .63895 L
s
.5205 .64037 m
.52059 .63943 L
s
.76577 .92577 m .77781 .92103 L .77414 .92062 L 0 1 .528 r
F
.75677 .92478 m .76577 .92577 L .76861 .92006 L 0 1 .526 r
F
.38996 .81985 m .38744 .82848 L .39058 .82652 L 0 1 .437 r
F
.40074 .83686 m .39058 .82652 L .38744 .82848 L 0 1 .438 r
F
0 g
.38744 .82848 m
.38865 .8351 L
s
.38191 .82466 m
.38744 .82848 L
s
.51861 .99411 m .50391 1.00231 L .51025 1.00279 L 0 1 .521 r
F
.43133 .86393 m .42033 .86322 L .42563 .86966 L 0 .929 .432 r
F
.43133 .86393 m .41824 .85672 L .42033 .86322 L F
0 g
.41446 .86001 m
.42033 .86322 L
s
.51316 .68035 m .52438 .65165 L .52107 .66031 L 0 0 .056 r
F
0 g
.52402 .6526 m
.52438 .65165 L
s
.52369 .65346 m
.52402 .6526 L
s
.52186 .65825 m
.52247 .65665 L
s
.51612 .66688 m
.51612 .66686 L
s
.52383 .65267 m
.52429 .6515 L
s
.52343 .65368 m
.52383 .65267 L
s
.52124 .65923 m
.522 .65732 L
s
.52092 .66004 m
.52124 .65923 L
s
.51998 .66099 m
.52267 .65316 L
s
.51999 .66098 m
.52004 .66084 L
s
.52004 .66084 m
.52005 .6608 L
s
.52005 .6608 m
.52008 .66072 L
s
.52283 .65448 m
.52399 .65143 L
s
.52317 .65399 m
.52413 .6514 L
s
.52438 .65165 m
.52474 .65047 L
s
.51316 .68035 m .51663 .64641 L .51778 .63107 L 0 .717 .28 r
F
0 g
.5157 .66764 m
.5157 .66764 L
s
.5157 .66764 m
.51573 .66754 L
s
.5157 .66764 m
.5157 .66764 L
s
.51518 .66869 m
.51518 .66869 L
s
.51518 .66869 m
.51524 .6685 L
s
.51518 .66869 m
.51518 .66869 L
s
.51778 .63107 m
.518 .62889 L
s
.51326 .63011 m
.51332 .63375 L
s
.36841 .79293 m .37172 .79128 L .36806 .79296 L 0 1 .482 r
F
.38067 .79185 m .37187 .79129 L .36841 .79293 L F
.37187 .79129 m .37172 .79128 L .36841 .79293 L F
.38067 .79185 m .37712 .7908 L .37171 .79128 L F
.38938 .78706 m .37712 .7908 L .38067 .79185 L 0 1 .465 r
F
.38938 .78706 m .37718 .78871 L .37712 .7908 L F
.38927 .79242 m .37728 .78874 L .37707 .79307 L 0 1 .504 r
F
.37728 .78874 m .37718 .78879 L .37707 .79307 L F
.38927 .79242 m .38574 .79872 L .38915 .79678 L F
.38927 .79242 m .38056 .79713 L .38574 .79872 L F
.37172 .79128 m .37171 .79128 L .37062 .79178 L 0 1 .482 r
F
.37172 .79128 m .37062 .79178 L .36806 .79296 L F
.36872 .79318 m .37171 .79128 L .36806 .79296 L 0 1 .508 r
F
.38056 .79713 m .37202 .79148 L .36872 .79318 L F
.37202 .79148 m .37171 .79128 L .36872 .79318 L F
.38056 .79713 m .37707 .79307 L .37214 .79142 L F
.37202 .79148 m .37214 .79142 L .37171 .79128 L F
.38056 .79713 m .37214 .79142 L .37202 .79148 L F
.37723 .78874 m .37718 .78877 L .37718 .78883 L 0 1 .428 r
F
.38927 .79242 m .37707 .79307 L .38056 .79713 L 0 1 .504 r
F
.37723 .7888 m .37718 .78883 L .37702 .79533 L 0 1 .428 r
F
.37723 .78874 m .37718 .78883 L .37723 .7888 L F
.38916 .79779 m .37727 .78878 L .37702 .79533 L F
.37727 .78878 m .37723 .78874 L .37723 .7888 L F
.37727 .78878 m .37723 .7888 L .37702 .79533 L F
.37728 .78874 m .37718 .78871 L .37718 .78879 L 0 1 .504 r
F
.37723 .78874 m .37718 .78871 L .37718 .78877 L 0 1 .428 r
F
0 g
.38535 .79122 m
.38589 .79114 L
s
.37023 .95284 m .37095 .95703 L .37361 .95514 L 0 1 .51 r
F
.37023 .95284 m .36332 .95738 L .37095 .95703 L F
0 g
.37095 .95703 m
.37502 .95912 L
s
.48786 .71251 m .48306 .7182 L .48027 .72199 L 0 .941 .173 r
F
.48786 .71251 m .48631 .71413 L .48306 .7182 L F
.49417 .7031 m .48631 .71413 L .48786 .71251 L 0 .822 .122 r
F
0 g
.48722 .71417 m
.48786 .71251 L
s
.48786 .71251 m
.49083 .70849 L
s
.51861 .99411 m .52517 .99741 L .52494 .9946 L 0 1 .521 r
F
0 g
.51888 1.00092 m
.52517 .99741 L
s
.52517 .99741 m
.52684 .99643 L
s
.43133 .86393 m .42563 .86966 L .43124 .87275 L 0 .929 .432 r
F
0 g
.42563 .86966 m
.42798 .87614 L
s
.24196 .82282 m .22641 .81597 L .22687 .8205 L 0 1 .538 r
F
.24196 .82282 m .23065 .81505 L .22641 .81597 L F
.24196 .82282 m .23732 .818 L .23065 .81505 L F
.25223 .82001 m .23732 .818 L .24196 .82282 L 0 1 .536 r
F
0 g
.24196 .82282 m
.24239 .82733 L
s
.24196 .82282 m
.24846 .82552 L
s
.32176 .96554 m .30214 .96356 L .30585 .96677 L 0 1 .528 r
F
.32176 .96554 m .30544 .96211 L .30214 .96356 L F
.32176 .96554 m .31387 .96296 L .30544 .96211 L F
.32947 .96151 m .31387 .96296 L .32176 .96554 L 0 1 .524 r
F
0 g
.32176 .96554 m
.32991 .96621 L
s
.32176 .96554 m
.32543 .96873 L
s
.67958 .94919 m .67957 .95393 L .68715 .94986 L 0 1 .468 r
F
0 g
.67579 .95524 m
.67957 .95393 L
s
.67826 .9552 m
.67957 .95393 L
s
.53236 .64747 m .54261 .61979 L .54191 .62717 L 0 0 .091 r
F
0 g
.54261 .61979 m
.54297 .61808 L
s
.53209 .63862 m
.53274 .63672 L
s
.54139 .6211 m
.54261 .61979 L
s
.52725 .99333 m
.53065 .99745 L
s
.5267 .99267 m
.52725 .99333 L
s
.52601 .99182 m
.5267 .99267 L
s
.52512 .99075 m
.52601 .99182 L
s
.34444 .80346 m
.34444 .80336 L
s
.34444 .80346 m
.34444 .80341 L
s
.34444 .80341 m
.34444 .80338 L
s
.34444 .80338 m
.34448 .80081 L
s
.51977 .47625 m .51687 .47989 L .51671 .48462 L 0 .816 .094 r
F
.51977 .47625 m .52052 .4647 L .51687 .47989 L F
.51904 .49714 m .51977 .47625 L .51648 .49425 L 0 1 .139 r
F
0 g
.51896 .47848 m
.51977 .47625 L
s
.52764 .63119 m .53194 .60779 L .52918 .62093 L 0 1 .307 r
F
.52574 .63053 m .52918 .62093 L .53194 .60779 L 0 1 .31 r
F
0 g
.53194 .60779 m
.53222 .6056 L
s
.53194 .60779 m
.53235 .60642 L
s
.41922 .84792 m .41267 .85346 L .41824 .85672 L 0 .981 .431 r
F
.41922 .84792 m .40776 .84687 L .41267 .85346 L F
0 g
.41267 .85346 m
.41446 .86001 L
s
.39849 .78188 m .39454 .78605 L .39811 .7839 L 0 1 .442 r
F
.39849 .78188 m .38938 .78706 L .39454 .78605 L F
0 g
.39454 .78605 m
.39472 .78814 L
s
.39811 .7839 m
.40342 .78258 L
s
.51316 .68036 m .5147 .67198 L .51569 .66768 L 0 0 .029 r
F
0 g
.51566 .66781 m
.51567 .66779 L
s
.51567 .66779 m
.51568 .66772 L
s
.51568 .66772 m
.51569 .66769 L
s
.51569 .66769 m
.51569 .66769 L
s
.51569 .66769 m
.51569 .66768 L
s
.51485 .66936 m
.51485 .66936 L
s
.51485 .66936 m
.51499 .66901 L
s
.51485 .66936 m
.51485 .66936 L
s
.51529 .66851 m
.51529 .66851 L
s
.51529 .66851 m
.51537 .66831 L
s
.51529 .66851 m
.51529 .66851 L
s
.51524 .66863 m
.51524 .66863 L
s
.51524 .66863 m
.51529 .66851 L
s
.51524 .66863 m
.51524 .66863 L
s
.51513 .66884 m
.51513 .66884 L
s
.51513 .66884 m
.51518 .66869 L
s
.51513 .66884 m
.51513 .66884 L
s
.51569 .66768 m
.5157 .66764 L
s
.51316 .68035 m .50754 .63226 L .50713 .63339 L 0 .707 .286 r
F
.51316 .68035 m .50943 .64604 L .50754 .63226 L F
0 g
.50745 .63139 m
.50754 .63226 L
s
.49733 1.00423 m .48873 1.00429 L .4817 1.00667 L 0 1 .537 r
F
0 g
.4817 1.00667 m
.48873 1.00429 L
s
.49733 1.00423 m
.5036 1.00692 L
s
.52807 .58506 m
.52869 .58251 L
s
.36307 .81124 m .35351 .79951 L .34988 .8011 L 0 1 .449 r
F
0 g
.34988 .80114 m
.34988 .80118 L
s
.34988 .80118 m
.35026 .80794 L
s
.36307 .81124 m .35917 .80385 L .35351 .79951 L 0 1 .449 r
F
.37175 .8069 m .35917 .80385 L .36307 .81124 L 0 1 .443 r
F
0 g
.36307 .81124 m
.36345 .81807 L
s
.36307 .81124 m
.36854 .81544 L
s
.50629 .81007 m .50544 .82149 L .50873 .81919 L 0 1 .455 r
F
0 g
.50544 .82149 m
.50843 .82593 L
s
.32602 .80811 m .31015 .80654 L .30964 .8099 L 0 1 .518 r
F
.32602 .80811 m .31517 .80492 L .31015 .80654 L F
.32602 .80811 m .32197 .8056 L .31517 .80492 L F
0 g
.32548 .81146 m
.32602 .80811 L
s
.33523 .8045 m .32198 .8056 L .32602 .80811 L 0 1 .512 r
F
0 g
.32602 .80811 m
.3317 .80884 L
s
.47967 .45117 m
.48253 .44534 L
s
.48789 .80255 m .48862 .81123 L .48973 .80701 L 0 1 .461 r
F
.497 .80655 m .48973 .80701 L .48862 .81123 L 0 1 .458 r
F
0 g
.48862 .81123 m
.49087 .8157 L
s
.48476 .81294 m
.48862 .81123 L
s
.45595 .56327 m
.45686 .56224 L
s
.3377 .93948 m .3191 .94314 L .32236 .94411 L 0 1 .335 r
F
.3377 .93948 m .32242 .94159 L .3191 .94314 L F
.3377 .93948 m .33041 .94002 L .32242 .94159 L F
.34545 .93511 m .33041 .94002 L .3377 .93948 L 0 1 .295 r
F
0 g
.3377 .93948 m
.3454 .93769 L
s
.3377 .93948 m
.34091 .94045 L
s
.33535 .80027 m .32224 .78883 L .32227 .7959 L 0 1 .459 r
F
.33535 .80027 m .32606 .78747 L .32224 .78883 L F
.33535 .80027 m .33168 .79238 L .32606 .78747 L F
.34456 .7965 m .33168 .79238 L .33535 .80027 L 0 1 .453 r
F
0 g
.33535 .80027 m
.33535 .80236 L
s
.33535 .80027 m
.33699 .80169 L
s
.77218 .77932 m .77918 .79084 L .78313 .78783 L 0 .651 .435 r
F
0 g
.77304 .79045 m
.77918 .79084 L
s
.77918 .79084 m
.77941 .79553 L
s
.47247 .61506 m .46454 .61662 L .46869 .61802 L 0 1 .317 r
F
.47247 .61506 m .46226 .61105 L .46454 .61662 L F
.47247 .61506 m .46336 .60504 L .46226 .61105 L F
.50483 .64177 m .50493 .64131 L .50256 .63185 L 0 .876 .293 r
F
0 g
.50256 .63185 m
.50258 .63191 L
s
.50462 .63798 m
.50481 .63855 L
s
.63206 .42499 m
.63322 .42754 L
s
.63744 .43686 m
.63871 .43968 L
s
.63322 .42754 m
.63744 .43686 L
s
.70475 .93437 m .69502 .94051 L .69819 .94255 L 0 1 .533 r
F
0 g
.69458 .94617 m
.69819 .94255 L
s
.51 .67958 m .50837 .68106 L .50949 .67981 L 0 0 0 r
F
.51114 .67721 m .50949 .67981 L .50837 .68106 L F
0 g
.50685 .68318 m
.50837 .68106 L
s
.50821 .68074 m
.50837 .68106 L
s
.30296 .94783 m .30256 .95091 L .30586 .94935 L 0 1 .36 r
F
0 g
.30586 .94935 m
.31433 .94821 L
s
.30296 .94783 m .29448 .9515 L .30256 .95091 L 0 1 .36 r
F
0 g
.30256 .95091 m
.30632 .95232 L
s
.53959 .39083 m .55159 .38569 L .55269 .39417 L 0 .268 .113 r
F
0 g
.55159 .38569 m
.55541 .37531 L
s
.54598 .38426 m
.55159 .38569 L
s
.8125 .60415 m .81712 .60811 L .82176 .61118 L 0 .207 .182 r
F
.8125 .60415 m .81315 .6051 L .81712 .60811 L F
0 g
.81322 .608 m
.81712 .60811 L
s
.29374 .79982 m .28929 .80664 L .29337 .80532 L 0 1 .523 r
F
.29374 .79982 m .28343 .80294 L .28929 .80664 L F
0 g
.28929 .80664 m
.28976 .81215 L
s
.29337 .80532 m
.29977 .80868 L
s
.41922 .84792 m .40622 .84032 L .40776 .84687 L 0 .981 .431 r
F
0 g
.40195 .84348 m
.40776 .84687 L
s
.61162 .40262 m .61764 .40544 L .62429 .41453 L 0 .569 .088 r
F
0 g
.61764 .40544 m
.61993 .39865 L
s
.47903 .79811 m .47889 .80656 L .48045 .80255 L 0 1 .464 r
F
.48789 .80255 m .48045 .80255 L .47889 .80656 L 0 1 .461 r
F
0 g
.47889 .80656 m
.48074 .81102 L
s
.47482 .80799 m
.47889 .80656 L
s
.60578 .41305 m .60583 .42959 L .6033 .41517 L 0 .804 .092 r
F
0 g
.6033 .41517 m
.60378 .41476 L
s
.60089 .40991 m
.6033 .41517 L
s
.60578 .41305 m .61243 .45075 L .60583 .42959 L 0 .804 .092 r
F
.60578 .41305 m .6187 .46448 L .61243 .45075 L F
.60578 .41305 m .62117 .46224 L .6187 .46448 L F
.60578 .41305 m .61819 .44562 L .62117 .46224 L F
.60578 .41305 m .6116 .42457 L .61819 .44562 L F
0 g
.61588 .42821 m
.61621 .42988 L
s
.61621 .42988 m
.61681 .43289 L
s
.61681 .43289 m
.61687 .43319 L
s
.60487 .40987 m
.60578 .41305 L
s
.60378 .41476 m
.60578 .41305 L
s
.44428 .87966 m .43385 .87922 L .4395 .88553 L 0 .869 .432 r
F
.44428 .87966 m .43124 .87275 L .43385 .87922 L F
0 g
.42798 .87614 m
.43385 .87922 L
s
.45881 .50819 m .46252 .49929 L .46365 .49339 L 0 1 .226 r
F
0 g
.46252 .49929 m
.46452 .49616 L
s
.46526 .80262 m .46157 .80035 L .45701 .8012 L 0 1 .474 r
F
0 g
.37361 .95514 m
.38139 .95424 L
s
.39646 .9487 m .37806 .95201 L .38139 .95424 L 0 1 .505 r
F
.51316 .68035 m .50713 .63339 L .50872 .64802 L 0 .707 .286 r
F
0 g
.51262 .67375 m
.51262 .67375 L
s
.51247 .67401 m
.51247 .67401 L
s
.50698 .63268 m
.50713 .63339 L
s
.30979 .80516 m
.30979 .80516 L
s
.50297 .65301 m .49325 .6312 L .49281 .63441 L 0 .872 .295 r
F
.50297 .65301 m .49651 .63516 L .49325 .6312 L F
0 g
.49064 .62454 m
.49325 .6312 L
s
.50258 .63191 m
.50292 .63328 L
s
.50256 .63185 m
.50298 .63311 L
s
.51316 .68036 m .51524 .66864 L .5147 .67198 L 0 0 .027 r
F
.51316 .68036 m .5151 .66894 L .51524 .66864 L F
0 g
.51474 .66964 m
.51474 .66964 L
s
.51474 .66964 m
.51485 .66936 L
s
.51474 .66964 m
.51474 .66964 L
s
.51524 .66864 m
.51524 .66863 L
s
.5151 .66893 m
.5151 .66893 L
s
.5151 .66893 m
.51513 .66884 L
s
.5151 .66893 m
.5151 .66893 L
s
.51524 .66865 m
.51524 .66864 L
s
.51523 .66868 m
.51524 .66865 L
s
.51523 .66868 m
.51523 .66868 L
s
.46939 .91668 m .46657 .92226 L .47226 .92524 L 0 .745 .435 r
F
0 g
.46657 .92226 m
.47075 .92847 L
s
.47053 .79325 m .46526 .80262 L .46952 .80146 L 0 1 .466 r
F
.47053 .79325 m .46157 .80035 L .46526 .80262 L F
0 g
.46526 .80262 m
.46655 .807 L
s
.28602 .95518 m .26607 .95556 L .26949 .95752 L 0 1 .413 r
F
.28602 .95518 m .26966 .95428 L .26607 .95556 L F
.28602 .95518 m .27823 .95412 L .26966 .95428 L F
.29448 .9515 m .27823 .95412 L .28602 .95518 L 0 1 .389 r
F
0 g
.28602 .95518 m
.28938 .95715 L
s
.28602 .95518 m
.29432 .95481 L
s
.52742 .60128 m
.52866 .59611 L
s
.497 .80655 m .4986 .81545 L .49926 .81103 L 0 1 .458 r
F
.50629 .81007 m .49926 .81103 L .4986 .81545 L 0 1 .455 r
F
0 g
.4986 .81545 m
.50124 .81993 L
s
.495 .81745 m
.4986 .81545 L
s
.49371 .4286 m .50333 .41482 L .50301 .41923 L 0 0 .046 r
F
0 g
.50333 .41482 m
.50783 .40377 L
s
.49936 .41883 m
.50333 .41482 L
s
.78256 .90593 m .77781 .92103 L .78554 .91502 L 0 1 .521 r
F
.78256 .90593 m .77414 .92062 L .77781 .92103 L F
0 g
.77475 .92699 m
.77781 .92103 L
s
.45715 .52886 m .44963 .53562 L .45261 .53536 L 0 1 .289 r
F
.45715 .52886 m .44998 .52952 L .44963 .53562 L F
0 g
.45444 .53889 m
.45707 .53548 L
s
.45715 .52886 m .45344 .52114 L .44998 .52952 L 0 1 .289 r
F
.45715 .52886 m .45798 .51466 L .45344 .52114 L F
0 g
.45707 .53548 m
.45715 .52886 L
s
.52052 .4647 m .52644 .44518 L .52127 .45958 L 0 0 0 r
F
.52127 .45958 m .53077 .4348 L .5314 .4353 L 0 0 .003 r
F
.52127 .45958 m .52645 .44518 L .53077 .4348 L F
0 g
.53077 .4348 m
.53408 .42197 L
s
.52644 .44518 m
.52983 .43541 L
s
.52645 .44518 m
.52903 .43898 L
s
.52903 .43898 m
.53077 .4348 L
s
.45013 .92536 m .45249 .92802 L .45389 .92587 L 0 1 .452 r
F
.45013 .92536 m .44632 .93062 L .45249 .92802 L F
0 g
.45249 .92802 m
.45672 .92812 L
s
.51316 .68036 m .51444 .67251 L .5151 .66894 L 0 0 .027 r
F
0 g
.51509 .66897 m
.5151 .66895 L
s
.5151 .66895 m
.5151 .66894 L
s
.5151 .66894 m
.5151 .66893 L
s
.32227 .7959 m
.32227 .7959 L
s
.35375 .7996 m
.35396 .79968 L
s
.35396 .79968 m
.3591 .80162 L
s
.51316 .68036 m .51417 .67089 L .51464 .66991 L 0 0 .025 r
F
.51316 .68035 m .51842 .63301 L .51663 .64641 L 0 .723 .28 r
F
.51316 .68035 m .51884 .63445 L .51842 .63301 L F
0 g
.51842 .63301 m
.51849 .63188 L
s
.51509 .66898 m
.51509 .66897 L
s
.51509 .66897 m
.51509 .66897 L
s
.51467 .66983 m
.51467 .66983 L
s
.51467 .66983 m
.51468 .6698 L
s
.51467 .66983 m
.51467 .66983 L
s
.51465 .66988 m
.51465 .66988 L
s
.51465 .66988 m
.51467 .66983 L
s
.51465 .66988 m
.51465 .66988 L
s
.51413 .67085 m
.51413 .67085 L
s
.51468 .6698 m
.51468 .6698 L
s
.51468 .6698 m
.51468 .6698 L
s
.51468 .6698 m
.51474 .66964 L
s
.43185 .7914 m .42883 .79855 L .43194 .79572 L 0 1 .487 r
F
.43185 .7914 m .42381 .79831 L .42883 .79855 L F
.44053 .79847 m .43194 .79572 L .42883 .79855 L 0 1 .485 r
F
0 g
.42883 .79855 m
.42944 .8029 L
s
.29388 .81208 m
.29961 .81333 L
s
.52365 .65403 m
.52387 .65346 L
s
.52387 .65346 m
.52391 .65338 L
s
.52391 .65338 m
.52407 .65298 L
s
.52407 .65298 m
.5242 .65267 L
s
.5242 .65267 m
.52435 .6523 L
s
.52435 .6523 m
.52444 .65209 L
s
.74004 .5557 m .75298 .5614 L .75151 .56763 L 0 .391 .063 r
F
0 g
.75298 .5614 m
.75755 .56043 L
s
.75058 .5524 m
.75298 .5614 L
s
.48122 .63336 m .47905 .62372 L .47491 .62107 L 0 1 .311 r
F
.48122 .63336 m .48175 .62898 L .47905 .62372 L F
0 g
.47905 .62372 m
.48265 .62238 L
s
.50423 .64481 m .50453 .64327 L .50223 .63338 L 0 .875 .293 r
F
0 g
.50398 .64094 m
.50401 .64105 L
s
.50223 .63338 m
.50224 .63339 L
s
.50424 .63987 m
.50442 .64046 L
s
.50401 .63912 m
.50424 .63987 L
s
.50432 .63077 m
.50522 .63613 L
s
.50429 .62936 m
.50579 .63507 L
s
.5042 .63842 m
.50441 .63925 L
s
.50441 .63925 m
.50489 .64115 L
s
.24316 .78021 m .23808 .78944 L .24232 .78833 L 0 1 .485 r
F
.24316 .78021 m .23246 .78283 L .23808 .78944 L F
0 g
.23808 .78944 m
.23823 .79754 L
s
.24232 .78833 m
.24343 .78943 L
s
.48253 .44534 m .47648 .45731 L .47775 .45479 L 0 0 0 r
F
.48253 .44534 m .47972 .45221 L .47648 .45731 L F
0 g
.47759 .45506 m
.47792 .45444 L
s
.47496 .45997 m
.47759 .45506 L
s
.48253 .44534 m .48529 .4429 L .47972 .45221 L 0 0 0 r
F
.48253 .44534 m .49007 .43347 L .48529 .4429 L F
.75746 .94269 m .75015 .94651 L .74728 .95055 L 0 1 .537 r
F
0 g
.73852 .95207 m
.74728 .95055 L
s
.40339 1.00063 m .38675 .99645 L .38447 .99827 L 0 1 .54 r
F
.40339 1.00063 m .39486 .99746 L .38675 .99645 L F
.40842 .99584 m .40339 1.00063 L .4112 1.00153 L F
.40842 .99584 m .39486 .99746 L .40339 1.00063 L F
0 g
.40339 1.00063 m
.40836 1.00448 L
s
.40842 .99584 m .4112 1.00153 L .41309 .99957 L 0 1 .54 r
F
.42941 1.00243 m .41309 .99957 L .4112 1.00153 L F
0 g
.4112 1.00153 m
.41647 1.00498 L
s
.40339 1.00063 m
.4112 1.00153 L
s
.46437 .73818 m .46035 .74337 L .46349 .73992 L 0 1 .218 r
F
.46437 .73818 m .45628 .74665 L .46035 .74337 L F
0 g
.45989 .74511 m
.46035 .74337 L
s
.45484 .55977 m .45555 .55744 L .4536 .55549 L 0 1 .327 r
F
0 g
.45555 .55744 m
.45856 .55649 L
s
.38996 .81985 m .37705 .81094 L .37768 .81761 L 0 1 .437 r
F
0 g
.37195 .81365 m
.37768 .81761 L
s
.42381 .79831 m .41508 .79461 L .41178 .79701 L 0 1 .492 r
F
.42381 .79831 m .42024 .79517 L .41508 .79461 L F
0 g
.42381 .79831 m
.42425 .80261 L
s
.43185 .7914 m .42024 .79516 L .42381 .79831 L 0 1 .487 r
F
0 g
.42381 .79831 m
.42883 .79855 L
s
.44428 .87966 m .4395 .88553 L .44509 .88849 L 0 .869 .432 r
F
0 g
.4395 .88553 m
.44239 .89194 L
s
.55566 .40921 m .56758 .39494 L .56912 .40067 L 0 .178 .102 r
F
.55566 .40921 m .56183 .39859 L .56758 .39494 L F
0 g
.56758 .39494 m
.56993 .38646 L
s
.56183 .39859 m
.56232 .3968 L
s
.56183 .39859 m
.56758 .39494 L
s
.29405 .7912 m .28051 .77805 L .28008 .78561 L 0 1 .472 r
F
.29405 .7912 m .28476 .77687 L .28051 .77805 L F
.29405 .7912 m .29057 .78251 L .28476 .77687 L F
.30437 .78786 m .29057 .78251 L .29405 .7912 L 0 1 .468 r
F
0 g
.2936 .79874 m
.29405 .7912 L
s
.29405 .7912 m
.29971 .79667 L
s
.78139 .69423 m .7824 .70922 L .78689 .7114 L 0 1 .491 r
F
.78139 .69423 m .78004 .70188 L .7824 .70922 L F
0 g
.7772 .71375 m
.7824 .70922 L
s
.77567 .70583 m
.78004 .70188 L
s
.51904 .49714 m .51648 .49425 L .51633 .50236 L 0 1 .139 r
F
.51832 .53018 m .51904 .49714 L .5161 .51785 L 0 1 .213 r
F
.44053 .79847 m .43696 .79569 L .43194 .79572 L 0 1 .485 r
F
.44772 .79066 m .44053 .79847 L .44528 .79817 L 0 1 .478 r
F
.44772 .79066 m .43696 .79569 L .44053 .79847 L F
0 g
.44053 .79847 m
.44113 .80283 L
s
.31706 .78367 m .31059 .79292 L .31561 .79117 L 0 1 .463 r
F
.31706 .78367 m .30437 .78786 L .31059 .79292 L F
0 g
.30995 .80043 m
.31059 .79292 L
s
.38243 .99232 m .38447 .99827 L .38675 .99645 L 0 1 .539 r
F
.38243 .99232 m .37645 .99676 L .38447 .99827 L F
0 g
.38447 .99827 m
.38946 1.00212 L
s
.48408 .71646 m .48027 .72199 L .48306 .7182 L 0 .896 .159 r
F
.48408 .71646 m .47684 .72589 L .48027 .72199 L F
0 g
.47964 .72364 m
.48027 .72199 L
s
.53115 .63157 m
.5319 .63051 L
s
.49281 .63441 m .48525 .62904 L .48938 .63349 L 0 .977 .301 r
F
.49186 .64247 m .48525 .62904 L .48175 .62898 L 0 .962 .303 r
F
.49186 .64247 m .48938 .63349 L .48525 .62904 L F
0 g
.48265 .62238 m
.48525 .62904 L
s
.48428 .62902 m
.48525 .62904 L
s
.48122 .63336 m .47491 .62107 L .47127 .623 L 0 1 .311 r
F
0 g
.47247 .61506 m
.47491 .62107 L
s
.47684 .72589 m .46819 .73465 L .46746 .73638 L 0 1 .199 r
F
0 g
.46349 .73992 m
.46746 .73638 L
s
.40074 .83686 m .39628 .83011 L .39058 .82652 L 0 1 .438 r
F
.40809 .83158 m .40074 .83686 L .40622 .84032 L 0 1 .43 r
F
.40809 .83158 m .39628 .83011 L .40074 .83686 L F
0 g
.40074 .83686 m
.40195 .84348 L
s
.5123 .6748 m .51184 .67577 L .51099 .67689 L 0 0 0 r
F
.51316 .68036 m .51184 .67577 L .5123 .6748 L 0 0 .026 r
F
.51316 .68035 m .50654 .63519 L .50616 .63647 L 0 .717 .287 r
F
.51316 .68035 m .50872 .64802 L .50654 .63519 L F
0 g
.50634 .63365 m
.50654 .63519 L
s
.51276 .67359 m
.51276 .67359 L
s
.42419 .77043 m .41252 .77487 L .41215 .77681 L 0 1 .408 r
F
.42419 .77043 m .41626 .77244 L .41252 .77487 L F
.42419 .77043 m .42126 .77054 L .41626 .77244 L F
.43302 .76361 m .42126 .77054 L .42419 .77043 L 0 1 .362 r
F
0 g
.42419 .77043 m
.42897 .76826 L
s
.42381 .77237 m
.42419 .77043 L
s
.51316 .68036 m .51464 .66991 L .51444 .67251 L 0 0 .025 r
F
0 g
.51464 .66991 m
.51465 .66988 L
s
.49809 .99815 m .49733 1.00423 L .50391 1.00231 L 0 1 .539 r
F
.49809 .99815 m .48873 1.00429 L .49733 1.00423 L F
.50251 .69072 m .49684 .69931 L .49597 .70067 L 0 0 0 r
F
0 g
.49323 .70475 m
.49597 .70067 L
s
.41922 .84792 m .41824 .85672 L .42076 .85448 L 0 .981 .431 r
F
.43133 .86393 m .42076 .85448 L .41824 .85672 L 0 .929 .432 r
F
0 g
.41824 .85672 m
.42033 .86322 L
s
.41267 .85346 m
.41824 .85672 L
s
.47053 .79325 m .46059 .79595 L .46157 .80035 L 0 1 .466 r
F
0 g
.45701 .8012 m
.46157 .80035 L
s
.44772 .79066 m .44528 .79817 L .44805 .79498 L 0 1 .478 r
F
.4562 .79683 m .44805 .79498 L .44528 .79817 L 0 1 .476 r
F
0 g
.44528 .79817 m
.4461 .80253 L
s
.44053 .79847 m
.44528 .79817 L
s
.35321 .93076 m .35291 .93311 L .35591 .93128 L 0 1 .254 r
F
0 g
.35591 .93128 m
.3636 .92872 L
s
.35321 .93076 m .34545 .93511 L .35291 .93311 L 0 1 .254 r
F
0 g
.35291 .93311 m
.35635 .9335 L
s
.51316 .68035 m .51736 .64893 L .51884 .63445 L 0 .723 .28 r
F
0 g
.51359 .67203 m
.51359 .67203 L
s
.51884 .63445 m
.51934 .63042 L
s
.51666 .66694 m
.51724 .66444 L
s
.51666 .66696 m
.51666 .66694 L
s
.51665 .66699 m
.51666 .66696 L
s
.73011 .94786 m .7421 .94815 L .73864 .94653 L 0 1 .538 r
F
.72168 .94352 m .73011 .94786 L .73344 .94407 L 0 1 .537 r
F
.47053 .79325 m .46952 .80146 L .4715 .79766 L 0 1 .466 r
F
.47903 .79811 m .4715 .79766 L .46952 .80146 L 0 1 .464 r
F
0 g
.46952 .80146 m
.47094 .80589 L
s
.46526 .80262 m
.46952 .80146 L
s
.33529 .80238 m .32202 .79579 L .32213 .80075 L 0 1 .518 r
F
.33529 .80238 m .32585 .79448 L .32202 .79579 L F
0 g
.31561 .79117 m
.32208 .79577 L
s
.33529 .80238 m .33154 .79731 L .32585 .79448 L 0 1 .518 r
F
.3445 .79865 m .33154 .79731 L .33529 .80238 L 0 1 .516 r
F
0 g
.33529 .80238 m
.33532 .80446 L
s
.33529 .80238 m
.33767 .80352 L
s
.34448 .80079 m
.34452 .79866 L
s
.34444 .80336 m
.34447 .80081 L
s
.5176 .57704 m .52161 .51738 L .51832 .53018 L 0 1 .25 r
F
.5176 .57704 m .52362 .52368 L .52161 .51738 L F
0 g
.52161 .51738 m
.52213 .51368 L
s
.44632 .93062 m .43303 .93448 L .43124 .93653 L 0 1 .476 r
F
.44632 .93062 m .4395 .93194 L .43303 .93448 L F
.45013 .92536 m .4395 .93194 L .44632 .93062 L 0 1 .452 r
F
0 g
.44632 .93062 m
.45038 .93131 L
s
.44632 .93062 m
.45249 .92802 L
s
.52405 .6535 m
.52407 .65344 L
s
.52407 .65344 m
.52409 .6534 L
s
.46226 .61105 m .46336 .60504 L .46124 .59976 L 0 1 .327 r
F
0 g
.46336 .60504 m
.46714 .60209 L
s
.40211 .94403 m .40349 .94756 L .40564 .94563 L 0 1 .493 r
F
.40211 .94403 m .39646 .9487 L .40349 .94756 L F
0 g
.40349 .94756 m
.40762 .94891 L
s
.48704 .9033 m
.49106 .90258 L
s
.49106 .90258 m
.49604 .89833 L
s
.78313 .78783 m .78992 .79882 L .79406 .7956 L 0 .714 .447 r
F
0 g
.78365 .79878 m
.78992 .79882 L
s
.78992 .79882 m
.79001 .80349 L
s
.536 .42472 m .53297 .43819 L .53234 .43675 L 0 0 .08 r
F
.536 .42472 m .53793 .42988 L .53297 .43819 L F
.536 .42472 m .54389 .41743 L .53793 .42988 L F
.49186 .64247 m .48175 .62898 L .48122 .63336 L 0 .962 .303 r
F
0 g
.47905 .62372 m
.48175 .62898 L
s
.48175 .62898 m
.48428 .62902 L
s
.50464 .68706 m .50377 .68855 L .50162 .69209 L 0 0 0 r
F
.50889 .68188 m .50464 .68706 L .50646 .68453 L F
.50889 .68188 m .50377 .68855 L .50464 .68706 L F
0 g
.50464 .68706 m
.50527 .68618 L
s
.52465 .55362 m .52362 .52368 L .52302 .54492 L 0 1 .238 r
F
.5176 .57704 m .52302 .54492 L .52362 .52368 L 0 1 .25 r
F
0 g
.52161 .51738 m
.52362 .52368 L
s
.52362 .52368 m
.52552 .50576 L
s
.38056 .79713 m
.38574 .79872 L
s
.38574 .79872 m
.3862 .80309 L
s
.38056 .79713 m
.38062 .80159 L
s
.67797 1.07974 m .6904 1.08058 L .68799 1.07981 L 0 1 .379 r
F
.70415 1.07726 m .6904 1.08058 L .70017 1.0801 L 0 .95 .341 r
F
.70415 1.07726 m .68799 1.07981 L .6904 1.08058 L F
0 g
.68372 1.08182 m
.6904 1.08058 L
s
.34981 .8011 m
.34985 .8011 L
s
.35368 .79703 m .34988 .8011 L .35351 .79951 L 0 1 .494 r
F
0 g
.34985 .8011 m
.34988 .8011 L
s
.35351 .79951 m
.35364 .79956 L
s
.35364 .79956 m
.35375 .7996 L
s
.35351 .79951 m
.35355 .79951 L
s
.34988 .8011 m
.34988 .80114 L
s
.35362 .79951 m
.35375 .79951 L
s
.35355 .79951 m
.35362 .79951 L
s
.35355 .79951 m
.35355 .79951 L
s
.45484 .55977 m .44833 .56114 L .45175 .56136 L 0 1 .327 r
F
.45484 .55977 m .44637 .5592 L .44833 .56114 L F
.45484 .55977 m .44718 .55682 L .44637 .5592 L F
.45484 .55977 m .45029 .55523 L .44718 .55682 L F
.45484 .55977 m .4536 .55549 L .45029 .55523 L F
0 g
.45361 .55549 m
.45361 .55549 L
s
.45361 .55549 m
.45794 .54984 L
s
.45175 .56136 m
.45484 .55977 L
s
.45484 .55977 m
.45686 .56224 L
s
.4536 .55549 m
.45555 .55744 L
s
.43133 .86393 m .43124 .87275 L .43341 .87044 L 0 .929 .432 r
F
.44428 .87966 m .43341 .87044 L .43124 .87275 L 0 .869 .432 r
F
0 g
.43124 .87275 m
.43385 .87922 L
s
.42563 .86966 m
.43124 .87275 L
s
.50297 .65301 m .49281 .63441 L .49557 .64206 L 0 .872 .295 r
F
0 g
.49325 .6312 m
.49631 .63492 L
s
.45881 .50819 m .46365 .49339 L .46145 .49441 L 0 1 .226 r
F
0 g
.46365 .49339 m
.46822 .48547 L
s
.46252 .49929 m
.46365 .49339 L
s
.78933 .58831 m .80155 .59703 L .80092 .59673 L 0 0 0 r
F
0 g
.79853 .59435 m
.80155 .59703 L
s
.80155 .59703 m
.8055 .59981 L
s
.47332 .91512 m
.47622 .91311 L
s
.47622 .91311 m
.47658 .91286 L
s
.47717 .91245 m
.47886 .91128 L
s
.47483 .912 m
.47487 .91199 L
s
.47698 .91161 m
.47886 .91128 L
s
.52797 .58011 m
.5287 .57751 L
s
.52758 .5815 m
.52797 .58011 L
s
.46226 .61105 m .46124 .59976 L .45729 .59873 L 0 1 .327 r
F
0 g
.46124 .59976 m
.46518 .59589 L
s
.46124 .59976 m
.46336 .60504 L
s
.51316 .68035 m .50616 .63647 L .50805 .65027 L 0 .717 .287 r
F
0 g
.50579 .63507 m
.50616 .63647 L
s
.50288 .89012 m .49198 .89965 L .49604 .89833 L 0 1 .363 r
F
.37645 .99676 m .35971 .99129 L .35706 .99297 L 0 1 .539 r
F
.37645 .99676 m .36802 .99292 L .35971 .99129 L F
.38243 .99232 m .36802 .99292 L .37645 .99676 L F
0 g
.37645 .99676 m
.38105 1.001 L
s
.37645 .99676 m
.38447 .99827 L
s
.40671 .79618 m .39439 .79374 L .39453 .79809 L 0 1 .499 r
F
0 g
.38915 .79678 m
.3945 .79809 L
s
.3945 .79809 m
.39453 .79809 L
s
.58135 .39249 m
.58757 .39261 L
s
.78139 .69423 m .78689 .7114 L .79132 .70718 L 0 1 .491 r
F
0 g
.78004 .70188 m
.7824 .70922 L
s
.78689 .7114 m
.78832 .71926 L
s
.28311 .8114 m .27889 .81632 L .28295 .81507 L 0 1 .529 r
F
.28311 .8114 m .2728 .81431 L .27889 .81632 L F
0 g
.27889 .81632 m
.2796 .82003 L
s
.28295 .81507 m
.28364 .81524 L
s
.50355 .64882 m .49651 .63516 L .50041 .64366 L 0 .876 .294 r
F
0 g
.50298 .63311 m
.50462 .63798 L
s
.50297 .65301 m .50041 .64366 L .49651 .63516 L 0 .872 .295 r
F
0 g
.50292 .63328 m
.5042 .63842 L
s
.50224 .63339 m
.50325 .63775 L
s
.49631 .63492 m
.49651 .63516 L
s
.49397 .62641 m
.49651 .63516 L
s
.41517 .79033 m .41178 .79701 L .41508 .79461 L 0 1 .494 r
F
.41517 .79033 m .40671 .79618 L .41178 .79701 L F
0 g
.41178 .79701 m
.41223 .80131 L
s
.50629 .81007 m .50873 .81919 L .50893 .81456 L 0 1 .455 r
F
0 g
.50873 .81919 m
.51174 .82367 L
s
.50544 .82149 m
.50873 .81919 L
s
.45551 .59294 m .45709 .58626 L .4555 .58078 L 0 1 .331 r
F
0 g
.45709 .58626 m
.46104 .5824 L
s
.4701 .91518 m
.47332 .91512 L
s
.27721 .96915 m .25688 .96473 L .26046 .96865 L 0 1 .533 r
F
.27721 .96915 m .26046 .9635 L .25688 .96473 L F
.27721 .96915 m .26919 .9654 L .26046 .9635 L F
.28565 .96567 m .26919 .9654 L .27721 .96915 L 0 1 .531 r
F
0 g
.27721 .96915 m
.28566 .97086 L
s
.27721 .96915 m
.28074 .97305 L
s
.27312 .80601 m .25876 .7964 L .25869 .80227 L 0 1 .524 r
F
.27312 .80601 m .26301 .79536 L .25876 .7964 L F
.27312 .80601 m .26917 .79948 L .26301 .79536 L F
.28343 .80294 m .26917 .79948 L .27312 .80601 L F
0 g
.27312 .80601 m
.27913 .80991 L
s
.27304 .81185 m
.27312 .80601 L
s
.53201 .6398 m
.53259 .63867 L
s
.53259 .63867 m
.53318 .63752 L
s
.47684 .72589 m .47134 .73106 L .46819 .73465 L 0 1 .199 r
F
.47684 .72589 m .47504 .72731 L .47134 .73106 L F
.48408 .71646 m .47504 .72731 L .47684 .72589 L 0 .896 .159 r
F
0 g
.47684 .72589 m
.48027 .72199 L
s
.47609 .72763 m
.47684 .72589 L
s
.49186 .64247 m .49221 .63924 L .48938 .63349 L 0 .962 .303 r
F
0 g
.48938 .63349 m
.49281 .63441 L
s
.40809 .83158 m .39529 .82352 L .39628 .83011 L 0 1 .43 r
F
0 g
.39058 .82652 m
.39628 .83011 L
s
.36332 .95738 m .34487 .95783 L .34855 .96031 L 0 1 .518 r
F
.40809 .83158 m .40622 .84032 L .40907 .83817 L 0 1 .43 r
F
.41922 .84792 m .40907 .83817 L .40622 .84032 L 0 .981 .431 r
F
0 g
.40622 .84032 m
.40776 .84687 L
s
.40074 .83686 m
.40622 .84032 L
s
.49417 .7031 m .48725 .71249 L .48631 .71413 L 0 .822 .122 r
F
0 g
.48306 .7182 m
.48631 .71413 L
s
.35357 .79956 m
.35917 .80385 L
s
.35351 .79951 m
.35357 .79956 L
s
.22177 .78542 m .2075 .77762 L .21109 .78799 L 0 1 .491 r
F
0 g
.21109 .78799 m
.21693 .79493 L
s
.497 .80655 m .49333 .805 L .48973 .80701 L 0 1 .458 r
F
.49809 .99815 m .48272 1.00265 L .48873 1.00429 L 0 1 .539 r
F
.69977 .5447 m .7121 .54092 L .71021 .55816 L 0 .578 .137 r
F
0 g
.7121 .54092 m
.7121 .54092 L
s
.73902 .7428 m
.73949 .74308 L
s
.42941 1.00243 m .4209 .99996 L .41309 .99957 L 0 1 .54 r
F
0 g
.42941 1.00243 m
.43467 1.00587 L
s
.43437 .99614 m .42941 1.00243 L .43716 1.00235 L 0 1 .541 r
F
.43437 .99614 m .4209 .99995 L .42941 1.00243 L F
.70475 .93437 m .69782 .93701 L .69502 .94051 L 0 1 .533 r
F
0 g
.68691 .9409 m
.69502 .94051 L
s
.36332 .95738 m .34788 .95616 L .34487 .95783 L 0 1 .518 r
F
.36332 .95738 m .35579 .95597 L .34788 .95616 L F
.37023 .95284 m .35579 .95597 L .36332 .95738 L 0 1 .51 r
F
0 g
.36332 .95738 m
.37095 .95703 L
s
.36332 .95738 m
.36697 .95986 L
s
.45628 .74665 m .44622 .7537 L .44559 .75546 L 0 1 .282 r
F
.45628 .74665 m .44967 .75061 L .44622 .7537 L F
.45628 .74665 m .45399 .74758 L .44967 .75061 L F
.46437 .73818 m .45399 .74758 L .45628 .74665 L 0 1 .218 r
F
0 g
.45628 .74665 m
.46035 .74337 L
s
.45565 .74842 m
.45628 .74665 L
s
.25223 .82001 m .23701 .81368 L .23732 .818 L 0 1 .536 r
F
.25223 .82001 m .24125 .81275 L .23701 .81368 L F
.25223 .82001 m .24778 .81548 L .24125 .81275 L F
.26251 .81718 m .24778 .81548 L .25223 .82001 L 0 1 .535 r
F
0 g
.25223 .82001 m
.25251 .82431 L
s
.25223 .82001 m
.25859 .82249 L
s
.33721 .9575 m .33738 .96201 L .34037 .96033 L 0 1 .519 r
F
0 g
.34037 .96033 m
.34855 .96031 L
s
.33721 .9575 m .32947 .96151 L .33738 .96201 L 0 1 .519 r
F
0 g
.33738 .96201 m
.34133 .96467 L
s
.45796 .8952 m .44819 .89493 L .45413 .90115 L 0 .799 .43 r
F
.45796 .8952 m .44509 .88849 L .44819 .89493 L F
0 g
.44239 .89194 m
.44819 .89493 L
s
.47056 .62823 m .46869 .61802 L .46454 .61662 L 0 1 .321 r
F
.47056 .62823 m .47127 .623 L .46869 .61802 L F
0 g
.46869 .61802 m
.47247 .61506 L
s
.45753 .90751 m
.46322 .91047 L
s
.52494 .9946 m
.52527 .99424 L
s
.52527 .99424 m
.52586 .99359 L
s
.52586 .99359 m
.52617 .99325 L
s
.52617 .99325 m
.52663 .99274 L
s
.52663 .99274 m
.5267 .99267 L
s
.5267 .99267 m
.527 .99234 L
s
.52813 .9911 m
.52842 .99078 L
s
.53046 .98855 m
.53087 .98809 L
s
.52481 .9909 m
.52523 .9907 L
s
.52523 .9907 m
.52538 .99063 L
s
.52538 .99063 m
.52567 .9905 L
s
.52689 .98993 m
.52754 .98963 L
s
.53028 .98837 m
.53087 .98809 L
s
.23727 .80739 m
.23777 .80775 L
s
.48789 .80255 m .4843 .80083 L .48045 .80255 L 0 1 .461 r
F
.32124 .98292 m .32189 .98945 L .32487 .98792 L 0 1 .537 r
F
.32124 .98292 m .31354 .9866 L .32189 .98945 L F
0 g
.32189 .98945 m
.32634 .99421 L
s
.67644 .55845 m
.68092 .53531 L
s
.48333 .93787 m .48736 .94612 L .48796 .94409 L 0 .663 .432 r
F
.50045 .95391 m .48736 .94612 L .49238 .9525 L 0 .513 .405 r
F
.50045 .95391 m .48796 .94409 L .48736 .94612 L F
0 g
.48153 .94296 m
.48736 .94612 L
s
.45551 .59294 m .4555 .58078 L .4518 .58014 L 0 1 .331 r
F
0 g
.4555 .58078 m
.45963 .57605 L
s
.4555 .58078 m
.45709 .58626 L
s
.56327 .66516 m
.56372 .57539 L
s
.25386 .77755 m .24868 .78665 L .25292 .78553 L 0 1 .482 r
F
.25386 .77755 m .24316 .78021 L .24868 .78665 L F
0 g
.24867 .79461 m
.24868 .78665 L
s
.25292 .78553 m
.25913 .79165 L
s
.51316 .68035 m .51944 .63683 L .51736 .64893 L 0 .727 .281 r
F
.51316 .68035 m .51983 .63855 L .51944 .63683 L F
0 g
.51944 .63683 m
.51962 .63453 L
s
.51899 .66286 m
.5215 .65554 L
s
.51406 .6716 m
.51406 .67159 L
s
.51952 .66181 m
.52184 .65485 L
s
.51954 .66176 m
.52232 .65387 L
s
.76296 .57766 m .76916 .57217 L .7738 .57638 L 0 .27 .022 r
F
.76296 .57766 m .76452 .57271 L .76916 .57217 L F
0 g
.76612 .56758 m
.76916 .57217 L
s
.51316 .68035 m .50561 .63849 L .50526 .6399 L 0 .728 .288 r
F
.51316 .68035 m .50805 .65027 L .50561 .63849 L F
0 g
.50551 .6379 m
.50561 .63849 L
s
.51236 .67453 m
.51236 .67453 L
s
.51291 .67343 m
.51291 .67343 L
s
.67221 1.07772 m .67797 1.07974 L .68436 1.07868 L 0 .956 .363 r
F
.48122 .63336 m .47127 .623 L .47056 .62823 L 0 1 .311 r
F
0 g
.47127 .623 m
.47491 .62107 L
s
.46869 .61802 m
.47127 .623 L
s
.52276 .6584 m .52913 .63442 L .52539 .647 L 0 .678 .273 r
F
0 g
.52069 .66007 m
.52283 .65448 L
s
.52008 .66072 m
.52305 .65251 L
s
.522 .65732 m
.52343 .65368 L
s
.52207 .65222 m .52539 .647 L .52913 .63442 L 0 .709 .272 r
F
0 g
.52913 .63442 m
.52927 .63359 L
s
.52251 .63695 m
.52337 .63029 L
s
.52037 .66041 m
.52327 .65217 L
s
.52913 .63442 m
.53115 .63157 L
s
.52178 .63824 m
.52214 .63642 L
s
.44187 .75644 m .43758 .76115 L .44103 .75822 L 0 1 .302 r
F
.44187 .75644 m .43302 .76361 L .43758 .76115 L F
0 g
.43721 .76298 m
.43758 .76115 L
s
.44103 .75822 m
.44559 .75546 L
s
.44772 .79066 m .43662 .79136 L .43696 .79569 L 0 1 .478 r
F
0 g
.43194 .79572 m
.43696 .79569 L
s
.50629 .81007 m .50255 .80872 L .49926 .81103 L 0 1 .455 r
F
.49968 .959 m .50485 .96694 L .50503 .9652 L 0 .518 .407 r
F
.51805 .97623 m .50485 .96694 L .51054 .9737 L 0 .35 .342 r
F
.51805 .97623 m .50503 .9652 L .50485 .96694 L F
0 g
.49892 .96342 m
.50485 .96694 L
s
.79406 .7956 m .80064 .80619 L .80496 .80274 L 0 .775 .458 r
F
0 g
.80059 .81087 m
.80064 .80619 L
s
.79424 .8065 m
.80064 .80619 L
s
.42474 .93847 m .40887 .94275 L .41272 .94392 L 0 1 .486 r
F
0 g
.40564 .94563 m
.41272 .94392 L
s
.4562 .79683 m .45273 .79441 L .44805 .79498 L 0 1 .476 r
F
.46247 .78799 m .4562 .79683 L .46059 .79595 L 0 1 .469 r
F
.46247 .78799 m .45273 .79441 L .4562 .79683 L F
0 g
.4562 .79683 m
.45701 .8012 L
s
.49809 .99815 m .50391 1.00231 L .50409 .9998 L 0 1 .539 r
F
.51861 .99411 m .50409 .9998 L .50391 1.00231 L 0 1 .521 r
F
0 g
.50391 1.00231 m
.51025 1.00279 L
s
.49733 1.00423 m
.50391 1.00231 L
s
.50045 .95391 m .49238 .9525 L .49968 .959 L 0 .513 .405 r
F
0 g
.48736 .94612 m
.49238 .9525 L
s
.48647 .949 m
.49238 .9525 L
s
.40671 .79618 m .39796 .79163 L .39439 .79374 L 0 1 .499 r
F
.40671 .79618 m .40325 .79268 L .39796 .79163 L F
.41517 .79033 m .40325 .79268 L .40671 .79618 L 0 1 .494 r
F
0 g
.40671 .79618 m
.40684 .80053 L
s
.40671 .79618 m
.41178 .79701 L
s
.8125 .60415 m .82176 .61118 L .82474 .6123 L 0 .207 .182 r
F
0 g
.82176 .61118 m
.82479 .616 L
s
.52939 .63276 m .53004 .63365 L .53311 .62448 L 0 1 .307 r
F
.34456 .7965 m .3318 .7854 L .33168 .79238 L 0 1 .453 r
F
.34456 .7965 m .33563 .78401 L .3318 .7854 L F
.34456 .7965 m .3411 .78877 L .33563 .78401 L F
.3538 .79264 m .3411 .78877 L .34456 .7965 L 0 1 .448 r
F
0 g
.34452 .79865 m
.34456 .7965 L
s
.34456 .7965 m
.34623 .79794 L
s
.53959 .39083 m .53589 .40713 L .53526 .40063 L 0 .268 .113 r
F
.53959 .39083 m .54152 .40858 L .53589 .40713 L F
.53959 .39083 m .54839 .404 L .54152 .40858 L F
.53959 .39083 m .55269 .39417 L .54839 .404 L F
0 g
.53432 .39043 m
.53959 .39083 L
s
.50288 .89012 m
.50692 .88881 L
s
.50692 .88881 m
.50929 .8864 L
s
.50929 .8864 m
.51051 .88515 L
s
.30407 .79665 m .29948 .80333 L .30355 .80199 L 0 1 .522 r
F
.30407 .79665 m .29374 .79982 L .29948 .80333 L F
0 g
.29948 .80333 m
.29977 .80868 L
s
.30355 .80199 m
.30979 .80516 L
s
.33523 .8045 m .32181 .80277 L .32198 .8056 L 0 1 .512 r
F
.33523 .8045 m .32564 .80151 L .32181 .80277 L F
.33523 .8045 m .33139 .80225 L .32564 .80151 L F
.34445 .80081 m .33139 .80225 L .33523 .8045 L 0 1 .504 r
F
0 g
.33523 .8045 m
.34075 .80501 L
s
.33523 .8045 m
.33537 .80724 L
s
.29411 .9622 m .29389 .96721 L .29719 .96575 L 0 1 .528 r
F
0 g
.29719 .96575 m
.30585 .96677 L
s
.29411 .9622 m .28565 .96567 L .29389 .96721 L 0 1 .528 r
F
0 g
.29389 .96721 m
.29786 .97058 L
s
.78256 .90593 m .77616 .91415 L .77414 .92062 L 0 1 .521 r
F
0 g
.76577 .92577 m
.77414 .92062 L
s
.37752 .78866 m .38083 .78696 L .37718 .78871 L 0 1 .465 r
F
.38938 .78706 m .38099 .78697 L .37752 .78866 L F
.38099 .78697 m .38083 .78696 L .37752 .78866 L F
.38938 .78706 m .38606 .78626 L .38083 .78696 L F
.39849 .78188 m .38606 .78626 L .38938 .78706 L 0 1 .442 r
F
.39849 .78188 m .38644 .78423 L .38606 .78626 L F
.39839 .78732 m .38656 .78427 L .38602 .78856 L 0 1 .501 r
F
.38656 .78427 m .38643 .78433 L .38602 .78856 L F
.39839 .78732 m .39439 .79374 L .39796 .79163 L F
.39839 .78732 m .38927 .79242 L .39439 .79374 L F
.38083 .78696 m .38083 .78696 L .38063 .78706 L 0 1 .465 r
F
.38083 .78696 m .38063 .78706 L .37718 .78871 L F
.37782 .7889 m .38083 .78696 L .37718 .78871 L 0 1 .504 r
F
.38927 .79242 m .38114 .78716 L .37782 .7889 L F
.38114 .78716 m .38083 .78696 L .37782 .7889 L F
.38927 .79242 m .38602 .78856 L .38126 .7871 L F
.38114 .78716 m .38126 .7871 L .38083 .78696 L F
.38927 .79242 m .38126 .7871 L .38114 .78716 L F
.3865 .78428 m .38643 .78431 L .38643 .78438 L 0 1 .42 r
F
.39839 .78732 m .38602 .78856 L .38927 .79242 L 0 1 .501 r
F
.38649 .78435 m .38643 .78438 L .38597 .79086 L 0 1 .42 r
F
.3865 .78428 m .38643 .78438 L .38649 .78435 L F
.39829 .79276 m .38655 .78432 L .38597 .79086 L F
.38655 .78432 m .3865 .78428 L .38649 .78435 L F
.38655 .78432 m .38649 .78435 L .38597 .79086 L F
.38656 .78427 m .38644 .78423 L .38643 .78433 L 0 1 .501 r
F
.3865 .78428 m .38644 .78423 L .38643 .78431 L 0 1 .42 r
F
0 g
.39394 .78617 m
.39454 .78605 L
s
.53096 .63527 m .53153 .63654 L .53476 .62826 L 0 1 .308 r
F
0 g
.53337 .63181 m
.53476 .62826 L
s
.53333 .63193 m
.53337 .63181 L
s
.5317 .63155 m
.53172 .63144 L
s
.53172 .63144 m
.53232 .62844 L
s
.53232 .62844 m
.53311 .62448 L
s
.53135 .62973 m
.53176 .6285 L
s
.53176 .6285 m
.53311 .62448 L
s
.50355 .64882 m .50381 .64719 L .50126 .63842 L 0 .876 .294 r
F
0 g
.50126 .63842 m
.50139 .63887 L
s
.50339 .64301 m
.5035 .64324 L
s
.50307 .64233 m
.50339 .64301 L
s
.50126 .63842 m
.50162 .6392 L
s
.50223 .63338 m
.50401 .63912 L
s
.50352 .63894 m
.50398 .64094 L
s
.50325 .63775 m
.50352 .63894 L
s
.38915 .79678 m
.38927 .79242 L
s
.79275 .69936 m .79362 .71453 L .7981 .71654 L 0 1 .497 r
F
.79275 .69936 m .79132 .70718 L .79362 .71453 L F
0 g
.78832 .71926 m
.79362 .71453 L
s
.45389 .92587 m
.45994 .92264 L
s
.47592 1.00364 m .46744 1.00271 L .46009 1.00411 L 0 1 .541 r
F
0 g
.46009 1.00411 m
.46744 1.00271 L
s
.47592 1.00364 m
.4817 1.00667 L
s
.50889 .68188 m .50462 .68781 L .50377 .68855 L 0 0 0 r
F
0 g
.50183 .69175 m
.50377 .68855 L
s
.72154 .93918 m .73315 .93562 L .72973 .93527 L 0 1 .52 r
F
.73873 .92366 m .73315 .93562 L .74087 .93083 L 0 1 .519 r
F
.73873 .92366 m .72973 .93527 L .73315 .93562 L F
0 g
.73827 .93623 m
.7407 .93117 L
s
.72985 .94025 m
.73315 .93562 L
s
.43185 .7914 m .42014 .79084 L .42024 .79516 L 0 1 .487 r
F
0 g
.41508 .79461 m
.42024 .79517 L
s
.48122 .63336 m .47327 .63351 L .47759 .6353 L 0 1 .311 r
F
.48122 .63336 m .47056 .62823 L .47327 .63351 L F
.49186 .64247 m .48122 .63336 L .48405 .63912 L 0 .962 .303 r
F
.38045 .80242 m .37705 .81094 L .38046 .80911 L 0 1 .436 r
F
.38045 .80242 m .37175 .8069 L .37705 .81094 L F
.38996 .81985 m .38046 .80911 L .37705 .81094 L 0 1 .437 r
F
0 g
.37705 .81094 m
.37768 .81761 L
s
.51316 .68035 m .51898 .66289 L .51566 .67285 L 0 0 .052 r
F
.51316 .68035 m .51566 .67285 L .51898 .66289 L 0 0 .056 r
F
0 g
.51898 .66289 m
.52104 .65648 L
s
.51898 .66289 m
.51899 .66286 L
s
.27682 .97946 m .26016 .97638 L .2684 .98274 L 0 1 .537 r
F
0 g
.2684 .98274 m
.27702 .98647 L
s
.51316 .68035 m .51951 .66184 L .51589 .6724 L 0 0 .056 r
F
.51316 .68035 m .51589 .6724 L .51951 .66184 L 0 0 .058 r
F
0 g
.51951 .66184 m
.51952 .66181 L
s
.51951 .66184 m
.51954 .66176 L
s
.51838 .66411 m
.52057 .65753 L
s
.51316 .68035 m .50526 .6399 L .50744 .65274 L 0 .728 .288 r
F
0 g
.50481 .63855 m
.50526 .6399 L
s
.40762 .77648 m .40346 .78061 L .40704 .77837 L 0 1 .411 r
F
.40762 .77648 m .39849 .78188 L .40346 .78061 L F
0 g
.40342 .78258 m
.40346 .78061 L
s
.40704 .77837 m
.41215 .77681 L
s
.50889 .68188 m .50646 .68453 L .50803 .68263 L 0 0 0 r
F
.51 .67958 m .50803 .68263 L .50646 .68453 L F
0 g
.50527 .68618 m
.50646 .68453 L
s
.50596 .68476 m
.50646 .68453 L
s
.46226 .61105 m .45414 .61456 L .45831 .61513 L 0 1 .327 r
F
.46226 .61105 m .45201 .60928 L .45414 .61456 L F
.46226 .61105 m .45333 .60281 L .45201 .60928 L F
.46226 .61105 m .45729 .59873 L .45333 .60281 L F
.30437 .78786 m .29114 .77508 L .29057 .78251 L 0 1 .468 r
F
.30437 .78786 m .2954 .77388 L .29114 .77508 L F
.30437 .78786 m .30107 .77936 L .2954 .77388 L F
0 g
.30378 .79527 m
.30437 .78786 L
s
.34894 .99086 m .32935 .98564 L .33353 .99028 L 0 1 .538 r
F
0 g
.32487 .98792 m
.33353 .99028 L
s
.31706 .78367 m .30107 .77936 L .30437 .78786 L 0 1 .463 r
F
0 g
.30437 .78786 m
.31059 .79292 L
s
.56975 .51671 m .5779 .51218 L .58102 .5351 L 0 .573 .181 r
F
0 g
.57782 .48209 m
.5779 .51218 L
s
.57309 .50435 m
.5779 .51218 L
s
.51316 .68035 m .51838 .66412 L .51541 .67338 L 0 0 .048 r
F
.51316 .68035 m .51541 .67338 L .51838 .66412 L 0 0 .052 r
F
0 g
.51838 .66412 m
.52012 .65845 L
s
.51838 .66412 m
.51838 .66411 L
s
.67113 .62815 m
.67186 .63255 L
s
.67098 .62726 m
.67113 .62815 L
s
.46247 .78799 m .46059 .79595 L .46299 .79235 L 0 1 .469 r
F
.47053 .79325 m .46299 .79235 L .46059 .79595 L 0 1 .466 r
F
0 g
.46059 .79595 m
.46157 .80035 L
s
.4562 .79683 m
.46059 .79595 L
s
.68715 .94986 m .69833 .9474 L .6952 .94706 L 0 1 .492 r
F
.70486 .93807 m .69833 .9474 L .70604 .94371 L 0 1 .5 r
F
0 g
.70294 .94556 m
.70344 .94496 L
s
.69819 .94255 m
.70193 .94225 L
s
.70486 .93807 m .6952 .94706 L .69833 .9474 L 0 1 .5 r
F
0 g
.70301 .94802 m
.70511 .94503 L
s
.70511 .94503 m
.70604 .94371 L
s
.69471 .95091 m
.69833 .9474 L
s
.69833 .9474 m
.70604 .94371 L
s
.61162 .40262 m .61135 .41427 L .60891 .40638 L 0 .569 .088 r
F
.61162 .40262 m .61803 .42341 L .61135 .41427 L F
.61162 .40262 m .62446 .42768 L .61803 .42341 L F
.61162 .40262 m .62714 .42386 L .62446 .42768 L F
.61162 .40262 m .62429 .41453 L .62714 .42386 L F
0 g
.61764 .40544 m
.62429 .41453 L
s
.6116 .42457 m
.61344 .41815 L
s
.60525 .39311 m
.61162 .40262 L
s
.62452 .41458 m
.62491 .41467 L
s
.62429 .41453 m
.62452 .41458 L
s
.62491 .41467 m
.6264 .41503 L
s
.51316 .68035 m .51998 .66101 L .51609 .67204 L 0 0 .058 r
F
.51316 .68035 m .51609 .67204 L .51998 .66101 L 0 0 .059 r
F
0 g
.51998 .66101 m
.51998 .66099 L
s
.51998 .66101 m
.51999 .66098 L
s
.37175 .8069 m .3626 .79545 L .35896 .79709 L 0 1 .443 r
F
0 g
.35897 .79713 m
.35897 .79718 L
s
.35897 .79718 m
.35917 .80385 L
s
.37175 .8069 m .36808 .79966 L .3626 .79545 L 0 1 .443 r
F
.38045 .80242 m .36808 .79966 L .37175 .8069 L 0 1 .436 r
F
0 g
.37175 .8069 m
.37705 .81094 L
s
.37175 .8069 m
.37195 .81365 L
s
.44428 .87966 m .44509 .88849 L .44689 .88613 L 0 .869 .432 r
F
.45796 .8952 m .44689 .88613 L .44509 .88849 L 0 .799 .43 r
F
0 g
.44509 .88849 m
.44819 .89493 L
s
.4395 .88553 m
.44509 .88849 L
s
.43437 .99614 m .43716 1.00235 L .43899 .99978 L 0 1 .541 r
F
.45486 1.00076 m .43899 .99978 L .43716 1.00235 L F
0 g
.43716 1.00235 m
.4424 1.00569 L
s
.42941 1.00243 m
.43716 1.00235 L
s
.52764 .63119 m .52836 .63171 L .53124 .62205 L 0 1 .307 r
F
0 g
.53001 .62617 m
.53124 .62205 L
s
.52969 .62726 m
.53001 .62617 L
s
.53063 .62556 m
.53124 .62205 L
s
.52969 .63101 m
.53063 .62556 L
s
.53101 .63074 m
.53135 .62973 L
s
.43133 .86393 m .42637 .85757 L .42076 .85448 L 0 .929 .432 r
F
0 g
.42076 .85448 m
.42637 .85757 L
s
.39646 .9487 m .38134 .94971 L .37806 .95201 L 0 1 .505 r
F
.39646 .9487 m .38923 .9483 L .38134 .94971 L F
0 g
.39646 .9487 m
.39976 .95094 L
s
.40211 .94403 m .38923 .9483 L .39646 .9487 L 0 1 .493 r
F
0 g
.39646 .9487 m
.40349 .94756 L
s
.51316 .68036 m .51371 .67699 L .51444 .67251 L 0 0 .027 r
F
.51316 .68036 m .51444 .67251 L .51371 .67699 L 0 0 .025 r
F
.51316 .68036 m .51316 .68036 L .51371 .67699 L 0 0 .027 r
F
.51316 .68035 m .51804 .65197 L .51983 .63855 L 0 .727 .281 r
F
0 g
.51774 .66545 m
.51775 .66542 L
s
.51775 .66542 m
.51776 .66539 L
s
.51776 .66539 m
.51925 .66023 L
s
.51773 .6655 m
.51975 .65921 L
s
.51983 .63855 m
.52012 .63672 L
s
.51507 .64292 m
.51554 .62658 L
s
.51332 .63375 m
.51343 .64154 L
s
.51426 .64198 m
.51437 .62545 L
s
.80496 .80274 m .81135 .81302 L .81585 .80932 L 0 .834 .469 r
F
0 g
.80481 .81367 m
.81135 .81302 L
s
.47903 .79811 m .47558 .79622 L .4715 .79766 L 0 1 .464 r
F
.5025 .65736 m .49221 .63924 L .49186 .64247 L 0 .865 .295 r
F
.5025 .65736 m .49557 .64206 L .49221 .63924 L F
0 g
.50139 .63887 m
.50224 .64178 L
s
.50162 .6392 m
.50307 .64233 L
s
.48938 .63349 m
.49221 .63924 L
s
.49221 .63924 m
.49503 .6416 L
s
.52382 .65938 m .53105 .64169 L .52685 .65221 L 0 0 .059 r
F
.52335 .66208 m .52685 .65221 L .53105 .64169 L 0 0 .065 r
F
0 g
.53105 .64169 m
.53201 .6398 L
s
.53105 .64169 m
.53209 .63862 L
s
.52038 .66039 m
.52104 .65862 L
s
.52104 .65862 m
.52358 .65178 L
s
.52069 .66008 m
.52166 .65739 L
s
.52166 .65739 m
.52376 .65159 L
s
.52247 .65665 m
.52304 .65514 L
s
.52304 .65514 m
.52369 .65346 L
s
.5233 .65487 m
.52365 .65403 L
s
.52359 .65466 m
.52367 .65447 L
s
.38996 .81985 m .386 .81293 L .38046 .80911 L 0 1 .437 r
F
.39803 .81487 m .38996 .81985 L .39529 .82352 L 0 1 .429 r
F
.39803 .81487 m .386 .81293 L .38996 .81985 L F
0 g
.38996 .81985 m
.39058 .82652 L
s
.50721 .88629 m
.51041 .88478 L
s
.47056 .62823 m .46454 .61662 L .46076 .61995 L 0 1 .321 r
F
0 g
.46226 .61105 m
.46454 .61662 L
s
.45796 .8952 m .45413 .90115 L .45965 .90403 L 0 .799 .43 r
F
0 g
.45413 .90115 m
.45753 .90751 L
s
.64434 .47734 m .65333 .50068 L .64695 .47165 L 0 .265 .248 r
F
.64434 .47734 m .65829 .52826 L .65333 .50068 L F
.64434 .47734 m .65925 .54539 L .65829 .52826 L F
.64434 .47734 m .65555 .54052 L .65925 .54539 L F
.64434 .47734 m .64915 .51126 L .65555 .54052 L F
0 g
.64319 .5059 m
.64626 .52448 L
s
.64293 .46884 m
.64434 .47734 L
s
.64394 .47012 m
.64434 .47734 L
s
.52128 .6465 m .5216 .64873 L .52444 .6382 L 0 .733 .272 r
F
0 g
.52064 .63895 m
.5222 .62344 L
s
.52151 .63957 m
.52178 .63824 L
s
.52085 .64289 m
.52151 .63957 L
s
.53233 .63869 m .53283 .64031 L .53619 .63333 L 0 1 .311 r
F
0 g
.53522 .63534 m
.53528 .6352 L
s
.53618 .63334 m
.53619 .63333 L
s
.53535 .63506 m
.53618 .63334 L
s
.53528 .6352 m
.53535 .63506 L
s
.53501 .63578 m
.53522 .63534 L
s
.53463 .63656 m
.53501 .63578 L
s
.53429 .63727 m
.53463 .63656 L
s
.53407 .63796 m
.5343 .63745 L
s
.5343 .63745 m
.53483 .63628 L
s
.53483 .63628 m
.5352 .63548 L
s
.5352 .63548 m
.53559 .63463 L
s
.53559 .63463 m
.53568 .63444 L
s
.53568 .63444 m
.53575 .63428 L
s
.53575 .63428 m
.53578 .6342 L
s
.53578 .6342 m
.53591 .63393 L
s
.53591 .63393 m
.53592 .63392 L
s
.53592 .63392 m
.53596 .63382 L
s
.53596 .63382 m
.53598 .63377 L
s
.53598 .63377 m
.53602 .63369 L
s
.53602 .63369 m
.53605 .63361 L
s
.53605 .63361 m
.53611 .63349 L
s
.53611 .63349 m
.53617 .63336 L
s
.53617 .63336 m
.53619 .63332 L
s
.53333 .6344 m
.53476 .62826 L
s
.53254 .63395 m
.53333 .63193 L
s
.42949 .93348 m .43124 .93653 L .43303 .93448 L 0 1 .467 r
F
.42949 .93348 m .42474 .93847 L .43124 .93653 L F
0 g
.43124 .93653 m
.43532 .93721 L
s
.5357 .6349 m
.53578 .63463 L
s
.53578 .63463 m
.53581 .63454 L
s
.53581 .63454 m
.53592 .63417 L
s
.53592 .63417 m
.53598 .63398 L
s
.53598 .63398 m
.53619 .63333 L
s
.51316 .68035 m .51773 .6655 L .51512 .67397 L 0 0 .043 r
F
.51316 .68035 m .51512 .67397 L .51773 .6655 L 0 0 .048 r
F
0 g
.51773 .6655 m
.51774 .66545 L
s
.51773 .6655 m
.51773 .6655 L
s
.22177 .78542 m .20809 .76916 L .2075 .77762 L 0 1 .491 r
F
.22177 .78542 m .21247 .76828 L .20809 .76916 L F
.22177 .78542 m .21834 .77526 L .21247 .76828 L F
.23246 .78283 m .21834 .77526 L .22177 .78542 L 0 1 .488 r
F
0 g
.22116 .79384 m
.22177 .78542 L
s
.22177 .78542 m
.2275 .7922 L
s
.79275 .69936 m .7981 .71654 L .80259 .71206 L 0 1 .497 r
F
0 g
.7981 .71654 m
.79942 .72438 L
s
.35582 .98679 m .35706 .99297 L .35971 .99129 L 0 1 .538 r
F
.35582 .98679 m .34894 .99086 L .35706 .99297 L F
0 g
.35706 .99297 m
.36169 .99722 L
s
.51805 .97623 m .51054 .9737 L .51832 .98099 L 0 .35 .342 r
F
0 g
.50485 .96694 m
.51054 .9737 L
s
.50458 .96932 m
.51054 .9737 L
s
.61644 .44002 m
.61758 .44368 L
s
.61635 .43975 m
.61644 .44002 L
s
.61611 .43897 m
.61635 .43975 L
s
.6116 .42457 m
.61611 .43897 L
s
.48513 .93229 m .47657 .93161 L .48333 .93787 L 0 .637 .424 r
F
.48513 .93229 m .47226 .92524 L .47657 .93161 L F
0 g
.47075 .92847 m
.47657 .93161 L
s
.45061 .57421 m .45272 .56696 L .45174 .56136 L 0 1 .332 r
F
0 g
.45272 .56696 m
.45595 .56327 L
s
.36304 .79561 m
.36808 .79741 L
s
.74832 .93911 m .7421 .94815 L .75015 .94651 L 0 1 .535 r
F
.74832 .93911 m .73864 .94653 L .7421 .94815 L F
0 g
.73852 .95207 m
.7421 .94815 L
s
.51316 .68035 m .50493 .64131 L .50483 .64177 L 0 .736 .289 r
F
.51316 .68035 m .50744 .65275 L .50493 .64131 L F
0 g
.50489 .64115 m
.50493 .64131 L
s
.45551 .59294 m .4474 .59738 L .45136 .59771 L 0 1 .331 r
F
.45551 .59294 m .4458 .59189 L .4474 .59738 L F
.45551 .59294 m .44764 .5849 L .4458 .59189 L F
.45551 .59294 m .4518 .58014 L .44764 .5849 L F
0 g
.45551 .59294 m
.45729 .59873 L
s
.51316 .68035 m .52037 .66041 L .51626 .67179 L 0 0 .059 r
F
.51316 .68035 m .51626 .67179 L .52037 .66041 L F
0 g
.52037 .66041 m
.52038 .66039 L
s
.52037 .66041 m
.52037 .66041 L
s
.51702 .667 m
.51886 .66104 L
s
.47771 .99815 m .47592 1.00364 L .48272 1.00265 L 0 1 .542 r
F
.47771 .99815 m .46744 1.00271 L .47592 1.00364 L F
.46247 .78799 m .45221 .79005 L .45273 .79441 L 0 1 .469 r
F
0 g
.44805 .79498 m
.45273 .79441 L
s
.49102 .79144 m .48789 .80255 L .49141 .80047 L 0 1 .453 r
F
.49102 .79144 m .4843 .80083 L .48789 .80255 L F
0 g
.48789 .80255 m
.48973 .80701 L
s
.32212 .80075 m
.32212 .80075 L
s
.32675 .78039 m .32224 .78883 L .32606 .78747 L 0 1 .458 r
F
.32675 .78039 m .31707 .78367 L .32224 .78883 L F
0 g
.32224 .78883 m
.32227 .79571 L
s
.52573 .60443 m .52744 .58771 L .5259 .59791 L 0 1 .297 r
F
.52237 .60878 m .52744 .58771 L .52724 .58274 L 0 1 .304 r
F
.52237 .60878 m .5259 .59791 L .52744 .58771 L F
0 g
.52744 .58771 m
.52807 .58506 L
s
.39803 .81487 m .39529 .82352 L .39844 .82149 L 0 1 .429 r
F
.40809 .83158 m .39844 .82149 L .39529 .82352 L 0 1 .43 r
F
0 g
.39529 .82352 m
.39628 .83011 L
s
.38996 .81985 m
.39529 .82352 L
s
.499 .7949 m .49333 .805 L .497 .80655 L 0 1 .449 r
F
.499 .7949 m .49141 .80047 L .49333 .805 L F
0 g
.48973 .80701 m
.49333 .805 L
s
.5469 .64947 m
.5477 .64788 L
s
.5434 .64945 m
.54603 .64351 L
s
.45881 .50819 m .45146 .51633 L .45407 .51549 L 0 1 .226 r
F
.45881 .50819 m .45259 .51042 L .45146 .51633 L F
0 g
.4555 .5182 m
.45798 .51466 L
s
.45881 .50819 m .45671 .5017 L .45259 .51042 L 0 1 .226 r
F
.45881 .50819 m .46145 .49441 L .45671 .5017 L F
0 g
.45798 .51466 m
.45881 .50819 L
s
.49102 .79144 m .48279 .79632 L .4843 .80083 L 0 1 .453 r
F
0 g
.48045 .80255 m
.4843 .80083 L
s
.40842 .99584 m .39018 .99373 L .39486 .99746 L 0 1 .54 r
F
0 g
.38675 .99645 m
.39486 .99746 L
s
.50893 .81456 m
.5119 .81195 L
s
.51316 .68035 m .50483 .64177 L .50727 .65355 L 0 .736 .289 r
F
0 g
.51038 .62676 m
.51097 .64297 L
s
.51084 .62623 m
.51177 .64206 L
s
.5097 .62773 m
.51096 .64289 L
s
.50442 .64046 m
.50483 .64177 L
s
.41922 .84792 m .41464 .84143 L .40907 .83817 L 0 .981 .431 r
F
0 g
.40907 .83817 m
.41464 .84143 L
s
.41922 .84792 m
.42076 .85448 L
s
.41309 .99957 m
.4209 .99996 L
s
.75746 .94269 m .75899 .95026 L .76659 .94618 L 0 1 .537 r
F
0 g
.75589 .95446 m
.75899 .95026 L
s
.75073 .95212 m
.75899 .95026 L
s
.46306 .48821 m .46741 .47893 L .46934 .47334 L 0 1 .153 r
F
0 g
.46741 .47893 m
.46973 .47492 L
s
.51316 .68035 m .51343 .64155 L .51328 .66368 L 0 .696 .28 r
F
.51316 .68035 m .51328 .66368 L .51343 .64155 L 0 .691 .281 r
F
0 g
.51343 .64154 m
.51343 .64155 L
s
.51343 .64155 m
.5139 .6252 L
s
.46939 .91668 m .47226 .92524 L .47327 .92301 L 0 .745 .435 r
F
.48513 .93229 m .47327 .92301 L .47226 .92524 L 0 .637 .424 r
F
0 g
.47226 .92524 m
.47657 .93161 L
s
.46657 .92226 m
.47226 .92524 L
s
.44428 .87966 m .439 .8734 L .43341 .87044 L 0 .869 .432 r
F
0 g
.43341 .87044 m
.439 .8734 L
s
.43133 .86393 m
.43341 .87044 L
s
.51316 .68035 m .5126 .6416 L .51292 .6637 L 0 .691 .281 r
F
.51316 .68035 m .51292 .6637 L .5126 .6416 L 0 .688 .281 r
F
0 g
.51201 .62532 m
.5126 .6416 L
s
.5126 .6416 m
.51272 .62507 L
s
.499 .7949 m .497 .80655 L .50025 .80417 L 0 1 .449 r
F
0 g
.497 .80655 m
.49926 .81103 L
s
.49417 .7031 m .49004 .70868 L .48725 .71249 L 0 .822 .122 r
F
.49417 .7031 m .49301 .70465 L .49004 .70868 L F
.50048 .69416 m .49301 .70465 L .49417 .7031 L 0 0 0 r
F
0 g
.49323 .70475 m
.49417 .7031 L
s
.49597 .70067 m
.49684 .69932 L
s
.55526 .51872 m .55651 .54274 L .55441 .53458 L 0 .295 .159 r
F
.55526 .51872 m .56084 .542 L .55651 .54274 L F
.55526 .51872 m .5645 .53285 L .56084 .542 L F
.55526 .51872 m .5653 .51699 L .5645 .53285 L F
.47056 .62823 m .46246 .63078 L .46679 .63157 L 0 1 .321 r
F
.47056 .62823 m .45988 .6258 L .46246 .63078 L F
.47056 .62823 m .46076 .61995 L .45988 .6258 L F
.51316 .68035 m .51702 .667 L .51482 .67462 L 0 0 .038 r
F
.51316 .68035 m .51482 .67462 L .51702 .667 L 0 0 .043 r
F
0 g
.51702 .667 m
.51702 .667 L
s
.51702 .667 m
.5183 .6622 L
s
.50048 .69416 m .49684 .69931 L .49925 .69581 L 0 0 0 r
F
.50251 .69072 m .49925 .69581 L .49684 .69931 L F
.78256 .90593 m .78554 .91502 L .79218 .90656 L 0 1 .521 r
F
0 g
.77781 .92103 m
.78554 .91502 L
s
.67922 .9354 m .69025 .93738 L .68707 .93525 L 0 1 .532 r
F
.3445 .79865 m .33159 .79249 L .33154 .79731 L 0 1 .516 r
F
.3445 .79865 m .33543 .79115 L .33159 .79249 L F
0 g
.32606 .78747 m
.33168 .79238 L
s
.3445 .79865 m .34096 .79379 L .33543 .79115 L 0 1 .516 r
F
.35374 .79483 m .34096 .79379 L .3445 .79865 L 0 1 .514 r
F
0 g
.34447 .8008 m
.3445 .79865 L
s
.3445 .79865 m
.34697 .79978 L
s
.51316 .68035 m .51426 .64198 L .51363 .66387 L 0 .702 .28 r
F
.51316 .68035 m .51363 .66387 L .51426 .64198 L 0 .696 .28 r
F
0 g
.51426 .64198 m
.51507 .62604 L
s
.51426 .64198 m
.51426 .64198 L
s
.26458 .77485 m .25928 .78383 L .26352 .78268 L 0 1 .479 r
F
.26458 .77485 m .25386 .77755 L .25928 .78383 L F
0 g
.25913 .79165 m
.25928 .78383 L
s
.26352 .78268 m
.2696 .78865 L
s
.51316 .68035 m .51178 .64212 L .51257 .66393 L 0 .688 .281 r
F
.51316 .68035 m .51257 .66393 L .51178 .64212 L 0 .689 .283 r
F
0 g
.51177 .64206 m
.51178 .64212 L
s
.51154 .62561 m
.51178 .64212 L
s
.48326 .78755 m .47903 .79811 L .48279 .79632 L 0 1 .455 r
F
.48326 .78755 m .47558 .79622 L .47903 .79811 L F
0 g
.47903 .79811 m
.48045 .80255 L
s
.28343 .80294 m .26939 .79379 L .26917 .79948 L 0 1 .524 r
F
.28343 .80294 m .27364 .79273 L .26939 .79379 L F
.28343 .80294 m .27966 .79666 L .27364 .79273 L F
.29374 .79982 m .27966 .79666 L .28343 .80294 L 0 1 .523 r
F
0 g
.28319 .80861 m
.28343 .80294 L
s
.28343 .80294 m
.28929 .80664 L
s
.47247 .72931 m .46819 .73465 L .47134 .73106 L 0 .933 .187 r
F
.47247 .72931 m .46437 .73818 L .46819 .73465 L F
0 g
.46746 .73638 m
.46819 .73465 L
s
.51114 .67721 m .51068 .67816 L .50949 .67981 L 0 0 0 r
F
.50737 .41589 m .5135 .40703 L .5182 .40441 L 0 .031 .08 r
F
.52382 .65938 m .52398 .65839 L .52735 .64849 L 0 0 .059 r
F
.51316 .68035 m .52069 .66008 L .5164 .67165 L F
.51316 .68035 m .5164 .67165 L .52069 .66008 L 0 0 .058 r
F
0 g
.52069 .66008 m
.52069 .66008 L
s
.52069 .66008 m
.52069 .66007 L
s
.51628 .6686 m
.51784 .6632 L
s
.52155 .63166 m .52703 .60291 L .52573 .60443 L 0 1 .321 r
F
.52155 .63166 m .52653 .61048 L .52703 .60291 L F
0 g
.52703 .60291 m
.52742 .60128 L
s
.52701 .6032 m
.52703 .60291 L
s
.50297 .65301 m .49557 .64206 L .4997 .64904 L 0 .872 .295 r
F
.5025 .65736 m .4997 .64904 L .49557 .64206 L 0 .865 .295 r
F
0 g
.49281 .63441 m
.49557 .64206 L
s
.49503 .6416 m
.49557 .64206 L
s
.48013 .6442 m .47759 .6353 L .47327 .63351 L 0 1 .313 r
F
.48013 .6442 m .48053 .63988 L .47759 .6353 L F
0 g
.47759 .6353 m
.48122 .63336 L
s
.59296 .54728 m
.59383 .5538 L
s
.59383 .5538 m
.59388 .55421 L
s
.59388 .55421 m
.59409 .55574 L
s
.59207 .54054 m
.59296 .54728 L
s
.58942 .5206 m
.59159 .53695 L
s
.59159 .53695 m
.59207 .54054 L
s
.36304 .78868 m .35896 .79709 L .3626 .79545 L 0 1 .441 r
F
.36299 .79091 m .35896 .79709 L .3626 .79545 L 0 1 .512 r
F
.36304 .78868 m .3538 .79264 L .35896 .79709 L 0 1 .441 r
F
.36299 .79091 m .35374 .79483 L .35896 .79709 L 0 1 .512 r
F
.36293 .79314 m .35896 .79709 L .3626 .79545 L 0 1 .48 r
F
.36293 .79314 m .35368 .79703 L .35896 .79709 L F
0 g
.36263 .79545 m
.36265 .79545 L
s
.36265 .79545 m
.36272 .79545 L
s
.36272 .79545 m
.36283 .79544 L
s
.36283 .79544 m
.36807 .79521 L
s
.35896 .79709 m
.35897 .79713 L
s
.3626 .79545 m
.36263 .79545 L
s
.36273 .7955 m
.36284 .79554 L
s
.3626 .79545 m
.36273 .7955 L
s
.36284 .79554 m
.36304 .79561 L
s
.35893 .79709 m
.35896 .79709 L
s
.35889 .79709 m
.35893 .79709 L
s
.43437 .99614 m .41626 .99632 L .4209 .99995 L 0 1 .541 r
F
.51316 .68035 m .50453 .64327 L .50423 .64481 L 0 .741 .289 r
F
.51316 .68035 m .50727 .65355 L .50453 .64327 L F
0 g
.50401 .64105 m
.50453 .64327 L
s
.50859 .62976 m
.51018 .64431 L
s
.50925 .62848 m
.51018 .64434 L
s
.29344 .80846 m .28906 .81319 L .29313 .81192 L 0 1 .525 r
F
.29344 .80846 m .28311 .8114 L .28906 .81319 L F
0 g
.28906 .81319 m
.2896 .8167 L
s
.29313 .81192 m
.29388 .81208 L
s
.71246 .62444 m
.71508 .62839 L
s
.71197 .62371 m
.71246 .62444 L
s
.71141 .62286 m
.71197 .62371 L
s
.49186 .64247 m .48405 .63912 L .48836 .64242 L 0 .962 .303 r
F
.49114 .65055 m .48405 .63912 L .48053 .63988 L 0 .945 .304 r
F
.49114 .65055 m .48836 .64242 L .48405 .63912 L F
0 g
.48122 .63336 m
.48405 .63912 L
s
.4828 .63939 m
.48405 .63912 L
s
.50714 .79789 m .50255 .80872 L .50629 .81007 L 0 1 .446 r
F
.50714 .79789 m .50025 .80417 L .50255 .80872 L F
0 g
.49926 .81103 m
.50255 .80872 L
s
.43302 .76361 m .42186 .76869 L .42126 .77054 L 0 1 .362 r
F
.43302 .76361 m .4256 .76613 L .42186 .76869 L F
.43302 .76361 m .43039 .76396 L .4256 .76613 L F
.44187 .75644 m .43039 .76396 L .43302 .76361 L 0 1 .302 r
F
0 g
.43302 .76361 m
.43758 .76115 L
s
.43241 .76546 m
.43302 .76361 L
s
.48408 .71646 m .47605 .72557 L .47504 .72731 L 0 .896 .159 r
F
.80411 .70405 m .80482 .71945 L .8093 .72132 L 0 1 .502 r
F
.80411 .70405 m .80259 .71206 L .80482 .71945 L F
0 g
.79942 .72438 m
.80482 .71945 L
s
.52237 .60878 m .52724 .58274 L .52543 .58631 L 0 1 .304 r
F
0 g
.52688 .60518 m
.52701 .6032 L
s
.52698 .60871 m
.52865 .60212 L
s
.52724 .58274 m
.52744 .58771 L
s
.52724 .58274 m
.52758 .5815 L
s
.52335 .66208 m .5335 .63921 L .53021 .64793 L 0 0 .065 r
F
.51316 .68035 m .52441 .65503 L .52101 .66297 L 0 0 .048 r
F
.51316 .68035 m .52428 .65617 L .52417 .65702 L 0 0 .045 r
F
.51316 .68035 m .52101 .66297 L .52428 .65617 L F
.52335 .66208 m .52355 .66096 L .52685 .65221 L 0 0 .065 r
F
.52276 .6584 m .53021 .64793 L .53282 .63656 L 0 .678 .273 r
F
0 g
.53165 .64163 m
.53198 .64019 L
s
.53198 .64019 m
.5321 .63967 L
s
.5321 .63967 m
.5323 .6388 L
s
.5323 .6388 m
.53282 .63656 L
s
.53282 .63656 m
.53284 .63654 L
s
.52107 .6603 m
.5233 .65487 L
s
.52092 .66004 m
.52317 .65399 L
s
.5025 .65736 m .49186 .64247 L .49482 .64903 L 0 .865 .295 r
F
0 g
.50224 .64178 m
.50269 .64334 L
s
.31354 .9866 m .29346 .97965 L .29738 .9848 L 0 1 .538 r
F
.39803 .81487 m .38558 .80631 L .386 .81293 L 0 1 .429 r
F
0 g
.38046 .80911 m
.386 .81293 L
s
.52574 .63053 m .52652 .63068 L .52918 .62093 L 0 1 .31 r
F
0 g
.52781 .63003 m
.52828 .62691 L
s
.52893 .6298 m
.52969 .62726 L
s
.51316 .68035 m .51097 .64305 L .51222 .66433 L 0 .689 .283 r
F
.51316 .68035 m .51222 .66433 L .51097 .64305 L 0 .692 .284 r
F
0 g
.51097 .64297 m
.51097 .64305 L
s
.51096 .64289 m
.51097 .64305 L
s
.51316 .68035 m .51507 .64293 L .51398 .66427 L 0 .709 .28 r
F
.51316 .68035 m .51398 .66427 L .51507 .64293 L 0 .702 .28 r
F
0 g
.51507 .64293 m
.51507 .64292 L
s
.51507 .64293 m
.51622 .62761 L
s
.51353 .67309 m
.51353 .67309 L
s
.48326 .78755 m .47449 .79174 L .47558 .79622 L 0 1 .455 r
F
0 g
.4715 .79766 m
.47558 .79622 L
s
.45061 .57421 m .45174 .56136 L .44832 .56115 L 0 1 .332 r
F
0 g
.45174 .56136 m
.45272 .56696 L
s
.70415 1.07726 m .70017 1.0801 L .71082 1.07869 L 0 .95 .341 r
F
0 g
.6904 1.08058 m
.70017 1.0801 L
s
.44991 .54906 m .45273 .54111 L .45261 .53536 L 0 1 .319 r
F
0 g
.45273 .54111 m
.45444 .53889 L
s
.51316 .68036 m .51628 .6686 L .5145 .67531 L 0 0 .033 r
F
.51316 .68035 m .5145 .67531 L .51628 .6686 L 0 0 .038 r
F
0 g
.51628 .6686 m
.51665 .66699 L
s
.51628 .6686 m
.51628 .6686 L
s
.51316 .68036 m .51382 .67676 L .5147 .67198 L 0 0 .029 r
F
.51316 .68036 m .5147 .67198 L .51382 .67676 L 0 0 .027 r
F
.51316 .68036 m .51316 .68036 L .51382 .67676 L 0 0 .029 r
F
.51316 .68035 m .5204 .64134 L .51804 .65197 L 0 .728 .282 r
F
.51316 .68035 m .52076 .64334 L .5204 .64134 L F
0 g
.5204 .64134 m
.5205 .64037 L
s
.51587 .6444 m
.51668 .62845 L
s
.31354 .9866 m .29676 .97829 L .29346 .97965 L 0 1 .538 r
F
.31354 .9866 m .30538 .98128 L .29676 .97829 L F
0 g
.29084 .98251 m
.29738 .9848 L
s
.32124 .98292 m .30538 .98128 L .31354 .9866 L 0 1 .537 r
F
0 g
.31354 .9866 m
.32189 .98945 L
s
.31354 .9866 m
.31742 .99174 L
s
.26251 .81718 m .24762 .81136 L .24778 .81548 L 0 1 .535 r
F
.26251 .81718 m .25187 .81043 L .24762 .81136 L F
.26251 .81718 m .25826 .81293 L .25187 .81043 L F
.2728 .81431 m .25826 .81293 L .26251 .81718 L 0 1 .532 r
F
0 g
.26251 .81718 m
.26264 .82126 L
s
.26251 .81718 m
.26873 .81942 L
s
.52722 .82714 m
.52735 .82699 L
s
.49133 .70688 m .48725 .71249 L .49004 .70868 L 0 0 0 r
F
.49133 .70688 m .48408 .71646 L .48725 .71249 L F
0 g
.48631 .71413 m
.48725 .71249 L
s
.42474 .93847 m .41103 .94085 L .40887 .94275 L 0 1 .486 r
F
.42474 .93847 m .41783 .93901 L .41103 .94085 L F
.42949 .93348 m .41783 .93901 L .42474 .93847 L 0 1 .467 r
F
0 g
.42474 .93847 m
.42856 .93965 L
s
.42474 .93847 m
.43124 .93653 L
s
.49371 .4286 m .48805 .4418 L .48886 .43845 L 0 0 .046 r
F
.49371 .4286 m .49205 .43778 L .48805 .4418 L F
0 g
.48816 .43725 m
.49007 .43347 L
s
.49371 .4286 m .49818 .42906 L .49205 .43778 L 0 0 .046 r
F
.49371 .4286 m .50301 .41923 L .49818 .42906 L F
0 g
.49007 .43347 m
.49371 .4286 L
s
.67958 .94919 m .68715 .94986 L .69051 .94666 L 0 1 .468 r
F
.50297 .65301 m .50319 .65131 L .50041 .64366 L 0 .872 .295 r
F
0 g
.50041 .64366 m
.50186 .64604 L
s
.50314 .64488 m
.50316 .64496 L
s
.50269 .64334 m
.50314 .64488 L
s
.48013 .6442 m .47327 .63351 L .46964 .636 L 0 1 .313 r
F
0 g
.47056 .62823 m
.47327 .63351 L
s
.22113 .799 m .21638 .80656 L .22061 .80556 L 0 1 .527 r
F
.22113 .799 m .21044 .8013 L .21638 .80656 L F
0 g
.21638 .80656 m
.2169 .81313 L
s
.22061 .80556 m
.22733 .81045 L
s
.38927 .79242 m
.39439 .79374 L
s
.39439 .79374 m
.39453 .79809 L
s
.5334 .63946 m
.5335 .63921 L
s
.5335 .63921 m
.53407 .63796 L
s
.70415 1.07726 m .69387 1.07839 L .68799 1.07981 L 0 .95 .341 r
F
0 g
.67797 1.07974 m
.68799 1.07981 L
s
.6406 .50885 m
.64131 .5146 L
s
.64131 .5146 m
.64221 .52188 L
s
.64314 .52947 m
.64407 .537 L
s
.64221 .52188 m
.64314 .52947 L
s
.64407 .537 m
.64427 .53866 L
s
.64427 .53866 m
.64434 .53917 L
s
.64434 .53917 m
.64476 .54261 L
s
.64476 .54261 m
.64515 .54578 L
s
.64515 .54578 m
.64581 .55106 L
s
.64607 .5532 m
.64614 .55381 L
s
.64643 .55612 m
.6466 .55752 L
s
.47771 .99815 m .46182 1.00046 L .46744 1.00271 L 0 1 .542 r
F
.34894 .99086 m .33234 .98412 L .32935 .98564 L 0 1 .538 r
F
.34894 .99086 m .34074 .98636 L .33234 .98412 L F
.35582 .98679 m .34074 .98636 L .34894 .99086 L F
0 g
.34894 .99086 m
.35309 .99548 L
s
.34894 .99086 m
.35706 .99297 L
s
.50714 .79789 m .50629 .81007 L .50924 .80739 L 0 1 .446 r
F
0 g
.50629 .81007 m
.50893 .81456 L
s
.74004 .5557 m .74697 .56909 L .74241 .56475 L 0 .391 .063 r
F
.74004 .5557 m .75151 .56763 L .74697 .56909 L F
.43991 .7841 m .43662 .79136 L .43975 .78838 L 0 1 .48 r
F
.43991 .7841 m .43185 .7914 L .43662 .79136 L F
.44772 .79066 m .43975 .78838 L .43662 .79136 L 0 1 .478 r
F
0 g
.43662 .79136 m
.43696 .79569 L
s
.47771 .99815 m .48272 1.00265 L .48332 1.0004 L 0 1 .542 r
F
.49809 .99815 m .48332 1.0004 L .48272 1.00265 L 0 1 .539 r
F
0 g
.48272 1.00265 m
.48873 1.00429 L
s
.47592 1.00364 m
.48272 1.00265 L
s
.51316 .68036 m .51199 .67765 L .51184 .67577 L 0 0 .026 r
F
0 g
.51099 .67689 m
.51184 .67577 L
s
.49114 .65055 m .4914 .64732 L .48836 .64242 L 0 .945 .304 r
F
0 g
.48836 .64242 m
.49186 .64247 L
s
.23246 .78283 m .21904 .76695 L .21834 .77526 L 0 1 .488 r
F
.23246 .78283 m .22342 .76606 L .21904 .76695 L F
.23246 .78283 m .22918 .77288 L .22342 .76606 L F
.24316 .78021 m .22918 .77288 L .23246 .78283 L 0 1 .485 r
F
0 g
.23174 .7911 m
.23246 .78283 L
s
.23246 .78283 m
.23808 .78944 L
s
.42609 .84187 m .41922 .84792 L .42464 .85095 L 0 .952 .422 r
F
.42609 .84187 m .41464 .84143 L .41922 .84792 L F
.28527 .97619 m .28523 .98305 L .28852 .98169 L 0 1 .537 r
F
0 g
.28852 .98169 m
.29084 .98251 L
s
.28527 .97619 m .27682 .97946 L .28523 .98305 L 0 1 .537 r
F
0 g
.28523 .98305 m
.28939 .98834 L
s
.52052 .4647 m .51726 .47221 L .5171 .47458 L 0 0 0 r
F
.52052 .4647 m .52127 .45958 L .51726 .47221 L F
.51316 .68035 m .50423 .64481 L .50674 .65626 L 0 .741 .289 r
F
0 g
.51294 .67419 m
.51294 .67419 L
s
.50754 .63226 m
.50943 .64601 L
s
.50816 .63071 m
.50943 .64603 L
s
.5035 .64324 m
.50423 .64481 L
s
.50251 .69072 m .50168 .69213 L .49925 .69581 L 0 0 0 r
F
.50782 .68411 m .50251 .69072 L .50462 .68781 L F
.50782 .68411 m .50168 .69213 L .50251 .69072 L F
0 g
.50251 .69072 m
.50305 .68997 L
s
.36267 .7955 m
.36808 .79966 L
s
.3626 .79545 m
.36267 .7955 L
s
.49114 .65055 m .48053 .63988 L .48013 .6442 L 0 .945 .304 r
F
0 g
.47759 .6353 m
.48053 .63988 L
s
.48053 .63988 m
.4828 .63939 L
s
.69624 .92952 m .69025 .93738 L .69782 .93701 L 0 1 .531 r
F
.69624 .92952 m .68707 .93525 L .69025 .93738 L F
0 g
.68691 .9409 m
.69025 .93738 L
s
.49102 .79144 m .49141 .80047 L .49253 .79596 L 0 1 .453 r
F
.499 .7949 m .49253 .79596 L .49141 .80047 L 0 1 .449 r
F
0 g
.49141 .80047 m
.49333 .805 L
s
.48789 .80255 m
.49141 .80047 L
s
.80411 .70405 m .8093 .72132 L .81386 .71658 L 0 1 .502 r
F
0 g
.8093 .72132 m
.81052 .72918 L
s
.43185 .7914 m .42358 .78822 L .42014 .79084 L 0 1 .487 r
F
.43185 .7914 m .4286 .78846 L .42358 .78822 L F
.43991 .7841 m .4286 .78846 L .43185 .7914 L 0 1 .48 r
F
0 g
.43185 .7914 m
.43662 .79136 L
s
.43185 .7914 m
.43194 .79572 L
s
.47053 .79325 m .46725 .79119 L .46299 .79235 L 0 1 .466 r
F
.52237 .60878 m .52373 .60694 L .5259 .59791 L 0 1 .304 r
F
.52155 .63166 m .52573 .60443 L .52359 .61349 L 0 1 .321 r
F
.52543 .58631 m .52599 .57782 L .5249 .5842 L 0 1 .233 r
F
.52237 .60878 m .52543 .58631 L .52326 .59534 L 0 1 .304 r
F
.51931 .63326 m .52373 .60694 L .52237 .60878 L 0 1 .328 r
F
.51931 .63326 m .52359 .61349 L .52373 .60694 L F
.52155 .63166 m .52359 .61349 L .52205 .62407 L 0 1 .321 r
F
.51931 .63326 m .52205 .62407 L .52359 .61349 L 0 1 .328 r
F
.52082 .5952 m .5249 .5842 L .52599 .57782 L 0 1 .23 r
F
.52082 .5952 m .52268 .59165 L .5249 .5842 L F
.52082 .5952 m .52599 .57782 L .52507 .57684 L F
.52275 .58194 m .52764 .57048 L .52839 .56818 L 0 .86 .116 r
F
.52572 .57389 m .52873 .56086 L .52742 .54393 L 0 1 .255 r
F
.52275 .58194 m .52839 .56818 L .52776 .56952 L 0 .86 .116 r
F
.52543 .58631 m .5285 .5688 L .52599 .57782 L 0 1 .233 r
F
.5285 .5688 m .52871 .56729 L .52764 .57048 L 0 .849 .109 r
F
.52871 .56729 m .52873 .56086 L .5285 .56782 L 0 .988 .249 r
F
.52871 .56729 m .52874 .56709 L .5285 .56782 L 0 .849 .109 r
F
.52871 .56729 m .5285 .56782 L .52764 .57048 L F
.52862 .6159 m .52871 .56729 L .52769 .59333 L 0 .988 .249 r
F
.52871 .56729 m .5285 .56782 L .52769 .59333 L F
.52275 .58194 m .52507 .57684 L .52764 .57048 L 0 .86 .116 r
F
.52697 .57118 m .52873 .56086 L .52572 .57389 L 0 1 .255 r
F
.52798 .56898 m .52798 .56895 L .52697 .57118 L F
.52798 .56895 m .52873 .56086 L .52697 .57118 L F
.52404 .57758 m .52572 .57389 L .52404 .57749 L F
.52399 .57773 m .52418 .57727 L .52404 .57758 L 0 .86 .116 r
F
.52275 .58194 m .52572 .57393 L .52399 .57773 L F
.52572 .57393 m .52572 .57389 L .52404 .57758 L 0 1 .255 r
F
.52572 .57389 m .52742 .54393 L .52404 .57749 L F
.52572 .57393 m .52578 .57377 L .52399 .57773 L 0 .86 .116 r
F
.52578 .57377 m .52748 .56917 L .52419 .57725 L F
.52578 .57377 m .52419 .57725 L .52399 .57773 L F
.52213 .58175 m .52465 .55362 L .52211 .58097 L 0 1 .255 r
F
.52275 .58194 m .52798 .56898 L .52572 .57393 L 0 .86 .116 r
F
.52237 .60878 m .52326 .59534 L .52217 .60381 L 0 1 .304 r
F
.51891 .61375 m .52326 .59534 L .52268 .59165 L 0 1 .311 r
F
.51891 .61375 m .52217 .60381 L .52326 .59534 L F
.51891 .61375 m .52268 .59165 L .52082 .5952 L F
.52082 .5952 m .52507 .57684 L .52275 .58194 L 0 1 .23 r
F
.52082 .5952 m .52275 .58194 L .52053 .5894 L F
.51947 .5867 m .52211 .58097 L .52044 .56781 L 0 1 .263 r
F
.51744 .59032 m .52044 .56781 L .5176 .57704 L F
.51743 .59042 m .51763 .58999 L .51744 .59032 L 0 .892 .132 r
F
.51686 .59383 m .51947 .5867 L .51743 .59042 L F
.51947 .5867 m .51947 .58665 L .51744 .59032 L 0 1 .263 r
F
.51947 .58665 m .52044 .56781 L .51744 .59032 L F
.51686 .59383 m .51744 .59032 L .51535 .59451 L 0 .892 .132 r
F
.51947 .5867 m .51951 .58659 L .51743 .59042 L F
.51951 .58659 m .52046 .58399 L .51764 .58996 L F
.51951 .58659 m .51764 .58996 L .51743 .59042 L F
.51508 .65812 m .51793 .63449 L .517 .63542 L 0 1 .347 r
F
.517 .63542 m .51739 .62153 L .51677 .62986 L 0 1 .335 r
F
.51464 .63802 m .51739 .62153 L .5168 .61692 L 0 1 .342 r
F
.51464 .63802 m .51677 .62986 L .51739 .62153 L F
.51538 .6191 m .51833 .61007 L .51896 .6031 L 0 1 .318 r
F
.51538 .6191 m .5168 .61692 L .51833 .61007 L F
.51316 .68035 m .51587 .6444 L .51432 .66491 L 0 .717 .28 r
F
.51316 .68035 m .51432 .66491 L .51587 .6444 L 0 .709 .28 r
F
.51508 .65812 m .517 .63542 L .51583 .64277 L 0 1 .347 r
F
.51464 .63802 m .51559 .63693 L .51677 .62986 L 0 1 .342 r
F
.51538 .6191 m .51896 .6031 L .51801 .60046 L 0 1 .318 r
F
.51464 .63802 m .5168 .61692 L .51538 .6191 L 0 1 .342 r
F
.51612 .60391 m .5199 .59424 L .52053 .5894 L 0 1 .235 r
F
.51612 .60391 m .51801 .60046 L .5199 .59424 L F
.51538 .6191 m .51612 .60391 L .51458 .61078 L 0 1 .318 r
F
.51538 .6191 m .51801 .60046 L .51612 .60391 L F
.51612 .60391 m .52053 .5894 L .51923 .58922 L 0 1 .235 r
F
.51612 .60391 m .51497 .60006 L .51481 .60374 L F
.51612 .60391 m .51686 .59383 L .51497 .60006 L F
.51612 .60391 m .51923 .58922 L .51686 .59383 L F
.51686 .59383 m .51923 .58922 L .52148 .58404 L 0 .892 .132 r
F
.51686 .59383 m .52148 .58404 L .5221 .58181 L F
.52275 .58194 m .52213 .58174 L .52148 .58404 L 0 .86 .116 r
F
.51891 .61375 m .52031 .6117 L .52217 .60381 L 0 1 .311 r
F
.517 .63542 m .52054 .61725 L .52031 .6117 L 0 1 .335 r
F
.517 .63542 m .51945 .6267 L .52054 .61725 L F
.517 .63542 m .52031 .6117 L .51891 .61375 L F
.517 .63542 m .51793 .63449 L .51945 .6267 L F
.51689 .63686 m .52151 .60788 L .5221 .58181 L 0 1 .263 r
F
.52202 .58195 m .5221 .58181 L .52211 .58097 L F
.51686 .59383 m .5221 .58181 L .52202 .58195 L 0 .892 .132 r
F
.51891 .61375 m .52082 .5952 L .51896 .6031 L 0 1 .311 r
F
.52082 .5952 m .52053 .5894 L .5199 .59424 L 0 1 .23 r
F
.51689 .63686 m .5221 .58181 L .52202 .58195 L 0 1 .263 r
F
.52202 .58195 m .5221 .58181 L .52203 .58195 L 0 .892 .132 r
F
.52203 .58195 m .5221 .58181 L .52212 .58174 L F
.51931 .63326 m .52237 .60878 L .52054 .61725 L 0 1 .328 r
F
.52282 .62507 m .52213 .58175 L .52151 .60788 L 0 1 .255 r
F
.52213 .58174 m .52213 .58174 L .52213 .58175 L 0 .86 .116 r
F
.52213 .58175 m .52211 .58097 L .5221 .58181 L 0 1 .255 r
F
.52213 .58175 m .5221 .58181 L .52151 .60788 L F
.51686 .59383 m .51535 .59451 L .5152 .5961 L 0 .892 .132 r
F
.52075 .58437 m .52211 .58097 L .51947 .5867 L 0 1 .263 r
F
.51947 .5867 m .52212 .58174 L .52046 .58399 L 0 .892 .132 r
F
.51686 .59383 m .52185 .58234 L .51947 .5867 L F
.52202 .58198 m .52202 .58195 L .51942 .58769 L 0 1 .263 r
F
.52202 .58195 m .52211 .58097 L .52083 .58417 L F
.52185 .58234 m .52202 .58195 L .51947 .5867 L 0 .892 .132 r
F
.52202 .58195 m .52083 .58417 L .51942 .58769 L 0 1 .263 r
F
.52202 .58195 m .52212 .58174 L .51947 .5867 L 0 .892 .132 r
F
.51744 .59041 m .51947 .5867 L .51744 .59032 L 0 1 .263 r
F
.517 .63542 m .51891 .61375 L .51739 .62153 L 0 1 .335 r
F
.51689 .63686 m .51947 .5867 L .51744 .59041 L 0 1 .263 r
F
.51689 .63686 m .51744 .59032 L .51536 .60089 L F
.51744 .59032 m .5176 .57704 L .51612 .59273 L F
.51744 .59032 m .51612 .59273 L .51535 .59451 L 0 .892 .132 r
F
.51744 .59032 m .51612 .59273 L .51536 .60089 L 0 1 .263 r
F
.51744 .59032 m .51617 .59262 L .51612 .59273 L 0 .892 .132 r
F
.51744 .59032 m .51761 .58931 L .51617 .59262 L F
.51744 .59032 m .52046 .58399 L .51761 .58931 L F
.51763 .58999 m .52046 .58399 L .51744 .59032 L F
.51942 .58769 m .52075 .58437 L .51947 .5867 L 0 1 .263 r
F
.52213 .58174 m .52213 .58175 L .52148 .58404 L 0 .86 .116 r
F
.52213 .58174 m .5221 .58181 L .52148 .58404 L F
.51891 .61375 m .51896 .6031 L .51833 .61007 L 0 1 .311 r
F
.51689 .63686 m .52202 .58198 L .51942 .58769 L 0 1 .263 r
F
.52213 .58174 m .52212 .58174 L .5221 .58181 L 0 .86 .116 r
F
.52404 .57758 m .52465 .55362 L .52213 .58174 L 0 1 .255 r
F
.52404 .57749 m .52742 .54393 L .52465 .55362 L F
.52213 .58174 m .52469 .57536 L .52212 .58174 L 0 .86 .116 r
F
.52275 .58194 m .52404 .57758 L .52213 .58174 L F
.52404 .57758 m .52469 .57536 L .52213 .58174 L F
.52404 .57758 m .52213 .58174 L .52213 .58175 L 0 1 .255 r
F
.52282 .62507 m .52403 .57762 L .52213 .58175 L F
.52403 .57762 m .52404 .57758 L .52264 .58063 L F
.52403 .57762 m .52264 .58063 L .52213 .58175 L F
.52282 .62507 m .52572 .57393 L .52404 .57758 L F
.52404 .57758 m .52748 .56917 L .52469 .57536 L 0 .86 .116 r
F
.52418 .57727 m .52748 .56917 L .52404 .57758 L F
.52776 .56952 m .52839 .56818 L .52849 .56788 L F
.52282 .62507 m .52769 .59333 L .5285 .56782 L 0 1 .255 r
F
.52798 .56898 m .5285 .56782 L .52873 .56086 L F
.52798 .56898 m .52849 .56788 L .5285 .56782 L 0 .86 .116 r
F
.52776 .56952 m .52849 .56788 L .52798 .56898 L F
.52282 .62507 m .5285 .56782 L .52798 .56898 L 0 1 .255 r
F
.52798 .56898 m .5285 .56782 L .52874 .56709 L 0 .86 .116 r
F
.52572 .57393 m .52874 .56709 L .52748 .56917 L F
.52572 .57393 m .52798 .56898 L .52572 .57389 L 0 1 .255 r
F
.52798 .56898 m .52874 .56709 L .52572 .57393 L 0 .86 .116 r
F
.52282 .62507 m .52798 .56898 L .52572 .57393 L 0 1 .255 r
F
0 g
.52742 .54393 m
.52873 .56086 L
s
.52711 .62852 m
.52918 .62093 L
s
.52659 .60969 m
.52688 .60518 L
s
.52742 .54393 m
.53027 .51689 L
s
.52828 .62691 m
.52918 .62093 L
s
.52873 .56086 m
.52913 .55622 L
s
.51316 .68035 m .51018 .64438 L .51188 .6649 L 0 .692 .284 r
F
.51316 .68035 m .51188 .6649 L .51018 .64438 L 0 .698 .285 r
F
0 g
.51018 .64431 m
.51018 .64438 L
s
.51018 .64434 m
.51018 .64438 L
s
.51244 .67512 m
.51244 .67512 L
s
.4373 .85763 m .42637 .85757 L .43133 .86393 L 0 .897 .423 r
F
.4373 .85763 m .42464 .85095 L .42637 .85757 L F
0 g
.42637 .85757 m
.42637 .85757 L
s
.42609 .84187 m .41344 .8348 L .41464 .84143 L 0 .952 .422 r
F
.51316 .68035 m .52092 .66004 L .5165 .67163 L 0 0 .058 r
F
.51316 .68035 m .5165 .67163 L .52092 .66004 L 0 0 .056 r
F
0 g
.52092 .66004 m
.52092 .66004 L
s
.52092 .66004 m
.52092 .66004 L
s
.5155 .67027 m
.51672 .66566 L
s
.41517 .79033 m .40333 .7884 L .40325 .79268 L 0 1 .494 r
F
0 g
.39796 .79163 m
.40325 .79268 L
s
.5164 .63915 m
.51681 .63513 L
s
.53772 .98082 m
.53775 .9808 L
s
.53775 .9808 m
.53776 .9808 L
s
.48326 .78755 m .48279 .79632 L .48436 .79203 L 0 1 .455 r
F
.49102 .79144 m .48436 .79203 L .48279 .79632 L 0 1 .453 r
F
0 g
.48279 .79632 m
.4843 .80083 L
s
.47903 .79811 m
.48279 .79632 L
s
.45013 .92536 m .43573 .93145 L .4395 .93194 L 0 1 .452 r
F
0 g
.43303 .93448 m
.4395 .93194 L
s
.51861 .99411 m .51039 .99628 L .50409 .9998 L 0 1 .521 r
F
.51833 .98899 m .51861 .99411 L .52459 .991 L 0 1 .526 r
F
.51833 .98899 m .51039 .99628 L .51861 .99411 L F
0 g
.51861 .99411 m
.52494 .9946 L
s
.3538 .79264 m .34138 .78189 L .3411 .78877 L 0 1 .448 r
F
.3538 .79264 m .34521 .78046 L .34138 .78189 L F
.3538 .79264 m .35054 .78507 L .34521 .78046 L F
.36304 .78868 m .35054 .78507 L .3538 .79264 L 0 1 .441 r
F
0 g
.3537 .79483 m
.3538 .79264 L
s
.3538 .79264 m
.35548 .79409 L
s
.47582 .78324 m .47053 .79325 L .47449 .79174 L 0 1 .458 r
F
.47582 .78324 m .46725 .79119 L .47053 .79325 L F
0 g
.47053 .79325 m
.4715 .79766 L
s
.40809 .83158 m .40393 .82494 L .39844 .82149 L 0 1 .43 r
F
0 g
.39844 .82149 m
.40393 .82494 L
s
.40809 .83158 m
.40907 .83817 L
s
.48408 .71646 m .4792 .72183 L .47605 .72557 L 0 .896 .159 r
F
.48408 .71646 m .48264 .71793 L .4792 .72183 L F
.49133 .70688 m .48264 .71793 L .48408 .71646 L 0 0 0 r
F
0 g
.48306 .7182 m
.48408 .71646 L
s
.48408 .71646 m
.48725 .71249 L
s
.75677 .92478 m .76861 .92006 L .76493 .91974 L 0 1 .526 r
F
.74776 .92407 m .75677 .92478 L .7594 .91935 L 0 1 .523 r
F
.31678 .79267 m .31037 .79972 L .31539 .79804 L 0 1 .52 r
F
.31678 .79267 m .30407 .79665 L .31037 .79972 L F
0 g
.30979 .80516 m
.31037 .79972 L
s
.31539 .79804 m
.32212 .80075 L
s
.31146 .94416 m .31082 .94702 L .31413 .94547 L 0 1 .327 r
F
0 g
.31413 .94547 m
.32236 .94411 L
s
.31146 .94416 m .30296 .94783 L .31082 .94702 L 0 1 .327 r
F
0 g
.31082 .94702 m
.31433 .94821 L
s
.5237 .63071 m .52653 .61048 L .52456 .62211 L 0 1 .315 r
F
.52155 .63166 m .52456 .62211 L .52653 .61048 L 0 1 .321 r
F
0 g
.52653 .61048 m
.52698 .60871 L
s
.52653 .61048 m
.52659 .60969 L
s
.38243 .99232 m .36369 .98879 L .36802 .99292 L 0 1 .539 r
F
0 g
.35971 .99129 m
.36802 .99292 L
s
.73873 .92366 m .74087 .93083 L .74776 .92407 L 0 1 .519 r
F
0 g
.73315 .93562 m
.74087 .93083 L
s
.7407 .93117 m
.74087 .93083 L
s
.45988 .6258 m .46076 .61995 L .45831 .61513 L 0 1 .331 r
F
0 g
.46076 .61995 m
.46454 .61662 L
s
.4373 .85763 m .43133 .86393 L .43675 .8668 L 0 .897 .423 r
F
.51316 .68036 m .5155 .67027 L .51417 .67602 L 0 0 .029 r
F
.51316 .68036 m .51417 .67602 L .5155 .67027 L 0 0 .033 r
F
0 g
.5155 .67027 m
.51612 .66688 L
s
.5155 .67027 m
.5155 .67027 L
s
.46306 .48821 m .46934 .47334 L .46757 .47514 L 0 1 .153 r
F
0 g
.46934 .47334 m
.47406 .46452 L
s
.46741 .47893 m
.46934 .47334 L
s
.74832 .93911 m .74129 .94266 L .73864 .94653 L 0 1 .535 r
F
0 g
.73011 .94786 m
.73864 .94653 L
s
.34445 .80081 m .33139 .79959 L .33139 .80225 L 0 1 .504 r
F
.34445 .80081 m .33522 .7983 L .33139 .79959 L F
.34445 .80081 m .34082 .79882 L .33522 .7983 L F
.35368 .79703 m .34082 .79882 L .34445 .80081 L 0 1 .494 r
F
0 g
.34445 .80081 m
.34981 .8011 L
s
.34444 .80346 m
.34445 .80081 L
s
.52582 .9907 m
.53027 .99689 L
s
.52567 .9905 m
.52582 .9907 L
s
.46437 .73818 m .45487 .74584 L .45399 .74758 L 0 1 .218 r
F
.46437 .73818 m .45833 .74258 L .45487 .74584 L F
.46437 .73818 m .46241 .7393 L .45833 .74258 L F
.47247 .72931 m .46241 .7393 L .46437 .73818 L 0 .933 .187 r
F
0 g
.46437 .73818 m
.46819 .73465 L
s
.46349 .73992 m
.46437 .73818 L
s
.47134 .73106 m
.47504 .72731 L
s
.499 .7949 m .50025 .80417 L .50092 .79944 L 0 1 .449 r
F
.50714 .79789 m .50092 .79944 L .50025 .80417 L 0 1 .446 r
F
0 g
.50025 .80417 m
.50255 .80872 L
s
.497 .80655 m
.50025 .80417 L
s
.44772 .79066 m .44451 .78808 L .43975 .78838 L 0 1 .478 r
F
.45493 .78235 m .44772 .79066 L .45221 .79005 L 0 1 .471 r
F
.45493 .78235 m .44451 .78808 L .44772 .79066 L F
0 g
.44772 .79066 m
.44805 .79498 L
s
.57497 .3934 m .57294 .4101 L .57135 .40056 L 0 .557 .121 r
F
0 g
.56897 .38514 m
.57497 .3934 L
s
.32947 .96151 m .31041 .95993 L .31387 .96296 L 0 1 .524 r
F
.32947 .96151 m .31372 .95848 L .31041 .95993 L F
.32947 .96151 m .3219 .95916 L .31372 .95848 L F
.33721 .9575 m .3219 .95916 L .32947 .96151 L 0 1 .519 r
F
0 g
.32947 .96151 m
.33738 .96201 L
s
.32947 .96151 m
.33289 .96453 L
s
.29448 .9515 m .27505 .95238 L .27823 .95412 L 0 1 .389 r
F
.29448 .9515 m .27864 .95111 L .27505 .95238 L F
.29448 .9515 m .28699 .95073 L .27864 .95111 L F
.30296 .94783 m .28699 .95073 L .29448 .9515 L 0 1 .36 r
F
0 g
.29448 .9515 m
.29761 .95325 L
s
.29448 .9515 m
.30256 .95091 L
s
.34545 .93511 m .32741 .93927 L .33041 .94002 L 0 1 .295 r
F
.34545 .93511 m .33073 .93773 L .32741 .93927 L F
.34545 .93511 m .33848 .93594 L .33073 .93773 L F
.35321 .93076 m .33848 .93594 L .34545 .93511 L 0 1 .254 r
F
0 g
.34545 .93511 m
.35291 .93311 L
s
.34545 .93511 m
.3484 .93586 L
s
.45061 .57421 m .44251 .57957 L .44623 .57962 L 0 1 .332 r
F
.45061 .57421 m .44153 .57397 L .44251 .57957 L F
.45061 .57421 m .44395 .56655 L .44153 .57397 L F
.45061 .57421 m .44832 .56115 L .44395 .56655 L F
0 g
.45061 .57421 m
.4518 .58014 L
s
.73873 .92366 m .73211 .93016 L .72973 .93527 L 0 1 .519 r
F
0 g
.72154 .93918 m
.72973 .93527 L
s
.50045 .95391 m .49356 .94743 L .48796 .94409 L 0 .513 .405 r
F
0 g
.52139 .87381 m
.52172 .87342 L
s
.52212 .87294 m
.52267 .87228 L
s
.424 .78394 m .42014 .79084 L .42358 .78822 L 0 1 .489 r
F
.424 .78394 m .41517 .79033 L .42014 .79084 L F
0 g
.42014 .79084 m
.42024 .79516 L
s
.51316 .68035 m .51868 .65546 L .52076 .64334 L 0 .728 .282 r
F
0 g
.52076 .64334 m
.52085 .64289 L
s
.51663 .6464 m
.51686 .64335 L
s
.41578 .82582 m .40809 .83158 L .41344 .8348 L 0 1 .422 r
F
.41578 .82582 m .40393 .82494 L .40809 .83158 L F
.53793 .42988 m .54913 .41085 L .5502 .41447 L 0 0 .08 r
F
.53793 .42988 m .54389 .41743 L .54913 .41085 L F
0 g
.54389 .41743 m
.5475 .40548 L
s
.54913 .41085 m
.55264 .39817 L
s
.54389 .41743 m
.54913 .41085 L
s
.45988 .6258 m .45831 .61513 L .45414 .61456 L 0 1 .331 r
F
0 g
.45831 .61513 m
.46226 .61105 L
s
.45831 .61513 m
.46076 .61995 L
s
.31706 .78367 m .30252 .77184 L .30107 .77936 L 0 1 .463 r
F
.31706 .78367 m .30775 .77033 L .30252 .77184 L F
.31706 .78367 m .31399 .7754 L .30775 .77033 L F
0 g
.31561 .79117 m
.31706 .78367 L
s
.32675 .78039 m .31399 .7754 L .31707 .78367 L 0 1 .458 r
F
0 g
.31707 .78367 m
.32224 .78883 L
s
.45074 .74888 m .44622 .7537 L .44967 .75061 L 0 1 .234 r
F
.45074 .74888 m .44187 .75644 L .44622 .7537 L F
0 g
.44559 .75546 m
.44622 .7537 L
s
.44967 .75061 m
.45399 .74758 L
s
.45493 .78235 m .45221 .79005 L .45499 .78666 L 0 1 .471 r
F
.46247 .78799 m .45499 .78666 L .45221 .79005 L 0 1 .469 r
F
0 g
.45221 .79005 m
.45273 .79441 L
s
.44772 .79066 m
.45221 .79005 L
s
.27531 .77211 m .26989 .78096 L .27414 .7798 L 0 1 .476 r
F
.27531 .77211 m .26458 .77485 L .26989 .78096 L F
0 g
.2696 .78865 m
.26989 .78096 L
s
.27414 .7798 m
.28008 .78561 L
s
.45796 .8952 m .45241 .88901 L .44689 .88613 L 0 .799 .43 r
F
0 g
.44689 .88613 m
.45241 .88901 L
s
.44428 .87966 m
.44689 .88613 L
s
.39849 .78188 m .39026 .78234 L .38644 .78423 L 0 1 .442 r
F
.39849 .78188 m .39543 .78133 L .39026 .78234 L F
.40762 .77648 m .39543 .78133 L .39849 .78188 L 0 1 .411 r
F
0 g
.39811 .7839 m
.39849 .78188 L
s
.39849 .78188 m
.40346 .78061 L
s
.51565 .8131 m
.51572 .8132 L
s
.52107 .66031 m
.52186 .65825 L
s
.51316 .68035 m .50943 .64604 L .51156 .66562 L 0 .698 .285 r
F
.51316 .68035 m .51156 .66562 L .50943 .64604 L 0 .707 .286 r
F
0 g
.50943 .64601 m
.50943 .64604 L
s
.50943 .64603 m
.50943 .64604 L
s
.33645 .77704 m .3318 .7854 L .33563 .78401 L 0 1 .453 r
F
.33645 .77704 m .32675 .78039 L .3318 .7854 L F
0 g
.33168 .79238 m
.3318 .7854 L
s
.33563 .78401 m
.3411 .78877 L
s
.74513 .66711 m
.74817 .66516 L
s
.50048 .69416 m .49423 .70301 L .49301 .70465 L 0 0 0 r
F
0 g
.49004 .70868 m
.49301 .70465 L
s
.81546 .70836 m .81602 .72403 L .82049 .72578 L 0 1 .506 r
F
.81546 .70836 m .81386 .71658 L .81602 .72403 L F
0 g
.81052 .72918 m
.81602 .72403 L
s
.52127 .45958 m .5314 .4353 L .52765 .44544 L 0 0 .003 r
F
0 g
.5314 .4353 m
.536 .42472 L
s
.51805 .97623 m .51068 .96917 L .50503 .9652 L 0 .35 .342 r
F
.50045 .95391 m .49968 .959 L .5053 .96236 L 0 .513 .405 r
F
0 g
.49968 .959 m
.50503 .9652 L
s
.51316 .68035 m .50381 .64719 L .50355 .64882 L 0 .748 .288 r
F
.51316 .68035 m .50674 .65626 L .50381 .64719 L F
0 g
.50316 .64496 m
.50381 .64719 L
s
.50713 .63339 m
.50872 .64801 L
s
.50654 .63519 m
.50871 .648 L
s
.44991 .54906 m .45261 .53536 L .44963 .53562 L 0 1 .319 r
F
0 g
.45261 .53536 m
.45715 .52886 L
s
.45261 .53536 m
.45273 .54111 L
s
.46911 .64113 m .46679 .63157 L .46246 .63078 L 0 1 .324 r
F
.46911 .64113 m .46964 .636 L .46679 .63157 L F
0 g
.46679 .63157 m
.47056 .62823 L
s
.47582 .78324 m .46658 .78677 L .46725 .79119 L 0 1 .458 r
F
0 g
.46299 .79235 m
.46725 .79119 L
s
.51316 .68036 m .51114 .67721 L .51199 .67765 L 0 0 .029 r
F
.51316 .68036 m .51068 .67816 L .51114 .67721 L F
0 g
.51099 .67689 m
.51114 .67721 L
s
.5434 .64945 m
.5469 .64947 L
s
.53236 .64747 m .54191 .62717 L .53858 .63791 L 0 0 .091 r
F
0 g
.54076 .6309 m
.54191 .62717 L
s
.53301 .64353 m
.53341 .64225 L
s
.53341 .64225 m
.53428 .63944 L
s
.53272 .63703 m
.53333 .6344 L
s
.53428 .63944 m
.53442 .63901 L
s
.53442 .63901 m
.5357 .6349 L
s
.53199 .63535 m
.53254 .63395 L
s
.53346 .639 m
.53429 .63727 L
s
.48513 .93229 m .48333 .93787 L .48885 .9409 L 0 .637 .424 r
F
0 g
.48333 .93787 m
.48796 .94409 L
s
.72168 .94352 m .73344 .94407 L .72998 .94241 L 0 1 .537 r
F
.71323 .93903 m .72168 .94352 L .72477 .93987 L 0 1 .535 r
F
.77292 .90556 m .76861 .92006 L .77616 .91415 L 0 1 .52 r
F
.77292 .90556 m .76493 .91974 L .76861 .92006 L F
0 g
.76577 .92577 m
.76861 .92006 L
s
.50782 .68411 m .50462 .68781 L .50663 .68533 L 0 0 0 r
F
.50889 .68188 m .50663 .68533 L .50462 .68781 L F
0 g
.50377 .68855 m
.50462 .68781 L
s
.50305 .68997 m
.50462 .68781 L
s
.45201 .60928 m .45333 .60281 L .45136 .59771 L 0 1 .338 r
F
0 g
.45333 .60281 m
.45729 .59873 L
s
.41578 .82582 m .40328 .8183 L .40393 .82494 L 0 1 .422 r
F
.48013 .6442 m .46964 .636 L .46911 .64113 L 0 1 .313 r
F
0 g
.46964 .636 m
.47327 .63351 L
s
.46679 .63157 m
.46964 .636 L
s
.76296 .57766 m .7738 .57638 L .77605 .58236 L 0 .27 .022 r
F
0 g
.7738 .57638 m
.77773 .57868 L
s
.41714 .77059 m .41252 .77487 L .41626 .77244 L 0 1 .368 r
F
.41714 .77059 m .40762 .77648 L .41252 .77487 L F
0 g
.41215 .77681 m
.41252 .77487 L
s
.41626 .77244 m
.42126 .77054 L
s
.50737 .41589 m .5182 .40441 L .51835 .40977 L 0 .031 .08 r
F
0 g
.5182 .40441 m
.52264 .39367 L
s
.5135 .40703 m
.5182 .40441 L
s
.51316 .68035 m .51663 .64641 L .51465 .66577 L 0 .723 .28 r
F
.51316 .68035 m .51465 .66577 L .51663 .64641 L 0 .717 .28 r
F
0 g
.51663 .64641 m
.51842 .63301 L
s
.51663 .64641 m
.51663 .6464 L
s
.48893 .89855 m .48704 .9033 L .49198 .89965 L 0 1 .354 r
F
.48893 .89855 m .48108 .90627 L .48704 .9033 L F
.50214 .66182 m .4914 .64732 L .49114 .65055 L 0 .855 .295 r
F
.50214 .66182 m .49482 .64903 L .4914 .64732 L F
0 g
.50041 .64366 m
.50226 .64876 L
s
.50186 .64604 m
.5032 .64824 L
s
.48836 .64242 m
.4914 .64732 L
s
.4914 .64732 m
.49394 .64859 L
s
.47582 .78324 m .47449 .79174 L .47648 .78767 L 0 1 .458 r
F
.48326 .78755 m .47648 .78767 L .47449 .79174 L 0 1 .455 r
F
0 g
.47449 .79174 m
.47558 .79622 L
s
.47053 .79325 m
.47449 .79174 L
s
.51316 .68035 m .52107 .66031 L .51656 .67174 L 0 0 .056 r
F
.51316 .68035 m .51656 .67174 L .52107 .66031 L 0 0 .053 r
F
0 g
.52107 .66031 m
.52107 .6603 L
s
.52107 .66031 m
.52107 .66031 L
s
.70486 .93807 m .69799 .94306 L .6952 .94706 L 0 1 .5 r
F
0 g
.68715 .94986 m
.6952 .94706 L
s
.41517 .79033 m .40691 .78621 L .40333 .7884 L 0 1 .494 r
F
.41517 .79033 m .41198 .78703 L .40691 .78621 L F
0 g
.41508 .79461 m
.41517 .79033 L
s
.424 .78394 m .41198 .78703 L .41517 .79033 L 0 1 .489 r
F
0 g
.41517 .79033 m
.42014 .79084 L
s
.4493 .87317 m .439 .8734 L .44428 .87966 L 0 .837 .422 r
F
.4493 .87317 m .43675 .8668 L .439 .8734 L F
0 g
.439 .8734 m
.439 .8734 L
s
.5237 .63071 m .52453 .63054 L .52695 .621 L 0 1 .315 r
F
0 g
.52483 .62936 m
.52695 .621 L
s
.52607 .62793 m
.52695 .621 L
s
.52584 .62971 m
.52607 .62793 L
s
.52686 .62945 m
.52711 .62852 L
s
.48013 .6442 m .47205 .64571 L .4765 .6467 L 0 1 .313 r
F
.48013 .6442 m .46911 .64113 L .47205 .64571 L F
.49114 .65055 m .48013 .6442 L .48317 .6491 L 0 .945 .304 r
F
0 g
.47036 .91463 m
.47483 .912 L
s
.45796 .8952 m .45965 .90403 L .46106 .90164 L 0 .799 .43 r
F
0 g
.45965 .90403 m
.46322 .91047 L
s
.45413 .90115 m
.45965 .90403 L
s
.81546 .70836 m .82049 .72578 L .82511 .72079 L 0 1 .506 r
F
0 g
.82049 .72578 m
.82161 .73368 L
s
.38916 .79779 m .38558 .80631 L .389 .80442 L 0 1 .428 r
F
.38916 .79779 m .38045 .80242 L .38558 .80631 L F
.39803 .81487 m .389 .80442 L .38558 .80631 L 0 1 .429 r
F
0 g
.38558 .80631 m
.386 .81293 L
s
.24316 .78021 m .23 .76472 L .22918 .77288 L 0 1 .485 r
F
.24316 .78021 m .23438 .76382 L .23 .76472 L F
.24316 .78021 m .24002 .77047 L .23438 .76382 L F
.25386 .77755 m .24002 .77047 L .24316 .78021 L 0 1 .482 r
F
0 g
.24232 .78833 m
.24316 .78021 L
s
.24316 .78021 m
.24868 .78665 L
s
.53211 .82691 m
.53215 .82651 L
s
.48893 .89855 m .49198 .89965 L .49261 .89776 L 0 1 .354 r
F
0 g
.48704 .9033 m
.49198 .89965 L
s
.49198 .89965 m
.49604 .89833 L
s
.50782 .68411 m .50287 .69092 L .50168 .69213 L 0 0 0 r
F
0 g
.49925 .69581 m
.50168 .69213 L
s
.38045 .80242 m .37171 .79128 L .36806 .79296 L 0 1 .436 r
F
0 g
.36806 .79302 m
.36807 .79307 L
s
.36807 .79307 m
.36808 .79966 L
s
.38045 .80242 m .37702 .79533 L .37171 .79128 L 0 1 .436 r
F
.38916 .79779 m .37702 .79533 L .38045 .80242 L 0 1 .428 r
F
0 g
.38045 .80242 m
.38558 .80631 L
s
.38045 .80242 m
.38046 .80911 L
s
.29374 .79982 m .28002 .79113 L .27966 .79666 L 0 1 .523 r
F
.29374 .79982 m .28428 .79005 L .28002 .79113 L F
.29374 .79982 m .29016 .79378 L .28428 .79005 L F
.30407 .79665 m .29016 .79378 L .29374 .79982 L 0 1 .522 r
F
0 g
.29337 .80532 m
.29374 .79982 L
s
.29374 .79982 m
.29948 .80333 L
s
.37707 .79307 m
.37718 .78879 L
s
.42609 .84187 m .42464 .85095 L .42729 .8485 L 0 .952 .422 r
F
.4373 .85763 m .42729 .8485 L .42464 .85095 L 0 .897 .423 r
F
0 g
.42464 .85095 m
.42637 .85757 L
s
.41922 .84792 m
.42464 .85095 L
s
.37875 .94732 m .37806 .95201 L .38134 .94971 L 0 1 .497 r
F
.37875 .94732 m .37024 .95284 L .37806 .95201 L F
0 g
.37806 .95201 m
.38139 .95424 L
s
.51316 .68035 m .50355 .64882 L .50629 .65911 L 0 .748 .288 r
F
0 g
.50616 .63647 m
.50805 .65026 L
s
.50561 .63849 m
.50805 .65025 L
s
.5032 .64824 m
.50355 .64882 L
s
.51 .67958 m .50955 .68051 L .50803 .68263 L 0 0 0 r
F
0 g
.50803 .68263 m
.50949 .68059 L
s
.50949 .67981 m
.51062 .67824 L
s
.51833 .98899 m .50437 .99627 L .51039 .99628 L 0 1 .526 r
F
0 g
.50409 .9998 m
.51039 .99628 L
s
.53522 .65346 m
.53709 .64923 L
s
.53499 .64991 m
.53624 .64863 L
s
.50714 .79789 m .50924 .80739 L .50944 .80245 L 0 1 .446 r
F
0 g
.50924 .80739 m
.5119 .81195 L
s
.50629 .81007 m
.50924 .80739 L
s
.51565 .8131 m
.51572 .81301 L
s
.5425 .53655 m .55131 .52556 L .55028 .53556 L 0 .092 .104 r
F
0 g
.55131 .52556 m
.55526 .51872 L
s
.51316 .68035 m .50872 .64802 L .51125 .66647 L 0 .707 .286 r
F
.51316 .68035 m .51125 .66647 L .50872 .64802 L 0 .717 .287 r
F
0 g
.50872 .64801 m
.50872 .64802 L
s
.50871 .648 m
.50872 .64802 L
s
.51286 .67522 m
.51286 .67522 L
s
.51264 .67558 m
.51264 .67558 L
s
.41578 .82582 m .41344 .8348 L .41643 .83246 L 0 1 .422 r
F
.42609 .84187 m .41643 .83246 L .41344 .8348 L 0 .952 .422 r
F
0 g
.41344 .8348 m
.41464 .84143 L
s
.40809 .83158 m
.41344 .8348 L
s
.51316 .68035 m .52417 .65702 L .52082 .66445 L 0 0 .045 r
F
.52335 .66208 m .53021 .64793 L .52621 .65649 L 0 0 .065 r
F
.52276 .6584 m .52621 .65649 L .53021 .64793 L 0 .678 .273 r
F
.51316 .68036 m .52398 .65839 L .52382 .65938 L 0 0 .044 r
F
.51316 .68036 m .52082 .66445 L .52398 .65839 L F
.52276 .6584 m .52301 .66098 L .52621 .65649 L 0 .678 .273 r
F
.51316 .68035 m .52114 .66088 L .51659 .67199 L 0 0 .053 r
F
.51316 .68035 m .51659 .67199 L .52114 .66088 L 0 0 .05 r
F
.51316 .68035 m .52112 .66177 L .51658 .67238 L F
.51316 .68035 m .51658 .67238 L .52112 .66177 L 0 0 .048 r
F
.51316 .68035 m .51316 .68035 L .51656 .67174 L 0 0 .053 r
F
.51316 .68035 m .51316 .68035 L .51659 .67199 L 0 0 .05 r
F
.51316 .68035 m .51316 .68035 L .51658 .67238 L 0 0 .048 r
F
.51316 .68035 m .52276 .6584 L .51976 .66362 L 0 .709 .284 r
F
.51316 .68035 m .52101 .66297 L .51653 .67289 L 0 0 .048 r
F
.51316 .68035 m .51653 .67289 L .52101 .66297 L 0 0 .045 r
F
.51316 .68035 m .52082 .66445 L .51645 .67353 L F
.51316 .68036 m .51645 .67353 L .52082 .66445 L 0 0 .044 r
F
.51316 .68035 m .51316 .68035 L .51653 .67289 L 0 0 .045 r
F
.51316 .68036 m .51316 .68035 L .51645 .67353 L 0 0 .044 r
F
.51316 .68035 m .52301 .66098 L .52276 .6584 L 0 .709 .284 r
F
.52208 .66021 m .53153 .63654 L .53096 .63527 L 0 1 .332 r
F
0 g
.52295 .65665 m
.52342 .65556 L
s
.52268 .65697 m
.52359 .65466 L
s
.52208 .66021 m .52915 .64459 L .53153 .63654 L 0 1 .332 r
F
0 g
.53153 .63654 m
.53199 .63535 L
s
.23183 .79667 m .22696 .80406 L .23119 .80305 L 0 1 .527 r
F
.23183 .79667 m .22113 .799 L .22696 .80406 L F
0 g
.22696 .80406 m
.22733 .81045 L
s
.23119 .80305 m
.23727 .80739 L
s
.52208 .66021 m .53096 .63527 L .52793 .64195 L 0 1 .332 r
F
0 g
.52166 .65967 m
.52295 .65665 L
s
.52158 .65976 m
.52268 .65697 L
s
.52138 .64572 m
.52251 .63695 L
s
.53096 .63527 m
.5317 .63155 L
s
.51833 .98899 m .52459 .991 L .52435 .98902 L 0 1 .526 r
F
0 g
.51861 .99411 m
.52459 .991 L
s
.52459 .991 m
.52481 .9909 L
s
.35374 .79483 m .34118 .78911 L .34096 .79379 L 0 1 .514 r
F
.35374 .79483 m .34502 .78773 L .34118 .78911 L F
.35374 .79483 m .3504 .79018 L .34502 .78773 L F
.36299 .79091 m .3504 .79018 L .35374 .79483 L 0 1 .512 r
F
0 g
.35374 .79483 m
.35629 .79593 L
s
.35363 .79703 m
.35374 .79483 L
s
.51316 .68036 m .51118 .67932 L .51068 .67816 L 0 0 .029 r
F
0 g
.51062 .67824 m
.51068 .67816 L
s
.52102 .87229 m
.5218 .87182 L
s
.45201 .60928 m .45136 .59771 L .4474 .59738 L 0 1 .338 r
F
0 g
.45136 .59771 m
.45551 .59294 L
s
.45136 .59771 m
.45333 .60281 L
s
.51316 .68036 m .52382 .65938 L .52055 .66618 L 0 0 .044 r
F
.52277 .66172 m .53233 .63869 L .52915 .64459 L 0 1 .334 r
F
.52277 .66172 m .53283 .64031 L .53233 .63869 L F
0 g
.53233 .63869 m
.53272 .63703 L
s
.48513 .93229 m .47878 .92603 L .47327 .92301 L 0 .637 .424 r
F
.45493 .78235 m .44445 .78377 L .44451 .78808 L 0 1 .471 r
F
0 g
.43975 .78838 m
.44451 .78808 L
s
.5025 .65736 m .50267 .6556 L .4997 .64904 L 0 .865 .295 r
F
.52207 .65222 m .52236 .65464 L .52539 .647 L 0 .709 .272 r
F
.52129 .65899 m .53004 .63365 L .52939 .63276 L 0 1 .331 r
F
.52129 .65899 m .52793 .64195 L .53004 .63365 L F
0 g
.53004 .63365 m
.53101 .63074 L
s
.52959 .63542 m
.53004 .63365 L
s
.45988 .6258 m .45162 .62996 L .45596 .63009 L 0 1 .331 r
F
.45988 .6258 m .44916 .62514 L .45162 .62996 L F
.45988 .6258 m .45022 .61885 L .44916 .62514 L F
.45988 .6258 m .45414 .61456 L .45022 .61885 L F
.5025 .65736 m .49482 .64903 L .49913 .65454 L 0 .865 .295 r
F
0 g
.50226 .64876 m
.50283 .65032 L
s
.50214 .66182 m .49913 .65454 L .49482 .64903 L 0 .855 .295 r
F
0 g
.49186 .64247 m
.49482 .64903 L
s
.49394 .64859 m
.49482 .64903 L
s
.43991 .7841 m .42875 .78418 L .4286 .78846 L 0 1 .48 r
F
0 g
.42358 .78822 m
.4286 .78846 L
s
.54043 1.01286 m
.54624 1.01641 L
s
.499 .7949 m .49578 .79357 L .49253 .79596 L 0 1 .449 r
F
.69624 .92952 m .68963 .93188 L .68707 .93525 L 0 1 .531 r
F
0 g
.67922 .9354 m
.68707 .93525 L
s
.52277 .66172 m .53021 .64793 L .53283 .64031 L 0 1 .334 r
F
0 g
.53041 .64733 m
.53044 .64725 L
s
.53044 .64725 m
.53045 .64721 L
s
.53045 .64721 m
.53053 .647 L
s
.53053 .647 m
.53099 .64565 L
s
.53099 .64565 m
.53113 .64525 L
s
.53113 .64525 m
.53162 .64382 L
s
.53162 .64382 m
.53226 .64197 L
s
.53226 .64197 m
.53283 .64031 L
s
.52989 .64322 m
.53233 .63869 L
s
.53008 .6372 m
.53096 .63527 L
s
.53283 .64031 m
.53346 .639 L
s
.53038 .64747 m
.53045 .64729 L
s
.53046 .64726 m
.5305 .64715 L
s
.53045 .64729 m
.53046 .64726 L
s
.5305 .64715 m
.53069 .64664 L
s
.53069 .64664 m
.5334 .63946 L
s
.75069 .75485 m
.75462 .75681 L
s
.30377 .80546 m .29925 .81 L .30333 .80872 L 0 1 .52 r
F
.30377 .80546 m .29344 .80846 L .29925 .81 L F
0 g
.29925 .81 m
.29961 .81333 L
s
.30333 .80872 m
.30964 .8099 L
s
.52129 .65899 m .52939 .63276 L .52655 .64005 L 0 1 .331 r
F
0 g
.5222 .65938 m
.5227 .65826 L
s
.52939 .63276 m
.52969 .63101 L
s
.28565 .96567 m .26584 .96166 L .26919 .9654 L 0 1 .531 r
F
.28565 .96567 m .26942 .96043 L .26584 .96166 L F
.28565 .96567 m .27793 .96216 L .26942 .96043 L F
.29411 .9622 m .27793 .96216 L .28565 .96567 L 0 1 .528 r
F
0 g
.28565 .96567 m
.29389 .96721 L
s
.28565 .96567 m
.28895 .96939 L
s
.45486 1.00076 m .44658 .9991 L .43899 .99978 L 0 1 .541 r
F
0 g
.45486 1.00076 m
.46009 1.00411 L
s
.44991 .54906 m .44196 .55551 L .4453 .55523 L 0 1 .319 r
F
.44991 .54906 m .44183 .54974 L .44196 .55551 L F
0 g
.44758 .55661 m
.45029 .55523 L
s
.44991 .54906 m .44501 .54178 L .44183 .54974 L 0 1 .319 r
F
.44991 .54906 m .44963 .53562 L .44501 .54178 L F
0 g
.44991 .54906 m
.45029 .55523 L
s
.4453 .55523 m
.44991 .54906 L
s
.45767 .99571 m .45487 1.00076 L .46182 1.00046 L 0 1 .542 r
F
.45767 .99571 m .44658 .9991 L .45487 1.00076 L F
.5316 .55903 m .53749 .54563 L .53906 .54482 L 0 0 .029 r
F
.5316 .55903 m .5343 .55171 L .53749 .54563 L F
0 g
.53749 .54563 m
.53825 .53962 L
s
.5343 .55171 m
.53515 .55006 L
s
.5343 .55171 m
.53749 .54563 L
s
.4493 .87317 m .44428 .87966 L .44966 .8824 L 0 .837 .422 r
F
0 g
.30107 .77936 m
.30107 .77935 L
s
.43899 .99978 m
.44658 .9991 L
s
.46911 .64113 m .46246 .63078 L .45872 .63447 L 0 1 .324 r
F
0 g
.45988 .6258 m
.46246 .63078 L
s
.3723 .78459 m .36806 .79296 L .37171 .79128 L 0 1 .435 r
F
.37225 .78685 m .36806 .79296 L .37171 .79128 L 0 1 .509 r
F
.3723 .78459 m .36304 .78868 L .36806 .79296 L 0 1 .435 r
F
.37225 .78685 m .36299 .79091 L .36806 .79296 L 0 1 .509 r
F
.3722 .78912 m .36806 .79296 L .37171 .79128 L 0 1 .463 r
F
.3722 .78912 m .36293 .79314 L .36806 .79296 L F
0 g
.37173 .79128 m
.37175 .79127 L
s
.37175 .79127 m
.37182 .79127 L
s
.37182 .79127 m
.37194 .79126 L
s
.37194 .79126 m
.37712 .7908 L
s
.36806 .79296 m
.36806 .79302 L
s
.37171 .79128 m
.37173 .79128 L
s
.37184 .79132 m
.37195 .79136 L
s
.37171 .79128 m
.37184 .79132 L
s
.37195 .79136 m
.37214 .79142 L
s
.37214 .79142 m
.37707 .79307 L
s
.36802 .79296 m
.36806 .79296 L
s
.36798 .79297 m
.36802 .79296 L
s
.51316 .68036 m .51316 .68036 L .51417 .67602 L 0 0 .033 r
F
.51316 .68035 m .52128 .6465 L .51868 .65546 L 0 .726 .282 r
F
.51316 .68035 m .51316 .68035 L .5145 .67531 L 0 0 .038 r
F
.51316 .68035 m .5216 .64873 L .52128 .6465 L 0 .726 .282 r
F
0 g
.51736 .64893 m
.51884 .63445 L
s
.51736 .64893 m
.51944 .63683 L
s
.52114 .66088 m
.52166 .65967 L
s
.52114 .66088 m
.52114 .66088 L
s
.52114 .66088 m
.52158 .65976 L
s
.52128 .6465 m
.52138 .64572 L
s
.49102 .79144 m .48788 .78994 L .48436 .79203 L 0 1 .453 r
F
.2728 .81431 m .25824 .80903 L .25826 .81293 L 0 1 .532 r
F
.2728 .81431 m .2625 .80809 L .25824 .80903 L F
.2728 .81431 m .26874 .81036 L .2625 .80809 L F
.28311 .8114 m .26874 .81036 L .2728 .81431 L 0 1 .529 r
F
0 g
.27279 .81819 m
.2728 .81431 L
s
.2728 .81431 m
.27889 .81632 L
s
.46247 .78799 m .45938 .78578 L .45499 .78666 L 0 1 .469 r
F
.46876 .77854 m .46247 .78799 L .46658 .78677 L 0 1 .46 r
F
.46876 .77854 m .45938 .78578 L .46247 .78799 L F
0 g
.46247 .78799 m
.46299 .79235 L
s
.39803 .81487 m .39433 .80808 L .389 .80442 L 0 1 .429 r
F
0 g
.39803 .81487 m
.39844 .82149 L
s
.40648 .80945 m .39803 .81487 L .40328 .8183 L 0 1 .421 r
F
.40648 .80945 m .39434 .80808 L .39803 .81487 L F
.48059 .72003 m .47605 .72557 L .4792 .72183 L 0 .833 .143 r
F
.48059 .72003 m .47247 .72931 L .47605 .72557 L F
0 g
.47504 .72731 m
.47605 .72557 L
s
.53029 .6478 m
.53086 .64695 L
s
.53086 .64695 m
.53158 .64587 L
s
.5316 .64583 m
.5329 .64387 L
s
.53158 .64587 m
.5316 .64583 L
s
.50714 .79789 m .50387 .79675 L .50092 .79944 L 0 1 .446 r
F
.49114 .65055 m .48317 .6491 L .48761 .65131 L 0 .945 .304 r
F
.50214 .66182 m .49114 .65055 L .49427 .65603 L 0 .855 .295 r
F
0 g
.50185 .65166 m
.50272 .65271 L
s
.4997 .64904 m
.50185 .65166 L
s
.4997 .64904 m
.50214 .65443 L
s
.78933 .58831 m .79696 .59414 L .79234 .59098 L 0 0 0 r
F
.78933 .58831 m .80092 .59673 L .79696 .59414 L F
.28604 .76932 m .28051 .77805 L .28476 .77687 L 0 1 .472 r
F
.28604 .76932 m .27531 .77211 L .28051 .77805 L F
0 g
.28008 .78561 m
.28051 .77805 L
s
.28476 .77687 m
.29057 .78251 L
s
.51316 .68035 m .51316 .68035 L .51512 .67397 L 0 0 .048 r
F
.51316 .68035 m .52207 .65222 L .51925 .65937 L 0 .72 .283 r
F
.51316 .68035 m .51316 .68035 L .51566 .67285 L 0 0 .056 r
F
.51316 .68035 m .51316 .68035 L .51589 .6724 L 0 0 .058 r
F
.51316 .68035 m .51316 .68035 L .51541 .67338 L 0 0 .052 r
F
.51316 .68035 m .51316 .68035 L .51609 .67204 L 0 0 .059 r
F
.51316 .68035 m .52236 .65464 L .52207 .65222 L 0 .72 .283 r
F
.52042 .65808 m .52836 .63171 L .52764 .63119 L 0 1 .331 r
F
.52042 .65808 m .52655 .64005 L .52836 .63171 L F
0 g
.52836 .63171 m
.52893 .6298 L
s
.51316 .68035 m .51736 .64893 L .51497 .66686 L 0 .727 .281 r
F
.51316 .68035 m .51497 .66686 L .51736 .64893 L 0 .723 .28 r
F
0 g
.51736 .64893 m
.51736 .64893 L
s
.51736 .64893 m
.51736 .64893 L
s
.51362 .67421 m
.51362 .67421 L
s
.4373 .85763 m .43675 .8668 L .43903 .86425 L 0 .897 .423 r
F
.4493 .87317 m .43903 .86425 L .43675 .8668 L 0 .837 .422 r
F
0 g
.43675 .8668 m
.439 .8734 L
s
.43133 .86393 m
.43675 .8668 L
s
.50288 .89012 m
.50721 .88629 L
s
.46911 .64113 m .46092 .64462 L .46537 .64482 L 0 1 .324 r
F
.46911 .64113 m .45806 .64018 L .46092 .64462 L F
.46911 .64113 m .45872 .63447 L .45806 .64018 L F
.51316 .68035 m .50319 .65131 L .50297 .65301 L 0 .753 .288 r
F
0 g
.51189 .67642 m
.51191 .67672 L
s
.51316 .68035 m .50629 .65911 L .50319 .65131 L 0 .753 .288 r
F
0 g
.50493 .64131 m
.50743 .6527 L
s
.50526 .6399 m
.50744 .65274 L
s
.50283 .65032 m
.50319 .65131 L
s
.44187 .75644 m .43121 .76219 L .43039 .76396 L 0 1 .302 r
F
.44187 .75644 m .43496 .75948 L .43121 .76219 L F
.44187 .75644 m .43953 .75702 L .43496 .75948 L F
.45074 .74888 m .43953 .75702 L .44187 .75644 L 0 1 .234 r
F
0 g
.44187 .75644 m
.44622 .7537 L
s
.44103 .75822 m
.44187 .75644 L
s
.51316 .68035 m .50805 .65027 L .51097 .66743 L 0 .717 .287 r
F
.51316 .68035 m .51097 .66743 L .50805 .65027 L 0 .728 .288 r
F
0 g
.50805 .65026 m
.50805 .65027 L
s
.50805 .65025 m
.50805 .65027 L
s
.49065 .65861 m .48317 .6491 L .47965 .65064 L 0 .925 .305 r
F
.49065 .65861 m .48761 .65131 L .48317 .6491 L F
0 g
.48013 .6442 m
.48317 .6491 L
s
.45201 .60928 m .4437 .61409 L .44788 .61411 L 0 1 .338 r
F
.45201 .60928 m .44172 .60898 L .4437 .61409 L F
.45201 .60928 m .44326 .60221 L .44172 .60898 L F
.45201 .60928 m .4474 .59738 L .44326 .60221 L F
0 g
.45201 .60928 m
.45414 .61456 L
s
.47223 .91066 m .46939 .91668 L .47479 .91953 L 0 .715 .425 r
F
0 g
.46939 .91668 m
.47327 .92301 L
s
.53311 .64687 m
.53371 .64539 L
s
.32675 .78039 m .31467 .7683 L .31399 .7754 L 0 1 .458 r
F
.32675 .78039 m .31866 .76712 L .31467 .7683 L F
.32675 .78039 m .32384 .7723 L .31866 .76712 L F
.33645 .77704 m .32384 .7723 L .32675 .78039 L 0 1 .453 r
F
0 g
.32675 .78039 m
.3318 .7854 L
s
.32606 .78747 m
.32675 .78039 L
s
.36304 .78868 m .35097 .77829 L .35054 .78507 L 0 1 .441 r
F
.49133 .70688 m .48393 .71614 L .48456 .71549 L 0 0 0 r
F
.49133 .70688 m .48708 .71228 L .48393 .71614 L F
.48871 .71037 m .48393 .71614 L .48708 .71228 L F
.48871 .71037 m .48344 .71664 L .48393 .71614 L F
.48344 .71664 m .48059 .72003 L .48393 .71614 L F
.48456 .71549 m .48393 .71614 L .48264 .71793 L F
0 g
.48264 .71793 m
.48393 .71614 L
s
.45395 .92036 m .456 .92272 L .45741 .92067 L 0 1 .42 r
F
.45395 .92036 m .45013 .92536 L .456 .92272 L F
0 g
.456 .92272 m
.45994 .92264 L
s
.47939 .6549 m .4765 .6467 L .47205 .64571 L 0 1 .315 r
F
.47939 .6549 m .47965 .65064 L .4765 .6467 L F
0 g
.4765 .6467 m
.48013 .6442 L
s
.389 .80442 m
.39433 .80808 L
s
.53912 1.00805 m .54043 1.01286 L .54644 1.02016 L 0 0 .146 r
F
0 g
.54043 1.01286 m
.54595 1.01957 L
s
.52042 .65808 m .52764 .63119 L .52502 .6389 L 0 1 .331 r
F
0 g
.52657 .63996 m
.52836 .63171 L
s
.5218 .648 m
.52444 .6382 L
s
.52185 .65998 m
.5231 .65693 L
s
.52764 .63119 m
.52781 .63003 L
s
.46876 .77854 m .46658 .78677 L .46898 .78292 L 0 1 .46 r
F
.47582 .78324 m .46898 .78292 L .46658 .78677 L 0 1 .458 r
F
0 g
.46658 .78677 m
.46725 .79119 L
s
.46247 .78799 m
.46658 .78677 L
s
.40648 .80945 m .40328 .8183 L .40657 .81609 L 0 1 .421 r
F
.41578 .82582 m .40657 .81609 L .40328 .8183 L 0 1 .422 r
F
0 g
.40328 .8183 m
.40393 .82494 L
s
.39803 .81487 m
.40328 .8183 L
s
.25386 .77755 m .24096 .76246 L .24002 .77047 L 0 1 .482 r
F
.25386 .77755 m .24535 .76154 L .24096 .76246 L F
.25386 .77755 m .25088 .76802 L .24535 .76154 L F
.26458 .77485 m .25088 .76802 L .25386 .77755 L 0 1 .479 r
F
0 g
.25292 .78553 m
.25386 .77755 L
s
.25386 .77755 m
.25928 .78383 L
s
.40777 .93942 m .40887 .94275 L .41103 .94085 L 0 1 .477 r
F
.40777 .93942 m .40211 .94403 L .40887 .94275 L F
0 g
.40887 .94275 m
.41272 .94392 L
s
.36304 .78868 m .35481 .77681 L .35097 .77829 L 0 1 .441 r
F
.36304 .78868 m .35998 .78127 L .35481 .77681 L F
.3723 .78459 m .35998 .78127 L .36304 .78868 L 0 1 .435 r
F
0 g
.3629 .7909 m
.36304 .78868 L
s
.36304 .78868 m
.36475 .79013 L
s
.51316 .68036 m .51 .67958 L .51118 .67932 L 0 0 .032 r
F
.51316 .68036 m .50955 .68051 L .51 .67958 L F
0 g
.50949 .67981 m
.51 .67958 L
s
.46306 .48821 m .45592 .49771 L .45814 .49626 L 0 1 .153 r
F
.46306 .48821 m .45785 .4921 L .45592 .49771 L F
0 g
.45911 .498 m
.46145 .49441 L
s
.46306 .48821 m .46265 .48318 L .45785 .4921 L 0 1 .153 r
F
.46306 .48821 m .46757 .47514 L .46265 .48318 L F
0 g
.46145 .49441 m
.46306 .48821 L
s
.49809 .99815 m .48991 .99847 L .48332 1.0004 L 0 1 .539 r
F
0 g
.48008 .9991 m
.48332 1.0004 L
s
.77218 .77932 m .78278 .78305 L .77834 .7797 L 0 .651 .435 r
F
.77218 .77932 m .78313 .78783 L .78278 .78305 L F
.49065 .65861 m .49081 .65539 L .48761 .65131 L 0 .925 .305 r
F
0 g
.48761 .65131 m
.49114 .65055 L
s
.56975 .51671 m .5718 .55139 L .56918 .53685 L 0 .573 .181 r
F
.56975 .51671 m .57666 .55938 L .5718 .55139 L F
.56975 .51671 m .5805 .55541 L .57666 .55938 L F
.56975 .51671 m .58102 .5351 L .5805 .55541 L F
0 g
.5653 .51699 m
.56975 .51671 L
s
.37177 .79133 m
.37702 .79533 L
s
.37171 .79128 m
.37177 .79133 L
s
.37702 .79533 m
.37718 .78883 L
s
.37718 .78883 m
.37718 .78877 L
s
.37023 .95284 m .35239 .95367 L .35579 .95597 L 0 1 .51 r
F
.34616 .7736 m .34138 .78189 L .34521 .78046 L 0 1 .447 r
F
.34616 .7736 m .33645 .77704 L .34138 .78189 L F
0 g
.3411 .78877 m
.34138 .78189 L
s
.34521 .78046 m
.35054 .78507 L
s
.45767 .99571 m .46182 1.00046 L .46282 .9984 L 0 1 .542 r
F
.47771 .99815 m .46282 .9984 L .46182 1.00046 L F
0 g
.46182 1.00046 m
.46744 1.00271 L
s
.45487 1.00076 m
.46182 1.00046 L
s
.76659 .94618 m .77569 .9496 L .77883 .94537 L 0 1 .538 r
F
0 g
.47635 .78677 m
.47643 .78731 L
s
.48326 .78755 m .48024 .78587 L .47648 .78767 L 0 1 .455 r
F
0 g
.47643 .78731 m
.47648 .78767 L
s
.3026 .95875 m .30214 .96356 L .30544 .96211 L 0 1 .525 r
F
0 g
.30544 .96211 m
.31387 .96296 L
s
.3026 .95875 m .29411 .9622 L .30214 .96356 L 0 1 .525 r
F
0 g
.30214 .96356 m
.30585 .96677 L
s
.40648 .80945 m .39424 .80145 L .39434 .80808 L 0 1 .421 r
F
.46876 .77854 m .45916 .7814 L .45938 .78578 L 0 1 .46 r
F
0 g
.45499 .78666 m
.45938 .78578 L
s
.40752 .78198 m .40333 .7884 L .40691 .78621 L 0 1 .496 r
F
.40752 .78198 m .39839 .78732 L .40333 .7884 L F
0 g
.40325 .79268 m
.40333 .7884 L
s
.78139 .69423 m .79132 .70718 L .79275 .69936 L 0 1 .491 r
F
0 g
.79132 .70718 m
.79362 .71453 L
s
.78689 .7114 m
.79132 .70718 L
s
.35368 .79703 m .34098 .79634 L .34082 .79882 L 0 1 .494 r
F
.35368 .79703 m .34482 .79501 L .34098 .79634 L F
.35368 .79703 m .35027 .79531 L .34482 .79501 L F
.36293 .79314 m .35027 .79531 L .35368 .79703 L 0 1 .48 r
F
0 g
.35351 .79951 m
.35368 .79703 L
s
.35368 .79703 m
.35889 .79709 L
s
.51832 .98099 m
.51984 .98264 L
s
.51984 .98264 m
.52225 .98527 L
s
.52225 .98527 m
.52435 .98755 L
s
.51832 .98099 m
.52253 .98396 L
s
.52253 .98396 m
.52389 .98492 L
s
.32648 .78956 m .32202 .79579 L .32585 .79448 L 0 1 .519 r
F
.32648 .78956 m .31678 .79267 L .32202 .79579 L F
0 g
.32202 .79579 m
.32213 .80075 L
s
.32585 .79448 m
.33154 .79731 L
s
.34496 .95351 m .34487 .95783 L .34788 .95616 L 0 1 .512 r
F
0 g
.34788 .95616 m
.35579 .95597 L
s
.34496 .95351 m .33721 .9575 L .34487 .95783 L 0 1 .512 r
F
0 g
.34487 .95783 m
.34855 .96031 L
s
.38844 .98793 m .39018 .99373 L .39247 .99192 L 0 1 .539 r
F
.38844 .98793 m .38243 .99232 L .39018 .99373 L F
.40842 .99584 m .39247 .99192 L .39018 .99373 L 0 1 .54 r
F
0 g
.39018 .99373 m
.39486 .99746 L
s
.52383 .66552 m .53446 .64796 L .53108 .65188 L 0 1 .339 r
F
.52383 .66552 m .53478 .65013 L .53446 .64796 L F
0 g
.53446 .64796 m
.53462 .64749 L
s
.52265 .64878 m
.52444 .6382 L
s
.5331 .64954 m
.53446 .64796 L
s
.47939 .6549 m .47205 .64571 L .46846 .64874 L 0 1 .315 r
F
0 g
.46911 .64113 m
.47205 .64571 L
s
.51316 .68035 m .50297 .65301 L .5059 .66209 L 0 .753 .288 r
F
0 g
.50453 .64327 m
.50726 .65355 L
s
.50483 .64177 m
.50726 .65355 L
s
.50272 .65271 m
.50297 .65301 L
s
.73915 .93542 m .73344 .94407 L .74129 .94266 L 0 1 .533 r
F
.73915 .93542 m .72998 .94241 L .73344 .94407 L F
0 g
.73011 .94786 m
.73344 .94407 L
s
.4458 .59189 m .44764 .5849 L .44623 .57962 L 0 1 .342 r
F
0 g
.44764 .5849 m
.4518 .58014 L
s
.72389 .57206 m .731 .55233 L .73556 .55757 L 0 .425 .1 r
F
.72389 .57206 m .72601 .55849 L .731 .55233 L F
0 g
.72854 .54133 m
.731 .55233 L
s
.40842 .99584 m .40029 .99283 L .39247 .99192 L 0 1 .54 r
F
0 g
.40842 .99584 m
.41309 .99957 L
s
.41463 .99004 m .40842 .99584 L .41626 .99632 L 0 1 .54 r
F
.41463 .99004 m .40029 .99283 L .40842 .99584 L F
.51316 .68035 m .51316 .68035 L .51482 .67462 L 0 0 .043 r
F
.51316 .68035 m .51925 .65937 L .5216 .64873 L 0 .726 .282 r
F
0 g
.5216 .64873 m
.5218 .648 L
s
.46998 .46941 m .47496 .45997 L .47775 .45479 L 0 0 0 r
F
.27682 .97946 m .25664 .97072 L .26016 .97638 L 0 1 .537 r
F
.27682 .97946 m .26022 .96954 L .25664 .97072 L F
.27682 .97946 m .26888 .97329 L .26022 .96954 L F
.28527 .97619 m .26888 .97329 L .27682 .97946 L F
0 g
.27682 .97946 m
.28523 .98305 L
s
.27682 .97946 m
.2803 .9851 L
s
.49065 .65861 m .47965 .65064 L .47939 .6549 L 0 .925 .305 r
F
0 g
.4765 .6467 m
.47965 .65064 L
s
.47965 .65064 m
.48317 .6491 L
s
.38134 .94971 m
.38923 .9483 L
s
.40211 .94403 m .38567 .9467 L .38923 .9483 L 0 1 .493 r
F
.5378 1.00139 m .5309 .99776 L .53912 1.00805 L 0 .184 .202 r
F
0 g
.53027 .99689 m
.5309 .99776 L
s
.53065 .99745 m
.5309 .99776 L
s
.49886 .99273 m .49809 .99815 L .50437 .99627 L 0 1 .539 r
F
.49886 .99273 m .48991 .99847 L .49809 .99815 L F
0 g
.49809 .99815 m
.50409 .9998 L
s
.77292 .90556 m .76677 .91354 L .76493 .91974 L 0 1 .52 r
F
0 g
.75677 .92478 m
.76493 .91974 L
s
.80092 .59673 m .81315 .6051 L .8125 .60415 L 0 0 0 r
F
0 g
.81015 .60324 m
.81315 .6051 L
s
.81315 .6051 m
.81712 .60811 L
s
.74832 .93911 m .75015 .94651 L .75746 .94269 L 0 1 .535 r
F
0 g
.74728 .95055 m
.75015 .94651 L
s
.7421 .94815 m
.75015 .94651 L
s
.45013 .92536 m .43752 .92946 L .43573 .93145 L 0 1 .452 r
F
.45013 .92536 m .4437 .92685 L .43752 .92946 L F
.45395 .92036 m .4437 .92685 L .45013 .92536 L 0 1 .42 r
F
0 g
.45013 .92536 m
.45389 .92587 L
s
.45013 .92536 m
.456 .92272 L
s
.51946 .65748 m .52652 .63068 L .52574 .63053 L 0 1 .333 r
F
0 g
.52466 .63004 m
.52483 .62936 L
s
.51946 .65748 m .52502 .6389 L .52652 .63068 L 0 1 .333 r
F
0 g
.52652 .63068 m
.52686 .62945 L
s
.52596 .63612 m
.52764 .63119 L
s
.51804 .65196 m
.51983 .63855 L
s
.52639 .63137 m
.52652 .63068 L
s
.52578 .63472 m
.52639 .63137 L
s
.50956 .53111 m .51648 .49425 L .5134 .49831 L 0 1 .195 r
F
0 g
.51727 .50966 m
.51904 .49714 L
s
.50956 .53111 m .51633 .50236 L .51648 .49425 L 0 1 .195 r
F
0 g
.51648 .49425 m
.51977 .47625 L
s
.37023 .95284 m .3554 .95201 L .35239 .95367 L 0 1 .51 r
F
.37023 .95284 m .36306 .95166 L .3554 .95201 L F
0 g
.37023 .95284 m
.37361 .95514 L
s
.37875 .94732 m .36306 .95166 L .37024 .95284 L 0 1 .497 r
F
0 g
.37024 .95284 m
.37806 .95201 L
s
.5425 .53655 m .54304 .54975 L .54144 .54658 L 0 .092 .104 r
F
.5425 .53655 m .54684 .54502 L .54304 .54975 L F
.5425 .53655 m .55028 .53556 L .54684 .54502 L F
.49416 .7795 m .49102 .79144 L .49421 .78894 L 0 1 .443 r
F
.49416 .7795 m .48788 .78994 L .49102 .79144 L F
0 g
.49102 .79144 m
.49253 .79596 L
s
.47247 .72931 m .46353 .73755 L .46241 .7393 L 0 .933 .187 r
F
.44998 .52952 m .45344 .52114 L .45407 .51549 L 0 1 .285 r
F
0 g
.45344 .52114 m
.4555 .5182 L
s
.47247 .72931 m .467 .7341 L .46353 .73755 L 0 .933 .187 r
F
.47247 .72931 m .47084 .73057 L .467 .7341 L F
.48059 .72003 m .47084 .73057 L .47247 .72931 L 0 .833 .143 r
F
0 g
.47247 .72931 m
.47605 .72557 L
s
.47134 .73106 m
.47247 .72931 L
s
.4792 .72183 m
.48264 .71793 L
s
.49859 .69738 m .49423 .70301 L .49703 .69927 L 0 0 0 r
F
.49859 .69738 m .49133 .70688 L .49423 .70301 L F
.50048 .69416 m .49703 .69927 L .49423 .70301 L F
0 g
.49137 .70683 m
.49423 .70301 L
s
.50101 .78239 m .49578 .79357 L .499 .7949 L 0 1 .44 r
F
.50101 .78239 m .49421 .78894 L .49578 .79357 L F
0 g
.49253 .79596 m
.49578 .79357 L
s
.32896 .97926 m .32935 .98564 L .33234 .98412 L 0 1 .537 r
F
.32896 .97926 m .32124 .98292 L .32935 .98564 L F
0 g
.32935 .98564 m
.33353 .99028 L
s
.52155 .63166 m .52243 .63119 L .52456 .62211 L 0 1 .321 r
F
0 g
.5234 .62706 m
.52456 .62211 L
s
.52395 .62828 m
.52456 .62211 L
s
.49416 .7795 m .48671 .78535 L .48788 .78994 L 0 1 .443 r
F
0 g
.48436 .79203 m
.48788 .78994 L
s
.52841 .81936 m
.52846 .81881 L
s
.24254 .79432 m .23755 .80154 L .24179 .80052 L 0 1 .526 r
F
.24254 .79432 m .23183 .79667 L .23755 .80154 L F
0 g
.23755 .80154 m
.23777 .80775 L
s
.24179 .80052 m
.24823 .80503 L
s
.51316 .68035 m .50744 .65274 L .51071 .6685 L 0 .728 .288 r
F
0 g
.50744 .65274 m
.50744 .65274 L
s
.51316 .68035 m .51071 .6685 L .50744 .65275 L 0 .736 .289 r
F
0 g
.5128 .67593 m
.5128 .67593 L
s
.50743 .6527 m
.50744 .65275 L
s
.50048 .69416 m .49971 .69547 L .49703 .69927 L 0 0 0 r
F
.50681 .68626 m .50048 .69416 L .50287 .69092 L F
.50681 .68626 m .49971 .69547 L .50048 .69416 L F
0 g
.49925 .69581 m
.50048 .69416 L
s
.50048 .69416 m
.50089 .69361 L
s
.42609 .84187 m .42185 .83548 L .41643 .83246 L 0 .952 .422 r
F
.424 .78394 m .41239 .78276 L .41198 .78703 L 0 1 .489 r
F
0 g
.50301 .41923 m
.50737 .41588 L
s
.69624 .92952 m .69782 .93701 L .70475 .93437 L 0 1 .531 r
F
0 g
.69502 .94051 m
.69782 .93701 L
s
.69025 .93738 m
.69782 .93701 L
s
.50101 .78239 m .499 .7949 L .50192 .7921 L 0 1 .44 r
F
0 g
.499 .7949 m
.50092 .79944 L
s
.74817 .66516 m
.74991 .66866 L
s
.52383 .66552 m .53175 .65634 L .53478 .65013 L 0 1 .339 r
F
0 g
.53478 .65013 m
.53499 .64991 L
s
.51316 .68036 m .5104 .68095 L .50955 .68051 L 0 0 .032 r
F
0 g
.50949 .68059 m
.50955 .68051 L
s
.53519 .65352 m .53541 .65587 L .53894 .65413 L 0 1 .324 r
F
.4373 .85763 m .43271 .85136 L .42729 .8485 L 0 .897 .423 r
F
.50956 .53111 m .51337 .51814 L .51633 .50236 L 0 1 .195 r
F
0 g
.51633 .50236 m
.51904 .49714 L
s
.38243 .99232 m .36634 .98713 L .36369 .98879 L 0 1 .539 r
F
.38243 .99232 m .37438 .98864 L .36634 .98713 L F
.38844 .98793 m .37438 .98864 L .38243 .99232 L F
0 g
.38243 .99232 m
.39018 .99373 L
s
.38243 .99232 m
.38675 .99645 L
s
.46198 .88855 m .45241 .889 L .45796 .8952 L 0 .767 .42 r
F
.46198 .88855 m .44966 .8824 L .45241 .889 L F
0 g
.45241 .889 m
.45241 .889 L
s
.45767 .99571 m .44141 .99642 L .44658 .9991 L 0 1 .542 r
F
.45962 .74087 m .45487 .74584 L .45833 .74258 L 0 .945 .207 r
F
.45962 .74087 m .45074 .74888 L .45487 .74584 L F
0 g
.45399 .74758 m
.45487 .74584 L
s
.45833 .74258 m
.46241 .7393 L
s
.40762 .77648 m .39599 .77943 L .39543 .78133 L 0 1 .411 r
F
.40762 .77648 m .39982 .77745 L .39599 .77943 L F
.40762 .77648 m .4048 .77618 L .39982 .77745 L F
0 g
.40704 .77837 m
.40762 .77648 L
s
.41714 .77059 m .40481 .77618 L .40762 .77648 L 0 1 .368 r
F
0 g
.40762 .77648 m
.41252 .77487 L
s
.68506 .54208 m
.68655 .5696 L
s
.30407 .79665 m .29067 .78843 L .29016 .79378 L 0 1 .522 r
F
.30407 .79665 m .29493 .78733 L .29067 .78843 L F
.30407 .79665 m .30068 .79086 L .29493 .78733 L F
0 g
.30355 .80199 m
.30407 .79665 L
s
.31678 .79267 m .30068 .79086 L .30407 .79665 L 0 1 .52 r
F
0 g
.30407 .79665 m
.31037 .79972 L
s
.49133 .70688 m .49025 .70831 L .48708 .71228 L 0 0 0 r
F
.49859 .69738 m .49025 .70831 L .49133 .70688 L F
0 g
.49133 .70688 m
.49137 .70683 L
s
.49004 .70868 m
.49111 .70719 L
s
.67529 .92969 m
.67849 .92974 L
s
.48751 .77619 m .48326 .78755 L .48671 .78535 L 0 1 .446 r
F
.48751 .77619 m .48024 .78587 L .48326 .78755 L F
0 g
.48326 .78755 m
.48436 .79203 L
s
.50214 .66182 m .50227 .66002 L .49913 .65454 L 0 .855 .295 r
F
.45806 .64018 m .45872 .63447 L .45596 .63009 L 0 1 .335 r
F
0 g
.45872 .63447 m
.46246 .63078 L
s
.41463 .99004 m .41626 .99632 L .4186 .99394 L 0 1 .54 r
F
.43437 .99614 m .4186 .99394 L .41626 .99632 L 0 1 .541 r
F
0 g
.41626 .99632 m
.4209 .99995 L
s
.40842 .99584 m
.41626 .99632 L
s
.51946 .65748 m .52574 .63053 L .52336 .63848 L 0 1 .333 r
F
0 g
.52521 .6323 m
.52567 .63078 L
s
.52567 .63078 m
.52574 .63053 L
s
.52523 .63774 m
.52578 .63472 L
s
.51804 .65196 m
.5204 .64134 L
s
.52574 .63053 m
.52584 .62971 L
s
.51316 .68035 m .50727 .65355 L .51063 .66885 L 0 .736 .289 r
F
0 g
.50726 .65355 m
.50727 .65355 L
s
.51316 .68035 m .51063 .66885 L .50727 .65355 L 0 .741 .289 r
F
0 g
.50726 .65355 m
.50727 .65355 L
s
.51316 .68035 m .51804 .65197 L .51526 .66817 L 0 .728 .282 r
F
.51316 .68035 m .51526 .66817 L .51804 .65197 L 0 .727 .281 r
F
0 g
.51804 .65197 m
.51804 .65196 L
s
.51804 .65197 m
.51804 .65196 L
s
.52572 .98884 m
.52705 .99008 L
s
.52521 .98835 m
.52572 .98884 L
s
.52435 .98755 m
.52521 .98835 L
s
.29679 .76647 m .29114 .77508 L .2954 .77388 L 0 1 .468 r
F
.29679 .76647 m .28604 .76932 L .29114 .77508 L F
0 g
.29057 .78251 m
.29114 .77508 L
s
.2954 .77388 m
.30107 .77936 L
s
.25803 .95519 m .25712 .95874 L .2607 .95747 L 0 1 .408 r
F
0 g
.2607 .95747 m
.26949 .95752 L
s
.25803 .95519 m .24889 .95816 L .25712 .95874 L 0 1 .408 r
F
0 g
.25712 .95874 m
.26077 .96092 L
s
.44799 .77635 m .44445 .78377 L .44758 .7806 L 0 1 .473 r
F
.44799 .77635 m .43991 .7841 L .44445 .78377 L F
.45493 .78235 m .44758 .7806 L .44445 .78377 L 0 1 .471 r
F
0 g
.44445 .78377 m
.44451 .78808 L
s
.5019 .66636 m .49081 .65539 L .49065 .65861 L 0 .842 .295 r
F
.5019 .66636 m .49427 .65603 L .49081 .65539 L F
0 g
.48761 .65131 m
.49081 .65539 L
s
.49081 .65539 m
.49306 .6558 L
s
.50889 .68188 m .50846 .68278 L .50663 .68533 L 0 0 0 r
F
.50799 .78483 m .50387 .79675 L .50714 .79789 L 0 1 .437 r
F
.50799 .78483 m .50192 .7921 L .50387 .79675 L F
0 g
.50092 .79944 m
.50387 .79675 L
s
.43991 .7841 m .4322 .78141 L .42875 .78418 L 0 1 .48 r
F
.43991 .7841 m .43699 .78138 L .4322 .78141 L F
.44799 .77635 m .43699 .78138 L .43991 .7841 L 0 1 .473 r
F
0 g
.43991 .7841 m
.44445 .78377 L
s
.43975 .78838 m
.43991 .7841 L
s
.45796 .8952 m
.46106 .90164 L
s
.46106 .90164 m
.46645 .90448 L
s
.45806 .64018 m .45596 .63009 L .45162 .62996 L 0 1 .335 r
F
0 g
.45596 .63009 m
.45988 .6258 L
s
.45596 .63009 m
.45872 .63447 L
s
.42949 .93348 m .41427 .93802 L .41783 .93901 L 0 1 .467 r
F
0 g
.41103 .94085 m
.41783 .93901 L
s
.48751 .77619 m .47947 .78133 L .48024 .78587 L 0 1 .446 r
F
0 g
.47648 .78767 m
.48024 .78587 L
s
.48672 .78541 m
.48788 .78994 L
s
.51316 .68036 m .51199 .67765 L .51266 .6792 L 0 0 .029 r
F
.51316 .68036 m .51266 .6792 L .51199 .67765 L 0 0 .026 r
F
.51316 .68036 m .51316 .68036 L .51266 .6792 L F
.51316 .68035 m .50267 .6556 L .5025 .65736 L 0 .755 .288 r
F
.51316 .68035 m .5059 .66209 L .50267 .6556 L F
0 g
.50423 .64481 m
.50674 .65625 L
s
.50381 .64719 m
.50674 .65625 L
s
.50214 .65443 m
.50267 .6556 L
s
.51196 .67734 m
.51196 .67734 L
s
.51114 .67721 m
.51188 .6776 L
s
.52277 .66172 m .52915 .64459 L .5254 .65408 L 0 1 .334 r
F
.52208 .66021 m .5254 .65408 L .52915 .64459 L 0 1 .332 r
F
0 g
.52915 .64459 m
.53153 .63654 L
s
.52915 .64459 m
.52989 .64322 L
s
.26458 .77485 m .25193 .76016 L .25088 .76802 L 0 1 .479 r
F
.26458 .77485 m .25632 .75922 L .25193 .76016 L F
.26458 .77485 m .26174 .76553 L .25632 .75922 L F
.27531 .77211 m .26174 .76553 L .26458 .77485 L 0 1 .476 r
F
0 g
.26352 .78268 m
.26458 .77485 L
s
.26458 .77485 m
.26989 .78096 L
s
.50681 .68626 m .50287 .69092 L .50529 .6879 L 0 0 0 r
F
.50782 .68411 m .50529 .6879 L .50287 .69092 L F
0 g
.50168 .69213 m
.50287 .69092 L
s
.50089 .69361 m
.50287 .69092 L
s
.50663 .68533 m
.5084 .68287 L
s
.42669 .76438 m .42186 .76869 L .4256 .76613 L 0 1 .313 r
F
.42669 .76438 m .41714 .77059 L .42186 .76869 L F
0 g
.42126 .77054 m
.42186 .76869 L
s
.4256 .76613 m
.43039 .76396 L
s
.52208 .66021 m .52793 .64195 L .52446 .65213 L 0 1 .332 r
F
.52129 .65899 m .52446 .65213 L .52793 .64195 L 0 1 .331 r
F
0 g
.52793 .64195 m
.53008 .6372 L
s
.52793 .64195 m
.52959 .63542 L
s
.31399 .7754 m
.31399 .77539 L
s
.4458 .59189 m .44623 .57962 L .44251 .57957 L 0 1 .342 r
F
0 g
.44623 .57962 m
.45061 .57421 L
s
.44623 .57962 m
.44764 .5849 L
s
.36299 .79091 m .35078 .78563 L .3504 .79018 L 0 1 .512 r
F
.36299 .79091 m .35462 .7842 L .35078 .78563 L F
.36299 .79091 m .35985 .78647 L .35462 .7842 L F
.37225 .78685 m .35985 .78647 L .36299 .79091 L 0 1 .509 r
F
0 g
.36299 .79091 m
.36562 .79197 L
s
.3628 .79316 m
.36299 .79091 L
s
.39839 .78732 m .39026 .78234 L .38644 .78423 L 0 1 .501 r
F
.39839 .78732 m .39538 .78366 L .39026 .78234 L F
.40752 .78198 m .39538 .78366 L .39839 .78732 L 0 1 .496 r
F
0 g
.39796 .79163 m
.39839 .78732 L
s
.39839 .78732 m
.40333 .7884 L
s
.40691 .78621 m
.41198 .78703 L
s
.46813 .65376 m .46537 .64482 L .46092 .64462 L 0 1 .326 r
F
.46813 .65376 m .46846 .64874 L .46537 .64482 L F
0 g
.46537 .64482 m
.46911 .64113 L
s
.53967 .61485 m .54178 .61937 L .54495 .57634 L 0 .92 .24 r
F
.44637 .5592 m .44718 .55682 L .4453 .55524 L 0 1 .337 r
F
0 g
.44718 .55682 m
.44758 .55661 L
s
.52419 .66774 m .53519 .65352 L .53175 .65634 L 0 1 .342 r
F
.52419 .66774 m .53541 .65587 L .53519 .65352 L F
0 g
.53519 .65352 m
.53522 .65346 L
s
.53443 .65414 m
.53519 .65352 L
s
.43285 .77719 m .42875 .78418 L .4322 .78141 L 0 1 .482 r
F
.43285 .77719 m .424 .78394 L .42875 .78418 L F
0 g
.4286 .78846 m
.42875 .78418 L
s
.50214 .66182 m .49427 .65603 L .49871 .66011 L 0 .855 .295 r
F
.5019 .66636 m .49871 .66011 L .49427 .65603 L 0 .842 .295 r
F
0 g
.49114 .65055 m
.49427 .65603 L
s
.49306 .6558 m
.49427 .65603 L
s
.49913 .65454 m
.50168 .65667 L
s
.50168 .65667 m
.5023 .65719 L
s
.49886 .99273 m .48421 .99714 L .48991 .99847 L 0 1 .539 r
F
0 g
.48332 1.0004 m
.48991 .99847 L
s
.4765 .90953 m
.47876 .90792 L
s
.48893 .89855 m .47739 .90707 L .48108 .90627 L 0 1 .354 r
F
0 g
.48107 .90627 m
.48108 .90627 L
s
.47876 .90792 m
.48107 .90627 L
s
.77292 .90556 m .77616 .91415 L .78256 .90593 L 0 1 .52 r
F
0 g
.76861 .92006 m
.77616 .91415 L
s
.77414 .92062 m
.77616 .91415 L
s
.35582 .98679 m .33683 .98185 L .34074 .98636 L 0 1 .538 r
F
0 g
.33234 .98412 m
.34074 .98636 L
s
.50799 .78483 m .50714 .79789 L .50974 .79478 L 0 1 .437 r
F
0 g
.50714 .79789 m
.50944 .80245 L
s
.55566 .40921 m .56912 .40067 L .56532 .41126 L 0 .178 .102 r
F
0 g
.56912 .40067 m
.57151 .40025 L
s
.52336 .6635 m .53021 .64793 L .52621 .65649 L 0 1 .337 r
F
.52336 .66493 m .53021 .64793 L .52621 .65649 L 0 .641 .273 r
F
.53179 .64626 m .53021 .64793 L .53284 .64407 L 0 0 .072 r
F
.51866 .67127 m .52356 .66428 L .52336 .6635 L 0 1 .357 r
F
.52277 .66504 m .52683 .65571 L .53179 .64626 L 0 0 .072 r
F
.52683 .65571 m .53021 .64793 L .53179 .64626 L F
.51789 .67254 m .51832 .67192 L .51866 .67127 L 0 1 .357 r
F
.51832 .67192 m .52356 .66428 L .51866 .67127 L F
.51316 .68036 m .51641 .67533 L .51789 .67254 L F
.51641 .67533 m .52356 .66428 L .51789 .67254 L F
.52277 .66504 m .53179 .64626 L .53236 .64747 L 0 0 .072 r
F
.53179 .64626 m .53284 .64407 L .5328 .64434 L F
.53179 .64626 m .5328 .64434 L .53236 .64747 L F
0 g
.53025 .64786 m
.53029 .6478 L
s
.53029 .6478 m
.53032 .64776 L
s
.53032 .64776 m
.53033 .64774 L
s
.53158 .64592 m
.53284 .64407 L
s
.53033 .64774 m
.53158 .64592 L
s
.53021 .64793 m
.53029 .6478 L
s
.53024 .64784 m
.53038 .64747 L
s
.53021 .64793 m
.53024 .64784 L
s
.53022 .64788 m
.53022 .64787 L
s
.53037 .64744 m
.53041 .64733 L
s
.53022 .64787 m
.53037 .64744 L
s
.53284 .64407 m
.53301 .64353 L
s
.41578 .82582 m .41193 .81931 L .40657 .81609 L 0 1 .422 r
F
.53995 .64617 m .54078 .63848 L .5442 .62752 L 0 .121 .123 r
F
0 g
.54191 .62717 m
.5442 .62752 L
s
.52277 .66172 m .52621 .65649 L .53021 .64793 L 0 1 .334 r
F
0 g
.53021 .64793 m
.53022 .64788 L
s
.47939 .6549 m .46846 .64874 L .46813 .65376 L 0 1 .315 r
F
0 g
.46846 .64874 m
.47205 .64571 L
s
.46537 .64482 m
.46846 .64874 L
s
.52277 .66504 m .52621 .65649 L .53021 .64793 L 0 0 .072 r
F
0 g
.53021 .64793 m
.53025 .64786 L
s
.53264 .64704 m
.53293 .64694 L
s
.75462 .75681 m
.75525 .75847 L
s
.47582 .78324 m .47294 .7814 L .46898 .78292 L 0 1 .458 r
F
.33645 .77704 m .32466 .76532 L .32384 .7723 L 0 1 .453 r
F
.33645 .77704 m .32865 .7641 L .32466 .76532 L F
.33645 .77704 m .33371 .76913 L .32865 .7641 L F
.34616 .7736 m .33371 .76913 L .33645 .77704 L 0 1 .447 r
F
0 g
.33645 .77704 m
.34138 .78189 L
s
.33563 .78401 m
.33645 .77704 L
s
.47939 .6549 m .47127 .6577 L .47581 .65793 L 0 1 .315 r
F
.47939 .6549 m .46813 .65376 L .47127 .6577 L F
.49065 .65861 m .47939 .6549 L .4826 .65897 L 0 .925 .305 r
F
.59589 .40392 m .6023 .40196 L .60891 .40638 L 0 .416 .099 r
F
0 g
.6023 .40196 m
.6043 .39595 L
s
.53593 .66566 m .54385 .65951 L .53931 .66196 L 0 .973 .328 r
F
.53568 .65948 m .53931 .66196 L .54385 .65951 L 0 1 .326 r
F
0 g
.54385 .65951 m
.54638 .65534 L
s
.54385 .65951 m
.54524 .66016 L
s
.40211 .94403 m .38818 .94497 L .38567 .9467 L 0 1 .493 r
F
.40211 .94403 m .39523 .94383 L .38818 .94497 L F
.40777 .93942 m .39523 .94383 L .40211 .94403 L 0 1 .477 r
F
0 g
.40211 .94403 m
.40887 .94275 L
s
.40211 .94403 m
.40564 .94563 L
s
.72968 .92361 m .7246 .93485 L .73211 .93016 L 0 1 .513 r
F
.72968 .92361 m .72117 .93464 L .7246 .93485 L F
0 g
.72154 .93918 m
.7246 .93485 L
s
.4493 .87317 m .44966 .8824 L .45155 .87978 L 0 .837 .422 r
F
.46198 .88855 m .45155 .87978 L .44966 .8824 L 0 .767 .42 r
F
0 g
.44966 .8824 m
.45241 .889 L
s
.44428 .87966 m
.44966 .8824 L
s
.28311 .8114 m .26888 .80666 L .26874 .81036 L 0 1 .529 r
F
.28311 .8114 m .27314 .80571 L .26888 .80666 L F
.28311 .8114 m .27924 .80775 L .27314 .80571 L F
.29344 .80846 m .27924 .80775 L .28311 .8114 L 0 1 .525 r
F
0 g
.28295 .81507 m
.28311 .8114 L
s
.28311 .8114 m
.28906 .81319 L
s
.49416 .7795 m .49421 .78894 L .49534 .7841 L 0 1 .443 r
F
.50101 .78239 m .49534 .7841 L .49421 .78894 L 0 1 .44 r
F
0 g
.49421 .78894 m
.49578 .79357 L
s
.49102 .79144 m
.49421 .78894 L
s
.38916 .79779 m .38083 .78696 L .37718 .78871 L 0 1 .428 r
F
.38916 .79779 m .38597 .79086 L .38083 .78696 L F
0 g
.389 .80442 m
.38916 .79779 L
s
.38602 .78856 m
.38643 .78433 L
s
.39829 .79276 m .38917 .79779 L .39424 .80145 L 0 1 .42 r
F
.39829 .79276 m .38597 .79086 L .38917 .79779 L F
.52129 .65899 m .52655 .64005 L .52341 .65067 L 0 1 .331 r
F
.52042 .65808 m .52341 .65067 L .52655 .64005 L F
0 g
.52655 .64005 m
.52657 .63996 L
s
.52655 .64005 m
.52939 .63276 L
s
.44916 .62514 m .45022 .61885 L .44788 .61411 L 0 1 .343 r
F
0 g
.45022 .61885 m
.45414 .61456 L
s
.53772 .98082 m
.53776 .98079 L
s
.45493 .78235 m .45207 .77999 L .44758 .7806 L 0 1 .471 r
F
.46216 .77347 m .45493 .78235 L .45916 .7814 L 0 1 .462 r
F
.46216 .77347 m .45207 .77999 L .45493 .78235 L F
0 g
.45493 .78235 m
.45499 .78666 L
s
.50911 .5119 m .51671 .48462 L .51687 .47989 L 0 1 .143 r
F
.50911 .5119 m .5134 .49831 L .51671 .48462 L F
0 g
.51671 .48462 m
.51896 .47848 L
s
.51844 .6572 m .52453 .63054 L .5237 .63071 L 0 1 .335 r
F
0 g
.51945 .65281 m
.52128 .6465 L
s
.51844 .6572 m .52336 .63848 L .52453 .63054 L 0 1 .335 r
F
0 g
.52427 .63545 m
.52521 .6323 L
s
.52453 .63054 m
.52466 .63004 L
s
.52384 .62936 m
.52395 .62828 L
s
.52254 .63069 m
.52255 .63065 L
s
.52255 .63065 m
.52318 .62798 L
s
.52318 .62798 m
.5234 .62706 L
s
.52442 .63131 m
.52453 .63054 L
s
.52409 .63356 m
.52442 .63131 L
s
.69977 .5447 m .70569 .56798 L .70157 .5637 L 0 .578 .137 r
F
.69977 .5447 m .71021 .55816 L .70569 .56798 L F
0 g
.69977 .5447 m
.70157 .5637 L
s
.69539 .55648 m
.69977 .5447 L
s
.31649 .8017 m .31015 .80654 L .31517 .80492 L 0 1 .512 r
F
.31649 .8017 m .30378 .80546 L .31015 .80654 L F
0 g
.30964 .8099 m
.31015 .80654 L
s
.31517 .80492 m
.32197 .8056 L
s
.68771 .92442 m .68229 .93198 L .68963 .93188 L 0 1 .527 r
F
.68771 .92442 m .6791 .92975 L .68229 .93198 L F
0 g
.67922 .9354 m
.68229 .93198 L
s
.67849 .92974 m
.6791 .92975 L
s
.39829 .79276 m .39424 .80145 L .39782 .79938 L 0 1 .42 r
F
.40648 .80945 m .39782 .79938 L .39424 .80145 L 0 1 .421 r
F
0 g
.39424 .80145 m
.39434 .80808 L
s
.38917 .79779 m
.39424 .80145 L
s
.4458 .59189 m .43746 .59735 L .44144 .59723 L 0 1 .342 r
F
.4458 .59189 m .43604 .59207 L .43746 .59735 L F
.4458 .59189 m .43814 .58491 L .43604 .59207 L F
.4458 .59189 m .44251 .57957 L .43814 .58491 L F
0 g
.4458 .59189 m
.4474 .59738 L
s
.53352 .64672 m .53743 .65611 L .54165 .65242 L 0 .578 .261 r
F
.53352 .64672 m .53395 .65367 L .53743 .65611 L F
.52383 .66552 m .53108 .65188 L .52687 .6593 L 0 1 .339 r
F
.52336 .66493 m .53395 .65367 L .53352 .64672 L 0 .641 .273 r
F
0 g
.53293 .64694 m
.53352 .64672 L
s
.53244 .65577 m
.53443 .65414 L
s
.53352 .64672 m
.53382 .64523 L
s
.51316 .68036 m .50889 .68188 L .5104 .68095 L 0 0 .037 r
F
.51316 .68036 m .50846 .68278 L .50889 .68188 L F
0 g
.50803 .68263 m
.50889 .68188 L
s
.4493 .87317 m .44441 .86698 L .43903 .86425 L 0 .837 .422 r
F
.424 .78394 m .41613 .78035 L .41239 .78276 L 0 1 .489 r
F
.424 .78394 m .42111 .78086 L .41613 .78035 L F
.43285 .77719 m .42111 .78086 L .424 .78394 L 0 1 .482 r
F
0 g
.42358 .78822 m
.424 .78394 L
s
.424 .78394 m
.42875 .78418 L
s
.48112 .77246 m .47582 .78324 L .47947 .78133 L 0 1 .449 r
F
.48112 .77246 m .47294 .7814 L .47582 .78324 L F
0 g
.47582 .78324 m
.47635 .78677 L
s
.46998 .46941 m .47775 .45479 L .47648 .45731 L 0 0 0 r
F
0 g
.47775 .45479 m
.48253 .44534 L
s
.47496 .45997 m
.47775 .45479 L
s
.38158 .78035 m .37718 .78871 L .38083 .78696 L 0 1 .428 r
F
.38153 .78265 m .37718 .78871 L .38083 .78696 L 0 1 .506 r
F
.38148 .78496 m .37718 .78871 L .38083 .78696 L 0 1 .44 r
F
.38158 .78035 m .3723 .78459 L .37718 .78871 L 0 1 .428 r
F
.38153 .78265 m .37225 .78685 L .37718 .78871 L 0 1 .506 r
F
.38148 .78496 m .3722 .78912 L .37718 .78871 L 0 1 .44 r
F
0 g
.38084 .78696 m
.38088 .78696 L
s
.38088 .78696 m
.38095 .78695 L
s
.38095 .78695 m
.38106 .78693 L
s
.38106 .78693 m
.38606 .78626 L
s
.37718 .78877 m
.37718 .78871 L
s
.37718 .78879 m
.37718 .78871 L
s
.37712 .7908 m
.37718 .78871 L
s
.38083 .78696 m
.38084 .78696 L
s
.38096 .787 m
.38108 .78704 L
s
.38108 .78704 m
.38126 .7871 L
s
.38083 .78696 m
.38096 .787 L
s
.38126 .7871 m
.38602 .78856 L
s
.37713 .78871 m
.37718 .78871 L
s
.37709 .78871 m
.37713 .78871 L
s
.49886 .99273 m .50437 .99627 L .50455 .99407 L 0 1 .539 r
F
.51833 .98899 m .50455 .99407 L .50437 .99627 L 0 1 .526 r
F
0 g
.50437 .99627 m
.51039 .99628 L
s
.49809 .99815 m
.50437 .99627 L
s
.64695 .47165 m
.6486 .47916 L
s
.64562 .46576 m
.64656 .46992 L
s
.64656 .46992 m
.64695 .47165 L
s
.49261 .89776 m
.49728 .89367 L
s
.51316 .68035 m .5025 .65736 L .5056 .66517 L 0 .755 .288 r
F
0 g
.5023 .65719 m
.5025 .65736 L
s
.50319 .65131 m
.50629 .65911 L
s
.52419 .66774 m .53223 .66116 L .53541 .65587 L 0 1 .342 r
F
0 g
.53454 .65732 m
.53541 .65587 L
s
.53541 .65587 m
.5364 .65539 L
s
.48751 .77619 m .48671 .78535 L .48827 .78073 L 0 1 .446 r
F
.49416 .7795 m .48827 .78073 L .48671 .78535 L 0 1 .443 r
F
0 g
.48326 .78755 m
.48671 .78535 L
s
.48671 .78535 m
.48672 .78541 L
s
.67221 1.07772 m .68436 1.07868 L .68194 1.07794 L 0 .956 .363 r
F
.69746 1.07593 m .68436 1.07868 L .69387 1.07839 L 0 .864 .315 r
F
.69746 1.07593 m .68194 1.07794 L .68436 1.07868 L F
0 g
.68799 1.07981 m
.68854 1.07968 L
s
.67797 1.07974 m
.68436 1.07868 L
s
.52435 .98902 m
.52452 .98889 L
s
.52452 .98889 m
.52477 .9887 L
s
.52477 .9887 m
.52503 .98849 L
s
.52503 .98849 m
.52521 .98835 L
s
.52521 .98835 m
.52606 .98769 L
s
.52792 .98625 m
.52822 .98602 L
s
.3723 .78459 m .36057 .77457 L .35998 .78127 L 0 1 .435 r
F
.44637 .5592 m .43974 .56148 L .44318 .5612 L 0 1 .337 r
F
.44637 .5592 m .43785 .5599 L .43974 .56148 L F
0 g
.44513 .56509 m
.44832 .56115 L
s
.44637 .5592 m .43876 .55751 L .43785 .5599 L 0 1 .337 r
F
.44637 .5592 m .44196 .55551 L .43876 .55751 L F
.44637 .5592 m .4453 .55524 L .44196 .55551 L F
0 g
.4453 .55524 m
.44718 .55682 L
s
.44318 .5612 m
.44637 .5592 L
s
.44637 .5592 m
.44833 .56114 L
s
.50101 .78239 m .50192 .7921 L .50258 .78703 L 0 1 .44 r
F
.50799 .78483 m .50258 .78703 L .50192 .7921 L 0 1 .437 r
F
0 g
.50192 .7921 m
.50387 .79675 L
s
.499 .7949 m
.50192 .7921 L
s
.51316 .68035 m .50674 .65626 L .51041 .67001 L 0 .741 .289 r
F
.51316 .68035 m .51041 .67001 L .50674 .65626 L 0 .748 .288 r
F
0 g
.50674 .65625 m
.50674 .65626 L
s
.50674 .65625 m
.50674 .65626 L
s
.46216 .77347 m .45916 .7814 L .46194 .77778 L 0 1 .462 r
F
.46876 .77854 m .46194 .77778 L .45916 .7814 L 0 1 .46 r
F
0 g
.45916 .7814 m
.45938 .78578 L
s
.45493 .78235 m
.45916 .7814 L
s
.35588 .77005 m .35097 .77829 L .35481 .77681 L 0 1 .441 r
F
.35588 .77005 m .34616 .7736 L .35097 .77829 L F
0 g
.35054 .78507 m
.35097 .77829 L
s
.35481 .77681 m
.35998 .78127 L
s
.50681 .68626 m .50123 .69384 L .49971 .69547 L 0 0 0 r
F
0 g
.49703 .69927 m
.49971 .69547 L
s
.73915 .93542 m .73241 .9387 L .72998 .94241 L 0 1 .533 r
F
0 g
.72168 .94352 m
.72998 .94241 L
s
.44998 .52952 m .45407 .51549 L .45146 .51633 L 0 1 .285 r
F
0 g
.45407 .51549 m
.45881 .50819 L
s
.45344 .52114 m
.45407 .51549 L
s
.46198 .88855 m .45796 .8952 L .46324 .89784 L 0 .767 .42 r
F
0 g
.52071 .61642 m
.52179 .61148 L
s
.49065 .65861 m .4826 .65897 L .48713 .66015 L 0 .925 .305 r
F
.5019 .66636 m .49065 .65861 L .49391 .66304 L 0 .842 .295 r
F
0 g
.49913 .65454 m
.5019 .65938 L
s
.43298 .83547 m .42185 .83548 L .42609 .84187 L 0 .922 .413 r
F
.43298 .83547 m .42091 .82885 L .42185 .83548 L F
0 g
.41643 .83246 m
.42185 .83548 L
s
.79275 .69936 m .80259 .71206 L .80411 .70405 L 0 1 .497 r
F
0 g
.80259 .71206 m
.80482 .71945 L
s
.7981 .71654 m
.80259 .71206 L
s
.45806 .64018 m .44975 .64498 L .45422 .64469 L 0 1 .335 r
F
.45806 .64018 m .44699 .6406 L .44975 .64498 L F
.45806 .64018 m .44777 .63446 L .44699 .6406 L F
.45806 .64018 m .45162 .62996 L .44777 .63446 L F
0 g
.45741 .92067 m
.46316 .91744 L
s
.48513 .93229 m .48885 .9409 L .48945 .93867 L 0 .637 .424 r
F
.50122 .94821 m .48885 .9409 L .49356 .94743 L 0 .507 .402 r
F
.50122 .94821 m .48945 .93867 L .48885 .9409 L F
0 g
.48333 .93787 m
.48885 .9409 L
s
.51503 .78679 m .50974 .79478 L .51206 .79946 L 0 1 .433 r
F
0 g
.50944 .80245 m
.51206 .79946 L
s
.43298 .83547 m .42609 .84187 L .43126 .84471 L 0 .922 .413 r
F
0 g
.42609 .84187 m
.42729 .8485 L
s
.50737 .41589 m .5022 .42966 L .50252 .42559 L 0 .031 .08 r
F
0 g
.49818 .42906 m
.50141 .42247 L
s
.50737 .41589 m .50693 .42703 L .5022 .42966 L 0 .031 .08 r
F
0 g
.50141 .42247 m
.50301 .41923 L
s
.50737 .41589 m .51352 .41947 L .50693 .42703 L 0 .031 .08 r
F
.50737 .41589 m .51835 .40977 L .51352 .41947 L F
.32124 .98292 m .30172 .97626 L .30538 .98128 L 0 1 .537 r
F
.4235 .81976 m .41578 .82582 L .42091 .82885 L 0 .972 .412 r
F
.4235 .81976 m .41193 .81931 L .41578 .82582 L F
0 g
.41578 .82582 m
.41643 .83246 L
s
.36273 .98276 m .36369 .98879 L .36634 .98713 L 0 1 .538 r
F
.36273 .98276 m .35582 .98679 L .36369 .98879 L F
0 g
.36369 .98879 m
.36802 .99292 L
s
.78313 .78783 m .79385 .79089 L .78943 .78784 L 0 .714 .447 r
F
.78313 .78783 m .79406 .7956 L .79385 .79089 L F
0 g
.60991 .54756 m
.61146 .55436 L
s
.60612 .53099 m
.60836 .5408 L
s
.60836 .5408 m
.60991 .54756 L
s
.60612 .53099 m
.6067 .56494 L
s
.51832 .53018 m .5161 .51785 L .51595 .5304 L 0 1 .213 r
F
.5176 .57704 m .51832 .53018 L .51573 .55303 L 0 1 .25 r
F
.43426 .92865 m .43573 .93145 L .43752 .92946 L 0 1 .44 r
F
.43426 .92865 m .42949 .93348 L .43573 .93145 L F
0 g
.43573 .93145 m
.4395 .93194 L
s
.46813 .65376 m .46092 .64462 L .45726 .64866 L 0 1 .326 r
F
0 g
.45796 .64788 m
.46092 .64462 L
s
.45806 .64018 m
.46092 .64462 L
s
.44916 .62514 m .44788 .61411 L .4437 .61409 L 0 1 .343 r
F
0 g
.44788 .61411 m
.45201 .60928 L
s
.44788 .61411 m
.45022 .61885 L
s
.52042 .65808 m .52502 .6389 L .52224 .64971 L 0 1 .331 r
F
.51946 .65748 m .52224 .64971 L .52502 .6389 L 0 1 .333 r
F
0 g
.52502 .6389 m
.52523 .63774 L
s
.52502 .6389 m
.52596 .63612 L
s
.3723 .78459 m .36441 .77305 L .36057 .77457 L 0 1 .435 r
F
.3723 .78459 m .36944 .77735 L .36441 .77305 L F
.38158 .78035 m .36944 .77735 L .3723 .78459 L 0 1 .428 r
F
0 g
.3721 .78685 m
.3723 .78459 L
s
.3723 .78459 m
.37403 .78605 L
s
.51844 .6572 m .5237 .63071 L .5216 .63872 L 0 1 .335 r
F
0 g
.52294 .63362 m
.52338 .63196 L
s
.52338 .63196 m
.52363 .63098 L
s
.52363 .63098 m
.5237 .63071 L
s
.51868 .65545 m
.52076 .64334 L
s
.52242 .6545 m
.52247 .65437 L
s
.52356 .63713 m
.52369 .63628 L
s
.52369 .63628 m
.52409 .63356 L
s
.51868 .65546 m
.51883 .65493 L
s
.5237 .63071 m
.52384 .62936 L
s
.52354 .6379 m
.52427 .63545 L
s
.25326 .79194 m .24815 .79898 L .25239 .79795 L 0 1 .526 r
F
.25326 .79194 m .24254 .79432 L .24815 .79898 L F
0 g
.24815 .79898 m
.24823 .80503 L
s
.25239 .79795 m
.25869 .80227 L
s
.48112 .77246 m .47259 .77692 L .47294 .7814 L 0 1 .449 r
F
0 g
.46898 .78292 m
.47294 .7814 L
s
.47955 .78181 m
.48024 .78587 L
s
.45074 .74888 m .44059 .7553 L .43953 .75702 L 0 1 .234 r
F
.45074 .74888 m .44434 .75242 L .44059 .7553 L F
.45074 .74888 m .44869 .74967 L .44434 .75242 L F
.45962 .74087 m .44869 .74967 L .45074 .74888 L 0 .945 .207 r
F
0 g
.45074 .74888 m
.45487 .74584 L
s
.44967 .75061 m
.45074 .74888 L
s
.33618 .78637 m .33159 .79249 L .33543 .79115 L 0 1 .518 r
F
.33618 .78637 m .32648 .78956 L .33159 .79249 L F
0 g
.33154 .79731 m
.33159 .79249 L
s
.33543 .79115 m
.34096 .79379 L
s
.50122 .94821 m .49356 .94743 L .50045 .95391 L 0 .507 .402 r
F
0 g
.48885 .9409 m
.49356 .94743 L
s
.48796 .94409 m
.49356 .94743 L
s
.4235 .81976 m .41152 .81269 L .41193 .81931 L 0 .972 .412 r
F
0 g
.40657 .81609 m
.41193 .81931 L
s
.29375 .97294 m .29346 .97965 L .29676 .97829 L 0 1 .537 r
F
.29375 .97294 m .28527 .97619 L .29346 .97965 L F
0 g
.29346 .97965 m
.29738 .9848 L
s
.27531 .77211 m .2629 .75781 L .26174 .76553 L 0 1 .476 r
F
.27531 .77211 m .26729 .75686 L .2629 .75781 L F
.27531 .77211 m .27261 .763 L .26729 .75686 L F
.28604 .76932 m .27261 .763 L .27531 .77211 L 0 1 .472 r
F
0 g
.27414 .7798 m
.27531 .77211 L
s
.27531 .77211 m
.28051 .77805 L
s
.51316 .68036 m .50964 .68253 L .50846 .68278 L 0 0 .037 r
F
0 g
.5084 .68287 m
.50846 .68278 L
s
.51316 .68035 m .51868 .65546 L .51553 .66967 L 0 .726 .282 r
F
.51316 .68035 m .51553 .66967 L .51868 .65546 L 0 .728 .282 r
F
0 g
.51868 .65546 m
.51868 .65546 L
s
.51868 .65546 m
.51868 .65545 L
s
.30296 .94783 m .28404 .94921 L .28699 .95073 L 0 1 .36 r
F
.30296 .94783 m .28764 .94794 L .28404 .94921 L F
.30296 .94783 m .29577 .94735 L .28764 .94794 L F
.31146 .94416 m .29577 .94735 L .30296 .94783 L 0 1 .327 r
F
0 g
.30296 .94783 m
.30586 .94935 L
s
.30296 .94783 m
.31082 .94702 L
s
.22113 .799 m .20673 .79326 L .21044 .8013 L 0 1 .527 r
F
0 g
.21044 .8013 m
.21638 .80656 L
s
.4904 .66663 m .4826 .65897 L .47912 .66124 L 0 .904 .306 r
F
.4904 .66663 m .48713 .66015 L .4826 .65897 L F
0 g
.47939 .6549 m
.4826 .65897 L
s
.32124 .98292 m .30503 .97491 L .30172 .97626 L 0 1 .537 r
F
0 g
.29676 .97829 m
.29925 .97916 L
s
.32124 .98292 m .3134 .97777 L .30503 .97491 L 0 1 .537 r
F
0 g
.29925 .97916 m
.30538 .98128 L
s
.32896 .97926 m .3134 .97777 L .32124 .98292 L 0 1 .537 r
F
0 g
.32124 .98292 m
.32935 .98564 L
s
.32124 .98292 m
.32487 .98792 L
s
.31 .76287 m .30252 .77184 L .30775 .77033 L 0 1 .462 r
F
.31 .76287 m .29679 .76647 L .30252 .77184 L F
0 g
.30107 .77935 m
.30252 .77184 L
s
.30775 .77033 m
.31399 .7754 L
s
.31998 .94052 m .3191 .94314 L .32242 .94159 L 0 1 .289 r
F
0 g
.32242 .94159 m
.33041 .94002 L
s
.31998 .94052 m .31146 .94416 L .3191 .94314 L 0 1 .289 r
F
0 g
.3191 .94314 m
.32236 .94411 L
s
.44799 .77635 m .43739 .77713 L .43699 .78138 L 0 1 .473 r
F
0 g
.4322 .78141 m
.43699 .78138 L
s
.5176 .57704 m .52044 .56781 L .52302 .54492 L 0 1 .25 r
F
0 g
.52044 .56781 m
.52112 .56175 L
s
.52112 .56175 m
.52302 .54492 L
s
.52302 .54492 m
.52465 .55362 L
s
.48112 .77246 m .47947 .78133 L .48147 .77695 L 0 1 .449 r
F
.48751 .77619 m .48147 .77695 L .47947 .78133 L 0 1 .446 r
F
0 g
.47582 .78324 m
.47947 .78133 L
s
.47947 .78133 m
.47955 .78181 L
s
.44329 .85095 m .43271 .85136 L .4373 .85763 L 0 .867 .412 r
F
.44329 .85095 m .43126 .84471 L .43271 .85136 L F
0 g
.42729 .8485 m
.43271 .85136 L
s
.53568 .65948 m .53581 .66194 L .53931 .66196 L 0 1 .326 r
F
.52444 .67013 m .53568 .65948 L .53223 .66116 L 0 1 .344 r
F
.52444 .67013 m .53581 .66194 L .53568 .65948 L F
0 g
.53568 .65948 m
.53807 .65555 L
s
.53568 .65948 m
.53568 .65948 L
s
.53428 .66016 m
.53568 .65948 L
s
.49859 .69738 m .49181 .70643 L .49025 .70831 L 0 0 0 r
F
.71323 .93903 m .72477 .93987 L .72129 .93815 L 0 1 .535 r
F
.36293 .79314 m .35058 .79298 L .35027 .79531 L 0 1 .48 r
F
.36293 .79314 m .35443 .79161 L .35058 .79298 L F
.36293 .79314 m .35973 .79168 L .35443 .79161 L F
.3722 .78912 m .35973 .79168 L .36293 .79314 L 0 1 .463 r
F
0 g
.3626 .79545 m
.36293 .79314 L
s
.36293 .79314 m
.36798 .79297 L
s
.46813 .65376 m .45993 .65817 L .46447 .6578 L 0 1 .326 r
F
.46813 .65376 m .45684 .65424 L .45993 .65817 L F
.46813 .65376 m .45726 .64866 L .45684 .65424 L F
.4904 .66663 m .49047 .66343 L .48713 .66015 L 0 .904 .306 r
F
0 g
.48713 .66015 m
.49065 .65861 L
s
.50045 .95391 m .5053 .96236 L .50548 .96031 L 0 .513 .405 r
F
.51777 .97068 m .5053 .96236 L .51068 .96917 L 0 .364 .362 r
F
.51777 .97068 m .50548 .96031 L .5053 .96236 L F
0 g
.49968 .959 m
.5053 .96236 L
s
.3809 .78701 m
.38597 .79086 L
s
.38083 .78696 m
.3809 .78701 L
s
.38597 .79086 m
.38597 .79085 L
s
.38597 .79085 m
.38643 .78431 L
s
.46216 .77347 m .45229 .77568 L .45207 .77999 L 0 1 .462 r
F
0 g
.44758 .7806 m
.45207 .77999 L
s
.67958 .94919 m .69051 .94666 L .68738 .94647 L 0 1 .468 r
F
.69649 .93811 m .69051 .94666 L .69799 .94306 L 0 1 .482 r
F
.69649 .93811 m .68738 .94647 L .69051 .94666 L F
0 g
.6952 .94706 m
.69709 .94436 L
s
.68715 .94986 m
.69051 .94666 L
s
.47901 .66544 m .47581 .65793 L .47127 .6577 L 0 .973 .317 r
F
.47901 .66544 m .47912 .66124 L .47581 .65793 L F
0 g
.47581 .65793 m
.47939 .6549 L
s
.51316 .68035 m .50227 .66002 L .50214 .66182 L 0 .753 .287 r
F
.51316 .68035 m .5056 .66517 L .50227 .66002 L F
0 g
.5019 .65938 m
.50227 .66002 L
s
.50799 .78483 m .50974 .79478 L .50995 .78949 L 0 1 .437 r
F
.51503 .78679 m .50995 .78949 L .50974 .79478 L 0 1 .433 r
F
0 g
.50974 .79478 m
.51206 .79946 L
s
.50714 .79789 m
.50974 .79478 L
s
.52419 .66774 m .53175 .65634 L .52739 .66245 L 0 1 .342 r
F
.52383 .66552 m .52739 .66245 L .53175 .65634 L 0 1 .339 r
F
0 g
.53175 .65634 m
.53244 .65577 L
s
.53175 .65634 m
.53209 .65564 L
s
.52388 .66011 m
.52388 .66011 L
s
.52388 .66011 m
.52388 .66011 L
s
.52388 .66011 m
.52394 .65994 L
s
.44916 .62514 m .44074 .63035 L .4451 .63007 L 0 1 .343 r
F
.44916 .62514 m .4384 .62561 L .44074 .63035 L F
0 g
.44877 .63329 m
.45162 .62996 L
s
.44916 .62514 m .43963 .61901 L .4384 .62561 L 0 1 .343 r
F
.44916 .62514 m .4437 .61409 L .43963 .61901 L F
0 g
.44916 .62514 m
.45162 .62996 L
s
.5019 .66636 m .50198 .66454 L .49871 .66011 L 0 .842 .295 r
F
.48695 .92619 m .47878 .92603 L .48513 .93229 L 0 .614 .415 r
F
.48695 .92619 m .47479 .91953 L .47878 .92603 L F
0 g
.47327 .92301 m
.47878 .92603 L
s
.75151 .56763 m .76452 .57271 L .76296 .57766 L 0 .328 .044 r
F
0 g
.76452 .57271 m
.76916 .57217 L
s
.7622 .56534 m
.76452 .57271 L
s
.51931 .63326 m .52022 .63254 L .52205 .62407 L 0 1 .328 r
F
0 g
.52193 .62462 m
.52205 .62407 L
s
.52199 .625 m
.52205 .62407 L
s
.78256 .90593 m .79218 .90656 L .79424 .90006 L 0 1 .521 r
F
.47771 .99815 m .46964 .99741 L .46282 .9984 L 0 1 .542 r
F
0 g
.46017 .99701 m
.46282 .9984 L
s
.39247 .99192 m
.40029 .99283 L
s
.47951 .99298 m .47771 .99815 L .48421 .99714 L 0 1 .542 r
F
.47951 .99298 m .46964 .99741 L .47771 .99815 L F
0 g
.47771 .99815 m
.48008 .9991 L
s
.41463 .99004 m .3963 .98892 L .40029 .99283 L 0 1 .54 r
F
.51316 .68035 m .50629 .65911 L .51021 .67124 L 0 .748 .288 r
F
.51316 .68035 m .51021 .67124 L .50629 .65911 L 0 .753 .288 r
F
0 g
.50355 .64882 m
.50629 .65911 L
s
.50629 .65911 m
.50629 .65911 L
s
.51 .67958 m
.51118 .67932 L
s
.47223 .91066 m .47479 .91953 L .4758 .91711 L 0 .715 .425 r
F
.48695 .92619 m .4758 .91711 L .47479 .91953 L 0 .614 .415 r
F
0 g
.47479 .91953 m
.47878 .92603 L
s
.46939 .91668 m
.47479 .91953 L
s
.35321 .93076 m .33573 .93543 L .33848 .93594 L 0 1 .254 r
F
.35321 .93076 m .33907 .9339 L .33573 .93543 L F
.35321 .93076 m .34657 .9319 L .33907 .9339 L F
0 g
.35321 .93076 m
.35591 .93128 L
s
.51316 .68035 m .51316 .68035 L .51626 .67179 L 0 0 .059 r
F
.51316 .68035 m .51316 .68035 L .5164 .67165 L 0 0 .058 r
F
.51316 .68035 m .51316 .68035 L .5165 .67163 L 0 0 .056 r
F
.51316 .68035 m .51976 .66362 L .52236 .65464 L 0 .72 .283 r
F
0 g
.52236 .65464 m
.52242 .6545 L
s
.40648 .80945 m .40307 .80282 L .39782 .79938 L 0 1 .421 r
F
.41496 .80377 m .40648 .80945 L .41152 .81269 L 0 1 .412 r
F
.41496 .80377 m .40307 .80282 L .40648 .80945 L F
0 g
.40648 .80945 m
.40657 .81609 L
s
.55853 .39843 m .56518 .39557 L .57135 .40056 L 0 .39 .116 r
F
0 g
.56518 .39557 m
.56897 .38514 L
s
.55566 .40921 m .55289 .42335 L .55181 .41983 L 0 .178 .102 r
F
.55566 .40921 m .55869 .41967 L .55289 .42335 L F
.55566 .40921 m .56532 .41126 L .55869 .41967 L F
.48059 .72003 m .47222 .72877 L .47084 .73057 L 0 .833 .143 r
F
0 g
.52701 .98554 m
.52706 .98552 L
s
.52706 .98552 m
.52769 .98534 L
s
.54415 .66917 m
.5455 .66769 L
s
.44998 .52952 m .44213 .53706 L .44513 .53635 L 0 1 .285 r
F
.44998 .52952 m .44276 .5314 L .44213 .53706 L F
0 g
.4471 .53899 m
.44963 .53562 L
s
.44998 .52952 m .44661 .52315 L .44276 .5314 L 0 1 .285 r
F
.44998 .52952 m .45146 .51633 L .44661 .52315 L F
0 g
.44963 .53562 m
.44998 .52952 L
s
.6287 .58202 m .63289 .57111 L .62842 .53256 L 0 .385 .231 r
F
0 g
.62842 .53256 m
.62843 .53386 L
s
.62843 .53386 m
.62861 .56642 L
s
.62861 .56642 m
.6287 .58202 L
s
.62768 .5644 m
.6287 .58202 L
s
.62836 .53186 m
.62842 .53256 L
s
.48059 .72003 m .47569 .72511 L .47222 .72877 L 0 .833 .143 r
F
.48059 .72003 m .47928 .72137 L .47569 .72511 L F
.48871 .71037 m .47928 .72137 L .48059 .72003 L 0 0 0 r
F
0 g
.4792 .72183 m
.48059 .72003 L
s
.48059 .72003 m
.48393 .71614 L
s
.48717 .71217 m
.49025 .70831 L
s
.44329 .85095 m .4373 .85763 L .44246 .86031 L 0 .867 .412 r
F
0 g
.4373 .85763 m
.43903 .86425 L
s
.53425 .61138 m .53645 .61142 L .53945 .5741 L 0 .956 .244 r
F
0 g
.52253 .66206 m
.52295 .66118 L
s
.52444 .67013 m .5325 .66621 L .53581 .66194 L 0 1 .344 r
F
0 g
.53458 .66352 m
.53581 .66194 L
s
.53581 .66194 m
.53581 .66194 L
s
.53581 .66194 m
.53931 .66196 L
s
.51316 .68036 m .51118 .67932 L .51231 .67991 L 0 0 .032 r
F
.51316 .68036 m .51231 .67991 L .51118 .67932 L 0 0 .029 r
F
0 g
.51118 .67932 m
.51118 .67932 L
s
.51068 .67816 m
.51118 .67932 L
s
.33721 .9575 m .3187 .95632 L .3219 .95916 L 0 1 .519 r
F
.33721 .9575 m .32202 .95488 L .3187 .95632 L F
.33721 .9575 m .32996 .95538 L .32202 .95488 L F
.34496 .95351 m .32996 .95538 L .33721 .9575 L 0 1 .512 r
F
0 g
.33721 .9575 m
.34487 .95783 L
s
.33721 .9575 m
.34037 .96033 L
s
.41706 .77614 m .41239 .78276 L .41613 .78035 L 0 1 .491 r
F
.41706 .77614 m .40753 .78198 L .41239 .78276 L F
0 g
.41198 .78703 m
.41239 .78276 L
s
.51001 .55967 m .5161 .51785 L .51337 .51814 L 0 1 .241 r
F
0 g
.51749 .53745 m
.51832 .53018 L
s
.51001 .55967 m .51595 .5304 L .5161 .51785 L 0 1 .241 r
F
0 g
.5161 .51785 m
.51727 .50966 L
s
.516 .53039 m
.51832 .53018 L
s
.51745 .53782 m
.51749 .53745 L
s
.51384 .51809 m
.5161 .51785 L
s
.47901 .66544 m .47127 .6577 L .46776 .66123 L 0 .973 .317 r
F
0 g
.46822 .66077 m
.47127 .6577 L
s
.46813 .65376 m
.47127 .6577 L
s
.50101 .78239 m .49825 .78129 L .49534 .7841 L 0 1 .44 r
F
.51946 .65748 m .52336 .63848 L .52097 .64924 L 0 1 .333 r
F
.51844 .6572 m .52097 .64924 L .52336 .63848 L 0 1 .335 r
F
0 g
.52329 .65609 m
.52395 .65324 L
s
.52336 .63848 m
.52356 .63713 L
s
.52336 .63848 m
.52354 .6379 L
s
.52337 .40838 m .5299 .40117 L .53526 .40063 L 0 .172 .097 r
F
0 g
.5299 .40117 m
.53432 .39043 L
s
.34616 .7736 m .33465 .76225 L .33371 .76913 L 0 1 .447 r
F
.34616 .7736 m .33864 .761 L .33465 .76225 L F
.34616 .7736 m .34358 .76586 L .33864 .761 L F
.35588 .77005 m .34358 .76586 L .34616 .7736 L 0 1 .441 r
F
0 g
.34616 .7736 m
.35097 .77829 L
s
.34521 .78046 m
.34616 .7736 L
s
.51736 .65722 m .52243 .63119 L .52155 .63166 L 0 1 .339 r
F
.51736 .65722 m .5216 .63872 L .52243 .63119 L F
0 g
.52166 .63847 m
.52294 .63362 L
s
.52243 .63119 m
.52254 .63069 L
s
.52177 .62538 m
.52193 .62462 L
s
.52189 .62656 m
.52199 .625 L
s
.5223 .63237 m
.52243 .63119 L
s
.52196 .63544 m
.5223 .63237 L
s
.52166 .63814 m
.52196 .63544 L
s
.4235 .81976 m .42091 .82885 L .42391 .82638 L 0 .972 .412 r
F
.43298 .83547 m .42391 .82638 L .42091 .82885 L 0 .922 .413 r
F
0 g
.42091 .82885 m
.42185 .83548 L
s
.41578 .82582 m
.42091 .82885 L
s
.5316 .55903 m .53906 .54482 L .53789 .55017 L 0 0 .029 r
F
0 g
.53906 .54482 m
.5425 .53655 L
s
.46876 .77854 m .46606 .77655 L .46194 .77778 L 0 1 .46 r
F
.47507 .76836 m .46876 .77854 L .47259 .77692 L 0 1 .451 r
F
.47507 .76836 m .46606 .77655 L .46876 .77854 L F
0 g
.46876 .77854 m
.46898 .78292 L
s
.4904 .66663 m .47912 .66124 L .47901 .66544 L 0 .904 .306 r
F
0 g
.47581 .65793 m
.47912 .66124 L
s
.47912 .66124 m
.4826 .65897 L
s
.74776 .92407 m .7594 .91935 L .75571 .91914 L 0 1 .523 r
F
.73873 .92366 m .74776 .92407 L .75017 .91892 L 0 1 .519 r
F
.46852 .73236 m .46353 .73755 L .467 .7341 L 0 .873 .17 r
F
.46852 .73236 m .45962 .74087 L .46353 .73755 L F
0 g
.46241 .7393 m
.46353 .73755 L
s
.467 .7341 m
.47084 .73057 L
s
.42949 .93348 m .41643 .93616 L .41427 .93802 L 0 1 .467 r
F
.42949 .93348 m .42296 .93422 L .41643 .93616 L F
.43426 .92865 m .42296 .93422 L .42949 .93348 L 0 1 .44 r
F
0 g
.42949 .93348 m
.43303 .93448 L
s
.42949 .93348 m
.43573 .93145 L
s
.35582 .98679 m .33983 .98034 L .33683 .98185 L 0 1 .538 r
F
.35582 .98679 m .34798 .98246 L .33983 .98034 L F
.36273 .98276 m .34798 .98246 L .35582 .98679 L F
0 g
.35582 .98679 m
.35971 .99129 L
s
.35582 .98679 m
.36369 .98879 L
s
.7744 .58616 m .78076 .58225 L .78539 .58589 L 0 .199 0 r
F
.7744 .58616 m .77605 .58236 L .78076 .58225 L F
0 g
.77773 .57868 m
.78076 .58225 L
s
.31678 .79267 m .30205 .78547 L .30068 .79086 L 0 1 .52 r
F
.31678 .79267 m .30729 .78409 L .30205 .78547 L F
.31678 .79267 m .31361 .78718 L .30729 .78409 L F
0 g
.31539 .79804 m
.31678 .79267 L
s
.32648 .78956 m .31361 .78718 L .31678 .79267 L 0 1 .519 r
F
0 g
.31678 .79267 m
.32202 .79579 L
s
.46757 .47514 m
.46998 .46941 L
s
.50782 .68411 m .50741 .68498 L .50529 .6879 L 0 0 0 r
F
.51316 .68035 m .50214 .66182 L .50537 .66832 L 0 .753 .287 r
F
0 g
.49871 .66011 m
.50214 .66182 L
s
.50267 .6556 m
.5059 .66209 L
s
.49416 .7795 m .49147 .77823 L .48827 .78073 L 0 1 .443 r
F
.43437 .99614 m .42636 .99386 L .4186 .99394 L 0 1 .541 r
F
0 g
.43437 .99614 m
.43899 .99978 L
s
.43816 .99146 m .43437 .99614 L .44141 .99642 L 0 1 .541 r
F
.43816 .99146 m .42637 .99386 L .43437 .99614 L F
.50799 .78483 m .50519 .78391 L .50258 .78703 L 0 1 .437 r
F
0 g
.6791 .92975 m
.68059 .92768 L
s
.41714 .77059 m .40568 .77433 L .40481 .77618 L 0 1 .368 r
F
.41714 .77059 m .40968 .77216 L .40568 .77433 L F
.41714 .77059 m .41459 .77055 L .40968 .77216 L F
.42669 .76438 m .41459 .77055 L .41714 .77059 L 0 1 .313 r
F
0 g
.41714 .77059 m
.42186 .76869 L
s
.41626 .77244 m
.41714 .77059 L
s
.44153 .57397 m .44395 .56655 L .44318 .5612 L 0 1 .343 r
F
0 g
.44395 .56655 m
.44513 .56509 L
s
.50177 .67095 m .49047 .66343 L .4904 .66663 L 0 .828 .296 r
F
.50177 .67095 m .49391 .66304 L .49047 .66343 L F
0 g
.48713 .66015 m
.49047 .66343 L
s
.49047 .66343 m
.49238 .66321 L
s
.41496 .80377 m .40319 .79622 L .40307 .80282 L 0 1 .412 r
F
0 g
.39782 .79938 m
.40307 .80282 L
s
.50911 .5119 m .51687 .47989 L .51342 .48638 L 0 1 .143 r
F
0 g
.51412 .49532 m
.51671 .48462 L
s
.51454 .51193 m
.51633 .50236 L
s
.51515 .496 m
.51648 .49425 L
s
.51687 .47989 m
.52052 .4647 L
s
.5019 .66636 m .49391 .66304 L .49844 .66572 L 0 .842 .295 r
F
.50177 .67095 m .49844 .66572 L .49391 .66304 L 0 .828 .296 r
F
0 g
.49871 .66011 m
.50171 .66417 L
s
.49238 .66321 m
.49391 .66304 L
s
.49065 .65861 m
.49391 .66304 L
s
.51777 .97068 m .51068 .96917 L .51805 .97623 L 0 .364 .362 r
F
0 g
.5053 .96236 m
.51068 .96917 L
s
.50503 .9652 m
.51068 .96917 L
s
.63547 .54204 m
.63731 .56055 L
s
.63532 .54058 m
.63547 .54204 L
s
.63526 .53997 m
.63532 .54058 L
s
.63521 .53946 m
.63526 .53997 L
s
.63444 .53166 m
.63458 .53314 L
s
.63488 .53612 m
.63488 .53613 L
s
.63502 .53756 m
.63521 .53946 L
s
.63442 .53147 m
.63444 .53166 L
s
.63437 .53098 m
.63442 .53147 L
s
.63307 .51793 m
.6336 .52323 L
s
.51316 .68036 m .50782 .68411 L .50964 .68253 L 0 0 .042 r
F
.51316 .68036 m .50741 .68498 L .50782 .68411 L F
0 g
.50955 .68051 m
.51039 .68095 L
s
.50663 .68533 m
.50782 .68411 L
s
.37225 .78685 m .36039 .78203 L .35985 .78647 L 0 1 .509 r
F
.37225 .78685 m .36423 .78056 L .36039 .78203 L F
.37225 .78685 m .36932 .78263 L .36423 .78056 L F
.38153 .78265 m .36932 .78263 L .37225 .78685 L 0 1 .506 r
F
0 g
.37225 .78685 m
.37497 .78788 L
s
.37197 .78917 m
.37225 .78685 L
s
.76327 .90549 m .7594 .91935 L .76677 .91354 L 0 1 .517 r
F
.76327 .90549 m .75571 .91914 L .7594 .91935 L F
0 g
.75677 .92478 m
.7594 .91935 L
s
.43298 .83547 m .43126 .84471 L .43391 .84211 L 0 .922 .413 r
F
.44329 .85095 m .43391 .84211 L .43126 .84471 L 0 .867 .412 r
F
0 g
.43126 .84471 m
.43271 .85136 L
s
.42609 .84187 m
.43126 .84471 L
s
.50549 .88544 m
.5074 .88472 L
s
.5074 .88472 m
.50975 .8823 L
s
.80411 .70405 m .81386 .71658 L .81546 .70836 L 0 1 .502 r
F
0 g
.81386 .71658 m
.81602 .72403 L
s
.8093 .72132 m
.81386 .71658 L
s
.41496 .80377 m .41152 .81269 L .41483 .81037 L 0 1 .412 r
F
.4235 .81976 m .41483 .81037 L .41152 .81269 L 0 .972 .412 r
F
0 g
.41152 .81269 m
.41193 .81931 L
s
.40648 .80945 m
.41152 .81269 L
s
.52444 .67013 m .53223 .66116 L .52775 .66586 L 0 1 .344 r
F
.52419 .66774 m .52775 .66586 L .53223 .66116 L 0 1 .342 r
F
0 g
.53223 .66116 m
.53454 .65732 L
s
.53223 .66116 m
.53428 .66016 L
s
.44172 .60898 m .44326 .60221 L .44144 .59723 L 0 1 .35 r
F
0 g
.44326 .60221 m
.4474 .59738 L
s
.72968 .92361 m .73211 .93016 L .73873 .92366 L 0 1 .513 r
F
0 g
.7246 .93485 m
.73211 .93016 L
s
.72973 .93527 m
.73211 .93016 L
s
.45684 .65424 m .45726 .64866 L .45422 .64469 L 0 1 .338 r
F
0 g
.45726 .64866 m
.45796 .64788 L
s
.28604 .76932 m .27388 .75542 L .27261 .763 L 0 1 .472 r
F
.28604 .76932 m .27827 .75445 L .27388 .75542 L F
.28604 .76932 m .28349 .76041 L .27827 .75445 L F
.29679 .76647 m .28349 .76041 L .28604 .76932 L 0 1 .468 r
F
0 g
.28476 .77687 m
.28604 .76932 L
s
.28604 .76932 m
.29114 .77508 L
s
.43285 .77719 m .42174 .77664 L .42111 .78086 L 0 1 .482 r
F
.47507 .76836 m .47259 .77692 L .475 .77278 L 0 1 .451 r
F
.48112 .77246 m .475 .77278 L .47259 .77692 L 0 1 .449 r
F
0 g
.47259 .77692 m
.47294 .7814 L
s
.46876 .77854 m
.47259 .77692 L
s
.53236 .64747 m .53858 .63791 L .53482 .64483 L 0 0 .091 r
F
.53102 .65629 m .53858 .63791 L .54078 .63848 L 0 .029 .101 r
F
.53102 .65629 m .53482 .64483 L .53858 .63791 L F
0 g
.53858 .63791 m
.54076 .6309 L
s
.36561 .76639 m .36057 .77457 L .36441 .77305 L 0 1 .434 r
F
.36561 .76639 m .35588 .77005 L .36057 .77457 L F
0 g
.35998 .78127 m
.36057 .77457 L
s
.29344 .80846 m .27953 .80427 L .27924 .80775 L 0 1 .525 r
F
.29344 .80846 m .28379 .8033 L .27953 .80427 L F
.29344 .80846 m .28976 .8051 L .28379 .8033 L F
.30377 .80546 m .28976 .8051 L .29344 .80846 L 0 1 .52 r
F
0 g
.29313 .81192 m
.29344 .80846 L
s
.29344 .80846 m
.29925 .81 L
s
.45684 .65424 m .45422 .64469 L .44975 .64498 L 0 1 .338 r
F
0 g
.45422 .64469 m
.45806 .64018 L
s
.45422 .64469 m
.45726 .64866 L
s
.43625 .75779 m .43121 .76219 L .43496 .75948 L 0 1 .25 r
F
.43625 .75779 m .42669 .76438 L .43121 .76219 L F
0 g
.43039 .76396 m
.43121 .76219 L
s
.43496 .75948 m
.43953 .75702 L
s
.79406 .7956 m .8049 .79805 L .80049 .79527 L 0 .775 .458 r
F
.79406 .7956 m .80496 .80274 L .8049 .79805 L F
.70415 1.07726 m .71082 1.07869 L .71675 1.07726 L 0 .95 .341 r
F
.38158 .78035 m .37019 .77073 L .36944 .77735 L 0 1 .428 r
F
0 g
.36441 .77305 m
.36944 .77735 L
s
.51736 .65722 m .52155 .63166 L .51974 .63957 L 0 1 .339 r
F
0 g
.52148 .63197 m
.52155 .63166 L
s
.51925 .65935 m
.52 .65599 L
s
.51925 .65936 m
.52123 .65434 L
s
.52155 .63166 m
.52189 .62656 L
s
.52078 .62994 m
.52177 .62538 L
s
.53593 .66566 m .5394 .66975 L .54396 .66938 L 0 .973 .328 r
F
.53593 .66566 m .53596 .66815 L .5394 .66975 L F
.52456 .67264 m .53593 .66566 L .5325 .66621 L 0 1 .346 r
F
.52456 .67264 m .53596 .66815 L .53593 .66566 L F
0 g
.53251 .6662 m
.53458 .66352 L
s
.53593 .66566 m
.53931 .66196 L
s
.53251 .66621 m
.53593 .66566 L
s
.46198 .88855 m .45683 .88241 L .45155 .87978 L 0 .767 .42 r
F
.40752 .78198 m .39599 .77943 L .39538 .78366 L 0 1 .496 r
F
0 g
.52211 .58097 m
.52264 .57526 L
s
.52264 .57526 m
.52398 .56085 L
s
.52398 .56085 m
.52465 .55362 L
s
.47507 .76836 m .46613 .77214 L .46606 .77655 L 0 1 .451 r
F
0 g
.46194 .77778 m
.46606 .77655 L
s
.43816 .99146 m .44141 .99642 L .44281 .9945 L 0 1 .541 r
F
.45767 .99571 m .44281 .9945 L .44141 .99642 L 0 1 .542 r
F
0 g
.44141 .99642 m
.44658 .9991 L
s
.43437 .99614 m
.44141 .99642 L
s
.26399 .78953 m .25876 .7964 L .26301 .79536 L 0 1 .525 r
F
.26399 .78953 m .25326 .79194 L .25876 .7964 L F
0 g
.25869 .80227 m
.25876 .7964 L
s
.26301 .79536 m
.26917 .79948 L
s
.29411 .9622 m .27481 .9586 L .27793 .96216 L 0 1 .528 r
F
.29411 .9622 m .27841 .95738 L .27481 .9586 L F
.29411 .9622 m .28669 .95893 L .27841 .95738 L F
.3026 .95875 m .28669 .95893 L .29411 .9622 L 0 1 .525 r
F
0 g
.29411 .9622 m
.30214 .96356 L
s
.29411 .9622 m
.29719 .96575 L
s
.49859 .69738 m .49497 .70249 L .49181 .70643 L 0 0 0 r
F
.49859 .69738 m .49788 .69861 L .49497 .70249 L F
.50587 .68831 m .49859 .69738 L .50123 .69384 L 0 0 .008 r
F
.50587 .68831 m .49788 .69861 L .49859 .69738 L F
0 g
.49703 .69927 m
.49859 .69738 L
s
.49859 .69738 m
.49881 .69709 L
s
.51316 .68035 m .5059 .66209 L .51005 .67252 L 0 .753 .288 r
F
.51316 .68035 m .51005 .67252 L .5059 .66209 L 0 .755 .288 r
F
0 g
.50297 .65301 m
.5059 .66209 L
s
.5059 .66209 m
.5059 .66209 L
s
.45395 .92036 m .44022 .92654 L .4437 .92685 L 0 1 .42 r
F
0 g
.43752 .92946 m
.4437 .92685 L
s
.22113 .799 m .20723 .78664 L .20673 .79326 L 0 1 .527 r
F
.22113 .799 m .21161 .7859 L .20723 .78664 L F
.22113 .799 m .21758 .79121 L .21161 .7859 L F
.23183 .79667 m .21758 .79121 L .22113 .799 L F
0 g
.22061 .80556 m
.22113 .799 L
s
.22113 .799 m
.22696 .80406 L
s
.38844 .98793 m .37033 .98464 L .37438 .98864 L 0 1 .539 r
F
0 g
.36634 .98713 m
.37438 .98864 L
s
.40752 .78198 m .39982 .77745 L .39599 .77943 L 0 1 .496 r
F
.40752 .78198 m .40476 .77855 L .39982 .77745 L F
0 g
.40691 .78621 m
.40752 .78198 L
s
.41706 .77614 m .40476 .77854 L .40753 .78198 L 0 1 .491 r
F
0 g
.41613 .78035 m
.42111 .78086 L
s
.40753 .78198 m
.41239 .78276 L
s
.48145 .77674 m
.48146 .77686 L
s
.48751 .77619 m .48492 .77474 L .48147 .77695 L 0 1 .446 r
F
0 g
.48146 .77686 m
.48147 .77695 L
s
.22049 .81263 m .21582 .81824 L .22005 .81734 L 0 1 .539 r
F
.22049 .81263 m .20978 .81467 L .21582 .81824 L F
0 g
.21582 .81824 m
.21643 .82299 L
s
.22037 .81748 m
.22687 .8205 L
s
.22005 .81734 m
.22037 .81748 L
s
.46762 .66616 m .46447 .6578 L .45993 .65817 L 0 1 .328 r
F
.46762 .66616 m .46776 .66123 L .46447 .6578 L F
0 g
.46447 .6578 m
.46813 .65376 L
s
.51931 .63326 m .52054 .61725 L .51945 .6267 L 0 1 .328 r
F
0 g
.52033 .63201 m
.52078 .62994 L
s
.52023 .63249 m
.52033 .63201 L
s
.52025 .63734 m
.52148 .63197 L
s
.52054 .61725 m
.52071 .61642 L
s
.52043 .61467 m
.52054 .61725 L
s
.47951 .99298 m .46433 .99536 L .46964 .99741 L 0 1 .542 r
F
0 g
.46282 .9984 m
.46964 .99741 L
s
.45434 .86622 m .44441 .86698 L .4493 .87317 L 0 .805 .411 r
F
.45434 .86622 m .44246 .86031 L .44441 .86698 L F
0 g
.43903 .86425 m
.44441 .86698 L
s
.72968 .92361 m .72334 .92983 L .72117 .93464 L 0 1 .513 r
F
0 g
.71402 .93806 m
.72117 .93464 L
s
.32007 .76005 m .31467 .7683 L .31866 .76712 L 0 1 .457 r
F
.32007 .76005 m .31 .76287 L .31467 .7683 L F
0 g
.31399 .77539 m
.31467 .7683 L
s
.31866 .76712 m
.32384 .7723 L
s
.76659 .94618 m .77883 .94537 L .7751 .94408 L 0 1 .538 r
F
.75746 .94269 m .76659 .94618 L .76951 .94212 L 0 1 .537 r
F
.50587 .68831 m .50123 .69384 L .50403 .69034 L 0 0 .008 r
F
.50681 .68626 m .50403 .69034 L .50123 .69384 L 0 0 0 r
F
0 g
.49971 .69547 m
.50123 .69384 L
s
.49881 .69709 m
.50123 .69384 L
s
.50529 .6879 m
.50736 .68506 L
s
.69649 .93811 m .69799 .94306 L .70486 .93807 L 0 1 .482 r
F
0 g
.69051 .94666 m
.69799 .94306 L
s
.69709 .94436 m
.69799 .94306 L
s
.51503 .78679 m .51221 .78606 L .50995 .78949 L 0 1 .433 r
F
.47951 .99298 m .48421 .99714 L .48481 .99503 L 0 1 .542 r
F
.49886 .99273 m .48481 .99503 L .48421 .99714 L 0 1 .539 r
F
0 g
.48421 .99714 m
.48991 .99847 L
s
.47771 .99815 m
.48421 .99714 L
s
.39128 .77575 m .38644 .78423 L .39026 .78234 L 0 1 .42 r
F
.39124 .77809 m .38644 .78423 L .39026 .78234 L 0 1 .503 r
F
.39119 .78042 m .38644 .78423 L .39026 .78234 L 0 1 .409 r
F
.39128 .77575 m .38158 .78035 L .38644 .78423 L 0 1 .42 r
F
.39124 .77809 m .38153 .78265 L .38644 .78423 L 0 1 .503 r
F
.39119 .78042 m .38148 .78496 L .38644 .78423 L 0 1 .409 r
F
0 g
.39031 .78233 m
.39038 .78232 L
s
.39038 .78232 m
.39543 .78133 L
s
.38632 .78425 m
.38638 .78424 L
s
.39829 .79276 m .39026 .78234 L .38644 .78423 L 0 1 .42 r
F
0 g
.38638 .78424 m
.38644 .78423 L
s
.38643 .78431 m
.38644 .78423 L
s
.38643 .78433 m
.38644 .78423 L
s
.38606 .78626 m
.38644 .78423 L
s
.51316 .68035 m .51925 .65937 L .51577 .67135 L 0 .72 .283 r
F
.51316 .68035 m .51577 .67135 L .51925 .65937 L 0 .726 .282 r
F
0 g
.51925 .65937 m
.51925 .65935 L
s
.51925 .65937 m
.51925 .65936 L
s
.54403 .66944 m
.54516 .67043 L
s
.54516 .67043 m
.54562 .67083 L
s
.53593 .67188 m .54396 .66938 L .5394 .66975 L 0 .945 .33 r
F
0 g
.54396 .66938 m
.54403 .66944 L
s
.54396 .66938 m
.54415 .66917 L
s
.47901 .66544 m .46776 .66123 L .46762 .66616 L 0 .973 .317 r
F
0 g
.46776 .66123 m
.46822 .66077 L
s
.46447 .6578 m
.46776 .66123 L
s
.44699 .6406 m .44777 .63446 L .4451 .63007 L 0 1 .347 r
F
0 g
.44777 .63446 m
.44877 .63329 L
s
.51316 .68036 m .50198 .66454 L .5019 .66636 L 0 .749 .286 r
F
.51316 .68036 m .50537 .66832 L .50198 .66454 L F
0 g
.50227 .66002 m
.5056 .66517 L
s
.50171 .66417 m
.50198 .66454 L
s
.4752 .90387 m .46324 .89784 L .46645 .90448 L 0 .685 .415 r
F
0 g
.46645 .90448 m
.46645 .90448 L
s
.52277 .66504 m .53236 .64747 L .52918 .6548 L 0 0 .072 r
F
0 g
.53225 .64772 m
.53236 .64747 L
s
.52208 .66021 m .52237 .66078 L .5254 .65408 L 0 1 .332 r
F
0 g
.52538 .65415 m
.52538 .65415 L
s
.52538 .65415 m
.5254 .65408 L
s
.59589 .40392 m .60891 .40638 L .61135 .41427 L 0 .416 .099 r
F
0 g
.60891 .40638 m
.61162 .40262 L
s
.6023 .40196 m
.60891 .40638 L
s
.51316 .68036 m .5104 .68095 L .51198 .68061 L 0 0 .037 r
F
.51316 .68036 m .51198 .68061 L .5104 .68095 L 0 0 .032 r
F
0 g
.50889 .68188 m
.5104 .68095 L
s
.51039 .68095 m
.5104 .68095 L
s
.51844 .6572 m .5216 .63872 L .51962 .64924 L 0 1 .335 r
F
.51736 .65722 m .51962 .64924 L .5216 .63872 L 0 1 .339 r
F
0 g
.5216 .63872 m
.52166 .63847 L
s
.5216 .63872 m
.52166 .63814 L
s
.47901 .66544 m .47094 .66947 L .47551 .66897 L 0 .973 .317 r
F
.47901 .66544 m .46762 .66616 L .47094 .66947 L F
.4904 .66663 m .47901 .66544 L .48236 .66872 L 0 .904 .306 r
F
0 g
.4186 .99394 m
.42636 .99386 L
s
.3459 .7831 m .34118 .78911 L .34502 .78773 L 0 1 .516 r
F
.3459 .7831 m .33618 .78637 L .34118 .78911 L F
0 g
.34096 .79379 m
.34118 .78911 L
s
.34502 .78773 m
.3504 .79018 L
s
.51316 .68036 m .50892 .68405 L .50741 .68498 L 0 0 .042 r
F
0 g
.50736 .68506 m
.50741 .68498 L
s
.3262 .79876 m .32181 .80277 L .32564 .80151 L 0 1 .503 r
F
.3262 .79876 m .31649 .8017 L .32181 .80277 L F
0 g
.32181 .80277 m
.32198 .8056 L
s
.32564 .80151 m
.33139 .80225 L
s
.49731 .7666 m .49416 .7795 L .49702 .77654 L 0 1 .433 r
F
.49731 .7666 m .49147 .77823 L .49416 .7795 L F
0 g
.49416 .7795 m
.49534 .7841 L
s
.52129 .65899 m .52162 .65944 L .52446 .65213 L 0 1 .331 r
F
0 g
.52369 .65413 m
.52446 .65213 L
s
.52402 .65363 m
.52446 .65213 L
s
.5225 .65878 m
.52255 .65861 L
s
.52242 .65905 m
.5225 .65878 L
s
.50303 .76889 m .49825 .78129 L .50101 .78239 L 0 1 .43 r
F
.50303 .76889 m .49702 .77654 L .49825 .78129 L F
0 g
.49534 .7841 m
.49825 .78129 L
s
.52456 .67264 m .53256 .67135 L .53596 .66815 L 0 1 .346 r
F
0 g
.53586 .66824 m
.53596 .66815 L
s
.53339 .67057 m
.53586 .66824 L
s
.53596 .66815 m
.5394 .66975 L
s
.51316 .68036 m .52355 .66096 L .52335 .66208 L 0 0 .045 r
F
.51316 .68036 m .52055 .66618 L .52355 .66096 L F
.52277 .66172 m .52302 .6624 L .52621 .65649 L 0 1 .334 r
F
.52277 .66504 m .52302 .66383 L .52621 .65649 L 0 0 .072 r
F
0 g
.5262 .6565 m
.52621 .65649 L
s
.52605 .65685 m
.5262 .6565 L
s
.52602 .65692 m
.52605 .65685 L
s
.52597 .65702 m
.52602 .65692 L
s
.52587 .65727 m
.52597 .65702 L
s
.52573 .65758 m
.52587 .65727 L
s
.5257 .65766 m
.52573 .65758 L
s
.52285 .65971 m
.52289 .65963 L
s
.52267 .66011 m
.52285 .65971 L
s
.52289 .65963 m
.52298 .65943 L
s
.52614 .65662 m
.52621 .65649 L
s
.52614 .65662 m
.52614 .65662 L
s
.52608 .65672 m
.52614 .65662 L
s
.52603 .65683 m
.52608 .65672 L
s
.52595 .65699 m
.52603 .65683 L
s
.52587 .65715 m
.52595 .65699 L
s
.52584 .6572 m
.52587 .65715 L
s
.52582 .65724 m
.52584 .6572 L
s
.5257 .65749 m
.52582 .65724 L
s
.52569 .65749 m
.5257 .65749 L
s
.52561 .65766 m
.52569 .65749 L
s
.5256 .65767 m
.52561 .65766 L
s
.52556 .65776 m
.5256 .65767 L
s
.52555 .65778 m
.52556 .65776 L
s
.52553 .6578 m
.52555 .65778 L
s
.52547 .65793 m
.52553 .6578 L
s
.52542 .65803 m
.52547 .65793 L
s
.52534 .65818 m
.52542 .65803 L
s
.52506 .65873 m
.52534 .65818 L
s
.52488 .65909 m
.52506 .65873 L
s
.52549 .65782 m
.52618 .65653 L
s
.52618 .65653 m
.52621 .65649 L
s
.5253 .65816 m
.52548 .65784 L
s
.52548 .65784 m
.52549 .65782 L
s
.44799 .77635 m .44085 .77419 L .43739 .77713 L 0 1 .473 r
F
.44799 .77635 m .44539 .77385 L .44085 .77419 L F
.45609 .76806 m .44799 .77635 L .45229 .77568 L 0 1 .465 r
F
.45609 .76806 m .44539 .77385 L .44799 .77635 L F
0 g
.44758 .7806 m
.44799 .77635 L
s
.44799 .77635 m
.45138 .77582 L
s
.25786 .95944 m .25688 .96473 L .26046 .9635 L 0 1 .531 r
F
0 g
.26046 .9635 m
.26919 .9654 L
s
.25786 .95944 m .24871 .96233 L .25688 .96473 L 0 1 .531 r
F
0 g
.25688 .96473 m
.26046 .96865 L
s
.46998 .46941 m .46324 .47998 L .46495 .47799 L 0 0 0 r
F
.46998 .46941 m .46603 .47478 L .46324 .47998 L F
0 g
.46265 .48318 m
.46539 .4787 L
s
.46539 .4787 m
.46757 .47514 L
s
.46998 .46941 m .47146 .46587 L .46603 .47478 L 0 0 0 r
F
.46998 .46941 m .47648 .45731 L .47146 .46587 L F
0 g
.76 .67269 m
.76002 .67272 L
s
.45609 .76806 m .45229 .77568 L .45543 .77229 L 0 1 .465 r
F
.46216 .77347 m .45543 .77229 L .45229 .77568 L 0 1 .462 r
F
0 g
.45207 .77999 m
.45229 .77568 L
s
.45138 .77582 m
.45229 .77568 L
s
.38158 .78035 m .37403 .76916 L .37019 .77073 L 0 1 .428 r
F
.38158 .78035 m .37892 .77328 L .37403 .76916 L F
0 g
.38132 .78265 m
.38158 .78035 L
s
.39128 .77575 m .37892 .77328 L .38158 .78035 L 0 1 .42 r
F
0 g
.38158 .78035 m
.38337 .78179 L
s
.49731 .7666 m .49063 .77353 L .49147 .77823 L 0 1 .433 r
F
0 g
.49709 .7768 m
.49825 .78129 L
s
.48827 .78073 m
.49147 .77823 L
s
.72995 .93161 m .72477 .93987 L .73241 .9387 L 0 1 .531 r
F
.72995 .93161 m .72129 .93815 L .72477 .93987 L F
0 g
.72168 .94352 m
.72477 .93987 L
s
.4904 .66663 m .48236 .66872 L .48692 .6689 L 0 .904 .306 r
F
.50177 .67095 m .4904 .66663 L .49376 .67002 L 0 .828 .296 r
F
.50303 .76889 m .50101 .78239 L .50359 .77912 L 0 1 .43 r
F
0 g
.50101 .78239 m
.50258 .78703 L
s
.39829 .79276 m .39534 .786 L .39026 .78234 L 0 1 .42 r
F
0 g
.3904 .78238 m
.39053 .78241 L
s
.39053 .78241 m
.39538 .78366 L
s
.39026 .78234 m
.3904 .78238 L
s
.39026 .78234 m
.39031 .78233 L
s
.40743 .7875 m .39829 .79276 L .40319 .79622 L 0 1 .411 r
F
.40743 .7875 m .39534 .786 L .39829 .79276 L F
0 g
.39782 .79938 m
.39829 .79276 L
s
.47972 .45221 m .48529 .4429 L .48886 .43845 L 0 0 0 r
F
0 g
.48529 .4429 m
.48816 .43725 L
s
.44171 .77001 m .43739 .77713 L .44085 .77419 L 0 1 .475 r
F
.44171 .77001 m .43285 .77719 L .43739 .77713 L F
0 g
.43699 .78138 m
.43739 .77713 L
s
.65023 .47984 m
.65166 .4842 L
s
.64562 .46576 m
.64884 .47561 L
s
.64884 .47561 m
.65023 .47984 L
s
.73915 .93542 m .74129 .94266 L .74832 .93911 L 0 1 .533 r
F
0 g
.73344 .94407 m
.74129 .94266 L
s
.73864 .94653 m
.74129 .94266 L
s
.53793 .42988 m .5502 .41447 L .54621 .42511 L 0 0 .08 r
F
0 g
.5502 .41447 m
.55566 .40921 L
s
.53608 .67178 m
.5394 .66975 L
s
.69746 1.07593 m .69387 1.07839 L .70415 1.07726 L 0 .864 .315 r
F
0 g
.68436 1.07868 m
.69387 1.07839 L
s
.68854 1.07968 m
.69387 1.07839 L
s
.51833 .98899 m .51053 .99095 L .50455 .99407 L 0 1 .526 r
F
.50177 .67095 m .50181 .66911 L .49844 .66572 L 0 .828 .296 r
F
.52042 .65808 m .52078 .65841 L .52341 .65067 L 0 1 .331 r
F
0 g
.52248 .6534 m
.52341 .65067 L
s
.52144 .6584 m
.52162 .65769 L
s
.52255 .65861 m
.52292 .65737 L
s
.52292 .65737 m
.52302 .65702 L
s
.52302 .65702 m
.52319 .65646 L
s
.52258 .65696 m
.52317 .65545 L
s
.52183 .65889 m
.52217 .65804 L
s
.52217 .65804 m
.52225 .65782 L
s
.52225 .65782 m
.52243 .65737 L
s
.52243 .65737 m
.52258 .65696 L
s
.52456 .67264 m .5325 .66621 L .52796 .66944 L 0 1 .346 r
F
.52444 .67013 m .52796 .66944 L .5325 .66621 L 0 1 .344 r
F
0 g
.5325 .66621 m
.53251 .6662 L
s
.5325 .66621 m
.53251 .66621 L
s
.49685 .70039 m .49181 .70643 L .49497 .70249 L 0 0 0 r
F
.49685 .70039 m .48871 .71037 L .49181 .70643 L F
0 g
.49025 .70831 m
.49181 .70643 L
s
.44172 .60898 m .44144 .59723 L .43746 .59735 L 0 1 .35 r
F
0 g
.44144 .59723 m
.4458 .59189 L
s
.44144 .59723 m
.44326 .60221 L
s
.45684 .65424 m .44856 .65968 L .45311 .65897 L 0 1 .338 r
F
.45684 .65424 m .44552 .65571 L .44856 .65968 L F
.45684 .65424 m .44602 .6497 L .44552 .65571 L F
.45684 .65424 m .44975 .64498 L .44602 .6497 L F
0 g
.52255 .66271 m
.5229 .66209 L
s
.52199 .66319 m
.52253 .66206 L
s
.45962 .74087 m .44997 .74797 L .44869 .74967 L 0 .945 .207 r
F
.45962 .74087 m .45373 .74489 L .44997 .74797 L F
.45962 .74087 m .45787 .74185 L .45373 .74489 L F
.46852 .73236 m .45787 .74185 L .45962 .74087 L 0 .873 .17 r
F
0 g
.45962 .74087 m
.46353 .73755 L
s
.45833 .74258 m
.45962 .74087 L
s
.49176 .76389 m .48751 .77619 L .49063 .77353 L 0 1 .436 r
F
.49176 .76389 m .48492 .77474 L .48751 .77619 L F
0 g
.48751 .77619 m
.48827 .78073 L
s
.50885 .77074 m .50519 .78391 L .50799 .78483 L 0 1 .427 r
F
.50885 .77074 m .50359 .77912 L .50519 .78391 L F
0 g
.50258 .78703 m
.50519 .78391 L
s
.44172 .60898 m .43322 .61461 L .43741 .6143 L 0 1 .35 r
F
.44172 .60898 m .43139 .60963 L .43322 .61461 L F
0 g
.44096 .6174 m
.4437 .61409 L
s
.44172 .60898 m .43315 .60266 L .43139 .60963 L 0 1 .35 r
F
.44172 .60898 m .43746 .59735 L .43315 .60266 L F
0 g
.44172 .60898 m
.4437 .61409 L
s
.76847 .76562 m .76724 .77071 L .77168 .77441 L 0 .376 .306 r
F
.76847 .76562 m .76586 .76694 L .76724 .77071 L F
0 g
.76266 .77015 m
.76724 .77071 L
s
.46198 .88855 m .46324 .89784 L .46472 .89516 L 0 .767 .42 r
F
.4752 .90387 m .46472 .89516 L .46324 .89784 L 0 .685 .415 r
F
0 g
.46324 .89784 m
.46645 .90448 L
s
.45796 .8952 m
.46324 .89784 L
s
.35588 .77005 m .34465 .75909 L .34358 .76586 L 0 1 .441 r
F
.35588 .77005 m .34865 .7578 L .34465 .75909 L F
.35588 .77005 m .35346 .7625 L .34865 .7578 L F
.36561 .76639 m .35346 .7625 L .35588 .77005 L 0 1 .434 r
F
0 g
.35588 .77005 m
.36057 .77457 L
s
.35481 .77681 m
.35588 .77005 L
s
.40743 .7875 m .40319 .79622 L .40677 .79406 L 0 1 .411 r
F
.41496 .80377 m .40677 .79406 L .40319 .79622 L 0 1 .412 r
F
0 g
.40307 .80282 m
.40319 .79622 L
s
.39829 .79276 m
.40319 .79622 L
s
.51806 .98504 m .51833 .98899 L .524 .98644 L 0 1 .524 r
F
.51806 .98504 m .51053 .99095 L .51833 .98899 L F
0 g
.51833 .98899 m
.52435 .98902 L
s
.44153 .57397 m .44318 .5612 L .43974 .56149 L 0 1 .343 r
F
0 g
.44318 .5612 m
.44395 .56655 L
s
.46762 .66616 m .45993 .65817 L .45639 .66254 L 0 1 .328 r
F
0 g
.45707 .66169 m
.45993 .65817 L
s
.45684 .65424 m
.45993 .65817 L
s
.72389 .57206 m .73556 .55757 L .7373 .56984 L 0 .425 .1 r
F
0 g
.72601 .55849 m
.731 .55233 L
s
.72334 .5423 m
.726 .55849 L
s
.73556 .55757 m
.74004 .5557 L
s
.44699 .6406 m .4451 .63007 L .44074 .63035 L 0 1 .347 r
F
0 g
.4451 .63007 m
.44916 .62514 L
s
.4451 .63007 m
.44777 .63446 L
s
.50122 .94821 m .49475 .9418 L .48945 .93867 L 0 .507 .402 r
F
.78139 .69423 m .7904 .69198 L .78582 .68998 L 0 1 .491 r
F
.78139 .69423 m .79275 .69936 L .7904 .69198 L F
.45259 .51042 m .45671 .5017 L .45814 .49626 L 0 1 .204 r
F
0 g
.45671 .5017 m
.45911 .498 L
s
.29679 .76647 m .28487 .75298 L .28349 .76041 L 0 1 .468 r
F
.29679 .76647 m .28926 .75199 L .28487 .75298 L F
.29679 .76647 m .29437 .75777 L .28926 .75199 L F
0 g
.2954 .77388 m
.29679 .76647 L
s
.31 .76287 m .29438 .75777 L .29679 .76647 L 0 1 .462 r
F
0 g
.29679 .76647 m
.30252 .77184 L
s
.43285 .77719 m .42549 .7741 L .42174 .77664 L 0 1 .482 r
F
.43285 .77719 m .43025 .77434 L .42549 .7741 L F
.44171 .77001 m .43025 .77434 L .43285 .77719 L 0 1 .475 r
F
0 g
.4322 .78141 m
.43285 .77719 L
s
.43285 .77719 m
.43739 .77713 L
s
.51624 .65753 m .52022 .63254 L .51931 .63326 L 0 1 .343 r
F
.51624 .65753 m .51974 .63957 L .52022 .63254 L F
0 g
.52022 .63254 m
.52023 .63249 L
s
.52005 .63498 m
.52022 .63254 L
s
.51982 .63843 m
.52005 .63498 L
s
.43298 .83547 m .42908 .82922 L .42391 .82638 L 0 .922 .413 r
F
0 g
.42391 .82638 m
.42908 .82922 L
s
.68771 .92442 m .68963 .93188 L .69624 .92952 L 0 1 .527 r
F
0 g
.68229 .93198 m
.68963 .93188 L
s
.68707 .93525 m
.68963 .93188 L
s
.69746 1.07593 m .68754 1.07676 L .68194 1.07794 L 0 .864 .315 r
F
0 g
.67221 1.07772 m
.68194 1.07794 L
s
.51316 .68036 m .5019 .66636 L .50523 .67151 L 0 .749 .286 r
F
0 g
.49844 .66572 m
.5019 .66636 L
s
.50198 .66454 m
.50537 .66831 L
s
.3722 .78912 m .3602 .78952 L .35973 .79168 L 0 1 .463 r
F
.3722 .78912 m .36405 .78809 L .3602 .78952 L F
.3722 .78912 m .3692 .78793 L .36405 .78809 L F
.38148 .78496 m .3692 .78793 L .3722 .78912 L 0 1 .44 r
F
0 g
.37171 .79128 m
.3722 .78912 L
s
.3722 .78912 m
.37709 .78871 L
s
.44329 .85095 m .44246 .86031 L .44474 .8576 L 0 .867 .412 r
F
.45434 .86622 m .44474 .8576 L .44246 .86031 L 0 .805 .411 r
F
0 g
.44246 .86031 m
.44441 .86698 L
s
.4373 .85763 m
.44246 .86031 L
s
.62015 .44971 m .62117 .46224 L .61819 .44562 L 0 .566 .019 r
F
0 g
.61833 .44591 m
.61855 .44637 L
s
.61819 .44562 m
.61833 .44591 L
s
.61758 .44368 m
.61819 .44562 L
s
.62015 .44971 m .6279 .49204 L .62117 .46224 L 0 .566 .019 r
F
.62015 .44971 m .6339 .51514 L .6279 .49204 L F
0 g
.63242 .51139 m
.63307 .51793 L
s
.62015 .44971 m .62574 .47178 L .63247 .50156 L 0 .566 .019 r
F
0 g
.61687 .43319 m
.62015 .44971 L
s
.61855 .44637 m
.62015 .44971 L
s
.49176 .76389 m .48447 .77011 L .48492 .77474 L 0 1 .436 r
F
0 g
.48147 .77695 m
.48492 .77474 L
s
.49065 .77361 m
.49147 .77823 L
s
.45434 .86622 m .4493 .87317 L .45439 .87571 L 0 .805 .411 r
F
0 g
.4493 .87317 m
.45155 .87978 L
s
.44153 .57397 m .43318 .58011 L .43692 .57978 L 0 1 .343 r
F
.44153 .57397 m .43241 .57476 L .43318 .58011 L F
0 g
.43985 .58283 m
.44251 .57957 L
s
.44153 .57397 m .43512 .56729 L .43241 .57476 L 0 1 .343 r
F
.44153 .57397 m .43974 .56149 L .43512 .56729 L F
0 g
.44153 .57397 m
.44251 .57957 L
s
.50885 .77074 m .50799 .78483 L .51025 .78124 L 0 1 .427 r
F
0 g
.50799 .78483 m
.50995 .78949 L
s
.51316 .68035 m .51316 .68035 L .51328 .66368 L 0 .691 .281 r
F
.51316 .68035 m .51316 .68035 L .51292 .6637 L 0 .688 .281 r
F
.81546 .70836 m .82511 .72079 L .8268 .71234 L 0 1 .506 r
F
0 g
.82049 .72578 m
.82511 .72079 L
s
.51316 .68035 m .5056 .66517 L .50992 .67384 L 0 .755 .288 r
F
.51316 .68035 m .50992 .67384 L .5056 .66517 L 0 .753 .287 r
F
0 g
.5056 .66517 m
.5056 .66517 L
s
.5025 .65736 m
.5056 .66517 L
s
.52383 .66552 m .52399 .66639 L .52739 .66245 L 0 1 .339 r
F
.52336 .66493 m .53111 .6621 L .53395 .65367 L 0 .641 .273 r
F
0 g
.52395 .66528 m
.52429 .66459 L
s
.52317 .65545 m
.52369 .65413 L
s
.52319 .65646 m
.5236 .65506 L
s
.52298 .65943 m
.5254 .65408 L
s
.52246 .65438 m
.52341 .65067 L
s
.5252 .65835 m
.5253 .65816 L
s
.52496 .6588 m
.5252 .65835 L
s
.52483 .65903 m
.52496 .6588 L
s
.52438 .65988 m
.52483 .65903 L
s
.52341 .66167 m
.52438 .65988 L
s
.52338 .66173 m
.52341 .66167 L
s
.52333 .66183 m
.52338 .66173 L
s
.52335 .66208 m
.52352 .66176 L
s
.52352 .66176 m
.52352 .66176 L
s
.52352 .66176 m
.52352 .66175 L
s
.52352 .66175 m
.52409 .66063 L
s
.52409 .66063 m
.52409 .66063 L
s
.52409 .66063 m
.52409 .66063 L
s
.52409 .66063 m
.52428 .66026 L
s
.52428 .66026 m
.52428 .66025 L
s
.52428 .66025 m
.52467 .6595 L
s
.52467 .6595 m
.52488 .65909 L
s
.5236 .6593 m
.5236 .6593 L
s
.5236 .6593 m
.5236 .6593 L
s
.5236 .6593 m
.52451 .65667 L
s
.52451 .65666 m
.52538 .65415 L
s
.52451 .65667 m
.52451 .65666 L
s
.52551 .6581 m
.52552 .65806 L
s
.52552 .65806 m
.5257 .65766 L
s
.52413 .66127 m
.52508 .65909 L
s
.52508 .65909 m
.5251 .65903 L
s
.5251 .65903 m
.52532 .65853 L
s
.52532 .65853 m
.52536 .65844 L
s
.52536 .65844 m
.52551 .6581 L
s
.52413 .66127 m
.52413 .66127 L
s
.52413 .66127 m
.52413 .66127 L
s
.52339 .66298 m
.52413 .66127 L
s
.52339 .66298 m
.52339 .66298 L
s
.52338 .66298 m
.52339 .66298 L
s
.5236 .65506 m
.52402 .65363 L
s
.51946 .65748 m .51985 .65768 L .52224 .64971 L 0 1 .333 r
F
0 g
.52162 .65769 m
.52196 .65637 L
s
.52196 .65637 m
.52198 .65629 L
s
.52198 .65629 m
.52206 .65595 L
s
.52206 .65595 m
.52246 .65438 L
s
.52097 .65784 m
.52118 .65722 L
s
.52118 .65722 m
.52122 .65711 L
s
.52122 .65711 m
.52122 .6571 L
s
.52122 .6571 m
.52133 .65677 L
s
.52133 .65677 m
.52145 .65642 L
s
.52145 .65642 m
.52197 .65488 L
s
.52197 .65488 m
.52248 .6534 L
s
.4235 .81976 m .41996 .8134 L .41483 .81037 L 0 .972 .412 r
F
0 g
.41483 .81037 m
.41996 .8134 L
s
.4235 .81976 m
.42391 .82638 L
s
.52412 .66624 m
.52416 .66619 L
s
.5239 .66538 m
.52395 .66528 L
s
.51316 .68035 m .51316 .68035 L .51363 .66387 L 0 .696 .28 r
F
.80496 .80274 m .81594 .80462 L .81153 .80206 L 0 .834 .469 r
F
.80496 .80274 m .81585 .80932 L .81594 .80462 L F
.51316 .68035 m .51316 .68035 L .51257 .66393 L 0 .689 .283 r
F
.31111 .95531 m .31041 .95993 L .31372 .95848 L 0 1 .52 r
F
0 g
.31372 .95848 m
.3219 .95916 L
s
.31111 .95531 m .3026 .95875 L .31041 .95993 L 0 1 .52 r
F
0 g
.31041 .95993 m
.31387 .96296 L
s
.46216 .77347 m .45966 .77134 L .45543 .77229 L 0 1 .462 r
F
.46941 .76391 m .46216 .77347 L .46613 .77214 L 0 1 .453 r
F
.46941 .76391 m .45966 .77134 L .46216 .77347 L F
0 g
.46194 .77778 m
.46216 .77347 L
s
.46216 .77347 m
.46553 .77234 L
s
.48695 .92619 m .48513 .93229 L .49035 .93516 L 0 .614 .415 r
F
0 g
.48513 .93229 m
.48945 .93867 L
s
.49039 .67458 m .48236 .66872 L .47896 .67168 L 0 .881 .307 r
F
.49039 .67458 m .48692 .6689 L .48236 .66872 L F
0 g
.47901 .66544 m
.48236 .66872 L
s
.47921 .67146 m
.48236 .66872 L
s
.48112 .77246 m .47865 .77087 L .475 .77278 L 0 1 .449 r
F
0 g
.475 .77278 m
.47501 .77208 L
s
.39026 .78234 m
.39033 .78239 L
s
.49039 .67458 m .49036 .67141 L .48692 .6689 L 0 .881 .307 r
F
0 g
.48692 .6689 m
.4904 .66663 L
s
.32648 .78956 m .31423 .78224 L .31361 .78718 L 0 1 .519 r
F
.32648 .78956 m .31822 .78116 L .31423 .78224 L F
.32648 .78956 m .32348 .7843 L .31822 .78116 L F
.33618 .78637 m .32348 .7843 L .32648 .78956 L 0 1 .518 r
F
0 g
.32585 .79448 m
.32648 .78956 L
s
.32648 .78956 m
.33159 .79249 L
s
.48871 .71037 m .48091 .71946 L .47928 .72137 L 0 0 0 r
F
.53593 .67188 m .5392 .67728 L .54373 .67874 L 0 .945 .33 r
F
.53593 .67188 m .53586 .67434 L .5392 .67728 L F
.52455 .67522 m .53593 .67188 L .53256 .67135 L 0 1 .347 r
F
.52455 .67522 m .53586 .67434 L .53593 .67188 L F
0 g
.53593 .67188 m
.53608 .67178 L
s
.44699 .6406 m .43856 .64623 L .44304 .64564 L 0 1 .347 r
F
0 g
.44699 .64848 m
.44975 .64498 L
s
.44699 .6406 m .43588 .64183 L .43856 .64623 L 0 1 .347 r
F
.44699 .6406 m .43679 .63539 L .43588 .64183 L F
.44699 .6406 m .44074 .63035 L .43679 .63539 L F
0 g
.44699 .6406 m
.44975 .64498 L
s
.28527 .97619 m .2656 .96777 L .26888 .97329 L 0 1 .537 r
F
.28527 .97619 m .26919 .96659 L .2656 .96777 L F
.28527 .97619 m .27763 .97021 L .26919 .96659 L F
.29375 .97294 m .27763 .97021 L .28527 .97619 L F
0 g
.28527 .97619 m
.29346 .97965 L
s
.28527 .97619 m
.28852 .98169 L
s
.51316 .68035 m .51316 .68035 L .51222 .66433 L 0 .692 .284 r
F
.51316 .68035 m .51316 .68035 L .51398 .66427 L 0 .702 .28 r
F
.48871 .71037 m .48439 .71558 L .48091 .71946 L 0 0 0 r
F
.48871 .71037 m .48774 .71168 L .48439 .71558 L F
.49685 .70039 m .48774 .71168 L .48871 .71037 L F
0 g
.48871 .71037 m
.49181 .70643 L
s
.40743 .7875 m .39599 .77943 L .39534 .786 L 0 1 .411 r
F
0 g
.39033 .78239 m
.39534 .786 L
s
.39538 .78366 m
.39598 .77955 L
s
.53102 .65629 m .53158 .6527 L .53482 .64483 L 0 .029 .101 r
F
0 g
.53367 .64763 m
.53482 .64483 L
s
.53236 .64747 m
.53482 .64483 L
s
.53077 .65113 m
.53225 .64772 L
s
.49731 .7666 m .49702 .77654 L .49815 .7713 L 0 1 .433 r
F
.50303 .76889 m .49815 .7713 L .49702 .77654 L 0 1 .43 r
F
0 g
.49416 .7795 m
.49702 .77654 L
s
.49702 .77654 m
.49709 .7768 L
s
.2672 .95223 m .26607 .95556 L .26966 .95428 L 0 1 .384 r
F
0 g
.26966 .95428 m
.27823 .95412 L
s
.2672 .95223 m .25803 .95519 L .26607 .95556 L 0 1 .384 r
F
0 g
.26607 .95556 m
.26949 .95752 L
s
.46762 .66616 m .45951 .67144 L .46408 .67053 L 0 1 .328 r
F
.46762 .66616 m .45621 .66801 L .45951 .67144 L F
.46762 .66616 m .45639 .66254 L .45621 .66801 L F
.33016 .75716 m .32466 .76532 L .32865 .7641 L 0 1 .452 r
F
.33016 .75716 m .32007 .76005 L .32466 .76532 L F
0 g
.32384 .7723 m
.32466 .76532 L
s
.32865 .7641 m
.33371 .76913 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.50587 .68831 m .49971 .69658 L .49788 .69861 L 0 0 .008 r
F
0 g
.49497 .70249 m
.49788 .69861 L
s
.51514 .78701 m
.51552 .78778 L
s
.51756 .79104 m
.51756 .79104 L
s
.51827 .78964 m
.51827 .78964 L
s
.43816 .99146 m .4217 .99082 L .42637 .99386 L 0 1 .541 r
F
.50122 .94821 m .50045 .95391 L .50576 .95706 L 0 .507 .402 r
F
.479 .67582 m .47551 .66897 L .47094 .66947 L 0 .945 .318 r
F
.479 .67582 m .47896 .67168 L .47551 .66897 L F
0 g
.47551 .66897 m
.47901 .66544 L
s
.47743 .72328 m .47222 .72877 L .47569 .72511 L 0 0 0 r
F
.47743 .72328 m .46852 .73236 L .47222 .72877 L F
0 g
.47084 .73057 m
.47222 .72877 L
s
.47569 .72511 m
.47928 .72137 L
s
.46941 .76391 m .46613 .77214 L .46892 .76824 L 0 1 .453 r
F
.47507 .76836 m .46892 .76824 L .46613 .77214 L 0 1 .451 r
F
0 g
.46606 .77655 m
.46613 .77214 L
s
.46553 .77234 m
.46613 .77214 L
s
.47501 .77208 m
.47503 .77092 L
s
.475 .77278 m
.47596 .77228 L
s
.23183 .79667 m .21819 .78478 L .21758 .79121 L 0 1 .527 r
F
.23183 .79667 m .22258 .78403 L .21819 .78478 L F
.23183 .79667 m .22843 .78914 L .22258 .78403 L F
.24254 .79432 m .22843 .78914 L .23183 .79667 L 0 1 .526 r
F
0 g
.23119 .80305 m
.23183 .79667 L
s
.23183 .79667 m
.23755 .80154 L
s
.48644 .76079 m .48112 .77246 L .48447 .77011 L 0 1 .439 r
F
.48644 .76079 m .47865 .77087 L .48112 .77246 L F
0 g
.48112 .77246 m
.48145 .77674 L
s
.50681 .68626 m .50643 .68709 L .50403 .69034 L 0 0 0 r
F
.51316 .68036 m .50681 .68626 L .50892 .68405 L 0 0 .047 r
F
.51316 .68036 m .50643 .68709 L .50681 .68626 L F
0 g
.50782 .68411 m
.50964 .68253 L
s
.50846 .68278 m
.50964 .68253 L
s
.50529 .6879 m
.50681 .68626 L
s
.38526 .94317 m .38567 .9467 L .38818 .94497 L 0 1 .484 r
F
.38526 .94317 m .37875 .94732 L .38567 .9467 L F
0 g
.38567 .9467 m
.38923 .9483 L
s
.50303 .76889 m .50359 .77912 L .50426 .77364 L 0 1 .43 r
F
.50885 .77074 m .50426 .77364 L .50359 .77912 L 0 1 .427 r
F
0 g
.50359 .77912 m
.50519 .78391 L
s
.50101 .78239 m
.50359 .77912 L
s
.44329 .85095 m .43907 .84478 L .43391 .84211 L 0 .867 .412 r
F
0 g
.43391 .84211 m
.43907 .84478 L
s
.43298 .83547 m
.43391 .84211 L
s
.51316 .68035 m .51316 .68035 L .51188 .6649 L 0 .698 .285 r
F
.49176 .76389 m .49063 .77353 L .4922 .76853 L 0 1 .436 r
F
.49731 .7666 m .4922 .76853 L .49063 .77353 L 0 1 .433 r
F
0 g
.48751 .77619 m
.49063 .77353 L
s
.49063 .77353 m
.49065 .77361 L
s
.48695 .92619 m .48101 .91997 L .4758 .91711 L 0 .614 .415 r
F
0 g
.4758 .91711 m
.48101 .91997 L
s
.37535 .76258 m .37019 .77073 L .37403 .76916 L 0 1 .427 r
F
.37535 .76258 m .36561 .76639 L .37019 .77073 L F
0 g
.36944 .77735 m
.37019 .77073 L
s
.51777 .97068 m .51082 .96388 L .50548 .96031 L 0 .364 .362 r
F
0 g
.50045 .95391 m
.50548 .96031 L
s
.51472 .77212 m .51221 .78606 L .51503 .78679 L 0 1 .423 r
F
0 g
.51503 .78679 m
.51514 .78701 L
s
.51472 .77212 m .51025 .78124 L .51221 .78606 L 0 1 .423 r
F
0 g
.50995 .78949 m
.51221 .78606 L
s
.51316 .68035 m .51316 .68035 L .51432 .66491 L 0 .709 .28 r
F
.51316 .68036 m .50964 .68253 L .51165 .68129 L 0 0 .042 r
F
.51316 .68036 m .51165 .68129 L .50964 .68253 L 0 0 .037 r
F
0 g
.50964 .68253 m
.50964 .68253 L
s
.50964 .68253 m
.50964 .68253 L
s
.69649 .93811 m .68993 .94281 L .68738 .94647 L 0 1 .482 r
F
0 g
.67958 .94919 m
.68738 .94647 L
s
.51624 .65753 m .51931 .63326 L .51781 .64095 L 0 1 .343 r
F
0 g
.51887 .6355 m
.51931 .63326 L
s
.51794 .63445 m
.51796 .63435 L
s
.51796 .63435 m
.51945 .6267 L
s
.51931 .63326 m
.51945 .6267 L
s
.52499 .98629 m
.52899 .99153 L
s
.5249 .98617 m
.52499 .98629 L
s
.52419 .66774 m .52431 .66868 L .52775 .66586 L 0 1 .342 r
F
0 g
.52436 .66863 m
.52775 .66586 L
s
.52416 .66619 m
.52612 .66392 L
s
.52426 .66764 m
.52661 .66374 L
s
.52423 .66769 m
.52426 .66764 L
s
.5242 .66774 m
.52423 .66769 L
s
.51736 .65722 m .51974 .63957 L .51819 .64967 L 0 1 .339 r
F
.51624 .65753 m .51819 .64967 L .51974 .63957 L 0 1 .343 r
F
0 g
.51974 .63957 m
.52025 .63734 L
s
.51974 .63957 m
.51982 .63843 L
s
.27473 .78708 m .26939 .79379 L .27364 .79273 L 0 1 .524 r
F
.27473 .78708 m .26399 .78953 L .26939 .79379 L F
0 g
.26917 .79948 m
.26939 .79379 L
s
.27364 .79273 m
.27966 .79666 L
s
.5316 .55903 m .53152 .56425 L .53041 .56442 L 0 0 .029 r
F
.5316 .55903 m .53474 .55814 L .53152 .56425 L F
.5316 .55903 m .53789 .55017 L .53474 .55814 L F
0 g
.52874 .56709 m
.5316 .55903 L
s
.51316 .68036 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68036 L
s
.37875 .94732 m .36044 .94927 L .36306 .95166 L 0 1 .497 r
F
.52455 .67522 m .53256 .67135 L .528 .67311 L 0 1 .347 r
F
.52456 .67264 m .528 .67311 L .53256 .67135 L 0 1 .346 r
F
0 g
.53256 .67135 m
.53339 .67057 L
s
.53256 .67135 m
.53593 .67188 L
s
.45609 .76806 m .44604 .76962 L .44539 .77385 L 0 1 .465 r
F
0 g
.44085 .77419 m
.44539 .77385 L
s
.52337 .40838 m .53526 .40063 L .53589 .40713 L 0 .172 .097 r
F
0 g
.53526 .40063 m
.53959 .39083 L
s
.5299 .40117 m
.53526 .40063 L
s
.51844 .6572 m .51886 .65727 L .52097 .64924 L 0 1 .335 r
F
0 g
.52036 .65156 m
.52093 .64939 L
s
.52093 .64939 m
.52097 .64924 L
s
.51968 .6563 m
.52039 .65239 L
s
.51964 .65649 m
.51968 .6563 L
s
.52039 .65239 m
.52093 .64946 L
s
.52093 .64946 m
.52097 .64924 L
s
.5205 .65771 m
.52062 .65716 L
s
.52062 .65716 m
.52074 .65659 L
s
.52074 .65659 m
.52078 .65641 L
s
.52078 .65641 m
.52224 .64971 L
s
.51997 .6573 m
.52005 .65704 L
s
.52005 .65704 m
.52015 .65671 L
s
.52015 .65671 m
.52224 .64971 L
s
.52455 .67522 m .53241 .67645 L .53586 .67434 L 0 1 .347 r
F
.50177 .67095 m .49376 .67002 L .49832 .67134 L 0 .828 .296 r
F
.50177 .67557 m .49376 .67002 L .49036 .67141 L 0 .811 .296 r
F
.50177 .67557 m .49832 .67134 L .49376 .67002 L F
0 g
.4904 .66663 m
.49376 .67002 L
s
.49191 .67078 m
.49376 .67002 L
s
.35273 .94955 m .35239 .95367 L .3554 .95201 L 0 1 .504 r
F
0 g
.3554 .95201 m
.36306 .95166 L
s
.35273 .94955 m .34496 .95351 L .35239 .95367 L 0 1 .504 r
F
0 g
.35239 .95367 m
.35579 .95597 L
s
.76327 .90549 m .75736 .91321 L .75571 .91914 L 0 1 .517 r
F
0 g
.74776 .92407 m
.75571 .91914 L
s
.37403 .76916 m
.37892 .77328 L
s
.39128 .77575 m .37994 .76669 L .37892 .77328 L 0 1 .42 r
F
0 g
.37892 .77328 m
.37892 .77328 L
s
.51316 .68036 m .52335 .66208 L .52019 .66814 L 0 0 .045 r
F
.51316 .68036 m .52055 .66618 L .51633 .67428 L 0 0 .044 r
F
.51316 .68036 m .51633 .67428 L .52055 .66618 L 0 0 .045 r
F
.51316 .68036 m .51316 .68036 L .51633 .67428 L F
.51316 .68035 m .52019 .66814 L .52301 .66098 L 0 .709 .284 r
F
0 g
.52214 .66321 m
.52214 .66321 L
s
.52214 .66321 m
.52214 .66321 L
s
.52214 .66321 m
.52301 .66098 L
s
.51976 .6636 m
.52236 .65464 L
s
.52295 .66118 m
.5236 .6593 L
s
.52187 .66389 m
.52255 .66271 L
s
.51976 .66361 m
.52246 .65893 L
s
.52301 .66098 m
.52303 .66095 L
s
.52288 .66139 m
.52295 .66118 L
s
.52277 .66172 m
.52288 .66139 L
s
.52277 .66172 m
.52277 .66172 L
s
.52277 .66172 m
.52277 .66172 L
s
.52334 .6621 m
.52335 .66208 L
s
.52311 .66223 m
.52333 .66183 L
s
.52335 .66208 m
.52335 .66208 L
s
.51316 .68035 m .51316 .68035 L .51156 .66562 L 0 .707 .286 r
F
.38153 .78265 m .37001 .77831 L .36932 .78263 L 0 1 .506 r
F
.38153 .78265 m .37386 .77679 L .37001 .77831 L F
.38153 .78265 m .3788 .77865 L .37386 .77679 L F
0 g
.38114 .78504 m
.38153 .78265 L
s
.39124 .77809 m .3788 .77865 L .38153 .78265 L 0 1 .503 r
F
0 g
.38153 .78265 m
.38442 .78358 L
s
.47565 .90583 m .47739 .90707 L .47596 .90542 L 0 1 .339 r
F
.47596 .90542 m .47736 .91325 L .47842 .91052 L 0 .685 .415 r
F
.4752 .90387 m .47565 .90583 L .47596 .90542 L F
.47565 .90583 m .47736 .91325 L .47596 .90542 L F
.47596 .90542 m .47739 .90707 L .47845 .90516 L 0 1 .339 r
F
.47519 .90551 m .47565 .90583 L .47596 .90542 L F
.48893 .89855 m .47845 .90516 L .47739 .90707 L 0 1 .354 r
F
0 g
.47739 .90707 m
.48108 .90627 L
s
.4769 .90737 m
.47739 .90707 L
s
.479 .67582 m .47094 .66947 L .46755 .67348 L 0 .945 .318 r
F
0 g
.46799 .67296 m
.47094 .66947 L
s
.46762 .66616 m
.47094 .66947 L
s
.47223 .91024 m .46639 .91258 L .46095 .91577 L 0 1 .392 r
F
0 g
.47223 .91066 m
.47467 .91508 L
s
.47467 .91508 m
.4758 .91711 L
s
.51316 .68036 m .50181 .66911 L .50177 .67095 L 0 .742 .286 r
F
.51316 .68036 m .50523 .67151 L .50181 .66911 L F
0 g
.49844 .66572 m
.50181 .66911 L
s
.51806 .98504 m .50482 .99101 L .51053 .99095 L 0 1 .524 r
F
0 g
.50455 .99407 m
.51053 .99095 L
s
.42669 .76438 m .41567 .7688 L .41459 .77055 L 0 1 .313 r
F
.42669 .76438 m .41967 .76649 L .41567 .7688 L F
.42669 .76438 m .42439 .76459 L .41967 .76649 L F
.43625 .75779 m .42439 .76459 L .42669 .76438 L 0 1 .25 r
F
0 g
.42669 .76438 m
.43121 .76219 L
s
.4256 .76613 m
.42669 .76438 L
s
.2312 .81057 m .22641 .81597 L .23065 .81505 L 0 1 .537 r
F
.2312 .81057 m .22049 .81263 L .22641 .81597 L F
0 g
.22641 .81597 m
.22687 .8205 L
s
.231 .81521 m
.23732 .818 L
s
.23065 .81505 m
.231 .81521 L
s
.50177 .67557 m .49036 .67141 L .49039 .67458 L 0 .811 .296 r
F
0 g
.48692 .6689 m
.49036 .67141 L
s
.49036 .67141 m
.49191 .67078 L
s
.41344 .93493 m .41427 .93802 L .41643 .93616 L 0 1 .455 r
F
.41344 .93493 m .40777 .93942 L .41427 .93802 L F
0 g
.41427 .93802 m
.41783 .93901 L
s
.48644 .76079 m .47861 .7663 L .47865 .77087 L 0 1 .439 r
F
0 g
.47596 .77228 m
.47865 .77087 L
s
.4845 .77036 m
.48492 .77474 L
s
.49039 .67458 m .47896 .67168 L .479 .67582 L 0 .881 .307 r
F
0 g
.47896 .67168 m
.47921 .67146 L
s
.47551 .66897 m
.47896 .67168 L
s
.42661 .76996 m .42174 .77664 L .42549 .7741 L 0 1 .484 r
F
.42661 .76996 m .41706 .77614 L .42174 .77664 L F
0 g
.42111 .78086 m
.42174 .77664 L
s
.51316 .68035 m .51316 .68035 L .51465 .66577 L 0 .717 .28 r
F
.76847 .76562 m .77168 .77441 L .77707 .77602 L 0 .376 .306 r
F
0 g
.77168 .77441 m
.77218 .77932 L
s
.52201 .4585 m .53234 .43675 L .53297 .43819 L 0 0 .021 r
F
.52201 .4585 m .52765 .44544 L .53234 .43675 L F
0 g
.53234 .43675 m
.536 .42472 L
s
.53112 .43901 m
.53234 .43675 L
s
.30377 .80546 m .29018 .80183 L .28976 .8051 L 0 1 .52 r
F
.30377 .80546 m .29445 .80084 L .29018 .80183 L F
.30377 .80546 m .30028 .8024 L .29445 .80084 L F
0 g
.30333 .80872 m
.30377 .80546 L
s
.31649 .8017 m .30028 .8024 L .30378 .80546 L 0 1 .512 r
F
0 g
.30378 .80546 m
.31015 .80654 L
s
.51316 .68036 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68035 L
s
.41496 .80377 m .41182 .7973 L .40677 .79406 L 0 1 .412 r
F
0 g
.40677 .79406 m
.41182 .7973 L
s
.41483 .81037 m
.41496 .80377 L
s
.51503 .78679 m
.51564 .78555 L
s
.46941 .76391 m .46015 .76701 L .45966 .77134 L 0 1 .453 r
F
0 g
.45543 .77229 m
.45966 .77134 L
s
.40777 .93942 m .39194 .94241 L .39523 .94383 L 0 1 .477 r
F
0 g
.38818 .94497 m
.39523 .94383 L
s
.45767 .99571 m .44978 .9942 L .44281 .9945 L 0 1 .542 r
F
.46048 .99084 m .45767 .99571 L .46433 .99536 L F
.46048 .99084 m .44978 .9942 L .45767 .99571 L F
0 g
.45767 .99571 m
.46017 .99701 L
s
.21411 .75983 m .20809 .76916 L .21247 .76828 L 0 1 .49 r
F
.21411 .75983 m .20308 .76186 L .20809 .76916 L F
0 g
.2075 .77762 m
.20809 .76916 L
s
.21247 .76828 m
.21834 .77526 L
s
.8125 .60415 m .82474 .6123 L .82407 .61072 L 0 .207 .182 r
F
0 g
.82176 .61118 m
.82474 .6123 L
s
.45621 .66801 m .45639 .66254 L .45311 .65897 L 0 1 .34 r
F
0 g
.45639 .66254 m
.45707 .66169 L
s
.72995 .93161 m .7235 .93461 L .72129 .93815 L 0 1 .531 r
F
0 g
.71323 .93903 m
.72129 .93815 L
s
.51316 .68035 m .51976 .66362 L .51599 .67318 L 0 .709 .284 r
F
.51316 .68035 m .51599 .67318 L .51976 .66362 L 0 .72 .283 r
F
0 g
.51976 .66362 m
.51976 .6636 L
s
.51976 .66362 m
.51976 .66361 L
s
.51316 .68036 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m .51316 .68035 L .51125 .66647 L 0 .717 .287 r
F
.51001 .55967 m .51335 .54831 L .51595 .5304 L 0 1 .241 r
F
0 g
.51393 .54432 m
.51595 .5304 L
s
.51595 .5304 m
.516 .53039 L
s
.50885 .77074 m .51025 .78124 L .51045 .77553 L 0 1 .427 r
F
.51472 .77212 m .51045 .77553 L .51025 .78124 L 0 1 .423 r
F
0 g
.51025 .78124 m
.51221 .78606 L
s
.50799 .78483 m
.51025 .78124 L
s
.48644 .76079 m .48447 .77011 L .48648 .76536 L 0 1 .439 r
F
.49176 .76389 m .48648 .76536 L .48447 .77011 L 0 1 .436 r
F
0 g
.48112 .77246 m
.48447 .77011 L
s
.48447 .77011 m
.4845 .77036 L
s
.52127 .45958 m .51764 .46896 L .51749 .4698 L 0 0 .003 r
F
0 g
.52127 .45958 m
.52127 .45958 L
s
.52127 .45958 m .52201 .4585 L .51764 .46896 L 0 0 .003 r
F
.52127 .45958 m .52765 .44544 L .52201 .4585 L F
0 g
.52765 .44544 m
.53112 .43901 L
s
.52765 .44544 m
.5314 .4353 L
s
.51316 .68035 m .50537 .66832 L .50982 .67519 L 0 .753 .287 r
F
.51316 .68036 m .50982 .67519 L .50537 .66832 L 0 .749 .286 r
F
0 g
.50537 .66831 m
.50537 .66832 L
s
.50214 .66182 m
.50537 .66832 L
s
.47972 .45221 m .48886 .43845 L .48805 .4418 L 0 0 0 r
F
0 g
.48886 .43845 m
.49371 .4286 L
s
.48529 .4429 m
.48886 .43845 L
s
.45621 .66801 m .45311 .65897 L .44856 .65968 L 0 1 .34 r
F
0 g
.45311 .65897 m
.45684 .65424 L
s
.45311 .65897 m
.45639 .66254 L
s
.43156 .81306 m .4235 .81976 L .4285 .82248 L 0 .941 .402 r
F
.43156 .81306 m .41996 .8134 L .4235 .81976 L F
.43156 .81306 m .4199 .80671 L .41996 .8134 L F
.44583 .75077 m .44059 .7553 L .44434 .75242 L 0 .946 .221 r
F
.44583 .75077 m .43625 .75779 L .44059 .7553 L F
0 g
.43953 .75702 m
.44059 .7553 L
s
.44434 .75242 m
.44869 .74967 L
s
.3367 .97562 m .33683 .98185 L .33983 .98034 L 0 1 .537 r
F
.3367 .97562 m .32896 .97926 L .33683 .98185 L F
0 g
.33683 .98185 m
.34074 .98636 L
s
.52444 .67013 m .5245 .67112 L .52796 .66944 L 0 1 .344 r
F
0 g
.52459 .67261 m
.52796 .66944 L
s
.52446 .67011 m
.52775 .66586 L
s
.4384 .62561 m .43963 .61901 L .43741 .6143 L 0 1 .355 r
F
0 g
.43963 .61901 m
.44096 .6174 L
s
.48893 .89855 m .4834 .9015 L .47845 .90516 L 0 1 .354 r
F
.49083 .89433 m .48893 .89855 L .49355 .89508 L 0 1 .292 r
F
.49083 .89433 m .4834 .9015 L .48893 .89855 L F
0 g
.48893 .89855 m
.49261 .89776 L
s
.51316 .68036 m .50824 .68551 L .50643 .68709 L 0 0 .047 r
F
0 g
.50403 .69034 m
.50643 .68709 L
s
.50681 .68626 m
.50892 .68406 L
s
.50741 .68498 m
.50891 .68406 L
s
.44183 .54974 m .44501 .54178 L .44513 .53635 L 0 1 .324 r
F
0 g
.44501 .54178 m
.4471 .53899 L
s
.31 .76287 m .29661 .7503 L .29438 .75777 L 0 1 .462 r
F
.31 .76287 m .30202 .74904 L .29661 .7503 L F
.31 .76287 m .30775 .75443 L .30202 .74904 L F
0 g
.30775 .77033 m
.31 .76287 L
s
.32007 .76005 m .30776 .75443 L .31 .76287 L 0 1 .457 r
F
0 g
.31 .76287 m
.31467 .7683 L
s
.35563 .77971 m .35078 .78563 L .35462 .7842 L 0 1 .514 r
F
.35563 .77971 m .3459 .7831 L .35078 .78563 L F
0 g
.3504 .79018 m
.35078 .78563 L
s
.35462 .7842 m
.35985 .78647 L
s
.53568 .67798 m .54373 .67874 L .5392 .67728 L 0 .928 .331 r
F
0 g
.53586 .67434 m
.5392 .67728 L
s
.36561 .76639 m .35466 .75582 L .35346 .7625 L 0 1 .434 r
F
.36561 .76639 m .35866 .75448 L .35466 .75582 L F
.36561 .76639 m .36336 .75901 L .35866 .75448 L F
.37535 .76258 m .36336 .75901 L .36561 .76639 L 0 1 .427 r
F
0 g
.36561 .76639 m
.37019 .77073 L
s
.36441 .77305 m
.36561 .76639 L
s
.7744 .58616 m .78539 .58589 L .78757 .59067 L 0 .199 0 r
F
0 g
.78539 .58589 m
.78933 .58831 L
s
.76327 .90549 m .76677 .91354 L .77292 .90556 L 0 1 .517 r
F
0 g
.7594 .91935 m
.76677 .91354 L
s
.76493 .91974 m
.76677 .91354 L
s
.44018 .82837 m .42908 .82922 L .43298 .83547 L 0 .89 .402 r
F
.44018 .82837 m .4285 .82248 L .42908 .82922 L F
0 g
.42908 .82921 m
.42908 .82922 L
s
.4238 .79751 m .41496 .80377 L .4199 .80671 L 0 .989 .402 r
F
.4238 .79751 m .41182 .79729 L .41496 .80377 L F
.41706 .77614 m .40568 .77433 L .40476 .77854 L 0 1 .491 r
F
.51316 .68035 m .51316 .68035 L .51497 .66686 L 0 .723 .28 r
F
.51806 .98504 m .524 .98644 L .52377 .98499 L 0 1 .524 r
F
0 g
.51833 .98899 m
.524 .98644 L
s
.524 .98644 m
.5249 .98617 L
s
.26213 .97036 m
.26888 .97329 L
s
.80092 .59673 m .8125 .60415 L .80853 .60135 L 0 0 0 r
F
.80092 .59673 m .80853 .60135 L .80391 .59859 L F
.50177 .67557 m .50176 .67372 L .49832 .67134 L 0 .811 .296 r
F
.51736 .65722 m .5178 .65717 L .51962 .64924 L 0 1 .339 r
F
0 g
.5196 .6493 m
.51962 .64924 L
s
.51854 .65651 m
.5196 .64933 L
s
.51848 .65698 m
.51854 .65651 L
s
.5196 .64933 m
.51962 .64924 L
s
.51951 .6572 m
.51959 .65677 L
s
.51959 .65677 m
.51964 .65649 L
s
.51894 .65698 m
.51896 .65687 L
s
.51896 .65687 m
.51903 .65661 L
s
.51903 .65661 m
.52036 .65156 L
s
.53568 .67798 m .54695 .68278 L .54373 .67874 L 0 .928 .331 r
F
.53568 .67798 m .5467 .68671 L .54695 .68278 L F
.53568 .67798 m .54318 .6874 L .5467 .68671 L F
0 g
.54436 .67836 m
.54606 .67731 L
s
.54373 .67874 m
.54436 .67836 L
s
.53568 .67798 m .53872 .6844 L .54318 .6874 L 0 .928 .331 r
F
.53568 .67798 m .53551 .68036 L .53872 .6844 L F
.52443 .67784 m .53568 .67798 L .53241 .67645 L 0 1 .347 r
F
.52443 .67784 m .53551 .68036 L .53568 .67798 L F
0 g
.53568 .67798 m
.5392 .67728 L
s
.51316 .68035 m .51316 .68035 L .51097 .66743 L 0 .728 .288 r
F
.51316 .68036 m .50177 .67095 L .50517 .67474 L 0 .742 .286 r
F
0 g
.49832 .67134 m
.50177 .67095 L
s
.50181 .66911 m
.50523 .67151 L
s
.50956 .53111 m .5134 .49831 L .50911 .5119 L 0 1 .195 r
F
0 g
.5134 .49831 m
.51515 .496 L
s
.5134 .49831 m
.51412 .49532 L
s
.33591 .79574 m .33139 .79959 L .33522 .7983 L 0 1 .492 r
F
.33591 .79574 m .3262 .79876 L .33139 .79959 L F
0 g
.33139 .79959 m
.33139 .80225 L
s
.33522 .7983 m
.34082 .79882 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.34025 .75417 m .33465 .76225 L .33864 .761 L 0 1 .447 r
F
.34025 .75417 m .33016 .75716 L .33465 .76225 L F
0 g
.33371 .76913 m
.33465 .76225 L
s
.33864 .761 m
.34358 .76586 L
s
.45778 .91564 m .45953 .91769 L .46095 .91577 L 0 1 .376 r
F
.45778 .91564 m .45395 .92036 L .45953 .91769 L F
0 g
.45953 .91769 m
.46316 .91744 L
s
.44552 .65571 m .44602 .6497 L .44304 .64564 L 0 1 .35 r
F
0 g
.44602 .6497 m
.44699 .64848 L
s
.44171 .77001 m .43111 .77016 L .43025 .77434 L 0 1 .475 r
F
.45259 .51042 m .45814 .49626 L .45592 .49771 L 0 1 .204 r
F
0 g
.45814 .49626 m
.46306 .48821 L
s
.45671 .5017 m
.45814 .49626 L
s
.59589 .40392 m .59457 .41603 L .59257 .40995 L 0 .416 .099 r
F
.59589 .40392 m .60123 .42049 L .59457 .41603 L F
.59589 .40392 m .60807 .42033 L .60123 .42049 L F
.59589 .40392 m .61135 .41427 L .60807 .42033 L F
0 g
.58957 .39991 m
.59589 .40392 L
s
.401 .77094 m .39599 .77943 L .39982 .77745 L 0 1 .411 r
F
.40096 .7733 m .39599 .77943 L .39982 .77745 L 0 1 .498 r
F
.40092 .77566 m .39599 .77943 L .39982 .77745 L 0 1 .37 r
F
.401 .77094 m .39128 .77575 L .39599 .77943 L 0 1 .411 r
F
.40096 .7733 m .39124 .77809 L .39599 .77943 L 0 1 .498 r
F
.40092 .77566 m .39119 .78042 L .39599 .77943 L 0 1 .37 r
F
0 g
.39987 .77744 m
.39995 .77742 L
s
.39995 .77742 m
.4048 .77618 L
s
.39586 .77946 m
.39593 .77945 L
s
.40743 .7875 m .39982 .77745 L .39599 .77943 L 0 1 .411 r
F
0 g
.39593 .77945 m
.39599 .77943 L
s
.39543 .78133 m
.39599 .77943 L
s
.39598 .77955 m
.39599 .77943 L
s
.39534 .786 m
.39599 .77943 L
s
.4676 .67832 m .46408 .67053 L .45951 .67144 L 0 1 .33 r
F
.4676 .67832 m .46755 .67348 L .46408 .67053 L F
0 g
.46408 .67053 m
.46762 .66616 L
s
.54373 .67874 m
.54695 .68278 L
s
.52839 .79986 m
.52842 .79991 L
s
.49083 .89433 m .49355 .89508 L .49418 .8934 L 0 1 .292 r
F
0 g
.48893 .89855 m
.49355 .89508 L
s
.49355 .89508 m
.49728 .89367 L
s
.51316 .68036 m .52302 .6624 L .52277 .66172 L 0 1 .356 r
F
.51316 .68035 m .51618 .67512 L .52019 .66814 L 0 .709 .284 r
F
.51316 .68035 m .51316 .68036 L .51618 .67512 L F
.51316 .68036 m .52019 .66814 L .52302 .6624 L 0 1 .356 r
F
0 g
.52302 .6624 m
.52311 .66223 L
s
.51316 .68036 m .52277 .66172 L .51976 .66695 L 0 1 .356 r
F
0 g
.52277 .66173 m
.52277 .66172 L
s
.52276 .66173 m
.52277 .66173 L
s
.52276 .66173 m
.52276 .66173 L
s
.52277 .66172 m
.52277 .66172 L
s
.50303 .76889 m .50073 .76802 L .49815 .7713 L 0 1 .43 r
F
.51316 .68036 m .52336 .6635 L .52019 .66814 L 0 1 .357 r
F
.39128 .77575 m .38397 .76498 L .37994 .76669 L 0 1 .42 r
F
.39128 .77575 m .38883 .76886 L .38397 .76498 L F
.401 .77094 m .38883 .76886 L .39128 .77575 L 0 1 .411 r
F
0 g
.39128 .77575 m
.3931 .77717 L
s
.39092 .7781 m
.39128 .77575 L
s
.51316 .68036 m .52237 .66078 L .52208 .66021 L 0 1 .354 r
F
.51316 .68036 m .51976 .66695 L .52237 .66078 L F
0 g
.52237 .66078 m
.52267 .66011 L
s
.52217 .66126 m
.52237 .66078 L
s
.52216 .66126 m
.52217 .66126 L
s
.52216 .66126 m
.52216 .66126 L
s
.47507 .76836 m .47275 .76662 L .46892 .76824 L 0 1 .451 r
F
.48139 .75733 m .47507 .76836 L .47861 .7663 L 0 1 .441 r
F
.48139 .75733 m .47275 .76662 L .47507 .76836 L F
0 g
.47503 .77092 m
.47507 .76836 L
s
.51316 .68036 m .52055 .66951 L .52356 .66428 L 0 1 .357 r
F
0 g
.52258 .66464 m
.52297 .66406 L
s
.52356 .66428 m
.52359 .66424 L
s
.4238 .79751 m .41227 .79066 L .41182 .79729 L 0 .989 .402 r
F
.51508 .65812 m .51781 .64095 L .51793 .63449 L 0 1 .347 r
F
0 g
.51788 .63722 m
.51793 .63449 L
s
.51783 .64085 m
.51887 .6355 L
s
.51793 .63449 m
.51794 .63445 L
s
.51316 .68036 m .52208 .66021 L .51926 .66595 L 0 1 .354 r
F
0 g
.52208 .66021 m
.52242 .65905 L
s
.44018 .82837 m .43298 .83547 L .43798 .838 L 0 .89 .402 r
F
.52443 .67784 m .53241 .67645 L .52789 .67679 L 0 1 .347 r
F
.52455 .67522 m .52789 .67679 L .53241 .67645 L F
0 g
.53241 .67645 m
.53586 .67434 L
s
.53241 .67645 m
.53568 .67798 L
s
.46601 .88138 m .45683 .88241 L .46198 .88855 L 0 .736 .409 r
F
.46601 .88138 m .45439 .87571 L .45683 .88241 L F
0 g
.45155 .87978 m
.45683 .88241 L
s
.41706 .77614 m .40968 .77216 L .40568 .77433 L 0 1 .491 r
F
.41706 .77614 m .41455 .77294 L .40968 .77216 L F
.42661 .76996 m .41455 .77294 L .41706 .77614 L 0 1 .484 r
F
0 g
.41706 .77614 m
.42174 .77664 L
s
.41613 .78035 m
.41706 .77614 L
s
.42549 .7741 m
.43025 .77434 L
s
.46852 .73236 m .45938 .74011 L .45787 .74185 L 0 .873 .17 r
F
.46852 .73236 m .46314 .73681 L .45938 .74011 L F
.46852 .73236 m .46706 .73349 L .46314 .73681 L F
.47743 .72328 m .46706 .73349 L .46852 .73236 L 0 0 0 r
F
0 g
.46852 .73236 m
.47222 .72877 L
s
.467 .7341 m
.46852 .73236 L
s
.51316 .68036 m .52383 .66552 L .52055 .66951 L 0 1 .359 r
F
.51316 .68036 m .52399 .66639 L .52383 .66552 L F
0 g
.52383 .66552 m
.5239 .66538 L
s
.53452 .66416 m .54165 .65242 L .53743 .65611 L 0 .507 .258 r
F
.53452 .66416 m .54521 .66026 L .54165 .65242 L F
0 g
.54165 .65242 m
.5443 .639 L
s
.70787 .93412 m
.71258 .93373 L
s
.69624 .92952 m .70475 .93437 L .70734 .931 L 0 1 .531 r
F
0 g
.70475 .93437 m
.70755 .93414 L
s
.53995 .64617 m .54998 .62682 L .54893 .64214 L 0 .121 .123 r
F
0 g
.53858 .63791 m
.54074 .63847 L
s
.54601 .64345 m
.54798 .64861 L
s
.54795 .62058 m
.54998 .62682 L
s
.54998 .62682 m
.55005 .62649 L
s
.51316 .68035 m .51316 .68035 L .51599 .67318 L 0 .72 .283 r
F
.51316 .68035 m .52162 .65944 L .52129 .65899 L 0 1 .353 r
F
.51316 .68035 m .51926 .66595 L .52162 .65944 L F
0 g
.52162 .65944 m
.52183 .65889 L
s
.52155 .66539 m
.52155 .66539 L
s
.52155 .66539 m
.52155 .66539 L
s
.50885 .77074 m .50651 .77005 L .50426 .77364 L 0 1 .427 r
F
0 g
.51704 .78307 m
.51741 .78385 L
s
.51793 .78495 m
.51828 .78568 L
s
.51316 .68036 m .52083 .67103 L .52399 .66639 L 0 1 .359 r
F
0 g
.52399 .66639 m
.52412 .66624 L
s
.51001 .55967 m .51337 .51814 L .50956 .53111 L 0 1 .241 r
F
0 g
.51337 .51814 m
.51454 .51193 L
s
.51337 .51814 m
.51384 .51809 L
s
.49731 .7666 m .49507 .76556 L .4922 .76853 L 0 1 .433 r
F
.22514 .75778 m .21904 .76695 L .22342 .76606 L 0 1 .488 r
F
.22514 .75778 m .21411 .75983 L .21904 .76695 L F
0 g
.21834 .77526 m
.21904 .76695 L
s
.22342 .76606 m
.22918 .77288 L
s
.25803 .95519 m .24145 .95609 L .24889 .95816 L 0 1 .408 r
F
0 g
.24889 .95816 m
.25712 .95874 L
s
.49039 .67458 m .48244 .67833 L .48699 .67755 L 0 .881 .307 r
F
.49039 .67458 m .479 .67582 L .48244 .67833 L F
.50177 .67557 m .49039 .67458 L .49382 .67696 L 0 .811 .296 r
F
0 g
.48857 .67616 m
.49039 .67458 L
s
.52456 .67264 m .52457 .67367 L .528 .67311 L 0 1 .346 r
F
.479 .67582 m .46755 .67348 L .4676 .67832 L 0 .945 .318 r
F
0 g
.46408 .67053 m
.46755 .67348 L
s
.46755 .67348 m
.46799 .67296 L
s
.51316 .68035 m .52129 .65899 L .51868 .66516 L 0 1 .353 r
F
0 g
.5212 .66621 m
.52334 .6621 L
s
.52115 .6663 m
.5212 .66621 L
s
.52129 .65899 m
.52144 .6584 L
s
.51316 .68035 m .51316 .68035 L .51071 .6685 L 0 .736 .289 r
F
.51316 .68036 m .50892 .68405 L .51134 .68194 L 0 0 .047 r
F
.51316 .68036 m .51134 .68194 L .50892 .68405 L 0 0 .042 r
F
0 g
.50892 .68406 m
.50892 .68405 L
s
.50891 .68406 m
.50892 .68405 L
s
.55853 .39843 m .55547 .41367 L .55436 .40617 L 0 .39 .116 r
F
0 g
.55196 .41942 m
.55505 .41087 L
s
.55869 .41967 m .57143 .40876 L .57298 .41382 L 0 .175 .094 r
F
.55869 .41967 m .56532 .41126 L .57143 .40876 L F
.55869 .41967 m .57222 .41413 L .56884 .42252 L F
.57222 .41413 m .57298 .41382 L .57192 .41604 L F
.57222 .41413 m .57192 .41604 L .56884 .42252 L F
.55869 .41967 m .56884 .42252 L .56175 .42907 L F
.56976 .43254 m .57693 .43156 L .57242 .43709 L 0 .38 .103 r
F
.56175 .42907 m .56884 .42252 L .57227 .42164 L 0 .161 .083 r
F
.56175 .42907 m .57227 .42164 L .57219 .42201 L F
.56175 .42907 m .57302 .42145 L .57264 .42247 L F
.57264 .42247 m .57302 .42145 L .57533 .42339 L 0 .38 .103 r
F
.57929 .41903 m .57693 .43156 L .57533 .42339 L 0 .542 .103 r
F
.57111 .42667 m .57533 .42339 L .57693 .43156 L 0 .38 .103 r
F
.57264 .42247 m .57533 .42339 L .57111 .42667 L F
.57111 .42667 m .5753 .42086 L .57686 .42519 L 0 .161 .083 r
F
.56175 .42907 m .57264 .42247 L .57111 .42667 L F
.57264 .42247 m .5753 .42086 L .57111 .42667 L F
.56166 .41871 m .57264 .42247 L .57111 .42667 L 0 .38 .103 r
F
.56609 .43639 m .57242 .43709 L .56594 .43675 L 0 .353 .091 r
F
.56586 .4368 m .56609 .43639 L .56593 .43677 L 0 .135 .068 r
F
.56539 .439 m .57606 .45341 L .56797 .45125 L 0 .353 .091 r
F
.56175 .42907 m .56768 .43082 L .56482 .43724 L 0 .161 .083 r
F
.56768 .43082 m .56886 .43117 L .5664 .43487 L F
.56768 .43082 m .5664 .43487 L .56482 .43724 L F
.56527 .43843 m .56567 .43756 L .56539 .439 L 0 .353 .091 r
F
.56567 .43756 m .57606 .45341 L .56539 .439 L F
.566 .4368 m .57242 .43709 L .57932 .44288 L F
.56593 .43677 m .56602 .43677 L .566 .4368 L F
.56602 .43677 m .57242 .43709 L .566 .4368 L F
.56594 .43675 m .57242 .43709 L .56593 .43677 L F
.56946 .43203 m .57242 .43709 L .56874 .43669 L 0 .38 .103 r
F
.57929 .41903 m .58363 .4408 L .57693 .43156 L 0 .542 .103 r
F
.5656 .43745 m .58092 .4498 L .57606 .45341 L 0 .353 .091 r
F
.56482 .43724 m .56587 .43654 L .56582 .43681 L 0 .135 .068 r
F
.56482 .43724 m .56593 .43677 L .5658 .43709 L F
.56886 .43117 m .56838 .43208 L .56679 .43438 L 0 .161 .083 r
F
.56689 .43413 m .56679 .43438 L .56482 .43724 L F
.56886 .43117 m .56679 .43438 L .56689 .43413 L F
.5658 .43709 m .58092 .4498 L .5656 .43745 L 0 .353 .091 r
F
.56946 .43203 m .56874 .43669 L .56609 .43639 L 0 .38 .103 r
F
.56831 .43221 m .56609 .43639 L .56505 .43709 L 0 .161 .083 r
F
.56898 .43121 m .56609 .43639 L .56831 .43221 L F
.56574 .43704 m .57932 .44288 L .58092 .4498 L 0 .353 .091 r
F
.5665 .4348 m .56505 .43709 L .56482 .43724 L 0 .161 .083 r
F
.56898 .43121 m .56643 .43503 L .5665 .4348 L F
.56643 .43503 m .56505 .43709 L .5665 .4348 L F
.56175 .42907 m .56482 .43724 L .55832 .4389 L F
.56482 .43724 m .56182 .44356 L .55996 .44279 L 0 .135 .068 r
F
.56481 .43625 m .56182 .44356 L .55994 .43982 L 0 .353 .091 r
F
.56182 .44356 m .56106 .44542 L .56097 .44499 L F
.56182 .44356 m .56097 .44499 L .55996 .44279 L 0 .135 .068 r
F
.56182 .44356 m .56097 .44499 L .55994 .43982 L 0 .353 .091 r
F
.56182 .44356 m .56098 .445 L .56097 .44499 L 0 .135 .068 r
F
.56182 .44356 m .56106 .44517 L .56098 .445 L F
.56182 .44356 m .56527 .43843 L .56106 .44542 L 0 .353 .091 r
F
.56527 .43843 m .56476 .43994 L .56106 .44542 L F
.56539 .439 m .56797 .45125 L .56357 .44754 L F
.56539 .439 m .56357 .44754 L .56106 .44542 L F
.56182 .44356 m .56791 .44413 L .56106 .44517 L 0 .135 .068 r
F
.56482 .43724 m .5652 .43807 L .56182 .44356 L F
.5652 .43807 m .56527 .43843 L .56182 .44356 L 0 .353 .091 r
F
.56527 .43843 m .56539 .439 L .56476 .43994 L F
.5652 .43807 m .56791 .44413 L .56182 .44356 L 0 .135 .068 r
F
.56515 .43784 m .5652 .43807 L .56182 .44356 L 0 .353 .091 r
F
.56481 .43625 m .56515 .43784 L .56182 .44356 L F
.56481 .43625 m .5659 .43675 L .56574 .43704 L F
.5659 .43675 m .57932 .44288 L .56574 .43704 L F
.56756 .43376 m .56609 .43639 L .56481 .43625 L 0 .38 .103 r
F
.56946 .43203 m .56609 .43639 L .56756 .43376 L F
.56898 .43121 m .57064 .42873 L .56976 .43254 L F
.57111 .42667 m .57693 .43156 L .56976 .43254 L F
.56886 .43117 m .56898 .43121 L .56838 .43208 L 0 .161 .083 r
F
.56175 .42907 m .57066 .42678 L .56898 .43121 L F
.56166 .41871 m .56898 .43121 L .56481 .43625 L 0 .38 .103 r
F
.56898 .43121 m .56946 .43203 L .56825 .43313 L F
.56898 .43121 m .56825 .43313 L .56481 .43625 L F
.56898 .43121 m .57686 .42519 L .57237 .43221 L 0 .161 .083 r
F
.57031 .42837 m .57111 .42667 L .57064 .42873 L 0 .38 .103 r
F
.57066 .42678 m .57111 .42667 L .56898 .43121 L 0 .161 .083 r
F
.56166 .41871 m .57111 .42667 L .57031 .42837 L 0 .38 .103 r
F
.56166 .41871 m .57064 .42873 L .56898 .43121 L F
.57111 .42667 m .57686 .42519 L .56898 .43121 L 0 .161 .083 r
F
.56898 .43121 m .57237 .43221 L .56609 .43639 L F
.5658 .43709 m .58075 .4348 L .56555 .43744 L 0 .135 .068 r
F
.56559 .43744 m .5658 .43709 L .5656 .43745 L 0 .353 .091 r
F
.56481 .43625 m .56574 .43704 L .56559 .43744 L F
.56482 .43724 m .5658 .43709 L .56555 .43744 L 0 .135 .068 r
F
.56574 .43704 m .5658 .43709 L .56559 .43744 L 0 .353 .091 r
F
.5656 .43745 m .58075 .4348 L .57592 .44036 L 0 .135 .068 r
F
.56554 .43759 m .56567 .43756 L .56527 .43843 L 0 .353 .091 r
F
.56555 .43744 m .56561 .43743 L .5656 .43745 L 0 .135 .068 r
F
.56559 .43744 m .5656 .43745 L .56554 .43759 L 0 .353 .091 r
F
.5656 .43745 m .56567 .43756 L .56554 .43759 L F
.56561 .43743 m .56561 .43743 L .5656 .43745 L 0 .135 .068 r
F
.56561 .43743 m .58075 .4348 L .5656 .43745 L F
.5652 .43807 m .57592 .44036 L .56791 .44413 L F
.56482 .43724 m .5656 .43745 L .5652 .43807 L F
.5652 .43807 m .56556 .43751 L .56527 .43843 L 0 .353 .091 r
F
.5656 .43745 m .57592 .44036 L .5652 .43807 L 0 .135 .068 r
F
.56481 .43625 m .56559 .43744 L .56556 .43751 L 0 .353 .091 r
F
.56481 .43625 m .56556 .43751 L .5652 .43807 L F
.56582 .43681 m .56593 .4365 L .56586 .4368 L 0 .135 .068 r
F
.56587 .43654 m .56593 .4365 L .56582 .43681 L F
.56593 .4365 m .56609 .43639 L .56586 .4368 L F
.56609 .43639 m .56594 .43675 L .5659 .43675 L 0 .353 .091 r
F
.5658 .43709 m .57919 .43117 L .58075 .4348 L 0 .135 .068 r
F
.56593 .43677 m .57919 .43117 L .5658 .43709 L F
.56593 .43677 m .57237 .43221 L .57919 .43117 L F
.56609 .43639 m .57237 .43221 L .56593 .43677 L F
.5659 .43675 m .56594 .43675 L .56593 .43677 L 0 .353 .091 r
F
.56481 .43625 m .56609 .43639 L .5659 .43675 L F
.57219 .42201 m .57227 .42164 L .57302 .42145 L 0 .161 .083 r
F
.57264 .42247 m .57302 .42145 L .5753 .42086 L F
.56166 .41871 m .5688 .4179 L .57302 .42145 L 0 .38 .103 r
F
.56166 .41871 m .57302 .42145 L .57264 .42247 L F
.55853 .39843 m .56166 .41871 L .55547 .41367 L 0 .39 .116 r
F
.55853 .39843 m .5688 .4179 L .56166 .41871 L F
.55853 .39843 m .57294 .4101 L .5688 .4179 L F
0 g
.56736 .40558 m
.56912 .40067 L
s
.57387 .39557 m
.57497 .3934 L
s
.55853 .39843 m .57135 .40056 L .57294 .4101 L 0 .39 .116 r
F
0 g
.57135 .40056 m
.57387 .39557 L
s
.55269 .39417 m
.55853 .39843 L
s
.56518 .39557 m
.57135 .40056 L
s
.51316 .68036 m .52419 .66774 L .52083 .67103 L 0 1 .361 r
F
.51316 .68036 m .52431 .66868 L .52419 .66774 L F
0 g
.52419 .66774 m
.5242 .66774 L
s
.52443 .67784 m .53206 .68141 L .53551 .68036 L 0 1 .347 r
F
.53102 .65629 m .54078 .63848 L .53995 .64617 L 0 .029 .101 r
F
0 g
.54074 .63847 m
.54078 .63848 L
s
.54078 .63848 m
.5442 .62752 L
s
.53395 .65367 m
.53743 .65611 L
s
.53179 .65218 m
.53367 .64763 L
s
.24254 .79432 m .22916 .7829 L .22843 .78914 L 0 1 .526 r
F
.24254 .79432 m .23355 .78214 L .22916 .7829 L F
.24254 .79432 m .23929 .78704 L .23355 .78214 L F
.25326 .79194 m .23929 .78704 L .24254 .79432 L F
0 g
.24179 .80052 m
.24254 .79432 L
s
.24254 .79432 m
.24815 .79898 L
s
.49886 .99273 m .49108 .99314 L .48481 .99503 L 0 1 .539 r
F
0 g
.48403 .99473 m
.48481 .99503 L
s
.44552 .65571 m .44304 .64564 L .43856 .64623 L 0 1 .35 r
F
0 g
.44304 .64564 m
.44699 .6406 L
s
.44304 .64564 m
.44602 .6497 L
s
.479 .67582 m .47105 .68104 L .47561 .67983 L 0 .945 .318 r
F
.479 .67582 m .4676 .67832 L .47105 .68104 L F
.43604 .59207 m .43814 .58491 L .43692 .57978 L 0 1 .355 r
F
0 g
.43814 .58491 m
.43985 .58283 L
s
.51316 .68035 m .51316 .68035 L .51063 .66885 L 0 .741 .289 r
F
.51316 .68035 m .51316 .68035 L .51526 .66817 L 0 .727 .281 r
F
.45621 .66801 m .44806 .67408 L .45264 .67296 L 0 1 .34 r
F
.45621 .66801 m .44478 .67051 L .44806 .67408 L F
.45621 .66801 m .44499 .66462 L .44478 .67051 L F
.45621 .66801 m .44856 .65968 L .44499 .66462 L F
.46048 .99084 m .46433 .99536 L .46533 .99338 L 0 1 .542 r
F
.47951 .99298 m .46533 .99338 L .46433 .99536 L F
0 g
.46433 .99536 m
.46964 .99741 L
s
.45767 .99571 m
.46433 .99536 L
s
.33618 .78637 m .32422 .77951 L .32348 .7843 L 0 1 .518 r
F
.33618 .78637 m .32822 .7784 L .32422 .77951 L F
.33618 .78637 m .33335 .78134 L .32822 .7784 L F
.3459 .7831 m .33335 .78134 L .33618 .78637 L 0 1 .516 r
F
0 g
.33543 .79115 m
.33618 .78637 L
s
.33618 .78637 m
.34118 .78911 L
s
.51316 .68035 m .52078 .65841 L .52042 .65808 L 0 1 .353 r
F
.51316 .68035 m .51868 .66516 L .52078 .65841 L F
0 g
.52078 .65841 m
.52097 .65784 L
s
.51316 .68036 m .52102 .67268 L .52431 .66868 L 0 1 .361 r
F
0 g
.52431 .66868 m
.52436 .66863 L
s
.45434 .86622 m .44984 .86013 L .44474 .8576 L 0 .805 .411 r
F
0 g
.44474 .8576 m
.44984 .86013 L
s
.44329 .85095 m
.44474 .8576 L
s
.5225 .78904 m
.52262 .78925 L
s
.52287 .78969 m
.52323 .79033 L
s
.45395 .92036 m .44202 .92464 L .44022 .92654 L 0 1 .42 r
F
.45395 .92036 m .44791 .92199 L .44202 .92464 L F
.45778 .91564 m .44791 .92199 L .45395 .92036 L 0 1 .376 r
F
0 g
.45395 .92036 m
.45741 .92067 L
s
.45395 .92036 m
.45953 .91769 L
s
.51624 .65753 m .51781 .64095 L .51672 .65049 L 0 1 .343 r
F
.51508 .65812 m .51672 .65049 L .51781 .64095 L 0 1 .347 r
F
0 g
.51781 .64095 m
.51788 .63722 L
s
.51781 .64095 m
.51783 .64085 L
s
.505 .69026 m .49971 .69658 L .50287 .69265 L 0 0 .016 r
F
.505 .69026 m .49685 .70039 L .49971 .69658 L F
.50587 .68831 m .50287 .69265 L .49971 .69658 L 0 0 .008 r
F
0 g
.49788 .69861 m
.49971 .69658 L
s
.52173 .86939 m
.52212 .86892 L
s
.49685 .70039 m .48962 .70958 L .48774 .71168 L 0 0 0 r
F
.4384 .62561 m .42983 .63146 L .4342 .63094 L 0 1 .355 r
F
.4384 .62561 m .42761 .62675 L .42983 .63146 L F
0 g
.43808 .63374 m
.44074 .63035 L
s
.4384 .62561 m .42901 .61995 L .42761 .62675 L 0 1 .355 r
F
.4384 .62561 m .43322 .61461 L .42901 .61995 L F
.4384 .62561 m .43741 .6143 L .43322 .61461 L F
0 g
.43741 .6143 m
.43963 .61901 L
s
.4384 .62561 m
.44074 .63035 L
s
.43741 .6143 m
.44172 .60898 L
s
.51316 .68035 m .52042 .65808 L .51805 .66458 L 0 1 .353 r
F
0 g
.52042 .65808 m
.5205 .65771 L
s
.53912 1.00805 m .54644 1.02016 L .54579 1.01767 L 0 0 .146 r
F
0 g
.54595 1.01957 m
.54644 1.02016 L
s
.5378 1.00139 m .53912 1.00805 L .54481 1.0134 L 0 .184 .202 r
F
0 g
.53912 1.00805 m
.54412 1.01275 L
s
.53912 1.00805 m
.54579 1.01767 L
s
.48139 .75733 m .47861 .7663 L .48103 .76181 L 0 1 .441 r
F
.48644 .76079 m .48103 .76181 L .47861 .7663 L 0 1 .439 r
F
0 g
.47861 .7663 m
.47865 .77087 L
s
.47507 .76836 m
.47861 .7663 L
s
.31146 .94416 m .29305 .94605 L .29577 .94735 L 0 1 .327 r
F
.31146 .94416 m .29666 .94479 L .29305 .94605 L F
.31146 .94416 m .30457 .94399 L .29666 .94479 L F
.31998 .94052 m .30457 .94399 L .31146 .94416 L 0 1 .289 r
F
0 g
.31146 .94416 m
.3191 .94314 L
s
.31146 .94416 m
.31413 .94547 L
s
.62734 .47062 m
.62858 .47896 L
s
.62858 .47896 m
.62871 .47984 L
s
.62871 .47984 m
.62883 .48066 L
s
.62883 .48066 m
.62915 .48281 L
s
.62915 .48281 m
.63089 .49457 L
s
.63396 .51525 m
.63399 .51549 L
s
.626 .47159 m
.62734 .47062 L
s
.62592 .47165 m
.626 .47159 L
s
.62586 .47169 m
.62592 .47165 L
s
.62574 .47178 m
.62586 .47169 L
s
.43426 .92865 m .41969 .93342 L .42296 .93422 L 0 1 .44 r
F
0 g
.41643 .93616 m
.42296 .93422 L
s
.38148 .78496 m .36983 .78592 L .3692 .78793 L 0 1 .44 r
F
.38148 .78496 m .37369 .78443 L .36983 .78592 L F
.38148 .78496 m .37869 .78402 L .37369 .78443 L F
0 g
.38083 .78696 m
.38148 .78496 L
s
.39119 .78042 m .37869 .78402 L .38148 .78496 L 0 1 .409 r
F
0 g
.38148 .78496 m
.38632 .78425 L
s
.51316 .68036 m .52444 .67013 L .52102 .67268 L 0 1 .363 r
F
.51316 .68036 m .5245 .67112 L .52444 .67013 L F
0 g
.52444 .67013 m
.52446 .67011 L
s
.36273 .98276 m .34434 .97809 L .34798 .98246 L 0 1 .538 r
F
0 g
.33983 .98034 m
.34798 .98246 L
s
.38844 .98793 m .373 .983 L .37033 .98464 L 0 1 .539 r
F
.38844 .98793 m .38076 .9844 L .373 .983 L F
0 g
.38844 .98793 m
.39247 .99192 L
s
.39584 .98259 m .38844 .98792 L .3963 .98892 L 0 1 .539 r
F
.39584 .98259 m .38076 .9844 L .38844 .98792 L F
.4676 .67832 m .45951 .67144 L .45612 .67614 L 0 1 .33 r
F
0 g
.45678 .67524 m
.45951 .67144 L
s
.45621 .66801 m
.45951 .67144 L
s
.38555 .75844 m .37994 .76669 L .38397 .76498 L 0 1 .419 r
F
.38555 .75844 m .37536 .76258 L .37994 .76669 L F
0 g
.37892 .77328 m
.37994 .76669 L
s
.51316 .68036 m .50523 .67151 L .50976 .67656 L 0 .749 .286 r
F
.51316 .68036 m .50976 .67656 L .50523 .67151 L 0 .742 .286 r
F
0 g
.50523 .67151 m
.50523 .67151 L
s
.5019 .66636 m
.50523 .67151 L
s
.4238 .79751 m .4199 .80671 L .42335 .80415 L 0 .989 .402 r
F
.43156 .81306 m .42335 .80415 L .4199 .80671 L 0 .941 .402 r
F
0 g
.4199 .80671 m
.41996 .8134 L
s
.41496 .80377 m
.4199 .80671 L
s
.48139 .75733 m .47311 .76214 L .47275 .76662 L 0 1 .441 r
F
0 g
.46892 .76824 m
.47275 .76662 L
s
.28548 .78459 m .28002 .79113 L .28428 .79005 L 0 1 .524 r
F
.28548 .78459 m .27473 .78708 L .28002 .79113 L F
0 g
.27966 .79666 m
.28002 .79113 L
s
.28428 .79005 m
.29016 .79378 L
s
.4752 .90387 m .46985 .89774 L .46472 .89516 L 0 .685 .415 r
F
.78382 .93559 m .77883 .94537 L .78674 .94291 L 0 1 .534 r
F
.78382 .93559 m .7751 .94408 L .77883 .94537 L F
0 g
.77569 .9496 m
.77883 .94537 L
s
.40743 .7875 m .40472 .78091 L .39982 .77745 L 0 1 .411 r
F
0 g
.40677 .79406 m
.40743 .7875 L
s
.39996 .77748 m
.4001 .77751 L
s
.4001 .77751 m
.40476 .77855 L
s
.39982 .77745 m
.39996 .77748 L
s
.39982 .77745 m
.39987 .77744 L
s
.41697 .78171 m .40743 .7875 L .41227 .79066 L 0 1 .402 r
F
.41697 .78171 m .40472 .78091 L .40743 .7875 L F
.79275 .69936 m .80182 .69665 L .79725 .69484 L 0 1 .497 r
F
.79275 .69936 m .80411 .70405 L .80182 .69665 L F
.44552 .65571 m .43717 .66179 L .44173 .66089 L 0 1 .35 r
F
0 g
.44592 .66334 m
.44856 .65968 L
s
.44552 .65571 m .43418 .65773 L .43717 .66179 L 0 1 .35 r
F
.44552 .65571 m .43476 .65141 L .43418 .65773 L F
.44552 .65571 m .43856 .64623 L .43476 .65141 L F
0 g
.44552 .65571 m
.44856 .65968 L
s
.51472 .77212 m .51237 .77162 L .51045 .77553 L 0 1 .423 r
F
.51316 .68036 m .52113 .67441 L .5245 .67112 L 0 1 .363 r
F
0 g
.5245 .67112 m
.52796 .66944 L
s
.32007 .76005 m .30916 .74735 L .30776 .75443 L 0 1 .457 r
F
.32007 .76005 m .31328 .74636 L .30916 .74735 L F
.32007 .76005 m .31796 .75181 L .31328 .74636 L F
.33016 .75716 m .31796 .75181 L .32007 .76005 L 0 1 .452 r
F
0 g
.31866 .76712 m
.32007 .76005 L
s
.32007 .76005 m
.32466 .76532 L
s
.48635 .71357 m .48091 .71946 L .48439 .71558 L 0 0 0 r
F
.48635 .71357 m .47743 .72328 L .48091 .71946 L F
0 g
.47928 .72137 m
.48049 .71995 L
s
.48439 .71558 m
.48774 .71168 L
s
.39584 .98259 m .3963 .98892 L .39912 .98673 L 0 1 .539 r
F
.41463 .99004 m .39912 .98673 L .3963 .98892 L 0 1 .54 r
F
0 g
.3963 .98892 m
.40029 .99283 L
s
.38844 .98792 m
.3963 .98892 L
s
.51624 .65753 m .51669 .65737 L .51819 .64967 L 0 1 .343 r
F
0 g
.51741 .65677 m
.51819 .64967 L
s
.51738 .65704 m
.51741 .65677 L
s
.51785 .65694 m
.51786 .65691 L
s
.51786 .65691 m
.5196 .6493 L
s
.32853 .93689 m .32741 .93927 L .33073 .93773 L 0 .936 .253 r
F
0 g
.33073 .93773 m
.33848 .93594 L
s
.32853 .93689 m .31998 .94052 L .32741 .93927 L 0 .936 .253 r
F
0 g
.32741 .93927 m
.33041 .94002 L
s
.51316 .68035 m .51316 .68035 L .51577 .67135 L 0 .726 .282 r
F
.51316 .68035 m .51985 .65768 L .51946 .65748 L 0 1 .353 r
F
.51316 .68035 m .51805 .66458 L .51985 .65768 L F
0 g
.51985 .65768 m
.51997 .6573 L
s
.62714 .42386 m
.63006 .43032 L
s
.62711 .4239 m
.62714 .42386 L
s
.45434 .86622 m .45439 .87571 L .45629 .8729 L 0 .805 .411 r
F
.46601 .88138 m .45629 .8729 L .45439 .87571 L 0 .736 .409 r
F
0 g
.45439 .87571 m
.45683 .88241 L
s
.4493 .87317 m
.45439 .87571 L
s
.52277 .66504 m .52918 .6548 L .52542 .66117 L 0 0 .072 r
F
.52336 .66493 m .52689 .6664 L .53111 .6621 L 0 .641 .273 r
F
.52336 .66493 m .52357 .66761 L .52689 .6664 L F
.51316 .68036 m .52055 .66951 L .51633 .67571 L 0 1 .359 r
F
.51316 .68036 m .51633 .67571 L .52055 .66951 L 0 1 .357 r
F
.51316 .68036 m .51316 .68036 L .51633 .67571 L F
.51316 .68036 m .52357 .66761 L .52336 .66493 L 0 .696 .284 r
F
.52209 .66822 m .52918 .6548 L .53158 .6527 L 0 0 .079 r
F
0 g
.52246 .66353 m
.52302 .6624 L
s
.52209 .66822 m .52542 .66117 L .52918 .6548 L 0 0 .079 r
F
0 g
.52205 .6669 m
.52356 .66428 L
s
.52155 .66539 m
.52246 .66353 L
s
.52307 .66372 m
.52338 .66298 L
s
.52307 .66372 m
.52307 .66372 L
s
.52307 .66372 m
.52307 .66372 L
s
.52305 .66377 m
.52307 .66372 L
s
.52303 .66381 m
.52305 .66377 L
s
.52918 .6548 m
.53077 .65113 L
s
.52918 .6548 m
.53119 .65304 L
s
.63328 .51505 m
.6345 .52331 L
s
.6345 .52331 m
.63465 .52434 L
s
.63631 .53552 m
.63632 .5356 L
s
.6367 .53813 m
.63678 .53869 L
s
.63622 .53493 m
.63631 .53552 L
s
.63473 .52488 m
.63496 .52639 L
s
.63496 .52639 m
.63497 .52649 L
s
.63465 .52434 m
.63473 .52488 L
s
.32896 .97926 m .31 .9729 L .3134 .97777 L 0 1 .537 r
F
.40777 .93942 m .39445 .94072 L .39194 .94241 L 0 1 .477 r
F
.40777 .93942 m .40124 .93944 L .39445 .94072 L F
.41344 .93493 m .40124 .93944 L .40777 .93942 L 0 1 .455 r
F
0 g
.40777 .93942 m
.41427 .93802 L
s
.40777 .93942 m
.41103 .94085 L
s
.49685 .70039 m .4931 .70547 L .48962 .70958 L 0 0 0 r
F
.49685 .70039 m .4962 .70153 L .4931 .70547 L F
.505 .69026 m .4962 .70153 L .49685 .70039 L 0 0 .016 r
F
0 g
.49497 .70249 m
.49685 .70039 L
s
.49685 .70039 m
.49971 .69658 L
s
.50403 .69034 m
.50585 .68833 L
s
.49962 .98799 m .49886 .99273 L .50482 .99101 L 0 1 .537 r
F
.49962 .98799 m .49108 .99314 L .49886 .99273 L F
0 g
.49886 .99273 m
.50455 .99407 L
s
.50866 .49981 m .5171 .47458 L .51726 .47221 L 0 .887 .118 r
F
.50866 .49981 m .51342 .48638 L .5171 .47458 L F
0 g
.5171 .47458 m
.52052 .4647 L
s
.51493 .48154 m
.5171 .47458 L
s
.43156 .81306 m .4285 .82248 L .43163 .81975 L 0 .941 .402 r
F
.44018 .82837 m .43163 .81975 L .4285 .82248 L 0 .89 .402 r
F
0 g
.4285 .82248 m
.42908 .82921 L
s
.4235 .81976 m
.4285 .82248 L
s
.51316 .68035 m .51316 .68035 L .51041 .67001 L 0 .748 .288 r
F
0 g
.5223 .78759 m
.52298 .78572 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.49176 .76389 m .4896 .76269 L .48648 .76536 L 0 1 .436 r
F
.50587 .68831 m .50551 .6891 L .50287 .69265 L 0 0 .008 r
F
.51316 .68036 m .50587 .68831 L .50824 .68551 L 0 0 .051 r
F
.51316 .68036 m .50551 .6891 L .50587 .68831 L F
0 g
.50585 .68833 m
.50587 .68831 L
s
.44956 .84347 m .43907 .84478 L .44329 .85094 L 0 .835 .401 r
F
.44956 .84347 m .43798 .838 L .43907 .84478 L F
0 g
.43907 .84478 m
.43907 .84478 L
s
.51316 .68036 m .51316 .68036 L .51231 .67991 L 0 0 .029 r
F
.51316 .68036 m .50176 .67372 L .50177 .67557 L 0 .733 .285 r
F
.51316 .68036 m .50517 .67474 L .50176 .67372 L F
0 g
.49832 .67134 m
.50176 .67372 L
s
.50227 .67387 m
.50517 .67474 L
s
.50176 .67372 m
.50227 .67387 L
s
.78256 .90593 m .79424 .90006 L .79032 .89988 L 0 1 .521 r
F
.77292 .90556 m .78256 .90593 L .78443 .89969 L 0 1 .52 r
F
.4506 .76232 m .44604 .76962 L .44951 .76647 L 0 1 .467 r
F
.4506 .76232 m .44171 .77001 L .44604 .76962 L F
.45609 .76806 m .44951 .76647 L .44604 .76962 L 0 1 .465 r
F
0 g
.44495 .76972 m
.44604 .76962 L
s
.44539 .77385 m
.44604 .76962 L
s
.30224 .96971 m .30172 .97626 L .30503 .97491 L 0 1 .537 r
F
.30224 .96971 m .29375 .97294 L .30172 .97626 L F
0 g
.30172 .97626 m
.30538 .98128 L
s
.51316 .68036 m .52336 .66493 L .52019 .66814 L 0 .696 .284 r
F
.51316 .68036 m .52302 .66383 L .52277 .66504 L 0 0 .047 r
F
.51316 .68036 m .52019 .66814 L .51618 .67512 L 0 .696 .284 r
F
.51316 .68036 m .52019 .66814 L .52302 .66383 L 0 0 .047 r
F
0 g
.52083 .66685 m
.52155 .66539 L
s
.52101 .66657 m
.52115 .6663 L
s
.52047 .66762 m
.52057 .66742 L
s
.52057 .66742 m
.52057 .66742 L
s
.52057 .66742 m
.52057 .66742 L
s
.52057 .66741 m
.52057 .66741 L
s
.52057 .66741 m
.52057 .66741 L
s
.52057 .66741 m
.52101 .66657 L
s
.52101 .66657 m
.52101 .66657 L
s
.52057 .66742 m
.52057 .66741 L
s
.52072 .66707 m
.52083 .66685 L
s
.52072 .66707 m
.52072 .66707 L
s
.52072 .66707 m
.52072 .66707 L
s
.52057 .66502 m
.52058 .66502 L
s
.52058 .66502 m
.52058 .66502 L
s
.5202 .66814 m
.52022 .66808 L
s
.52022 .66808 m
.52033 .66786 L
s
.52033 .66786 m
.52033 .66786 L
s
.52033 .66786 m
.52033 .66786 L
s
.52033 .66786 m
.52072 .66707 L
s
.52029 .66796 m
.52031 .66792 L
s
.52031 .66792 m
.52037 .66781 L
s
.52037 .66781 m
.52047 .66762 L
s
.52037 .66781 m
.52037 .66781 L
s
.52031 .66792 m
.52031 .66792 L
s
.52031 .66792 m
.52031 .66792 L
s
.52029 .66796 m
.52029 .66796 L
s
.52029 .66796 m
.52029 .66796 L
s
.52027 .668 m
.52027 .668 L
s
.52027 .668 m
.52029 .66796 L
s
.52027 .668 m
.52027 .668 L
s
.5204 .66583 m
.52041 .66583 L
s
.52041 .66583 m
.52041 .66583 L
s
.51976 .66694 m
.52057 .66502 L
s
.51976 .66695 m
.5204 .66583 L
s
.52084 .67102 m
.52111 .67062 L
s
.52058 .66502 m
.52216 .66126 L
s
.52041 .66583 m
.52276 .66173 L
s
.52302 .66383 m
.52303 .66381 L
s
.5202 .66814 m
.52172 .6658 L
s
.52172 .6658 m
.52298 .66388 L
s
.52298 .66388 m
.52302 .66383 L
s
.51316 .68035 m .51946 .65748 L .51737 .66423 L 0 1 .353 r
F
0 g
.51923 .65823 m
.51946 .65748 L
s
.51926 .66594 m
.52162 .65944 L
s
.51926 .66595 m
.52208 .66021 L
s
.51946 .65748 m
.51951 .6572 L
s
.39989 .7775 m
.40472 .78091 L
s
.39982 .77745 m
.39989 .7775 L
s
.51316 .68036 m .52456 .67264 L .52113 .67441 L 0 1 .364 r
F
0 g
.5246 .67519 m
.528 .67311 L
s
.51316 .68036 m .52457 .67367 L .52456 .67264 L 0 1 .364 r
F
0 g
.52456 .67264 m
.52459 .67261 L
s
.52453 .67265 m
.52456 .67264 L
s
.52195 .66635 m
.52336 .66493 L
s
.52336 .66493 m
.52385 .66347 L
s
.52464 .67777 m
.52464 .67777 L
s
.5246 .67778 m
.52464 .67777 L
s
.52455 .67522 m .52452 .67627 L .52789 .67679 L 0 1 .347 r
F
0 g
.52459 .67628 m
.52789 .67679 L
s
.52464 .67777 m
.52789 .67679 L
s
.45609 .76806 m .45382 .7658 L .44951 .76647 L 0 1 .465 r
F
.4642 .75912 m .45609 .76806 L .46015 .76701 L 0 1 .455 r
F
.4642 .75912 m .45382 .7658 L .45609 .76806 L F
0 g
.45543 .77229 m
.45609 .76806 L
s
.45609 .76806 m
.45931 .76723 L
s
.54695 .68278 m
.54695 .68278 L
s
.77982 .77445 m .77834 .7797 L .78278 .78305 L 0 .419 .329 r
F
.77982 .77445 m .77707 .77602 L .77834 .7797 L F
0 g
.77218 .77932 m
.77834 .7797 L
s
.75151 .56763 m .75836 .57867 L .7538 .57505 L 0 .328 .044 r
F
.75151 .56763 m .76296 .57766 L .75836 .57867 L F
.46048 .99084 m .44492 .99167 L .44978 .9942 L 0 1 .542 r
F
0 g
.44281 .9945 m
.44978 .9942 L
s
.4642 .75912 m .46015 .76701 L .4633 .76336 L 0 1 .455 r
F
.46941 .76391 m .4633 .76336 L .46015 .76701 L 0 1 .453 r
F
0 g
.45966 .77134 m
.46015 .76701 L
s
.45931 .76723 m
.46015 .76701 L
s
.37875 .94732 m .36415 .94726 L .36044 .94927 L 0 1 .497 r
F
.37875 .94732 m .37201 .94642 L .36415 .94726 L F
0 g
.37875 .94732 m
.38134 .94971 L
s
.38526 .94317 m .37201 .94642 L .37875 .94732 L 0 1 .484 r
F
0 g
.37875 .94732 m
.38567 .9467 L
s
.23618 .75569 m .23 .76472 L .23438 .76382 L 0 1 .485 r
F
.23618 .75569 m .22514 .75778 L .23 .76472 L F
0 g
.22918 .77288 m
.23 .76472 L
s
.23438 .76382 m
.24002 .77047 L
s
.49062 .68245 m .48699 .67755 L .48244 .67833 L 0 .858 .307 r
F
.49062 .68245 m .4905 .67931 L .48699 .67755 L F
0 g
.48699 .67755 m
.48857 .67616 L
s
.53519 .68385 m .54318 .6874 L .53872 .6844 L 0 .923 .333 r
F
.53519 .68385 m .54622 .6923 L .54318 .6874 L F
.53519 .68385 m .54583 .69582 L .54622 .6923 L F
.53519 .68385 m .54229 .69526 L .54583 .69582 L F
.53519 .68385 m .53797 .691 L .54229 .69526 L F
.53519 .68385 m .53492 .68611 L .53797 .691 L F
0 g
.53551 .68036 m
.53872 .6844 L
s
.52418 .68044 m .53519 .68385 L .53206 .68141 L 0 1 .347 r
F
.52418 .68044 m .53492 .68611 L .53519 .68385 L F
0 g
.53283 .68117 m
.53551 .68036 L
s
.53519 .68385 m
.53872 .6844 L
s
.51316 .68036 m .52116 .67621 L .52457 .67367 L 0 1 .364 r
F
0 g
.52456 .67367 m
.52457 .67367 L
s
.5246 .67519 m
.5246 .67519 L
s
.52459 .67628 m
.52459 .67628 L
s
.5246 .67778 m
.5246 .67778 L
s
.52457 .67367 m
.528 .67311 L
s
.51805 .97623 m
.51999 .97854 L
s
.51999 .97854 m
.52152 .98036 L
s
.52152 .98036 m
.52196 .98088 L
s
.52196 .98088 m
.52329 .98246 L
s
.52373 .98298 m
.52376 .98302 L
s
.51805 .97623 m
.52061 .97795 L
s
.52061 .97795 m
.52267 .97933 L
s
.401 .77094 m .39001 .76235 L .38883 .76886 L 0 1 .411 r
F
0 g
.38397 .76498 m
.38883 .76886 L
s
.35035 .75108 m .34465 .75909 L .34865 .7578 L 0 1 .441 r
F
.35035 .75108 m .34025 .75417 L .34465 .75909 L F
0 g
.34358 .76586 m
.34465 .75909 L
s
.34865 .7578 m
.35346 .7625 L
s
.52718 .79272 m
.528 .7903 L
s
.52418 .68044 m .53206 .68141 L .52761 .68041 L 0 1 .347 r
F
.52443 .67784 m .52761 .68041 L .53206 .68141 L F
0 g
.53206 .68141 m
.53283 .68117 L
s
.53206 .68141 m
.53519 .68385 L
s
.50505 .75421 m .50073 .76802 L .50303 .76889 L 0 1 .419 r
F
.50505 .75421 m .49984 .7631 L .50073 .76802 L F
0 g
.49815 .7713 m
.50073 .76802 L
s
.51316 .68035 m .51316 .68035 L .51553 .66967 L 0 .728 .282 r
F
.53647 .99468 m .53 .99285 L .5378 1.00139 L 0 .286 .291 r
F
0 g
.52899 .99153 m
.53 .99285 L
s
.52705 .99008 m
.53 .99285 L
s
.51564 .63663 m
.51663 .6307 L
s
.45259 .51042 m .44488 .51906 L .44752 .51786 L 0 1 .204 r
F
.45259 .51042 m .44631 .51361 L .44488 .51906 L F
0 g
.44906 .5197 m
.45146 .51633 L
s
.45259 .51042 m .45085 .50514 L .44631 .51361 L 0 1 .204 r
F
.45259 .51042 m .45592 .49771 L .45085 .50514 L F
0 g
.45146 .51633 m
.45259 .51042 L
s
.50047 .75254 m .49731 .7666 L .49984 .7631 L 0 1 .423 r
F
.50047 .75254 m .49507 .76556 L .49731 .7666 L F
0 g
.49731 .7666 m
.49815 .7713 L
s
.49062 .68245 m .48244 .67833 L .47916 .68196 L 0 .858 .307 r
F
0 g
.479 .67582 m
.48244 .67833 L
s
.54766 1.025 m
.54779 1.02554 L
s
.54644 1.02017 m
.54766 1.025 L
s
.50505 .75421 m .50303 .76889 L .50526 .76508 L 0 1 .419 r
F
0 g
.50303 .76889 m
.50426 .77364 L
s
.44171 .77001 m .43486 .76746 L .43111 .77016 L 0 1 .475 r
F
.44171 .77001 m .43941 .76739 L .43486 .76746 L F
.4506 .76232 m .43941 .76739 L .44171 .77001 L 0 1 .467 r
F
0 g
.44085 .77419 m
.44171 .77001 L
s
.44171 .77001 m
.44495 .76972 L
s
.24192 .80849 m .23701 .81368 L .24125 .81275 L 0 1 .536 r
F
.24192 .80849 m .2312 .81057 L .23701 .81368 L F
0 g
.23701 .81368 m
.23732 .818 L
s
.24165 .81292 m
.24778 .81548 L
s
.24125 .81275 m
.24165 .81292 L
s
.51316 .68035 m .51886 .65727 L .51844 .6572 L 0 1 .353 r
F
0 g
.51687 .65648 m
.51819 .64967 L
s
.51316 .68035 m .51737 .66423 L .51886 .65727 L 0 1 .353 r
F
0 g
.51886 .65727 m
.51894 .65698 L
s
.51868 .66516 m
.52078 .65841 L
s
.51877 .65771 m
.51886 .65727 L
s
.51849 .659 m
.51877 .65771 L
s
.41697 .78171 m .41227 .79066 L .41601 .78829 L 0 1 .402 r
F
.4238 .79751 m .41601 .78829 L .41227 .79066 L 0 .989 .402 r
F
0 g
.41182 .79729 m
.41227 .79066 L
s
.40743 .7875 m
.41227 .79066 L
s
.50047 .75254 m .49457 .7607 L .49507 .76556 L 0 1 .423 r
F
0 g
.4922 .76853 m
.49507 .76556 L
s
.49993 .76358 m
.50073 .76802 L
s
.41697 .78171 m .40568 .77433 L .40472 .78091 L 0 1 .402 r
F
0 g
.40476 .77854 m
.40565 .77447 L
s
.37535 .76258 m .36467 .75243 L .36336 .75901 L 0 1 .427 r
F
.37535 .76258 m .36868 .75104 L .36467 .75243 L F
.37535 .76258 m .37326 .75539 L .36868 .75104 L F
0 g
.37403 .76916 m
.37535 .76258 L
s
.38555 .75844 m .37326 .75539 L .37536 .76258 L 0 1 .419 r
F
0 g
.37536 .76258 m
.37994 .76669 L
s
.51316 .68036 m .52455 .67522 L .52116 .67621 L 0 1 .364 r
F
.51316 .68036 m .52452 .67627 L .52455 .67522 L F
0 g
.52455 .67522 m
.5246 .67519 L
s
.4676 .67832 m .45966 .68446 L .46422 .68303 L 0 1 .33 r
F
.4676 .67832 m .45619 .68151 L .45966 .68446 L F
.4676 .67832 m .45612 .67614 L .45619 .68151 L F
.50177 .67557 m .49382 .67696 L .49837 .67696 L 0 .811 .296 r
F
.50189 .68017 m .49382 .67696 L .4905 .67931 L 0 .793 .296 r
F
.50189 .68017 m .49837 .67696 L .49382 .67696 L F
0 g
.49039 .67458 m
.49382 .67696 L
s
.51316 .68035 m .51316 .68035 L .51021 .67124 L 0 .753 .288 r
F
.25769 .96369 m .25664 .97072 L .26022 .96954 L 0 1 .536 r
F
0 g
.26022 .96954 m
.26213 .97036 L
s
.25769 .96369 m .24854 .9665 L .25664 .97072 L 0 1 .536 r
F
0 g
.25664 .97072 m
.26016 .97638 L
s
.50971 .75545 m .50651 .77005 L .50885 .77074 L 0 1 .416 r
F
.50971 .75545 m .50526 .76508 L .50651 .77005 L F
0 g
.50426 .77364 m
.50651 .77005 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.44183 .54974 m .44513 .53635 L .44213 .53706 L 0 1 .324 r
F
0 g
.44513 .53635 m
.44998 .52952 L
s
.44501 .54178 m
.44513 .53635 L
s
.51316 .68035 m .51844 .6572 L .51664 .6641 L 0 1 .353 r
F
0 g
.51783 .65956 m
.51837 .65746 L
s
.51837 .65746 m
.51843 .65724 L
s
.51843 .65724 m
.51844 .6572 L
s
.51805 .66458 m
.51985 .65768 L
s
.51844 .6572 m
.51848 .65698 L
s
.32896 .97926 m .31331 .97155 L .31 .9729 L 0 1 .537 r
F
0 g
.30503 .97491 m
.30768 .97582 L
s
.32896 .97926 m .32145 .97429 L .31331 .97155 L 0 1 .537 r
F
0 g
.30768 .97582 m
.3134 .97777 L
s
.3367 .97562 m .32145 .97429 L .32896 .97926 L 0 1 .537 r
F
0 g
.32896 .97926 m
.33683 .98185 L
s
.32896 .97926 m
.33234 .98412 L
s
.51316 .68036 m .5211 .67804 L .52452 .67627 L 0 1 .364 r
F
0 g
.52451 .67627 m
.52452 .67627 L
s
.52448 .67782 m
.52448 .67782 L
s
.52448 .67782 m
.5246 .67778 L
s
.52448 .67782 m
.52448 .67782 L
s
.52452 .67627 m
.52459 .67628 L
s
.49603 .75047 m .49176 .76389 L .49457 .7607 L 0 1 .425 r
F
.49603 .75047 m .4896 .76269 L .49176 .76389 L F
0 g
.49176 .76389 m
.4922 .76853 L
s
.47934 .68603 m .47561 .67983 L .47105 .68104 L 0 .916 .319 r
F
.47934 .68603 m .47916 .68196 L .47561 .67983 L F
0 g
.47561 .67983 m
.479 .67582 L
s
.50675 .88335 m
.50742 .88275 L
s
.75746 .94269 m .76951 .94212 L .76577 .9408 L 0 1 .537 r
F
.74832 .93911 m .75746 .94269 L .76016 .9388 L 0 1 .535 r
F
.39124 .77809 m .37978 .77439 L .3788 .77865 L 0 1 .503 r
F
.39124 .77809 m .38381 .77272 L .37978 .77439 L F
.39124 .77809 m .38872 .7743 L .38381 .77272 L F
.40096 .7733 m .38872 .7743 L .39124 .77809 L 0 1 .498 r
F
0 g
.39124 .77809 m
.39423 .77893 L
s
.39066 .78057 m
.39124 .77809 L
s
.5236 .77332 m .52481 .78872 L .52568 .78884 L 0 1 .414 r
F
0 g
.52477 .79049 m
.52481 .78872 L
s
.52418 .68044 m .53149 .68613 L .53492 .68611 L 0 1 .347 r
F
.50971 .75545 m .50885 .77074 L .51076 .76662 L 0 1 .416 r
F
0 g
.50885 .77074 m
.51045 .77553 L
s
.51316 .68036 m .50177 .67557 L .50519 .67797 L 0 .733 .285 r
F
0 g
.50177 .67557 m
.5033 .67664 L
s
.50177 .67557 m
.50177 .67557 L
s
.46601 .88138 m .46198 .88855 L .46696 .89098 L 0 .736 .409 r
F
0 g
.46198 .88855 m
.46472 .89516 L
s
.44956 .84347 m .44329 .85094 L .44825 .8533 L 0 .835 .401 r
F
.51316 .68036 m .52019 .66814 L .51618 .67512 L 0 0 .045 r
F
0 g
.52019 .66814 m
.52027 .668 L
s
.51316 .68036 m .51618 .67512 L .52019 .66814 L 0 1 .356 r
F
0 g
.52019 .66814 m
.5202 .66814 L
s
.51316 .68036 m .52019 .66814 L .51618 .67512 L 0 1 .357 r
F
.51316 .68036 m .51618 .67512 L .52019 .66814 L 0 0 .047 r
F
0 g
.52019 .66814 m
.5202 .66814 L
s
.51316 .68036 m .51976 .66695 L .51599 .67461 L 0 1 .356 r
F
.51316 .68036 m .51599 .67461 L .51976 .66695 L 0 1 .354 r
F
0 g
.51976 .66695 m
.51976 .66694 L
s
.51976 .66695 m
.51976 .66695 L
s
.43604 .59207 m .42748 .59815 L .43147 .59775 L 0 1 .355 r
F
.43604 .59207 m .42624 .59302 L .42748 .59815 L F
0 g
.43483 .60059 m
.43746 .59735 L
s
.43604 .59207 m .4286 .58579 L .42624 .59302 L 0 1 .355 r
F
.43604 .59207 m .43318 .58011 L .4286 .58579 L F
.43604 .59207 m .43692 .57978 L .43318 .58011 L F
0 g
.43604 .59207 m
.43746 .59735 L
s
.43692 .57978 m
.44153 .57397 L
s
.43692 .57978 m
.43814 .58491 L
s
.52443 .67784 m .52434 .67888 L .52761 .68041 L 0 1 .347 r
F
0 g
.52443 .67892 m
.52443 .67892 L
s
.52443 .67892 m
.52443 .67892 L
s
.52443 .67892 m
.52456 .67898 L
s
.52456 .67898 m
.52456 .67898 L
s
.52456 .67898 m
.52456 .67898 L
s
.52456 .67898 m
.52459 .679 L
s
.52459 .679 m
.52459 .679 L
s
.52459 .679 m
.52761 .68041 L
s
.44183 .54974 m .43358 .55681 L .43694 .55619 L 0 1 .324 r
F
.44183 .54974 m .4337 .55137 L .43358 .55681 L F
0 g
.43928 .55719 m
.44196 .55551 L
s
.44183 .54974 m .43723 .5435 L .4337 .55137 L 0 1 .324 r
F
.44183 .54974 m .44213 .53706 L .43723 .5435 L F
0 g
.44183 .54974 m
.44196 .55551 L
s
.43694 .55619 m
.44183 .54974 L
s
.43625 .75779 m .42567 .76291 L .42439 .76459 L 0 1 .25 r
F
.43625 .75779 m .42968 .76044 L .42567 .76291 L F
.43625 .75779 m .43421 .75825 L .42968 .76044 L F
.44583 .75077 m .43421 .75825 L .43625 .75779 L 0 .946 .221 r
F
0 g
.43625 .75779 m
.44059 .7553 L
s
.43496 .75948 m
.43625 .75779 L
s
.52384 .67167 m .53111 .6621 L .52689 .6664 L 0 .602 .272 r
F
.52384 .67167 m .53452 .66416 L .53111 .6621 L F
0 g
.53111 .6621 m
.53395 .65367 L
s
.52083 .67103 m
.52419 .66774 L
s
.52104 .67267 m
.52444 .67013 L
s
.52105 .67265 m
.52431 .66868 L
s
.51316 .68036 m .51926 .66595 L .51578 .67418 L 0 1 .354 r
F
.51316 .68035 m .51578 .67418 L .51926 .66595 L 0 1 .353 r
F
0 g
.51926 .66595 m
.51926 .66594 L
s
.51926 .66595 m
.51926 .66595 L
s
.52058 .77301 m .51824 .77271 L .51668 .77695 L 0 1 .419 r
F
0 g
.51616 .77567 m
.51668 .77695 L
s
.36538 .77621 m .36039 .78203 L .36423 .78056 L 0 1 .511 r
F
.36538 .77621 m .35563 .77971 L .36039 .78203 L F
0 g
.35985 .78647 m
.36039 .78203 L
s
.36423 .78056 m
.36932 .78263 L
s
.51316 .68036 m .52443 .67784 L .5211 .67804 L 0 1 .364 r
F
.51316 .68036 m .52434 .67888 L .52443 .67784 L F
0 g
.52443 .67784 m
.52448 .67782 L
s
.51316 .68036 m .50762 .6869 L .50551 .6891 L 0 0 .051 r
F
0 g
.50287 .69265 m
.50551 .6891 L
s
.50587 .68831 m
.50824 .68552 L
s
.50643 .68709 m
.50823 .68552 L
s
.49603 .75047 m .48949 .75791 L .4896 .76269 L 0 1 .425 r
F
0 g
.48648 .76536 m
.4896 .76269 L
s
.49459 .76096 m
.49507 .76556 L
s
.51316 .68035 m .5178 .65717 L .51736 .65722 L 0 1 .355 r
F
.51316 .68035 m .51664 .6641 L .5178 .65717 L F
0 g
.5178 .65717 m
.51785 .65694 L
s
.51756 .66056 m
.51783 .65956 L
s
.51737 .66423 m
.51849 .659 L
s
.51672 .65721 m
.51687 .65648 L
s
.51736 .65722 m
.51738 .65704 L
s
.51779 .65727 m
.5178 .65717 L
s
.51775 .6575 m
.51779 .65727 L
s
.5177 .65779 m
.51775 .6575 L
s
.5176 .65835 m
.5177 .65779 L
s
.51748 .65907 m
.5176 .65835 L
s
.50189 .68017 m .50183 .67833 L .49837 .67696 L 0 .793 .296 r
F
0 g
.50177 .67831 m
.50177 .67831 L
s
.50177 .67831 m
.50177 .67831 L
s
.50143 .67818 m
.50177 .67831 L
s
.49837 .67696 m
.50143 .67818 L
s
.49837 .67696 m
.50177 .67557 L
s
.45619 .68151 m .45264 .67296 L .44806 .67408 L 0 1 .342 r
F
.45619 .68151 m .45612 .67614 L .45264 .67296 L F
0 g
.45264 .67296 m
.45621 .66801 L
s
.45612 .67614 m
.45678 .67524 L
s
.45264 .67296 m
.45612 .67614 L
s
.46941 .76391 m .46727 .76203 L .4633 .76336 L 0 1 .453 r
F
.47667 .75352 m .46941 .76391 L .47311 .76214 L 0 1 .443 r
F
.47667 .75352 m .46727 .76203 L .46941 .76391 L F
0 g
.46892 .76824 m
.46941 .76391 L
s
.46941 .76391 m
.47263 .76237 L
s
.43588 .64183 m .43679 .63539 L .4342 .63094 L 0 1 .359 r
F
0 g
.43679 .63539 m
.43808 .63374 L
s
.51316 .68036 m .50824 .68551 L .51105 .68257 L 0 0 .051 r
F
.51316 .68036 m .51105 .68257 L .50824 .68551 L 0 0 .047 r
F
0 g
.50824 .68552 m
.50824 .68551 L
s
.50823 .68552 m
.50824 .68551 L
s
.50189 .68017 m .4905 .67931 L .49062 .68245 L 0 .793 .296 r
F
0 g
.4905 .67931 m
.49382 .67696 L
s
.48699 .67755 m
.4905 .67931 L
s
.51316 .68036 m .52083 .67103 L .51645 .67636 L 0 1 .361 r
F
.51316 .68036 m .51645 .67636 L .52083 .67103 L 0 1 .359 r
F
0 g
.52083 .67103 m
.52083 .67103 L
s
.52083 .67103 m
.52084 .67102 L
s
.51508 .65812 m .51555 .65785 L .51672 .65049 L 0 1 .347 r
F
0 g
.51613 .6542 m
.51672 .65049 L
s
.51643 .65477 m
.51672 .65049 L
s
.51628 .65698 m
.51643 .65477 L
s
.5236 .77332 m .52568 .78884 L .52567 .78426 L 0 1 .414 r
F
0 g
.52567 .78426 m
.52568 .78884 L
s
.52568 .78884 m
.52589 .78956 L
s
.52397 .78541 m
.52481 .78872 L
s
.33016 .75716 m .31946 .74485 L .31796 .75181 L 0 1 .452 r
F
.33016 .75716 m .32358 .74382 L .31946 .74485 L F
.33016 .75716 m .32817 .7491 L .32358 .74382 L F
.34025 .75417 m .32817 .7491 L .33016 .75716 L 0 1 .447 r
F
0 g
.32865 .7641 m
.33016 .75716 L
s
.33016 .75716 m
.33465 .76225 L
s
.52337 .40838 m .51873 .42248 L .51858 .41752 L 0 .172 .097 r
F
.52337 .40838 m .52411 .42195 L .51873 .42248 L F
.52337 .40838 m .53112 .41628 L .52411 .42195 L F
.52337 .40838 m .53589 .40713 L .53112 .41628 L F
0 g
.51835 .40977 m
.52337 .40838 L
s
.45542 .74324 m .44997 .74797 L .45373 .74489 L 0 .886 .191 r
F
.45542 .74324 m .44583 .75077 L .44997 .74797 L F
0 g
.44869 .74967 m
.44997 .74797 L
s
.45373 .74489 m
.45787 .74185 L
s
.36965 .97877 m .37033 .98464 L .373 .983 L 0 1 .538 r
F
.36965 .97877 m .36273 .98276 L .37033 .98464 L F
0 g
.37033 .98464 m
.37438 .98864 L
s
.51316 .68035 m .51316 .68035 L .51005 .67252 L 0 .755 .288 r
F
.51316 .68035 m .51868 .66516 L .51553 .67384 L 0 1 .353 r
F
.51316 .68035 m .51553 .67384 L .51868 .66516 L F
0 g
.51868 .66516 m
.52129 .65899 L
s
.51868 .66516 m
.51868 .66516 L
s
.44018 .82837 m .43798 .838 L .44076 .83511 L 0 .89 .402 r
F
.44956 .84347 m .44076 .83511 L .43798 .838 L 0 .835 .401 r
F
0 g
.43798 .838 m
.43907 .84478 L
s
.43298 .83547 m
.43798 .838 L
s
.51316 .68036 m .50517 .67474 L .50973 .67795 L 0 .742 .286 r
F
.51316 .68036 m .50973 .67795 L .50517 .67474 L 0 .733 .285 r
F
0 g
.50177 .67095 m
.50517 .67474 L
s
.50517 .67474 m
.50517 .67474 L
s
.47934 .68603 m .47105 .68104 L .46782 .68551 L 0 .916 .319 r
F
0 g
.4676 .67832 m
.47105 .68104 L
s
.49962 .98799 m .4857 .992 L .49108 .99314 L 0 1 .537 r
F
0 g
.48481 .99503 m
.49108 .99314 L
s
.48644 .76079 m .48438 .75945 L .48103 .76181 L 0 1 .439 r
F
0 g
.48103 .76181 m
.48106 .76143 L
s
.48106 .76143 m
.48107 .76126 L
s
.51316 .68036 m .52095 .67987 L .52434 .67888 L 0 1 .364 r
F
0 g
.52434 .67888 m
.52443 .67892 L
s
.24722 .75357 m .24096 .76246 L .24535 .76154 L 0 1 .482 r
F
.24722 .75357 m .23618 .75569 L .24096 .76246 L F
0 g
.24002 .77047 m
.24096 .76246 L
s
.24535 .76154 m
.25088 .76802 L
s
.44478 .67051 m .44499 .66462 L .44173 .66089 L 0 1 .352 r
F
0 g
.44499 .66462 m
.44592 .66334 L
s
.34496 .95351 m .32701 .95272 L .32996 .95538 L 0 1 .512 r
F
.34496 .95351 m .33034 .9513 L .32701 .95272 L F
.34496 .95351 m .33804 .95163 L .33034 .9513 L F
.35273 .94955 m .33804 .95163 L .34496 .95351 L 0 1 .504 r
F
0 g
.34496 .95351 m
.35239 .95367 L
s
.34496 .95351 m
.34788 .95616 L
s
.50047 .75254 m .49984 .7631 L .50097 .7574 L 0 1 .423 r
F
.50505 .75421 m .50097 .7574 L .49984 .7631 L 0 1 .419 r
F
0 g
.49731 .7666 m
.49984 .7631 L
s
.49984 .7631 m
.49993 .76358 L
s
.25326 .79194 m .24014 .78099 L .23929 .78704 L 0 1 .526 r
F
.25326 .79194 m .24454 .78022 L .24014 .78099 L F
.25326 .79194 m .25016 .78492 L .24454 .78022 L F
.26399 .78953 m .25016 .78492 L .25326 .79194 L 0 1 .525 r
F
0 g
.25239 .79795 m
.25326 .79194 L
s
.25326 .79194 m
.25876 .7964 L
s
.51441 .75625 m .51237 .77162 L .51472 .77212 L 0 1 .412 r
F
.51441 .75625 m .51076 .76662 L .51237 .77162 L F
0 g
.51045 .77553 m
.51237 .77162 L
s
.5482 .69015 m
.54865 .69119 L
s
.5467 .68671 m
.5482 .69015 L
s
.54318 .6874 m
.54345 .68735 L
s
.54345 .68735 m
.5467 .68671 L
s
.51316 .68036 m .52102 .67268 L .51653 .67706 L 0 1 .363 r
F
.51316 .68036 m .51653 .67706 L .52102 .67268 L 0 1 .361 r
F
0 g
.52102 .67268 m
.52104 .67267 L
s
.52102 .67268 m
.52105 .67265 L
s
.51316 .68035 m .51736 .65722 L .51587 .66418 L 0 1 .355 r
F
0 g
.51729 .65757 m
.51733 .65736 L
s
.51733 .65736 m
.51735 .65726 L
s
.51735 .65726 m
.51736 .65722 L
s
.51736 .65722 m
.51736 .65722 L
s
.51672 .65724 m
.51672 .65721 L
s
.51672 .65724 m
.51672 .65724 L
s
.51672 .65724 m
.51672 .65724 L
s
.51316 .68036 m .51316 .68036 L .51198 .68061 L 0 0 .032 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.52123 .86886 m
.52207 .86828 L
s
.77982 .77445 m .78278 .78305 L .78826 .78419 L 0 .419 .329 r
F
0 g
.78278 .78305 m
.78313 .78783 L
s
.47743 .72328 m .4688 .73166 L .47006 .73053 L 0 0 0 r
F
.47464 .72624 m .4688 .73166 L .47257 .72809 L F
.47464 .72624 m .46784 .7325 L .4688 .73166 L F
.46784 .7325 m .46502 .7351 L .4688 .73166 L F
.47006 .73053 m .4688 .73166 L .46706 .73349 L F
.47743 .72328 m .47257 .72809 L .4688 .73166 L F
.47743 .72328 m .47627 .72449 L .47257 .72809 L F
.48635 .71357 m .47627 .72449 L .47743 .72328 L F
0 g
.48034 .72009 m
.48091 .71946 L
s
.47569 .72511 m
.47743 .72328 L
s
.50505 .75421 m .50526 .76508 L .50593 .75913 L 0 1 .419 r
F
.50971 .75545 m .50593 .75913 L .50526 .76508 L 0 1 .416 r
F
0 g
.50526 .76508 m
.50651 .77005 L
s
.50303 .76889 m
.50526 .76508 L
s
.52744 .98587 m
.52764 .98603 L
s
.52565 .98448 m
.52591 .98469 L
s
.52591 .98469 m
.52744 .98587 L
s
.52523 .98416 m
.52545 .98433 L
s
.52545 .98433 m
.52565 .98448 L
s
.52476 .9838 m
.52523 .98416 L
s
.52376 .98302 m
.52476 .9838 L
s
.51316 .68035 m .51805 .66458 L .51526 .67359 L 0 1 .353 r
F
.51316 .68035 m .51526 .67359 L .51805 .66458 L F
0 g
.51805 .66458 m
.52042 .65808 L
s
.51805 .66458 m
.51805 .66458 L
s
.49062 .68245 m .47916 .68196 L .47934 .68603 L 0 .858 .307 r
F
0 g
.47916 .68196 m
.48244 .67833 L
s
.47561 .67983 m
.47916 .68196 L
s
.52381 .68299 m .53149 .68613 L .52718 .68391 L 0 1 .348 r
F
.52381 .68299 m .53446 .68938 L .53149 .68613 L F
.52418 .68044 m .52718 .68391 L .53149 .68613 L 0 1 .347 r
F
0 g
.53149 .68613 m
.53492 .68611 L
s
.47667 .75352 m .47311 .76214 L .47591 .75791 L 0 1 .443 r
F
.48139 .75733 m .47591 .75791 L .47311 .76214 L 0 1 .441 r
F
0 g
.47275 .76662 m
.47311 .76214 L
s
.47263 .76237 m
.47311 .76214 L
s
.48107 .76126 m
.4811 .76088 L
s
.48103 .76181 m
.48188 .76121 L
s
.52058 .77301 m .52361 .78401 L .52288 .77785 L 0 1 .419 r
F
.5236 .77332 m .52288 .77785 L .52361 .78401 L 0 1 .414 r
F
.51508 .65812 m .51583 .64277 L .5152 .65165 L 0 1 .347 r
F
.5139 .65895 m .51583 .64277 L .51559 .63693 L 0 1 .352 r
F
.5139 .65895 m .5152 .65165 L .51583 .64277 L F
0 g
.51572 .65674 m
.51613 .6542 L
s
.51583 .64277 m
.51686 .63626 L
s
.5139 .65895 m .51559 .63693 L .51464 .63802 L 0 1 .352 r
F
0 g
.51559 .63693 m
.51583 .64277 L
s
.51559 .63693 m
.51564 .63663 L
s
.43618 .76338 m .43111 .77016 L .43486 .76746 L 0 1 .477 r
F
.43618 .76338 m .42661 .76996 L .43111 .77016 L F
0 g
.43025 .77434 m
.43111 .77016 L
s
.72074 .92766 m .71607 .93552 L .7235 .93461 L 0 1 .528 r
F
0 g
.72195 .9307 m
.72334 .92983 L
s
.72242 .93188 m
.72334 .92983 L
s
.71323 .93903 m
.71607 .93552 L
s
.43905 .92402 m .44022 .92654 L .44202 .92464 L 0 1 .404 r
F
.43905 .92402 m .43426 .92865 L .44022 .92654 L F
0 g
.44022 .92654 m
.4437 .92685 L
s
.4642 .75912 m .45472 .76156 L .45382 .7658 L 0 1 .455 r
F
0 g
.44951 .76647 m
.45382 .7658 L
s
.72995 .93161 m .73241 .9387 L .73915 .93542 L 0 1 .531 r
F
0 g
.72477 .93987 m
.73241 .9387 L
s
.72998 .94241 m
.73241 .9387 L
s
.52209 .66822 m .52238 .66693 L .52542 .66117 L 0 0 .079 r
F
0 g
.52277 .66504 m
.52304 .66466 L
s
.52304 .66466 m
.52304 .66466 L
s
.52304 .66466 m
.52304 .66466 L
s
.52304 .66466 m
.52431 .6628 L
s
.52431 .6628 m
.52542 .66117 L
s
.34564 .79263 m .34098 .79634 L .34482 .79501 L 0 1 .478 r
F
.34564 .79263 m .33591 .79574 L .34098 .79634 L F
0 g
.34082 .79882 m
.34098 .79634 L
s
.34482 .79501 m
.35027 .79531 L
s
.52418 .68044 m .52405 .68147 L .52718 .68391 L 0 1 .347 r
F
.51316 .68036 m .52418 .68044 L .52095 .67987 L 0 1 .363 r
F
.51316 .68036 m .52405 .68147 L .52418 .68044 L F
0 g
.52418 .68044 m
.52761 .68041 L
s
.51316 .68036 m .52277 .66504 L .51976 .67028 L 0 0 .047 r
F
0 g
.52276 .66507 m
.52277 .66504 L
s
.52277 .66504 m
.52277 .66504 L
s
.52115 .67439 m
.52418 .67144 L
s
.31649 .8017 m .30159 .79916 L .30028 .8024 L 0 1 .512 r
F
.31649 .8017 m .30683 .79792 L .30159 .79916 L F
.31649 .8017 m .31323 .79901 L .30683 .79792 L F
0 g
.31517 .80492 m
.31649 .8017 L
s
.3262 .79876 m .31323 .79901 L .31649 .8017 L 0 1 .503 r
F
0 g
.31649 .8017 m
.32181 .80277 L
s
.51316 .68036 m .52113 .67441 L .51658 .67781 L 0 1 .364 r
F
.51316 .68036 m .51658 .67781 L .52113 .67441 L 0 1 .363 r
F
0 g
.52113 .67441 m
.52115 .67439 L
s
.52113 .67441 m
.52453 .67265 L
s
.49603 .75047 m .49457 .7607 L .49615 .75526 L 0 1 .425 r
F
.50047 .75254 m .49615 .75526 L .49457 .7607 L 0 1 .423 r
F
0 g
.49176 .76389 m
.49457 .7607 L
s
.49457 .7607 m
.49459 .76096 L
s
.52209 .66822 m .53158 .6527 L .53102 .65629 L 0 0 .079 r
F
0 g
.52243 .66684 m
.52243 .66684 L
s
.52243 .66684 m
.52243 .66683 L
s
.52243 .66683 m
.52294 .66587 L
s
.52442 .66305 m
.52542 .66117 L
s
.52294 .66587 m
.52442 .66305 L
s
.52294 .66587 m
.52294 .66587 L
s
.52294 .66587 m
.52294 .66587 L
s
.53158 .6527 m
.53179 .65218 L
s
.53119 .65304 m
.53158 .6527 L
s
.53446 .68938 m .54229 .69526 L .53797 .691 L 0 .927 .336 r
F
.53446 .68938 m .54513 .7008 L .54229 .69526 L F
.53446 .68938 m .54459 .70391 L .54513 .7008 L F
.53446 .68938 m .54108 .70228 L .54459 .70391 L F
0 g
.54318 .6874 m
.54622 .6923 L
s
.53446 .68938 m .53694 .69701 L .54108 .70228 L 0 .927 .336 r
F
0 g
.53492 .68611 m
.53663 .68885 L
s
.53446 .68938 m .5341 .69148 L .53694 .69701 L 0 .927 .336 r
F
0 g
.53663 .68885 m
.53797 .691 L
s
.52381 .68299 m .5341 .69148 L .53446 .68938 L 0 1 .348 r
F
0 g
.53446 .68938 m
.53797 .691 L
s
.53149 .68613 m
.53446 .68938 L
s
.49177 .74803 m .48644 .76079 L .48949 .75791 L 0 1 .428 r
F
.49177 .74803 m .48438 .75945 L .48644 .76079 L F
0 g
.48644 .76079 m
.48648 .76536 L
s
.51316 .68036 m .51316 .68036 L .51645 .67636 L 0 1 .359 r
F
.51316 .68036 m .52056 .67284 L .52357 .66761 L 0 .696 .284 r
F
0 g
.52357 .66761 m
.52689 .6664 L
s
.5211 .66795 m
.52276 .66507 L
s
.52116 .67621 m
.52456 .67367 L
s
.43156 .81306 m .42835 .80687 L .42335 .80415 L 0 .941 .402 r
F
0 g
.29438 .75777 m
.29438 .75777 L
s
.401 .77094 m .39404 .76055 L .39001 .76235 L 0 1 .411 r
F
.401 .77094 m .39876 .76424 L .39404 .76055 L F
0 g
.40057 .77333 m
.401 .77094 L
s
.41115 .76566 m .40101 .77094 L .40568 .77433 L 0 1 .401 r
F
.41115 .76566 m .39876 .76424 L .40101 .77094 L F
.44478 .67051 m .44173 .66089 L .43717 .66179 L 0 1 .352 r
F
0 g
.44173 .66089 m
.44552 .65571 L
s
.44173 .66089 m
.44499 .66462 L
s
.41463 .99004 m .40698 .98721 L .39912 .98673 L 0 1 .54 r
F
0 g
.41463 .99004 m
.4186 .99394 L
s
.41938 .98569 m .41463 .99003 L .4217 .99082 L 0 1 .54 r
F
.41938 .98569 m .40698 .98721 L .41463 .99003 L F
.36045 .74787 m .35466 .75582 L .35866 .75448 L 0 1 .434 r
F
.36045 .74787 m .35035 .75108 L .35466 .75582 L F
0 g
.35346 .7625 m
.35466 .75582 L
s
.35866 .75448 m
.36336 .75901 L
s
.51441 .75625 m .51472 .77212 L .51629 .76768 L 0 1 .412 r
F
0 g
.51472 .77212 m
.51616 .77565 L
s
.51316 .68036 m .52071 .68167 L .52405 .68147 L 0 1 .363 r
F
0 g
.52405 .68147 m
.52718 .68391 L
s
.3026 .95875 m .28381 .95555 L .28669 .95893 L 0 1 .525 r
F
.3026 .95875 m .28742 .95434 L .28381 .95555 L F
.3026 .95875 m .29548 .95571 L .28742 .95434 L F
.31111 .95531 m .29548 .95571 L .3026 .95875 L 0 1 .52 r
F
0 g
.3026 .95875 m
.31041 .95993 L
s
.3026 .95875 m
.30544 .96211 L
s
.505 .69026 m .49833 .69915 L .4962 .70153 L 0 0 .016 r
F
.51316 .68035 m .51316 .68035 L .50992 .67384 L 0 .753 .287 r
F
.51316 .68035 m .51669 .65737 L .51624 .65753 L 0 1 .356 r
F
.51316 .68035 m .51587 .66418 L .51669 .65737 L F
0 g
.51629 .66223 m
.5166 .66081 L
s
.5166 .66081 m
.51729 .65757 L
s
.51669 .65737 m
.51672 .65724 L
s
.51624 .65753 m
.51628 .65698 L
s
.51664 .6641 m
.51748 .65907 L
s
.51668 .65749 m
.51669 .65737 L
s
.51645 .65938 m
.51668 .65749 L
s
.51628 .66081 m
.51645 .65938 L
s
.3459 .7831 m .33423 .7767 L .33335 .78134 L 0 1 .516 r
F
.3459 .7831 m .33823 .77555 L .33423 .7767 L F
.3459 .7831 m .34324 .7783 L .33823 .77555 L F
.35563 .77971 m .34324 .7783 L .3459 .7831 L 0 1 .514 r
F
0 g
.34502 .78773 m
.3459 .7831 L
s
.3459 .7831 m
.35078 .78563 L
s
.53793 .42988 m .53451 .44234 L .5339 .44058 L 0 0 .08 r
F
.53793 .42988 m .5398 .43569 L .53451 .44234 L F
0 g
.53792 .42989 m
.53793 .42988 L
s
.53793 .42988 m .54621 .42511 L .5398 .43569 L 0 0 .08 r
F
0 g
.53793 .42989 m
.53793 .42988 L
s
.78382 .93559 m .77723 .9399 L .7751 .94408 L 0 1 .534 r
F
0 g
.76659 .94618 m
.7751 .94408 L
s
.51316 .68035 m .51737 .66423 L .51497 .67344 L 0 1 .353 r
F
.51316 .68035 m .51497 .67344 L .51737 .66423 L F
0 g
.51737 .66423 m
.51737 .66423 L
s
.51737 .66423 m
.51923 .65823 L
s
.26703 .95656 m .26584 .96166 L .26942 .96043 L 0 1 .529 r
F
0 g
.26942 .96043 m
.27793 .96216 L
s
.26703 .95656 m .25786 .95944 L .26584 .96166 L 0 1 .529 r
F
0 g
.26584 .96166 m
.26919 .9654 L
s
.42661 .76996 m .41567 .7688 L .41455 .77294 L 0 1 .484 r
F
.41115 .76566 m .40568 .77433 L .40968 .77216 L 0 1 .401 r
F
.41111 .76804 m .40568 .77433 L .40968 .77216 L 0 1 .493 r
F
.41111 .76804 m .40096 .7733 L .40568 .77433 L F
0 g
.40101 .77094 m
.40289 .7723 L
s
.41107 .77043 m .40568 .77433 L .40968 .77216 L 0 1 .319 r
F
.41107 .77043 m .40092 .77566 L .40568 .77433 L F
0 g
.40973 .77214 m
.40982 .77211 L
s
.40982 .77211 m
.40992 .77208 L
s
.40992 .77208 m
.41459 .77055 L
s
.41697 .78171 m .40968 .77216 L .40568 .77433 L 0 1 .402 r
F
0 g
.40553 .77438 m
.40568 .77433 L
s
.40998 .77221 m
.41455 .77294 L
s
.40983 .77218 m
.40998 .77221 L
s
.40472 .78091 m
.40568 .77433 L
s
.40565 .77447 m
.40568 .77433 L
s
.40481 .77618 m
.40568 .77433 L
s
.41938 .98569 m .4217 .99082 L .42348 .98904 L 0 1 .54 r
F
.43816 .99146 m .42348 .98904 L .4217 .99082 L 0 1 .541 r
F
0 g
.4217 .99082 m
.42637 .99386 L
s
.41463 .99003 m
.4217 .99082 L
s
.68655 .5696 m
.69126 .55115 L
s
.39575 .75411 m .39001 .76235 L .39404 .76055 L 0 1 .411 r
F
.39575 .75411 m .38555 .75844 L .39001 .76235 L F
0 g
.38883 .76886 m
.39001 .76235 L
s
.47596 .90542 m
.47597 .90542 L
s
.47597 .90542 m
.47598 .90542 L
s
.47598 .90542 m
.47845 .90516 L
s
.49528 .70319 m .48962 .70958 L .4931 .70547 L 0 0 0 r
F
.49528 .70319 m .48635 .71357 L .48962 .70958 L F
0 g
.48774 .71168 m
.48962 .70958 L
s
.4931 .70547 m
.4962 .70153 L
s
.29624 .78204 m .29067 .78843 L .29493 .78733 L 0 1 .523 r
F
.29624 .78204 m .28548 .78459 L .29067 .78843 L F
0 g
.29016 .79378 m
.29067 .78843 L
s
.29493 .78733 m
.30068 .79086 L
s
.50971 .75545 m .51076 .76662 L .51096 .76043 L 0 1 .416 r
F
.51441 .75625 m .51096 .76043 L .51076 .76662 L 0 1 .412 r
F
0 g
.51076 .76662 m
.51237 .77162 L
s
.50885 .77074 m
.51076 .76662 L
s
.51316 .68036 m .52116 .67621 L .51659 .67858 L 0 1 .364 r
F
.51316 .68036 m .51659 .67858 L .52116 .67621 L F
0 g
.5211 .67804 m
.52451 .67627 L
s
.52116 .67621 m
.52116 .67621 L
s
.52116 .67621 m
.52455 .67522 L
s
.48695 .92619 m .49035 .93516 L .49096 .93271 L 0 .614 .415 r
F
.50199 .94193 m .49035 .93516 L .49475 .9418 L 0 .497 .397 r
F
.50199 .94193 m .49096 .93271 L .49035 .93516 L F
0 g
.48513 .93229 m
.49035 .93516 L
s
.711 .93512 m
.7126 .93436 L
s
.69649 .93811 m .70486 .93807 L .70744 .93439 L 0 1 .482 r
F
0 g
.70486 .93807 m
.711 .93512 L
s
.49962 .98799 m .50482 .99101 L .505 .98913 L 0 1 .537 r
F
.51806 .98504 m .505 .98913 L .50482 .99101 L 0 1 .524 r
F
0 g
.50482 .99101 m
.51053 .99095 L
s
.49886 .99273 m
.50482 .99101 L
s
.43588 .64183 m .42734 .64798 L .43183 .64723 L 0 1 .359 r
F
0 g
.436 .64972 m
.43856 .64623 L
s
.43588 .64183 m .42474 .64353 L .42734 .64798 L 0 1 .359 r
F
.43588 .64183 m .42578 .63686 L .42474 .64353 L F
.43588 .64183 m .42983 .63146 L .42578 .63686 L F
.43588 .64183 m .4342 .63094 L .42983 .63146 L F
0 g
.4342 .63094 m
.43679 .63539 L
s
.43588 .64183 m
.43856 .64623 L
s
.4342 .63094 m
.4384 .62561 L
s
.79657 .88371 m .79424 .90006 L .80128 .89317 L 0 1 .512 r
F
.79657 .88371 m .79032 .89988 L .79424 .90006 L F
0 g
.79218 .90656 m
.79424 .90006 L
s
.4238 .79751 m .42095 .79122 L .41601 .78829 L 0 .989 .402 r
F
.73873 .92366 m .75017 .91892 L .74648 .91884 L 0 1 .519 r
F
.72968 .92361 m .73873 .92366 L .74093 .91883 L 0 1 .513 r
F
.46806 .69026 m .46422 .68303 L .45966 .68446 L 0 .971 .331 r
F
.46806 .69026 m .46782 .68551 L .46422 .68303 L F
0 g
.46422 .68303 m
.4676 .67832 L
s
.47972 .45221 m .4733 .46375 L .47457 .46115 L 0 0 0 r
F
.47972 .45221 m .47688 .45928 L .4733 .46375 L F
0 g
.47453 .46063 m
.47648 .45731 L
s
.47972 .45221 m .48292 .45073 L .47688 .45928 L 0 0 0 r
F
.47972 .45221 m .48805 .4418 L .48292 .45073 L F
0 g
.47648 .45731 m
.47972 .45221 L
s
.47519 .90551 m .46312 .91293 L .46639 .91257 L 0 1 .339 r
F
0 g
.46639 .91258 m
.46639 .91258 L
s
.46095 .91577 m
.46639 .91258 L
s
.7713 .67132 m .77897 .68682 L .78256 .68332 L 0 .965 .489 r
F
0 g
.77897 .68682 m
.78139 .69423 L
s
.52381 .68299 m .53073 .69056 L .5341 .69148 L 0 1 .348 r
F
.52381 .68299 m .5266 .68723 L .53073 .69056 L F
.52381 .68299 m .52363 .68399 L .5266 .68723 L F
.51316 .68036 m .52381 .68299 L .52071 .68167 L 0 1 .362 r
F
.51316 .68036 m .52363 .68399 L .52381 .68299 L F
0 g
.52381 .68299 m
.52718 .68391 L
s
.47667 .75352 m .46803 .75764 L .46727 .76203 L 0 1 .443 r
F
0 g
.4633 .76336 m
.46727 .76203 L
s
.51316 .68036 m .51316 .68036 L .51165 .68129 L 0 0 .037 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.49177 .74803 m .48465 .75475 L .48438 .75945 L 0 1 .428 r
F
0 g
.48188 .76121 m
.48438 .75945 L
s
.48949 .75793 m
.4896 .76269 L
s
.45619 .68151 m .44806 .67408 L .44468 .67926 L 0 1 .342 r
F
.51316 .68036 m .50183 .67833 L .50189 .68017 L 0 .723 .285 r
F
.51316 .68036 m .50519 .67797 L .50183 .67833 L F
0 g
.50177 .67831 m
.50183 .67833 L
s
.50183 .67833 m
.50264 .67825 L
s
.50264 .67825 m
.50519 .67797 L
s
.7536 .90576 m .75017 .91892 L .75736 .91321 L 0 1 .514 r
F
.7536 .90576 m .74648 .91884 L .75017 .91892 L F
0 g
.74776 .92407 m
.75017 .91892 L
s
.51316 .68035 m .51624 .65753 L .51508 .66446 L 0 1 .356 r
F
0 g
.51604 .6587 m
.51613 .65818 L
s
.51613 .65818 m
.51623 .65758 L
s
.51623 .65758 m
.51624 .65753 L
s
.51555 .65783 m
.51556 .65778 L
s
.51556 .65778 m
.51557 .65772 L
s
.51557 .65772 m
.51572 .65674 L
s
.51557 .65772 m
.51557 .65772 L
s
.51557 .65772 m
.51557 .65772 L
s
.51624 .65753 m
.51624 .65753 L
s
.5236 .77332 m .52567 .78426 L .5248 .77803 L 0 1 .414 r
F
0 g
.52567 .78426 m
.52567 .78426 L
s
.52598 .7848 m
.52792 .78824 L
s
.52819 .77338 m .5248 .77803 L .52568 .78426 L 0 1 .412 r
F
0 g
.52568 .78426 m
.52598 .7848 L
s
.49083 .89433 m .48004 .90244 L .4834 .9015 L 0 1 .292 r
F
0 g
.47845 .90516 m
.4834 .9015 L
s
.44478 .67051 m .4366 .67707 L .44118 .67584 L 0 1 .352 r
F
0 g
.44556 .67791 m
.44806 .67408 L
s
.44478 .67051 m .43333 .67333 L .4366 .67707 L 0 1 .352 r
F
.44478 .67051 m .43357 .66712 L .43333 .67333 L F
.44478 .67051 m .43717 .66179 L .43357 .66712 L F
0 g
.44478 .67051 m
.44806 .67408 L
s
.44018 .82837 m .43663 .82227 L .43163 .81975 L 0 .89 .402 r
F
.25827 .75141 m .25193 .76016 L .25632 .75922 L 0 1 .479 r
F
.25827 .75141 m .24722 .75357 L .25193 .76016 L F
0 g
.25088 .76802 m
.25193 .76016 L
s
.25632 .75922 m
.26174 .76553 L
s
.51316 .68035 m .51664 .6641 L .51465 .67339 L 0 1 .353 r
F
.51316 .68035 m .51465 .67339 L .51664 .6641 L 0 1 .355 r
F
0 g
.51664 .6641 m
.51664 .6641 L
s
.51664 .6641 m
.51756 .66056 L
s
.51587 .66418 m
.51628 .66081 L
s
.51316 .68036 m .5204 .68342 L .52363 .68399 L 0 1 .362 r
F
.51316 .68036 m .5211 .67804 L .51656 .67936 L 0 1 .364 r
F
.51316 .68036 m .51656 .67936 L .5211 .67804 L F
0 g
.5211 .67804 m
.5211 .67804 L
s
.5211 .67804 m
.52443 .67784 L
s
.45619 .68151 m .44825 .68822 L .45281 .68669 L 0 1 .342 r
F
.45619 .68151 m .44476 .68503 L .44825 .68822 L F
.45619 .68151 m .44468 .67926 L .44476 .68503 L F
.4506 .76232 m .44049 .76325 L .43941 .76739 L 0 1 .467 r
F
.49177 .74803 m .48949 .75791 L .4915 .75273 L 0 1 .428 r
F
.49603 .75047 m .4915 .75273 L .48949 .75791 L 0 1 .425 r
F
0 g
.48644 .76079 m
.48949 .75791 L
s
.48949 .75791 m
.48949 .75793 L
s
.42661 .76996 m .41967 .76649 L .41567 .7688 L 0 1 .484 r
F
.42661 .76996 m .42436 .76699 L .41967 .76649 L F
.43618 .76338 m .42436 .76699 L .42661 .76996 L 0 1 .477 r
F
0 g
.42661 .76996 m
.43111 .77016 L
s
.42549 .7741 m
.42661 .76996 L
s
.43486 .76746 m
.43941 .76739 L
s
.49062 .68245 m .48285 .68779 L .48734 .68608 L 0 .858 .307 r
F
.49062 .68245 m .47934 .68603 L .48285 .68779 L F
.50189 .68017 m .49062 .68245 L .49408 .68382 L 0 .793 .296 r
F
.50199 .94193 m .49475 .9418 L .50122 .94821 L 0 .497 .397 r
F
0 g
.49035 .93516 m
.49475 .9418 L
s
.48945 .93867 m
.49475 .9418 L
s
.34025 .75417 m .32976 .74226 L .32817 .7491 L 0 1 .447 r
F
.34025 .75417 m .33389 .7412 L .32976 .74226 L F
.34025 .75417 m .33838 .74631 L .33389 .7412 L F
.35035 .75108 m .33838 .74631 L .34025 .75417 L 0 1 .441 r
F
0 g
.33864 .761 m
.34025 .75417 L
s
.34025 .75417 m
.34465 .75909 L
s
.51316 .68036 m .51316 .68035 L .50982 .67519 L 0 .749 .286 r
F
0 g
.51021 .67124 m
.51191 .67648 L
s
.51281 .67608 m
.51283 .67629 L
s
.5128 .67594 m
.51281 .67608 L
s
.51188 .6649 m
.5128 .67594 L
s
.25786 .95944 m .24137 .95788 L .24871 .96233 L 0 1 .531 r
F
0 g
.24871 .96233 m
.25558 .96434 L
s
.52333 .68545 m .53073 .69056 L .5266 .68723 L 0 1 .349 r
F
0 g
.52363 .68399 m
.5266 .68723 L
s
.38555 .75844 m .37484 .74885 L .37326 .75539 L 0 1 .419 r
F
.38555 .75844 m .37903 .74733 L .37484 .74885 L F
.38555 .75844 m .38362 .75144 L .37903 .74733 L F
.39575 .75411 m .38362 .75144 L .38555 .75844 L 0 1 .411 r
F
0 g
.38555 .75844 m
.39001 .76235 L
s
.38397 .76498 m
.38555 .75844 L
s
.48885 .91923 m .48101 .91997 L .48695 .92619 L 0 .589 .405 r
F
.48885 .91923 m .47736 .91325 L .48101 .91997 L F
0 g
.48101 .91997 m
.48101 .91997 L
s
.36273 .98276 m .34734 .97659 L .34434 .97809 L 0 1 .538 r
F
.36273 .98276 m .35523 .9786 L .34734 .97659 L F
.36965 .97877 m .35523 .9786 L .36273 .98276 L F
0 g
.36273 .98276 m
.36634 .98713 L
s
.36273 .98276 m
.37033 .98464 L
s
.5139 .65895 m .51437 .65859 L .5152 .65165 L 0 1 .352 r
F
0 g
.51479 .65506 m
.5152 .65165 L
s
.51512 .65589 m
.5152 .65165 L
s
.51464 .63802 m .5142 .62617 L .51404 .63341 L 0 1 .342 r
F
.51464 .63802 m .51538 .6191 L .5142 .62617 L F
.5139 .65895 m .51464 .63802 L .51381 .64495 L 0 1 .352 r
F
.52333 .68545 m .5335 .69451 L .53073 .69056 L 0 1 .349 r
F
0 g
.53073 .69056 m
.5341 .69148 L
s
.5191 .75657 m .51824 .77271 L .52058 .77301 L 0 1 .408 r
F
.5191 .75657 m .51629 .76768 L .51824 .77271 L F
0 g
.51668 .77695 m
.51824 .77271 L
s
.37326 .75539 m
.37326 .75538 L
s
.46706 .73349 m
.4688 .73166 L
s
.47934 .68603 m .46782 .68551 L .46806 .69026 L 0 .916 .319 r
F
0 g
.46422 .68303 m
.46782 .68551 L
s
.46782 .68551 m
.47105 .68104 L
s
.54684 .54502 m .55028 .53556 L .55441 .53458 L 0 .23 .128 r
F
0 g
.55028 .53556 m
.55131 .52556 L
s
.52333 .68545 m .53305 .69644 L .5335 .69451 L 0 1 .349 r
F
.52333 .68545 m .52978 .69465 L .53305 .69644 L F
.52333 .68545 m .52587 .69035 L .52978 .69465 L F
.52333 .68545 m .5231 .68641 L .52587 .69035 L F
.51316 .68036 m .52333 .68545 L .5204 .68342 L 0 1 .361 r
F
.51316 .68036 m .5231 .68641 L .52333 .68545 L F
0 g
.52333 .68545 m
.5266 .68723 L
s
.48885 .91923 m .47842 .91052 L .47736 .91325 L 0 .589 .405 r
F
0 g
.47223 .91066 m
.47736 .91325 L
s
.47736 .91325 m
.48101 .91997 L
s
.51316 .68035 m .51555 .65785 L .51508 .65812 L 0 1 .358 r
F
.51316 .68035 m .51508 .66446 L .51555 .65785 L F
0 g
.51555 .65785 m
.51555 .65783 L
s
.51508 .65811 m
.51512 .65589 L
s
.51515 .664 m
.51604 .6587 L
s
.51552 .65817 m
.51555 .65785 L
s
.51515 .66346 m
.51552 .65817 L
s
.39119 .78042 m .37961 .7821 L .37869 .78402 L 0 1 .409 r
F
.39119 .78042 m .38365 .78048 L .37961 .7821 L F
.39119 .78042 m .38861 .77976 L .38365 .78048 L F
.40092 .77566 m .38861 .77976 L .39119 .78042 L 0 1 .37 r
F
0 g
.39026 .78234 m
.39119 .78042 L
s
.39119 .78042 m
.39586 .77946 L
s
.5236 .77332 m .52288 .77327 L .52288 .77785 L 0 1 .414 r
F
0 g
.52288 .77785 m
.52288 .77785 L
s
.45961 .85841 m .44984 .86013 L .45434 .86622 L 0 .773 .4 r
F
.45961 .85841 m .44825 .8533 L .44984 .86013 L F
0 g
.44984 .86013 m
.44984 .86013 L
s
.505 .69026 m .50182 .69482 L .49833 .69915 L 0 0 .016 r
F
.505 .69026 m .50468 .69101 L .50182 .69482 L F
.51316 .68036 m .505 .69026 L .50762 .6869 L 0 0 .055 r
F
.51316 .68036 m .50468 .69101 L .505 .69026 L F
0 g
.50287 .69265 m
.505 .69026 L
s
.505 .69026 m
.5076 .68693 L
s
.51316 .68036 m .52095 .67987 L .5165 .68015 L 0 1 .363 r
F
.51316 .68036 m .5165 .68015 L .52095 .67987 L 0 1 .364 r
F
0 g
.52095 .67987 m
.52434 .67888 L
s
.52095 .67987 m
.52418 .68044 L
s
.46806 .69026 m .45966 .68446 L .45647 .68949 L 0 .971 .331 r
F
0 g
.45619 .68151 m
.45966 .68446 L
s
.39404 .76055 m
.39876 .76424 L
s
.41115 .76566 m .40022 .75773 L .39876 .76424 L 0 1 .401 r
F
0 g
.39876 .76424 m
.39876 .76423 L
s
.53995 .64617 m .54893 .64214 L .54549 .65318 L 0 .121 .123 r
F
.54487 .63158 m .54688 .64337 L .5502 .59574 L 0 .881 .237 r
F
0 g
.54964 .60367 m
.5502 .59574 L
s
.51316 .68036 m .50519 .67797 L .50974 .67934 L 0 .733 .285 r
F
.51316 .68036 m .50974 .67934 L .50519 .67797 L 0 .723 .285 r
F
0 g
.50519 .67797 m
.50519 .67797 L
s
.5033 .67664 m
.50519 .67797 L
s
.80411 .70405 m .81324 .70092 L .80867 .69926 L 0 1 .502 r
F
.80411 .70405 m .81546 .70836 L .81324 .70092 L F
.50505 .75421 m .50321 .75359 L .50097 .7574 L 0 1 .419 r
F
.43426 .92865 m .42186 .93161 L .41969 .93342 L 0 1 .44 r
F
.43426 .92865 m .42811 .92957 L .42186 .93161 L F
.43905 .92402 m .42811 .92957 L .43426 .92865 L 0 1 .404 r
F
0 g
.43426 .92865 m
.43752 .92946 L
s
.43426 .92865 m
.44022 .92654 L
s
.51538 .6191 m .51458 .61078 L .51443 .61647 L 0 1 .318 r
F
.51316 .68035 m .51587 .66418 L .51433 .67342 L 0 1 .355 r
F
.51316 .68035 m .51433 .67342 L .51587 .66418 L 0 1 .356 r
F
0 g
.51587 .66418 m
.51587 .66418 L
s
.51587 .66418 m
.51629 .66223 L
s
.50971 .75545 m .50784 .75501 L .50593 .75913 L 0 1 .416 r
F
.51316 .68036 m .52001 .6851 L .5231 .68641 L 0 1 .361 r
F
0 g
.52071 .68167 m
.52405 .68147 L
s
.5335 .69451 m .54108 .70228 L .53694 .69701 L 0 .938 .339 r
F
.5335 .69451 m .54369 .70827 L .54108 .70228 L F
.5335 .69451 m .54301 .71097 L .54369 .70827 L F
.5335 .69451 m .53957 .70847 L .54301 .71097 L F
.5335 .69451 m .53565 .70242 L .53957 .70847 L F
0 g
.5341 .69148 m
.53484 .69292 L
s
.5335 .69451 m .53305 .69644 L .53565 .70242 L 0 .938 .339 r
F
0 g
.53484 .69292 m
.53694 .69701 L
s
.53073 .69056 m
.5335 .69451 L
s
.5335 .69451 m
.53694 .69701 L
s
.69074 1.07469 m .6783 1.07683 L .68754 1.07676 L 0 .775 .287 r
F
.69074 1.07469 m .67587 1.07611 L .6783 1.07683 L F
0 g
.67221 1.07772 m
.6783 1.07683 L
s
.68194 1.07794 m
.68231 1.07786 L
s
.47934 .68603 m .47161 .6924 L .47611 .6905 L 0 .916 .319 r
F
.47934 .68603 m .46806 .69026 L .47161 .6924 L F
.51441 .75625 m .51629 .76768 L .51602 .76127 L 0 1 .412 r
F
.5191 .75657 m .51602 .76127 L .51629 .76768 L 0 1 .408 r
F
0 g
.51629 .76768 m
.51824 .77271 L
s
.51472 .77212 m
.51629 .76768 L
s
.43139 .60963 m .43315 .60266 L .43147 .59775 L 0 1 .363 r
F
0 g
.43315 .60266 m
.43483 .60059 L
s
.51316 .68036 m .51316 .68036 L .51134 .68194 L 0 0 .042 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.25265 .80639 m .24762 .81136 L .25187 .81043 L 0 1 .533 r
F
.25265 .80639 m .24192 .80849 L .24762 .81136 L F
0 g
.24762 .81136 m
.24778 .81548 L
s
.25231 .81061 m
.25826 .81293 L
s
.25187 .81043 m
.25231 .81061 L
s
.46601 .88138 m .46127 .87533 L .45629 .8729 L 0 .736 .409 r
F
0 g
.45629 .8729 m
.46127 .87533 L
s
.45434 .86622 m
.45629 .8729 L
s
.48139 .75733 m .47946 .75584 L .47591 .75791 L 0 1 .441 r
F
.48773 .74525 m .48139 .75733 L .48465 .75475 L 0 1 .43 r
F
.48773 .74525 m .47946 .75584 L .48139 .75733 L F
0 g
.4811 .76088 m
.48139 .75733 L
s
.27639 .94928 m .27505 .95238 L .27864 .95111 L 0 1 .356 r
F
0 g
.27864 .95111 m
.28699 .95073 L
s
.27639 .94928 m .2672 .95223 L .27505 .95238 L 0 1 .356 r
F
0 g
.27505 .95238 m
.27823 .95412 L
s
.51316 .68036 m .50762 .6869 L .51079 .68316 L 0 0 .055 r
F
.51316 .68036 m .51079 .68316 L .50762 .6869 L 0 0 .051 r
F
0 g
.50551 .6891 m
.50762 .6869 L
s
.5076 .68693 m
.50762 .6869 L
s
.51316 .68035 m .51508 .65812 L .51426 .66493 L 0 1 .358 r
F
0 g
.51506 .65825 m
.51508 .65812 L
s
.51508 .66445 m
.51515 .66346 L
s
.51438 .65854 m
.5144 .65838 L
s
.5144 .65837 m
.51479 .65506 L
s
.5144 .65838 m
.5144 .65837 L
s
.5144 .65837 m
.5144 .65837 L
s
.51508 .65812 m
.51508 .65811 L
s
.50189 .68017 m .49408 .68382 L .49857 .68253 L 0 .793 .296 r
F
0 g
.50166 .68033 m
.50189 .68017 L
s
.50078 .68096 m
.50166 .68033 L
s
.51316 .68036 m .50189 .68017 L .5053 .68119 L 0 .723 .285 r
F
0 g
.50189 .68017 m
.50189 .68017 L
s
.52377 .98499 m
.52523 .98416 L
s
.52523 .98416 m
.52533 .98411 L
s
.52533 .98411 m
.52533 .98411 L
s
.52533 .98411 m
.52551 .984 L
s
.52551 .984 m
.52626 .98358 L
s
.52626 .98358 m
.52631 .98356 L
s
.5669 .61494 m
.56721 .62237 L
s
.51316 .68036 m .52071 .68167 L .5164 .68092 L 0 1 .362 r
F
.51316 .68036 m .5164 .68092 L .52071 .68167 L 0 1 .363 r
F
0 g
.52071 .68167 m
.52071 .68167 L
s
.52071 .68167 m
.52381 .68299 L
s
.54622 .6923 m
.54915 .69366 L
s
.49205 .43778 m .49818 .42907 L .50252 .42559 L 0 0 .047 r
F
.51316 .68036 m .51316 .68036 L .50976 .67656 L 0 .742 .286 r
F
0 g
.51188 .6649 m
.51286 .67672 L
s
.51286 .67672 m
.51287 .67684 L
s
.51287 .67684 m
.51289 .67703 L
s
.51191 .67648 m
.51205 .67693 L
s
.50047 .75254 m .49868 .75176 L .49615 .75526 L 0 1 .423 r
F
0 g
.30776 .75443 m
.30776 .75443 L
s
.52274 .6878 m .52978 .69465 L .52587 .69035 L 0 1 .35 r
F
.52274 .6878 m .53231 .69919 L .52978 .69465 L F
.52274 .6878 m .53178 .70093 L .53231 .69919 L F
.52274 .6878 m .52864 .69838 L .53178 .70093 L F
.52274 .6878 m .525 .69323 L .52864 .69838 L F
0 g
.5231 .68641 m
.52346 .68691 L
s
.52274 .6878 m .52247 .6887 L .525 .69323 L 0 1 .35 r
F
0 g
.52346 .68691 m
.52587 .69035 L
s
.51316 .68036 m .52274 .6878 L .52001 .6851 L 0 1 .36 r
F
.51316 .68036 m .52247 .6887 L .52274 .6878 L F
0 g
.52274 .6878 m
.52587 .69035 L
s
.5191 .75657 m .52058 .77301 L .52178 .76825 L 0 1 .408 r
F
0 g
.52058 .77301 m
.52288 .77785 L
s
.37056 .74452 m .36467 .75243 L .36868 .75104 L 0 1 .427 r
F
.37056 .74452 m .36045 .74787 L .36467 .75243 L F
0 g
.36336 .75901 m
.36467 .75243 L
s
.36868 .75104 m
.37326 .75539 L
s
.41697 .78171 m .41452 .77532 L .40968 .77216 L 0 1 .402 r
F
0 g
.40968 .77216 m
.40975 .77221 L
s
.40968 .77216 m
.40973 .77214 L
s
.40968 .77216 m
.40983 .77218 L
s
.79115 .78235 m .78943 .78784 L .79385 .79089 L 0 .468 .352 r
F
.79115 .78235 m .78826 .78419 L .78943 .78784 L F
0 g
.78313 .78783 m
.78943 .78784 L
s
.43267 .79083 m .4238 .79751 L .42853 .80018 L 0 .958 .392 r
F
.43267 .79083 m .42095 .79122 L .4238 .79751 L F
0 g
.42335 .80415 m
.4238 .79751 L
s
.43418 .65773 m .43476 .65141 L .43183 .64723 L 0 1 .362 r
F
0 g
.43476 .65141 m
.436 .64972 L
s
.50122 .94821 m .50576 .95706 L .50594 .95476 L 0 .507 .402 r
F
.51749 .96455 m .50576 .95706 L .51082 .96388 L 0 .379 .37 r
F
.51749 .96455 m .50594 .95476 L .50576 .95706 L F
0 g
.50045 .95391 m
.50576 .95706 L
s
.51441 .75625 m .51253 .75599 L .51096 .76043 L 0 1 .412 r
F
.43267 .79083 m .42162 .78461 L .42095 .79122 L 0 .958 .392 r
F
0 g
.41601 .78829 m
.42095 .79122 L
s
.47951 .99298 m .47184 .99236 L .46533 .99338 L 0 1 .542 r
F
0 g
.46435 .99286 m
.46533 .99338 L
s
.26932 .7492 m .2629 .75781 L .26729 .75686 L 0 1 .476 r
F
.26932 .7492 m .25827 .75141 L .2629 .75781 L F
0 g
.26174 .76553 m
.2629 .75781 L
s
.26729 .75686 m
.27261 .763 L
s
.53305 .69644 m
.53319 .69676 L
s
.52978 .69465 m
.53141 .69554 L
s
.53141 .69554 m
.53305 .69644 L
s
.52819 .77338 m .52588 .77336 L .5248 .77803 L 0 1 .412 r
F
.51316 .68036 m .51954 .68667 L .52247 .6887 L 0 1 .36 r
F
0 g
.5204 .68342 m
.52363 .68399 L
s
.48635 .71357 m .47823 .72249 L .47627 .72449 L 0 0 0 r
F
.48635 .71357 m .482 .71861 L .47823 .72249 L F
.48635 .71357 m .48548 .71478 L .482 .71861 L F
.49528 .70319 m .48548 .71478 L .48635 .71357 L F
0 g
.48635 .71357 m
.48962 .70958 L
s
.48439 .71558 m
.48635 .71357 L
s
.26399 .78953 m .25113 .77906 L .25016 .78492 L 0 1 .525 r
F
.26399 .78953 m .25552 .77828 L .25113 .77906 L F
.26399 .78953 m .26104 .78277 L .25552 .77828 L F
.27473 .78708 m .26104 .78277 L .26399 .78953 L 0 1 .524 r
F
0 g
.26301 .79536 m
.26399 .78953 L
s
.26399 .78953 m
.26939 .79379 L
s
.43785 .5599 m .43876 .55751 L .43693 .55619 L 0 1 .348 r
F
0 g
.43876 .55751 m
.43928 .55719 L
s
.49418 .8934 m
.49852 .88956 L
s
.64193 .44934 m
.64284 .45211 L
s
.64284 .45211 m
.64346 .454 L
s
.64346 .454 m
.64501 .45873 L
s
.64028 .44899 m
.64175 .4493 L
s
.64175 .4493 m
.64193 .44934 L
s
.53118 .78936 m
.53194 .79051 L
s
.53364 .79309 m
.53398 .79361 L
s
.53118 .78936 m
.53168 .78719 L
s
.53213 .78526 m
.53226 .78469 L
s
.51316 .68035 m .51508 .66446 L .51398 .67354 L 0 1 .356 r
F
.51316 .68035 m .51398 .67354 L .51508 .66446 L 0 1 .358 r
F
0 g
.51508 .66446 m
.51508 .66445 L
s
.51508 .66446 m
.51515 .664 L
s
.45785 .4921 m .46265 .48318 L .46495 .47799 L 0 .917 .145 r
F
.48131 .98819 m .47951 .99298 L .4857 .992 L 0 1 .54 r
F
.48131 .98819 m .47184 .99236 L .47951 .99298 L F
0 g
.47951 .99298 m
.48403 .99473 L
s
.71022 .55816 m .726 .55849 L .72389 .57206 L 0 .509 .118 r
F
0 g
.726 .55849 m
.726 .55849 L
s
.43965 .80588 m .42835 .80687 L .43156 .81306 L 0 .91 .392 r
F
.43965 .80588 m .42853 .80018 L .42835 .80687 L F
0 g
.42335 .80415 m
.42835 .80687 L
s
.52862 .6159 m .5309 .6133 L .53369 .58124 L 0 .988 .249 r
F
.51316 .68036 m .5204 .68342 L .51627 .68167 L 0 1 .361 r
F
.51316 .68036 m .51627 .68167 L .5204 .68342 L 0 1 .362 r
F
0 g
.5204 .68342 m
.5204 .68342 L
s
.5204 .68342 m
.52333 .68545 L
s
.50213 .68474 m .49408 .68382 L .49087 .68711 L 0 .775 .296 r
F
.50213 .68474 m .49857 .68253 L .49408 .68382 L F
0 g
.49062 .68245 m
.49408 .68382 L
s
.68811 .93862 m .68268 .94633 L .68993 .94281 L 0 1 .456 r
F
.68811 .93862 m .67954 .94632 L .68268 .94633 L F
0 g
.67958 .94919 m
.68268 .94633 L
s
.68738 .94647 m
.68904 .94409 L
s
.42653 .77556 m .41697 .78171 L .42162 .78461 L 0 1 .392 r
F
.42653 .77556 m .41452 .77532 L .41697 .78171 L F
0 g
.41601 .78829 m
.41697 .78171 L
s
.48773 .74525 m .48465 .75475 L .48707 .74984 L 0 1 .43 r
F
.49177 .74803 m .48707 .74984 L .48465 .75475 L 0 1 .428 r
F
0 g
.48438 .75945 m
.48465 .75475 L
s
.48139 .75733 m
.48465 .75475 L
s
.37513 .77255 m .37001 .77831 L .37386 .77679 L 0 1 .509 r
F
.37513 .77255 m .36538 .77621 L .37001 .77831 L F
0 g
.36932 .78263 m
.37001 .77831 L
s
.37386 .77679 m
.3788 .77865 L
s
.49109 .6902 m .48734 .68608 L .48285 .68779 L 0 .833 .308 r
F
.49109 .6902 m .49087 .68711 L .48734 .68608 L F
0 g
.48734 .68608 m
.49062 .68245 L
s
.51316 .68035 m .51437 .65859 L .5139 .65895 L 0 1 .36 r
F
.51316 .68035 m .51426 .66493 L .51437 .65859 L F
0 g
.51437 .65859 m
.51438 .65854 L
s
.51426 .6649 m
.51437 .65859 L
s
.5139 .65895 m .51381 .64495 L .51366 .65311 L 0 1 .352 r
F
.51271 .66002 m .51381 .64495 L .51321 .63976 L 0 1 .356 r
F
.51271 .66002 m .51366 .65311 L .51381 .64495 L F
0 g
.51381 .64495 m
.51464 .63802 L
s
.44476 .68503 m .44468 .67926 L .44118 .67584 L 0 1 .354 r
F
0 g
.44468 .67926 m
.44556 .67791 L
s
.53452 .66416 m .54575 .67446 L .54521 .66026 L 0 .507 .258 r
F
0 g
.54521 .66026 m
.54798 .64861 L
s
.54165 .65242 m
.54521 .66026 L
s
.53452 .66416 m .54284 .68254 L .54575 .67446 L 0 .507 .258 r
F
.53452 .66416 m .53842 .67908 L .54284 .68254 L F
.53452 .66416 m .53486 .6712 L .53842 .67908 L F
.52384 .67167 m .53486 .6712 L .53452 .66416 L 0 .602 .272 r
F
0 g
.53111 .6621 m
.53452 .66416 L
s
.53452 .66416 m
.53743 .65611 L
s
.50213 .68474 m .50202 .68292 L .49857 .68253 L 0 .775 .296 r
F
0 g
.49857 .68253 m
.50078 .68096 L
s
.51226 .64098 m .51404 .63341 L .5142 .62617 L 0 1 .348 r
F
.51226 .64098 m .51321 .63976 L .51404 .63341 L F
0 g
.51404 .63341 m
.51464 .63802 L
s
.52204 .69 m .52864 .69838 L .525 .69323 L 0 1 .351 r
F
.52204 .69 m .53092 .7034 L .52864 .69838 L F
.52204 .69 m .53031 .70494 L .53092 .7034 L F
.52204 .69 m .52734 .70171 L .53031 .70494 L F
0 g
.52978 .69465 m
.53221 .69901 L
s
.52204 .69 m .52401 .69586 L .52734 .70171 L 0 1 .351 r
F
0 g
.52247 .6887 m
.52265 .68902 L
s
.52204 .69 m .52173 .69084 L .52401 .69586 L 0 1 .351 r
F
0 g
.52265 .68902 m
.525 .69323 L
s
.51316 .68036 m .52204 .69 L .51954 .68667 L 0 1 .359 r
F
.51316 .68036 m .52173 .69084 L .52204 .69 L F
0 g
.52001 .6851 m
.5231 .68641 L
s
.52204 .69 m
.525 .69323 L
s
.45951 .75402 m .45472 .76156 L .45819 .75816 L 0 1 .457 r
F
.45951 .75402 m .4506 .76232 L .45472 .76156 L F
.4642 .75912 m .45819 .75816 L .45472 .76156 L 0 1 .455 r
F
0 g
.45366 .76176 m
.45472 .76156 L
s
.45382 .7658 m
.45472 .76156 L
s
.51316 .68036 m .51316 .68036 L .51618 .67512 L 0 1 .356 r
F
.51316 .68036 m .51316 .68036 L .51618 .67512 L 0 0 .047 r
F
.51316 .68036 m .51316 .68036 L .51599 .67461 L 0 1 .354 r
F
.31964 .95189 m .3187 .95632 L .32202 .95488 L 0 1 .515 r
F
0 g
.32202 .95488 m
.32996 .95538 L
s
.31964 .95189 m .31111 .95531 L .3187 .95632 L 0 1 .515 r
F
0 g
.3187 .95632 m
.3219 .95916 L
s
.35035 .75108 m .34007 .73957 L .33838 .74631 L 0 1 .441 r
F
.35035 .75108 m .3442 .73847 L .34007 .73957 L F
.35035 .75108 m .3486 .7434 L .3442 .73847 L F
.36045 .74787 m .3486 .7434 L .35035 .75108 L 0 1 .434 r
F
0 g
.34865 .7578 m
.35035 .75108 L
s
.35035 .75108 m
.35466 .75582 L
s
.50422 .69211 m .49833 .69915 L .50182 .69482 L 0 0 .023 r
F
.50422 .69211 m .49528 .70319 L .49833 .69915 L F
0 g
.4962 .70153 m
.49833 .69915 L
s
.43816 .99146 m .43054 .98932 L .42348 .98904 L 0 1 .541 r
F
.44196 .9869 m .43816 .99146 L .44492 .99167 L F
.44196 .9869 m .43054 .98932 L .43816 .99146 L F
0 g
.43816 .99146 m
.44281 .9945 L
s
.48773 .74525 m .48011 .75125 L .47946 .75584 L 0 1 .43 r
F
0 g
.47591 .75791 m
.47946 .75584 L
s
.51316 .68036 m .51976 .67028 L .51599 .67604 L 0 0 .047 r
F
.51316 .68036 m .51976 .67028 L .52238 .66693 L 0 0 .05 r
F
0 g
.51977 .67027 m
.52049 .66935 L
s
.51316 .68036 m .51599 .67604 L .51976 .67028 L 0 0 .05 r
F
0 g
.5161 .67526 m
.51618 .67512 L
s
.51976 .67028 m
.5211 .66795 L
s
.51976 .67028 m
.51977 .67027 L
s
.40096 .7733 m .38986 .77015 L .38872 .7743 L 0 1 .498 r
F
.40096 .7733 m .39389 .76839 L .38986 .77015 L F
.40096 .7733 m .39865 .76975 L .39389 .76839 L F
0 g
.40025 .77589 m
.40096 .7733 L
s
.41111 .76804 m .39866 .76974 L .40096 .7733 L 0 1 .493 r
F
0 g
.40096 .7733 m
.40415 .774 L
s
.51316 .68035 m .51316 .68035 L .51578 .67418 L 0 1 .353 r
F
0 g
.51316 .68035 m
.51316 .68035 L
s
.46502 .7351 m .45938 .74011 L .46314 .73681 L 0 0 0 r
F
.46502 .7351 m .45542 .74324 L .45938 .74011 L F
0 g
.45787 .74185 m
.45938 .74011 L
s
.46399 .73609 m
.46706 .73349 L
s
.46314 .73681 m
.46399 .73609 L
s
.29375 .97294 m .27458 .96483 L .27763 .97021 L 0 1 .537 r
F
.29375 .97294 m .27818 .96366 L .27458 .96483 L F
.29375 .97294 m .2864 .96714 L .27818 .96366 L F
.30224 .96971 m .2864 .96714 L .29375 .97294 L F
0 g
.29375 .97294 m
.30172 .97626 L
s
.29375 .97294 m
.29676 .97829 L
s
.44956 .84347 m .44825 .8533 L .45065 .85026 L 0 .835 .401 r
F
.45961 .85841 m .45065 .85026 L .44825 .8533 L 0 .773 .4 r
F
0 g
.44825 .8533 m
.44984 .86013 L
s
.44329 .85094 m
.44825 .8533 L
s
.44583 .75077 m .43569 .7566 L .43421 .75825 L 0 .946 .221 r
F
.44583 .75077 m .43971 .75395 L .43569 .7566 L F
.44583 .75077 m .44405 .75145 L .43971 .75395 L F
.45542 .74324 m .44405 .75145 L .44583 .75077 L 0 .886 .191 r
F
0 g
.44583 .75077 m
.44997 .74797 L
s
.44434 .75242 m
.44583 .75077 L
s
.51316 .68036 m .51316 .68036 L .51105 .68257 L 0 0 .047 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.43965 .80588 m .43156 .81306 L .43633 .8155 L 0 .91 .392 r
F
0 g
.43156 .81306 m
.43163 .81975 L
s
.71371 .93183 m
.71457 .93037 L
s
.71355 .93209 m
.71371 .93183 L
s
.71258 .93373 m
.71355 .93209 L
s
.51316 .68036 m .52056 .67284 L .51633 .67714 L 0 .68 .284 r
F
.51316 .68036 m .51316 .68036 L .51653 .67706 L 0 1 .361 r
F
.51316 .68036 m .52384 .67167 L .52056 .67284 L 0 .68 .284 r
F
.51316 .68036 m .51633 .67714 L .52056 .67284 L 0 .696 .284 r
F
0 g
.52056 .67284 m
.52075 .67277 L
s
.52056 .67284 m
.52357 .66761 L
s
.45677 .69476 m .45281 .68669 L .44825 .68822 L 0 1 .343 r
F
.45677 .69476 m .45647 .68949 L .45281 .68669 L F
0 g
.45281 .68669 m
.45619 .68151 L
s
.52152 .75659 m .52288 .77327 L .5236 .77332 L 0 1 .403 r
F
.52152 .75659 m .52178 .76825 L .52288 .77327 L F
0 g
.52288 .77327 m
.52288 .77785 L
s
.51316 .68035 m .51316 .68035 L .51553 .67384 L 0 1 .353 r
F
0 g
.54229 .69526 m
.54269 .69533 L
s
.54269 .69533 m
.54583 .69582 L
s
.51316 .68036 m .51316 .68036 L .50973 .67795 L 0 .733 .285 r
F
0 g
.51097 .66743 m
.51276 .67801 L
s
.49109 .6902 m .48285 .68779 L .47972 .69207 L 0 .833 .308 r
F
0 g
.47934 .68603 m
.48285 .68779 L
s
.44476 .68503 m .44118 .67584 L .4366 .67707 L 0 1 .354 r
F
0 g
.44118 .67584 m
.44478 .67051 L
s
.44118 .67584 m
.44468 .67926 L
s
.4642 .75912 m .46226 .75711 L .45819 .75816 L 0 1 .455 r
F
.47234 .7494 m .4642 .75912 L .46803 .75764 L 0 1 .445 r
F
.47234 .7494 m .46226 .75711 L .4642 .75912 L F
0 g
.4633 .76336 m
.4642 .75912 L
s
.4642 .75912 m
.46726 .75794 L
s
.51316 .68036 m .52001 .6851 L .5161 .68239 L 0 1 .36 r
F
.51316 .68036 m .5161 .68239 L .52001 .6851 L 0 1 .361 r
F
0 g
.52001 .6851 m
.52274 .6878 L
s
.52001 .6851 m
.52001 .6851 L
s
.51316 .68036 m .519 .68814 L .52173 .69084 L 0 1 .359 r
F
.51316 .68036 m .50705 .68821 L .50468 .69101 L 0 0 .055 r
F
0 g
.50182 .69482 m
.50468 .69101 L
s
.44956 .84347 m .44572 .83745 L .44076 .83511 L 0 .835 .401 r
F
.49603 .75047 m .4943 .74954 L .4915 .75273 L 0 1 .425 r
F
0 g
.4915 .75273 m
.49153 .75269 L
s
.49153 .75269 m
.49155 .75267 L
s
.42653 .77556 m .41567 .7688 L .41452 .77532 L 0 1 .392 r
F
0 g
.40975 .77221 m
.41452 .77532 L
s
.41455 .77294 m
.41563 .76896 L
s
.53231 .69919 m .53957 .70847 L .53565 .70242 L 0 .954 .344 r
F
.53231 .69919 m .54191 .71475 L .53957 .70847 L F
.53231 .69919 m .54111 .71708 L .54191 .71475 L F
.53231 .69919 m .53777 .71384 L .54111 .71708 L F
.53231 .69919 m .53411 .70721 L .53777 .71384 L F
0 g
.53319 .69676 m
.53352 .69752 L
s
.53231 .69919 m .53178 .70093 L .53411 .70721 L 0 .954 .344 r
F
0 g
.53352 .69752 m
.53565 .70242 L
s
.53221 .69901 m
.53231 .69919 L
s
.53231 .69919 m
.53565 .70242 L
s
.47234 .7494 m .46803 .75764 L .47118 .75367 L 0 1 .445 r
F
.47667 .75352 m .47118 .75367 L .46803 .75764 L 0 1 .443 r
F
0 g
.46727 .76203 m
.46803 .75764 L
s
.46726 .75794 m
.46803 .75764 L
s
.51316 .68035 m .51316 .68035 L .51526 .67359 L 0 1 .353 r
F
.50708 .73817 m .50505 .75421 L .50694 .74981 L 0 1 .408 r
F
.50708 .73817 m .50321 .75359 L .50505 .75421 L F
0 g
.50505 .75421 m
.50593 .75913 L
s
.50708 .73817 m .50267 .74844 L .50321 .75359 L 0 1 .408 r
F
0 g
.50097 .7574 m
.50321 .75359 L
s
.54579 1.01767 m
.54658 1.01811 L
s
.54716 1.01843 m
.54722 1.01847 L
s
.46806 .69026 m .46037 .69725 L .46487 .69529 L 0 .971 .331 r
F
.46806 .69026 m .45677 .69476 L .46037 .69725 L F
.46806 .69026 m .45647 .68949 L .45677 .69476 L F
0 g
.45281 .68669 m
.45647 .68949 L
s
.45647 .68949 m
.45966 .68446 L
s
.4506 .76232 m .44425 .76034 L .44049 .76325 L 0 1 .467 r
F
.4506 .76232 m .44858 .75995 L .44425 .76034 L F
.45951 .75402 m .44858 .75995 L .4506 .76232 L 0 1 .457 r
F
0 g
.44951 .76647 m
.4506 .76232 L
s
.4506 .76232 m
.45366 .76176 L
s
.43418 .65773 m .42576 .6642 L .43033 .66321 L 0 1 .362 r
F
0 g
.43475 .66538 m
.43717 .66179 L
s
.43418 .65773 m .42282 .66002 L .42576 .6642 L 0 1 .362 r
F
.43418 .65773 m .42348 .65346 L .42282 .66002 L F
.43418 .65773 m .42734 .64798 L .42348 .65346 L F
.43418 .65773 m .43183 .64723 L .42734 .64798 L F
0 g
.43183 .64723 m
.43476 .65141 L
s
.43418 .65773 m
.43717 .66179 L
s
.43183 .64723 m
.43588 .64183 L
s
.51316 .68035 m .5139 .65895 L .51343 .66556 L 0 1 .36 r
F
0 g
.5139 .65896 m
.5139 .65895 L
s
.51271 .66002 m .51319 .65957 L .51366 .65311 L 0 1 .356 r
F
0 g
.51366 .65311 m
.5139 .65895 L
s
.51316 .68036 m .51316 .68036 L .51658 .67781 L 0 1 .363 r
F
.39584 .98259 m .37746 .98026 L .38076 .9844 L 0 1 .539 r
F
0 g
.373 .983 m
.38076 .9844 L
s
.5191 .75657 m .51723 .7565 L .51602 .76127 L 0 1 .408 r
F
.51057 .73883 m .50784 .75501 L .50971 .75545 L 0 1 .405 r
F
.51057 .73883 m .50694 .74981 L .50784 .75501 L F
0 g
.50593 .75913 m
.50784 .75501 L
s
.50713 .7509 m
.50784 .75501 L
s
.52152 .75659 m .5236 .77332 L .52348 .76832 L 0 1 .403 r
F
0 g
.52058 .77301 m
.52178 .76825 L
s
.5236 .77332 m
.5248 .77803 L
s
.22049 .81263 m .20595 .80898 L .20978 .81467 L 0 1 .539 r
F
0 g
.20978 .81467 m
.21582 .81824 L
s
.50364 .73712 m .50047 .75254 L .50267 .74844 L 0 1 .411 r
F
.50364 .73712 m .49868 .75176 L .50047 .75254 L F
0 g
.50047 .75254 m
.50097 .7574 L
s
.51316 .68035 m .51426 .66493 L .51363 .67374 L 0 1 .358 r
F
.51316 .68035 m .51363 .67374 L .51426 .66493 L 0 1 .36 r
F
0 g
.51426 .66493 m
.51506 .65825 L
s
.51426 .66493 m
.51426 .6649 L
s
.43785 .5599 m .43111 .56275 L .43457 .56215 L 0 1 .348 r
F
.43785 .5599 m .42927 .56143 L .43111 .56275 L F
0 g
.43656 .56548 m
.43974 .56149 L
s
.43785 .5599 m .43029 .55906 L .42927 .56143 L 0 1 .348 r
F
.43785 .5599 m .43358 .55682 L .43029 .55906 L F
.43785 .5599 m .43693 .55619 L .43358 .55682 L F
0 g
.43693 .55619 m
.43876 .55751 L
s
.43457 .56215 m
.43785 .5599 L
s
.43785 .5599 m
.43974 .56148 L
s
.51316 .68036 m .52238 .66693 L .52209 .66822 L 0 0 .05 r
F
0 g
.52238 .66693 m
.52243 .66684 L
s
.52049 .66935 m
.52238 .66693 L
s
.51226 .64098 m .5142 .62617 L .51324 .62241 L 0 1 .348 r
F
0 g
.51325 .63946 m
.51404 .63341 L
s
.5142 .62617 m
.51538 .6191 L
s
.43139 .60963 m .4227 .61574 L .42691 .61523 L 0 1 .363 r
F
.43139 .60963 m .42101 .61082 L .4227 .61574 L F
0 g
.43065 .61787 m
.43322 .61461 L
s
.43139 .60963 m .42299 .60375 L .42101 .61082 L 0 1 .363 r
F
.43139 .60963 m .42748 .59815 L .42299 .60375 L F
.43139 .60963 m .43147 .59775 L .42748 .59815 L F
0 g
.43139 .60963 m
.43322 .61461 L
s
.43147 .59775 m
.43604 .59207 L
s
.43147 .59775 m
.43315 .60266 L
s
.51316 .68035 m .51316 .68035 L .51497 .67344 L 0 1 .353 r
F
.51271 .66002 m .51321 .63976 L .51226 .64098 L 0 1 .356 r
F
0 g
.51321 .63976 m
.51381 .64495 L
s
.51321 .63976 m
.51325 .63946 L
s
.51319 .65949 m
.51366 .65311 L
s
.51319 .65949 m
.51319 .65949 L
s
.51319 .65949 m
.51319 .65949 L
s
.52125 .69204 m .52734 .70171 L .52401 .69586 L 0 1 .354 r
F
.52125 .69204 m .52933 .70712 L .52734 .70171 L F
.52125 .69204 m .52865 .70847 L .52933 .70712 L F
.52125 .69204 m .52589 .70466 L .52865 .70847 L F
.52125 .69204 m .52289 .69821 L .52589 .70466 L F
0 g
.52311 .69461 m
.52401 .69586 L
s
.52173 .69084 m
.52185 .6911 L
s
.52365 .69507 m
.52401 .69586 L
s
.52315 .69398 m
.52365 .69507 L
s
.52125 .69204 m .5209 .69281 L .52289 .69821 L 0 1 .354 r
F
0 g
.52185 .6911 m
.52315 .69398 L
s
.51316 .68036 m .52125 .69204 L .519 .68814 L 0 1 .359 r
F
.51316 .68036 m .5209 .69281 L .52125 .69204 L F
0 g
.51954 .68667 m
.52247 .6887 L
s
.52125 .69204 m
.52311 .69461 L
s
.40639 .74935 m .40022 .75773 L .40443 .75577 L 0 1 .401 r
F
.40639 .74935 m .39575 .75411 L .40022 .75773 L F
.41115 .76566 m .40443 .75577 L .40022 .75773 L F
0 g
.39876 .76423 m
.40022 .75773 L
s
.54583 .69582 m
.54679 .69832 L
s
.51057 .73883 m .50971 .75545 L .51127 .75075 L 0 1 .405 r
F
0 g
.50971 .75545 m
.51096 .76043 L
s
.51316 .68036 m .51316 .68036 L .51659 .67858 L 0 1 .364 r
F
.39575 .75411 m .38532 .74499 L .38362 .75144 L 0 1 .411 r
F
.50364 .73712 m .49851 .74668 L .49868 .75176 L F
0 g
.49615 .75526 m
.49868 .75176 L
s
.50276 .74925 m
.50321 .75359 L
s
.51316 .68036 m .51954 .68667 L .5159 .68307 L 0 1 .359 r
F
.51316 .68036 m .5159 .68307 L .51954 .68667 L 0 1 .36 r
F
0 g
.51954 .68667 m
.52204 .69 L
s
.51954 .68667 m
.51954 .68667 L
s
.52384 .67167 m .53181 .67649 L .53486 .6712 L 0 .602 .272 r
F
.52384 .67167 m .52742 .67647 L .53181 .67649 L F
.52384 .67167 m .52401 .67441 L .52742 .67647 L F
.51316 .68036 m .52401 .67441 L .52384 .67167 L 0 .68 .284 r
F
0 g
.52384 .67167 m
.52689 .6664 L
s
.52075 .67277 m
.52384 .67167 L
s
.52882 .69876 m
.52912 .69942 L
s
.52864 .69838 m
.52882 .69876 L
s
.5299 .6994 m
.53178 .70093 L
s
.52864 .69838 m
.5299 .6994 L
s
.45961 .85841 m .45434 .86622 L .45921 .86842 L 0 .773 .4 r
F
.5191 .75657 m .52178 .76825 L .52105 .76161 L 0 1 .408 r
F
0 g
.52178 .76825 m
.52178 .76825 L
s
.52152 .75659 m .52105 .76161 L .52178 .76825 L 0 1 .403 r
F
0 g
.52178 .76825 m
.52288 .77327 L
s
.45778 .91564 m .44473 .92186 L .44791 .92199 L 0 1 .376 r
F
0 g
.44202 .92464 m
.44791 .92199 L
s
.28038 .74694 m .27388 .75542 L .27827 .75445 L 0 1 .472 r
F
.28038 .74694 m .26932 .7492 L .27388 .75542 L F
0 g
.27261 .763 m
.27388 .75542 L
s
.27827 .75445 m
.28349 .76041 L
s
.35563 .77971 m .34424 .77379 L .34324 .7783 L 0 1 .514 r
F
.35563 .77971 m .34825 .7726 L .34424 .77379 L F
.35563 .77971 m .35314 .77514 L .34825 .7726 L F
.36538 .77621 m .35314 .77514 L .35563 .77971 L 0 1 .511 r
F
0 g
.35462 .7842 m
.35563 .77971 L
s
.35563 .77971 m
.36039 .78203 L
s
.48005 .69607 m .47611 .6905 L .47161 .6924 L 0 .887 .32 r
F
.48005 .69607 m .47972 .69207 L .47611 .6905 L F
0 g
.47611 .6905 m
.47934 .68603 L
s
.51316 .68035 m .51316 .68035 L .51465 .67339 L 0 1 .355 r
F
.51316 .68036 m .5184 .68948 L .5209 .69281 L 0 1 .359 r
F
0 g
.519 .68814 m
.52125 .69204 L
s
.519 .68814 m
.52173 .69084 L
s
.7126 .93436 m
.71371 .93183 L
s
.71371 .93183 m
.71374 .93176 L
s
.71374 .93176 m
.71377 .93168 L
s
.71377 .93168 m
.71434 .93039 L
s
.79115 .78235 m .79385 .79089 L .79943 .79158 L 0 .468 .352 r
F
0 g
.79385 .79089 m
.79406 .7956 L
s
.51316 .68036 m .51316 .68036 L .51656 .67936 L 0 1 .364 r
F
.51316 .68036 m .5053 .68119 L .50979 .68072 L 0 .723 .285 r
F
.51316 .68036 m .5053 .68119 L .50202 .68292 L 0 .712 .284 r
F
.51316 .68036 m .50979 .68072 L .5053 .68119 L F
0 g
.50189 .68017 m
.5053 .68119 L
s
.30947 .77883 m .30205 .78547 L .30729 .78409 L 0 1 .522 r
F
.30947 .77883 m .29624 .78204 L .30205 .78547 L F
0 g
.30068 .79086 m
.30205 .78547 L
s
.30729 .78409 m
.31361 .78718 L
s
.47819 .89648 m .46985 .89774 L .4752 .90387 L 0 .656 .404 r
F
.47819 .89648 m .46696 .89098 L .46985 .89774 L F
0 g
.46472 .89516 m
.46985 .89774 L
s
.6464 .53372 m
.64655 .54368 L
s
.64626 .52448 m
.6464 .53372 L
s
.64655 .54368 m
.64663 .54901 L
s
.64663 .54901 m
.64669 .5531 L
s
.64672 .55459 m
.64672 .5549 L
s
.64675 .55677 m
.64677 .55802 L
s
.39912 .98673 m
.40698 .98721 L
s
.53474 .55814 m .53789 .55017 L .54144 .54658 L 0 .007 .086 r
F
0 g
.53789 .55017 m
.53906 .54482 L
s
.51316 .68036 m .50202 .68292 L .50213 .68474 L 0 .712 .284 r
F
0 g
.50202 .68292 m
.5053 .68119 L
s
.49857 .68253 m
.50202 .68292 L
s
.50213 .68474 m .49087 .68711 L .49109 .6902 L 0 .775 .296 r
F
0 g
.48734 .68608 m
.49087 .68711 L
s
.49087 .68711 m
.49408 .68382 L
s
.39575 .75411 m .38951 .74339 L .38532 .74499 L 0 1 .411 r
F
.39575 .75411 m .39398 .7473 L .38951 .74339 L F
0 g
.39404 .76055 m
.39575 .75411 L
s
.40639 .74935 m .39399 .7473 L .39575 .75411 L 0 1 .401 r
F
0 g
.39575 .75411 m
.40022 .75773 L
s
.5141 .73907 m .51253 .75599 L .51441 .75625 L 0 1 .401 r
F
.5141 .73907 m .51127 .75075 L .51253 .75599 L F
0 g
.51096 .76043 m
.51253 .75599 L
s
.3262 .79876 m .31378 .79625 L .31323 .79901 L 0 1 .503 r
F
.3262 .79876 m .31778 .79527 L .31378 .79625 L F
.3262 .79876 m .32311 .79635 L .31778 .79527 L F
.33591 .79574 m .32311 .79635 L .3262 .79876 L 0 1 .492 r
F
0 g
.32564 .80151 m
.3262 .79876 L
s
.3262 .79876 m
.33139 .79959 L
s
.35539 .78941 m .35058 .79298 L .35443 .79161 L 0 1 .46 r
F
.35539 .78941 m .34564 .79263 L .35058 .79298 L F
0 g
.35027 .79531 m
.35058 .79298 L
s
.35443 .79161 m
.35973 .79168 L
s
.42653 .77556 m .42162 .78461 L .42537 .78209 L 0 1 .392 r
F
.43267 .79083 m .42537 .78209 L .42162 .78461 L 0 .958 .392 r
F
0 g
.42095 .79122 m
.42162 .78461 L
s
.41697 .78171 m
.42162 .78461 L
s
.44476 .68503 m .43683 .69208 L .4414 .69053 L 0 1 .354 r
F
.44476 .68503 m .43333 .68867 L .43683 .69208 L F
.44476 .68503 m .43323 .68256 L .43333 .68867 L F
.44476 .68503 m .4366 .67707 L .43323 .68256 L F
.51316 .68036 m .51316 .68036 L .5165 .68015 L 0 1 .364 r
F
0 g
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .50974 .67934 L 0 .723 .285 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.50031 .73571 m .49603 .75047 L .49851 .74668 L 0 1 .413 r
F
.50031 .73571 m .4943 .74954 L .49603 .75047 L F
0 g
.49603 .75047 m
.49615 .75526 L
s
.38114 .74087 m .37484 .74885 L .37903 .74733 L 0 1 .419 r
F
.38114 .74087 m .37057 .74452 L .37484 .74885 L F
0 g
.37326 .75538 m
.37484 .74885 L
s
.37903 .74733 m
.38362 .75144 L
s
.51316 .68035 m .51316 .68035 L .51433 .67342 L 0 1 .356 r
F
.51316 .68035 m .51319 .65957 L .51271 .66002 L 0 1 .363 r
F
0 g
.51097 .66743 m
.51283 .67837 L
s
.51289 .67703 m
.51299 .67824 L
s
.51283 .67629 m
.513 .67839 L
s
.51316 .68035 m .51343 .66556 L .51319 .65957 L 0 1 .363 r
F
0 g
.51319 .65957 m
.51319 .65949 L
s
.51319 .65957 m
.51343 .6655 L
s
.51749 .96455 m .51082 .96388 L .51777 .97068 L 0 .379 .37 r
F
0 g
.50576 .95706 m
.51082 .96388 L
s
.50548 .96031 m
.51082 .96388 L
s
.51316 .68036 m .519 .68814 L .51567 .68369 L 0 1 .359 r
F
.51316 .68036 m .51567 .68369 L .519 .68814 L F
0 g
.519 .68814 m
.519 .68814 L
s
.519 .68814 m
.519 .68814 L
s
.45677 .69476 m .44825 .68822 L .44511 .69363 L 0 1 .343 r
F
0 g
.44476 .68503 m
.44825 .68822 L
s
.52037 .6939 m .52589 .70466 L .52289 .69821 L 0 1 .356 r
F
.52037 .6939 m .52757 .71036 L .52589 .70466 L F
.52037 .6939 m .52682 .71153 L .52757 .71036 L F
.52037 .6939 m .52429 .70721 L .52682 .71153 L F
.52037 .6939 m .52167 .70029 L .52429 .70721 L F
0 g
.5209 .69281 m
.52099 .69304 L
s
.52037 .6939 m .51999 .69459 L .52167 .70029 L 0 1 .356 r
F
0 g
.52099 .69304 m
.52289 .69821 L
s
.51316 .68036 m .52037 .6939 L .5184 .68948 L 0 1 .358 r
F
.51316 .68036 m .51999 .69459 L .52037 .6939 L F
0 g
.52037 .6939 m
.52289 .69821 L
s
.78279 .67641 m .78582 .68998 L .7904 .69198 L 0 1 .497 r
F
.78279 .67641 m .78256 .68332 L .78582 .68998 L F
0 g
.78139 .69423 m
.78582 .68998 L
s
.79657 .88371 m .79131 .89289 L .79032 .89988 L 0 1 .512 r
F
0 g
.78256 .90593 m
.79032 .89988 L
s
.4474 .82072 m .43663 .82227 L .44018 .82837 L 0 .859 .391 r
F
.4474 .82072 m .43633 .8155 L .43663 .82227 L F
0 g
.43163 .81975 m
.43663 .82227 L
s
.41115 .76566 m .40911 .75916 L .40443 .75577 L 0 1 .401 r
F
.4213 .76006 m .41115 .76566 L .41567 .7688 L 0 1 .391 r
F
.4213 .76006 m .40911 .75916 L .41115 .76566 L F
0 g
.41059 .76811 m
.41115 .76566 L
s
.44196 .9869 m .44492 .99167 L .44632 .98981 L 0 1 .541 r
F
.46048 .99084 m .44632 .98981 L .44492 .99167 L 0 1 .542 r
F
0 g
.44492 .99167 m
.44978 .9942 L
s
.43816 .99146 m
.44492 .99167 L
s
.47257 .72809 m
.47627 .72449 L
s
.21411 .75983 m .20077 .75122 L .20308 .76186 L 0 1 .49 r
F
0 g
.20308 .76186 m
.20809 .76916 L
s
.50866 .49981 m .51726 .47221 L .51345 .47997 L 0 .887 .118 r
F
0 g
.51726 .47221 m
.52037 .46242 L
s
.78584 .59343 m .79234 .59098 L .79696 .59414 L 0 .116 0 r
F
.78584 .59343 m .78757 .59067 L .79234 .59098 L F
0 g
.78933 .58831 m
.79234 .59098 L
s
.51316 .68036 m .51316 .68036 L .51079 .68316 L 0 0 .051 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .5164 .68092 L 0 1 .363 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51318 .68036 L
s
.43267 .79083 m .42853 .80018 L .43199 .79745 L 0 .958 .392 r
F
.43965 .80588 m .43199 .79745 L .42853 .80018 L 0 .91 .392 r
F
0 g
.42835 .80687 m
.42853 .80018 L
s
.4238 .79751 m
.42853 .80018 L
s
.5141 .73907 m .51441 .75625 L .51562 .75125 L 0 1 .401 r
F
0 g
.51441 .75625 m
.51602 .76127 L
s
.50708 .73817 m .50694 .74981 L .50761 .74332 L 0 1 .408 r
F
.51057 .73883 m .50761 .74332 L .50694 .74981 L 0 1 .405 r
F
0 g
.50694 .74981 m
.50713 .7509 L
s
.50505 .75421 m
.50694 .74981 L
s
.48005 .69607 m .47161 .6924 L .46857 .69732 L 0 .887 .32 r
F
0 g
.46806 .69026 m
.47161 .6924 L
s
.51316 .68035 m .51343 .66556 L .51328 .67401 L 0 1 .36 r
F
.51316 .68035 m .51328 .67401 L .51343 .66556 L 0 1 .363 r
F
0 g
.51343 .6655 m
.51343 .66556 L
s
.51343 .66556 m
.5139 .65896 L
s
.54684 .54502 m .55441 .53458 L .55651 .54274 L 0 .23 .128 r
F
0 g
.55441 .53458 m
.55526 .51872 L
s
.55028 .53556 m
.55441 .53458 L
s
.51316 .68036 m .51775 .69068 L .51999 .69459 L 0 1 .358 r
F
0 g
.5184 .68948 m
.52037 .6939 L
s
.5184 .68948 m
.5209 .69281 L
s
.53092 .7034 m .53777 .71384 L .53411 .70721 L 0 .974 .348 r
F
.53092 .7034 m .53982 .72031 L .53777 .71384 L F
.53092 .7034 m .5389 .72228 L .53982 .72031 L F
.53092 .7034 m .5357 .71846 L .5389 .72228 L F
.53092 .7034 m .53235 .7114 L .5357 .71846 L F
0 g
.53178 .70093 m
.53211 .70182 L
s
.53092 .7034 m .53031 .70494 L .53235 .7114 L 0 .974 .348 r
F
0 g
.52912 .69942 m
.53092 .7034 L
s
.53211 .70182 m
.53335 .70516 L
s
.53092 .7034 m
.53307 .70596 L
s
.50364 .73712 m .50267 .74844 L .5038 .74219 L 0 1 .411 r
F
.50708 .73817 m .5038 .74219 L .50267 .74844 L 0 1 .408 r
F
0 g
.50047 .75254 m
.50267 .74844 L
s
.50267 .74844 m
.50276 .74925 L
s
.52152 .75659 m .52348 .76832 L .52261 .76161 L 0 1 .403 r
F
0 g
.52348 .76832 m
.5236 .77332 L
s
.52518 .7562 m .52349 .76832 L .52588 .77336 L 0 1 .401 r
F
.52518 .7562 m .52261 .76161 L .52349 .76832 L F
0 g
.52349 .76832 m
.52388 .76915 L
s
.69624 .92952 m .70734 .931 L .70384 .92913 L 0 1 .531 r
F
.68771 .92442 m .69624 .92952 L .69859 .92627 L 0 1 .527 r
F
.49528 .70319 m .48766 .7125 L .48548 .71478 L 0 0 0 r
F
.49528 .70319 m .49144 .70825 L .48766 .7125 L F
.49528 .70319 m .49471 .70426 L .49144 .70825 L F
.50422 .69211 m .49471 .70426 L .49528 .70319 L 0 0 .023 r
F
0 g
.49528 .70319 m
.49833 .69915 L
s
.4931 .70547 m
.49528 .70319 L
s
.50031 .73571 m .49451 .74455 L .4943 .74954 L 0 1 .413 r
F
0 g
.49155 .75267 m
.4943 .74954 L
s
.49853 .7472 m
.49868 .75176 L
s
.51316 .68035 m .51316 .68035 L .51398 .67354 L 0 1 .358 r
F
.51316 .68036 m .51316 .68036 L .51627 .68167 L 0 1 .362 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.52518 .7562 m .52588 .77336 L .52819 .77338 L 0 1 .401 r
F
0 g
.5248 .77803 m
.52588 .77336 L
s
.52388 .76915 m
.52588 .77336 L
s
.36045 .74787 m .35039 .73678 L .3486 .7434 L 0 1 .434 r
F
.36045 .74787 m .35452 .73563 L .35039 .73678 L F
.36045 .74787 m .35883 .74038 L .35452 .73563 L F
.37056 .74452 m .35883 .74038 L .36045 .74787 L 0 1 .427 r
F
0 g
.35866 .75448 m
.36045 .74787 L
s
.36045 .74787 m
.36467 .75243 L
s
.52734 .70171 m
.52814 .70389 L
s
.52734 .70171 m
.53031 .70494 L
s
.47667 .75352 m .47489 .75191 L .47118 .75367 L 0 1 .443 r
F
.48395 .74214 m .47667 .75352 L .48011 .75125 L 0 1 .432 r
F
.48395 .74214 m .47489 .75191 L .47667 .75352 L F
0 g
.47591 .75791 m
.47667 .75352 L
s
.47667 .75352 m
.47977 .75148 L
s
.51316 .68036 m .5184 .68948 L .51541 .68427 L 0 1 .358 r
F
.51316 .68036 m .51541 .68427 L .5184 .68948 L 0 1 .359 r
F
0 g
.5184 .68948 m
.5184 .68948 L
s
.5184 .68948 m
.5184 .68948 L
s
.44577 .7563 m .44049 .76325 L .44425 .76034 L 0 1 .469 r
F
.44577 .7563 m .43618 .76338 L .44049 .76325 L F
0 g
.43941 .76739 m
.44049 .76325 L
s
.46601 .88138 m .46696 .89098 L .46845 .88809 L 0 .736 .409 r
F
.47819 .89648 m .46845 .88809 L .46696 .89098 L 0 .656 .404 r
F
0 g
.46696 .89098 m
.46985 .89774 L
s
.46198 .88855 m
.46696 .89098 L
s
.51057 .73883 m .51127 .75075 L .51147 .74403 L 0 1 .405 r
F
.5141 .73907 m .51147 .74403 L .51127 .75075 L 0 1 .401 r
F
0 g
.51127 .75075 m
.51253 .75599 L
s
.50971 .75545 m
.51127 .75075 L
s
.51316 .68036 m .51316 .68036 L .51599 .67604 L 0 0 .05 r
F
.51271 .66002 m .51179 .64744 L .51211 .65482 L 0 1 .356 r
F
.51271 .66002 m .51226 .64098 L .51179 .64744 L F
.51316 .68035 m .51271 .66002 L .5126 .66636 L 0 1 .363 r
F
0 g
.51222 .66433 m
.5131 .67927 L
s
.5131 .67927 m
.5131 .67928 L
s
.5131 .67928 m
.5131 .6793 L
s
.51257 .66393 m
.51262 .6653 L
s
.51257 .66393 m
.51262 .6653 L
s
.51125 .66647 m
.51305 .67951 L
s
.51305 .67951 m
.51305 .67952 L
s
.51125 .66647 m
.51303 .67942 L
s
.51303 .67942 m
.51303 .67943 L
s
.53226 .78469 m
.53302 .78592 L
s
.43333 .67333 m .43357 .66712 L .43033 .66321 L 0 1 .364 r
F
0 g
.43357 .66712 m
.43475 .66538 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51633 .67714 L 0 .696 .284 r
F
0 g
.51369 .67945 m
.51371 .67941 L
s
.51371 .67941 m
.51618 .67512 L
s
.49177 .74803 m .49012 .74696 L .48707 .74984 L 0 1 .428 r
F
.51316 .68036 m .51316 .68036 L .5161 .68239 L 0 1 .361 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.53474 .55814 m .54144 .54658 L .54304 .54975 L 0 .007 .086 r
F
0 g
.54144 .54658 m
.5425 .53655 L
s
.53789 .55017 m
.54144 .54658 L
s
.51941 .69556 m .52429 .70721 L .52167 .70029 L 0 1 .359 r
F
.51941 .69556 m .52565 .71313 L .52429 .70721 L F
.51941 .69556 m .52484 .71411 L .52565 .71313 L F
.51941 .69556 m .52258 .70938 L .52484 .71411 L F
.51941 .69556 m .52036 .70209 L .52258 .70938 L F
0 g
.51999 .69459 m
.52005 .69479 L
s
.51941 .69556 m .519 .69617 L .52036 .70209 L 0 1 .359 r
F
0 g
.52005 .69479 m
.52167 .70029 L
s
.51316 .68036 m .51941 .69556 L .51775 .69068 L 0 1 .358 r
F
.51316 .68036 m .519 .69617 L .51941 .69556 L F
0 g
.51941 .69556 m
.52167 .70029 L
s
.25803 .95519 m .23873 .9538 L .24145 .95609 L 0 1 .408 r
F
.25803 .95519 m .24258 .95282 L .23873 .9538 L F
.25803 .95519 m .25087 .95341 L .24258 .95282 L F
.2672 .95223 m .25087 .95341 L .25803 .95519 L 0 1 .384 r
F
0 g
.25803 .95519 m
.26607 .95556 L
s
.25803 .95519 m
.2607 .95747 L
s
.4213 .76006 m .41567 .7688 L .41967 .76649 L 0 1 .391 r
F
.42127 .76245 m .41567 .7688 L .41967 .76649 L 0 1 .487 r
F
.42127 .76245 m .41111 .76804 L .41567 .7688 L F
0 g
.41115 .76566 m
.41304 .76697 L
s
.42123 .76485 m .41567 .7688 L .41967 .76649 L 0 1 .26 r
F
.42123 .76485 m .41107 .77043 L .41567 .7688 L F
0 g
.41973 .76647 m
.41981 .76643 L
s
.41981 .76643 m
.41991 .76639 L
s
.42653 .77556 m .41967 .76649 L .41567 .7688 L 0 1 .392 r
F
0 g
.41549 .76886 m
.41567 .7688 L
s
.41452 .77532 m
.41567 .7688 L
s
.41563 .76896 m
.41567 .7688 L
s
.41459 .77055 m
.41567 .7688 L
s
.51316 .68036 m .50705 .68821 L .51054 .68373 L 0 0 .057 r
F
.51316 .68036 m .50422 .69211 L .50705 .68821 L F
.51316 .68036 m .51054 .68373 L .50705 .68821 L 0 0 .055 r
F
0 g
.50468 .69101 m
.50705 .68821 L
s
.51316 .68035 m .51316 .68035 L .51363 .67374 L 0 1 .36 r
F
0 g
.51331 .6801 m
.5161 .67526 L
s
.51331 .68011 m
.51369 .67945 L
s
.51334 .68005 m
.51618 .67512 L
s
.51333 .67989 m
.51553 .67384 L
s
.51334 .67987 m
.51553 .67384 L
s
.51328 .68015 m
.51334 .68005 L
s
.51338 .6803 m
.51656 .67936 L
s
.51338 .6803 m
.51338 .6803 L
s
.51338 .6803 m
.51338 .6803 L
s
.51335 .6803 m
.51656 .67936 L
s
.51335 .6803 m
.51335 .6803 L
s
.51335 .6803 m
.51335 .6803 L
s
.48131 .98819 m .46684 .99048 L .47184 .99236 L 0 1 .54 r
F
0 g
.46533 .99338 m
.47184 .99236 L
s
.41983 .76651 m
.41998 .76652 L
s
.43618 .76338 m .42567 .76291 L .42436 .76699 L 0 1 .477 r
F
0 g
.41998 .76652 m
.42436 .76699 L
s
.41991 .76639 m
.42439 .76459 L
s
.49109 .6902 m .47972 .69207 L .48005 .69607 L 0 .833 .308 r
F
0 g
.47611 .6905 m
.47972 .69207 L
s
.47972 .69207 m
.48285 .68779 L
s
.77404 .9328 m .76951 .94212 L .77723 .9399 L 0 1 .532 r
F
.77404 .9328 m .76577 .9408 L .76951 .94212 L F
0 g
.76659 .94618 m
.76951 .94212 L
s
.2712 .96745 m
.27763 .97021 L
s
.50911 .5119 m .51342 .48638 L .50866 .49981 L 0 1 .143 r
F
0 g
.51342 .48638 m
.51687 .47989 L
s
.51342 .48638 m
.51493 .48154 L
s
.52152 .75659 m .52094 .75661 L .52105 .76161 L 0 1 .403 r
F
0 g
.52105 .7616 m
.52105 .76161 L
s
.47234 .7494 m .46341 .75284 L .46226 .75711 L 0 1 .445 r
F
0 g
.45819 .75816 m
.46226 .75711 L
s
.51761 .73888 m .51723 .7565 L .5191 .75657 L 0 1 .397 r
F
.51761 .73888 m .51562 .75125 L .51723 .7565 L F
0 g
.51602 .76127 m
.51723 .7565 L
s
.39179 .9391 m .39194 .94241 L .39445 .94072 L 0 1 .465 r
F
.39179 .9391 m .38526 .94317 L .39194 .94241 L F
0 g
.39194 .94241 m
.39523 .94383 L
s
.50031 .73571 m .49851 .74668 L .5001 .74069 L 0 1 .413 r
F
.50364 .73712 m .5001 .74069 L .49851 .74668 L 0 1 .411 r
F
0 g
.49603 .75047 m
.49851 .74668 L
s
.49851 .74668 m
.49853 .7472 L
s
.51316 .68036 m .51316 .68036 L .5159 .68307 L 0 1 .36 r
F
0 g
.51317 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m .51704 .69174 L .519 .69617 L 0 1 .358 r
F
0 g
.51775 .69068 m
.51941 .69556 L
s
.51775 .69069 m
.51999 .69459 L
s
.51226 .64098 m .51098 .63101 L .51131 .63723 L 0 1 .348 r
F
.51226 .64098 m .51181 .62466 L .51098 .63101 L F
.51226 .64098 m .51324 .62241 L .51181 .62466 L F
.51316 .68036 m .51775 .69068 L .51513 .68478 L 0 1 .358 r
F
.51316 .68036 m .51513 .68478 L .51775 .69068 L F
0 g
.51775 .69068 m
.51775 .69068 L
s
.51775 .69068 m
.51775 .69069 L
s
.48395 .74214 m .48011 .75125 L .48292 .74661 L 0 1 .432 r
F
.48773 .74525 m .48292 .74661 L .48011 .75125 L 0 1 .43 r
F
0 g
.47946 .75584 m
.48011 .75125 L
s
.47977 .75148 m
.48011 .75125 L
s
.48707 .74984 m
.48778 .74917 L
s
.64915 .51126 m
.64999 .53155 L
s
.4213 .76006 m .41074 .75273 L .40911 .75916 L 0 1 .391 r
F
0 g
.40443 .75577 m
.40911 .75916 L
s
.51316 .68036 m .51316 .68036 L .50979 .68072 L 0 .712 .284 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.29144 .74462 m .28487 .75298 L .28926 .75199 L 0 1 .468 r
F
.29144 .74462 m .28038 .74694 L .28487 .75298 L F
0 g
.28349 .76041 m
.28487 .75298 L
s
.28926 .75199 m
.29437 .75777 L
s
.76296 .57766 m .77605 .58236 L .7744 .58616 L 0 .27 .022 r
F
0 g
.77605 .58236 m
.78076 .58225 L
s
.7738 .57638 m
.77605 .58236 L
s
.45677 .69476 m .44913 .70211 L .45363 .70017 L 0 1 .343 r
F
.45677 .69476 m .44548 .6993 L .44913 .70211 L F
.45677 .69476 m .44511 .69363 L .44548 .6993 L F
.51316 .68036 m .51316 .68036 L .51567 .68369 L 0 1 .359 r
F
0 g
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.41938 .98569 m .40286 .98386 L .40698 .98721 L 0 1 .54 r
F
.68811 .93862 m .68993 .94281 L .69649 .93811 L 0 1 .456 r
F
0 g
.68268 .94633 m
.68993 .94281 L
s
.68904 .94409 m
.68993 .94281 L
s
.70415 1.07726 m .71675 1.07726 L .71398 1.07677 L 0 .95 .341 r
F
.72859 1.07351 m .71675 1.07726 L .72623 1.07613 L 0 .894 .3 r
F
.72859 1.07351 m .71398 1.07677 L .71675 1.07726 L F
0 g
.71082 1.07869 m
.71675 1.07726 L
s
.73501 .58104 m .74241 .56475 L .74697 .56909 L 0 .347 .088 r
F
.73501 .58104 m .7373 .56984 L .74241 .56475 L F
0 g
.74004 .5557 m
.74241 .56475 L
s
.49711 .73395 m .49177 .74803 L .49451 .74455 L 0 1 .416 r
F
.49711 .73395 m .49012 .74696 L .49177 .74803 L F
0 g
.4915 .75273 m
.49177 .74803 L
s
.50213 .68474 m .49454 .6906 L .49892 .68803 L 0 .775 .296 r
F
.50213 .68474 m .49109 .6902 L .49454 .6906 L F
.51316 .68036 m .50213 .68474 L .50549 .68438 L 0 .712 .284 r
F
0 g
.51105 .68257 m
.51266 .68088 L
s
.51105 .68257 m
.51275 .68079 L
s
.469 .70199 m .46487 .69529 L .46037 .69725 L 0 .937 .332 r
F
.469 .70199 m .46857 .69732 L .46487 .69529 L F
0 g
.46487 .69529 m
.46806 .69026 L
s
.4474 .82072 m .44018 .82837 L .44492 .83061 L 0 .859 .391 r
F
0 g
.44018 .82837 m
.44076 .83511 L
s
.52589 .70466 m
.52682 .70782 L
s
.51316 .68035 m .51316 .68035 L .51328 .67401 L 0 1 .363 r
F
0 g
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .6803 L
s
.51316 .6803 m
.51316 .68028 L
s
.51316 .68028 m
.51316 .68028 L
s
.51316 .68028 m
.51316 .68028 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68033 m
.51316 .6803 L
s
.51316 .6803 m
.51316 .6803 L
s
.51316 .6803 m
.51316 .6803 L
s
.51316 .6803 m
.51316 .6803 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68034 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68035 m
.51316 .68034 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.5141 .73907 m .51562 .75125 L .51536 .74431 L 0 1 .401 r
F
.51761 .73888 m .51536 .74431 L .51562 .75125 L 0 1 .397 r
F
0 g
.51562 .75125 m
.51723 .7565 L
s
.51441 .75625 m
.51562 .75125 L
s
.7536 .90576 m .74794 .91321 L .74648 .91884 L 0 1 .514 r
F
0 g
.73873 .92366 m
.74648 .91884 L
s
.48131 .98819 m .4857 .992 L .4863 .99007 L 0 1 .54 r
F
.49962 .98799 m .4863 .99007 L .4857 .992 L 0 1 .537 r
F
0 g
.4857 .992 m
.49108 .99314 L
s
.47951 .99298 m
.4857 .992 L
s
.51838 .69702 m .52258 .70938 L .52036 .70209 L 0 1 .362 r
F
.51838 .69702 m .5236 .71544 L .52258 .70938 L F
.51838 .69702 m .52274 .71624 L .5236 .71544 L F
.51838 .69702 m .52076 .71117 L .52274 .71624 L F
.51838 .69702 m .51897 .7036 L .52076 .71117 L F
0 g
.51904 .69634 m
.52036 .70209 L
s
.519 .69617 m
.51904 .69634 L
s
.51838 .69702 m .51795 .69754 L .51897 .7036 L 0 1 .362 r
F
.51316 .68036 m .51838 .69702 L .51704 .69174 L 0 1 .359 r
F
.51316 .68036 m .51795 .69754 L .51838 .69702 L F
0 g
.51838 .69702 m
.52036 .70209 L
s
.51704 .69175 m
.51838 .69702 L
s
.52933 .70712 m .5357 .71846 L .53235 .7114 L 0 .996 .353 r
F
.52933 .70712 m .53743 .725 L .5357 .71846 L F
.52933 .70712 m .5364 .72666 L .53743 .725 L F
.52933 .70712 m .53338 .72237 L .5364 .72666 L F
.52933 .70712 m .53038 .71501 L .53338 .72237 L F
0 g
.53031 .70494 m
.53054 .70568 L
s
.53335 .70516 m
.53411 .70721 L
s
.53307 .70596 m
.53411 .70721 L
s
.52933 .70712 m .52865 .70847 L .53038 .71501 L 0 .996 .353 r
F
0 g
.52814 .70389 m
.52933 .70712 L
s
.52589 .70466 m
.52865 .70847 L
s
.7571 .75567 m .76586 .76694 L .76847 .76562 L 0 .333 .285 r
F
0 g
.76353 .76602 m
.76586 .76694 L
s
.76586 .76694 m
.76724 .77071 L
s
.51316 .68035 m .5126 .66636 L .51292 .67435 L 0 1 .363 r
F
.51316 .68035 m .5126 .66636 L .512 .66075 L 0 1 .365 r
F
.51316 .68035 m .51292 .67435 L .5126 .66636 L F
0 g
.5126 .66636 m
.51271 .66002 L
s
.51316 .68036 m .51316 .68036 L .51541 .68427 L 0 1 .359 r
F
0 g
.51317 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.21411 .75983 m .20239 .74273 L .20077 .75122 L 0 1 .49 r
F
.21411 .75983 m .20688 .74207 L .20239 .74273 L F
.21411 .75983 m .2119 .74942 L .20688 .74207 L F
.22514 .75778 m .2119 .74942 L .21411 .75983 L 0 1 .488 r
F
0 g
.21247 .76828 m
.21411 .75983 L
s
.21411 .75983 m
.21904 .76695 L
s
.51153 .66128 m .51211 .65482 L .51179 .64744 L 0 1 .361 r
F
.51153 .66128 m .512 .66075 L .51211 .65482 L F
0 g
.51211 .65482 m
.51271 .66002 L
s
.51316 .68036 m .51704 .69174 L .51482 .68524 L 0 1 .359 r
F
.51316 .68036 m .51482 .68524 L .51704 .69174 L 0 1 .358 r
F
0 g
.51704 .69174 m
.519 .69617 L
s
.51704 .69174 m
.51704 .69175 L
s
.27473 .78708 m .26212 .7771 L .26104 .78277 L 0 1 .524 r
F
.27473 .78708 m .26652 .7763 L .26212 .7771 L F
.27473 .78708 m .27193 .78059 L .26652 .7763 L F
.28548 .78459 m .27193 .78059 L .27473 .78708 L F
0 g
.27364 .79273 m
.27473 .78708 L
s
.27473 .78708 m
.28002 .79113 L
s
.69746 1.07593 m .70415 1.07726 L .7098 1.07608 L 0 .864 .315 r
F
.51761 .73888 m .5191 .75657 L .51995 .75127 L 0 1 .397 r
F
0 g
.5191 .75657 m
.52105 .7616 L
s
.51316 .68035 m .512 .66075 L .51153 .66128 L 0 1 .365 r
F
0 g
.512 .66075 m
.51211 .65482 L
s
.512 .66075 m
.5126 .66636 L
s
.51071 .6685 m
.51304 .67978 L
s
.51316 .68036 m .51316 .68036 L .51054 .68373 L 0 0 .055 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.54513 .7008 m .54459 .70391 L .54731 .71171 L 0 .803 .328 r
F
0 g
.54513 .7008 m
.54722 .70234 L
s
.54229 .69526 m
.54513 .7008 L
s
.43333 .67333 m .42512 .68018 L .42971 .67892 L 0 1 .364 r
F
0 g
.43433 .68077 m
.4366 .67707 L
s
.43333 .67333 m .42187 .67627 L .42512 .68018 L 0 1 .364 r
F
.43333 .67333 m .42214 .6698 L .42187 .67627 L F
.43333 .67333 m .42576 .6642 L .42214 .6698 L F
.43333 .67333 m .43033 .66321 L .42576 .6642 L F
0 g
.43033 .66321 m
.43357 .66712 L
s
.43333 .67333 m
.4366 .67707 L
s
.43033 .66321 m
.43418 .65773 L
s
.51316 .68036 m .51629 .69266 L .51795 .69754 L 0 1 .359 r
F
.52518 .7562 m .52334 .75641 L .52261 .76161 L 0 1 .401 r
F
0 g
.54108 .70228 m
.54132 .70284 L
s
.54108 .70228 m
.54459 .70391 L
s
.51316 .68036 m .51316 .68036 L .51513 .68478 L 0 1 .358 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51317 .68036 m
.51318 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.42761 .62675 m .42901 .61995 L .42691 .61523 L 0 1 .368 r
F
0 g
.42901 .61995 m
.43065 .61787 L
s
.44276 .5314 m .44661 .52315 L .44752 .51786 L 0 1 .278 r
F
0 g
.44661 .52315 m
.44906 .5197 L
s
.2634 .80427 m .25824 .80903 L .2625 .80809 L 0 1 .53 r
F
.2634 .80427 m .25265 .80639 L .25824 .80903 L F
0 g
.25824 .80903 m
.25826 .81293 L
s
.2625 .80809 m
.26874 .81036 L
s
.50422 .69211 m .49711 .70154 L .49471 .70426 L 0 0 .023 r
F
.50422 .69211 m .50089 .69686 L .49711 .70154 L F
.50422 .69211 m .50393 .69281 L .50089 .69686 L F
.51316 .68036 m .50393 .69281 L .50422 .69211 L 0 0 .057 r
F
0 g
.50182 .69482 m
.50422 .69211 L
s
.50422 .69211 m
.50705 .68821 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51165 .68129 m
.51316 .68036 L
s
.51315 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51165 .68129 m
.51315 .68036 L
s
.51134 .68194 m
.51314 .68037 L
s
.51314 .68037 m
.51314 .68037 L
s
.51314 .68037 m
.51314 .68037 L
s
.51314 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51134 .68194 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51275 .68079 m
.51313 .68039 L
s
.51313 .68039 m
.51313 .68039 L
s
.51313 .68039 m
.51313 .68039 L
s
.51313 .68039 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51266 .68088 m
.51314 .68038 L
s
.51314 .68038 m
.51314 .68038 L
s
.51314 .68038 m
.51314 .68038 L
s
.51314 .68038 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51303 .68052 m
.51303 .68052 L
s
.51079 .68316 m
.51303 .68052 L
s
.51303 .68052 m
.5131 .68044 L
s
.5131 .68044 m
.5131 .68044 L
s
.5131 .68044 m
.5131 .68044 L
s
.5131 .68044 m
.51314 .68038 L
s
.51314 .68038 m
.51314 .68038 L
s
.51314 .68038 m
.51314 .68038 L
s
.51314 .68038 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51296 .6806 m
.51296 .6806 L
s
.51079 .68316 m
.51296 .6806 L
s
.51296 .6806 m
.51312 .68041 L
s
.51312 .68041 m
.51312 .68041 L
s
.51312 .68041 m
.51312 .68041 L
s
.51312 .68041 m
.51314 .68038 L
s
.51314 .68038 m
.51314 .68038 L
s
.51314 .68038 m
.51314 .68038 L
s
.51314 .68038 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.50979 .68072 m
.51316 .68036 L
s
.50979 .68072 m
.51316 .68036 L
s
.51054 .68373 m
.51296 .68061 L
s
.51296 .68061 m
.51297 .68061 L
s
.51297 .68061 m
.51297 .68061 L
s
.51297 .68061 m
.51312 .68042 L
s
.51312 .68042 m
.51312 .68042 L
s
.51312 .68042 m
.51312 .68042 L
s
.51312 .68042 m
.51314 .68038 L
s
.51314 .68038 m
.51314 .68038 L
s
.51314 .68038 m
.51314 .68038 L
s
.51314 .68038 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51316 .68037 L
s
.51054 .68373 m
.51302 .68054 L
s
.51302 .68054 m
.51302 .68054 L
s
.51302 .68054 m
.51302 .68054 L
s
.51302 .68054 m
.51313 .68041 L
s
.51313 .68041 m
.51313 .68041 L
s
.51313 .68041 m
.51313 .68041 L
s
.51313 .68041 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.81546 .70836 m .82465 .70484 L .82009 .70331 L 0 1 .506 r
F
.81546 .70836 m .8268 .71234 L .82465 .70484 L F
.49205 .43778 m .50252 .42559 L .5022 .42966 L 0 0 .047 r
F
0 g
.50252 .42559 m
.50737 .41589 L
s
.49818 .42907 m
.50252 .42559 L
s
.51316 .68035 m .51316 .68035 L .51292 .67435 L 0 1 .365 r
F
0 g
.51292 .67435 m
.51316 .68035 L
s
.51292 .67435 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68035 m
.51316 .68035 L
s
.50973 .67795 m
.51314 .68034 L
s
.51314 .68034 m
.51314 .68034 L
s
.51314 .68034 m
.51314 .68034 L
s
.51314 .68034 m
.51314 .68034 L
s
.51314 .68034 m
.51315 .68035 L
s
.51315 .68035 m
.51315 .68035 L
s
.51315 .68035 m
.51315 .68035 L
s
.51315 .68035 m
.51315 .68035 L
s
.51315 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68036 L
s
.50973 .67795 m
.51314 .68034 L
s
.51314 .68034 m
.51315 .68035 L
s
.51315 .68035 m
.51315 .68035 L
s
.51315 .68035 m
.51315 .68035 L
s
.51315 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51063 .66885 m
.51311 .68014 L
s
.51156 .66562 m
.51314 .68012 L
s
.51314 .68012 m
.51314 .68012 L
s
.51156 .66562 m
.51313 .68009 L
s
.51313 .68009 m
.51313 .68009 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.50992 .67384 m
.51315 .68034 L
s
.51315 .68034 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.50992 .67384 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51041 .67001 m
.51315 .6803 L
s
.51315 .6803 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51041 .67001 m
.51314 .68027 L
s
.51314 .68027 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51071 .6685 m
.51314 .68027 L
s
.51314 .68027 m
.51314 .68027 L
s
.51314 .68027 m
.51314 .68027 L
s
.51314 .68027 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68035 L
s
.51304 .67978 m
.51314 .68023 L
s
.51314 .68023 m
.51314 .68023 L
s
.51314 .68023 m
.51314 .68023 L
s
.51314 .68023 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51283 .67837 m
.51315 .68031 L
s
.51315 .68031 m
.51315 .68031 L
s
.51315 .68031 m
.51315 .68031 L
s
.51315 .68031 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51276 .67801 m
.51315 .68028 L
s
.51315 .68028 m
.51315 .68028 L
s
.51315 .68028 m
.51315 .68028 L
s
.51315 .68028 m
.51316 .68032 L
s
.51316 .68032 m
.51316 .68032 L
s
.51316 .68032 m
.51316 .68032 L
s
.51316 .68032 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68035 L
s
.51313 .68009 m
.51315 .68026 L
s
.51315 .68026 m
.51315 .68026 L
s
.51315 .68026 m
.51315 .68026 L
s
.51315 .68026 m
.51315 .68026 L
s
.51315 .68026 m
.51316 .68031 L
s
.51316 .68031 m
.51316 .68031 L
s
.51316 .68031 m
.51316 .68031 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68031 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68033 m
.51316 .68034 L
s
.51314 .68012 m
.51315 .68023 L
s
.51315 .68023 m
.51315 .68023 L
s
.51315 .68023 m
.51315 .68023 L
s
.51315 .68023 m
.51315 .68025 L
s
.51315 .68025 m
.51316 .6803 L
s
.51316 .6803 m
.51316 .6803 L
s
.51316 .6803 m
.51316 .6803 L
s
.51316 .68032 m
.51316 .68032 L
s
.51316 .6803 m
.51316 .68032 L
s
.51316 .68032 m
.51316 .68032 L
s
.51316 .68032 m
.51316 .68032 L
s
.51316 .68032 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68033 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68033 m
.51316 .68034 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68031 m
.51316 .68033 L
s
.51316 .68031 m
.51316 .68031 L
s
.51316 .68031 m
.51316 .68031 L
s
.51315 .68027 m
.51315 .6803 L
s
.51315 .6803 m
.51316 .68031 L
s
.51315 .68027 m
.51315 .68027 L
s
.51315 .68027 m
.51315 .68027 L
s
.51305 .67952 m
.51315 .68027 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68033 m
.51316 .68034 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68032 m
.51316 .68033 L
s
.51316 .68032 m
.51316 .68032 L
s
.51316 .68032 m
.51316 .68032 L
s
.51315 .68029 m
.51316 .6803 L
s
.51316 .6803 m
.51316 .68032 L
s
.51315 .68029 m
.51315 .68029 L
s
.51315 .68029 m
.51315 .68029 L
s
.51303 .67943 m
.51315 .68029 L
s
.51316 .68035 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68035 L
s
.51316 .68033 m
.51316 .68034 L
s
.51316 .68033 m
.51316 .68033 L
s
.51315 .68031 m
.51316 .68033 L
s
.51311 .68014 m
.51315 .68031 L
s
.51316 .68034 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51315 .68032 m
.51316 .68034 L
s
.51063 .66885 m
.51315 .68032 L
s
.51316 .68035 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68036 L
s
.51205 .67693 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51021 .67124 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51005 .67252 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51005 .67252 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.50982 .67519 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51315 .68035 m
.51316 .68035 L
s
.51315 .68035 m
.51315 .68035 L
s
.51315 .68034 m
.51315 .68035 L
s
.50982 .67519 m
.51315 .68034 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51315 .68035 m
.51316 .68035 L
s
.51315 .68035 m
.51315 .68035 L
s
.51315 .68035 m
.51315 .68035 L
s
.51315 .68035 m
.51315 .68035 L
s
.50976 .67656 m
.51315 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51315 .68035 m
.51316 .68035 L
s
.51315 .68034 m
.51315 .68035 L
s
.51315 .68034 m
.51315 .68034 L
s
.51315 .68034 m
.51315 .68034 L
s
.50976 .67656 m
.51315 .68034 L
s
.51316 .68035 m
.51316 .68036 L
s
.51315 .68035 m
.51316 .68036 L
s
.51315 .68035 m
.51315 .68035 L
s
.51315 .68035 m
.51315 .68035 L
s
.51315 .68035 m
.51315 .68035 L
s
.51314 .68035 m
.51315 .68035 L
s
.51314 .68035 m
.51314 .68035 L
s
.51314 .68035 m
.51314 .68035 L
s
.50974 .67934 m
.51314 .68035 L
s
.51315 .68035 m
.51316 .68036 L
s
.51315 .68035 m
.51315 .68035 L
s
.51315 .68035 m
.51315 .68035 L
s
.51315 .68035 m
.51315 .68035 L
s
.51313 .68035 m
.51315 .68035 L
s
.51313 .68035 m
.51313 .68035 L
s
.51313 .68035 m
.51313 .68035 L
s
.50974 .67934 m
.51313 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68033 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m .51316 .68036 L .51482 .68524 L 0 1 .358 r
F
0 g
.51317 .68036 m
.51318 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.43618 .76338 m .42968 .76044 L .42567 .76291 L 0 1 .477 r
F
.43618 .76338 m .43418 .76064 L .42968 .76044 L F
.44577 .7563 m .43418 .76064 L .43618 .76338 L 0 1 .469 r
F
0 g
.43618 .76338 m
.44049 .76325 L
s
.43486 .76746 m
.43618 .76338 L
s
.52201 .4585 m .53297 .43819 L .52887 .44794 L 0 0 .021 r
F
0 g
.53297 .43819 m
.53792 .42989 L
s
.40639 .74935 m .39594 .74088 L .39399 .7473 L 0 1 .401 r
F
0 g
.39399 .7473 m
.39399 .7473 L
s
.51057 .73883 m .50917 .73861 L .50761 .74332 L 0 1 .405 r
F
.51316 .68036 m .51629 .69266 L .5145 .68563 L 0 1 .36 r
F
.51316 .68036 m .5173 .69826 L .51629 .69266 L F
.51316 .68036 m .5145 .68563 L .51629 .69266 L 0 1 .359 r
F
0 g
.51629 .69266 m
.51629 .69267 L
s
.51629 .69266 m
.51795 .69754 L
s
.52518 .7562 m .52819 .77338 L .52891 .76818 L 0 1 .401 r
F
0 g
.52819 .77338 m
.53092 .77823 L
s
.48395 .74214 m .47592 .74743 L .47489 .75191 L 0 1 .432 r
F
0 g
.47118 .75367 m
.47489 .75191 L
s
.51153 .66128 m .51179 .64744 L .51084 .64289 L 0 1 .361 r
F
0 g
.51179 .64744 m
.51226 .64098 L
s
.44548 .6993 m .4414 .69053 L .43683 .69208 L 0 1 .355 r
F
.44548 .6993 m .44511 .69363 L .4414 .69053 L F
0 g
.4414 .69053 m
.44476 .68503 L
s
.44511 .69363 m
.44825 .68822 L
s
.4414 .69053 m
.44511 .69363 L
s
.49711 .73395 m .4907 .74208 L .49012 .74696 L 0 1 .416 r
F
0 g
.48778 .74917 m
.49012 .74696 L
s
.4943 .74954 m
.4945 .74477 L
s
.43965 .80588 m .43633 .8155 L .43946 .81257 L 0 .91 .392 r
F
.4474 .82072 m .43946 .81257 L .43633 .8155 L 0 .859 .391 r
F
0 g
.43633 .8155 m
.43663 .82227 L
s
.43156 .81306 m
.43633 .8155 L
s
.45951 .75402 m .44989 .75581 L .44858 .75995 L 0 1 .457 r
F
0 g
.44425 .76034 m
.44858 .75995 L
s
.51181 .62466 m .51443 .61647 L .51458 .61078 L 0 1 .325 r
F
.51181 .62466 m .51324 .62241 L .51443 .61647 L F
0 g
.51443 .61647 m
.51538 .6191 L
s
.51324 .62241 m
.5142 .62617 L
s
.51324 .62241 m
.51443 .61647 L
s
.5173 .69826 m .52076 .71117 L .51897 .7036 L 0 1 .366 r
F
.5173 .69826 m .52143 .71731 L .52076 .71117 L F
.5173 .69826 m .52054 .71794 L .52143 .71731 L F
.5173 .69826 m .51886 .71259 L .52054 .71794 L F
.5173 .69826 m .51752 .70484 L .51886 .71259 L F
0 g
.51795 .69754 m
.51798 .69769 L
s
.5173 .69826 m .51685 .6987 L .51752 .70484 L 0 1 .366 r
F
.51316 .68036 m .51685 .6987 L .5173 .69826 L 0 1 .36 r
F
0 g
.51629 .69267 m
.5173 .69826 L
s
.40092 .77566 m .3897 .77797 L .38861 .77976 L 0 1 .37 r
F
.40092 .77566 m .39374 .77625 L .3897 .77797 L F
.40092 .77566 m .39855 .77526 L .39374 .77625 L F
0 g
.39982 .77745 m
.40092 .77566 L
s
.41107 .77043 m .39855 .77526 L .40092 .77566 L 0 1 .319 r
F
0 g
.40092 .77566 m
.40553 .77438 L
s
.52429 .70721 m
.52523 .71128 L
s
.52209 .66822 m .52798 .66204 L .52449 .66613 L 0 0 .079 r
F
.52209 .66822 m .53102 .65629 L .52798 .66204 L F
.51316 .68036 m .52209 .66822 L .51926 .67254 L 0 0 .05 r
F
0 g
.51317 .68036 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68036 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68033 L
s
.51316 .68033 m
.51317 .68032 L
s
.51317 .68032 m
.51317 .68032 L
s
.51317 .68032 m
.51317 .68032 L
s
.51317 .68032 m
.51317 .68025 L
s
.51317 .68025 m
.51317 .68025 L
s
.51317 .68025 m
.51317 .68025 L
s
.51318 .68012 m
.51363 .67374 L
s
.51318 .68013 m
.51318 .68012 L
s
.51317 .68025 m
.51318 .68013 L
s
.51316 .68033 m
.51317 .68029 L
s
.51317 .68029 m
.51317 .68029 L
s
.51317 .68029 m
.51317 .68029 L
s
.51319 .68003 m
.51363 .67374 L
s
.51319 .68003 m
.51319 .68003 L
s
.51317 .68029 m
.51319 .68003 L
s
.51318 .68033 m
.51319 .68032 L
s
.5132 .68031 m
.51323 .68025 L
s
.5132 .68031 m
.5132 .68031 L
s
.5132 .68031 m
.5132 .68031 L
s
.51319 .68032 m
.5132 .68031 L
s
.51323 .68025 m
.51599 .67604 L
s
.51318 .68034 m
.51318 .68033 L
s
.51318 .68034 m
.51318 .68034 L
s
.51318 .68034 m
.51318 .68034 L
s
.51317 .68035 m
.51318 .68034 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51318 .68033 m
.51319 .68032 L
s
.51318 .68033 m
.51318 .68033 L
s
.51318 .68033 m
.51318 .68033 L
s
.51318 .68033 m
.51318 .68033 L
s
.51319 .68032 m
.51323 .68026 L
s
.51323 .68026 m
.51599 .67604 L
s
.51317 .68034 m
.51318 .68033 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68035 m
.51317 .68034 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51316 .68036 m
.51317 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68032 L
s
.51317 .68032 m
.51317 .68032 L
s
.51317 .68032 m
.51317 .68032 L
s
.51317 .68032 m
.51317 .68031 L
s
.51317 .68031 m
.51433 .67342 L
s
.51317 .68034 m
.51317 .68032 L
s
.51317 .68032 m
.51433 .67342 L
s
.51316 .68035 m
.51316 .68035 L
s
.51318 .68035 m
.51319 .68035 L
s
.51317 .68035 m
.51318 .68035 L
s
.51319 .68035 m
.51319 .68035 L
s
.51319 .68035 m
.51319 .68035 L
s
.51319 .68035 m
.51335 .6803 L
s
.51318 .68035 m
.51319 .68035 L
s
.51317 .68035 m
.51318 .68035 L
s
.51316 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51497 .67344 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51497 .67344 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51317 .68034 L
s
.51317 .68034 m
.51526 .67359 L
s
.51316 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51526 .67359 L
s
.51317 .68036 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51318 .68034 L
s
.51318 .68034 m
.51318 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68035 m
.51317 .68034 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51318 .68033 m
.51318 .68032 L
s
.51318 .68033 m
.51318 .68033 L
s
.51318 .68034 m
.51318 .68033 L
s
.51318 .68032 m
.51319 .68032 L
s
.51318 .68032 m
.51318 .68032 L
s
.51318 .68032 m
.51318 .68032 L
s
.51318 .68032 m
.51318 .68032 L
s
.51319 .68032 m
.5132 .68029 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51316 .68036 m
.51317 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51317 .68035 m
.51317 .68034 L
s
.51317 .68035 m
.51317 .68035 L
s
.51316 .68036 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51319 .68032 m
.51319 .68031 L
s
.51318 .68032 m
.51319 .68032 L
s
.51318 .68032 m
.51318 .68032 L
s
.51318 .68032 m
.51318 .68032 L
s
.51318 .68032 m
.51318 .68032 L
s
.51318 .68033 m
.51318 .68032 L
s
.51318 .68033 m
.51318 .68033 L
s
.51318 .68034 m
.51318 .68034 L
s
.51318 .68034 m
.51318 .68034 L
s
.51318 .68034 m
.51318 .68034 L
s
.51318 .68034 m
.51318 .68033 L
s
.51318 .68034 m
.51318 .68034 L
s
.51318 .68034 m
.51318 .68034 L
s
.51318 .68034 m
.51318 .68034 L
s
.51318 .68034 m
.51318 .68034 L
s
.51318 .68034 m
.51318 .68034 L
s
.51317 .68034 m
.51318 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68035 m
.51317 .68034 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51318 .68033 m
.51319 .68031 L
s
.51318 .68033 m
.51318 .68033 L
s
.51318 .68034 m
.51318 .68033 L
s
.51318 .68033 m
.51318 .68033 L
s
.51318 .68033 m
.51318 .68033 L
s
.51318 .68033 m
.51318 .68033 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51318 .68034 L
s
.51318 .68034 m
.51318 .68034 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68035 m
.51317 .68034 L
s
.51316 .68036 m
.51317 .68035 L
s
.51317 .68034 m
.51317 .68033 L
s
.51317 .68033 m
.51324 .68021 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68035 m
.51317 .68034 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68034 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51318 .68033 L
s
.51318 .68033 m
.51324 .6802 L
s
.51317 .68035 m
.51318 .68032 L
s
.51318 .68032 m
.51578 .67418 L
s
.51316 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51317 .68035 m
.51318 .68031 L
s
.51318 .68031 m
.51578 .67418 L
s
.51316 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51333 .67989 L
s
.51316 .68035 m
.51334 .67987 L
s
.51317 .68035 m
.51318 .68035 L
s
.51318 .68035 m
.51318 .68035 L
s
.51318 .68035 m
.51318 .68035 L
s
.51318 .68035 m
.51319 .68034 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51319 .68035 m
.5132 .68034 L
s
.51319 .68035 m
.51319 .68035 L
s
.51319 .68035 m
.51319 .68035 L
s
.51317 .68035 m
.51318 .68035 L
s
.51318 .68035 m
.51319 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51319 .68025 m
.51465 .67339 L
s
.51317 .68034 m
.51319 .68025 L
s
.51317 .68034 m
.51319 .68022 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68035 m
.51317 .68034 L
s
.51316 .68035 m
.51317 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.5132 .68036 m
.5165 .68015 L
s
.5132 .68036 m
.5165 .68015 L
s
.51319 .68022 m
.51465 .67339 L
s
.5132 .68034 m
.51324 .68032 L
s
.5132 .68034 m
.5132 .68034 L
s
.5132 .68034 m
.5132 .68034 L
s
.51324 .68032 m
.51324 .68032 L
s
.51324 .68032 m
.51324 .68032 L
s
.51324 .68032 m
.51659 .67858 L
s
.51319 .68034 m
.51319 .68034 L
s
.51319 .68034 m
.51319 .68034 L
s
.51319 .68034 m
.51326 .68031 L
s
.51326 .68031 m
.51326 .68031 L
s
.51326 .68031 m
.51326 .68031 L
s
.51326 .68031 m
.51659 .67858 L
s
.51324 .6802 m
.51599 .67461 L
s
.51324 .6802 m
.51324 .6802 L
s
.51324 .6802 m
.51324 .6802 L
s
.51324 .68021 m
.51599 .67461 L
s
.51324 .68021 m
.51324 .68021 L
s
.51324 .68021 m
.51324 .68021 L
s
.5132 .68029 m
.51328 .68015 L
s
.5132 .68029 m
.5132 .68029 L
s
.5132 .68029 m
.5132 .68029 L
s
.51319 .68031 m
.5132 .68029 L
s
.51319 .68031 m
.51319 .68031 L
s
.51319 .68031 m
.51319 .68031 L
s
.51324 .68023 m
.51331 .68011 L
s
.51319 .68031 m
.51319 .68031 L
s
.51319 .68031 m
.51319 .68031 L
s
.51319 .68031 m
.5132 .6803 L
s
.5132 .6803 m
.5132 .6803 L
s
.5132 .6803 m
.5132 .6803 L
s
.5132 .6803 m
.51323 .68024 L
s
.51323 .68024 m
.51323 .68024 L
s
.51323 .68024 m
.51323 .68024 L
s
.51323 .68024 m
.51323 .68024 L
s
.51323 .68024 m
.51324 .68023 L
s
.5132 .68029 m
.5132 .68029 L
s
.5132 .68029 m
.5132 .68029 L
s
.5132 .68029 m
.51322 .68026 L
s
.51322 .68026 m
.51325 .68021 L
s
.51325 .68021 m
.51325 .68021 L
s
.51325 .68021 m
.51331 .6801 L
s
.51319 .68035 m
.51338 .6803 L
s
.51319 .68035 m
.51319 .68035 L
s
.51319 .68035 m
.51319 .68035 L
s
.51317 .68032 m
.51321 .67998 L
s
.51321 .67998 m
.51321 .67998 L
s
.51321 .67998 m
.51398 .67354 L
s
.51317 .6803 m
.5132 .68005 L
s
.5132 .68005 m
.5132 .68005 L
s
.5132 .68005 m
.51398 .67354 L
s
.51317 .6803 m
.51317 .6803 L
s
.51317 .6803 m
.51317 .6803 L
s
.51317 .68034 m
.51317 .6803 L
s
.51317 .68034 m
.51317 .68034 L
s
.51317 .68034 m
.51317 .68034 L
s
.51316 .68034 m
.51317 .68034 L
s
.51316 .68035 m
.51316 .68034 L
s
.51316 .68035 m
.51316 .68035 L
s
.51324 .68028 m
.51633 .67714 L
s
.51324 .68028 m
.51324 .68028 L
s
.51324 .68028 m
.51324 .68028 L
s
.51319 .68034 m
.51324 .68028 L
s
.51319 .68034 m
.51319 .68034 L
s
.51319 .68034 m
.51319 .68034 L
s
.51317 .68035 m
.51319 .68034 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68036 m
.51317 .68035 L
s
.51322 .6803 m
.51633 .67714 L
s
.51322 .6803 m
.51322 .6803 L
s
.51322 .6803 m
.51322 .6803 L
s
.51318 .68034 m
.51322 .6803 L
s
.51318 .68034 m
.51318 .68034 L
s
.51318 .68034 m
.51318 .68034 L
s
.51317 .68035 m
.51318 .68034 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68036 m
.51317 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .6803 m
.51316 .68024 L
s
.51317 .68012 m
.51328 .67401 L
s
.51317 .68012 m
.51317 .68012 L
s
.51317 .68012 m
.51317 .68012 L
s
.51316 .68024 m
.51317 .68012 L
s
.51316 .68028 m
.51316 .68024 L
s
.51317 .67999 m
.51328 .67401 L
s
.51317 .67999 m
.51317 .67999 L
s
.51317 .67999 m
.51317 .67999 L
s
.51316 .68024 m
.51317 .67999 L
s
.51316 .68036 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51316 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51316 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51317 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.5132 .68036 m
.5132 .68036 L
s
.5132 .68036 m
.5132 .68036 L
s
.51318 .68036 m
.5132 .68036 L
s
.5132 .68036 m
.5132 .68036 L
s
.5132 .68036 m
.5132 .68036 L
s
.51317 .68036 m
.5132 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.5141 .73907 m .51269 .73903 L .51147 .74403 L 0 1 .401 r
F
.49109 .6902 m .48358 .6971 L .48796 .69448 L 0 .833 .308 r
F
.49109 .6902 m .48005 .69607 L .48358 .6971 L F
.50199 .94193 m .49594 .9356 L .49096 .93271 L 0 .497 .397 r
F
0 g
.48695 .92619 m
.49096 .93271 L
s
.51316 .68036 m .51316 .68036 L .5145 .68563 L 0 1 .359 r
F
0 g
.51317 .68039 m
.5145 .68563 L
s
.51317 .68039 m
.51317 .68039 L
s
.51317 .68039 m
.51317 .68039 L
s
.51317 .68037 m
.51317 .68039 L
s
.51317 .68037 m
.51317 .68037 L
s
.51317 .68037 m
.51317 .68037 L
s
.51316 .68036 m
.51317 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51317 .6804 m
.5145 .68563 L
s
.51317 .6804 m
.51317 .6804 L
s
.51317 .6804 m
.51317 .6804 L
s
.51317 .68038 m
.51317 .6804 L
s
.51317 .68037 m
.51513 .68478 L
s
.51317 .68037 m
.51317 .68037 L
s
.51316 .68036 m
.51317 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51317 .68037 m
.51513 .68478 L
s
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51318 .68038 m
.51541 .68427 L
s
.51317 .68036 m
.51318 .68038 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51318 .6804 m
.51541 .68427 L
s
.51317 .68036 m
.51318 .6804 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.5161 .68239 L
s
.51317 .68036 m
.5161 .68239 L
s
.51318 .68036 m
.5164 .68092 L
s
.51318 .68036 m
.5164 .68092 L
s
.51317 .68036 m
.51627 .68167 L
s
.51317 .68036 m
.51627 .68167 L
s
.51316 .68036 m
.5159 .68307 L
s
.51316 .68036 m
.5159 .68307 L
s
.51316 .68036 m
.51318 .68039 L
s
.51318 .68039 m
.51567 .68369 L
s
.51316 .68036 m
.51317 .68037 L
s
.51317 .68037 m
.51567 .68369 L
s
.51316 .68036 m
.51316 .68036 L
s
.51317 .68038 m
.51482 .68524 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51317 .68037 L
s
.51317 .68037 m
.51317 .68037 L
s
.51317 .68037 m
.51317 .68037 L
s
.51317 .68037 m
.51317 .68038 L
s
.51317 .68038 m
.51317 .68038 L
s
.51317 .68038 m
.51317 .68038 L
s
.51317 .68038 m
.51482 .68524 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.469 .70199 m .46037 .69725 L .45741 .7026 L 0 .937 .332 r
F
0 g
.45677 .69476 m
.46037 .69725 L
s
.39172 .73703 m .38532 .74499 L .38951 .74339 L 0 1 .41 r
F
.39172 .73703 m .38114 .74087 L .38532 .74499 L F
0 g
.38362 .75144 m
.38532 .74499 L
s
.38951 .74339 m
.39398 .7473 L
s
.49711 .73395 m .49451 .74455 L .49652 .73884 L 0 1 .416 r
F
.50031 .73571 m .49652 .73884 L .49451 .74455 L 0 1 .413 r
F
0 g
.49177 .74803 m
.49451 .74455 L
s
.4945 .74477 m
.49451 .74455 L
s
.80246 .78944 m .80049 .79527 L .8049 .79805 L 0 .547 .374 r
F
.80246 .78944 m .79943 .79158 L .80049 .79527 L F
0 g
.79406 .7956 m
.80049 .79527 L
s
.52481 .98278 m
.52498 .98275 L
s
.52498 .98275 m
.52559 .98264 L
s
.7536 .90576 m .75736 .91321 L .76327 .90549 L 0 1 .514 r
F
0 g
.75017 .91892 m
.75736 .91321 L
s
.75571 .91914 m
.75736 .91321 L
s
.51316 .68036 m .52084 .67763 L .52401 .67441 L 0 .68 .284 r
F
.51316 .68036 m .51645 .67919 L .52084 .67763 L F
.51316 .68036 m .51316 .68036 L .51645 .67919 L F
0 g
.51316 .68036 m
.51317 .68035 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50549 .68438 L .50988 .68208 L 0 .712 .284 r
F
0 g
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m .51551 .69343 L .51685 .6987 L 0 1 .36 r
F
.51316 .68036 m .51417 .68596 L .51551 .69343 L F
.51316 .68036 m .51316 .68036 L .51417 .68596 L F
.51316 .68035 m .51177 .66728 L .51257 .67475 L 0 1 .365 r
F
.51316 .68035 m .51153 .66128 L .51177 .66728 L F
.51316 .68036 m .51551 .69343 L .51417 .68596 L 0 1 .361 r
F
.51316 .68036 m .51617 .69929 L .51551 .69343 L F
.51316 .68036 m .51571 .69965 L .51617 .69929 L F
.51316 .68036 m .5147 .69404 L .51571 .69965 L F
.51316 .68036 m .51382 .68623 L .5147 .69404 L F
.51316 .68036 m .51316 .68036 L .51382 .68623 L F
.51316 .68036 m .51316 .68035 L .51257 .67475 L 0 1 .366 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50655 .68945 L .50393 .69281 L 0 0 .057 r
F
.51316 .68036 m .51033 .68425 L .50655 .68945 L F
.51316 .68036 m .51316 .68036 L .51033 .68425 L F
.51316 .68036 m .51926 .67254 L .51578 .67701 L 0 0 .05 r
F
.51316 .68036 m .51096 .66833 L .51222 .6752 L 0 1 .366 r
F
0 g
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m .51036 .66273 L .51096 .66833 L 0 1 .366 r
F
.51316 .68036 m .51083 .66213 L .51036 .66273 L F
.51316 .68036 m .51177 .66728 L .51083 .66213 L F
.51316 .68036 m .51257 .67475 L .51177 .66728 L F
.51316 .68036 m .5147 .69404 L .51382 .68623 L 0 1 .362 r
F
.51316 .68036 m .51525 .69998 L .5147 .69404 L F
.51316 .68036 m .51511 .70007 L .51525 .69998 L F
.51316 .68036 m .51445 .6942 L .51511 .70007 L F
.51316 .68036 m .51371 .68629 L .51445 .6942 L F
.51316 .68036 m .51316 .68036 L .51371 .68629 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51222 .6752 L 0 1 .368 r
F
0 g
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m .51445 .6942 L .51371 .68629 L 0 1 .363 r
F
.51316 .68036 m .51465 .70032 L .51445 .6942 L F
.51316 .68036 m .51418 .70055 L .51465 .70032 L F
.51316 .68036 m .51363 .69462 L .51418 .70055 L F
.51316 .68036 m .51336 .68647 L .51363 .69462 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51336 .68647 L 0 1 .363 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .50988 .68208 L 0 .7 .284 r
F
.51316 .68036 m .51017 .66948 L .51188 .67569 L 0 1 .368 r
F
0 g
.51316 .68035 m
.51316 .68036 L
s
.51316 .68036 m .50923 .66432 L .51017 .66948 L 0 1 .368 r
F
.51316 .68036 m .50968 .66367 L .50923 .66432 L F
.51316 .68036 m .51096 .66833 L .50968 .66367 L F
.51316 .68036 m .51222 .6752 L .51096 .66833 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51188 .67569 L 0 1 .368 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m .51363 .69462 L .51336 .68647 L 0 1 .365 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51347 .70085 L .51363 .69462 L 0 1 .365 r
F
.51316 .68036 m .513 .70101 L .51347 .70085 L F
0 g
.51316 .68036 m
.51316 .68037 L
s
.51316 .68036 m .5128 .69489 L .513 .70101 L 0 1 .365 r
F
.51316 .68036 m .51301 .68659 L .5128 .69489 L F
.51316 .68036 m .51316 .68036 L .51301 .68659 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .52084 .67763 L .51645 .67919 L 0 .664 .284 r
F
.51316 .68036 m .52421 .67851 L .52084 .67763 L F
.51316 .68036 m .52433 .68125 L .52421 .67851 L F
.51316 .68036 m .52104 .68242 L .52433 .68125 L F
.51316 .68036 m .51654 .68124 L .52104 .68242 L F
.51316 .68036 m .51316 .68036 L .51654 .68124 L F
.51316 .68036 m .50942 .67071 L .51156 .67622 L 0 1 .368 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50813 .66605 L .50942 .67071 L 0 1 .368 r
F
0 g
.51316 .68034 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68035 L
s
.51316 .68036 m .50857 .66534 L .50813 .66605 L 0 1 .368 r
F
0 g
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68036 m .51017 .66948 L .50857 .66534 L 0 1 .368 r
F
.51316 .68036 m .51188 .67569 L .51017 .66948 L F
.51316 .68036 m .51316 .68036 L .51156 .67622 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68036 L
s
.51316 .68036 m .5128 .69489 L .51301 .68659 L 0 1 .367 r
F
.51316 .68036 m .5123 .70118 L .5128 .69489 L F
.51316 .68036 m .51183 .70125 L .5123 .70118 L F
.51316 .68036 m .51198 .69502 L .51183 .70125 L F
.51316 .68036 m .51266 .68664 L .51198 .69502 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51266 .68664 L 0 1 .367 r
F
.51316 .68036 m .50577 .68752 L .50999 .68343 L 0 .7 .284 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50248 .68925 L .50577 .68752 L 0 .7 .284 r
F
.51316 .68036 m .50232 .68745 L .50248 .68925 L F
.51316 .68036 m .50549 .68438 L .50232 .68745 L F
.51316 .68036 m .50988 .68208 L .50549 .68438 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .5087 .67201 L .51125 .67678 L 0 1 .368 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50709 .66787 L .5087 .67201 L 0 1 .368 r
F
.51316 .68036 m .5075 .66713 L .50709 .66787 L F
.51316 .68036 m .50942 .67071 L .5075 .66713 L F
.51316 .68036 m .51156 .67622 L .50942 .67071 L F
.51316 .68036 m .51316 .68036 L .51578 .67701 L 0 0 .055 r
F
.51316 .68036 m .51198 .69502 L .51266 .68664 L 0 1 .369 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51113 .7013 L .51198 .69502 L 0 1 .369 r
F
.51316 .68036 m .51067 .7013 L .51113 .7013 L F
.51316 .68036 m .51118 .69501 L .51067 .7013 L F
.51316 .68036 m .51231 .68664 L .51118 .69501 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51231 .68664 L 0 1 .369 r
F
.51316 .68036 m .51316 .68036 L .51125 .67678 L 0 1 .368 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68036 L
s
.51316 .68036 m .50803 .67336 L .51096 .67736 L 0 1 .368 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50612 .66978 L .50803 .67336 L 0 1 .368 r
F
0 g
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m .5065 .66901 L .50612 .66978 L 0 1 .368 r
F
.51316 .68036 m .5087 .67201 L .5065 .66901 L F
.51316 .68036 m .51125 .67678 L .5087 .67201 L F
0 g
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68034 L
s
.51316 .68036 m .51118 .69501 L .51231 .68664 L 0 1 .37 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50999 .70124 L .51118 .69501 L 0 1 .37 r
F
.51316 .68036 m .50954 .70116 L .50999 .70124 L F
.51316 .68036 m .51039 .69487 L .50954 .70116 L F
.51316 .68036 m .51197 .68658 L .51039 .69487 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51197 .68658 L 0 1 .37 r
F
0 g
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68036 L
s
.51316 .68039 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51096 .67736 L 0 1 .367 r
F
0 g
.51316 .68035 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m .50742 .67475 L .5107 .67796 L 0 1 .367 r
F
0 g
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m .50522 .67175 L .50742 .67475 L 0 1 .367 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50557 .67096 L .50522 .67175 L 0 1 .367 r
F
.51316 .68036 m .50803 .67336 L .50557 .67096 L F
.51316 .68036 m .51096 .67736 L .50803 .67336 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .5107 .67796 L 0 1 .366 r
F
0 g
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m .50724 .67519 L .51063 .67814 L 0 1 .366 r
F
0 g
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m .50478 .67279 L .50724 .67519 L 0 1 .366 r
F
.51316 .68036 m .50488 .67254 L .50478 .67279 L F
.51316 .68036 m .50742 .67475 L .50488 .67254 L F
.51316 .68036 m .5107 .67796 L .50742 .67475 L F
0 g
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50655 .68945 L .51033 .68425 L 0 0 .059 r
F
.51316 .68036 m .50353 .69384 L .50655 .68945 L F
.51316 .68036 m .50329 .6945 L .50353 .69384 L F
.51316 .68036 m .50612 .6906 L .50329 .6945 L F
.51316 .68036 m .51014 .68475 L .50612 .6906 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51014 .68475 L 0 0 .059 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51039 .69487 L .51197 .68658 L 0 1 .372 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50888 .70098 L .51039 .69487 L 0 1 .372 r
F
.51316 .68036 m .50844 .70082 L .50888 .70098 L F
.51316 .68036 m .50963 .6946 L .50844 .70082 L F
.51316 .68036 m .51165 .68646 L .50963 .6946 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51165 .68646 L 0 1 .372 r
F
.51316 .68036 m .51869 .67488 L .51553 .67801 L 0 0 .055 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .52131 .67153 L .51869 .67488 L 0 0 .055 r
F
.51316 .68036 m .52163 .67019 L .52131 .67153 L F
.51316 .68036 m .51926 .67254 L .52163 .67019 L F
0 g
.51929 .6725 m
.52209 .66822 L
s
.51316 .68036 m .51578 .67701 L .51926 .67254 L 0 0 .055 r
F
0 g
.51926 .67254 m
.51929 .6725 L
s
.51316 .68036 m .51316 .68036 L .51063 .67814 L 0 1 .366 r
F
0 g
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68031 m
.51316 .68034 L
s
.51316 .68031 m
.51316 .68031 L
s
.51316 .68031 m
.51316 .68031 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m .51316 .68036 L .50999 .68343 L 0 .689 .284 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50672 .6766 L .5104 .67875 L 0 1 .366 r
F
.51316 .68036 m .50418 .67438 L .50672 .6766 L F
.51316 .68036 m .50448 .67357 L .50418 .67438 L F
.51316 .68036 m .50724 .67519 L .50448 .67357 L F
.51316 .68036 m .51063 .67814 L .50724 .67519 L F
0 g
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m .50963 .6946 L .51165 .68646 L 0 1 .372 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50781 .70054 L .50963 .6946 L 0 1 .372 r
F
.51316 .68036 m .5074 .70031 L .50781 .70054 L F
.51316 .68036 m .50891 .69421 L .5074 .70031 L F
.51316 .68036 m .51134 .68629 L .50891 .69421 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51134 .68629 L 0 1 .372 r
F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .5104 .67875 L 0 1 .365 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50627 .67801 L .51021 .67935 L 0 1 .365 r
F
.51316 .68036 m .5035 .6764 L .50627 .67801 L F
.51316 .68036 m .50376 .67559 L .5035 .6764 L F
.51316 .68036 m .50672 .6766 L .50376 .67559 L F
.51316 .68036 m .5104 .67875 L .50672 .6766 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50891 .69421 L .51134 .68629 L 0 1 .373 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .5068 .69993 L .50891 .69421 L 0 1 .373 r
F
.51316 .68036 m .50641 .69963 L .5068 .69993 L F
.51316 .68036 m .50824 .6937 L .50641 .69963 L F
.51316 .68036 m .51105 .68608 L .50824 .6937 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51105 .68608 L 0 1 .373 r
F
0 g
.51316 .6804 m
.51316 .6804 L
s
.51316 .6804 m
.51316 .6804 L
s
.51316 .6804 m
.51316 .68038 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m .52104 .68242 L .51654 .68124 L 0 .649 .283 r
F
.51316 .68036 m .52446 .68531 L .52104 .68242 L F
.51316 .68036 m .52453 .68799 L .52446 .68531 L F
.51316 .68036 m .52115 .68711 L .52453 .68799 L F
.51316 .68036 m .51659 .68325 L .52115 .68711 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51659 .68325 L 0 .649 .283 r
F
0 g
.51316 .68036 m
.51318 .68048 L
s
.51318 .68048 m
.51319 .68048 L
s
.51316 .68036 m
.51319 .68051 L
s
.51319 .68051 m
.51319 .68051 L
s
.51316 .68036 m .51316 .68036 L .51021 .67935 L 0 1 .364 r
F
0 g
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m .50588 .67943 L .51004 .67996 L 0 1 .364 r
F
.51316 .68036 m .50292 .67842 L .50588 .67943 L F
.51316 .68036 m .50314 .67761 L .50292 .67842 L F
.51316 .68036 m .50627 .67801 L .50314 .67761 L F
.51316 .68036 m .51021 .67935 L .50627 .67801 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68036 L
s
.51063 .67814 m
.51088 .67836 L
s
.51316 .68036 m .50824 .6937 L .51105 .68608 L 0 1 .372 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50586 .69915 L .50824 .6937 L 0 1 .372 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .5055 .69879 L .50586 .69915 L 0 1 .372 r
F
.51316 .68036 m .50761 .69307 L .5055 .69879 L F
.51316 .68036 m .51078 .68581 L .50761 .69307 L F
.51316 .68036 m .51316 .68036 L .51078 .68581 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50612 .6906 L .51014 .68475 L 0 .689 .284 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50295 .69367 L .50612 .6906 L 0 .689 .284 r
F
.51316 .68036 m .50275 .69192 L .50295 .69367 L F
.51316 .68036 m .50577 .68752 L .50275 .69192 L F
.51316 .68036 m .50999 .68343 L .50577 .68752 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51004 .67996 L 0 1 .363 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50558 .68083 L .50991 .68056 L 0 1 .363 r
F
0 g
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m .50246 .68043 L .50558 .68083 L 0 1 .363 r
F
.51316 .68036 m .50263 .67963 L .50246 .68043 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50588 .67943 L .50263 .67963 L 0 1 .363 r
F
.51316 .68036 m .51004 .67996 L .50588 .67943 L F
0 g
.51237 .67958 m
.51238 .6796 L
s
.5107 .67796 m
.51237 .67958 L
s
.51316 .68036 m
.51316 .68036 L
s
.51004 .67996 m
.51313 .68035 L
s
.51313 .68035 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51021 .67935 m
.51312 .68034 L
s
.51312 .68034 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.5104 .67875 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51063 .67814 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.5107 .67796 m
.51316 .68036 L
s
.51096 .67736 m
.51316 .68036 L
s
.51312 .68028 m
.51316 .68035 L
s
.51125 .67678 m
.51312 .68028 L
s
.51316 .68035 m
.51316 .68035 L
s
.51156 .67622 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68034 L
s
.51188 .67569 m
.51315 .6803 L
s
.51315 .6803 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68035 L
s
.51316 .68033 m
.51316 .68033 L
s
.51222 .6752 m
.51316 .68033 L
s
.51316 .68033 m
.51316 .68033 L
s
.51316 .68034 m
.51316 .68035 L
s
.51316 .68033 m
.51316 .68034 L
s
.51257 .67475 m
.51316 .68031 L
s
.51257 .67475 m
.51316 .68033 L
s
.51316 .68034 m
.51316 .68034 L
s
.51222 .6752 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68034 m
.51316 .68035 L
s
.51316 .68034 m
.51316 .68034 L
s
.51316 .68035 m
.51316 .68035 L
s
.51188 .67569 m
.51315 .68031 L
s
.51315 .68031 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51156 .67622 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51316 .68035 m
.51316 .68035 L
s
.51314 .68031 m
.51316 .68035 L
s
.51125 .67678 m
.51314 .68031 L
s
.51316 .68035 m
.51316 .68036 L
s
.51096 .67736 m
.51316 .68036 L
s
.51293 .68013 m
.51316 .68036 L
s
.51245 .67966 m
.51293 .68013 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68036 L
s
.51279 .68003 m
.51316 .68035 L
s
.51088 .67836 m
.51279 .68003 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68035 m
.51316 .68036 L
s
.5104 .67875 m
.51316 .68035 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51311 .68034 m
.51315 .68036 L
s
.51021 .67935 m
.51311 .68034 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51312 .68035 m
.51315 .68036 L
s
.51004 .67996 m
.51312 .68035 L
s
.51238 .6796 m
.51245 .67966 L
s
.51316 .68036 m .50761 .69307 L .51078 .68581 L 0 1 .372 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50499 .69821 L .50761 .69307 L 0 1 .372 r
F
.51316 .68036 m .50467 .6978 L .50499 .69821 L F
.51316 .68036 m .50705 .69235 L .50467 .6978 L F
.51316 .68036 m .51054 .6855 L .50705 .69235 L F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51054 .6855 L 0 1 .372 r
F
0 g
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .50991 .68056 L 0 1 .362 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50535 .68221 L .50982 .68115 L 0 1 .362 r
F
.51316 .68036 m .5021 .68242 L .50535 .68221 L F
.51316 .68036 m .50223 .68163 L .5021 .68242 L F
.51316 .68036 m .50558 .68083 L .50223 .68163 L F
.51316 .68036 m .50991 .68056 L .50558 .68083 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50705 .69235 L .51054 .6855 L 0 1 .37 r
F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m .50421 .69713 L .50705 .69235 L 0 1 .37 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50393 .69666 L .50421 .69713 L 0 1 .37 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50655 .69152 L .50393 .69666 L 0 1 .37 r
F
.51316 .68036 m .51033 .68514 L .50655 .69152 L F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m .51316 .68036 L .51033 .68514 L 0 1 .37 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .50982 .68115 L 0 1 .362 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51553 .67801 L 0 0 .06 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50521 .68357 L .50976 .68173 L 0 1 .362 r
F
.51316 .68036 m .50186 .68436 L .50521 .68357 L F
.51316 .68036 m .50194 .68359 L .50186 .68436 L F
.51316 .68036 m .50535 .68221 L .50194 .68359 L F
.51316 .68036 m .50982 .68115 L .50535 .68221 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50655 .69152 L .51033 .68514 L 0 1 .369 r
F
.51316 .68036 m .50353 .69591 L .50655 .69152 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50328 .69539 L .50353 .69591 L 0 1 .369 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50612 .6906 L .50328 .69539 L 0 1 .369 r
F
.51316 .68036 m .51014 .68475 L .50612 .6906 L F
0 g
.51316 .68038 m
.51316 .68037 L
s
.51316 .68036 m .51316 .68036 L .51014 .68475 L 0 1 .369 r
F
0 g
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .50976 .68173 L 0 1 .362 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50515 .68488 L .50973 .6823 L 0 1 .362 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50174 .68626 L .50515 .68488 L 0 1 .362 r
F
0 g
.51312 .68038 m
.51316 .68036 L
s
.51316 .68036 m .50178 .68551 L .50174 .68626 L 0 1 .362 r
F
0 g
.50213 .68474 m
.50389 .68455 L
s
.51316 .68036 m .50521 .68357 L .50178 .68551 L 0 1 .362 r
F
.51316 .68036 m .50976 .68173 L .50521 .68357 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50612 .6906 L .51014 .68475 L 0 1 .368 r
F
.51316 .68036 m .50295 .69456 L .50612 .6906 L F
0 g
.51315 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50274 .69399 L .50295 .69456 L 0 1 .368 r
F
0 g
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51316 .68036 m .50577 .6896 L .50274 .69399 L 0 1 .368 r
F
.51316 .68036 m .50999 .68432 L .50577 .6896 L F
.51316 .68036 m .51316 .68036 L .50999 .68432 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .50973 .6823 L 0 1 .363 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50518 .68615 L .50974 .68284 L 0 1 .363 r
F
.50248 .68925 m .50232 .68745 L .49892 .68803 L 0 .756 .296 r
F
.51316 .68036 m .50175 .68809 L .50518 .68615 L 0 1 .363 r
F
.51316 .68036 m .50173 .68737 L .50175 .68809 L F
.51316 .68036 m .50515 .68488 L .50173 .68737 L F
.51316 .68036 m .50973 .6823 L .50515 .68488 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50577 .6896 L .50999 .68432 L 0 1 .366 r
F
.50295 .69367 m .50275 .69192 L .49943 .69345 L 0 .736 .296 r
F
.51316 .68036 m .50247 .6931 L .50577 .6896 L 0 1 .366 r
F
0 g
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51316 .68036 m .50232 .69248 L .50247 .6931 L 0 1 .366 r
F
0 g
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51316 .68036 m .50549 .68852 L .50232 .69248 L 0 1 .366 r
F
.51316 .68036 m .50987 .68385 L .50549 .68852 L F
.51316 .68036 m .51316 .68036 L .50987 .68385 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .50974 .68284 L 0 1 .364 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50529 .68737 L .50979 .68336 L 0 1 .364 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.50248 .68925 m .4952 .69725 L .49943 .69345 L 0 .756 .296 r
F
.50248 .68925 m .49179 .69783 L .4952 .69725 L F
.51316 .68036 m .50187 .68985 L .50529 .68737 L 0 1 .364 r
F
.50248 .68925 m .49892 .68803 L .49454 .6906 L 0 .756 .296 r
F
.51316 .68036 m .50181 .68916 L .50187 .68985 L 0 1 .364 r
F
.51316 .68036 m .50518 .68615 L .50181 .68916 L F
.51316 .68036 m .50974 .68284 L .50518 .68615 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50549 .68852 L .50987 .68385 L 0 1 .365 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50211 .69152 L .50549 .68852 L 0 1 .365 r
F
0 g
.51313 .68036 m
.51315 .68036 L
s
.51316 .68036 m .502 .69086 L .50211 .69152 L 0 1 .365 r
F
0 g
.51313 .68036 m
.51313 .68036 L
s
.51316 .68036 m .50529 .68737 L .502 .69086 L 0 1 .365 r
F
.51316 .68036 m .50979 .68336 L .50529 .68737 L F
.51316 .68036 m .51316 .68036 L .50979 .68336 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51313 .68036 m
.51313 .68036 L
s
.51313 .68036 m
.51315 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51014 .68475 L 0 .68 .284 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51014 .68475 L .50612 .6906 L 0 .68 .284 r
F
.51316 .68036 m .50612 .6906 L .51014 .68475 L 0 0 .061 r
F
.50353 .69591 m .49445 .70697 L .49389 .70921 L 0 1 .388 r
F
.49445 .70697 m .4934 .70826 L .49345 .70836 L F
.49445 .70697 m .49345 .70836 L .49389 .70921 L F
.49445 .70697 m .49605 .70377 L .4934 .70826 L F
.50353 .69591 m .49897 .70071 L .49445 .70697 L F
.49897 .70071 m .49605 .70377 L .49445 .70697 L F
.49897 .70071 m .50008 .69876 L .49605 .70377 L F
.50353 .69591 m .5008 .69817 L .49897 .70071 L F
.5008 .69817 m .50008 .69876 L .49897 .70071 L F
.50353 .69591 m .50328 .69539 L .50008 .69876 L F
.51316 .68036 m .50612 .6906 L .50328 .69628 L 0 .68 .284 r
F
.50468 .69348 m .50247 .69695 L .50487 .69309 L 0 0 .061 r
F
.50468 .69348 m .50487 .69309 L .50576 .69167 L F
.50879 .68705 m .50468 .69348 L .50576 .69167 L F
.51316 .68036 m .5094 .6862 L .50879 .68705 L F
.5094 .6862 m .50247 .69695 L .50879 .68705 L F
.50421 .69713 m .50393 .69666 L .50088 .70039 L 0 1 .389 r
F
.50353 .69591 m .4971 .70584 L .50088 .70039 L 0 1 .388 r
F
.50353 .69591 m .49389 .70921 L .4971 .70584 L F
.50353 .69799 m .50328 .69628 L .50064 .69832 L 0 .717 .296 r
F
.50353 .69799 m .50064 .69832 L .50038 .69869 L F
.50421 .69713 m .50088 .70039 L .4971 .70584 L 0 1 .389 r
F
.51316 .68036 m .50328 .69628 L .50353 .69799 L 0 .68 .284 r
F
.49765 .70254 m .50008 .69876 L .49605 .70377 L 0 .717 .296 r
F
.50353 .69799 m .50038 .69869 L .49765 .70254 L F
.50038 .69869 m .50008 .69876 L .49765 .70254 L F
.51186 .68251 m .50529 .69355 L .50199 .69883 L 0 0 .06 r
F
.51316 .68036 m .51197 .68236 L .51186 .68251 L F
.51197 .68236 m .50529 .69355 L .51186 .68251 L F
.51168 .68276 m .50199 .69883 L .5021 .69832 L F
.51316 .68036 m .51186 .68251 L .51168 .68276 L F
.51186 .68251 m .50199 .69883 L .51168 .68276 L F
.50038 .69869 m .50064 .69832 L .50008 .69876 L 0 .717 .296 r
F
.51151 .683 m .5021 .69832 L .50548 .69265 L 0 0 .06 r
F
.51316 .68036 m .51168 .68276 L .51151 .683 L F
.51168 .68276 m .5021 .69832 L .51151 .683 L F
.50975 .68576 m .50548 .69265 L .50231 .69751 L 0 0 .061 r
F
.51316 .68036 m .51009 .68529 L .50975 .68576 L F
.51009 .68529 m .50548 .69265 L .50975 .68576 L F
.50905 .68673 m .50409 .69466 L .50461 .69363 L F
.50409 .69466 m .50231 .69751 L .50461 .69363 L F
.50461 .69363 m .50231 .69751 L .50247 .69695 L F
.51316 .68036 m .50967 .68588 L .50905 .68673 L F
.50967 .68588 m .50231 .69751 L .50905 .68673 L F
.51316 .68036 m .50295 .69545 L .50612 .6906 L F
.51316 .68036 m .50274 .69606 L .50295 .69545 L F
.51316 .68036 m .50576 .69167 L .50274 .69606 L F
.51316 .68036 m .50999 .68521 L .50576 .69167 L F
.51316 .68036 m .51316 .68036 L .50999 .68521 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m .51806 .67726 L .51526 .67903 L 0 0 .06 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .52044 .67491 L .51806 .67726 L 0 0 .06 r
F
.51316 .68036 m .5208 .67355 L .52044 .67491 L F
.51316 .68036 m .51869 .67488 L .5208 .67355 L F
.51316 .68036 m .51553 .67801 L .51869 .67488 L F
.51316 .68036 m .52115 .68711 L .51659 .68325 L 0 .637 .282 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .52459 .69194 L .52115 .68711 L 0 .637 .282 r
F
.51316 .68036 m .52461 .69452 L .52459 .69194 L F
.51316 .68036 m .52118 .69162 L .52461 .69452 L F
.51316 .68036 m .5166 .68518 L .52118 .69162 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .5166 .68518 L 0 .637 .282 r
F
.51316 .68036 m .50655 .69359 L .51033 .68603 L 0 .68 .284 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50353 .69799 L .50655 .69359 L 0 .68 .284 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51526 .67903 L 0 0 .064 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51033 .68603 L 0 .672 .285 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68036 m .50576 .69167 L .50999 .68521 L 0 0 .061 r
F
.51316 .68036 m .50987 .68563 L .50548 .69265 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .50987 .68563 L 0 0 .061 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51738 .67961 L .51497 .68004 L 0 0 .064 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m .51949 .67828 L .51738 .67961 L 0 0 .064 r
F
.51316 .68036 m .51988 .67693 L .51949 .67828 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51806 .67726 L .51988 .67693 L 0 0 .064 r
F
.51316 .68036 m .51526 .67903 L .51806 .67726 L F
0 g
.51316 .68036 m
.51318 .68034 L
s
.51318 .68034 m
.51318 .68034 L
s
.51318 .68034 m
.51318 .68034 L
s
.51316 .68036 m .52118 .69162 L .5166 .68518 L 0 .628 .281 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .5246 .69829 L .52118 .69162 L 0 .628 .281 r
F
.51316 .68036 m .52456 .70073 L .5246 .69829 L F
.51316 .68036 m .52112 .69588 L .52456 .70073 L F
.51316 .68036 m .51657 .687 L .52112 .69588 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51657 .687 L 0 .628 .281 r
F
.51316 .68036 m .50705 .69649 L .51054 .68727 L 0 .672 .285 r
F
.50586 .69915 m .49968 .70943 L .49784 .71463 L 0 1 .389 r
F
.50586 .69915 m .50286 .7032 L .49968 .70943 L F
.50586 .69915 m .5055 .69879 L .50286 .7032 L F
.51316 .68036 m .50421 .70217 L .50705 .69649 L 0 .672 .285 r
F
.50499 .69821 m .49682 .71351 L .49968 .70943 L 0 1 .389 r
F
.50499 .69821 m .49617 .71271 L .49682 .71351 L F
.50499 .69821 m .49831 .70773 L .49617 .71271 L F
.50499 .69821 m .50181 .70187 L .49831 .70773 L F
.50499 .69821 m .50467 .6978 L .50181 .70187 L F
.51316 .68036 m .50392 .70051 L .50421 .70217 L 0 .672 .285 r
F
.51316 .68036 m .50655 .69359 L .50392 .70051 L F
.51316 .68036 m .51033 .68603 L .50655 .69359 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51497 .68004 L 0 0 .069 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51318 .68034 m
.51318 .68034 L
s
.51318 .68034 m
.51318 .68034 L
s
.51316 .68036 m
.51318 .68034 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51054 .68727 L 0 .666 .285 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50548 .69265 L .50987 .68563 L 0 0 .06 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50979 .68601 L .50529 .69355 L 0 0 .06 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .50979 .68601 L 0 0 .06 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .52112 .69588 L .51657 .687 L 0 .624 .28 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .52448 .70425 L .52112 .69588 L 0 .624 .28 r
F
.51316 .68036 m .52439 .70651 L .52448 .70425 L F
.51316 .68036 m .52097 .69983 L .52439 .70651 L F
.51316 .68036 m .51651 .68869 L .52097 .69983 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51651 .68869 L 0 .624 .28 r
F
.51316 .68036 m .51665 .6819 L .51466 .68102 L 0 0 .069 r
F
0 g
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m .51846 .68158 L .51665 .6819 L 0 0 .069 r
F
.51316 .68036 m .51888 .68027 L .51846 .68158 L F
.51316 .68036 m .51738 .67961 L .51888 .68027 L F
.51316 .68036 m .51497 .68004 L .51738 .67961 L F
0 g
.51316 .68036 m
.51497 .68004 L
s
.51318 .68035 m
.51526 .67903 L
s
.51316 .68036 m
.51318 .68035 L
s
.51318 .68035 m
.51318 .68035 L
s
.51317 .68035 m
.51319 .68033 L
s
.51316 .68036 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51319 .68033 m
.51319 .68033 L
s
.51319 .68033 m
.51553 .67801 L
s
.51319 .68033 m
.51319 .68033 L
s
.51318 .68034 m
.51321 .68029 L
s
.51321 .68029 m
.51321 .68029 L
s
.51321 .68029 m
.51578 .67701 L
s
.51321 .68029 m
.51321 .68029 L
s
.51318 .68034 m
.5132 .68031 L
s
.5132 .68031 m
.5132 .68031 L
s
.5132 .68031 m
.51578 .67701 L
s
.5132 .68031 m
.5132 .68031 L
s
.51317 .68035 m
.51318 .68034 L
s
.51316 .68036 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51318 .68034 m
.51318 .68034 L
s
.51318 .68034 m
.51553 .67801 L
s
.51318 .68034 m
.51318 .68034 L
s
.51317 .68035 m
.51526 .67903 L
s
.51316 .68036 m
.51317 .68035 L
s
.51317 .68035 m
.51317 .68035 L
s
.51316 .68036 m
.51497 .68004 L
s
.51316 .68036 m .50761 .69926 L .51078 .68846 L 0 .666 .285 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50498 .70619 L .50761 .69926 L 0 .666 .285 r
F
.5068 .69993 m .50284 .7122 L .50527 .70531 L 0 1 .389 r
F
.5068 .69993 m .50044 .71692 L .50284 .7122 L F
.5068 .69993 m .49967 .71631 L .50044 .71692 L F
.5068 .69993 m .5012 .71092 L .49967 .71631 L F
.5068 .69993 m .50401 .70435 L .5012 .71092 L F
.5068 .69993 m .50641 .69963 L .50401 .70435 L F
.51316 .68036 m .50466 .7046 L .50498 .70619 L 0 .666 .285 r
F
.51316 .68036 m .50705 .69649 L .50466 .7046 L F
.51316 .68036 m .51054 .68727 L .50705 .69649 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68039 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51078 .68846 L 0 .663 .286 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68037 L
s
.51316 .68039 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51466 .68102 L 0 0 .072 r
F
.51316 .68036 m .52097 .69983 L .51651 .68869 L 0 .624 .28 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m .52423 .70975 L .52097 .69983 L 0 .624 .28 r
F
0 g
.51317 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m .5241 .7118 L .52423 .70975 L 0 .624 .28 r
F
.51316 .68036 m .52074 .70342 L .5241 .7118 L F
.51316 .68036 m .51641 .69023 L .52074 .70342 L F
.51316 .68036 m .51316 .68036 L .51641 .69023 L F
0 g
.51318 .68047 m
.51318 .68047 L
s
.51316 .68036 m
.51318 .68047 L
s
.51316 .68036 m .50823 .7019 L .51105 .68959 L 0 .663 .286 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.50888 .70098 m .50459 .71325 L .50372 .71892 L 0 1 .387 r
F
.50888 .70098 m .50661 .70608 L .50459 .71325 L F
.50888 .70098 m .50844 .70082 L .50661 .70608 L F
.51316 .68036 m .50584 .71002 L .50823 .7019 L 0 .663 .286 r
F
.50781 .70054 m .50459 .71325 L .50661 .70608 L 0 1 .388 r
F
.50781 .70054 m .50246 .71825 L .50459 .71325 L F
.50781 .70054 m .50163 .71775 L .50246 .71825 L F
.50781 .70054 m .50284 .7122 L .50163 .71775 L F
.50781 .70054 m .50527 .70531 L .50284 .7122 L F
.50781 .70054 m .5074 .70031 L .50527 .70531 L F
.51316 .68036 m .50549 .70851 L .50584 .71002 L 0 .663 .286 r
F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m .50761 .69926 L .50549 .70851 L 0 .663 .286 r
F
.51316 .68036 m .51078 .68846 L .50761 .69926 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50529 .69355 L .50979 .68601 L 0 0 .059 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.49389 .70921 m .48598 .71521 L .48351 .71949 L 0 1 .406 r
F
.49389 .70921 m .49001 .71083 L .48598 .71521 L F
.49389 .70921 m .4934 .70826 L .49001 .71083 L F
.50353 .69799 m .49721 .70288 L .49339 .70972 L 0 .717 .296 r
F
.50421 .69713 m .49469 .71059 L .49526 .71146 L 0 1 .389 r
F
.50421 .69713 m .4971 .70584 L .49469 .71059 L F
.49526 .71146 m .49142 .71349 L .48764 .71824 L 0 1 .406 r
F
.49526 .71146 m .49469 .71059 L .49142 .71349 L F
.49389 .70921 m .48764 .71824 L .49142 .71349 L F
.49389 .70921 m .48425 .72081 L .48764 .71824 L F
.49389 .70921 m .48351 .71949 L .48425 .72081 L F
.50353 .69799 m .49339 .70972 L .49388 .71262 L 0 .717 .296 r
F
.51159 .68302 m .50179 .70002 L .50185 .69956 L 0 0 .059 r
F
.51316 .68036 m .51173 .68283 L .51159 .68302 L F
.51173 .68283 m .50179 .70002 L .51159 .68302 L F
.49721 .70288 m .49605 .70377 L .49523 .70561 L 0 .717 .296 r
F
.49721 .70288 m .49523 .70561 L .49339 .70972 L F
.51147 .68319 m .50185 .69956 L .50529 .69355 L 0 0 .059 r
F
.51316 .68036 m .51159 .68302 L .51147 .68319 L F
.51159 .68302 m .50185 .69956 L .51147 .68319 L F
.51316 .68036 m .50517 .69435 L .50179 .70002 L F
.51316 .68036 m .50974 .68635 L .50517 .69435 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .50974 .68635 L 0 0 .059 r
F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51588 .68409 L .51433 .68195 L 0 0 .072 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51738 .68475 L .51588 .68409 L 0 0 .072 r
F
.51316 .68036 m .51782 .6835 L .51738 .68475 L F
.51316 .68036 m .51665 .6819 L .51782 .6835 L F
.51316 .68036 m .51466 .68102 L .51665 .6819 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51105 .68959 L 0 .662 .286 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51433 .68195 L 0 0 .075 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .52074 .70342 L .51641 .69023 L 0 .629 .279 r
F
0 g
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m .52387 .71471 L .52074 .70342 L 0 .629 .279 r
F
.5236 .71544 m .52344 .72262 L .52523 .73032 L 0 1 .369 r
F
.5236 .71544 m .52274 .71624 L .52344 .72262 L F
.51316 .68036 m .52369 .71654 L .52387 .71471 L 0 .629 .279 r
F
.51316 .68036 m .52043 .70661 L .52369 .71654 L F
.51316 .68036 m .51627 .69159 L .52043 .70661 L F
.51316 .68036 m .51316 .68036 L .51627 .69159 L F
.50999 .70124 m .50801 .70665 L .50643 .71406 L 0 1 .385 r
F
.50999 .70124 m .50954 .70116 L .50801 .70665 L F
.51316 .68036 m .50891 .7044 L .51134 .69065 L 0 .662 .286 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.50999 .70124 m .50643 .71406 L .50591 .71982 L 0 1 .385 r
F
.51316 .68036 m .50679 .71366 L .50891 .7044 L 0 .662 .286 r
F
.50888 .70098 m .50643 .71406 L .50801 .70665 L 0 1 .387 r
F
.50888 .70098 m .50459 .71932 L .50643 .71406 L F
.50888 .70098 m .50372 .71892 L .50459 .71932 L F
.51316 .68036 m .5064 .71223 L .50679 .71366 L 0 .662 .286 r
F
.51316 .68036 m .50823 .7019 L .5064 .71223 L F
.51316 .68036 m .51105 .68959 L .50823 .7019 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68039 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68039 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m .50517 .69435 L .50974 .68635 L 0 0 .057 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50172 .70067 L .50517 .69435 L 0 0 .057 r
F
.50421 .69713 m .49526 .71146 L .49831 .70773 L 0 1 .389 r
F
.50353 .69799 m .49388 .71262 L .49708 .71014 L 0 .717 .296 r
F
.51316 .68036 m .5017 .70108 L .50172 .70067 L 0 0 .057 r
F
.51316 .68036 m .50514 .69506 L .5017 .70108 L F
.51316 .68036 m .50973 .68665 L .50514 .69506 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .50973 .68665 L 0 0 .057 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m .51508 .68614 L .51399 .68283 L 0 0 .075 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51625 .68775 L .51508 .68614 L 0 0 .075 r
F
.51316 .68036 m .51671 .68657 L .51625 .68775 L F
.51316 .68036 m .51588 .68409 L .51671 .68657 L F
.51316 .68036 m .51433 .68195 L .51588 .68409 L F
0 g
.51318 .68049 m
.51318 .68049 L
s
.51316 .68037 m
.51318 .68049 L
s
.51316 .68036 m
.51317 .68047 L
s
.51317 .68047 m
.51317 .68047 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68037 m .51316 .68037 L .51134 .69065 L 0 .664 .287 r
F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .52043 .70661 L .51627 .69159 L 0 .636 .279 r
F
.51316 .68036 m .52339 .7191 L .52043 .70661 L F
.51316 .68036 m .52316 .72068 L .52339 .7191 L F
.51316 .68036 m .52003 .70938 L .52316 .72068 L F
0 g
.5173 .69826 m
.51773 .69964 L
s
.51316 .68036 m .5161 .69277 L .52003 .70938 L 0 .636 .279 r
F
.51316 .68036 m .51316 .68036 L .5161 .69277 L F
.51316 .68036 m .51316 .68036 L .51399 .68283 L 0 0 .076 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51317 .68039 m
.51317 .68048 L
s
.51317 .68048 m
.51317 .68048 L
s
.51318 .6805 m
.51318 .6805 L
s
.51318 .68049 m
.51318 .6805 L
s
.51316 .68036 m
.51316 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51113 .7013 m .50947 .707 L .50834 .7146 L 0 1 .383 r
F
.51113 .7013 m .51067 .7013 L .50947 .707 L F
.51316 .68037 m .50963 .70672 L .51165 .69165 L 0 .664 .287 r
F
0 g
.51316 .68037 m
.51316 .68036 L
s
.50999 .70124 m .50834 .7146 L .50947 .707 L 0 1 .385 r
F
.50999 .70124 m .50681 .7201 L .50834 .7146 L F
.51316 .68037 m .5078 .71705 L .50963 .70672 L 0 .664 .287 r
F
0 g
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.50999 .70124 m .50591 .71982 L .50681 .7201 L 0 1 .385 r
F
.51316 .68037 m .50738 .71572 L .5078 .71705 L 0 .664 .287 r
F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m .50891 .7044 L .50738 .71572 L 0 .664 .287 r
F
.51316 .68037 m .51134 .69065 L .50891 .7044 L F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68041 m
.51316 .68038 L
s
.51316 .68041 m
.51316 .68041 L
s
.51316 .68041 m
.51316 .68041 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m .50514 .69506 L .50973 .68665 L 0 0 .055 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.50421 .69713 m .49831 .70773 L .50181 .70187 L 0 1 .389 r
F
.50353 .69799 m .49708 .71014 L .50087 .70393 L 0 .717 .296 r
F
.51316 .68036 m .50171 .70164 L .50514 .69506 L 0 0 .055 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50175 .70199 L .50171 .70164 L 0 0 .055 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .5052 .69567 L .50175 .70199 L 0 0 .055 r
F
.51316 .68036 m .50975 .68691 L .5052 .69567 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .50975 .68691 L 0 0 .055 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51617 .69929 m .51825 .71921 L .51917 .71875 L 0 1 .369 r
F
.51617 .69929 m .5169 .71367 L .51825 .71921 L F
.51617 .69929 m .51602 .7058 L .5169 .71367 L F
.51617 .69929 m .51571 .69965 L .51602 .7058 L F
.51917 .71875 m .52079 .73829 L .52218 .7379 L 0 1 .379 r
F
.51917 .71875 m .5191 .73288 L .52079 .73829 L F
.51917 .71875 m .51822 .72527 L .5191 .73288 L F
.51917 .71875 m .51825 .71921 L .51822 .72527 L F
.51316 .68037 m .52003 .73102 L .52041 .73043 L 0 .678 .282 r
F
.51316 .68036 m .51426 .68804 L .51363 .68365 L 0 0 .076 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.52143 .71731 m .52221 .73185 L .52422 .73716 L 0 1 .374 r
F
.52143 .71731 m .52087 .72417 L .52221 .73185 L F
.52143 .71731 m .52054 .71794 L .52087 .72417 L F
.51316 .68037 m .52178 .7271 L .52209 .72602 L 0 .656 .28 r
F
.51617 .69929 m .51886 .71259 L .51752 .70484 L 0 1 .369 r
F
.51617 .69929 m .51917 .71875 L .51886 .71259 L F
.51316 .68037 m .51903 .71359 L .52178 .7271 L 0 .656 .28 r
F
.51316 .68037 m .51567 .69457 L .51903 .71359 L F
.51316 .68037 m .51316 .68037 L .51567 .69457 L F
.51316 .68037 m .51903 .71359 L .51567 .69457 L 0 .667 .281 r
F
.51917 .71875 m .52221 .73185 L .52087 .72417 L 0 1 .379 r
F
.51917 .71875 m .52218 .7379 L .52221 .73185 L F
.51316 .68037 m .52129 .72854 L .51903 .71359 L 0 .667 .281 r
F
.51316 .68037 m .52095 .72937 L .52129 .72854 L F
.51316 .68037 m .51842 .71504 L .52095 .72937 L F
.51316 .68037 m .51541 .69519 L .51842 .71504 L F
.51316 .68037 m .51316 .68037 L .51541 .69519 L F
.51316 .68037 m .51842 .71504 L .51541 .69519 L 0 .678 .282 r
F
.51316 .68037 m .52041 .73043 L .51842 .71504 L F
.51316 .68036 m .51509 .69054 L .51426 .68804 L 0 0 .076 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .52003 .70938 L .5161 .69277 L 0 .645 .28 r
F
.52143 .71731 m .52523 .73032 L .52344 .72262 L 0 1 .374 r
F
.52143 .71731 m .52557 .73655 L .52523 .73032 L F
.51316 .68036 m .52279 .72287 L .52003 .70938 L 0 .645 .28 r
F
.52143 .71731 m .52422 .73716 L .52557 .73655 L 0 1 .374 r
F
.51316 .68036 m .52252 .72421 L .52279 .72287 L 0 .645 .28 r
F
.51316 .68036 m .51956 .7117 L .52252 .72421 L F
.51316 .68036 m .5159 .69377 L .51956 .7117 L F
.51316 .68036 m .51316 .68036 L .5159 .69377 L F
.51316 .68037 m .51956 .7117 L .5159 .69377 L 0 .656 .28 r
F
.51316 .68037 m .52209 .72602 L .51956 .7117 L F
.51316 .68036 m .51556 .68945 L .51509 .69054 L 0 0 .076 r
F
.51316 .68036 m .51508 .68614 L .51556 .68945 L F
.51316 .68036 m .51399 .68283 L .51508 .68614 L F
0 g
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51317 .68036 m
.51317 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m .51316 .68037 L .51165 .69165 L 0 .669 .288 r
F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68037 m
.51316 .68036 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51113 .7013 m .50818 .72042 L .5091 .72058 L 0 1 .383 r
F
.51113 .7013 m .50834 .7146 L .50818 .72042 L F
.51316 .68037 m .51038 .70886 L .51197 .69256 L 0 .669 .288 r
F
.51316 .68037 m .50886 .72019 L .51038 .70886 L F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m .50843 .71897 L .50886 .72019 L 0 .669 .288 r
F
.51316 .68037 m .50963 .70672 L .50843 .71897 L F
.51316 .68037 m .51165 .69165 L .50963 .70672 L F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68043 m
.51316 .68043 L
s
.51316 .68043 m
.51316 .68042 L
s
.51316 .68042 m
.51316 .68039 L
s
.51316 .68043 m
.51316 .6804 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m .51316 .68036 L .51363 .68365 L 0 0 .076 r
F
0 g
.51318 .6805 m
.51318 .6805 L
s
.51317 .68048 m
.51318 .6805 L
s
.51318 .68047 m
.51318 .68052 L
s
.51318 .68052 m
.51318 .68053 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m .51316 .68037 L .51197 .69256 L 0 .675 .288 r
F
0 g
.51316 .68043 m
.51316 .68043 L
s
.51316 .68036 m .5052 .69567 L .50975 .68691 L 0 0 .052 r
F
0 g
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50183 .70247 L .5052 .69567 L 0 0 .052 r
F
.51316 .68036 m .50191 .70277 L .50183 .70247 L F
.51316 .68036 m .50534 .69618 L .50191 .70277 L F
.51316 .68036 m .50981 .68713 L .50534 .69618 L F
.51316 .68036 m .51316 .68036 L .50981 .68713 L F
0 g
.51315 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51379 .72056 m .5141 .73907 L .51496 .73352 L 0 1 .389 r
F
.51379 .72056 m .51496 .73352 L .51469 .72607 L F
.51347 .70085 m .51429 .71455 L .51403 .70666 L 0 1 .377 r
F
.51347 .70085 m .51379 .72056 L .51429 .71455 L F
.51316 .68037 m .51418 .73052 L .51465 .73103 L 0 .7 .288 r
F
.51316 .68036 m .51343 .68977 L .51328 .68438 L 0 0 .076 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68039 L
s
.51465 .70032 m .51429 .71455 L .51519 .72028 L 0 1 .374 r
F
.51465 .70032 m .51403 .70666 L .51429 .71455 L F
.51465 .70032 m .51418 .70055 L .51403 .70666 L F
.51316 .68037 m .51445 .71605 L .51371 .69563 L 0 .7 .288 r
F
.51316 .68037 m .51465 .73103 L .51445 .71605 L F
.51316 .68037 m .51316 .68037 L .51371 .69563 L 0 .7 .287 r
F
.51316 .68037 m .51471 .71627 L .51382 .69572 L F
.51613 .72003 m .51496 .73352 L .51621 .73901 L 0 1 .385 r
F
.51613 .72003 m .51469 .72607 L .51496 .73352 L F
.51613 .72003 m .51519 .72028 L .51469 .72607 L F
.51316 .68037 m .51526 .73164 L .51471 .71627 L 0 .7 .287 r
F
.51316 .68037 m .51512 .73152 L .51526 .73164 L F
.51316 .68037 m .51445 .71605 L .51512 .73152 L F
.51316 .68037 m .51371 .69563 L .51445 .71605 L F
.51316 .68037 m .51316 .68037 L .51382 .69572 L 0 .701 .287 r
F
.51465 .70032 m .51519 .72028 L .51613 .72003 L 0 1 .374 r
F
.51316 .68037 m .51572 .73195 L .51618 .73224 L 0 .701 .287 r
F
.51316 .68037 m .51471 .71627 L .51572 .73195 L F
.51316 .68037 m .51382 .69572 L .51471 .71627 L F
.51316 .68036 m .51391 .69308 L .51343 .68977 L 0 0 .076 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51525 .69998 m .51705 .71975 L .51734 .71964 L 0 1 .37 r
F
.51525 .69998 m .51628 .71393 L .51705 .71975 L F
.51525 .69998 m .51555 .70605 L .51628 .71393 L F
.51525 .69998 m .51511 .70007 L .51555 .70605 L F
.51734 .71964 m .51812 .7331 L .51899 .73873 L 0 1 .381 r
F
.51734 .71964 m .51738 .72552 L .51812 .7331 L F
.51734 .71964 m .51705 .71975 L .51738 .72552 L F
.51316 .68037 m .51841 .73244 L .51706 .71669 L 0 .695 .284 r
F
.51465 .70032 m .51628 .71393 L .51555 .70605 L 0 1 .374 r
F
.51465 .70032 m .51613 .72003 L .51628 .71393 L F
.51613 .72003 m .51761 .73888 L .51812 .7331 L 0 1 .385 r
F
.51613 .72003 m .51812 .7331 L .51738 .72552 L F
.51316 .68037 m .51798 .73257 L .51841 .73244 L 0 .695 .284 r
F
.51316 .68037 m .5163 .71691 L .51798 .73257 L F
.51316 .68037 m .51451 .69599 L .5163 .71691 L F
.51316 .68037 m .51316 .68037 L .51451 .69599 L F
.51316 .68037 m .5163 .71691 L .51451 .69599 L 0 .699 .286 r
F
.51316 .68037 m .51732 .7326 L .5163 .71691 L F
.51613 .72003 m .51621 .73901 L .51761 .73888 L 0 1 .385 r
F
.51316 .68037 m .51687 .73251 L .51732 .7326 L 0 .699 .286 r
F
.51316 .68037 m .51552 .71676 L .51687 .73251 L F
.51316 .68037 m .51417 .69593 L .51552 .71676 L F
.51316 .68037 m .51316 .68037 L .51417 .69593 L F
.51316 .68037 m .51552 .71676 L .51417 .69593 L 0 .701 .287 r
F
.51316 .68037 m .51618 .73224 L .51552 .71676 L F
.51316 .68036 m .51438 .69209 L .51391 .69308 L 0 0 .076 r
F
.51316 .68037 m .51776 .71607 L .52003 .73102 L 0 .678 .282 r
F
.51316 .68037 m .51513 .69563 L .51776 .71607 L F
.51316 .68037 m .51316 .68037 L .51513 .69563 L F
.51316 .68037 m .51776 .71607 L .51513 .69563 L 0 .687 .283 r
F
.51316 .68037 m .51944 .73173 L .51776 .71607 L F
.51316 .68037 m .51904 .73208 L .51944 .73173 L F
.51525 .69998 m .5169 .71367 L .51602 .7058 L 0 1 .37 r
F
.51525 .69998 m .51734 .71964 L .5169 .71367 L F
.51316 .68037 m .51706 .71669 L .51904 .73208 L 0 .687 .283 r
F
.51316 .68037 m .51483 .6959 L .51706 .71669 L F
.51316 .68037 m .51316 .68037 L .51483 .6959 L F
.51316 .68037 m .51706 .71669 L .51483 .6959 L 0 .695 .284 r
F
.51316 .68036 m .51426 .68804 L .51438 .69209 L 0 0 .076 r
F
.51316 .68036 m .51363 .68365 L .51426 .68804 L F
0 g
.51519 .6903 m
.5159 .69377 L
s
.5123 .70118 m .5103 .71488 L .5105 .72071 L 0 1 .38 r
F
.5123 .70118 m .51097 .70712 L .5103 .71488 L F
.5123 .70118 m .51183 .70125 L .51097 .70712 L F
.51316 .68037 m .51117 .71079 L .51231 .69338 L 0 .675 .288 r
F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m .50998 .72305 L .51117 .71079 L 0 .675 .288 r
F
.51113 .7013 m .5103 .71488 L .51097 .70712 L 0 1 .383 r
F
.51113 .7013 m .5091 .72058 L .5103 .71488 L F
.51316 .68037 m .50953 .72194 L .50998 .72305 L 0 .675 .288 r
F
.51316 .68037 m .51038 .70886 L .50953 .72194 L F
.51316 .68037 m .51197 .69256 L .51038 .70886 L F
0 g
.51315 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51481 .68969 m
.51567 .69457 L
s
.51316 .68036 m .51316 .68036 L .51328 .68438 L 0 0 .075 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m .51316 .68037 L .51231 .69338 L 0 .682 .289 r
F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51481 .68969 m
.51567 .69457 L
s
.51316 .68036 m .50534 .69618 L .50981 .68713 L 0 0 .05 r
F
0 g
.51316 .68037 m
.51316 .68036 L
s
.50499 .69821 m .49968 .70943 L .50286 .7032 L 0 1 .389 r
F
.50421 .70217 m .50392 .70051 L .50087 .70393 L 0 .699 .296 r
F
.51316 .68036 m .50206 .70316 L .50534 .69618 L 0 0 .05 r
F
.50421 .70217 m .50087 .70393 L .49708 .71014 L 0 .699 .296 r
F
.51316 .68036 m .50219 .70339 L .50206 .70316 L 0 0 .05 r
F
0 g
.49892 .68803 m
.50213 .68474 L
s
.51316 .68036 m .50556 .69658 L .50219 .70339 L 0 0 .05 r
F
.51316 .68036 m .50991 .6873 L .50556 .69658 L F
.51316 .68036 m .51316 .68036 L .50991 .6873 L F
0 g
.51315 .68036 m
.51315 .68036 L
s
.5123 .70118 m .51229 .71487 L .5125 .70701 L 0 1 .38 r
F
.5123 .70118 m .51144 .72074 L .51229 .71487 L F
.51316 .68037 m .51198 .71249 L .51266 .69411 L 0 .682 .289 r
F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51144 .72074 m .50917 .73861 L .51057 .73883 L 0 1 .393 r
F
.51144 .72074 m .50862 .73312 L .50917 .73861 L F
.51144 .72074 m .50929 .72602 L .50862 .73312 L F
.5123 .70118 m .5105 .72071 L .51144 .72074 L 0 1 .38 r
F
.51144 .72074 m .5105 .72071 L .50929 .72602 L 0 1 .393 r
F
.51316 .68037 m .51113 .72559 L .51198 .71249 L 0 .682 .289 r
F
.51316 .68037 m .51066 .72461 L .51113 .72559 L F
.51316 .68037 m .51117 .71079 L .51066 .72461 L F
.51316 .68037 m .51231 .69338 L .51117 .71079 L F
.51316 .68036 m .5126 .69131 L .51292 .68504 L 0 0 .075 r
F
.51316 .68037 m .51316 .68037 L .51266 .69411 L 0 .689 .289 r
F
.51144 .72074 m .51178 .73352 L .51199 .72623 L 0 1 .393 r
F
.51316 .68037 m .51198 .71249 L .51183 .72695 L 0 .689 .289 r
F
.51316 .68037 m .51266 .69411 L .51198 .71249 L F
.51316 .68036 m .51271 .69537 L .5126 .69131 L 0 0 .075 r
F
.51347 .70085 m .51229 .71487 L .51285 .72067 L 0 1 .377 r
F
.51347 .70085 m .5125 .70701 L .51229 .71487 L F
.51347 .70085 m .513 .70101 L .5125 .70701 L F
.51316 .68037 m .5128 .71395 L .51301 .69473 L 0 .689 .289 r
F
.51379 .72056 m .51199 .72623 L .51178 .73352 L 0 1 .389 r
F
.51379 .72056 m .51285 .72067 L .51199 .72623 L F
.51316 .68037 m .5123 .72779 L .5128 .71395 L 0 .689 .289 r
F
.51316 .68037 m .51183 .72695 L .5123 .72779 L F
.51316 .68037 m .51316 .68037 L .51301 .69473 L 0 .696 .288 r
F
.51379 .72056 m .51269 .73903 L .5141 .73907 L 0 1 .389 r
F
.51379 .72056 m .51178 .73352 L .51269 .73903 L F
.51347 .70085 m .51285 .72067 L .51379 .72056 L 0 1 .377 r
F
.51316 .68037 m .513 .72893 L .51348 .72961 L 0 .696 .288 r
F
.51316 .68037 m .5128 .71395 L .513 .72893 L F
.51316 .68037 m .51301 .69473 L .5128 .71395 L F
.51316 .68036 m .51319 .69449 L .51271 .69537 L 0 0 .075 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51316 .68036 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51316 .68036 L
s
.51316 .68037 m .51363 .71515 L .51336 .69524 L 0 .696 .288 r
F
.51316 .68037 m .51348 .72961 L .51363 .71515 L F
.51316 .68037 m .51316 .68037 L .51336 .69524 L 0 .7 .288 r
F
.51316 .68037 m .51363 .71515 L .51418 .73052 L F
.51316 .68037 m .51336 .69524 L .51363 .71515 L F
.51316 .68036 m .51343 .68977 L .51319 .69449 L 0 0 .075 r
F
0 g
.51316 .68036 m
.51317 .68036 L
s
.51316 .68036 m .51328 .68438 L .51343 .68977 L 0 0 .075 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51328 .68438 L
s
.51316 .68036 m
.51363 .68365 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51399 .68283 L
s
.51317 .68036 m
.51317 .68039 L
s
.51317 .68036 m
.51433 .68195 L
s
.51316 .68036 m
.51317 .68036 L
s
.51317 .68037 m
.51317 .68037 L
s
.51317 .68037 m
.51318 .68039 L
s
.51317 .68037 m
.51317 .68037 L
s
.51317 .68037 m
.51317 .68037 L
s
.51317 .68036 m
.51466 .68102 L
s
.51317 .68036 m
.51466 .68102 L
s
.51318 .68041 m
.51319 .68045 L
s
.51317 .68039 m
.51318 .68041 L
s
.51318 .68041 m
.51318 .68041 L
s
.51316 .68036 m
.51433 .68195 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51399 .68283 L
s
.51316 .68036 m
.51363 .68365 L
s
.51316 .68037 m
.51328 .68438 L
s
.51316 .68036 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51438 .6884 m
.51541 .69519 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51317 .68037 L
s
.51438 .6884 m
.51541 .69519 L
s
.51519 .6903 m
.5159 .69377 L
s
.51655 .68698 m
.51657 .687 L
s
.51655 .68698 m
.51657 .687 L
s
.51597 .68736 m
.51651 .68869 L
s
.51597 .68736 m
.51651 .68869 L
s
.51594 .68426 m
.5166 .68518 L
s
.51594 .68426 m
.5166 .68518 L
s
.5154 .68981 m
.5161 .69277 L
s
.5151 .68625 m
.51641 .69023 L
s
.5151 .68625 m
.51641 .69023 L
s
.51543 .68856 m
.51627 .69159 L
s
.51543 .68856 m
.51627 .69159 L
s
.5154 .68981 m
.5161 .69277 L
s
.51316 .68036 m .51316 .68036 L .51292 .68504 L 0 0 .074 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51316 .68036 L
s
.51315 .68037 m
.51316 .68036 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.5143 .68916 m
.51513 .69563 L
s
.51316 .68036 m .50556 .69658 L .50991 .6873 L 0 0 .048 r
F
0 g
.51315 .68037 m
.51316 .68037 L
s
.51316 .68036 m .50241 .70368 L .50556 .69658 L 0 0 .048 r
F
.51316 .68036 m .50259 .70385 L .50241 .70368 L F
.51316 .68036 m .50586 .69686 L .50259 .70385 L F
.51316 .68036 m .51004 .68742 L .50586 .69686 L F
.51316 .68036 m .51316 .68036 L .51004 .68742 L F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m .51177 .69266 L .51257 .68562 L 0 0 .074 r
F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m .51152 .69738 L .51177 .69266 L 0 0 .074 r
F
.51316 .68036 m .512 .69661 L .51152 .69738 L F
.51316 .68036 m .5126 .69131 L .512 .69661 L F
.51316 .68036 m .51292 .68504 L .5126 .69131 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.5143 .68916 m
.51513 .69563 L
s
.51332 .69197 m
.51336 .69524 L
s
.51437 .6916 m
.51483 .6959 L
s
.51332 .69197 m
.51336 .69524 L
s
.51437 .6916 m
.51483 .6959 L
s
.51316 .68037 m
.51316 .68038 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68038 L
s
.51353 .69043 m
.51371 .69563 L
s
.51316 .68036 m .51316 .68036 L .51257 .68562 L 0 0 .071 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.5142 .69246 m
.51451 .69599 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51369 .69484 m
.51371 .69563 L
s
.51353 .69043 m
.51369 .69484 L
s
.51363 .69113 m
.51382 .69572 L
s
.51381 .69552 m
.51382 .69572 L
s
.51363 .69113 m
.51381 .69552 L
s
.5142 .69246 m
.51451 .69599 L
s
.51398 .69293 m
.51417 .69593 L
s
.51398 .69293 m
.51417 .69593 L
s
.51316 .68036 m .50586 .69686 L .51004 .68742 L 0 0 .047 r
F
.49682 .71351 m .49175 .72363 L .49493 .71818 L 0 1 .405 r
F
.49682 .71351 m .48865 .72686 L .49175 .72363 L F
.49682 .71351 m .48768 .72573 L .48865 .72686 L F
.49682 .71351 m .48957 .72105 L .48768 .72573 L F
.49682 .71351 m .49307 .71595 L .48957 .72105 L F
.49682 .71351 m .49617 .71271 L .49307 .71595 L F
.50421 .70217 m .49708 .71014 L .49467 .71693 L 0 .699 .296 r
F
.51316 .68036 m .50288 .70405 L .50586 .69686 L 0 0 .047 r
F
.49855 .71533 m .49175 .72363 L .49018 .72848 L 0 1 .405 r
F
.49855 .71533 m .49493 .71818 L .49175 .72363 L F
.49855 .71533 m .49784 .71463 L .49493 .71818 L F
.50421 .70217 m .49467 .71693 L .49524 .71976 L 0 .699 .296 r
F
.51316 .68036 m .5031 .70414 L .50288 .70405 L 0 0 .047 r
F
.51316 .68036 m .50624 .69703 L .5031 .70414 L F
.51316 .68036 m .5102 .68749 L .50624 .69703 L F
.51316 .68036 m .51316 .68036 L .5102 .68749 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68039 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m .51095 .69382 L .51222 .68611 L 0 0 .071 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51035 .69913 L .51095 .69382 L 0 0 .071 r
F
.51316 .68036 m .51081 .69846 L .51035 .69913 L F
.51316 .68036 m .51177 .69266 L .51081 .69846 L F
.51316 .68036 m .51257 .68562 L .51177 .69266 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51222 .68611 L 0 0 .068 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51316 .68036 m .50624 .69703 L .5102 .68749 L 0 0 .048 r
F
.50586 .69915 m .49784 .71463 L .49855 .71533 L 0 1 .389 r
F
.51316 .68036 m .50346 .70423 L .50624 .69703 L 0 0 .048 r
F
.50586 .69915 m .49855 .71533 L .5012 .71092 L 0 1 .389 r
F
.51316 .68036 m .50372 .70426 L .50346 .70423 L 0 0 .048 r
F
.51316 .68036 m .5067 .69707 L .50372 .70426 L F
.51316 .68036 m .5104 .68751 L .5067 .69707 L F
.51316 .68036 m .51316 .68036 L .5104 .68751 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m .51016 .69479 L .51188 .68653 L 0 0 .068 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .5092 .7006 L .51016 .69479 L 0 0 .068 r
F
.51316 .68036 m .50966 .70004 L .5092 .7006 L F
.51316 .68036 m .51095 .69382 L .50966 .70004 L F
.51316 .68036 m .51222 .68611 L .51095 .69382 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51188 .68653 L 0 0 .064 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68037 m
.51315 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68038 m
.51315 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .5067 .69707 L .5104 .68751 L 0 0 .049 r
F
.51316 .68036 m .50414 .70424 L .5067 .69707 L F
.51316 .68036 m .50444 .70418 L .50414 .70424 L F
.51316 .68036 m .50722 .69698 L .50444 .70418 L F
.51316 .68036 m .51062 .68747 L .50722 .69698 L F
.51316 .68036 m .51316 .68036 L .51062 .68747 L F
0 g
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m .5094 .69558 L .51155 .68687 L 0 0 .064 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .5081 .7018 L .5094 .69558 L 0 0 .064 r
F
.51316 .68036 m .50854 .70135 L .5081 .7018 L F
.51316 .68036 m .51016 .69479 L .50854 .70135 L F
.51316 .68036 m .51188 .68653 L .51016 .69479 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68037 L
s
.51315 .68038 m
.51315 .68038 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51155 .68687 L 0 0 .06 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51316 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50722 .69698 L .51062 .68747 L 0 0 .049 r
F
.51316 .68036 m .50474 .70412 L .50722 .69698 L F
.51316 .68036 m .50484 .70409 L .50474 .70412 L F
.51316 .68036 m .5074 .69692 L .50484 .70409 L F
.51316 .68036 m .5107 .68744 L .5074 .69692 L F
.51316 .68036 m .51316 .68036 L .5107 .68744 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50868 .69619 L .51125 .68713 L 0 0 .06 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50706 .70275 L .50868 .69619 L 0 0 .06 r
F
.51316 .68036 m .50747 .7024 L .50706 .70275 L F
0 g
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m .5094 .69558 L .50747 .7024 L 0 0 .06 r
F
.51316 .68036 m .51155 .68687 L .5094 .69558 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .5074 .69692 L .5107 .68744 L 0 0 .053 r
F
.51316 .68036 m .50518 .70394 L .5074 .69692 L F
.51316 .68036 m .50553 .70377 L .50518 .70394 L F
.51316 .68036 m .50801 .69663 L .50553 .70377 L F
.51316 .68036 m .51096 .68732 L .50801 .69663 L F
.51316 .68036 m .51316 .68036 L .51096 .68732 L F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .51316 .68036 L .51125 .68713 L 0 0 .056 r
F
0 g
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m .50801 .69663 L .51096 .68732 L 0 0 .056 r
F
.51316 .68036 m .50608 .70346 L .50801 .69663 L F
.51316 .68036 m .50646 .70321 L .50608 .70346 L F
.51316 .68036 m .50868 .69619 L .50646 .70321 L F
.51316 .68036 m .51125 .68713 L .50868 .69619 L F
0 g
.51308 .6806 m
.51312 .68051 L
s
.51308 .68061 m
.51308 .6806 L
s
.51308 .68061 m
.51308 .68061 L
s
.51096 .68732 m
.51308 .68061 L
s
.51312 .68051 m
.51312 .6805 L
s
.51312 .6805 m
.51312 .6805 L
s
.51312 .6805 m
.51312 .6805 L
s
.51312 .6805 m
.51314 .68044 L
s
.51314 .68044 m
.51314 .68044 L
s
.51314 .68044 m
.51314 .68044 L
s
.51314 .68044 m
.51314 .68042 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51311 .68054 m
.51314 .68044 L
s
.51314 .68044 m
.51314 .68044 L
s
.51314 .68044 m
.51314 .68044 L
s
.51314 .68044 m
.51315 .68042 L
s
.51311 .68054 m
.51311 .68054 L
s
.51311 .68054 m
.51311 .68054 L
s
.51311 .68055 m
.51311 .68054 L
s
.51311 .68055 m
.51311 .68055 L
s
.51125 .68713 m
.51311 .68055 L
s
.51311 .68055 m
.51311 .68055 L
s
.51172 .6845 m
.51309 .68056 L
s
.51154 .68502 m
.51172 .6845 L
s
.5114 .68543 m
.51154 .68502 L
s
.5107 .68744 m
.5114 .68543 L
s
.51309 .68056 m
.51309 .68056 L
s
.51309 .68056 m
.51309 .68056 L
s
.51309 .68056 m
.51313 .68046 L
s
.51315 .68039 m
.51315 .68038 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .68039 m
.51315 .68039 L
s
.51313 .68044 m
.51315 .68041 L
s
.51313 .68044 m
.51313 .68044 L
s
.51313 .68044 m
.51313 .68044 L
s
.51313 .68046 m
.51313 .68044 L
s
.51315 .68041 m
.51315 .68041 L
s
.51315 .68041 m
.51315 .68041 L
s
.51315 .68041 m
.51315 .68039 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51062 .68747 m
.51313 .68044 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51315 .68042 m
.51315 .68042 L
s
.51315 .68042 m
.51315 .68042 L
s
.51315 .68042 m
.51315 .68042 L
s
.51315 .68042 m
.51315 .6804 L
s
.51315 .68042 m
.51315 .68042 L
s
.51315 .68042 m
.51315 .68042 L
s
.51313 .68048 m
.51315 .68042 L
s
.51313 .68048 m
.51313 .68048 L
s
.513 .68103 m
.513 .68103 L
s
.51155 .68687 m
.513 .68103 L
s
.513 .68103 m
.513 .68102 L
s
.513 .68102 m
.51313 .68048 L
s
.51313 .68048 m
.51313 .68048 L
s
.51311 .68051 m
.51314 .68041 L
s
.51311 .68051 m
.51311 .68051 L
s
.51311 .68051 m
.51311 .68051 L
s
.5104 .68751 m
.51311 .68051 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68039 m
.51316 .68039 L
s
.51315 .68042 m
.51315 .68042 L
s
.51314 .68047 m
.51315 .68042 L
s
.51314 .68047 m
.51314 .68047 L
s
.51188 .68653 m
.51314 .68048 L
s
.51314 .68048 m
.51314 .68047 L
s
.51315 .68042 m
.51315 .68041 L
s
.51315 .68041 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68039 L
s
.5102 .68749 m
.51314 .68041 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68039 m
.51316 .68039 L
s
.51315 .68042 m
.51315 .68042 L
s
.51313 .68053 m
.51315 .68042 L
s
.51313 .68053 m
.51313 .68053 L
s
.51222 .68611 m
.51313 .68053 L
s
.51313 .68053 m
.51313 .68053 L
s
.51315 .68042 m
.51315 .68042 L
s
.51315 .68042 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51313 .68044 m
.51315 .68038 L
s
.51313 .68044 m
.51313 .68044 L
s
.51004 .68742 m
.51313 .68044 L
s
.51313 .68044 m
.51313 .68044 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .6804 m
.51316 .6804 L
s
.51315 .68045 m
.51315 .68045 L
s
.51257 .68562 m
.51315 .68045 L
s
.51315 .68045 m
.51315 .68045 L
s
.51315 .68045 m
.51316 .6804 L
s
.51316 .6804 m
.51316 .6804 L
s
.51316 .6804 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68037 L
s
.51315 .68039 m
.51316 .68037 L
s
.51315 .68039 m
.51315 .68039 L
s
.5127 .68136 m
.51315 .68039 L
s
.51269 .68138 m
.5127 .68136 L
s
.50991 .6873 m
.51268 .68139 L
s
.51268 .68139 m
.51269 .68138 L
s
.51315 .68039 m
.51315 .68039 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68042 m
.51316 .68042 L
s
.51292 .68504 m
.51316 .68042 L
s
.51316 .68042 m
.51316 .68042 L
s
.51316 .68042 m
.51316 .68038 L
s
.51315 .68038 m
.51316 .68037 L
s
.51314 .68041 m
.51315 .68038 L
s
.51314 .68041 m
.51314 .68041 L
s
.50981 .68713 m
.51314 .68041 L
s
.51314 .68041 m
.51314 .68041 L
s
.51315 .68038 m
.51315 .68038 L
s
.51314 .6804 m
.51316 .68037 L
s
.50973 .68665 m
.51314 .6804 L
s
.51314 .6804 m
.51314 .6804 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68038 L
s
.51303 .68059 m
.51316 .68037 L
s
.50974 .68635 m
.51303 .68059 L
s
.51303 .68059 m
.51303 .68059 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68037 L
s
.51303 .68059 m
.51316 .68037 L
s
.50974 .68635 m
.51303 .68059 L
s
.51303 .68059 m
.51303 .68059 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68038 m
.51315 .68038 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68038 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68038 m
.51315 .68038 L
s
.51312 .68043 m
.51315 .68038 L
s
.50987 .68563 m
.51312 .68043 L
s
.51315 .68039 m
.51315 .68038 L
s
.50999 .68521 m
.51315 .68039 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51316 .68037 L
s
.51315 .68038 m
.51315 .68037 L
s
.51311 .68041 m
.51312 .6804 L
s
.51312 .6804 m
.51312 .6804 L
s
.51312 .6804 m
.51312 .6804 L
s
.51313 .68039 m
.51314 .68038 L
s
.51313 .68039 m
.51313 .68039 L
s
.51313 .68039 m
.51313 .68039 L
s
.51312 .6804 m
.51313 .68039 L
s
.51314 .68038 m
.51314 .68038 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51314 .68038 m
.51315 .68037 L
s
.5128 .68068 m
.51311 .68041 L
s
.51315 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68038 m
.51315 .68037 L
s
.50987 .68385 m
.51311 .68042 L
s
.51311 .68042 m
.51311 .68041 L
s
.51311 .68041 m
.51311 .68041 L
s
.51313 .68039 m
.51314 .68038 L
s
.51313 .68039 m
.51313 .68039 L
s
.51313 .68039 m
.51313 .68039 L
s
.51311 .68041 m
.51313 .68039 L
s
.51314 .68038 m
.51314 .68038 L
s
.51314 .68038 m
.51315 .68038 L
s
.51312 .68039 m
.51312 .68039 L
s
.51312 .68039 m
.51312 .68039 L
s
.51312 .68039 m
.51312 .68039 L
s
.51314 .68037 m
.51314 .68037 L
s
.51314 .68037 m
.51314 .68037 L
s
.51314 .68037 m
.51314 .68037 L
s
.51312 .68039 m
.51314 .68037 L
s
.51314 .68037 m
.51314 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51314 .68037 m
.51315 .68037 L
s
.50974 .68284 m
.51302 .68046 L
s
.51302 .68046 m
.51302 .68046 L
s
.51302 .68046 m
.51302 .68046 L
s
.51312 .68039 m
.51312 .68039 L
s
.51312 .68039 m
.51312 .68039 L
s
.51302 .68046 m
.51312 .68039 L
s
.51312 .68039 m
.51312 .68039 L
s
.51313 .6804 m
.51314 .68039 L
s
.51313 .6804 m
.51313 .6804 L
s
.51312 .68041 m
.51313 .6804 L
s
.51313 .6804 m
.51313 .6804 L
s
.51314 .68039 m
.51314 .68039 L
s
.51314 .68038 m
.51315 .68037 L
s
.51314 .68038 m
.51314 .68038 L
s
.51314 .68038 m
.51314 .68038 L
s
.51314 .68039 m
.51314 .68038 L
s
.50999 .68432 m
.513 .68056 L
s
.513 .68056 m
.513 .68056 L
s
.513 .68056 m
.51301 .68056 L
s
.51301 .68056 m
.51312 .68041 L
s
.50973 .6823 m
.51301 .68044 L
s
.51301 .68044 m
.51301 .68044 L
s
.51301 .68044 m
.51301 .68044 L
s
.51307 .68041 m
.51307 .68041 L
s
.51301 .68044 m
.51307 .68041 L
s
.51307 .68041 m
.51307 .68041 L
s
.51307 .68041 m
.51312 .68038 L
s
.51312 .68038 m
.51312 .68038 L
s
.51312 .68038 m
.51312 .68038 L
s
.51313 .68038 m
.51314 .68037 L
s
.51313 .68038 m
.51313 .68038 L
s
.51312 .68038 m
.51313 .68038 L
s
.51313 .68038 m
.51313 .68038 L
s
.51314 .68037 m
.51314 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51314 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.5131 .68044 m
.51313 .68041 L
s
.5131 .68044 m
.5131 .68044 L
s
.5131 .68044 m
.5131 .68044 L
s
.51308 .68048 m
.5131 .68044 L
s
.51273 .68099 m
.51308 .68048 L
s
.51313 .68041 m
.51313 .68041 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51314 .68039 m
.51314 .68039 L
s
.51314 .68039 m
.51314 .68039 L
s
.51314 .68039 m
.51314 .68039 L
s
.51314 .68039 m
.51314 .68039 L
s
.51314 .68039 m
.51315 .68038 L
s
.51314 .68039 m
.51314 .68039 L
s
.51314 .68039 m
.51314 .68039 L
s
.51313 .68041 m
.51314 .68039 L
s
.51314 .68039 m
.51314 .68039 L
s
.51309 .68039 m
.51309 .68039 L
s
.51271 .68054 m
.51309 .68039 L
s
.51309 .68039 m
.51309 .68039 L
s
.51309 .68039 m
.5131 .68038 L
s
.5131 .68038 m
.5131 .68038 L
s
.5131 .68038 m
.5131 .68038 L
s
.51313 .68037 m
.51314 .68037 L
s
.51313 .68037 m
.51313 .68037 L
s
.5131 .68038 m
.51313 .68037 L
s
.51313 .68037 m
.51313 .68037 L
s
.51314 .68037 m
.51314 .68037 L
s
.51314 .68037 m
.51315 .68036 L
s
.51308 .68038 m
.51308 .68038 L
s
.50982 .68115 m
.51308 .68038 L
s
.51308 .68038 m
.51308 .68038 L
s
.51308 .68038 m
.51313 .68037 L
s
.51313 .68037 m
.51313 .68037 L
s
.51313 .68037 m
.51313 .68036 L
s
.513 .68037 m
.51301 .68037 L
s
.50991 .68056 m
.513 .68037 L
s
.51301 .68037 m
.51301 .68037 L
s
.51301 .68037 m
.51313 .68036 L
s
.51312 .68042 m
.51312 .68042 L
s
.51312 .68042 m
.51312 .68041 L
s
.51312 .68042 m
.51312 .68042 L
s
.5131 .68044 m
.51312 .68042 L
s
.5131 .68044 m
.5131 .68044 L
s
.51307 .6805 m
.5131 .68044 L
s
.5131 .68044 m
.5131 .68044 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51314 .68039 m
.51315 .68038 L
s
.51314 .68039 m
.51314 .68039 L
s
.51314 .68039 m
.51314 .68039 L
s
.51313 .6804 m
.51314 .68039 L
s
.51313 .6804 m
.51313 .6804 L
s
.51313 .6804 m
.51313 .6804 L
s
.51313 .6804 m
.51313 .6804 L
s
.51314 .68039 m
.51314 .68039 L
s
.51314 .68039 m
.51314 .68039 L
s
.51313 .68041 m
.51313 .68041 L
s
.51313 .68041 m
.51313 .6804 L
s
.51313 .68041 m
.51313 .68041 L
s
.51312 .68041 m
.51313 .68041 L
s
.51313 .68041 m
.51313 .68041 L
s
.51299 .68037 m
.51299 .68037 L
s
.50991 .68056 m
.51299 .68037 L
s
.51299 .68037 m
.51299 .68037 L
s
.51299 .68037 m
.51313 .68036 L
s
.51306 .68051 m
.51306 .68051 L
s
.51305 .68053 m
.51306 .68051 L
s
.51046 .68428 m
.51305 .68053 L
s
.51306 .68051 m
.51306 .68051 L
s
.51306 .68051 m
.51306 .6805 L
s
.51306 .6805 m
.51306 .6805 L
s
.51306 .6805 m
.51307 .6805 L
s
.51307 .68038 m
.51307 .68038 L
s
.50982 .68115 m
.51307 .68038 L
s
.51307 .68038 m
.51307 .68038 L
s
.51307 .68038 m
.51313 .68037 L
s
.51313 .68037 m
.51314 .68037 L
s
.51313 .68037 m
.51313 .68037 L
s
.51312 .68037 m
.51313 .68037 L
s
.51313 .68037 m
.51313 .68037 L
s
.51312 .68037 m
.51312 .68037 L
s
.51312 .68037 m
.51312 .68037 L
s
.51308 .68039 m
.51308 .68039 L
s
.51255 .6806 m
.51308 .68039 L
s
.51308 .68039 m
.51308 .68039 L
s
.51308 .68039 m
.51312 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51314 .68037 m
.51315 .68037 L
s
.51314 .68037 m
.51314 .68037 L
s
.51313 .68038 m
.51314 .68037 L
s
.51314 .68037 m
.51314 .68037 L
s
.51313 .68038 m
.51313 .68038 L
s
.51313 .68038 m
.51313 .68038 L
s
.51312 .68038 m
.51313 .68038 L
s
.51312 .68038 m
.51312 .68038 L
s
.51307 .68041 m
.51312 .68038 L
s
.51312 .68038 m
.51312 .68038 L
s
.51307 .68041 m
.51307 .68041 L
s
.51307 .68041 m
.51307 .68041 L
s
.51304 .68043 m
.51304 .68043 L
s
.50973 .6823 m
.51304 .68043 L
s
.51304 .68043 m
.51304 .68043 L
s
.51304 .68043 m
.51307 .68041 L
s
.5131 .68044 m
.51313 .6804 L
s
.5131 .68044 m
.5131 .68044 L
s
.51299 .68057 m
.5131 .68044 L
s
.5131 .68044 m
.5131 .68044 L
s
.51299 .68057 m
.51299 .68057 L
s
.51299 .68058 m
.51299 .68057 L
s
.50999 .68432 m
.51299 .68058 L
s
.51314 .68039 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68037 L
s
.51314 .68039 m
.51314 .68039 L
s
.51313 .6804 m
.51314 .68039 L
s
.5131 .68041 m
.51312 .68039 L
s
.5131 .68041 m
.5131 .68041 L
s
.51305 .68044 m
.5131 .68041 L
s
.5131 .68041 m
.5131 .68041 L
s
.51305 .68044 m
.51305 .68044 L
s
.51305 .68044 m
.51305 .68044 L
s
.50974 .68284 m
.51305 .68044 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51314 .68038 m
.51315 .68037 L
s
.51314 .68038 m
.51314 .68038 L
s
.51313 .68038 m
.51314 .68038 L
s
.51314 .68038 m
.51314 .68038 L
s
.51313 .68038 m
.51313 .68038 L
s
.51313 .68038 m
.51313 .68038 L
s
.51312 .68039 m
.51313 .68038 L
s
.51314 .68038 m
.51315 .68037 L
s
.51314 .68038 m
.51314 .68038 L
s
.5131 .68042 m
.51314 .68038 L
s
.51314 .68038 m
.51314 .68038 L
s
.51314 .68038 m
.51314 .68038 L
s
.51314 .68038 m
.51314 .68038 L
s
.5131 .68042 m
.5131 .68042 L
s
.5131 .68042 m
.5131 .68042 L
s
.50987 .68385 m
.5131 .68042 L
s
.51315 .68037 m
.51315 .68037 L
s
.51286 .68063 m
.5131 .68041 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51312 .68039 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51312 .68039 m
.51312 .68039 L
s
.51312 .68039 m
.51312 .68039 L
s
.5131 .68041 m
.51312 .6804 L
s
.51312 .6804 m
.51312 .6804 L
s
.51312 .6804 m
.51312 .6804 L
s
.51312 .6804 m
.51312 .68039 L
s
.51315 .68038 m
.51315 .68037 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51314 .68039 m
.51315 .68038 L
s
.51314 .68039 m
.51314 .68039 L
s
.51314 .68039 m
.51314 .68039 L
s
.51311 .68043 m
.51313 .68041 L
s
.51313 .68041 m
.51314 .68039 L
s
.51311 .68043 m
.51311 .68043 L
s
.51305 .68052 m
.51311 .68043 L
s
.5126 .68118 m
.51305 .68052 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51314 .68039 m
.51315 .68038 L
s
.51314 .68039 m
.51314 .68039 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68038 m
.51315 .68037 L
s
.51314 .68039 m
.51314 .68039 L
s
.51314 .68039 m
.51314 .68039 L
s
.50999 .68521 m
.51314 .68039 L
s
.51315 .68038 m
.51316 .68037 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68037 m
.51315 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51312 .68042 m
.51315 .68037 L
s
.50987 .68563 m
.51312 .68042 L
s
.51315 .68038 m
.51315 .68038 L
s
.50979 .68601 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .68039 m
.51316 .68038 L
s
.51316 .68037 m
.51316 .68037 L
s
.50979 .68601 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51314 .6804 m
.51316 .68037 L
s
.50973 .68665 m
.51314 .6804 L
s
.51314 .6804 m
.51314 .6804 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68038 m
.51316 .68037 L
s
.51301 .68064 m
.51315 .68038 L
s
.51301 .68065 m
.51301 .68064 L
s
.50975 .68691 m
.51301 .68065 L
s
.51301 .68065 m
.51301 .68065 L
s
.51315 .68038 m
.51315 .68038 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51315 .68038 m
.51316 .68037 L
s
.51302 .68063 m
.51315 .68038 L
s
.51302 .68063 m
.51302 .68063 L
s
.50975 .68691 m
.51302 .68064 L
s
.51302 .68064 m
.51302 .68063 L
s
.51315 .68038 m
.51315 .68038 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51315 .68038 m
.51316 .68037 L
s
.51314 .68041 m
.51315 .68038 L
s
.51314 .68041 m
.51314 .68041 L
s
.50981 .68713 m
.51314 .68041 L
s
.51314 .68041 m
.51314 .68041 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68037 m
.51315 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51315 .68037 m
.51315 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68037 m
.51315 .68036 L
s
.51314 .68037 m
.51314 .68037 L
s
.51314 .68037 m
.51315 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68036 L
s
.51313 .68037 m
.51314 .68036 L
s
.51313 .68037 m
.51313 .68037 L
s
.51313 .68037 m
.51313 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68037 L
s
.51315 .68037 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51313 .68036 m
.51315 .68036 L
s
.51313 .68036 m
.51313 .68036 L
s
.51313 .68036 m
.51313 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51315 .68036 m
.51315 .68036 L
s
.51314 .68036 m
.51315 .68036 L
s
.51314 .68036 m
.51314 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68039 m
.51316 .68037 L
s
.51315 .68039 m
.51315 .68039 L
s
.51267 .6814 m
.51315 .68039 L
s
.51266 .68143 m
.51267 .6814 L
s
.50991 .6873 m
.51265 .68144 L
s
.51265 .68144 m
.51266 .68143 L
s
.51315 .68039 m
.51315 .68039 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68042 m
.51316 .68042 L
s
.51292 .68504 m
.51316 .68042 L
s
.51316 .68042 m
.51316 .68041 L
s
.51316 .68041 m
.51316 .68038 L
s
.51235 .68154 m
.5126 .68118 L
s
.5127 .68054 m
.51271 .68054 L
s
.50976 .68173 m
.51269 .68055 L
s
.51269 .68055 m
.5127 .68054 L
s
.50979 .68336 m
.51285 .68064 L
s
.51285 .68064 m
.51285 .68064 L
s
.51285 .68064 m
.51286 .68063 L
s
.51217 .68181 m
.51273 .68099 L
s
.5128 .68068 m
.5128 .68068 L
s
.51279 .68069 m
.5128 .68068 L
s
.50979 .68336 m
.51279 .68069 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51312 .68045 m
.51315 .68038 L
s
.51312 .68045 m
.51312 .68045 L
s
.51004 .68742 m
.51312 .68045 L
s
.51312 .68045 m
.51312 .68045 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .6804 m
.51316 .6804 L
s
.51315 .68044 m
.51315 .68044 L
s
.51257 .68562 m
.51315 .68044 L
s
.51315 .68044 m
.51315 .68044 L
s
.51315 .68044 m
.51316 .6804 L
s
.51316 .6804 m
.51316 .6804 L
s
.51316 .6804 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68037 L
s
.51089 .68366 m
.51235 .68154 L
s
.51254 .68061 m
.51255 .6806 L
s
.50976 .68173 m
.51253 .68061 L
s
.51253 .68061 m
.51254 .68061 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51316 .68037 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68039 m
.51315 .68038 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.5102 .68749 m
.51314 .68041 L
s
.51314 .68041 m
.51314 .68041 L
s
.51314 .68041 m
.51314 .68041 L
s
.51314 .68041 m
.51315 .68039 L
s
.51316 .68039 m
.51316 .68039 L
s
.51315 .68041 m
.51315 .68041 L
s
.51314 .68051 m
.51315 .68041 L
s
.51314 .68051 m
.51314 .68051 L
s
.51222 .68611 m
.51314 .68051 L
s
.51314 .68051 m
.51314 .68051 L
s
.51315 .68041 m
.51315 .68041 L
s
.51315 .68041 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68039 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68039 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51117 .68325 m
.51203 .68201 L
s
.51203 .68201 m
.51217 .68181 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51315 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51315 .68039 m
.51315 .68038 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .6804 m
.51315 .68039 L
s
.5104 .68751 m
.5131 .68052 L
s
.5131 .68052 m
.5131 .68052 L
s
.5131 .68052 m
.5131 .68052 L
s
.5131 .68052 m
.51315 .6804 L
s
.51315 .6804 m
.51315 .6804 L
s
.51315 .6804 m
.51315 .6804 L
s
.51315 .6804 m
.51315 .6804 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51314 .68046 m
.51315 .68041 L
s
.51314 .68046 m
.51314 .68046 L
s
.51188 .68653 m
.51314 .68046 L
s
.51314 .68046 m
.51314 .68046 L
s
.51315 .68041 m
.51315 .68041 L
s
.51315 .68041 m
.51315 .68041 L
s
.51316 .68039 m
.51316 .68039 L
s
.51315 .68041 m
.51315 .68041 L
s
.51315 .68041 m
.51315 .68041 L
s
.51315 .68041 m
.51315 .68041 L
s
.51315 .68041 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68039 L
s
.51316 .68039 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51315 .68038 m
.51316 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68038 m
.51315 .68038 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .68039 m
.51315 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51314 .68041 m
.51315 .68039 L
s
.51314 .68041 m
.51314 .68041 L
s
.51314 .68041 m
.51314 .68041 L
s
.51062 .68747 m
.51313 .68045 L
s
.51313 .68045 m
.51313 .68045 L
s
.51313 .68045 m
.51313 .68045 L
s
.51313 .68045 m
.51314 .68041 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51304 .68085 m
.51304 .68084 L
s
.51155 .68687 m
.51304 .68085 L
s
.51304 .68084 m
.51304 .68084 L
s
.51304 .68084 m
.51314 .68046 L
s
.51314 .68046 m
.51314 .68046 L
s
.51314 .68046 m
.51314 .68046 L
s
.51315 .68041 m
.51315 .68041 L
s
.51314 .68046 m
.51315 .68041 L
s
.51314 .68046 m
.51314 .68046 L
s
.51314 .68046 m
.51314 .68046 L
s
.51314 .68046 m
.51314 .68046 L
s
.51315 .68041 m
.51315 .68041 L
s
.51315 .68041 m
.51315 .6804 L
s
.51315 .6804 m
.51315 .6804 L
s
.51315 .6804 m
.51315 .6804 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51315 .68039 m
.51316 .68038 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .6804 m
.51315 .68039 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51312 .68047 m
.51314 .68043 L
s
.51306 .68064 m
.51312 .68047 L
s
.51306 .68065 m
.51306 .68064 L
s
.51306 .68065 m
.51306 .68065 L
s
.5107 .68744 m
.51147 .68522 L
s
.51147 .68522 m
.51162 .68481 L
s
.51162 .68481 m
.5118 .68427 L
s
.5118 .68427 m
.51306 .68065 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .68039 m
.51316 .68038 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .68039 m
.51315 .68039 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51313 .68045 m
.51314 .68043 L
s
.51313 .68045 m
.51313 .68045 L
s
.51313 .68045 m
.51313 .68045 L
s
.51312 .6805 m
.51313 .68045 L
s
.51314 .68043 m
.51314 .68043 L
s
.51314 .68043 m
.51314 .68043 L
s
.51314 .68042 m
.51315 .68039 L
s
.51314 .68042 m
.51314 .68042 L
s
.51314 .68042 m
.51314 .68042 L
s
.51314 .68043 m
.51314 .68042 L
s
.51096 .68732 m
.51306 .68068 L
s
.51306 .68068 m
.51306 .68068 L
s
.51306 .68068 m
.51306 .68067 L
s
.51306 .68067 m
.51312 .6805 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68036 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68036 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51125 .68713 m
.51308 .68064 L
s
.51308 .68064 m
.51308 .68064 L
s
.51308 .68064 m
.51308 .68064 L
s
.51312 .68049 m
.51314 .68043 L
s
.51312 .68049 m
.51312 .68049 L
s
.51312 .68049 m
.51312 .68049 L
s
.51308 .68064 m
.51312 .68049 L
s
.51314 .68043 m
.51314 .68043 L
s
.51314 .68043 m
.51314 .68043 L
s
.51315 .6804 m
.51315 .68039 L
s
.51315 .6804 m
.51315 .6804 L
s
.51315 .6804 m
.51315 .6804 L
s
.51315 .68042 m
.51315 .6804 L
s
.51315 .68042 m
.51315 .68042 L
s
.51315 .68042 m
.51315 .68042 L
s
.51314 .68043 m
.51315 .68042 L
s
.51315 .68039 m
.51315 .68039 L
s
.51315 .68039 m
.51315 .68039 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51315 .68039 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68038 m
.51316 .68038 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68037 m
.51316 .68037 L
s
.51316 .68038 m
.51316 .68037 L
s
.51104 .68344 m
.51104 .68344 L
s
.51014 .68475 m
.51104 .68344 L
s
.51104 .68344 m
.51117 .68325 L
s
.51037 .68441 m
.51078 .68382 L
s
.51078 .68382 m
.51089 .68366 L
s
.51266 .69411 m
.51267 .69383 L
s
.51266 .69411 m
.51267 .69383 L
s
.51033 .68447 m
.51037 .68441 L
s
.51014 .68475 m
.51025 .6846 L
s
.51025 .6846 m
.51027 .68456 L
s
.51014 .68475 m
.51033 .68447 L
s
.51041 .68436 m
.51046 .68428 L
s
.51027 .68456 m
.51041 .68436 L
s
.50708 .73817 m .50569 .73779 L .5038 .74219 L 0 1 .408 r
F
.53102 .65629 m .53671 .65406 L .53321 .65687 L 0 .029 .101 r
F
.53102 .65629 m .53995 .64617 L .53671 .65406 L F
.43241 .57476 m .43512 .56729 L .43457 .56215 L 0 1 .355 r
F
0 g
.43512 .56729 m
.43656 .56548 L
s
.51943 .73865 m .52094 .75661 L .52152 .75659 L 0 1 .392 r
F
.51943 .73865 m .51995 .75127 L .52094 .75661 L F
0 g
.52094 .75661 m
.52105 .76161 L
s
.52757 .71036 m .53338 .72237 L .53038 .71501 L 0 1 .358 r
F
0 g
.52933 .70712 m
.53 .70807 L
s
.53054 .70568 m
.53116 .70765 L
s
.52757 .71036 m .53479 .72892 L .53338 .72237 L 0 1 .358 r
F
.52757 .71036 m .53366 .73027 L .53479 .72892 L F
.52757 .71036 m .53085 .72562 L .53366 .73027 L F
0 g
.53116 .70765 m
.53235 .7114 L
s
.52757 .71036 m .52822 .71807 L .53085 .72562 L 0 1 .358 r
F
0 g
.52865 .70847 m
.52881 .70909 L
s
.53 .70807 m
.53235 .7114 L
s
.52757 .71036 m .52682 .71153 L .52822 .71807 L 0 1 .358 r
F
0 g
.52682 .70782 m
.52757 .71036 L
s
.52429 .70721 m
.52682 .71153 L
s
.36231 .94475 m .36044 .94927 L .36415 .94726 L 0 1 .49 r
F
.36231 .94475 m .35273 .94955 L .36044 .94927 L F
0 g
.36044 .94927 m
.36306 .95166 L
s
.51153 .66128 m .50978 .65015 L .51058 .65674 L 0 1 .361 r
F
.51153 .66128 m .5099 .64421 L .50978 .65015 L F
.51153 .66128 m .51084 .64289 L .5099 .64421 L F
0 g
.51177 .66728 m
.51177 .66728 L
s
.51153 .66128 m
.51177 .66728 L
s
.37056 .74452 m .36071 .73386 L .35883 .74038 L 0 1 .427 r
F
.37056 .74452 m .36484 .73265 L .36071 .73386 L F
.37056 .74452 m .36906 .73723 L .36484 .73265 L F
0 g
.36868 .75104 m
.37056 .74452 L
s
.38114 .74087 m .36906 .73723 L .37057 .74452 L 0 1 .419 r
F
0 g
.37057 .74452 m
.37484 .74885 L
s
.45785 .4921 m .46495 .47799 L .46324 .47998 L 0 .917 .145 r
F
0 g
.46495 .47799 m
.46998 .46941 L
s
.46265 .48318 m
.46495 .47799 L
s
.25769 .96369 m .24129 .95967 L .24854 .9665 L 0 1 .536 r
F
0 g
.24854 .9665 m
.25664 .97072 L
s
.52084 .67763 m
.52401 .67441 L
s
.51558 .69405 m
.51558 .69405 L
s
.50446 .68539 m
.50485 .685 L
s
.51943 .73865 m .52152 .75659 L .52129 .75118 L 0 1 .392 r
F
0 g
.5191 .75657 m
.51995 .75127 L
s
.52152 .75659 m
.52261 .76161 L
s
.45592 .49771 m
.45785 .4921 L
s
.48885 .91923 m .48695 .92619 L .49188 .92877 L 0 .589 .405 r
F
.48005 .69607 m .46857 .69732 L .469 .70199 L 0 .887 .32 r
F
0 g
.46857 .69732 m
.47161 .6924 L
s
.46487 .69529 m
.46857 .69732 L
s
.51761 .73888 m .51621 .73901 L .51536 .74431 L 0 1 .397 r
F
0 g
.51536 .74431 m
.51621 .73901 L
s
.5141 .73907 m
.51536 .74431 L
s
.43267 .79083 m .43011 .78475 L .42537 .78209 L 0 .958 .392 r
F
0 g
.52258 .70938 m
.52287 .7111 L
s
.51761 .73888 m .51995 .75127 L .51922 .74414 L 0 1 .397 r
F
0 g
.51995 .75127 m
.51995 .75127 L
s
.51943 .73865 m .51922 .74414 L .51995 .75127 L 0 1 .392 r
F
0 g
.51995 .75127 m
.52094 .75661 L
s
.41344 .93493 m .39823 .9382 L .40124 .93944 L 0 1 .455 r
F
0 g
.39445 .94072 m
.40124 .93944 L
s
.38534 .76856 m .37978 .77439 L .38381 .77272 L 0 1 .505 r
F
.38534 .76856 m .37513 .77255 L .37978 .77439 L F
0 g
.3788 .77865 m
.37978 .77439 L
s
.38381 .77272 m
.38872 .7743 L
s
.78279 .67641 m .7904 .69198 L .79402 .68812 L 0 1 .497 r
F
0 g
.7904 .69198 m
.79275 .69936 L
s
.30504 .74168 m .29661 .7503 L .30202 .74904 L 0 1 .462 r
F
.30504 .74168 m .29144 .74462 L .29661 .7503 L F
0 g
.29438 .75777 m
.29661 .7503 L
s
.30202 .74904 m
.30775 .75443 L
s
.22514 .75778 m .21361 .74109 L .2119 .74942 L 0 1 .488 r
F
.22514 .75778 m .2181 .74042 L .21361 .74109 L F
.22514 .75778 m .22304 .74759 L .2181 .74042 L F
.23618 .75569 m .22304 .74759 L .22514 .75778 L 0 1 .485 r
F
0 g
.22342 .76606 m
.22514 .75778 L
s
.22514 .75778 m
.23 .76472 L
s
.52565 .71313 m .53085 .72562 L .52822 .71807 L 0 1 .364 r
F
0 g
.52757 .71036 m
.52798 .71105 L
s
.52881 .70909 m
.52919 .71051 L
s
.52565 .71313 m .5319 .73211 L .53085 .72562 L 0 1 .364 r
F
.52565 .71313 m .53069 .73319 L .5319 .73211 L F
.52565 .71313 m .52812 .72826 L .53069 .73319 L F
0 g
.52919 .71051 m
.53038 .71501 L
s
.52565 .71313 m .5259 .72059 L .52812 .72826 L 0 1 .364 r
F
0 g
.52682 .71153 m
.52692 .71201 L
s
.52798 .71105 m
.53038 .71501 L
s
.52565 .71313 m .52484 .71411 L .5259 .72059 L 0 1 .364 r
F
0 g
.52523 .71128 m
.52565 .71313 L
s
.52258 .70938 m
.52484 .71411 L
s
.41704 .74432 m .41074 .75273 L .41495 .75065 L 0 1 .391 r
F
.41704 .74432 m .40639 .74935 L .41074 .75273 L F
.4213 .76006 m .41495 .75065 L .41074 .75273 L F
0 g
.40911 .75916 m
.41074 .75273 L
s
.42653 .77556 m .42433 .76939 L .41967 .76649 L 0 1 .392 r
F
0 g
.41967 .76649 m
.41975 .76654 L
s
.41967 .76649 m
.41983 .76651 L
s
.41967 .76649 m
.41973 .76647 L
s
.31998 .94052 m .30209 .94292 L .30457 .94399 L 0 1 .289 r
F
.31998 .94052 m .30571 .94167 L .30209 .94292 L F
.31998 .94052 m .31339 .94064 L .30571 .94167 L F
.32853 .93689 m .31339 .94064 L .31998 .94052 L 0 .936 .253 r
F
0 g
.31998 .94052 m
.32741 .93927 L
s
.31998 .94052 m
.32242 .94159 L
s
.40639 .74935 m .40032 .73913 L .39594 .74088 L 0 1 .401 r
F
.40639 .74935 m .40479 .74276 L .40032 .73913 L F
.41704 .74432 m .40479 .74276 L .40639 .74935 L 0 1 .391 r
F
0 g
.40639 .74935 m
.41074 .75273 L
s
.40443 .75577 m
.40639 .74935 L
s
.50364 .73712 m .50229 .73659 L .5001 .74069 L 0 1 .411 r
F
.45542 .74324 m .44573 .7498 L .44405 .75145 L 0 .886 .191 r
F
.45542 .74324 m .44975 .74692 L .44573 .7498 L F
.45542 .74324 m .4539 .74411 L .44975 .74692 L F
.46502 .7351 m .4539 .74411 L .45542 .74324 L 0 0 0 r
F
0 g
.45373 .74489 m
.45542 .74324 L
s
.45542 .74324 m
.45938 .74011 L
s
.49892 .68803 m
.50173 .68755 L
s
.51451 .69598 m
.51451 .69598 L
s
.54459 .70391 m
.54482 .70456 L
s
.54482 .70456 m
.54551 .70654 L
s
.43333 .68867 m .43323 .68256 L .42971 .67892 L 0 1 .366 r
F
0 g
.43323 .68256 m
.43433 .68077 L
s
.34447 .97201 m .34434 .97809 L .34734 .97659 L 0 1 .537 r
F
.34447 .97201 m .3367 .97562 L .34434 .97809 L F
0 g
.34434 .97809 m
.34798 .98246 L
s
.51806 .98504 m .51067 .98657 L .505 .98913 L 0 1 .524 r
F
.74832 .93911 m .76016 .9388 L .75641 .93745 L 0 1 .535 r
F
.73915 .93542 m .74832 .93911 L .75079 .93539 L 0 1 .533 r
F
0 g
.52091 .71255 m
.52117 .71495 L
s
.52266 .71602 m
.52274 .71624 L
s
.5249 .71447 m
.52497 .71487 L
s
.52484 .71411 m
.5249 .71447 L
s
.42761 .62675 m .41889 .63298 L .42327 .63234 L 0 1 .368 r
F
.42761 .62675 m .41678 .62826 L .41889 .63298 L F
0 g
.42736 .63475 m
.42983 .63146 L
s
.42761 .62675 m .41835 .62132 L .41678 .62826 L 0 1 .368 r
F
.42761 .62675 m .4227 .61574 L .41835 .62132 L F
.42761 .62675 m .42691 .61523 L .4227 .61574 L F
0 g
.42691 .61523 m
.42901 .61995 L
s
.42761 .62675 m
.42983 .63146 L
s
.42691 .61523 m
.43139 .60963 L
s
.41913 .93056 m .41969 .93342 L .42186 .93161 L 0 1 .425 r
F
.41913 .93056 m .41344 .93493 L .41969 .93342 L F
0 g
.41969 .93342 m
.42296 .93422 L
s
.51943 .73865 m .52129 .75118 L .52041 .74398 L 0 1 .392 r
F
0 g
.52129 .75118 m
.52152 .75659 L
s
.52218 .7379 m .52129 .75118 L .52334 .75641 L 0 1 .39 r
F
.52218 .7379 m .52041 .74398 L .52129 .75118 L F
0 g
.52129 .75118 m
.5218 .75247 L
s
.69145 .67185 m
.69188 .67415 L
s
.47596 .90542 m
.47596 .90544 L
s
.48885 .91923 m .48335 .91308 L .47842 .91052 L 0 .589 .405 r
F
0 g
.47596 .90544 m
.47842 .91052 L
s
.51144 .72074 m .51057 .73883 L .51178 .73352 L 0 1 .393 r
F
0 g
.51057 .73883 m
.51178 .73352 L
s
.51057 .73883 m
.51147 .74403 L
s
.50761 .74332 m
.50917 .73861 L
s
.48773 .74525 m .48618 .74404 L .48292 .74661 L 0 1 .43 r
F
0 g
.48292 .74661 m
.48319 .74545 L
s
.48319 .74545 m
.48334 .74481 L
s
.51036 .66273 m .51083 .66213 L .51058 .65674 L 0 1 .364 r
F
0 g
.51083 .66213 m
.51177 .66728 L
s
.49408 .73188 m .48773 .74525 L .4907 .74208 L 0 1 .417 r
F
.49408 .73188 m .48618 .74404 L .48773 .74525 L F
0 g
.48707 .74984 m
.48773 .74525 L
s
.45796 .70777 m .45363 .70017 L .44913 .70211 L 0 .984 .344 r
F
.45796 .70777 m .45741 .7026 L .45363 .70017 L F
0 g
.45363 .70017 m
.45677 .69476 L
s
.67712 .94717 m
.67779 .94693 L
s
.67509 .94788 m
.67712 .94717 L
s
.51178 .73352 m
.51269 .73903 L
s
.51147 .74403 m
.51269 .73903 L
s
.5236 .71544 m .52812 .72826 L .5259 .72059 L 0 1 .369 r
F
0 g
.52565 .71313 m
.52588 .71357 L
s
.52692 .71201 m
.52712 .71292 L
s
.5236 .71544 m .52882 .73464 L .52812 .72826 L 0 1 .369 r
F
.5236 .71544 m .52754 .73547 L .52882 .73464 L F
.5236 .71544 m .52523 .73032 L .52754 .73547 L F
0 g
.52712 .71292 m
.52822 .71807 L
s
.52588 .71357 m
.52822 .71807 L
s
.52497 .71487 m
.5259 .72059 L
s
.52376 .71581 m
.5259 .72059 L
s
.22049 .81263 m .20636 .80423 L .20595 .80898 L 0 1 .539 r
F
.22049 .81263 m .21075 .80362 L .20636 .80423 L F
.22049 .81263 m .21681 .80723 L .21075 .80362 L F
.2312 .81057 m .21681 .80723 L .22049 .81263 L 0 1 .537 r
F
0 g
.22005 .81734 m
.22049 .81263 L
s
.22049 .81263 m
.22641 .81597 L
s
.52218 .7379 m .52334 .75641 L .52518 .7562 L 0 1 .39 r
F
0 g
.52261 .76161 m
.52334 .75641 L
s
.5218 .75247 m
.52334 .75641 L
s
.51371 .6955 m
.51371 .6955 L
s
.5139 .69758 m
.5139 .69758 L
s
.44196 .9869 m .42617 .98641 L .43054 .98932 L 0 1 .541 r
F
0 g
.42348 .98904 m
.43054 .98932 L
s
.61455 .55559 m
.61527 .55889 L
s
.5091 .72058 m .50708 .73817 L .50862 .73312 L 0 1 .396 r
F
.5091 .72058 m .50569 .73779 L .50708 .73817 L F
0 g
.50708 .73817 m
.50761 .74332 L
s
.44548 .6993 m .43683 .69208 L .43374 .69775 L 0 1 .355 r
F
0 g
.5141 .73907 m
.51496 .73352 L
s
.51943 .73865 m .51899 .73873 L .51922 .74414 L 0 1 .392 r
F
0 g
.51761 .73888 m
.51921 .74413 L
s
.51921 .74413 m
.51922 .74414 L
s
.52274 .71624 m
.52277 .71651 L
s
.5232 .72041 m
.52344 .72262 L
s
.50248 .68925 m .49454 .6906 L .49148 .69479 L 0 .756 .296 r
F
0 g
.49109 .6902 m
.49454 .6906 L
s
.48005 .69607 m .47262 .70356 L .477 .70099 L 0 .887 .32 r
F
.48005 .69607 m .469 .70199 L .47262 .70356 L F
0 g
.54584 .80403 m
.54587 .80407 L
s
.44548 .6993 m .43788 .70686 L .44238 .70497 L 0 1 .355 r
F
.44548 .6993 m .43418 .70376 L .43788 .70686 L F
.44548 .6993 m .43374 .69775 L .43418 .70376 L F
.5091 .72058 m .5055 .73235 L .50569 .73779 L 0 1 .396 r
F
0 g
.5038 .74219 m
.50569 .73779 L
s
.50878 .73477 m
.50917 .73861 L
s
.74986 .74648 m
.75025 .74668 L
s
.43965 .80588 m .43676 .79989 L .43199 .79745 L 0 .91 .392 r
F
.52518 .7562 m .52891 .76818 L .52757 .76125 L 0 1 .401 r
F
.5297 .75526 m .52891 .76818 L .5316 .77322 L 0 .998 .396 r
F
0 g
.53092 .77823 m
.5316 .77322 L
s
.5297 .75526 m .52757 .76125 L .52891 .76818 L 0 .998 .396 r
F
0 g
.52819 .77338 m
.52891 .76818 L
s
.52891 .76818 m
.5316 .77322 L
s
.51565 .73655 m
.51621 .73901 L
s
.51496 .73352 m
.51565 .73655 L
s
.52192 .7186 m
.52344 .72262 L
s
.41111 .76804 m .40008 .76562 L .39866 .76974 L 0 1 .493 r
F
.41111 .76804 m .40429 .76369 L .40008 .76562 L F
.41111 .76804 m .40902 .76472 L .40429 .76369 L F
.42127 .76245 m .40902 .76472 L .41111 .76804 L 0 1 .487 r
F
0 g
.41111 .76804 m
.41442 .76859 L
s
.41016 .77078 m
.41111 .76804 L
s
.51406 .70526 m
.51406 .70526 L
s
.51412 .70274 m
.51412 .70274 L
s
.5099 .64421 m .51084 .64289 L .51131 .63723 L 0 1 .354 r
F
0 g
.51084 .64289 m
.51179 .64744 L
s
.52218 .7379 m .52079 .73829 L .52041 .74398 L 0 1 .39 r
F
0 g
.52041 .74398 m
.52079 .73829 L
s
.36538 .77621 m .35427 .77077 L .35314 .77514 L 0 1 .511 r
F
.36538 .77621 m .35828 .76953 L .35427 .77077 L F
.36538 .77621 m .36305 .77186 L .35828 .76953 L F
.37513 .77255 m .36305 .77186 L .36538 .77621 L 0 1 .509 r
F
0 g
.36423 .78056 m
.36538 .77621 L
s
.36538 .77621 m
.37001 .77831 L
s
.51096 .66833 m
.51096 .66833 L
s
.80246 .78944 m .8049 .79805 L .81058 .7983 L 0 .547 .374 r
F
0 g
.8049 .79805 m
.80496 .80274 L
s
.52076 .72208 m
.52087 .72417 L
s
.33709 .9333 m .33573 .93543 L .33907 .9339 L 0 .853 .242 r
F
0 g
.33907 .9339 m
.34657 .9319 L
s
.33709 .9333 m .32853 .93689 L .33573 .93543 L 0 .853 .242 r
F
0 g
.33573 .93543 m
.33848 .93594 L
s
.51799 .71813 m
.51823 .71912 L
s
.43333 .68867 m .42541 .69591 L .42998 .69439 L 0 1 .366 r
F
.43333 .68867 m .42189 .69227 L .42541 .69591 L F
.43333 .68867 m .42176 .6859 L .42189 .69227 L F
.43333 .68867 m .42512 .68018 L .42176 .6859 L F
.43333 .68867 m .42971 .67892 L .42512 .68018 L F
0 g
.42971 .67892 m
.43323 .68256 L
s
.43333 .68867 m
.43683 .69208 L
s
.42971 .67892 m
.43333 .67333 L
s
.45961 .85841 m .45551 .85246 L .45065 .85026 L 0 .773 .4 r
F
0 g
.53957 .70847 m
.54034 .71054 L
s
.49408 .73188 m .4907 .74208 L .49313 .73664 L 0 1 .417 r
F
.49711 .73395 m .49313 .73664 L .4907 .74208 L 0 1 .416 r
F
0 g
.49012 .74696 m
.4907 .74208 L
s
.48773 .74525 m
.4907 .74208 L
s
.69074 1.07469 m .68754 1.07676 L .69746 1.07593 L 0 .775 .287 r
F
0 g
.6783 1.07683 m
.68754 1.07676 L
s
.68231 1.07786 m
.68754 1.07676 L
s
.50265 .69452 m
.50265 .69452 L
s
.50265 .69452 m
.50265 .69452 L
s
.50265 .69452 m
.50284 .69426 L
s
.50681 .7201 m .50364 .73712 L .5055 .73235 L 0 1 .399 r
F
.50681 .7201 m .50229 .73659 L .50364 .73712 L F
0 g
.50364 .73712 m
.5038 .74219 L
s
.77292 .90556 m .78443 .89969 L .7805 .89962 L 0 1 .52 r
F
.76327 .90549 m .77292 .90556 L .7746 .8996 L 0 1 .517 r
F
.51036 .66273 m .50781 .65305 L .50907 .65884 L 0 1 .364 r
F
.51036 .66273 m .50756 .64765 L .50781 .65305 L F
.51036 .66273 m .50849 .64626 L .50756 .64765 L F
.51036 .66273 m .50978 .65015 L .50849 .64626 L F
.51036 .66273 m .51058 .65674 L .50978 .65015 L F
0 g
.5103 .66255 m
.51036 .66273 L
s
.51036 .66273 m
.51096 .66833 L
s
.51058 .65674 m
.51153 .66128 L
s
.51058 .65674 m
.51083 .66213 L
s
.5091 .72058 m .50862 .73312 L .50929 .72602 L 0 1 .396 r
F
0 g
.50862 .73312 m
.50878 .73477 L
s
.50708 .73817 m
.50862 .73312 L
s
.52041 .72269 m
.52087 .72417 L
s
.45585 .83538 m .44572 .83745 L .44956 .84347 L 0 .803 .39 r
F
.45585 .83538 m .44492 .83061 L .44572 .83745 L F
0 g
.44076 .83511 m
.44572 .83745 L
s
.38114 .74087 m .37117 .73076 L .36906 .73723 L 0 1 .419 r
F
.38114 .74087 m .37549 .72943 L .37117 .73076 L F
.38114 .74087 m .37976 .73377 L .37549 .72943 L F
.39172 .73703 m .37976 .73377 L .38114 .74087 L 0 1 .41 r
F
0 g
.37903 .74733 m
.38114 .74087 L
s
.38114 .74087 m
.38532 .74499 L
s
.50031 .73571 m .49901 .73504 L .49652 .73884 L 0 1 .413 r
F
0 g
.49652 .73884 m
.49698 .73814 L
s
.49698 .73814 m
.49734 .73759 L
s
.45796 .70777 m .44913 .70211 L .44625 .70775 L 0 .984 .344 r
F
0 g
.44548 .6993 m
.44913 .70211 L
s
.51734 .71964 m .51899 .73873 L .51943 .73865 L 0 1 .381 r
F
0 g
.51812 .7331 m
.51899 .73873 L
s
.51824 .72053 m
.51825 .71927 L
s
.51761 .73888 m
.51812 .7331 L
s
.51899 .73873 m
.51922 .74414 L
s
.50199 .94193 m .50122 .94821 L .50621 .95113 L 0 .497 .397 r
F
.40275 .73281 m .39594 .74088 L .40032 .73913 L 0 1 .401 r
F
.40275 .73281 m .39172 .73703 L .39594 .74088 L F
0 g
.39399 .7473 m
.39594 .74088 L
s
.51734 .71964 m .51943 .73865 L .5191 .73288 L 0 1 .381 r
F
0 g
.5191 .73288 m
.51943 .73865 L
s
.51943 .73865 m
.52041 .74398 L
s
.46843 .74498 m .46341 .75284 L .46689 .74914 L 0 1 .447 r
F
.46843 .74498 m .45951 .75402 L .46341 .75284 L F
.47234 .7494 m .46689 .74914 L .46341 .75284 L 0 1 .445 r
F
0 g
.46238 .75315 m
.46341 .75284 L
s
.46226 .75711 m
.46341 .75284 L
s
.26687 .9609 m .2656 .96777 L .26919 .96659 L 0 1 .536 r
F
0 g
.26919 .96659 m
.2712 .96745 L
s
.26687 .9609 m .25769 .96369 L .2656 .96777 L 0 1 .536 r
F
0 g
.2656 .96777 m
.26888 .97329 L
s
.31957 .77631 m .31423 .78224 L .31822 .78116 L 0 1 .521 r
F
.31957 .77631 m .30947 .77883 L .31423 .78224 L F
0 g
.31361 .78718 m
.31423 .78224 L
s
.31822 .78116 m
.32348 .7843 L
s
.51734 .71964 m .5191 .73288 L .51822 .72527 L 0 1 .381 r
F
0 g
.51734 .71964 m
.51789 .72321 L
s
.51721 .71789 m
.51734 .71964 L
s
.5191 .73288 m
.5191 .73288 L
s
.51665 .72232 m
.51709 .72422 L
s
.5099 .64421 m .51131 .63723 L .51098 .63101 L 0 1 .354 r
F
0 g
.51131 .63723 m
.51226 .64098 L
s
.51084 .64289 m
.51131 .63723 L
s
.50681 .7201 m .50247 .73123 L .50229 .73659 L 0 1 .399 r
F
0 g
.5001 .74069 m
.50229 .73659 L
s
.50555 .73363 m
.50569 .73779 L
s
.5191 .73288 m
.52079 .73829 L
s
.52218 .7379 m .52518 .7562 L .52556 .75051 L 0 1 .39 r
F
.23618 .75569 m .22483 .73942 L .22304 .74759 L 0 1 .485 r
F
.23618 .75569 m .22932 .73874 L .22483 .73942 L F
.23618 .75569 m .23419 .74573 L .22932 .73874 L F
.24722 .75357 m .23419 .74573 L .23618 .75569 L 0 1 .482 r
F
0 g
.23438 .76382 m
.23618 .75569 L
s
.23618 .75569 m
.24096 .76246 L
s
.51379 .72056 m
.51384 .72086 L
s
.51458 .72537 m
.51469 .72607 L
s
.51469 .72607 m
.51482 .72461 L
s
.51495 .72308 m
.51506 .7218 L
s
.469 .70199 m .45741 .7026 L .45796 .70777 L 0 .937 .332 r
F
0 g
.45741 .7026 m
.46037 .69725 L
s
.45363 .70017 m
.45741 .7026 L
s
.49408 .73188 m .48713 .73928 L .48618 .74404 L 0 1 .417 r
F
0 g
.48292 .74661 m
.48618 .74404 L
s
.4213 .76006 m .41948 .75379 L .41495 .75065 L 0 1 .391 r
F
.41704 .74432 m .40688 .73643 L .40479 .74276 L F
0 g
.40032 .73913 m
.40479 .74276 L
s
.51379 .72056 m
.51381 .72024 L
s
.51443 .71541 m
.51443 .71542 L
s
.51475 .71745 m
.51481 .71781 L
s
.5297 .75526 m .52791 .75571 L .52757 .76125 L 0 .998 .396 r
F
0 g
.52518 .7562 m
.52757 .76125 L
s
.49179 .69783 m .48796 .69448 L .48358 .6971 L 0 .807 .308 r
F
.49179 .69783 m .49148 .69479 L .48796 .69448 L F
0 g
.48796 .69448 m
.49109 .6902 L
s
.47023 .87325 m .46127 .87533 L .46601 .88137 L 0 .705 .397 r
F
.47023 .87325 m .45921 .86842 L .46127 .87533 L F
0 g
.46127 .87533 m
.46127 .87533 L
s
.50681 .7201 m .5055 .73235 L .50664 .72547 L 0 1 .399 r
F
.5091 .72058 m .50664 .72547 L .5055 .73235 L 0 1 .396 r
F
0 g
.50364 .73712 m
.5055 .73235 L
s
.5055 .73235 m
.50555 .73363 L
s
.51144 .72077 m
.51185 .72485 L
s
.51252 .72278 m
.51285 .72067 L
s
.51247 .72311 m
.51252 .72278 L
s
.50355 .69381 m
.50356 .6938 L
s
.79657 .88371 m .80128 .89317 L .80675 .88376 L 0 1 .512 r
F
0 g
.79424 .90006 m
.80128 .89317 L
s
.47234 .7494 m .47072 .74766 L .46689 .74914 L 0 1 .445 r
F
.48049 .73872 m .47234 .7494 L .47592 .74743 L 0 1 .433 r
F
.48049 .73872 m .47072 .74766 L .47234 .7494 L F
0 g
.47118 .75367 m
.47234 .7494 L
s
.47234 .7494 m
.47523 .74781 L
s
.3154 .73935 m .30916 .74735 L .31328 .74636 L 0 1 .458 r
F
.3154 .73935 m .30504 .74168 L .30916 .74735 L F
0 g
.30776 .75443 m
.30916 .74735 L
s
.31328 .74636 m
.31796 .75181 L
s
.47819 .89648 m .4752 .90387 L .47666 .90458 L 0 .656 .404 r
F
.47819 .89648 m .47666 .90458 L .47921 .90192 L F
.47817 .90125 m .47519 .90551 L .47666 .90458 L 0 1 .273 r
F
.49083 .89433 m .4811 .90073 L .48004 .90244 L 0 1 .292 r
F
.48011 .90095 m .48002 .90623 L .48109 .90325 L 0 .656 .404 r
F
.48009 .90091 m .48004 .90244 L .4811 .90073 L 0 1 .273 r
F
.47819 .89648 m .47921 .90192 L .48009 .90091 L 0 .656 .404 r
F
.47817 .90125 m .47921 .90192 L .48009 .90091 L 0 1 .273 r
F
.47921 .90192 m .48004 .90244 L .48009 .90091 L F
.48009 .90091 m .47921 .90192 L .48011 .90095 L 0 .656 .404 r
F
.47921 .90192 m .47685 .90446 L .48004 .90244 L 0 1 .273 r
F
.47921 .90192 m .48002 .90623 L .48011 .90095 L 0 .656 .404 r
F
.47921 .90192 m .47666 .90458 L .47685 .90446 L 0 1 .273 r
F
.47817 .90125 m .47666 .90458 L .47921 .90192 L F
.47921 .90192 m .47666 .90458 L .48002 .90623 L 0 .656 .404 r
F
0 g
.4752 .90387 m
.47605 .90428 L
s
.47593 .90537 m
.47596 .90542 L
s
.4752 .90387 m
.47567 .90483 L
s
.47581 .90512 m
.47593 .90537 L
s
.47592 .90543 m
.47596 .90542 L
s
.43611 .76897 m .42433 .76939 L .42653 .77556 L 0 .972 .381 r
F
.43611 .76897 m .42567 .76291 L .42433 .76939 L F
0 g
.41975 .76654 m
.42433 .76939 L
s
.42436 .76699 m
.42561 .7631 L
s
.48049 .73872 m .47592 .74743 L .47908 .74307 L 0 1 .433 r
F
.48395 .74214 m .47908 .74307 L .47592 .74743 L 0 1 .432 r
F
0 g
.47489 .75191 m
.47592 .74743 L
s
.47523 .74781 m
.47592 .74743 L
s
.45951 .75402 m .45366 .75267 L .44989 .75581 L 0 1 .457 r
F
.45951 .75402 m .45778 .7519 L .45366 .75267 L F
.46843 .74498 m .45778 .7519 L .45951 .75402 L 0 1 .447 r
F
0 g
.45819 .75816 m
.45951 .75402 L
s
.45951 .75402 m
.46238 .75315 L
s
.52221 .73185 m
.52252 .73266 L
s
.43611 .76897 m .42653 .77556 L .431 .77816 L 0 .972 .381 r
F
0 g
.42537 .78209 m
.42653 .77556 L
s
.54369 .70827 m .54546 .71872 L .54939 .72636 L 0 .828 .335 r
F
0 g
.54606 .71052 m
.54731 .71171 L
s
.54661 .70969 m
.54731 .71171 L
s
.54551 .70654 m
.54661 .70969 L
s
.54369 .70827 m .54301 .71097 L .54546 .71872 L 0 .828 .335 r
F
0 g
.54132 .70284 m
.54369 .70827 L
s
.54369 .70827 m
.54606 .71052 L
s
.53957 .70847 m
.54301 .71097 L
s
.50459 .71932 m .50031 .73571 L .50247 .73123 L 0 1 .401 r
F
.50459 .71932 m .49901 .73504 L .50031 .73571 L F
0 g
.5001 .74069 m
.50031 .73571 L
s
.50229 .73659 m
.50244 .73213 L
s
.33591 .79574 m .32379 .79377 L .32311 .79635 L 0 1 .492 r
F
.33591 .79574 m .32779 .79276 L .32379 .79377 L F
.33591 .79574 m .333 .79361 L .32779 .79276 L F
.34564 .79263 m .333 .79361 L .33591 .79574 L 0 1 .478 r
F
0 g
.33522 .7983 m
.33591 .79574 L
s
.33591 .79574 m
.34098 .79634 L
s
.43147 .75408 m .4213 .76006 L .42567 .76291 L 0 1 .38 r
F
.43147 .75408 m .41948 .75379 L .4213 .76006 L F
0 g
.42067 .76256 m
.4213 .76006 L
s
.72074 .92766 m .7235 .93461 L .72995 .93161 L 0 1 .528 r
F
0 g
.72129 .93815 m
.7235 .93461 L
s
.71607 .93552 m
.7235 .93461 L
s
.52218 .7379 m .52556 .75051 L .52422 .74314 L 0 1 .39 r
F
0 g
.52218 .7379 m
.52221 .73185 L
s
.51749 .96455 m .51096 .95796 L .50594 .95476 L 0 .379 .37 r
F
0 g
.50122 .94821 m
.50594 .95476 L
s
.71367 .93045 m
.71457 .93037 L
s
.7115 .92353 m .70384 .92913 L .70734 .931 L 0 1 .524 r
F
0 g
.70734 .931 m
.70895 .93086 L
s
.70475 .93437 m
.70734 .931 L
s
.42474 .64353 m .42578 .63686 L .42327 .63234 L 0 1 .372 r
F
0 g
.42578 .63686 m
.42736 .63475 L
s
.31075 .96649 m .31 .9729 L .31331 .97155 L 0 1 .536 r
F
.31075 .96649 m .30224 .96971 L .31 .9729 L F
0 g
.31 .9729 m
.3134 .97777 L
s
.50929 .72602 m
.50997 .72303 L
s
.50998 .72297 m
.5105 .72071 L
s
.51145 .72066 m
.51193 .71736 L
s
.51264 .71848 m
.51285 .72067 L
s
.77404 .9328 m .7677 .93682 L .76577 .9408 L 0 1 .532 r
F
0 g
.75746 .94269 m
.76577 .9408 L
s
.78382 .93559 m .78674 .94291 L .79359 .93832 L 0 1 .534 r
F
0 g
.77883 .94537 m
.78674 .94291 L
s
.51017 .66948 m
.51017 .66948 L
s
.51017 .66947 m
.51017 .66948 L
s
.36415 .94726 m
.37201 .94642 L
s
.38526 .94317 m .36907 .94462 L .37201 .94642 L 0 1 .484 r
F
.50923 .66432 m .50968 .66367 L .50907 .65884 L 0 1 .367 r
F
0 g
.50968 .66367 m
.51096 .66833 L
s
.36514 .78606 m .3602 .78952 L .36405 .78809 L 0 1 .437 r
F
.36514 .78606 m .35539 .78941 L .3602 .78952 L F
0 g
.35973 .79168 m
.3602 .78952 L
s
.36405 .78809 m
.3692 .78793 L
s
.52557 .73655 m .52556 .75051 L .52791 .75571 L 0 1 .385 r
F
.52557 .73655 m .52422 .74314 L .52556 .75051 L F
0 g
.52518 .7562 m
.52556 .75051 L
s
.48427 .71653 m .47823 .72249 L .482 .71861 L 0 0 0 r
F
.48427 .71653 m .47464 .72624 L .47823 .72249 L F
0 g
.47627 .72449 m
.47823 .72249 L
s
.482 .71861 m
.48548 .71478 L
s
.52557 .73655 m .52422 .73716 L .52422 .74314 L 0 1 .385 r
F
0 g
.52422 .74314 m
.52422 .73716 L
s
.52252 .73266 m
.52422 .73716 L
s
.52218 .7379 m
.52422 .74314 L
s
.49179 .69783 m .48358 .6971 L .48064 .70201 L 0 .807 .308 r
F
0 g
.48005 .69607 m
.48358 .6971 L
s
.469 .70199 m .46165 .70981 L .46604 .70734 L 0 .937 .332 r
F
.469 .70199 m .45796 .70777 L .46165 .70981 L F
.3367 .97562 m .31829 .96955 L .32145 .97429 L 0 1 .537 r
F
.69074 1.07469 m .68119 1.07519 L .67587 1.07611 L 0 .775 .287 r
F
0 g
.66752 1.07577 m
.67587 1.07611 L
s
.43418 .70376 m .43374 .69775 L .42998 .69439 L 0 1 .367 r
F
0 g
.43374 .69775 m
.43683 .69208 L
s
.43147 .75408 m .42127 .74742 L .41948 .75379 L 0 1 .38 r
F
0 g
.41495 .75065 m
.41948 .75379 L
s
.51778 .98184 m .51806 .98504 L .52341 .98304 L 0 1 .511 r
F
.51778 .98184 m .51067 .98657 L .51806 .98504 L F
0 g
.51806 .98504 m
.52377 .98499 L
s
.51806 .98504 m
.52275 .98329 L
s
.50459 .71932 m .50247 .73123 L .50405 .72459 L 0 1 .401 r
F
.50681 .7201 m .50405 .72459 L .50247 .73123 L 0 1 .399 r
F
0 g
.50244 .73213 m
.50247 .73123 L
s
.50031 .73571 m
.50247 .73123 L
s
.8125 .60415 m .8201 .60769 L .81547 .60526 L 0 .207 .182 r
F
.8125 .60415 m .82407 .61072 L .8201 .60769 L F
.50459 .71932 m .49955 .72977 L .49901 .73504 L 0 1 .401 r
F
0 g
.49734 .73759 m
.49901 .73504 L
s
.44691 .71333 m .44238 .70497 L .43788 .70686 L 0 1 .356 r
F
.44691 .71333 m .44625 .70775 L .44238 .70497 L F
0 g
.44238 .70497 m
.44548 .6993 L
s
.44156 .78364 m .43011 .78475 L .43267 .79083 L 0 .926 .381 r
F
.44156 .78364 m .431 .77816 L .43011 .78475 L F
0 g
.42537 .78209 m
.43011 .78475 L
s
.52523 .73032 m
.52525 .73037 L
s
.52525 .73037 m
.52707 .73443 L
s
.28548 .78459 m .27312 .77509 L .27193 .78059 L 0 1 .524 r
F
.28548 .78459 m .27752 .77428 L .27312 .77509 L F
.28548 .78459 m .28282 .77836 L .27752 .77428 L F
.29624 .78204 m .28282 .77836 L .28548 .78459 L 0 1 .523 r
F
0 g
.28428 .79005 m
.28548 .78459 L
s
.28548 .78459 m
.29067 .78843 L
s
.53777 .71384 m
.5388 .71711 L
s
.51181 .62466 m .51458 .61078 L .51327 .60899 L 0 1 .325 r
F
0 g
.51458 .61078 m
.51559 .60628 L
s
.51042 .71847 m
.5105 .72071 L
s
.50326 .68884 m
.50453 .68817 L
s
.50275 .69192 m
.50445 .68944 L
s
.53995 .64617 m .54549 .65318 L .54197 .65248 L 0 .121 .123 r
F
.43241 .57476 m .42379 .58134 L .42755 .58078 L 0 1 .355 r
F
.43241 .57476 m .42323 .57619 L .42379 .58134 L F
0 g
.43065 .58324 m
.43318 .58011 L
s
.43241 .57476 m .42625 .56877 L .42323 .57619 L 0 1 .355 r
F
.43241 .57476 m .43111 .56276 L .42625 .56877 L F
.43241 .57476 m .43457 .56215 L .43111 .56276 L F
0 g
.43241 .57476 m
.43318 .58011 L
s
.43457 .56215 m
.43512 .56729 L
s
.5091 .72058 m .50818 .72042 L .50664 .72547 L 0 1 .396 r
F
0 g
.50664 .72547 m
.50818 .72042 L
s
.5091 .72058 m
.50985 .71703 L
s
.5091 .72058 m
.50929 .72602 L
s
.52575 .98284 m
.5265 .98381 L
s
.52574 .98283 m
.52575 .98284 L
s
.52559 .98264 m
.52574 .98283 L
s
.52372 .98022 m
.52456 .98131 L
s
.50248 .68925 m .49148 .69479 L .49179 .69783 L 0 .756 .296 r
F
0 g
.48796 .69448 m
.49148 .69479 L
s
.49148 .69479 m
.49454 .6906 L
s
.52131 .67153 m .52449 .66613 L .52798 .66204 L 0 0 .086 r
F
.52131 .67153 m .52163 .67019 L .52449 .66613 L F
0 g
.52209 .66822 m
.52449 .66613 L
s
.51926 .67254 m
.52163 .67019 L
s
.52163 .67019 m
.52449 .66613 L
s
.39172 .73703 m .38196 .7274 L .37976 .73377 L 0 1 .41 r
F
.39172 .73703 m .38628 .726 L .38196 .7274 L F
.39172 .73703 m .39046 .73013 L .38628 .726 L F
0 g
.38951 .74339 m
.39172 .73703 L
s
.40275 .73281 m .39046 .73013 L .39172 .73703 L 0 1 .401 r
F
0 g
.39172 .73703 m
.39594 .74088 L
s
.48805 .4418 m
.49205 .43778 L
s
.43418 .70376 m .42998 .69439 L .42541 .69591 L 0 1 .367 r
F
0 g
.42998 .69439 m
.43333 .68867 L
s
.42998 .69439 m
.43374 .69775 L
s
.5099 .64421 m .50779 .63597 L .50859 .64125 L 0 1 .354 r
F
.5099 .64421 m .50826 .6303 L .50779 .63597 L F
.5099 .64421 m .50968 .62804 L .50826 .6303 L F
.5099 .64421 m .51098 .63101 L .50968 .62804 L F
0 g
.50978 .65015 m
.50984 .64713 L
s
.50984 .64713 m
.5099 .64421 L
s
.50923 .66432 m .50589 .65607 L .50761 .66107 L 0 1 .367 r
F
.50923 .66432 m .50529 .65124 L .50589 .65607 L F
.50923 .66432 m .50619 .64979 L .50529 .65124 L F
.50923 .66432 m .50781 .65305 L .50619 .64979 L F
.50923 .66432 m .50907 .65884 L .50781 .65305 L F
0 g
.50907 .66402 m
.50923 .66432 L
s
.50907 .65884 m
.5103 .66255 L
s
.50923 .66432 m
.51017 .66948 L
s
.50907 .65884 m
.50968 .66367 L
s
.24722 .75357 m .23606 .73771 L .23419 .74573 L 0 1 .482 r
F
.24722 .75357 m .24055 .73702 L .23606 .73771 L F
.24722 .75357 m .24533 .74383 L .24055 .73702 L F
.25827 .75141 m .24533 .74383 L .24722 .75357 L 0 1 .479 r
F
0 g
.24535 .76154 m
.24722 .75357 L
s
.24722 .75357 m
.25193 .76016 L
s
.52557 .73655 m .5297 .74928 L .52791 .74175 L 0 1 .385 r
F
.52557 .73655 m .5297 .75526 L .5297 .74928 L F
.52557 .73655 m .52791 .75571 L .5297 .75526 L F
0 g
.52556 .75051 m
.52791 .75571 L
s
.52523 .73032 m
.52557 .73655 L
s
.52757 .76125 m
.52791 .75571 L
s
.49711 .73395 m .49587 .73316 L .49313 .73664 L 0 1 .416 r
F
.42474 .64353 m .41609 .64996 L .42059 .64915 L 0 1 .372 r
F
0 g
.42498 .65132 m
.42734 .64798 L
s
.42474 .64353 m .41358 .64544 L .41609 .64996 L 0 1 .372 r
F
.42474 .64353 m .41473 .6386 L .41358 .64544 L F
.42474 .64353 m .41889 .63298 L .41473 .6386 L F
.42474 .64353 m .42327 .63234 L .41889 .63298 L F
0 g
.42327 .63234 m
.42578 .63686 L
s
.42474 .64353 m
.42734 .64798 L
s
.42327 .63234 m
.42761 .62675 L
s
.52469 .57536 m .52748 .56917 L .53041 .56442 L 0 0 .002 r
F
0 g
.52748 .56917 m
.52874 .56709 L
s
.52812 .72826 m
.52871 .7336 L
s
.52812 .72826 m
.53041 .73265 L
s
.67184 .63256 m
.67186 .63255 L
s
.67183 .63256 m
.67184 .63256 L
s
.6718 .63258 m
.67183 .63256 L
s
.5176 .57704 m .51573 .55303 L .51558 .5707 L 0 1 .25 r
F
.51045 .59923 m .51573 .55303 L .51335 .54831 L 0 1 .262 r
F
.51045 .59923 m .51558 .5707 L .51573 .55303 L F
0 g
.51573 .55303 m
.51745 .53782 L
s
.51181 .62466 m .51017 .61826 L .5105 .62288 L 0 1 .325 r
F
.51181 .62466 m .51136 .61231 L .51017 .61826 L F
.51181 .62466 m .51327 .60899 L .51136 .61231 L F
0 g
.51098 .63101 m
.51181 .62466 L
s
.41704 .74432 m .41126 .73457 L .40688 .73643 L 0 1 .391 r
F
.41704 .74432 m .41561 .73795 L .41126 .73457 L F
.4277 .73896 m .41704 .74432 L .42127 .74742 L 0 1 .38 r
F
.4277 .73896 m .41561 .73795 L .41704 .74432 L F
0 g
.41495 .75065 m
.41704 .74432 L
s
.45796 .70777 m .44625 .70775 L .44691 .71333 L 0 .984 .344 r
F
0 g
.44238 .70497 m
.44625 .70775 L
s
.44625 .70775 m
.44913 .70211 L
s
.44156 .78364 m .43267 .79083 L .43719 .79319 L 0 .926 .381 r
F
0 g
.43199 .79745 m
.43267 .79083 L
s
.45961 .85841 m .45921 .86842 L .46119 .86526 L 0 .773 .4 r
F
.47023 .87325 m .46119 .86526 L .45921 .86842 L 0 .705 .397 r
F
0 g
.45921 .86842 m
.46127 .87533 L
s
.45434 .86622 m
.45921 .86842 L
s
.4474 .82072 m .44492 .83061 L .44771 .82749 L 0 .859 .391 r
F
.45585 .83538 m .44771 .82749 L .44492 .83061 L 0 .803 .39 r
F
0 g
.44492 .83061 m
.44572 .83745 L
s
.44018 .82837 m
.44492 .83061 L
s
.32576 .73695 m .31946 .74485 L .32358 .74382 L 0 1 .453 r
F
.32576 .73695 m .3154 .73935 L .31946 .74485 L F
0 g
.31796 .75181 m
.31946 .74485 L
s
.32358 .74382 m
.32817 .7491 L
s
.43418 .70376 m .42663 .71142 L .43113 .70962 L 0 1 .367 r
F
.43418 .70376 m .42288 .70806 L .42663 .71142 L F
.43418 .70376 m .42236 .70177 L .42288 .70806 L F
.43418 .70376 m .42541 .69591 L .42236 .70177 L F
.41378 .72835 m .40688 .73643 L .41126 .73457 L 0 1 .39 r
F
.41378 .72835 m .40275 .73281 L .40688 .73643 L F
0 g
.40479 .74276 m
.40688 .73643 L
s
.50353 .69384 m .49711 .70154 L .50089 .69686 L 0 0 .029 r
F
0 g
.50089 .69686 m
.50265 .69452 L
s
.68811 .93862 m .68186 .94302 L .67954 .94632 L 0 1 .456 r
F
0 g
.67954 .94632 m
.68186 .94302 L
s
.67779 .94693 m
.67954 .94632 L
s
.45537 .74865 m .44989 .75581 L .45366 .75267 L 0 1 .459 r
F
.45537 .74865 m .44577 .7563 L .44989 .75581 L F
0 g
.44858 .75995 m
.44989 .75581 L
s
.48395 .74214 m .48253 .7408 L .47908 .74307 L 0 1 .432 r
F
.49125 .72951 m .48395 .74214 L .48713 .73928 L 0 1 .419 r
F
.49125 .72951 m .48253 .7408 L .48395 .74214 L F
0 g
.48334 .74481 m
.48395 .74214 L
s
.48395 .74214 m
.48697 .73942 L
s
.50942 .67071 m
.50942 .67071 L
s
.50941 .67071 m
.50942 .67071 L
s
.44691 .71333 m .43788 .70686 L .43509 .7127 L 0 1 .356 r
F
0 g
.43418 .70376 m
.43788 .70686 L
s
.50818 .72042 m
.50829 .71644 L
s
.50829 .71644 m
.50834 .7146 L
s
.4811 .70593 m .477 .70099 L .47262 .70356 L 0 .856 .32 r
F
.4811 .70593 m .48064 .70201 L .477 .70099 L F
0 g
.477 .70099 m
.48005 .69607 L
s
.81375 .79584 m .81153 .80206 L .81594 .80462 L 0 .631 .396 r
F
.81375 .79584 m .81058 .7983 L .81153 .80206 L F
0 g
.80496 .80274 m
.81153 .80206 L
s
.50246 .71825 m .49711 .73395 L .49955 .72977 L 0 1 .402 r
F
.50246 .71825 m .49587 .73316 L .49711 .73395 L F
0 g
.49901 .73504 m
.49949 .73029 L
s
.49652 .73884 m
.49711 .73395 L
s
.43147 .75408 m .42567 .76291 L .42968 .76044 L 0 1 .38 r
F
.43144 .75647 m .42567 .76291 L .42968 .76044 L 0 1 .479 r
F
.43144 .75647 m .42127 .76245 L .42567 .76291 L F
0 g
.4213 .76006 m
.42322 .76131 L
s
.43141 .75887 m .42567 .76291 L .42968 .76044 L 0 .931 .231 r
F
.43141 .75887 m .42123 .76485 L .42567 .76291 L F
0 g
.42974 .76041 m
.42982 .76037 L
s
.42982 .76037 m
.42993 .76032 L
s
.43611 .76897 m .42968 .76044 L .42567 .76291 L 0 .972 .381 r
F
0 g
.42547 .763 m
.42567 .76291 L
s
.42433 .76939 m
.42567 .76291 L
s
.42561 .7631 m
.42567 .76291 L
s
.42439 .76459 m
.42567 .76291 L
s
.46048 .99084 m .453 .98945 L .44632 .98981 L 0 1 .542 r
F
.4633 .98621 m .46048 .99084 L .46684 .99048 L 0 1 .541 r
F
.4633 .98621 m .453 .98945 L .46048 .99084 L F
0 g
.46048 .99084 m
.46435 .99286 L
s
.50804 .71569 m
.50834 .7146 L
s
.5357 .71846 m
.53682 .72271 L
s
.52469 .57536 m .53041 .56442 L .53152 .56425 L 0 0 .002 r
F
0 g
.53041 .56442 m
.5316 .55903 L
s
.52748 .56917 m
.53041 .56442 L
s
.53085 .72562 m
.53143 .72921 L
s
.53143 .72921 m
.5318 .73147 L
s
.53085 .72562 m
.53283 .72891 L
s
.36965 .97877 m .35186 .97436 L .35523 .9786 L 0 1 .538 r
F
0 g
.34734 .97659 m
.35523 .9786 L
s
.38526 .94317 m .3719 .94312 L .36907 .94462 L 0 1 .484 r
F
.38526 .94317 m .37885 .94249 L .3719 .94312 L F
.39179 .9391 m .37885 .94249 L .38526 .94317 L 0 1 .465 r
F
0 g
.38526 .94317 m
.39194 .94241 L
s
.38526 .94317 m
.38818 .94497 L
s
.4474 .82072 m .44421 .81481 L .43946 .81257 L 0 .859 .391 r
F
.49125 .72951 m .48713 .73928 L .48994 .73414 L 0 1 .419 r
F
.49408 .73188 m .48994 .73414 L .48713 .73928 L 0 1 .417 r
F
0 g
.48618 .74404 m
.48713 .73928 L
s
.48697 .73942 m
.48713 .73928 L
s
.49313 .73664 m
.49355 .73611 L
s
.42984 .76045 m
.43 .76046 L
s
.44577 .7563 m .43569 .7566 L .43418 .76064 L 0 1 .469 r
F
0 g
.43 .76046 m
.43418 .76064 L
s
.42993 .76032 m
.43421 .75825 L
s
.50681 .7201 m .50591 .71982 L .50405 .72459 L 0 1 .399 r
F
0 g
.50681 .7201 m
.50772 .71682 L
s
.50664 .72547 m
.50681 .7201 L
s
.52882 .73464 m .52754 .73547 L .52791 .74175 L 0 1 .378 r
F
0 g
.52707 .73443 m
.52754 .73547 L
s
.4277 .73896 m .42127 .74742 L .42548 .74521 L 0 1 .38 r
F
.43147 .75408 m .42548 .74521 L .42127 .74742 L F
0 g
.41948 .75379 m
.42127 .74742 L
s
.41704 .74432 m
.42127 .74742 L
s
.50246 .71825 m .49955 .72977 L .50156 .7234 L 0 1 .402 r
F
.50459 .71932 m .50156 .7234 L .49955 .72977 L 0 1 .401 r
F
0 g
.49949 .73029 m
.49955 .72977 L
s
.49711 .73395 m
.49955 .72977 L
s
.50405 .72459 m
.50591 .71982 L
s
.53338 .72237 m
.53447 .72746 L
s
.54152 .40858 m .54839 .404 L .55436 .40617 L 0 .271 .104 r
F
0 g
.54839 .404 m
.55269 .39417 L
s
.45585 .83538 m .44956 .84347 L .45424 .84552 L 0 .803 .39 r
F
0 g
.44956 .84347 m
.45065 .85026 L
s
.53457 .77418 m
.53563 .77589 L
s
.45785 .4921 m .4505 .50164 L .45265 .50001 L 0 .917 .145 r
F
.45785 .4921 m .45281 .49643 L .4505 .50164 L F
0 g
.45085 .50514 m
.45368 .50099 L
s
.45368 .50099 m
.45592 .49771 L
s
.45785 .4921 m .45803 .48788 L .45281 .49643 L 0 .917 .145 r
F
.45785 .4921 m .46324 .47998 L .45803 .48788 L F
.45796 .70777 m .45069 .71576 L .45508 .71342 L 0 .984 .344 r
F
.45796 .70777 m .44691 .71333 L .45069 .71576 L F
.52882 .73464 m .52791 .74175 L .5297 .74928 L 0 1 .378 r
F
0 g
.52557 .73655 m
.52791 .74175 L
s
.52754 .73547 m
.52791 .74175 L
s
.48049 .73872 m .47212 .74331 L .47072 .74766 L 0 1 .433 r
F
0 g
.46689 .74914 m
.47072 .74766 L
s
.50353 .69384 m .4939 .7058 L .49711 .70154 L 0 0 .029 r
F
0 g
.49471 .70426 m
.49711 .70154 L
s
.50089 .69686 m
.50267 .69482 L
s
.50267 .69482 m
.50267 .69482 L
s
.50267 .69482 m
.50268 .69481 L
s
.50268 .69481 m
.50293 .69452 L
s
.50348 .69389 m
.50353 .69384 L
s
.49371 .70548 m
.49471 .70426 L
s
.4277 .73896 m .41782 .73171 L .41561 .73795 L 0 1 .38 r
F
0 g
.41126 .73457 m
.41561 .73795 L
s
.4939 .7058 m .48766 .7125 L .49144 .70825 L 0 0 0 r
F
.4939 .7058 m .48427 .71653 L .48766 .7125 L F
0 g
.48548 .71478 m
.48766 .7125 L
s
.49144 .70825 m
.49371 .70548 L
s
.50813 .66605 m .50857 .66534 L .50761 .66107 L 0 1 .369 r
F
0 g
.50837 .66446 m
.50857 .66534 L
s
.50857 .66534 m
.51017 .66947 L
s
.60551 .43018 m
.60583 .42959 L
s
.4811 .70593 m .47262 .70356 L .46979 .70892 L 0 .856 .32 r
F
0 g
.469 .70199 m
.47262 .70356 L
s
.46502 .7351 m .45578 .7424 L .4539 .74411 L 0 0 0 r
F
.46502 .7351 m .4598 .73925 L .45578 .7424 L F
.46502 .7351 m .46376 .73612 L .4598 .73925 L F
.47464 .72624 m .46376 .73612 L .46502 .7351 L F
0 g
.46502 .7351 m
.4688 .73166 L
s
.46314 .73681 m
.46502 .7351 L
s
.52882 .73464 m .53367 .74742 L .53145 .73976 L 0 1 .378 r
F
.52882 .73464 m .53405 .7537 L .53367 .74742 L F
.52882 .73464 m .53233 .7544 L .53405 .7537 L F
.52882 .73464 m .5297 .74928 L .53233 .7544 L F
0 g
.52871 .7336 m
.52882 .73464 L
s
.27623 .9537 m .27481 .9586 L .27841 .95738 L 0 1 .526 r
F
0 g
.27841 .95738 m
.28669 .95893 L
s
.27623 .9537 m .26703 .95656 L .27481 .9586 L 0 1 .526 r
F
0 g
.27481 .9586 m
.27793 .96216 L
s
.27415 .80212 m .26888 .80666 L .27314 .80571 L 0 1 .527 r
F
.27415 .80212 m .2634 .80427 L .26888 .80666 L F
0 g
.26874 .81036 m
.26888 .80666 L
s
.27314 .80571 m
.27924 .80775 L
s
.50246 .71825 m .49677 .72801 L .49587 .73316 L 0 1 .402 r
F
0 g
.49355 .73611 m
.49587 .73316 L
s
.36906 .73723 m
.36907 .73722 L
s
.52044 .56781 m
.52211 .58097 L
s
.72493 .62881 m
.72494 .62881 L
s
.50591 .71982 m
.50631 .71544 L
s
.50631 .71544 m
.50643 .71406 L
s
.42282 .66002 m .42348 .65346 L .42059 .64915 L 0 1 .374 r
F
0 g
.42348 .65346 m
.42498 .65132 L
s
.40275 .73281 m .39289 .7238 L .39046 .73013 L 0 1 .401 r
F
.40275 .73281 m .39739 .72227 L .39289 .7238 L F
.40275 .73281 m .40161 .72613 L .39739 .72227 L F
.41378 .72835 m .40161 .72613 L .40275 .73281 L 0 1 .39 r
F
0 g
.40275 .73281 m
.40688 .73643 L
s
.40032 .73913 m
.40275 .73281 L
s
.54191 .71475 m .54939 .72636 L .54546 .71872 L 0 .857 .342 r
F
.54191 .71475 m .54325 .72467 L .54692 .73248 L F
0 g
.5435 .71252 m
.54489 .71694 L
s
.54301 .71097 m
.5435 .71252 L
s
.54489 .71694 m
.54546 .71872 L
s
.5446 .71777 m
.54546 .71872 L
s
.54191 .71475 m .54111 .71708 L .54325 .72467 L 0 .857 .342 r
F
0 g
.54191 .71475 m
.5446 .71777 L
s
.54034 .71054 m
.54191 .71475 L
s
.53777 .71384 m
.54111 .71708 L
s
.43611 .76897 m .431 .77816 L .43476 .77545 L 0 .972 .381 r
F
.44156 .78364 m .43476 .77545 L .431 .77816 L 0 .926 .381 r
F
0 g
.43011 .78475 m
.431 .77816 L
s
.42653 .77556 m
.431 .77816 L
s
.47819 .89648 m .47326 .89044 L .46845 .88809 L 0 .656 .404 r
F
0 g
.46845 .88809 m
.47326 .89044 L
s
.46601 .88138 m
.46845 .88809 L
s
.5297 .75526 m .53418 .76746 L .53239 .7603 L 0 .998 .396 r
F
0 g
.5297 .75526 m
.5297 .74928 L
s
.41344 .93493 m .40075 .93655 L .39823 .9382 L 0 1 .455 r
F
.41344 .93493 m .40727 .93514 L .40075 .93655 L F
.41913 .93056 m .40727 .93514 L .41344 .93493 L 0 1 .425 r
F
0 g
.41344 .93493 m
.41643 .93616 L
s
.41344 .93493 m
.41969 .93342 L
s
.5087 .67201 m
.5087 .67201 L
s
.5087 .67201 m
.5087 .67201 L
s
.43905 .92402 m .42512 .92896 L .42811 .92957 L 0 1 .404 r
F
0 g
.42186 .93161 m
.42811 .92957 L
s
.25827 .75141 m .24728 .73597 L .24533 .74383 L 0 1 .479 r
F
.25827 .75141 m .25177 .73527 L .24728 .73597 L F
.25827 .75141 m .25648 .74189 L .25177 .73527 L F
.26932 .7492 m .25648 .74189 L .25827 .75141 L 0 1 .476 r
F
0 g
.25632 .75922 m
.25827 .75141 L
s
.25827 .75141 m
.2629 .75781 L
s
.43586 .71862 m .43113 .70962 L .42663 .71142 L 0 1 .368 r
F
.43586 .71862 m .43509 .7127 L .43113 .70962 L F
0 g
.43113 .70962 m
.43418 .70376 L
s
.44276 .5314 m .44752 .51786 L .44488 .51906 L 0 1 .278 r
F
0 g
.44752 .51786 m
.45259 .51042 L
s
.44661 .52315 m
.44752 .51786 L
s
.79427 .68095 m .79725 .69484 L .80182 .69665 L 0 1 .504 r
F
.79427 .68095 m .79402 .68812 L .79725 .69484 L F
0 g
.79275 .69936 m
.79725 .69484 L
s
.52131 .67153 m .52798 .66204 L .53011 .66169 L 0 0 .086 r
F
0 g
.52798 .66204 m
.53102 .65629 L
s
.5378 1.00139 m .54481 1.0134 L .54415 1.0102 L 0 .184 .202 r
F
0 g
.54237 1.00772 m
.54389 1.00984 L
s
.54389 1.00984 m
.54415 1.0102 L
s
.54412 1.01275 m
.54481 1.0134 L
s
.53647 .99468 m .5378 1.00139 L .54317 1.00557 L 0 .286 .291 r
F
0 g
.54219 1.00481 m
.54317 1.00557 L
s
.5378 1.00139 m
.54038 1.00339 L
s
.54038 1.00339 m
.54219 1.00481 L
s
.5394 1.00361 m
.54237 1.00772 L
s
.5378 1.00139 m
.5394 1.00361 L
s
.33613 .73444 m .32976 .74226 L .33389 .7412 L 0 1 .447 r
F
.33613 .73444 m .32576 .73695 L .32976 .74226 L F
0 g
.32817 .7491 m
.32976 .74226 L
s
.33389 .7412 m
.33838 .74631 L
s
.5319 .73211 m .53069 .73319 L .53145 .73976 L 0 .98 .372 r
F
0 g
.53041 .73265 m
.53069 .73319 L
s
.44691 .71333 m .43509 .7127 L .43586 .71862 L 0 1 .356 r
F
0 g
.43113 .70962 m
.43509 .7127 L
s
.43509 .7127 m
.43788 .70686 L
s
.5297 .74928 m
.53049 .75081 L
s
.50813 .66605 m .50406 .6592 L .5062 .66342 L 0 1 .369 r
F
.50813 .66605 m .50309 .65492 L .50406 .6592 L F
.50813 .66605 m .50396 .65344 L .50309 .65492 L F
.50813 .66605 m .50589 .65607 L .50396 .65344 L F
.50813 .66605 m .50761 .66107 L .50589 .65607 L F
0 g
.5077 .66545 m
.50813 .66605 L
s
.50761 .66107 m
.50907 .66402 L
s
.50813 .66605 m
.50942 .67071 L
s
.50761 .66107 m
.50837 .66446 L
s
.52421 .67851 m .53181 .67649 L .52742 .67647 L 0 .566 .27 r
F
0 g
.52401 .67441 m
.52742 .67647 L
s
.52421 .67851 m .53529 .68167 L .53181 .67649 L 0 .566 .27 r
F
0 g
.53181 .67649 m
.53486 .6712 L
s
.53486 .6712 m
.53551 .67266 L
s
.52421 .67851 m .53553 .68858 L .53529 .68167 L 0 .566 .27 r
F
.52421 .67851 m .53232 .69062 L .53553 .68858 L F
0 g
.53551 .67266 m
.53658 .67502 L
s
.52421 .67851 m .5278 .68643 L .53232 .69062 L 0 .566 .27 r
F
.52421 .67851 m .52433 .68125 L .5278 .68643 L F
0 g
.52084 .67763 m
.52421 .67851 L
s
.52421 .67851 m
.52742 .67647 L
s
.49125 .72951 m .48383 .73618 L .48253 .7408 L 0 1 .419 r
F
0 g
.47908 .74307 m
.48253 .7408 L
s
.50353 .69384 m .4934 .7068 L .4939 .7058 L 0 0 .029 r
F
.50353 .69384 m .49605 .70377 L .4934 .7068 L F
0 g
.49144 .70825 m
.49217 .70752 L
s
.50353 .69384 m .50008 .69876 L .49605 .70377 L 0 0 .029 r
F
.50353 .69384 m .50329 .6945 L .50008 .69876 L F
0 g
.50353 .69384 m
.50355 .69381 L
s
.50353 .69384 m
.50353 .69384 L
s
.78638 .88394 m .78443 .89969 L .79131 .89289 L 0 1 .51 r
F
.78638 .88394 m .7805 .89962 L .78443 .89969 L F
0 g
.78256 .90593 m
.78443 .89969 L
s
.47519 .90551 m .4646 .91108 L .46312 .91293 L 0 1 .339 r
F
.47519 .90551 m .46978 .90789 L .4646 .91108 L F
0 g
.48067 .90227 m
.4834 .9015 L
s
.47817 .90125 m .46978 .90789 L .47519 .90551 L 0 1 .273 r
F
0 g
.47519 .90551 m
.47666 .90458 L
s
.47519 .90551 m
.47592 .90543 L
s
.47666 .90458 m
.47667 .90459 L
s
.47666 .90458 m
.47666 .90458 L
s
.44577 .7563 m .43971 .75395 L .43569 .7566 L 0 1 .469 r
F
.44577 .7563 m .44402 .75382 L .43971 .75395 L F
.45537 .74865 m .44402 .75382 L .44577 .7563 L 0 1 .459 r
F
0 g
.44577 .7563 m
.44989 .75581 L
s
.44425 .76034 m
.44577 .7563 L
s
.50459 .71932 m .50372 .71892 L .50156 .7234 L 0 1 .401 r
F
0 g
.50156 .7234 m
.50372 .71892 L
s
.50459 .71932 m
.50643 .71406 L
s
.50405 .72459 m
.50459 .71932 L
s
.44776 .79811 m .43676 .79989 L .43965 .80588 L 0 .878 .38 r
F
.44776 .79811 m .43719 .79319 L .43676 .79989 L F
0 g
.43199 .79745 m
.43676 .79989 L
s
.42282 .66002 m .41433 .66672 L .41891 .66571 L 0 1 .374 r
F
0 g
.42356 .66761 m
.42576 .6642 L
s
.42282 .66002 m .41144 .66241 L .41433 .66672 L 0 1 .374 r
F
.42282 .66002 m .41217 .65565 L .41144 .66241 L F
.42282 .66002 m .41609 .64996 L .41217 .65565 L F
.42282 .66002 m .42059 .64915 L .41609 .64996 L F
0 g
.42059 .64915 m
.42348 .65346 L
s
.42282 .66002 m
.42576 .6642 L
s
.42059 .64915 m
.42474 .64353 L
s
.42482 .72362 m .41782 .73171 L .4222 .72974 L 0 1 .379 r
F
.42482 .72362 m .41378 .72835 L .41782 .73171 L F
.4277 .73896 m .4222 .72974 L .41782 .73171 L 0 1 .38 r
F
0 g
.41561 .73795 m
.41782 .73171 L
s
.25786 .95944 m .23873 .9538 L .24137 .95788 L 0 1 .531 r
F
.25786 .95944 m .24258 .95282 L .23873 .9538 L F
.25786 .95944 m .25079 .95524 L .24258 .95282 L F
.26703 .95656 m .25079 .95524 L .25786 .95944 L 0 1 .529 r
F
0 g
.25786 .95944 m
.26508 .96145 L
s
.25786 .95944 m
.26012 .96296 L
s
.47041 .71351 m .46604 .70734 L .46165 .70981 L 0 .902 .333 r
F
.47041 .71351 m .46979 .70892 L .46604 .70734 L F
0 g
.46604 .70734 m
.469 .70199 L
s
.81375 .79584 m .81594 .80462 L .82172 .80445 L 0 .631 .396 r
F
0 g
.81585 .80932 m
.81594 .80462 L
s
.39555 .76434 m .38986 .77015 L .39389 .76839 L 0 1 .501 r
F
.39555 .76434 m .38534 .76856 L .38986 .77015 L F
0 g
.38872 .7743 m
.38986 .77015 L
s
.39389 .76839 m
.39865 .76975 L
s
.46843 .74498 m .45931 .74775 L .45778 .7519 L 0 1 .447 r
F
0 g
.45366 .75267 m
.45778 .7519 L
s
.44691 .71333 m .43973 .72139 L .44411 .71918 L 0 1 .356 r
F
.44691 .71333 m .43586 .71862 L .43973 .72139 L F
.5319 .73211 m .53741 .7449 L .53478 .73712 L 0 .98 .372 r
F
.5319 .73211 m .53367 .74742 L .53655 .75244 L F
.5319 .73211 m .53145 .73976 L .53367 .74742 L F
0 g
.5319 .73211 m
.53192 .73213 L
s
.5318 .73147 m
.5319 .73211 L
s
.52882 .73464 m
.53145 .73976 L
s
.53069 .73319 m
.53145 .73976 L
s
.3367 .97562 m .32162 .96822 L .31829 .96955 L 0 1 .537 r
F
0 g
.31331 .97155 m
.31614 .9725 L
s
.31614 .9725 m
.32145 .97429 L
s
.3367 .97562 m .32952 .97083 L .32162 .96822 L 0 1 .537 r
F
.34447 .97201 m .32952 .97083 L .3367 .97562 L F
0 g
.3367 .97562 m
.34434 .97809 L
s
.3367 .97562 m
.33983 .98034 L
s
.56084 .542 m .5645 .53285 L .56918 .53685 L 0 .424 .16 r
F
0 g
.5645 .53285 m
.5653 .51699 L
s
.56697 .51688 m
.56701 .535 L
s
.59395 .55361 m
.59459 .54799 L
s
.59388 .55421 m
.59395 .55361 L
s
.59382 .55478 m
.59388 .55421 L
s
.44276 .5314 m .43458 .53936 L .43761 .53835 L 0 1 .278 r
F
.44276 .5314 m .43548 .53406 L .43458 .53936 L F
0 g
.4397 .54025 m
.44213 .53706 L
s
.44276 .5314 m .43972 .526 L .43548 .53406 L 0 1 .278 r
F
.44276 .5314 m .44488 .51906 L .43972 .526 L F
0 g
.44213 .53706 m
.44276 .5314 L
s
.51778 .98184 m .50527 .98652 L .51067 .98657 L 0 1 .511 r
F
0 g
.505 .98913 m
.51067 .98657 L
s
.78584 .59343 m .79696 .59414 L .79909 .59787 L 0 .116 0 r
F
0 g
.79696 .59414 m
.80092 .59673 L
s
.51045 .59923 m .51335 .54831 L .51001 .55967 L 0 1 .262 r
F
0 g
.51335 .54831 m
.51573 .55303 L
s
.51335 .54831 m
.51393 .54432 L
s
.58102 .5351 m
.58279 .54105 L
s
.50732 .7005 m
.50733 .70047 L
s
.50568 .70434 m
.50613 .7033 L
s
.43147 .75408 m .42985 .74806 L .42548 .74521 L 0 1 .38 r
F
.46179 .91107 m .46312 .91293 L .4646 .91108 L 0 1 .319 r
F
.46179 .91107 m .45778 .91564 L .46312 .91293 L F
0 g
.46312 .91293 m
.46639 .91257 L
s
.43586 .71862 m .42663 .71142 L .42393 .71742 L 0 1 .368 r
F
.41107 .77043 m .39993 .77353 L .39855 .77526 L 0 1 .319 r
F
.41107 .77043 m .40415 .77162 L .39993 .77353 L F
.41107 .77043 m .40892 .77029 L .40415 .77162 L F
.42123 .76485 m .40892 .77029 L .41107 .77043 L 0 1 .26 r
F
0 g
.40968 .77216 m
.41107 .77043 L
s
.41107 .77043 m
.41549 .76886 L
s
.31111 .95531 m .29283 .95253 L .29548 .95571 L 0 1 .52 r
F
.31111 .95531 m .29644 .95133 L .29283 .95253 L F
.31111 .95531 m .30429 .95252 L .29644 .95133 L F
.31964 .95189 m .30429 .95252 L .31111 .95531 L 0 1 .515 r
F
0 g
.31111 .95531 m
.3187 .95632 L
s
.31111 .95531 m
.31372 .95848 L
s
.41378 .72835 m .40414 .7199 L .40161 .72613 L 0 1 .39 r
F
.41378 .72835 m .40864 .71828 L .40414 .7199 L F
.41378 .72835 m .41277 .7219 L .40864 .71828 L F
.42482 .72362 m .41277 .7219 L .41378 .72835 L 0 1 .379 r
F
0 g
.41126 .73457 m
.41378 .72835 L
s
.41378 .72835 m
.41782 .73171 L
s
.49179 .69783 m .48064 .70201 L .4811 .70593 L 0 .807 .308 r
F
0 g
.477 .70099 m
.48064 .70201 L
s
.48064 .70201 m
.48358 .6971 L
s
.49408 .73188 m .49292 .73097 L .48994 .73414 L 0 1 .417 r
F
.50044 .71692 m .49408 .73188 L .49677 .72801 L 0 1 .404 r
F
.50044 .71692 m .49292 .73097 L .49408 .73188 L F
0 g
.49587 .73316 m
.49675 .7281 L
s
.49313 .73664 m
.49408 .73188 L
s
.50372 .71892 m
.50445 .71416 L
s
.50445 .71416 m
.50459 .71325 L
s
.53405 .7537 m .53239 .7603 L .53418 .76746 L 0 .964 .389 r
F
0 g
.53395 .77118 m
.53418 .76746 L
s
.53405 .7537 m .53233 .7544 L .53239 .7603 L 0 .964 .389 r
F
0 g
.5297 .75526 m
.53239 .7603 L
s
.53233 .7544 m
.53239 .7603 L
s
.53049 .75081 m
.53233 .7544 L
s
.50044 .71692 m .49677 .72801 L .4992 .72193 L 0 1 .404 r
F
.50246 .71825 m .4992 .72193 L .49677 .72801 L 0 1 .402 r
F
0 g
.49675 .7281 m
.49677 .72801 L
s
.49408 .73188 m
.49677 .72801 L
s
.4277 .73896 m .42643 .73285 L .4222 .72974 L 0 1 .38 r
F
.47041 .71351 m .46165 .70981 L .45895 .71547 L 0 .902 .333 r
F
0 g
.45796 .70777 m
.46165 .70981 L
s
.53418 .76746 m
.53468 .76832 L
s
.42187 .67627 m .42214 .6698 L .41891 .66571 L 0 1 .376 r
F
0 g
.42214 .6698 m
.42356 .66761 L
s
.50803 .67336 m
.50803 .67336 L
s
.50295 .69367 m .49943 .69345 L .4952 .69725 L 0 .736 .296 r
F
0 g
.49943 .69345 m
.50275 .69192 L
s
.49943 .69345 m
.50224 .68958 L
s
.53479 .72892 m .53366 .73027 L .53478 .73712 L 0 .95 .365 r
F
0 g
.53366 .73027 m
.53375 .7308 L
s
.53283 .72891 m
.53366 .73027 L
s
.2312 .81057 m .21734 .80271 L .21681 .80723 L 0 1 .537 r
F
.2312 .81057 m .22173 .8021 L .21734 .80271 L F
.2312 .81057 m .22768 .80548 L .22173 .8021 L F
.24192 .80849 m .22768 .80548 L .2312 .81057 L 0 1 .536 r
F
0 g
.23065 .81505 m
.2312 .81057 L
s
.2312 .81057 m
.23701 .81368 L
s
.53982 .72031 m .54692 .73248 L .54325 .72467 L 0 .888 .35 r
F
.53982 .72031 m .54407 .73752 L .54751 .74189 L F
.53982 .72031 m .54072 .72966 L .54407 .73752 L F
0 g
.54146 .71832 m
.54325 .72467 L
s
.54111 .71708 m
.54146 .71832 L
s
.53982 .72031 m .5389 .72228 L .54072 .72966 L 0 .888 .35 r
F
0 g
.5388 .71711 m
.53982 .72031 L
s
.53982 .72031 m
.54325 .72467 L
s
.5357 .71846 m
.5389 .72228 L
s
.42187 .67627 m .41363 .68327 L .41822 .68204 L 0 1 .376 r
F
0 g
.42307 .68367 m
.42512 .68018 L
s
.42187 .67627 m .41039 .67918 L .41363 .68327 L 0 1 .376 r
F
.42187 .67627 m .41068 .6725 L .41039 .67918 L F
.42187 .67627 m .41433 .66672 L .41068 .6725 L F
.42187 .67627 m .41891 .66571 L .41433 .66672 L F
0 g
.41891 .66571 m
.42214 .6698 L
s
.42187 .67627 m
.42512 .68018 L
s
.41891 .66571 m
.42282 .66002 L
s
.43586 .71862 m .42877 .72671 L .43316 .72462 L 0 1 .368 r
F
.43586 .71862 m .42482 .72362 L .42877 .72671 L F
.43586 .71862 m .42393 .71742 L .42482 .72362 L F
.42482 .72362 m .42393 .71742 L .41988 .71406 L 0 1 .379 r
F
0 g
.42393 .71742 m
.42663 .71142 L
s
.42482 .72362 m .41539 .71577 L .41277 .7219 L 0 1 .379 r
F
.42482 .72362 m .41988 .71406 L .41539 .71577 L F
0 g
.4222 .72974 m
.42482 .72362 L
s
.42288 .70806 m .41539 .71577 L .41988 .71406 L 0 1 .379 r
F
.42288 .70806 m .41157 .71216 L .41539 .71577 L F
0 g
.41988 .71406 m
.42393 .71742 L
s
.42288 .70806 m .41099 .70563 L .41157 .71216 L 0 1 .379 r
F
.42288 .70806 m .41398 .69962 L .41099 .70563 L F
.42288 .70806 m .41855 .69816 L .41398 .69962 L F
.42288 .70806 m .42236 .70177 L .41855 .69816 L F
0 g
.42288 .70806 m
.42663 .71142 L
s
.41988 .71406 m
.42288 .70806 L
s
.42236 .70177 m
.42541 .69591 L
s
.50709 .66787 m .5075 .66713 L .5062 .66342 L 0 1 .371 r
F
0 g
.50738 .66679 m
.5075 .66713 L
s
.5075 .66713 m
.50941 .67071 L
s
.53479 .72892 m .54089 .74162 L .53788 .73378 L 0 .95 .365 r
F
.53479 .72892 m .54202 .74847 L .54089 .74162 L F
.53479 .72892 m .54051 .74976 L .54202 .74847 L F
.53479 .72892 m .53741 .7449 L .54051 .74976 L F
.53479 .72892 m .53478 .73712 L .53741 .7449 L F
0 g
.53479 .72892 m
.53506 .72935 L
s
.53447 .72746 m
.53479 .72892 L
s
.53192 .73213 m
.53478 .73712 L
s
.53375 .7308 m
.53478 .73712 L
s
.43611 .76897 m .43415 .76304 L .42968 .76044 L 0 .972 .381 r
F
0 g
.42968 .76044 m
.42976 .76049 L
s
.42968 .76044 m
.42984 .76045 L
s
.42968 .76044 m
.42974 .76041 L
s
.32967 .77371 m .32422 .77951 L .32822 .7784 L 0 1 .519 r
F
.32967 .77371 m .31957 .77631 L .32422 .77951 L F
0 g
.32348 .7843 m
.32422 .77951 L
s
.32822 .7784 m
.33335 .78134 L
s
.37513 .77255 m .36431 .76762 L .36305 .77186 L 0 1 .509 r
F
.37513 .77255 m .36832 .76632 L .36431 .76762 L F
.37513 .77255 m .37296 .76843 L .36832 .76632 L F
0 g
.37386 .77679 m
.37513 .77255 L
s
.38534 .76856 m .37297 .76843 L .37513 .77255 L 0 1 .505 r
F
0 g
.37513 .77255 m
.37978 .77439 L
s
.42189 .69227 m .42176 .6859 L .41822 .68204 L 0 1 .378 r
F
0 g
.42176 .6859 m
.42307 .68367 L
s
.42189 .69227 m .41398 .69962 L .41855 .69816 L 0 1 .378 r
F
.42189 .69227 m .41044 .69577 L .41398 .69962 L F
0 g
.41855 .69816 m
.42236 .70177 L
s
.42189 .69227 m .41029 .68916 L .41044 .69577 L 0 1 .378 r
F
.42189 .69227 m .41363 .68327 L .41029 .68916 L F
.42189 .69227 m .41822 .68204 L .41363 .68327 L F
0 g
.41822 .68204 m
.42176 .6859 L
s
.41855 .69816 m
.42189 .69227 L
s
.42189 .69227 m
.42541 .69591 L
s
.41822 .68204 m
.42187 .67627 L
s
.34651 .73183 m .34007 .73957 L .3442 .73847 L 0 1 .441 r
F
.34651 .73183 m .33613 .73444 L .34007 .73957 L F
0 g
.33838 .74631 m
.34007 .73957 L
s
.3442 .73847 m
.3486 .7434 L
s
.43836 .73325 m .42643 .73285 L .4277 .73896 L 0 1 .369 r
F
.43836 .73325 m .42877 .72671 L .42643 .73285 L F
0 g
.4222 .72974 m
.42643 .73285 L
s
.26932 .7492 m .25851 .73419 L .25648 .74189 L 0 1 .476 r
F
.26932 .7492 m .263 .73347 L .25851 .73419 L F
.26932 .7492 m .26763 .73991 L .263 .73347 L F
.28038 .74694 m .26763 .73991 L .26932 .7492 L 0 1 .472 r
F
0 g
.26729 .75686 m
.26932 .7492 L
s
.26932 .7492 m
.27388 .75542 L
s
.43836 .73325 m .43316 .72462 L .42877 .72671 L 0 1 .369 r
F
0 g
.42482 .72362 m
.42877 .72671 L
s
.42643 .73285 m
.42877 .72671 L
s
.35273 .94955 m .33535 .94916 L .33804 .95163 L 0 1 .504 r
F
.35273 .94955 m .33869 .94775 L .33535 .94916 L F
.35273 .94955 m .34615 .94792 L .33869 .94775 L F
0 g
.35273 .94955 m
.3554 .95201 L
s
.36231 .94475 m .34615 .94791 L .35273 .94955 L 0 1 .49 r
F
0 g
.35273 .94955 m
.36044 .94927 L
s
.50551 .70141 m
.50572 .701 L
s
.45973 .72056 m .45508 .71342 L .45069 .71576 L 0 .946 .345 r
F
.45973 .72056 m .45895 .71547 L .45508 .71342 L F
0 g
.45508 .71342 m
.45796 .70777 L
s
.53743 .725 m .5364 .72666 L .53788 .73378 L 0 .919 .357 r
F
0 g
.5364 .72666 m
.53676 .72835 L
s
.53338 .72237 m
.5364 .72666 L
s
.39046 .73013 m
.39046 .73013 L
s
.69539 .55648 m
.69665 .57878 L
s
.53743 .725 m .54407 .73752 L .54072 .72966 L 0 .919 .357 r
F
.53743 .725 m .54555 .74465 L .54407 .73752 L F
.53743 .725 m .54418 .74628 L .54555 .74465 L F
.53743 .725 m .54089 .74162 L .54418 .74628 L F
.53743 .725 m .53788 .73378 L .54089 .74162 L F
0 g
.53743 .725 m
.53805 .72587 L
s
.53805 .72587 m
.54072 .72966 L
s
.53682 .72271 m
.53743 .725 L
s
.53506 .72935 m
.53788 .73378 L
s
.53676 .72835 m
.53788 .73378 L
s
.53914 .72325 m
.5396 .72514 L
s
.5389 .72228 m
.53914 .72325 L
s
.5396 .72514 m
.54072 .72966 L
s
.70569 .56798 m
.71021 .55816 L
s
.71022 .55816 m .71823 .57898 L .71283 .57453 L 0 .509 .118 r
F
.71022 .55816 m .72389 .57206 L .71823 .57898 L F
0 g
.71022 .55816 m
.71283 .57453 L
s
.50246 .71825 m .50163 .71775 L .4992 .72193 L 0 1 .402 r
F
0 g
.50156 .7234 m
.50246 .71825 L
s
.50246 .71825 m
.50459 .71325 L
s
.50756 .64765 m .50849 .64626 L .50859 .64125 L 0 1 .359 r
F
0 g
.50849 .64626 m
.50978 .65015 L
s
.43836 .73325 m .4277 .73896 L .4318 .74177 L 0 1 .369 r
F
0 g
.42548 .74521 m
.4277 .73896 L
s
.49179 .69783 m .48463 .70624 L .48886 .70274 L 0 .807 .308 r
F
.49179 .69783 m .4811 .70593 L .48463 .70624 L F
.45778 .91564 m .44653 .92006 L .44473 .92186 L 0 1 .376 r
F
.45778 .91564 m .45213 .91739 L .44653 .92006 L F
0 g
.45778 .91564 m
.46095 .91577 L
s
.46179 .91107 m .45213 .91739 L .45778 .91564 L 0 1 .319 r
F
0 g
.45778 .91564 m
.46312 .91293 L
s
.54481 1.01341 m
.54633 1.0166 L
s
.54711 1.01823 m
.54722 1.01847 L
s
.50329 .69414 m
.50345 .69393 L
s
.50345 .69393 m
.5042 .693 L
s
.5042 .693 m
.5042 .69299 L
s
.5042 .69299 m
.5042 .69299 L
s
.5042 .69299 m
.50515 .69181 L
s
.50515 .69181 m
.50515 .69181 L
s
.50515 .69181 m
.50515 .69181 L
s
.50515 .69181 m
.50549 .69139 L
s
.50549 .69139 m
.50571 .69112 L
s
.50571 .69112 m
.50571 .69112 L
s
.50571 .69112 m
.50571 .69112 L
s
.50571 .69112 m
.506 .69075 L
s
.506 .69075 m
.506 .69075 L
s
.506 .69075 m
.506 .69075 L
s
.506 .69075 m
.50612 .6906 L
s
.50612 .6906 m
.50612 .6906 L
s
.50612 .6906 m
.50612 .6906 L
s
.50612 .6906 m
.50612 .6906 L
s
.50612 .6906 m
.50612 .6906 L
s
.50328 .69539 m
.50376 .69458 L
s
.50435 .6933 m
.50481 .69261 L
s
.50296 .69542 m
.50435 .6933 L
s
.50481 .69261 m
.50577 .69114 L
s
.50577 .69114 m
.50612 .6906 L
s
.50612 .6906 m
.50612 .6906 L
s
.50612 .6906 m
.50612 .6906 L
s
.50612 .6906 m
.50612 .6906 L
s
.50612 .6906 m
.50612 .6906 L
s
.50612 .6906 m
.50612 .6906 L
s
.50612 .6906 m
.50612 .6906 L
s
.50606 .69069 m
.50612 .6906 L
s
.50606 .69069 m
.50606 .69069 L
s
.50606 .69069 m
.50606 .69069 L
s
.50605 .69069 m
.50606 .69069 L
s
.50605 .69069 m
.50605 .69069 L
s
.50605 .69069 m
.50605 .69069 L
s
.50604 .69072 m
.50605 .69069 L
s
.50604 .69072 m
.50604 .69072 L
s
.50604 .69072 m
.50604 .69072 L
s
.50594 .69085 m
.50604 .69072 L
s
.50594 .69085 m
.50594 .69085 L
s
.50594 .69085 m
.50594 .69085 L
s
.50589 .69092 m
.50594 .69085 L
s
.50589 .69092 m
.50589 .69092 L
s
.50589 .69092 m
.50589 .69092 L
s
.50585 .69097 m
.50589 .69092 L
s
.50585 .69097 m
.50585 .69097 L
s
.50585 .69097 m
.50585 .69097 L
s
.50556 .69137 m
.50585 .69097 L
s
.50556 .69138 m
.50556 .69137 L
s
.50556 .69138 m
.50556 .69138 L
s
.50555 .69138 m
.50556 .69138 L
s
.50555 .69138 m
.50555 .69138 L
s
.50555 .69138 m
.50555 .69138 L
s
.5042 .69324 m
.50555 .69138 L
s
.50396 .69357 m
.5042 .69324 L
s
.50329 .6945 m
.50396 .69357 L
s
.50328 .69628 m
.50383 .69518 L
s
.50487 .69309 m
.50511 .69262 L
s
.43836 .73325 m .43727 .72742 L .43316 .72462 L 0 1 .369 r
F
0 g
.43316 .72462 m
.43586 .71862 L
s
.45973 .72056 m .45069 .71576 L .4481 .72164 L 0 .946 .345 r
F
0 g
.44691 .71333 m
.45069 .71576 L
s
.50044 .71692 m .49416 .72595 L .49292 .73097 L 0 1 .404 r
F
0 g
.49292 .73097 m
.49384 .72723 L
s
.48994 .73414 m
.49292 .73097 L
s
.41277 .7219 m
.41539 .71577 L
s
.49957 .72129 m
.50163 .71775 L
s
.49942 .72154 m
.49957 .72129 L
s
.4992 .72193 m
.49942 .72154 L
s
.63093 .49472 m
.6313 .49639 L
s
.6313 .49639 m
.6324 .50125 L
s
.6324 .50125 m
.63247 .50156 L
s
.44776 .79811 m .43965 .80588 L .44418 .808 L 0 .878 .38 r
F
0 g
.43946 .81257 m
.43965 .80588 L
s
.44904 .72713 m .43973 .72139 L .43727 .72742 L 0 .986 .357 r
F
.44904 .72713 m .44411 .71918 L .43973 .72139 L F
0 g
.43586 .71862 m
.43973 .72139 L
s
.44904 .72713 m .4481 .72164 L .44411 .71918 L 0 .986 .357 r
F
0 g
.44411 .71918 m
.44691 .71333 L
s
.50709 .66787 m .50232 .66239 L .50487 .66584 L 0 1 .371 r
F
.50709 .66787 m .50101 .65867 L .50232 .66239 L F
.50709 .66787 m .50183 .65716 L .50101 .65867 L F
.50709 .66787 m .50406 .6592 L .50183 .65716 L F
.50709 .66787 m .5062 .66342 L .50406 .6592 L F
0 g
.50659 .66741 m
.50709 .66787 L
s
.50709 .66787 m
.5087 .67201 L
s
.5062 .66342 m
.5077 .66545 L
s
.5062 .66342 m
.50697 .66561 L
s
.50697 .66561 m
.50738 .66679 L
s
.47023 .87325 m .46601 .88137 L .47074 .88345 L 0 .705 .397 r
F
.50586 .69915 m .5012 .71092 L .50401 .70435 L 0 1 .389 r
F
0 g
.50401 .70435 m
.50468 .70248 L
s
.50468 .70248 m
.50508 .70133 L
s
.50508 .70133 m
.50545 .70028 L
s
.50545 .70028 m
.50586 .69915 L
s
.50401 .70435 m
.5043 .70378 L
s
.50586 .69915 m
.50641 .69789 L
s
.50163 .71775 m
.50275 .7126 L
s
.50275 .7126 m
.50284 .7122 L
s
.42127 .76245 m .41061 .76068 L .40902 .76472 L 0 1 .487 r
F
.42127 .76245 m .41482 .75862 L .41061 .76068 L F
.42127 .76245 m .41939 .75938 L .41482 .75862 L F
.43144 .75647 m .41939 .75938 L .42127 .76245 L 0 1 .479 r
F
0 g
.42127 .76245 m
.4247 .76281 L
s
.42012 .76534 m
.42127 .76245 L
s
.2856 .94635 m .28404 .94921 L .28764 .94794 L 0 1 .324 r
F
0 g
.28764 .94794 m
.29577 .94735 L
s
.2856 .94635 m .27639 .94928 L .28404 .94921 L 0 1 .324 r
F
0 g
.28404 .94921 m
.28699 .95073 L
s
.44166 .74765 m .42985 .74806 L .43147 .75408 L 0 .982 .369 r
F
.44166 .74765 m .4318 .74177 L .42985 .74806 L F
0 g
.42548 .74521 m
.42985 .74806 L
s
.50336 .69216 m
.50336 .69215 L
s
.50336 .69215 m
.50495 .69046 L
s
.50495 .69046 m
.50495 .69046 L
s
.50495 .69046 m
.50495 .69046 L
s
.50495 .69046 m
.50576 .6896 L
s
.50576 .6896 m
.50577 .6896 L
s
.50529 .69029 m
.50576 .68961 L
s
.50529 .69029 m
.50529 .69029 L
s
.50529 .69029 m
.50529 .69029 L
s
.50369 .69262 m
.50529 .69029 L
s
.50369 .69262 m
.50369 .69262 L
s
.50369 .69262 m
.50369 .69262 L
s
.50576 .68961 m
.50577 .6896 L
s
.44156 .78364 m .43719 .79319 L .44066 .79024 L 0 .926 .381 r
F
.44776 .79811 m .44066 .79024 L .43719 .79319 L 0 .878 .38 r
F
0 g
.43676 .79989 m
.43719 .79319 L
s
.43267 .79083 m
.43719 .79319 L
s
.4811 .70593 m .46979 .70892 L .47041 .71351 L 0 .856 .32 r
F
0 g
.46604 .70734 m
.46979 .70892 L
s
.46979 .70892 m
.47262 .70356 L
s
.4633 .98621 m .46684 .99048 L .46785 .9886 L 0 1 .541 r
F
.48131 .98819 m .46785 .9886 L .46684 .99048 L 0 1 .54 r
F
0 g
.46684 .99048 m
.47184 .99236 L
s
.46048 .99084 m
.46684 .99048 L
s
.35688 .7291 m .35039 .73678 L .35452 .73563 L 0 1 .435 r
F
.35688 .7291 m .34651 .73183 L .35039 .73678 L F
0 g
.3486 .7434 m
.35039 .73678 L
s
.35452 .73563 m
.35883 .74038 L
s
.48865 .72686 m .48383 .73618 L .487 .73134 L 0 1 .42 r
F
.48865 .72686 m .48049 .73872 L .48383 .73618 L F
.49125 .72951 m .487 .73134 L .48383 .73618 L 0 1 .419 r
F
0 g
.48324 .73663 m
.48383 .73618 L
s
.48253 .7408 m
.48383 .73618 L
s
.29624 .78204 m .28412 .77305 L .28282 .77836 L 0 1 .523 r
F
.29624 .78204 m .28853 .77221 L .28412 .77305 L F
.29624 .78204 m .29372 .77608 L .28853 .77221 L F
0 g
.29493 .78733 m
.29624 .78204 L
s
.30947 .77883 m .29373 .77608 L .29624 .78204 L 0 1 .522 r
F
0 g
.29624 .78204 m
.30205 .78547 L
s
.47736 .73503 m .47212 .74331 L .47561 .73924 L 0 1 .434 r
F
.47736 .73503 m .46843 .74498 L .47212 .74331 L F
.48049 .73872 m .47561 .73924 L .47212 .74331 L 0 1 .433 r
F
0 g
.47111 .74377 m
.47212 .74331 L
s
.47072 .74766 m
.47212 .74331 L
s
.47464 .72624 m .46583 .73428 L .46376 .73612 L 0 0 0 r
F
.47464 .72624 m .46986 .7308 L .46583 .73428 L F
.47464 .72624 m .47364 .72736 L .46986 .7308 L F
.48427 .71653 m .47364 .72736 L .47464 .72624 L F
0 g
.47257 .72809 m
.47464 .72624 L
s
.47464 .72624 m
.47823 .72249 L
s
.7115 .92353 m .70562 .92594 L .70384 .92913 L 0 1 .524 r
F
0 g
.69624 .92952 m
.70384 .92913 L
s
.43836 .73325 m .4318 .74177 L .43602 .73939 L 0 1 .369 r
F
.44166 .74765 m .43602 .73939 L .4318 .74177 L 0 .982 .369 r
F
0 g
.42985 .74806 m
.4318 .74177 L
s
.4277 .73896 m
.4318 .74177 L
s
.50548 .68852 m
.50549 .68852 L
s
.50548 .68853 m
.50549 .68852 L
s
.50295 .69367 m .4952 .69725 L .49233 .70234 L 0 .736 .296 r
F
0 g
.49179 .69783 m
.4952 .69725 L
s
.494 .70567 m
.49711 .70154 L
s
.44166 .74765 m .43147 .75408 L .43569 .7566 L 0 .982 .369 r
F
0 g
.43075 .75664 m
.43147 .75408 L
s
.48049 .73872 m .47919 .73728 L .47561 .73924 L 0 1 .433 r
F
.48865 .72686 m .47919 .73728 L .48049 .73872 L 0 1 .42 r
F
0 g
.47908 .74307 m
.48049 .73872 L
s
.48049 .73872 m
.48324 .73663 L
s
.50672 .6766 m
.50672 .6766 L
s
.58417 .60786 m
.58455 .6005 L
s
.58372 .61682 m
.58417 .60786 L
s
.44904 .72713 m .43727 .72742 L .43836 .73325 L 0 .986 .357 r
F
0 g
.43727 .72742 m
.43973 .72139 L
s
.43316 .72462 m
.43727 .72742 L
s
.50771 .65089 m
.50781 .65305 L
s
.72859 1.07351 m .71903 1.07517 L .71398 1.07677 L 0 .894 .3 r
F
0 g
.70415 1.07726 m
.71398 1.07677 L
s
.49962 .98799 m .49227 .98835 L .4863 .99007 L 0 1 .537 r
F
0 g
.51869 .67488 m
.5187 .67488 L
s
.41157 .71216 m .40414 .7199 L .40864 .71828 L 0 1 .39 r
F
0 g
.40864 .71828 m
.41277 .7219 L
s
.28038 .74694 m .26973 .73237 L .26763 .73991 L 0 1 .472 r
F
.28038 .74694 m .27422 .73162 L .26973 .73237 L F
.28038 .74694 m .27879 .73788 L .27422 .73162 L F
.29144 .74462 m .27879 .73788 L .28038 .74694 L 0 1 .468 r
F
0 g
.27827 .75445 m
.28038 .74694 L
s
.28038 .74694 m
.28487 .75298 L
s
.50612 .66978 m .5065 .66901 L .50487 .66584 L 0 1 .372 r
F
0 g
.5065 .66901 m
.5087 .67201 L
s
.49855 .71533 m .49416 .72595 L .49698 .72018 L 0 1 .405 r
F
.49855 .71533 m .49125 .72951 L .49416 .72595 L F
.50044 .71692 m .49698 .72018 L .49416 .72595 L 0 1 .404 r
F
0 g
.49384 .72723 m
.49416 .72595 L
s
.50293 .69497 m
.50293 .69497 L
s
.50293 .69497 m
.50293 .69497 L
s
.50293 .69497 m
.50323 .69457 L
s
.50323 .69457 m
.50323 .69457 L
s
.50323 .69457 m
.50323 .69457 L
s
.50323 .69457 m
.50329 .6945 L
s
.42624 .59302 m .4286 .58579 L .42755 .58078 L 0 1 .368 r
F
0 g
.4286 .58579 m
.43065 .58324 L
s
.53367 .74742 m
.53405 .7537 L
s
.53554 .75068 m
.53655 .75244 L
s
.53367 .74742 m
.5341 .74817 L
s
.5341 .74817 m
.53554 .75068 L
s
.50044 .71692 m .49967 .71631 L .49698 .72018 L 0 1 .404 r
F
0 g
.4992 .72193 m
.50044 .71692 L
s
.50044 .71692 m
.50284 .7122 L
s
.44156 .78364 m .43928 .7778 L .43476 .77545 L 0 .926 .381 r
F
.46843 .74498 m .46308 .74432 L .45931 .74775 L 0 1 .447 r
F
.46843 .74498 m .46699 .74313 L .46308 .74432 L F
.47736 .73503 m .46699 .74313 L .46843 .74498 L 0 1 .434 r
F
0 g
.46689 .74914 m
.46843 .74498 L
s
.46843 .74498 m
.47111 .74377 L
s
.50529 .68737 m
.50529 .68737 L
s
.50528 .68738 m
.50529 .68737 L
s
.50408 .69863 m
.50439 .6982 L
s
.50398 .69877 m
.50408 .69863 L
s
.41157 .71216 m .40027 .71605 L .40414 .7199 L 0 1 .39 r
F
0 g
.40161 .72613 m
.40414 .7199 L
s
.52104 .68242 m
.52193 .68316 L
s
.52193 .68316 m
.52265 .68377 L
s
.52265 .68377 m
.52445 .6853 L
s
.52104 .68242 m
.52104 .68241 L
s
.52104 .68241 m
.52292 .68175 L
s
.52292 .68175 m
.52331 .68161 L
s
.52331 .68161 m
.52433 .68125 L
s
.50626 .67801 m
.50627 .67801 L
s
.36727 .72623 m .36071 .73386 L .36484 .73265 L 0 1 .427 r
F
.36727 .72623 m .35688 .7291 L .36071 .73386 L F
0 g
.35883 .74038 m
.36071 .73386 L
s
.36484 .73265 m
.36906 .73723 L
s
.49125 .72951 m .49018 .72848 L .487 .73134 L 0 1 .419 r
F
.49855 .71533 m .49018 .72848 L .49125 .72951 L 0 1 .405 r
F
0 g
.48994 .73414 m
.49125 .72951 L
s
.49125 .72951 m
.49416 .72595 L
s
.53405 .7537 m
.53528 .75581 L
s
.5365 .75787 m
.537 .75872 L
s
.47041 .71351 m .45895 .71547 L .45973 .72056 L 0 .902 .333 r
F
0 g
.45508 .71342 m
.45895 .71547 L
s
.45895 .71547 m
.46165 .70981 L
s
.79427 .68095 m .80182 .69665 L .80547 .69246 L 0 1 .504 r
F
0 g
.80182 .69665 m
.80411 .70405 L
s
.49205 .43778 m .48608 .44977 L .48686 .44665 L 0 0 .047 r
F
.49205 .43778 m .49045 .44628 L .48608 .44977 L F
0 g
.48292 .45073 m
.48636 .44475 L
s
.48636 .44475 m
.48805 .4418 L
s
.49205 .43778 m .49703 .43852 L .49045 .44628 L 0 0 .047 r
F
.49205 .43778 m .5022 .42966 L .49703 .43852 L F
0 g
.49855 .71533 m
.5012 .71092 L
s
.49967 .71631 m
.50103 .7115 L
s
.50103 .7115 m
.5012 .71092 L
s
.4939 .7058 m .48352 .71765 L .48427 .71653 L 0 0 0 r
F
.4939 .7058 m .48598 .71521 L .48352 .71765 L F
.4939 .7058 m .49001 .71083 L .48598 .71521 L F
.4939 .7058 m .4934 .7068 L .49001 .71083 L F
0 g
.4939 .7058 m
.494 .70567 L
s
.49217 .70752 m
.4939 .7058 L
s
.45973 .72056 m .4481 .72164 L .44904 .72713 L 0 .946 .345 r
F
0 g
.4481 .72164 m
.45069 .71576 L
s
.44411 .71918 m
.4481 .72164 L
s
.50295 .69367 m .49605 .70377 L .50008 .69876 L 0 .736 .296 r
F
.50295 .69367 m .49273 .70531 L .49605 .70377 L F
.50295 .69367 m .49233 .70234 L .49273 .70531 L F
0 g
.50289 .69378 m
.50295 .69367 L
s
.50234 .69474 m
.50234 .69474 L
s
.50234 .69474 m
.50234 .69474 L
s
.50234 .69474 m
.50275 .69402 L
s
.50182 .70185 m
.50288 .70034 L
s
.50224 .69589 m
.50293 .69497 L
s
.50224 .69589 m
.50224 .69589 L
s
.50224 .69589 m
.50224 .69589 L
s
.50295 .69367 m
.50299 .69364 L
s
.41157 .71216 m .39961 .70929 L .40027 .71605 L 0 1 .39 r
F
.41157 .71216 m .40255 .70317 L .39961 .70929 L F
.41157 .71216 m .40712 .70177 L .40255 .70317 L F
.41157 .71216 m .41099 .70563 L .40712 .70177 L F
0 g
.41157 .71216 m
.41539 .71577 L
s
.40864 .71828 m
.41157 .71216 L
s
.50517 .68616 m
.50518 .68615 L
s
.50516 .68617 m
.50518 .68615 L
s
.50612 .66978 m .50069 .66561 L .50363 .66833 L 0 1 .372 r
F
.50612 .66978 m .49906 .66244 L .50069 .66561 L F
.50612 .66978 m .49982 .66093 L .49906 .66244 L F
.50612 .66978 m .50232 .66239 L .49982 .66093 L F
.50612 .66978 m .50487 .66584 L .50232 .66239 L F
0 g
.50612 .66978 m
.50803 .67336 L
s
.50584 .66773 m
.50604 .66811 L
s
.50604 .66811 m
.5065 .66901 L
s
.49083 .89433 m .48573 .89725 L .4811 .90073 L 0 1 .292 r
F
0 g
.49083 .89433 m
.49418 .8934 L
s
.49281 .89057 m .49083 .89433 L .49514 .89103 L 0 1 .228 r
F
.49281 .89057 m .48573 .89725 L .49083 .89433 L F
.76847 .76562 m .77707 .77602 L .77982 .77445 L 0 .376 .306 r
F
0 g
.77168 .77441 m
.77707 .77602 L
s
.77707 .77602 m
.77834 .7797 L
s
.50588 .67943 m
.50588 .67943 L
s
.49698 .72018 m
.49855 .71533 L
s
.49826 .71833 m
.49967 .71631 L
s
.49698 .72018 m
.49826 .71833 L
s
.5398 .43569 m .55181 .41983 L .55289 .42335 L 0 .011 .075 r
F
.5398 .43569 m .54621 .42511 L .55181 .41983 L F
0 g
.55181 .41983 m
.55196 .41942 L
s
.54621 .42511 m
.5502 .41447 L
s
.54621 .42511 m
.55181 .41983 L
s
.50756 .64765 m .50859 .64125 L .50779 .63597 L 0 1 .359 r
F
0 g
.50859 .64125 m
.5099 .64421 L
s
.50849 .64626 m
.50859 .64125 L
s
.40027 .71605 m .39289 .7238 L .39739 .72227 L 0 1 .4 r
F
0 g
.39739 .72227 m
.40161 .72613 L
s
.52131 .67153 m .52661 .66939 L .52344 .67119 L 0 0 .086 r
F
.52131 .67153 m .52947 .66532 L .52661 .66939 L F
.52131 .67153 m .53011 .66169 L .52947 .66532 L F
0 g
.5187 .67488 m
.52131 .67153 L
s
.34564 .79263 m .33381 .79122 L .333 .79361 L 0 1 .478 r
F
.34564 .79263 m .33782 .79017 L .33381 .79122 L F
.34564 .79263 m .3429 .79078 L .33782 .79017 L F
.35539 .78941 m .3429 .79078 L .34564 .79263 L 0 1 .46 r
F
0 g
.34482 .79501 m
.34564 .79263 L
s
.34564 .79263 m
.35058 .79298 L
s
.50508 .68491 m
.50515 .68488 L
s
.50501 .68499 m
.50515 .68488 L
s
.50756 .64765 m .50465 .64097 L .50592 .64539 L 0 1 .359 r
F
.50756 .64765 m .50475 .63596 L .50465 .64097 L F
.50756 .64765 m .50615 .6337 L .50475 .63596 L F
.50756 .64765 m .50779 .63597 L .50615 .6337 L F
0 g
.50756 .64765 m
.50771 .65089 L
s
.4633 .98621 m .44843 .98707 L .453 .98945 L 0 1 .541 r
F
0 g
.44632 .98981 m
.453 .98945 L
s
.37811 .72307 m .37117 .73076 L .37549 .72943 L 0 1 .419 r
F
.37811 .72307 m .36727 .72623 L .37117 .73076 L F
0 g
.36907 .73722 m
.37117 .73076 L
s
.37549 .72943 m
.37976 .73377 L
s
.40027 .71605 m .38897 .71973 L .39289 .7238 L 0 1 .4 r
F
0 g
.39046 .73013 m
.39289 .7238 L
s
.4457 .76184 m .43415 .76304 L .43611 .76897 L 0 .938 .369 r
F
.4457 .76184 m .43569 .7566 L .43415 .76304 L F
0 g
.42976 .76049 m
.43415 .76304 L
s
.43418 .76064 m
.43561 .75682 L
s
.5052 .68357 m
.50521 .68357 L
s
.44166 .74765 m .44025 .74192 L .43602 .73939 L 0 .982 .369 r
F
0 g
.50535 .68222 m
.50535 .68221 L
s
.44904 .72713 m .43836 .73325 L .44235 .73571 L 0 .986 .357 r
F
0 g
.43602 .73939 m
.43836 .73325 L
s
.37491 .78256 m .36983 .78592 L .37369 .78443 L 0 1 .408 r
F
.37491 .78256 m .36514 .78606 L .36983 .78592 L F
0 g
.3692 .78793 m
.36983 .78592 L
s
.37369 .78443 m
.37869 .78402 L
s
.38896 .71973 m .38196 .7274 L .38628 .726 L 0 1 .41 r
F
0 g
.38628 .726 m
.39046 .73013 L
s
.69649 .93811 m .70744 .93439 L .704 .9345 L 0 1 .482 r
F
0 g
.71344 .93059 m
.71366 .93045 L
s
.71366 .93045 m
.71367 .93045 L
s
.71154 .92477 m .704 .9345 L .70744 .93439 L 0 1 .492 r
F
0 g
.70744 .93439 m
.71344 .93059 L
s
.70486 .93807 m
.70744 .93439 L
s
.38896 .71973 m .37811 .72307 L .38196 .7274 L 0 1 .41 r
F
0 g
.37976 .73377 m
.38196 .7274 L
s
.53514 .98795 m .5291 .98716 L .53647 .99468 L 0 .322 .328 r
F
0 g
.5265 .98381 m
.5291 .98716 L
s
.52764 .98603 m
.5291 .98716 L
s
.487 .73134 m
.49018 .72848 L
s
.48427 .71653 m .4759 .72528 L .47364 .72736 L 0 0 0 r
F
.48427 .71653 m .47993 .7214 L .4759 .72528 L F
.48427 .71653 m .48352 .71765 L .47993 .7214 L F
0 g
.48427 .71653 m
.48766 .7125 L
s
.482 .71861 m
.48427 .71653 L
s
.29144 .74462 m .28096 .73049 L .27879 .73788 L 0 1 .468 r
F
.29144 .74462 m .28545 .72972 L .28096 .73049 L F
.29144 .74462 m .28994 .73578 L .28545 .72972 L F
0 g
.28926 .75199 m
.29144 .74462 L
s
.30504 .74168 m .28995 .73578 L .29144 .74462 L 0 1 .462 r
F
0 g
.29144 .74462 m
.29661 .7503 L
s
.4811 .70593 m .47405 .71452 L .47828 .71129 L 0 .856 .32 r
F
.4811 .70593 m .47041 .71351 L .47405 .71452 L F
0 g
.52468 .68178 m
.52468 .68178 L
s
.52438 .68132 m
.52468 .68178 L
s
.52438 .68132 m
.52438 .68132 L
s
.52438 .68132 m
.52438 .68132 L
s
.52433 .68125 m
.52438 .68132 L
s
.41099 .70563 m
.41398 .69962 L
s
.50522 .67175 m .50557 .67096 L .50363 .66833 L 0 1 .373 r
F
0 g
.50557 .67096 m
.50803 .67336 L
s
.49018 .72848 m
.49175 .72363 L
s
.72859 1.07351 m .72623 1.07613 L .73613 1.07413 L 0 .894 .3 r
F
0 g
.71675 1.07726 m
.72623 1.07613 L
s
.51778 .98184 m .52341 .98304 L .52318 .98189 L 0 1 .511 r
F
0 g
.52341 .98304 m
.52481 .98278 L
s
.52275 .98329 m
.52341 .98304 L
s
.51777 .97068 m
.5205 .97413 L
s
.5205 .97413 m
.52139 .97527 L
s
.52197 .976 m
.52239 .97653 L
s
.52239 .97653 m
.52275 .97699 L
s
.51777 .97068 m
.52003 .97213 L
s
.52003 .97213 m
.5202 .97224 L
s
.5209 .97268 m
.52201 .9734 L
s
.46498 .74029 m .45931 .74775 L .46308 .74432 L 0 1 .448 r
F
.46498 .74029 m .45537 .74865 L .45931 .74775 L F
0 g
.45778 .7519 m
.45931 .74775 L
s
.72968 .92361 m .74093 .91883 L .73722 .91889 L 0 1 .513 r
F
.74393 .90641 m .74093 .91883 L .74794 .91321 L 0 1 .509 r
F
.74393 .90641 m .73722 .91889 L .74093 .91883 L F
0 g
.73873 .92366 m
.74093 .91883 L
s
.4649 .84989 m .45551 .85246 L .45961 .85841 L 0 .743 .388 r
F
.4649 .84989 m .45424 .84552 L .45551 .85246 L F
0 g
.45065 .85026 m
.45551 .85246 L
s
.48865 .72686 m .48084 .7328 L .47919 .73728 L 0 1 .42 r
F
0 g
.47561 .73924 m
.47919 .73728 L
s
.45585 .83538 m .45239 .82953 L .44771 .82749 L 0 .803 .39 r
F
.44166 .74765 m .43569 .7566 L .43971 .75395 L 0 .982 .369 r
F
.44163 .75002 m .43569 .7566 L .43971 .75395 L 0 1 .471 r
F
.44163 .75002 m .43144 .75647 L .43569 .7566 L F
0 g
.43147 .75408 m
.4334 .75523 L
s
.4416 .7524 m .43569 .7566 L .43971 .75395 L 0 .879 .205 r
F
.4416 .7524 m .43141 .75887 L .43569 .7566 L F
0 g
.43977 .75391 m
.43985 .75386 L
s
.43985 .75386 m
.43996 .7538 L
s
.4457 .76184 m .43971 .75395 L .43569 .7566 L 0 .938 .369 r
F
0 g
.43546 .75673 m
.43569 .7566 L
s
.43561 .75682 m
.43569 .7566 L
s
.43421 .75825 m
.43569 .7566 L
s
.43415 .76304 m
.43569 .7566 L
s
.50301 .69568 m
.50328 .69539 L
s
.50522 .67175 m .4992 .66886 L .50249 .67085 L 0 1 .373 r
F
0 g
.50589 .66965 m
.50612 .66978 L
s
.50522 .67175 m .49726 .66622 L .4992 .66886 L 0 1 .373 r
F
.50522 .67175 m .49796 .66471 L .49726 .66622 L F
.50522 .67175 m .50069 .66561 L .49796 .66471 L F
.50522 .67175 m .50363 .66833 L .50069 .66561 L F
0 g
.50487 .66584 m
.50497 .66593 L
s
.50497 .66593 m
.50659 .66741 L
s
.50487 .66584 m
.50503 .66616 L
s
.50503 .66616 m
.50584 .66773 L
s
.50522 .67175 m
.50742 .67475 L
s
.50956 .53111 m .50613 .52776 L .50645 .53525 L 0 1 .195 r
F
.50956 .53111 m .50911 .5119 L .50613 .52776 L F
.51001 .55967 m .50956 .53111 L .50694 .54907 L 0 1 .241 r
F
.49273 .70531 m .48886 .70274 L .48463 .70624 L 0 .781 .308 r
F
.49273 .70531 m .49233 .70234 L .48886 .70274 L F
0 g
.48886 .70274 m
.49179 .69783 L
s
.45465 .81239 m .44421 .81481 L .4474 .82072 L 0 .827 .38 r
F
.45465 .81239 m .44418 .808 L .44421 .81481 L F
0 g
.43946 .81257 m
.44421 .81481 L
s
.4457 .76184 m .43611 .76897 L .4404 .77122 L 0 .938 .369 r
F
0 g
.43476 .77545 m
.43611 .76897 L
s
.43987 .75394 m
.44003 .75394 L
s
.44003 .75394 m
.44029 .75393 L
s
.45537 .74865 m .44573 .7498 L .44402 .75382 L 0 1 .459 r
F
0 g
.44402 .75382 m
.44562 .75006 L
s
.44029 .75393 m
.44402 .75382 L
s
.43996 .7538 m
.44405 .75145 L
s
.52947 .66532 m .53321 .65687 L .53671 .65406 L 0 .104 .11 r
F
.52947 .66532 m .53011 .66169 L .53321 .65687 L F
0 g
.53102 .65629 m
.53321 .65687 L
s
.52798 .66204 m
.53011 .66169 L
s
.53011 .66169 m
.53321 .65687 L
s
.68771 .92442 m .69859 .92627 L .69508 .92432 L 0 1 .527 r
F
0 g
.68771 .92442 m
.68921 .92094 L
s
.50039 .98387 m .49962 .98799 L .50527 .98652 L 0 1 .53 r
F
.50039 .98387 m .49227 .98835 L .49962 .98799 L F
0 g
.49962 .98799 m
.505 .98913 L
s
.50826 .6303 m .50968 .62804 L .5105 .62288 L 0 1 .333 r
F
0 g
.50968 .62804 m
.51098 .63101 L
s
.50911 .5119 m .50531 .51359 L .50564 .51847 L 0 1 .143 r
F
.50911 .5119 m .50866 .49981 L .50531 .51359 L F
.76424 .92994 m .76016 .9388 L .7677 .93682 L 0 1 .529 r
F
.76424 .92994 m .75641 .93745 L .76016 .9388 L F
0 g
.75746 .94269 m
.76016 .9388 L
s
.53181 .67649 m
.5352 .68153 L
s
.40027 .71605 m .38823 .71276 L .38897 .71973 L 0 1 .4 r
F
0 g
.38897 .71973 m
.39289 .7238 L
s
.40027 .71605 m .39111 .70653 L .38823 .71276 L 0 1 .4 r
F
.40027 .71605 m .39568 .70521 L .39111 .70653 L F
.40027 .71605 m .39961 .70929 L .39568 .70521 L F
0 g
.40027 .71605 m
.40414 .7199 L
s
.39739 .72227 m
.40027 .71605 L
s
.50295 .69456 m .49605 .70377 L .50008 .69876 L 0 1 .387 r
F
.50295 .69456 m .49272 .70677 L .49605 .70377 L F
.50295 .69456 m .49232 .70574 L .49272 .70677 L F
0 g
.50172 .69586 m
.50234 .69474 L
s
.49273 .70531 m .48463 .70624 L .4819 .71176 L 0 .781 .308 r
F
.49273 .70531 m .4819 .71176 L .4825 .71561 L F
.50295 .69456 m .49519 .70155 L .49232 .70574 L 0 1 .387 r
F
.50295 .69456 m .49942 .69698 L .49519 .70155 L F
0 g
.49279 .70152 m
.4952 .69725 L
s
.50095 .6976 m
.50095 .6976 L
s
.50295 .69456 m .50274 .69399 L .49942 .69698 L 0 1 .387 r
F
0 g
.50095 .6976 m
.50224 .69589 L
s
.50295 .69456 m
.50329 .69414 L
s
.50274 .69399 m
.50369 .69262 L
s
.50478 .67279 m .50488 .67254 L .50249 .67085 L 0 1 .374 r
F
0 g
.50526 .67053 m
.50557 .67096 L
s
.50488 .67254 m
.50742 .67475 L
s
.53655 .75244 m
.537 .75872 L
s
.4015 .9786 m .40286 .98386 L .40502 .98222 L 0 1 .539 r
F
.4015 .9786 m .39584 .98259 L .40286 .98386 L F
.41938 .98569 m .40502 .98222 L .40286 .98386 L 0 1 .54 r
F
0 g
.40286 .98386 m
.40698 .98721 L
s
.50353 .69799 m
.5039 .69744 L
s
.50455 .69885 m
.50494 .69782 L
s
.50478 .67279 m .49877 .66986 L .50217 .67164 L 0 1 .374 r
F
0 g
.50485 .67163 m
.50522 .67175 L
s
.50478 .67279 m .49638 .66817 L .49877 .66986 L 0 1 .374 r
F
.50478 .67279 m .49658 .66771 L .49638 .66817 L F
.50478 .67279 m .4992 .66886 L .49658 .66771 L F
.50478 .67279 m .50249 .67085 L .4992 .66886 L F
0 g
.50363 .66833 m
.50529 .6693 L
s
.50529 .6693 m
.50589 .66965 L
s
.50478 .67279 m
.50724 .67519 L
s
.75777 .66143 m
.75928 .6645 L
s
.75742 .66073 m
.75777 .66143 L
s
.75701 .6599 m
.75742 .66073 L
s
.75646 .65878 m
.75701 .6599 L
s
.44904 .72713 m .44235 .73571 L .44658 .73316 L 0 .986 .357 r
F
.45973 .72056 m .44904 .72713 L .45291 .72919 L 0 .946 .345 r
F
.45185 .7407 m .44235 .73571 L .44025 .74192 L 0 .945 .357 r
F
.45185 .7407 m .44658 .73316 L .44235 .73571 L F
0 g
.43836 .73325 m
.44235 .73571 L
s
.37819 .97393 m .37746 .98026 L .38074 .97827 L 0 1 .538 r
F
.37819 .97393 m .36965 .97877 L .37746 .98026 L F
.39584 .98259 m .38074 .97827 L .37746 .98026 L 0 1 .539 r
F
0 g
.37746 .98026 m
.38076 .9844 L
s
.5476 .79324 m
.54799 .79375 L
s
.57924 .41394 m .58601 .40906 L .59257 .40995 L 0 .277 .096 r
F
0 g
.58601 .40906 m
.58957 .39991 L
s
.50229 .6944 m
.50229 .6944 L
s
.50229 .6944 m
.50274 .69399 L
s
.30504 .74168 m .29296 .7284 L .28995 .73578 L 0 1 .462 r
F
.30504 .74168 m .29848 .72742 L .29296 .7284 L F
.30504 .74168 m .30365 .73311 L .29848 .72742 L F
0 g
.30202 .74904 m
.30504 .74168 L
s
.3154 .73935 m .30366 .73311 L .30504 .74168 L 0 1 .458 r
F
0 g
.30504 .74168 m
.30916 .74735 L
s
.42624 .59302 m .41745 .59942 L .42146 .59887 L 0 1 .368 r
F
0 g
.42501 .60123 m
.42748 .59815 L
s
.42624 .59302 m .4164 .59441 L .41745 .59942 L 0 1 .368 r
F
.42624 .59302 m .41901 .58718 L .4164 .59441 L F
.42624 .59302 m .42379 .58134 L .41901 .58718 L F
.42624 .59302 m .42755 .58078 L .42379 .58134 L F
0 g
.42624 .59302 m
.42748 .59815 L
s
.42755 .58078 m
.43241 .57476 L
s
.42755 .58078 m
.4286 .58579 L
s
.65333 .50068 m .65575 .49392 L .65225 .48601 L 0 .284 .268 r
F
0 g
.65166 .4842 m
.65225 .48601 L
s
.47041 .71351 m .46348 .72215 L .46771 .71917 L 0 .902 .333 r
F
.47041 .71351 m .45973 .72056 L .46348 .72215 L F
.28492 .79993 m .27953 .80427 L .28379 .8033 L 0 1 .521 r
F
.28492 .79993 m .27415 .80212 L .27953 .80427 L F
0 g
.27924 .80775 m
.27953 .80427 L
s
.28379 .8033 m
.28976 .8051 L
s
.46603 .47478 m .47146 .46587 L .47457 .46115 L 0 0 0 r
F
0 g
.47146 .46587 m
.47453 .46063 L
s
.30224 .96971 m .28358 .96192 L .2864 .96714 L 0 1 .537 r
F
.30224 .96971 m .28719 .96076 L .28358 .96192 L F
.30224 .96971 m .29519 .9641 L .28719 .96076 L F
.31075 .96649 m .29519 .9641 L .30224 .96971 L 0 1 .536 r
F
0 g
.30224 .96971 m
.31 .9729 L
s
.30224 .96971 m
.30503 .97491 L
s
.47736 .73503 m .46874 .73892 L .46699 .74313 L 0 1 .434 r
F
.50418 .67438 m .50448 .67357 L .50217 .67164 L 0 1 .374 r
F
0 g
.50464 .67236 m
.50488 .67254 L
s
.50448 .67357 m
.50724 .67519 L
s
.49281 .89057 m .49514 .89103 L .4958 .88954 L 0 1 .228 r
F
0 g
.49083 .89433 m
.49514 .89103 L
s
.49514 .89103 m
.49852 .88956 L
s
.45537 .74865 m .44975 .74692 L .44573 .7498 L 0 1 .459 r
F
.45537 .74865 m .45388 .74643 L .44975 .74692 L F
.46498 .74029 m .45388 .74643 L .45537 .74865 L 0 1 .448 r
F
0 g
.45537 .74865 m
.45931 .74775 L
s
.45366 .75267 m
.45537 .74865 L
s
.46308 .74432 m
.46699 .74313 L
s
.45185 .7407 m .44025 .74192 L .44166 .74765 L 0 .945 .357 r
F
0 g
.44025 .74192 m
.44235 .73571 L
s
.43602 .73939 m
.44025 .74192 L
s
.33977 .77101 m .33423 .7767 L .33823 .77555 L 0 1 .518 r
F
.33977 .77101 m .32967 .77371 L .33423 .7767 L F
0 g
.33335 .78134 m
.33423 .7767 L
s
.33823 .77555 m
.34324 .7783 L
s
.44385 .91963 m .44473 .92186 L .44653 .92006 L 0 1 .357 r
F
.44385 .91963 m .43905 .92402 L .44473 .92186 L F
0 g
.44473 .92186 m
.44791 .92199 L
s
.53741 .7449 m
.53799 .74993 L
s
.53741 .7449 m
.53993 .74886 L
s
.40621 .75968 m .40008 .76562 L .40429 .76369 L 0 1 .495 r
F
.40621 .75968 m .39555 .76434 L .40008 .76562 L F
0 g
.39866 .76974 m
.40008 .76562 L
s
.40429 .76369 m
.40902 .76472 L
s
.32819 .94851 m .32701 .95272 L .33034 .9513 L 0 1 .507 r
F
0 g
.33034 .9513 m
.33804 .95163 L
s
.32819 .94851 m .31964 .95189 L .32701 .95272 L 0 1 .507 r
F
0 g
.32701 .95272 m
.32996 .95538 L
s
.4811 .70593 m
.48136 .70595 L
s
.48136 .70595 m
.48463 .70624 L
s
.50247 .6931 m .49519 .70155 L .49942 .69698 L 0 1 .386 r
F
0 g
.5027 .69492 m
.50295 .69456 L
s
.50268 .69602 m
.5028 .6959 L
s
.50247 .6931 m .49177 .70415 L .49519 .70155 L 0 1 .386 r
F
.50247 .6931 m .49145 .70306 L .49177 .70415 L F
.50247 .6931 m .49451 .69917 L .49145 .70306 L F
0 g
.48886 .70274 m
.49199 .70237 L
s
.50247 .6931 m .4989 .69508 L .49451 .69917 L 0 1 .386 r
F
0 g
.50129 .69699 m
.50131 .69696 L
s
.50131 .69696 m
.50131 .69696 L
s
.5014 .69737 m
.50268 .69602 L
s
.50066 .69799 m
.50087 .69771 L
s
.50087 .69771 m
.50095 .6976 L
s
.50065 .69799 m
.50066 .69799 L
s
.50062 .69804 m
.50065 .69799 L
s
.50051 .69818 m
.50062 .69804 L
s
.50074 .69806 m
.50082 .69797 L
s
.50082 .69797 m
.50106 .69773 L
s
.50106 .69773 m
.50127 .6975 L
s
.50127 .6975 m
.50127 .6975 L
s
.50127 .6975 m
.5014 .69737 L
s
.5014 .69737 m
.5014 .69737 L
s
.50095 .69748 m
.50129 .69699 L
s
.50247 .6931 m .50232 .69248 L .4989 .69508 L 0 1 .386 r
F
0 g
.50247 .6931 m
.50336 .69216 L
s
.50131 .69696 m
.5027 .69492 L
s
.50232 .69248 m
.50548 .68853 L
s
.45973 .72056 m .45291 .72919 L .45714 .72644 L 0 .946 .345 r
F
.63381 .4386 m .63426 .44353 L .63141 .43629 L 0 .379 0 r
F
.63381 .4386 m .64118 .45671 L .63426 .44353 L F
.63381 .4386 m .64757 .46701 L .64118 .45671 L F
0 g
.63983 .44889 m
.64028 .44899 L
s
.63354 .43834 m
.63381 .4386 L
s
.63006 .43032 m
.63381 .4386 L
s
.48865 .72686 m .48433 .72827 L .48084 .7328 L 0 1 .42 r
F
.48865 .72686 m .48768 .72573 L .48433 .72827 L F
0 g
.487 .73134 m
.48865 .72686 L
s
.48865 .72686 m
.49175 .72363 L
s
.47023 .87325 m .46592 .86732 L .46119 .86526 L 0 .705 .397 r
F
.51136 .61231 m .51327 .60899 L .51481 .60374 L 0 1 .249 r
F
0 g
.51327 .60899 m
.51458 .61078 L
s
.50418 .67438 m .4975 .67306 L .50119 .67416 L 0 1 .374 r
F
.50418 .67438 m .49518 .67112 L .4975 .67306 L F
.50418 .67438 m .49578 .66964 L .49518 .67112 L F
.50418 .67438 m .49877 .66986 L .49578 .66964 L F
.50418 .67438 m .50217 .67164 L .49877 .66986 L F
0 g
.5025 .67086 m
.50431 .67145 L
s
.50431 .67145 m
.50485 .67163 L
s
.50217 .67164 m
.50228 .67173 L
s
.50249 .67085 m
.50464 .67236 L
s
.50236 .67172 m
.50478 .67279 L
s
.50217 .67164 m
.5022 .67165 L
s
.5022 .67165 m
.50236 .67172 L
s
.50418 .67438 m
.50672 .6766 L
s
.50249 .67085 m
.50249 .67085 L
s
.50363 .66833 m
.50502 .67021 L
s
.50502 .67021 m
.50526 .67053 L
s
.50249 .67085 m
.5025 .67086 L
s
.2672 .95223 m .24836 .95135 L .25087 .95341 L 0 1 .384 r
F
.2672 .95223 m .25221 .95037 L .24836 .95135 L F
.2672 .95223 m .26031 .95075 L .25221 .95037 L F
.27639 .94928 m .26031 .95075 L .2672 .95223 L 0 1 .356 r
F
0 g
.2672 .95223 m
.27505 .95238 L
s
.2672 .95223 m
.26966 .95428 L
s
.45585 .83538 m .45424 .84552 L .45664 .84223 L 0 .803 .39 r
F
.4649 .84989 m .45664 .84223 L .45424 .84552 L 0 .743 .388 r
F
0 g
.45424 .84552 m
.45551 .85246 L
s
.44956 .84347 m
.45424 .84552 L
s
.73501 .58104 m .74697 .56909 L .74857 .57921 L 0 .347 .088 r
F
0 g
.74697 .56909 m
.75151 .56763 L
s
.45185 .7407 m .45065 .7353 L .44658 .73316 L 0 .945 .357 r
F
0 g
.44658 .73316 m
.44904 .72713 L
s
.41044 .69577 m .40255 .70317 L .40712 .70177 L 0 1 .389 r
F
.41044 .69577 m .39898 .6991 L .40255 .70317 L F
0 g
.40712 .70177 m
.41099 .70563 L
s
.41044 .69577 m .39881 .69228 L .39898 .6991 L 0 1 .389 r
F
.41044 .69577 m .40213 .68627 L .39881 .69228 L F
.41044 .69577 m .40673 .68508 L .40213 .68627 L F
.41044 .69577 m .41029 .68916 L .40673 .68508 L F
0 g
.41044 .69577 m
.41398 .69962 L
s
.40712 .70177 m
.41044 .69577 L
s
.41029 .68916 m
.41363 .68327 L
s
.41938 .98569 m .4121 .983 L .40502 .98222 L 0 1 .54 r
F
.42414 .98145 m .41938 .98569 L .42617 .98641 L F
.42414 .98145 m .4121 .983 L .41938 .98569 L F
0 g
.41938 .98569 m
.42348 .98904 L
s
.44776 .79811 m .44519 .79235 L .44066 .79024 L 0 .878 .38 r
F
.39584 .98259 m .38863 .97927 L .38074 .97827 L 0 1 .539 r
F
0 g
.39584 .98259 m
.39912 .98673 L
s
.4015 .9786 m .38863 .97927 L .39584 .98259 L 0 1 .539 r
F
0 g
.39584 .98259 m
.40286 .98386 L
s
.50509 .69275 m
.50576 .69167 L
s
.50576 .69167 m
.50576 .69167 L
s
.50494 .69287 m
.50576 .69167 L
s
.3154 .73935 m .30577 .72609 L .30366 .73311 L 0 1 .458 r
F
.3154 .73935 m .30998 .7253 L .30577 .72609 L F
.3154 .73935 m .3141 .73099 L .30998 .7253 L F
.32576 .73695 m .3141 .73099 L .3154 .73935 L 0 1 .453 r
F
0 g
.31328 .74636 m
.3154 .73935 L
s
.3154 .73935 m
.31946 .74485 L
s
.78638 .88394 m .78133 .89288 L .7805 .89962 L 0 1 .51 r
F
0 g
.77292 .90556 m
.7805 .89962 L
s
.38534 .76856 m .37449 .76426 L .37297 .76843 L 0 1 .505 r
F
.38534 .76856 m .37869 .76283 L .37449 .76426 L F
.38534 .76856 m .38334 .76467 L .37869 .76283 L F
.39555 .76434 m .38334 .76467 L .38534 .76856 L 0 1 .501 r
F
0 g
.38381 .77272 m
.38534 .76856 L
s
.38534 .76856 m
.38986 .77015 L
s
.48631 .72396 m .48084 .7328 L .48433 .72827 L 0 1 .421 r
F
.48631 .72396 m .47736 .73503 L .48084 .7328 L F
0 g
.47919 .73728 m
.48084 .7328 L
s
.38896 .71973 m .3773 .71589 L .37811 .72307 L 0 1 .41 r
F
.38896 .71973 m .37999 .70962 L .3773 .71589 L F
.38896 .71973 m .38438 .70842 L .37999 .70962 L F
.38896 .71973 m .38823 .71276 L .38438 .70842 L F
0 g
.38628 .726 m
.38896 .71973 L
s
.50294 .69654 m
.50328 .69628 L
s
.44776 .79811 m .44418 .808 L .44732 .80482 L 0 .878 .38 r
F
.45465 .81239 m .44732 .80482 L .44418 .808 L 0 .827 .38 r
F
0 g
.44418 .808 m
.44421 .81481 L
s
.43965 .80588 m
.44418 .808 L
s
.50211 .69152 m .49451 .69917 L .4989 .69508 L 0 1 .385 r
F
0 g
.5023 .69331 m
.50247 .6931 L
s
.50211 .69152 m .49105 .70137 L .49451 .69917 L 0 1 .385 r
F
.50211 .69152 m .49082 .70022 L .49105 .70137 L F
.50211 .69152 m .49404 .69665 L .49082 .70022 L F
0 g
.50037 .69837 m
.50038 .69835 L
s
.50041 .69832 m
.50051 .69818 L
s
.50038 .69835 m
.50041 .69832 L
s
.50032 .69844 m
.50037 .69837 L
s
.50032 .69844 m
.50032 .69844 L
s
.50028 .69849 m
.50032 .69844 L
s
.50015 .69866 m
.50016 .69865 L
s
.5002 .69859 m
.50028 .69849 L
s
.50016 .69865 m
.5002 .69859 L
s
.50056 .69825 m
.50074 .69806 L
s
.50052 .69811 m
.50061 .69797 L
s
.50061 .69797 m
.50095 .69748 L
s
.5006 .69835 m
.50083 .69817 L
s
.50037 .69853 m
.50054 .6984 L
s
.50054 .6984 m
.5006 .69835 L
s
.50033 .69856 m
.50037 .69853 L
s
.50032 .69857 m
.50033 .69856 L
s
.50029 .6986 m
.50032 .69857 L
s
.50083 .69817 m
.50083 .69817 L
s
.50083 .69817 m
.50252 .69687 L
s
.50022 .69865 m
.50029 .6986 L
s
.5002 .69866 m
.50022 .69865 L
s
.50019 .69867 m
.5002 .69866 L
s
.50011 .69873 m
.50019 .69867 L
s
.50211 .69152 m .49854 .69306 L .49404 .69665 L 0 1 .385 r
F
0 g
.50221 .69256 m
.50232 .69248 L
s
.50211 .69152 m .502 .69086 L .49854 .69306 L 0 1 .385 r
F
0 g
.50211 .69152 m
.50548 .68852 L
s
.502 .69086 m
.50528 .68738 L
s
.24192 .80849 m .22833 .80118 L .22768 .80548 L 0 1 .536 r
F
.24192 .80849 m .23272 .80057 L .22833 .80118 L F
.24192 .80849 m .23856 .80371 L .23272 .80057 L F
.25265 .80639 m .23856 .80371 L .24192 .80849 L 0 1 .533 r
F
0 g
.24125 .81275 m
.24192 .80849 L
s
.24192 .80849 m
.24762 .81136 L
s
.5035 .6764 m .50376 .67559 L .50119 .67416 L 0 1 .375 r
F
0 g
.50376 .67559 m
.50672 .6766 L
s
.50573 .65479 m
.50589 .65607 L
s
.50826 .6303 m .5105 .62288 L .51017 .61826 L 0 1 .333 r
F
0 g
.5105 .62288 m
.51181 .62466 L
s
.50968 .62804 m
.5105 .62288 L
s
.45046 .77583 m .43928 .7778 L .44156 .78364 L 0 .893 .369 r
F
.45046 .77583 m .4404 .77122 L .43928 .7778 L F
0 g
.43476 .77545 m
.43928 .7778 L
s
.50529 .65124 m .50619 .64979 L .50592 .64539 L 0 1 .364 r
F
0 g
.50619 .64979 m
.50781 .65305 L
s
.7713 .67132 m .78256 .68332 L .78279 .67641 L 0 .965 .489 r
F
0 g
.78256 .68332 m
.78582 .68998 L
s
.77897 .68682 m
.78256 .68332 L
s
.4457 .76184 m .444 .75619 L .43971 .75395 L 0 .938 .369 r
F
0 g
.43971 .75395 m
.43978 .75399 L
s
.43971 .75395 m
.43987 .75394 L
s
.43971 .75395 m
.43977 .75391 L
s
.36965 .97877 m .35488 .97288 L .35186 .97436 L 0 1 .538 r
F
.36965 .97877 m .36251 .97477 L .35488 .97288 L F
0 g
.36965 .97877 m
.373 .983 L
s
.37819 .97393 m .36251 .97477 L .36965 .97877 L 0 1 .538 r
F
0 g
.36965 .97877 m
.37746 .98026 L
s
.42123 .76485 m .41047 .76866 L .40892 .77029 L 0 1 .26 r
F
.42123 .76485 m .41469 .7666 L .41047 .76866 L F
.42123 .76485 m .4193 .76497 L .41469 .7666 L F
.43141 .75887 m .4193 .76497 L .42123 .76485 L 0 .931 .231 r
F
0 g
.41967 .76649 m
.42123 .76485 L
s
.42123 .76485 m
.42547 .763 L
s
.5035 .6764 m .49639 .67623 L .50035 .67667 L 0 1 .375 r
F
.5035 .6764 m .49382 .6748 L .49639 .67623 L F
.5035 .6764 m .49434 .67333 L .49382 .6748 L F
.5035 .6764 m .4975 .67306 L .49434 .67333 L F
.5035 .6764 m .50119 .67416 L .4975 .67306 L F
0 g
.50119 .67416 m
.50376 .67559 L
s
.5035 .6764 m
.50627 .67801 L
s
.50119 .67416 m
.50418 .67438 L
s
.50228 .67173 m
.50419 .67333 L
s
.50419 .67333 m
.50448 .67357 L
s
.50295 .69545 m .49605 .70377 L .50008 .69876 L 0 0 .034 r
F
0 g
.50008 .69876 m
.50011 .69872 L
s
.50011 .69872 m
.50019 .69863 L
s
.50019 .69863 m
.50019 .69863 L
s
.50019 .69863 m
.50021 .6986 L
s
.50021 .6986 m
.50028 .69853 L
s
.50279 .69563 m
.50295 .69545 L
s
.50279 .69563 m
.50279 .69563 L
s
.50279 .69563 m
.50279 .69563 L
s
.50226 .69624 m
.50279 .69563 L
s
.50226 .69624 m
.50226 .69624 L
s
.50226 .69624 m
.50226 .69624 L
s
.50104 .69765 m
.50226 .69624 L
s
.50104 .69765 m
.50104 .69765 L
s
.50028 .69853 m
.5003 .6985 L
s
.5003 .6985 m
.50031 .69849 L
s
.50031 .69849 m
.50034 .69845 L
s
.50034 .69845 m
.50041 .69838 L
s
.50041 .69838 m
.5005 .69827 L
s
.5005 .69827 m
.5005 .69827 L
s
.5005 .69827 m
.50055 .69821 L
s
.50055 .69821 m
.50071 .69803 L
s
.50071 .69803 m
.50104 .69765 L
s
.50008 .69876 m
.50052 .69811 L
s
.50008 .69876 m
.50015 .69866 L
s
.50295 .69545 m .49272 .70823 L .49605 .70377 L 0 0 .034 r
F
0 g
.50369 .69498 m
.50509 .69275 L
s
.50331 .69523 m
.50494 .69287 L
s
.50295 .69545 m .4923 .70915 L .49272 .70823 L 0 0 .034 r
F
.50295 .69545 m .49517 .70585 L .4923 .70915 L F
0 g
.50346 .69535 m
.50369 .69498 L
s
.50318 .69543 m
.50331 .69523 L
s
.50295 .69545 m .49941 .70052 L .49517 .70585 L 0 0 .034 r
F
.50295 .69545 m .50274 .69606 L .49941 .70052 L F
0 g
.50295 .69545 m
.50296 .69542 L
s
.50258 .69676 m
.50346 .69535 L
s
.50249 .69692 m
.50251 .69689 L
s
.50251 .69689 m
.50258 .69676 L
s
.50278 .69601 m
.50318 .69543 L
s
.50274 .69606 m
.50278 .69601 L
s
.50295 .69545 m
.50295 .69545 L
s
.4825 .71561 m .47828 .71129 L .47405 .71452 L 0 .825 .321 r
F
.4825 .71561 m .4819 .71176 L .47828 .71129 L F
0 g
.47828 .71129 m
.4811 .70593 L
s
.4819 .71176 m
.48463 .70624 L
s
.47828 .71129 m
.4819 .71176 L
s
.42414 .98145 m .42617 .98641 L .42796 .98467 L 0 1 .54 r
F
.44196 .9869 m .42796 .98467 L .42617 .98641 L 0 1 .541 r
F
0 g
.42617 .98641 m
.43054 .98932 L
s
.41938 .98569 m
.42617 .98641 L
s
.49543 .71349 m
.49617 .71272 L
s
.49434 .71462 m
.49543 .71349 L
s
.50187 .68985 m .49404 .69665 L .49854 .69306 L 0 1 .384 r
F
0 g
.50225 .69444 m
.50229 .6944 L
s
.50221 .69343 m
.5023 .69331 L
s
.502 .69164 m
.50211 .69152 L
s
.50201 .69271 m
.50221 .69256 L
s
.50187 .68985 m .49056 .69844 L .49404 .69665 L 0 1 .384 r
F
.50187 .68985 m .49043 .69723 L .49056 .69844 L F
.50187 .68985 m .49376 .69401 L .49043 .69723 L F
.50187 .68985 m .49833 .69094 L .49376 .69401 L F
0 g
.50221 .69343 m
.50221 .69343 L
s
.50192 .69091 m
.502 .69086 L
s
.50187 .68985 m .50181 .68916 L .49833 .69094 L 0 1 .384 r
F
0 g
.50187 .68985 m
.50529 .68737 L
s
.50181 .68916 m
.50516 .68617 L
s
.32576 .73695 m .31628 .7241 L .3141 .73099 L 0 1 .453 r
F
.32576 .73695 m .32049 .72328 L .31628 .7241 L F
.32576 .73695 m .32455 .72879 L .32049 .72328 L F
.33613 .73444 m .32455 .72879 L .32576 .73695 L 0 1 .447 r
F
0 g
.32358 .74382 m
.32576 .73695 L
s
.32576 .73695 m
.32976 .74226 L
s
.45465 .81239 m .4474 .82072 L .45189 .82261 L 0 .827 .38 r
F
0 g
.4474 .82072 m
.44771 .82749 L
s
.48885 .91923 m .49188 .92877 L .49251 .92596 L 0 .589 .405 r
F
.5028 .93473 m .49188 .92877 L .49594 .9356 L 0 .482 .39 r
F
0 g
.49594 .9356 m
.49594 .9356 L
s
.5028 .93473 m .49251 .92596 L .49188 .92877 L 0 .482 .39 r
F
0 g
.49096 .93271 m
.49594 .9356 L
s
.48695 .92619 m
.49188 .92877 L
s
.46206 .73313 m .45291 .72919 L .45065 .7353 L 0 .907 .345 r
F
.46206 .73313 m .45714 .72644 L .45291 .72919 L F
0 g
.44904 .72713 m
.45291 .72919 L
s
.45185 .7407 m .44166 .74765 L .44573 .7498 L 0 .945 .357 r
F
0 g
.44075 .75058 m
.44166 .74765 L
s
.47736 .73503 m .47252 .73515 L .46874 .73892 L 0 1 .434 r
F
.47736 .73503 m .47621 .73348 L .47252 .73515 L F
.48631 .72396 m .47621 .73348 L .47736 .73503 L 0 1 .421 r
F
0 g
.47561 .73924 m
.47736 .73503 L
s
.47736 .73503 m
.48084 .7328 L
s
.48433 .72827 m
.48768 .72573 L
s
.50292 .67842 m .50314 .67761 L .50035 .67667 L 0 1 .376 r
F
0 g
.50314 .67761 m
.50626 .67801 L
s
.51136 .61231 m .51481 .60374 L .51497 .60006 L 0 1 .249 r
F
0 g
.51481 .60374 m
.51548 .60383 L
s
.51327 .60899 m
.51481 .60374 L
s
.52741 .98045 m
.52819 .981 L
s
.52736 .98042 m
.52741 .98045 L
s
.52708 .98023 m
.52736 .98042 L
s
.52379 .97795 m
.52478 .97863 L
s
.52697 .98015 m
.52708 .98023 L
s
.52664 .97992 m
.52697 .98015 L
s
.37811 .72307 m .36637 .71885 L .36727 .72623 L 0 1 .419 r
F
0 g
.36727 .72623 m
.37117 .73076 L
s
.37811 .72307 m .369 .71248 L .36637 .71885 L 0 1 .419 r
F
.37811 .72307 m .37339 .71135 L .369 .71248 L F
.37811 .72307 m .3773 .71589 L .37339 .71135 L F
0 g
.37549 .72943 m
.37811 .72307 L
s
.37811 .72307 m
.38196 .7274 L
s
.39961 .70929 m
.40255 .70317 L
s
.43144 .75647 m .42115 .7554 L .41939 .75938 L 0 1 .479 r
F
.43144 .75647 m .42537 .75318 L .42115 .7554 L F
.43144 .75647 m .42978 .75364 L .42537 .75318 L F
.44163 .75002 m .42978 .75364 L .43144 .75647 L 0 1 .471 r
F
0 g
.43144 .75647 m
.43501 .75658 L
s
.43008 .75954 m
.43144 .75647 L
s
.50292 .67842 m .49546 .67937 L .49963 .67917 L 0 1 .376 r
F
.50292 .67842 m .49266 .67843 L .49546 .67937 L F
.50292 .67842 m .4931 .67698 L .49266 .67843 L F
.50292 .67842 m .49639 .67623 L .4931 .67698 L F
.50292 .67842 m .50035 .67667 L .49639 .67623 L F
0 g
.50035 .67667 m
.5035 .6764 L
s
.50292 .67842 m
.50588 .67943 L
s
.50035 .67667 m
.50314 .67761 L
s
.61146 .55437 m .61573 .58718 L .61196 .56785 L 0 .953 .114 r
F
.61146 .55437 m .62006 .58083 L .62438 .61361 L F
0 g
.61527 .55889 m
.61614 .56287 L
s
.61786 .57074 m
.62006 .58083 L
s
.61712 .56738 m
.61786 .57074 L
s
.61692 .56645 m
.61712 .56738 L
s
.61614 .56287 m
.61692 .56645 L
s
.61892 .60184 m
.6192 .60677 L
s
.50175 .68809 m .49376 .69401 L .49833 .69094 L 0 1 .382 r
F
0 g
.50181 .6899 m
.50187 .68985 L
s
.50182 .69098 m
.50192 .69091 L
s
.50198 .69274 m
.50201 .69271 L
s
.50195 .6917 m
.502 .69164 L
s
.50213 .69353 m
.50221 .69343 L
s
.50175 .68809 m .49031 .69537 L .49376 .69401 L 0 1 .382 r
F
.50175 .68809 m .49028 .69411 L .49031 .69537 L F
0 g
.49942 .69698 m
.50225 .69444 L
s
.50175 .68809 m .49369 .69126 L .49028 .69411 L 0 1 .382 r
F
0 g
.49942 .69698 m
.50213 .69353 L
s
.4989 .69508 m
.50198 .69274 L
s
.50175 .68809 m .49828 .68873 L .49369 .69126 L 0 1 .382 r
F
0 g
.50175 .68919 m
.50181 .68916 L
s
.5018 .68992 m
.50181 .6899 L
s
.50181 .69098 m
.50182 .69098 L
s
.50175 .68809 m .50173 .68737 L .49828 .68873 L 0 1 .382 r
F
0 g
.50175 .68809 m
.50517 .68616 L
s
.50173 .6881 m
.50175 .68809 L
s
.50173 .68737 m
.50501 .68499 L
s
.4825 .71561 m .47405 .71452 L .47148 .72032 L 0 .825 .321 r
F
0 g
.47041 .71351 m
.47405 .71452 L
s
.46206 .73313 m .46106 .72813 L .45714 .72644 L 0 .907 .345 r
F
0 g
.45714 .72644 m
.45973 .72056 L
s
.50693 .42703 m .51352 .41947 L .51858 .41752 L 0 .044 .076 r
F
0 g
.51352 .41947 m
.51835 .40977 L
s
.4457 .76184 m .4404 .77122 L .44416 .76828 L 0 .938 .369 r
F
.45046 .77583 m .44416 .76828 L .4404 .77122 L 0 .893 .369 r
F
0 g
.43928 .7778 m
.4404 .77122 L
s
.43611 .76897 m
.4404 .77122 L
s
.33613 .73444 m .3268 .72202 L .32455 .72879 L 0 1 .447 r
F
.33613 .73444 m .331 .72116 L .3268 .72202 L F
.33613 .73444 m .335 .72649 L .331 .72116 L F
.34651 .73183 m .335 .72649 L .33613 .73444 L 0 1 .441 r
F
0 g
.33389 .7412 m
.33613 .73444 L
s
.33613 .73444 m
.34007 .73957 L
s
.50246 .68043 m .50263 .67963 L .49963 .67917 L 0 1 .377 r
F
0 g
.50263 .67963 m
.50588 .67943 L
s
.49526 .71146 m .48957 .72105 L .49307 .71595 L 0 1 .406 r
F
0 g
.49307 .71595 m
.49434 .71462 L
s
.50246 .68043 m .49472 .68245 L .49907 .68164 L 0 1 .377 r
F
.50246 .68043 m .49172 .68199 L .49472 .68245 L F
0 g
.50215 .68241 m
.50535 .68221 L
s
.50203 .68355 m
.50535 .68222 L
s
.50246 .68043 m .49207 .68057 L .49172 .68199 L 0 1 .377 r
F
0 g
.50225 .68162 m
.50558 .68083 L
s
.50246 .68043 m .49546 .67937 L .49207 .68057 L 0 1 .377 r
F
0 g
.50225 .68051 m
.50225 .68051 L
s
.50225 .68051 m
.5024 .68045 L
s
.5024 .68045 m
.5024 .68045 L
s
.5024 .68045 m
.5024 .68045 L
s
.50246 .68043 m .49963 .67917 L .49546 .67937 L 0 1 .377 r
F
0 g
.49963 .67917 m
.50263 .67963 L
s
.5024 .68045 m
.50246 .68043 L
s
.50246 .68043 m
.50558 .68083 L
s
.49963 .67917 m
.50292 .67842 L
s
.50174 .68626 m .49369 .69126 L .49828 .68873 L 0 1 .381 r
F
0 g
.5018 .69099 m
.50181 .69098 L
s
.50179 .68992 m
.5018 .68992 L
s
.50174 .68919 m
.50175 .68919 L
s
.50174 .68626 m .4903 .69218 L .49369 .69126 L 0 1 .381 r
F
.50174 .68626 m .49036 .69088 L .4903 .69218 L F
0 g
.4989 .69508 m
.50195 .6917 L
s
.49854 .69306 m
.5018 .69099 L
s
.50174 .68626 m .49383 .68841 L .49036 .69088 L 0 1 .381 r
F
0 g
.49833 .69094 m
.50174 .68919 L
s
.49854 .69306 m
.50179 .68992 L
s
.50174 .68626 m .49839 .68643 L .49383 .68841 L 0 1 .381 r
F
0 g
.50169 .68738 m
.50173 .68737 L
s
.5017 .68813 m
.50173 .6881 L
s
.50174 .68626 m .50178 .68551 L .49839 .68643 L 0 1 .381 r
F
0 g
.50174 .68626 m
.50508 .68491 L
s
.50171 .68628 m
.50174 .68626 L
s
.50178 .68551 m
.5052 .68357 L
s
.50039 .98387 m .48719 .9873 L .49227 .98835 L 0 1 .53 r
F
0 g
.4863 .99007 m
.49227 .98835 L
s
.36727 .72623 m .35591 .72153 L .35688 .7291 L 0 1 .427 r
F
.36727 .72623 m .35834 .71509 L .35591 .72153 L F
.36727 .72623 m .36255 .71408 L .35834 .71509 L F
.36727 .72623 m .36637 .71885 L .36255 .71408 L F
0 g
.36484 .73265 m
.36727 .72623 L
s
.47228 .72482 m .46771 .71917 L .46348 .72215 L 0 .867 .333 r
F
.47228 .72482 m .47148 .72032 L .46771 .71917 L F
0 g
.46771 .71917 m
.47041 .71351 L
s
.47228 .72482 m .46348 .72215 L .46106 .72813 L 0 .867 .333 r
F
0 g
.45973 .72056 m
.46348 .72215 L
s
.80576 .68502 m .80867 .69926 L .81324 .70092 L 0 1 .509 r
F
.80576 .68502 m .80547 .69246 L .80867 .69926 L F
0 g
.80411 .70405 m
.80867 .69926 L
s
.5021 .68242 m .50223 .68163 L .49907 .68164 L 0 1 .379 r
F
0 g
.50215 .68163 m
.50223 .68163 L
s
.50215 .68163 m
.50215 .68163 L
s
.50223 .68163 m
.50225 .68162 L
s
.2803 .96456 m
.2864 .96714 L
s
.49526 .71146 m .48631 .72396 L .48957 .72105 L 0 1 .406 r
F
0 g
.48768 .72573 m
.48957 .72105 L
s
.49442 .71317 m
.49519 .71161 L
s
.49307 .71595 m
.49442 .71317 L
s
.34651 .73183 m .33731 .71983 L .335 .72649 L 0 1 .441 r
F
.34651 .73183 m .34152 .71893 L .33731 .71983 L F
.34651 .73183 m .34546 .72407 L .34152 .71893 L F
.35688 .7291 m .34546 .72407 L .34651 .73183 L 0 1 .435 r
F
0 g
.3442 .73847 m
.34651 .73183 L
s
.34651 .73183 m
.35039 .73678 L
s
.30947 .77883 m .29589 .7708 L .29373 .77608 L 0 1 .522 r
F
.30947 .77883 m .30131 .76974 L .29589 .7708 L F
.30947 .77883 m .30713 .77319 L .30131 .76974 L F
0 g
.30729 .78409 m
.30947 .77883 L
s
.31957 .77631 m .30713 .77319 L .30947 .77883 L 0 1 .521 r
F
0 g
.30947 .77883 m
.31423 .78224 L
s
.54517 .78439 m
.54784 .78812 L
s
.73915 .93542 m .75079 .93539 L .74703 .934 L 0 1 .533 r
F
.72995 .93161 m .73915 .93542 L .7414 .93187 L 0 1 .531 r
F
.50186 .68436 m .49383 .68841 L .49839 .68643 L 0 1 .38 r
F
.50186 .68436 m .49053 .68888 L .49383 .68841 L F
.50186 .68436 m .4907 .68753 L .49053 .68888 L F
0 g
.49833 .69094 m
.5017 .68813 L
s
.50186 .68436 m .49418 .68547 L .4907 .68753 L 0 1 .38 r
F
0 g
.49828 .68873 m
.50169 .68738 L
s
.49828 .68873 m
.50171 .68628 L
s
.49839 .68643 m
.50178 .68551 L
s
.50186 .68436 m .49865 .68406 L .49418 .68547 L 0 1 .38 r
F
.50186 .68436 m .50194 .68359 L .49865 .68406 L F
0 g
.50186 .68436 m
.50521 .68357 L
s
.5021 .68242 m .49418 .68547 L .49865 .68406 L 0 1 .379 r
F
0 g
.50196 .68358 m
.50203 .68355 L
s
.5021 .68242 m .49101 .68548 L .49418 .68547 L 0 1 .379 r
F
.5021 .68242 m .49127 .68409 L .49101 .68548 L F
0 g
.50181 .6844 m
.50186 .68436 L
s
.49839 .68643 m
.50181 .6844 L
s
.5021 .68242 m .49472 .68245 L .49127 .68409 L 0 1 .379 r
F
0 g
.50194 .68359 m
.50196 .68358 L
s
.5021 .68242 m .49907 .68164 L .49472 .68245 L 0 1 .379 r
F
0 g
.50204 .68244 m
.5021 .68242 L
s
.50204 .68245 m
.50204 .68244 L
s
.49865 .68406 m
.50204 .68245 L
s
.5021 .68242 m
.50215 .68241 L
s
.49907 .68164 m
.50225 .68051 L
s
.49907 .68164 m
.50215 .68163 L
s
.49077 .91161 m .48002 .90623 L .48335 .91308 L 0 .565 .395 r
F
.49077 .91161 m .48109 .90325 L .48002 .90623 L F
0 g
.47667 .90459 m
.48002 .90623 L
s
.49865 .68406 m
.50194 .68359 L
s
.35688 .7291 m .34783 .71753 L .34546 .72407 L 0 1 .435 r
F
.35688 .7291 m .35203 .71657 L .34783 .71753 L F
.35688 .7291 m .35591 .72153 L .35203 .71657 L F
0 g
.35452 .73563 m
.35688 .7291 L
s
.35688 .7291 m
.36071 .73386 L
s
.49269 .70764 m
.49322 .70701 L
s
.49322 .70701 m
.4934 .7068 L
s
.49603 .7038 m
.49605 .70377 L
s
.496 .70383 m
.49603 .7038 L
s
.49595 .70389 m
.496 .70383 L
s
.49588 .70397 m
.49595 .70389 L
s
.49582 .70404 m
.49588 .70397 L
s
.4958 .70406 m
.49582 .70404 L
s
.49495 .70503 m
.4958 .70406 L
s
.49451 .70553 m
.49495 .70503 L
s
.4934 .7068 m
.49451 .70553 L
s
.49077 .91161 m .48335 .91308 L .48885 .91923 L 0 .565 .395 r
F
0 g
.48002 .90623 m
.48335 .91308 L
s
.47842 .91052 m
.48335 .91308 L
s
.45046 .77583 m .44156 .78364 L .44587 .78562 L 0 .893 .369 r
F
0 g
.44066 .79024 m
.44156 .78364 L
s
.49526 .71146 m .48545 .72272 L .48631 .72396 L 0 1 .406 r
F
.49526 .71146 m .48764 .71824 L .48545 .72272 L F
.68811 .93862 m .69649 .93811 L .69884 .9348 L 0 1 .456 r
F
.5028 .93473 m .49594 .9356 L .50199 .94193 L 0 .482 .39 r
F
0 g
.49188 .92877 m
.49594 .9356 L
s
.54089 .74162 m
.54178 .74705 L
s
.54089 .74162 m
.54372 .74563 L
s
.46206 .73313 m .45065 .7353 L .45185 .7407 L 0 .907 .345 r
F
0 g
.45065 .7353 m
.45291 .72919 L
s
.44658 .73316 m
.45065 .7353 L
s
.43905 .92402 m .42729 .92722 L .42512 .92896 L 0 1 .404 r
F
.43905 .92402 m .43327 .9251 L .42729 .92722 L F
.44385 .91963 m .43327 .9251 L .43905 .92402 L 0 1 .357 r
F
0 g
.43905 .92402 m
.44202 .92464 L
s
.43905 .92402 m
.44473 .92186 L
s
.4649 .84989 m .45961 .85841 L .46418 .86029 L 0 .743 .388 r
F
0 g
.45961 .85841 m
.46119 .86526 L
s
.50529 .65124 m .5016 .64598 L .50332 .64961 L 0 1 .364 r
F
.50529 .65124 m .50133 .64158 L .5016 .64598 L F
.50529 .65124 m .50269 .63934 L .50133 .64158 L F
.50529 .65124 m .50465 .64097 L .50269 .63934 L F
.50529 .65124 m .50592 .64539 L .50465 .64097 L F
0 g
.50529 .65124 m
.50573 .65479 L
s
.50592 .64539 m
.50756 .64765 L
s
.50592 .64539 m
.50619 .64979 L
s
.42101 .61082 m .42299 .60375 L .42146 .59887 L 0 1 .377 r
F
0 g
.42299 .60375 m
.42501 .60123 L
s
.25769 .96369 m .23873 .9538 L .24129 .95967 L 0 1 .536 r
F
.25769 .96369 m .24258 .95282 L .23873 .9538 L F
.25769 .96369 m .25071 .95707 L .24258 .95282 L F
.26687 .9609 m .25071 .95707 L .25769 .96369 L F
0 g
.25769 .96369 m
.2656 .96777 L
s
.25769 .96369 m
.26022 .96954 L
s
.50087 .70393 m
.50174 .70198 L
s
.50297 .69922 m
.50353 .69799 L
s
.47461 .73108 m .46874 .73892 L .47252 .73515 L 0 1 .436 r
F
.47461 .73108 m .46498 .74029 L .46874 .73892 L F
0 g
.46699 .74313 m
.46874 .73892 L
s
.61803 .42341 m .62446 .42768 L .63141 .43629 L 0 .447 .061 r
F
0 g
.62446 .42768 m
.62711 .4239 L
s
.50644 .69769 m
.50657 .69744 L
s
.50514 .70297 m
.50587 .70047 L
s
.50826 .6303 m .50579 .6255 L .50659 .62922 L 0 1 .333 r
F
.50826 .6303 m .50661 .62034 L .50579 .6255 L F
.50826 .6303 m .50851 .61717 L .50661 .62034 L F
.50826 .6303 m .51017 .61826 L .50851 .61717 L F
0 g
.50779 .63597 m
.50826 .6303 L
s
.41039 .67918 m .40213 .68627 L .40673 .68508 L 0 1 .388 r
F
.41039 .67918 m .3989 .682 L .40213 .68627 L F
0 g
.40673 .68508 m
.41029 .68916 L
s
.41039 .67918 m .39921 .67511 L .3989 .682 L 0 1 .388 r
F
.41039 .67918 m .40288 .66921 L .39921 .67511 L F
.41039 .67918 m .40747 .66822 L .40288 .66921 L F
.41039 .67918 m .41068 .6725 L .40747 .66822 L F
0 g
.41039 .67918 m
.41363 .68327 L
s
.40673 .68508 m
.41039 .67918 L
s
.41068 .6725 m
.41433 .66672 L
s
.54202 .74847 m .54051 .74976 L .54135 .75645 L 0 .891 .374 r
F
0 g
.53993 .74886 m
.54051 .74976 L
s
.54416 1.01021 m
.54428 1.01017 L
s
.54428 1.01017 m
.54532 1.00981 L
s
.55327 1.04333 m
.5545 1.04493 L
s
.48631 .72396 m .47819 .72916 L .47621 .73348 L 0 1 .421 r
F
.48631 .72396 m .48197 .72495 L .47819 .72916 L F
.48631 .72396 m .48545 .72272 L .48197 .72495 L F
0 g
.48631 .72396 m
.48957 .72105 L
s
.48433 .72827 m
.48631 .72396 L
s
.47252 .73515 m
.47621 .73348 L
s
.63983 .44889 m
.64564 .45992 L
s
.64564 .45992 m
.64627 .46112 L
s
.64627 .46112 m
.64675 .46203 L
s
.52947 .66532 m .53671 .65406 L .53863 .65756 L 0 .104 .11 r
F
0 g
.53671 .65406 m
.53995 .64617 L
s
.49273 .70531 m .48598 .71521 L .49001 .71083 L 0 .781 .308 r
F
.49273 .70531 m .4825 .71561 L .48598 .71521 L F
0 g
.49032 .71045 m
.49151 .70904 L
s
.49151 .70904 m
.49269 .70764 L
s
.49142 .71349 m
.49369 .71148 L
s
.52044 .67491 m .5208 .67355 L .52344 .67119 L 0 .027 .093 r
F
0 g
.51869 .67488 m
.5208 .67355 L
s
.51806 .67726 m
.51807 .67725 L
s
.45185 .7407 m .44573 .7498 L .44975 .74692 L 0 .945 .357 r
F
.45183 .74302 m .44573 .7498 L .44975 .74692 L 0 1 .461 r
F
.45183 .74302 m .44163 .75002 L .44573 .7498 L F
0 g
.44166 .74765 m
.4436 .74868 L
s
.45532 .75407 m .44573 .7498 L .444 .75619 L 0 .903 .358 r
F
.45532 .75407 m .44975 .74692 L .44573 .7498 L F
.45181 .74535 m .44573 .7498 L .44975 .74692 L 0 .806 .171 r
F
.45181 .74535 m .4416 .7524 L .44573 .7498 L F
0 g
.44981 .74688 m
.4499 .74682 L
s
.4499 .74682 m
.45001 .74674 L
s
.44562 .75006 m
.44573 .7498 L
s
.44405 .75145 m
.44573 .7498 L
s
.44546 .74997 m
.44573 .7498 L
s
.44991 .7469 m
.45034 .74685 L
s
.46498 .74029 m .45578 .7424 L .45388 .74643 L 0 1 .448 r
F
0 g
.45388 .74643 m
.45562 .74272 L
s
.45034 .74685 m
.45388 .74643 L
s
.45001 .74674 m
.4539 .74411 L
s
.45532 .75407 m .444 .75619 L .4457 .76184 L 0 .903 .358 r
F
0 g
.444 .75619 m
.44573 .7498 L
s
.43978 .75399 m
.444 .75619 L
s
.4337 .55137 m .43723 .5435 L .43761 .53835 L 0 1 .328 r
F
0 g
.43723 .5435 m
.4397 .54025 L
s
.77404 .9328 m .77723 .9399 L .78382 .93559 L 0 1 .532 r
F
0 g
.76951 .94212 m
.77723 .9399 L
s
.7751 .94408 m
.77723 .9399 L
s
.4944 .70526 m
.49482 .70488 L
s
.49482 .70488 m
.49566 .70413 L
s
.49566 .70413 m
.49577 .70403 L
s
.49577 .70403 m
.49582 .70399 L
s
.49582 .70399 m
.49605 .70377 L
s
.4934 .70826 m
.49407 .70712 L
s
.49534 .70472 m
.49583 .70407 L
s
.49583 .70407 m
.4959 .70397 L
s
.4959 .70397 m
.49596 .7039 L
s
.49596 .7039 m
.496 .70385 L
s
.496 .70385 m
.49605 .70377 L
s
.49413 .70807 m
.49507 .70597 L
s
.50072 .69876 m
.50072 .69876 L
s
.50072 .69876 m
.50179 .69734 L
s
.50179 .69734 m
.50179 .69734 L
s
.50179 .69734 m
.5024 .69652 L
s
.5024 .69652 m
.5024 .69652 L
s
.5024 .69652 m
.5024 .69652 L
s
.5024 .69652 m
.50269 .69614 L
s
.50269 .69614 m
.50269 .69614 L
s
.50269 .69614 m
.50269 .69614 L
s
.50269 .69614 m
.50274 .69606 L
s
.35539 .78941 m .34384 .78857 L .3429 .79078 L 0 1 .46 r
F
.35539 .78941 m .34786 .78748 L .34384 .78857 L F
.35539 .78941 m .35281 .78784 L .34786 .78748 L F
.36514 .78606 m .35281 .78784 L .35539 .78941 L 0 1 .437 r
F
0 g
.35443 .79161 m
.35539 .78941 L
s
.35539 .78941 m
.3602 .78952 L
s
.57924 .41394 m .59257 .40995 L .59457 .41603 L 0 .277 .096 r
F
0 g
.59257 .40995 m
.59589 .40392 L
s
.58601 .40906 m
.59257 .40995 L
s
.52115 .68711 m
.52141 .68747 L
s
.52115 .68711 m
.52115 .68711 L
s
.52115 .68711 m
.52151 .6872 L
s
.54202 .74847 m .54135 .75645 L .54398 .76408 L 0 .891 .374 r
F
0 g
.53858 .75211 m
.54135 .75645 L
s
.54051 .74976 m
.54135 .75645 L
s
.46498 .74029 m .4598 .73925 L .45578 .7424 L 0 1 .448 r
F
.46498 .74029 m .46374 .73835 L .4598 .73925 L F
.47461 .73108 m .46374 .73835 L .46498 .74029 L 0 1 .436 r
F
0 g
.46498 .74029 m
.46874 .73892 L
s
.46308 .74432 m
.46498 .74029 L
s
.38823 .71276 m
.38823 .71275 L
s
.76424 .92994 m .75815 .93366 L .75641 .93745 L 0 1 .529 r
F
0 g
.74832 .93911 m
.75641 .93745 L
s
.52446 .68531 m .53232 .69062 L .5278 .68643 L 0 .535 .269 r
F
.52446 .68531 m .53583 .69868 L .53232 .69062 L F
0 g
.52141 .68747 m
.52326 .69007 L
s
.52151 .6872 m
.52386 .68781 L
s
.52446 .68531 m .53597 .70524 L .53583 .69868 L 0 .535 .269 r
F
.52446 .68531 m .53262 .70411 L .53597 .70524 L F
0 g
.52326 .69007 m
.52351 .69042 L
s
.52386 .68781 m
.52401 .68785 L
s
.52446 .68531 m .52802 .69604 L .53262 .70411 L 0 .535 .269 r
F
.52446 .68531 m .52453 .68799 L .52802 .69604 L F
0 g
.52445 .6853 m
.52446 .68531 L
s
.52468 .68178 m
.5278 .68643 L
s
.52351 .69042 m
.5245 .69181 L
s
.52401 .68785 m
.5245 .68798 L
s
.5245 .68798 m
.52453 .68799 L
s
.52463 .68536 m
.5278 .68643 L
s
.52463 .68536 m
.52463 .68536 L
s
.52446 .68531 m
.52463 .68536 L
s
.52446 .68531 m
.52446 .68531 L
s
.5245 .69181 m
.52458 .69192 L
s
.5082 .49274 m .51749 .4698 L .51764 .46896 L 0 .804 .092 r
F
.5082 .49274 m .51345 .47997 L .51749 .4698 L F
0 g
.51749 .4698 m
.51905 .46558 L
s
.51581 .47404 m
.51749 .4698 L
s
.51345 .47997 m
.51581 .47404 L
s
.42101 .61082 m .41214 .61716 L .41637 .61656 L 0 1 .377 r
F
0 g
.42031 .6188 m
.4227 .61574 L
s
.42101 .61082 m .4106 .61228 L .41214 .61716 L 0 1 .377 r
F
.42101 .61082 m .41279 .60517 L .4106 .61228 L F
.42101 .61082 m .41745 .59942 L .41279 .60517 L F
.42101 .61082 m .42146 .59887 L .41745 .59942 L F
0 g
.42101 .61082 m
.4227 .61574 L
s
.42146 .59887 m
.42624 .59302 L
s
.42146 .59887 m
.42299 .60375 L
s
.50398 .65884 m
.50406 .6592 L
s
.38513 .7787 m .37961 .7821 L .38365 .78048 L 0 1 .369 r
F
.38513 .7787 m .37491 .78256 L .37961 .7821 L F
0 g
.37869 .78402 m
.37961 .7821 L
s
.38365 .78048 m
.38861 .77976 L
s
.47228 .72482 m .46106 .72813 L .46206 .73313 L 0 .867 .333 r
F
0 g
.45714 .72644 m
.46106 .72813 L
s
.46106 .72813 m
.46348 .72215 L
s
.34989 .76821 m .34424 .77379 L .34825 .7726 L 0 1 .516 r
F
.34989 .76821 m .33977 .77101 L .34424 .77379 L F
0 g
.34324 .7783 m
.34424 .77379 L
s
.34825 .7726 m
.35314 .77514 L
s
.39898 .6991 m .39111 .70653 L .39568 .70521 L 0 1 .4 r
F
0 g
.39568 .70521 m
.39961 .70929 L
s
.49142 .71349 m
.49344 .70999 L
s
.21316 .77934 m .20723 .78664 L .21161 .7859 L 0 1 .527 r
F
.21316 .77934 m .20212 .781 L .20723 .78664 L F
0 g
.20673 .79326 m
.20723 .78664 L
s
.21161 .7859 m
.21758 .79121 L
s
.54202 .74847 m .54398 .76408 L .54737 .76902 L 0 .891 .374 r
F
0 g
.54178 .74705 m
.54202 .74847 L
s
.4825 .71561 m .47148 .72032 L .47228 .72482 L 0 .825 .321 r
F
0 g
.46771 .71917 m
.47148 .72032 L
s
.47148 .72032 m
.47405 .71452 L
s
.47817 .90125 m .46683 .90842 L .46978 .90789 L 0 1 .273 r
F
0 g
.4646 .91108 m
.46978 .90789 L
s
.70223 .91919 m .69859 .92627 L .70562 .92594 L 0 1 .519 r
F
.70223 .91919 m .69508 .92432 L .69859 .92627 L F
0 g
.69624 .92952 m
.69859 .92627 L
s
.48545 .72272 m
.48764 .71824 L
s
.45046 .77583 m .44848 .77026 L .44416 .76828 L 0 .893 .369 r
F
.53474 .55814 m .53435 .5685 L .53321 .566 L 0 .007 .086 r
F
.53474 .55814 m .53792 .5649 L .53435 .5685 L F
.53474 .55814 m .54154 .5576 L .53792 .5649 L F
.53474 .55814 m .54304 .54975 L .54154 .5576 L F
0 g
.54407 .73752 m
.54538 .7438 L
s
.54407 .73752 m
.54751 .74189 L
s
.50039 .98387 m .50527 .98652 L .50545 .98492 L 0 1 .53 r
F
.51778 .98184 m .50545 .98492 L .50527 .98652 L 0 1 .511 r
F
0 g
.50527 .98652 m
.51067 .98657 L
s
.49962 .98799 m
.50527 .98652 L
s
.54979 1.02202 m .55316 1.04211 L .55233 1.03215 L 0 .117 .189 r
F
0 g
.54979 1.02202 m
.55015 1.02346 L
s
.55015 1.02346 m
.55027 1.02395 L
s
.55027 1.02395 m
.55233 1.03215 L
s
.54979 1.02202 m
.54988 1.02199 L
s
.55001 1.02195 m
.55005 1.02194 L
s
.55034 1.02184 m
.55048 1.02179 L
s
.5509 1.02165 m
.55112 1.02158 L
s
.46206 .73313 m .45185 .7407 L .45578 .7424 L 0 .907 .345 r
F
0 g
.45084 .74371 m
.45185 .7407 L
s
.48132 .88804 m .47326 .89044 L .47819 .89647 L 0 .628 .392 r
F
.48132 .88804 m .47074 .88345 L .47326 .89044 L F
0 g
.47326 .89044 m
.47326 .89044 L
s
.41687 .7547 m .41061 .76068 L .41482 .75862 L 0 1 .489 r
F
.41687 .7547 m .40621 .75968 L .41061 .76068 L F
0 g
.40902 .76472 m
.41061 .76068 L
s
.32853 .93689 m .31114 .93981 L .31339 .94064 L 0 .936 .253 r
F
.32853 .93689 m .31477 .93857 L .31114 .93981 L F
.32853 .93689 m .32223 .93732 L .31477 .93857 L F
.33709 .9333 m .32223 .93732 L .32853 .93689 L 0 .853 .242 r
F
0 g
.32853 .93689 m
.33573 .93543 L
s
.32853 .93689 m
.33073 .93773 L
s
.39898 .6991 m .38752 .70226 L .39111 .70653 L 0 1 .4 r
F
0 g
.38823 .71275 m
.39111 .70653 L
s
.39898 .6991 m .38731 .69523 L .38752 .70226 L 0 1 .4 r
F
.39898 .6991 m .39061 .68911 L .38731 .69523 L F
.39898 .6991 m .39522 .688 L .39061 .68911 L F
.39898 .6991 m .39881 .69228 L .39522 .688 L F
0 g
.39898 .6991 m
.40255 .70317 L
s
.39568 .70521 m
.39898 .6991 L
s
.50199 .94193 m .50621 .95113 L .5064 .94858 L 0 .497 .397 r
F
.51721 .95791 m .50621 .95113 L .51096 .95796 L 0 .383 .371 r
F
.51721 .95791 m .5064 .94858 L .50621 .95113 L F
0 g
.50122 .94821 m
.50621 .95113 L
s
.48425 .72081 m .47819 .72916 L .48197 .72495 L 0 1 .421 r
F
.48425 .72081 m .47461 .73108 L .47819 .72916 L F
0 g
.47621 .73348 m
.47819 .72916 L
s
.48197 .72495 m
.48545 .72272 L
s
.80576 .68502 m .81324 .70092 L .81691 .69641 L 0 1 .509 r
F
0 g
.81324 .70092 m
.81546 .70836 L
s
.76296 .57766 m .76974 .58674 L .76519 .58368 L 0 .27 .022 r
F
.76296 .57766 m .7744 .58616 L .76974 .58674 L F
.45589 .78961 m .44519 .79235 L .44776 .79811 L 0 .846 .369 r
F
.45589 .78961 m .44587 .78562 L .44519 .79235 L F
0 g
.44066 .79024 m
.44519 .79235 L
s
.50442 .69444 m
.50548 .69265 L
s
.50403 .69509 m
.50442 .69444 L
s
.50548 .69266 m
.50548 .69265 L
s
.5042 .69461 m
.50548 .69266 L
s
.50382 .6952 m
.5042 .69461 L
s
.49248 .70895 m
.4934 .70826 L
s
.41144 .66241 m .40288 .66921 L .40747 .66822 L 0 1 .387 r
F
.41144 .66241 m .40004 .66475 L .40288 .66921 L F
0 g
.40747 .66822 m
.41068 .6725 L
s
.41144 .66241 m .40084 .65782 L .40004 .66475 L 0 1 .387 r
F
.41144 .66241 m .40482 .65201 L .40084 .65782 L F
.41144 .66241 m .40933 .65119 L .40482 .65201 L F
.41144 .66241 m .41217 .65565 L .40933 .65119 L F
0 g
.41144 .66241 m
.41433 .66672 L
s
.40747 .66822 m
.41144 .66241 L
s
.41217 .65565 m
.41609 .64996 L
s
.45532 .75407 m .45385 .74875 L .44975 .74692 L 0 .903 .358 r
F
0 g
.44975 .74692 m
.44983 .74696 L
s
.44975 .74692 m
.44991 .7469 L
s
.44975 .74692 m
.44981 .74688 L
s
.78638 .88394 m .79131 .89289 L .79657 .88371 L 0 1 .51 r
F
0 g
.78443 .89969 m
.79131 .89289 L
s
.79032 .89988 m
.79131 .89289 L
s
.39555 .76434 m .38499 .76062 L .38334 .76467 L 0 1 .501 r
F
.39555 .76434 m .3892 .75909 L .38499 .76062 L F
.39555 .76434 m .39372 .76069 L .3892 .75909 L F
0 g
.39389 .76839 m
.39555 .76434 L
s
.40621 .75968 m .39373 .76069 L .39555 .76434 L 0 1 .495 r
F
0 g
.39555 .76434 m
.40008 .76562 L
s
.50309 .65492 m .50396 .65344 L .50332 .64961 L 0 1 .368 r
F
0 g
.50396 .65344 m
.50589 .65607 L
s
.54152 .40858 m .55436 .40617 L .55547 .41367 L 0 .271 .104 r
F
0 g
.55436 .40617 m
.55853 .39843 L
s
.54839 .404 m
.55436 .40617 L
s
.45465 .81239 m .45181 .8067 L .44732 .80482 L 0 .827 .38 r
F
.54684 .54502 m .5471 .56221 L .54547 .55644 L 0 .23 .128 r
F
.54684 .54502 m .55127 .56123 L .5471 .56221 L F
.54684 .54502 m .55517 .55417 L .55127 .56123 L F
.54684 .54502 m .55651 .54274 L .55517 .55417 L F
0 g
.54304 .54975 m
.54684 .54502 L
s
.49318 .70308 m
.49519 .70155 L
s
.45532 .75407 m .4457 .76184 L .44981 .76368 L 0 .903 .358 r
F
0 g
.44416 .76828 m
.4457 .76184 L
s
.48009 .90091 m
.48012 .90091 L
s
.48012 .90091 m
.48015 .9009 L
s
.48015 .9009 m
.4811 .90073 L
s
.4811 .90073 m
.48573 .89725 L
s
.39834 .93512 m .39823 .9382 L .40075 .93655 L 0 1 .441 r
F
.39834 .93512 m .39179 .9391 L .39823 .9382 L F
0 g
.39823 .9382 m
.40124 .93944 L
s
.46216 .82651 m .45239 .82953 L .45585 .83538 L 0 .773 .378 r
F
.46216 .82651 m .45189 .82261 L .45239 .82953 L F
0 g
.44771 .82749 m
.45239 .82953 L
s
.41678 .62826 m .41835 .62132 L .41637 .61656 L 0 1 .382 r
F
0 g
.41835 .62132 m
.42031 .6188 L
s
.38752 .70226 m
.39111 .70653 L
s
.29569 .7977 m .29018 .80183 L .29445 .80084 L 0 1 .515 r
F
.29569 .7977 m .28492 .79993 L .29018 .80183 L F
0 g
.28976 .8051 m
.29018 .80183 L
s
.29445 .80084 m
.30028 .8024 L
s
.47023 .87325 m .47074 .88345 L .4723 .88016 L 0 .705 .397 r
F
.48132 .88804 m .4723 .88016 L .47074 .88345 L 0 .628 .392 r
F
0 g
.47074 .88345 m
.47326 .89044 L
s
.46601 .88137 m
.47074 .88345 L
s
.27606 .95813 m .27458 .96483 L .27818 .96366 L 0 1 .536 r
F
0 g
.27818 .96366 m
.2803 .96456 L
s
.27606 .95813 m .26687 .9609 L .27458 .96483 L 0 1 .536 r
F
0 g
.27458 .96483 m
.27763 .97021 L
s
.50087 .70393 m
.50262 .70197 L
s
.50323 .70129 m
.50372 .70074 L
s
.46603 .47478 m .47457 .46115 L .4733 .46375 L 0 0 0 r
F
0 g
.47457 .46115 m
.47972 .45221 L
s
.47146 .46587 m
.47457 .46115 L
s
.54692 .73248 m
.54748 .73474 L
s
.54692 .73248 m
.54744 .73307 L
s
.44163 .75002 m .4317 .74971 L .42978 .75364 L 0 1 .471 r
F
.44163 .75002 m .43592 .74731 L .4317 .74971 L F
.44163 .75002 m .44018 .74745 L .43592 .74731 L F
.45183 .74302 m .44018 .74745 L .44163 .75002 L 0 1 .461 r
F
0 g
.44163 .75002 m
.44533 .74982 L
s
.43995 .75344 m
.44163 .75002 L
s
.54939 .72636 m
.54999 .72849 L
s
.54939 .72636 m
.54981 .72676 L
s
.44196 .9869 m .43473 .98488 L .42796 .98467 L 0 1 .541 r
F
.44578 .9825 m .44196 .9869 L .44843 .98707 L 0 1 .54 r
F
.44578 .9825 m .43473 .98488 L .44196 .9869 L F
0 g
.44196 .9869 m
.44632 .98981 L
s
.45046 .77583 m .44587 .78562 L .44935 .78241 L 0 .893 .369 r
F
.45589 .78961 m .44935 .78241 L .44587 .78562 L 0 .846 .369 r
F
0 g
.44519 .79235 m
.44587 .78562 L
s
.44156 .78364 m
.44587 .78562 L
s
.48131 .98819 m .47405 .98762 L .46785 .9886 L 0 1 .54 r
F
0 g
.46767 .9885 m
.46785 .9886 L
s
.41678 .62826 m .40791 .63467 L .41231 .63398 L 0 1 .382 r
F
0 g
.41662 .63605 m
.41889 .63298 L
s
.41678 .62826 m .40592 .62991 L .40791 .63467 L 0 1 .382 r
F
.41678 .62826 m .40766 .62288 L .40592 .62991 L F
.41678 .62826 m .41214 .61716 L .40766 .62288 L F
.41678 .62826 m .41637 .61656 L .41214 .61716 L F
0 g
.41637 .61656 m
.41835 .62132 L
s
.41678 .62826 m
.41889 .63298 L
s
.41637 .61656 m
.42101 .61082 L
s
.31957 .77631 m .30847 .76832 L .30713 .77319 L 0 1 .521 r
F
.31957 .77631 m .31259 .76748 L .30847 .76832 L F
.31957 .77631 m .31735 .77091 L .31259 .76748 L F
.32967 .77371 m .31735 .77091 L .31957 .77631 L 0 1 .519 r
F
0 g
.31822 .78116 m
.31957 .77631 L
s
.31957 .77631 m
.32422 .77951 L
s
.25265 .80639 m .23932 .79964 L .23856 .80371 L 0 1 .533 r
F
.25265 .80639 m .24372 .79902 L .23932 .79964 L F
.25265 .80639 m .24944 .80192 L .24372 .79902 L F
.2634 .80427 m .24944 .80192 L .25265 .80639 L 0 1 .53 r
F
0 g
.25187 .81043 m
.25265 .80639 L
s
.25265 .80639 m
.25824 .80903 L
s
.74393 .90641 m .74794 .91321 L .7536 .90576 L 0 1 .509 r
F
0 g
.74093 .91883 m
.74794 .91321 L
s
.74648 .91884 m
.74794 .91321 L
s
.74393 .90641 m .7385 .91358 L .73722 .91889 L 0 1 .509 r
F
0 g
.72968 .92361 m
.73722 .91889 L
s
.43141 .75887 m .42103 .7634 L .4193 .76497 L 0 .931 .231 r
F
0 g
.41482 .75862 m
.41939 .75938 L
s
.43141 .75887 m .42525 .76118 L .42103 .7634 L 0 .931 .231 r
F
.43141 .75887 m .4297 .75923 L .42525 .76118 L F
.4416 .7524 m .4297 .75923 L .43141 .75887 L 0 .879 .205 r
F
0 g
.43141 .75887 m
.43546 .75673 L
s
.42968 .76044 m
.43141 .75887 L
s
.54443 .77035 m
.54792 .77522 L
s
.54398 .76408 m
.54443 .77035 L
s
.7571 .75567 m .76699 .76168 L .7624 .75776 L 0 .333 .285 r
F
.7571 .75567 m .76847 .76562 L .76699 .76168 L F
.77982 .77445 m .78826 .78419 L .79115 .78235 L 0 .419 .329 r
F
0 g
.78278 .78305 m
.78826 .78419 L
s
.78826 .78419 m
.78943 .78784 L
s
.41358 .64544 m .40482 .65201 L .40933 .65119 L 0 1 .385 r
F
.41358 .64544 m .40239 .64739 L .40482 .65201 L F
0 g
.40933 .65119 m
.41217 .65565 L
s
.41358 .64544 m .40366 .64042 L .40239 .64739 L 0 1 .385 r
F
.41358 .64544 m .40791 .63467 L .40366 .64042 L F
.41358 .64544 m .41231 .63398 L .40791 .63467 L F
.41358 .64544 m .41473 .6386 L .41231 .63398 L F
0 g
.41231 .63398 m
.41678 .62826 L
s
.41358 .64544 m
.41609 .64996 L
s
.40933 .65119 m
.41358 .64544 L
s
.41473 .6386 m
.41662 .63605 L
s
.52201 .4585 m .51803 .46831 L .51787 .46832 L 0 0 .021 r
F
.52201 .4585 m .52275 .45956 L .51803 .46831 L F
.52201 .4585 m .52887 .44794 L .52275 .45956 L F
.49272 .70677 m .48598 .71521 L .49001 .71083 L 0 1 .405 r
F
0 g
.49085 .70911 m
.4924 .70597 L
s
.49272 .70677 m .48249 .71744 L .48598 .71521 L 0 1 .405 r
F
.4825 .71561 m .4759 .72528 L .47993 .7214 L 0 .825 .321 r
F
.4825 .71561 m .47228 .72482 L .4759 .72528 L F
.49272 .70677 m .48188 .71603 L .48249 .71744 L 0 1 .405 r
F
.49272 .70677 m .4846 .71198 L .48188 .71603 L F
0 g
.48591 .71527 m
.48595 .71523 L
s
.48352 .71765 m
.48577 .71542 L
s
.48577 .71542 m
.48591 .71528 L
s
.48591 .71528 m
.48591 .71527 L
s
.49272 .70677 m .48883 .70797 L .4846 .71198 L 0 1 .405 r
F
0 g
.49079 .71023 m
.49235 .70905 L
s
.49071 .71029 m
.49079 .71023 L
s
.49043 .71051 m
.49071 .71029 L
s
.4903 .71048 m
.49032 .71045 L
s
.49019 .71061 m
.4903 .71048 L
s
.49008 .71074 m
.49012 .71069 L
s
.49012 .71069 m
.49019 .71061 L
s
.49272 .70677 m .49232 .70574 L .48883 .70797 L 0 1 .405 r
F
0 g
.49272 .70677 m
.4944 .70526 L
s
.49034 .71033 m
.49272 .70677 L
s
.49232 .70574 m
.49519 .70155 L
s
.52044 .67491 m .52344 .67119 L .52661 .66939 L 0 .027 .093 r
F
0 g
.52131 .67153 m
.52344 .67119 L
s
.5208 .67355 m
.52344 .67119 L
s
.47461 .73108 m .46583 .73428 L .46374 .73835 L 0 1 .436 r
F
.47461 .73108 m .46986 .7308 L .46583 .73428 L F
.47461 .73108 m .47362 .72943 L .46986 .7308 L F
.48425 .72081 m .47362 .72943 L .47461 .73108 L 0 1 .421 r
F
0 g
.47461 .73108 m
.47819 .72916 L
s
.47252 .73515 m
.47461 .73108 L
s
.54555 .74465 m .54418 .74628 L .5454 .75342 L 0 .851 .366 r
F
0 g
.54418 .74628 m
.5454 .75342 L
s
.54538 .7438 m
.54555 .74465 L
s
.54202 .74847 m
.5454 .75342 L
s
.54372 .74563 m
.54418 .74628 L
s
.41231 .63398 m
.41473 .6386 L
s
.54398 .76408 m
.54517 .76582 L
s
.54517 .76582 m
.54737 .76902 L
s
.48425 .72081 m .4759 .72528 L .47362 .72943 L 0 1 .421 r
F
.48425 .72081 m .47993 .7214 L .4759 .72528 L F
.48425 .72081 m .48351 .71949 L .47993 .7214 L F
0 g
.4801 .72122 m
.48021 .72111 L
s
.48009 .72124 m
.4801 .72122 L
s
.48425 .72081 m
.48764 .71824 L
s
.48197 .72495 m
.48425 .72081 L
s
.49281 .89057 m .48273 .89829 L .48573 .89725 L 0 1 .228 r
F
.4649 .84989 m .46121 .8441 L .45664 .84223 L 0 .743 .388 r
F
.49388 .71262 m .49001 .71083 L .48598 .71521 L 0 .755 .308 r
F
.49388 .71262 m .49339 .70972 L .49001 .71083 L F
.49272 .70823 m .48598 .71521 L .49001 .71083 L 0 0 .001 r
F
0 g
.49001 .71083 m
.49009 .71075 L
s
.49009 .71075 m
.49018 .71066 L
s
.49018 .71066 m
.49018 .71066 L
s
.49001 .71083 m
.49008 .71074 L
s
.49001 .71083 m
.49034 .71033 L
s
.51136 .61231 m .50936 .60988 L .50969 .61269 L 0 1 .249 r
F
.51136 .61231 m .51091 .60462 L .50936 .60988 L F
.51136 .61231 m .51329 .60043 L .51091 .60462 L F
.51136 .61231 m .51497 .60006 L .51329 .60043 L F
0 g
.51017 .61826 m
.51136 .61231 L
s
.46374 .73835 m
.46563 .73468 L
s
.50309 .65492 m .49868 .65095 L .50083 .65386 L 0 1 .368 r
F
.50309 .65492 m .49804 .64712 L .49868 .65095 L F
.50309 .65492 m .49934 .64491 L .49804 .64712 L F
.50309 .65492 m .5016 .64598 L .49934 .64491 L F
.50309 .65492 m .50332 .64961 L .5016 .64598 L F
0 g
.50309 .65492 m
.50398 .65884 L
s
.50332 .64961 m
.50529 .65124 L
s
.50332 .64961 m
.50396 .65344 L
s
.48311 .9838 m .48131 .98819 L .48719 .9873 L 0 1 .536 r
F
.48311 .9838 m .47405 .98762 L .48131 .98819 L F
0 g
.48131 .98819 m
.4863 .99007 L
s
.46206 .73313 m .45578 .7424 L .4598 .73925 L 0 .907 .345 r
F
.47228 .72482 m .46206 .73313 L .46583 .73428 L 0 .867 .333 r
F
.76327 .90549 m .7746 .8996 L .77067 .89965 L 0 1 .517 r
F
.7536 .90576 m .76327 .90549 L .76476 .89983 L 0 1 .514 r
F
0 g
.39881 .69228 m
.40213 .68627 L
s
.46179 .91107 m .44931 .91739 L .45213 .91739 L 0 1 .319 r
F
0 g
.45213 .91739 m
.45213 .91739 L
s
.45213 .91739 m
.45213 .91739 L
s
.44653 .92006 m
.45213 .91739 L
s
.50193 .66216 m
.50232 .66239 L
s
.49395 .69953 m
.49451 .69917 L
s
.4936 .70033 m
.49451 .69917 L
s
.45465 .81239 m .45189 .82261 L .45468 .81921 L 0 .827 .38 r
F
.46216 .82651 m .45468 .81921 L .45189 .82261 L 0 .773 .378 r
F
0 g
.45189 .82261 m
.45239 .82953 L
s
.4474 .82072 m
.45189 .82261 L
s
.71154 .92477 m .70575 .93038 L .704 .9345 L 0 1 .492 r
F
0 g
.69649 .93811 m
.704 .9345 L
s
.52469 .57536 m .52372 .5802 L .52307 .58009 L 0 0 .002 r
F
.52469 .57536 m .52666 .57543 L .52372 .5802 L F
.52469 .57536 m .52992 .56896 L .52666 .57543 L F
.52469 .57536 m .53152 .56425 L .52992 .56896 L F
0 g
.53152 .56425 m
.53474 .55814 L
s
.52213 .58169 m
.52469 .57536 L
s
.52212 .58174 m
.52213 .58169 L
s
.46494 .74549 m .45578 .7424 L .45385 .74875 L 0 .867 .346 r
F
.46494 .74549 m .4598 .73925 L .45578 .7424 L F
.46204 .73536 m .45578 .7424 L .4598 .73925 L 0 1 .449 r
F
.46204 .73536 m .45183 .74302 L .45578 .7424 L F
0 g
.46093 .7362 m
.46206 .73313 L
s
.45185 .7407 m
.4538 .74155 L
s
.46494 .74549 m .46373 .74057 L .4598 .73925 L 0 .867 .346 r
F
.46203 .73759 m .45578 .7424 L .4598 .73925 L 0 0 0 r
F
.46203 .73759 m .45181 .74535 L .45578 .7424 L F
0 g
.46042 .73911 m
.46374 .73835 L
s
.46006 .73904 m
.46376 .73612 L
s
.45995 .73912 m
.46006 .73904 L
s
.4539 .74411 m
.45578 .7424 L
s
.45562 .74272 m
.45578 .7424 L
s
.4598 .73925 m
.45986 .7392 L
s
.45986 .7392 m
.45995 .73912 L
s
.45997 .73921 m
.46042 .73911 L
s
.4599 .73923 m
.45997 .73921 L
s
.45546 .74263 m
.45578 .7424 L
s
.52044 .67491 m .52509 .6766 L .52228 .67621 L 0 .027 .093 r
F
.52044 .67491 m .52774 .67423 L .52509 .6766 L F
.52044 .67491 m .52846 .67069 L .52774 .67423 L F
.52044 .67491 m .52661 .66939 L .52846 .67069 L F
0 g
.51807 .67725 m
.52044 .67491 L
s
.65333 .50068 m .66224 .51736 L .65575 .49392 L 0 .284 .268 r
F
.65333 .50068 m .6674 .54076 L .66224 .51736 L F
.65333 .50068 m .6685 .55557 L .6674 .54076 L F
.65333 .50068 m .6648 .55185 L .6685 .55557 L F
.65333 .50068 m .65829 .52826 L .6648 .55185 L F
0 g
.65462 .53626 m
.655 .53797 L
s
.6486 .47916 m
.65333 .50068 L
s
.65225 .48601 m
.65333 .50068 L
s
.64915 .51126 m
.65462 .53626 L
s
.45589 .78961 m .44776 .79811 L .45205 .79983 L 0 .846 .369 r
F
0 g
.44732 .80482 m
.44776 .79811 L
s
.684 1.07353 m .67221 1.07503 L .68119 1.07519 L 0 .705 .261 r
F
.684 1.07353 m .66977 1.07431 L .67221 1.07503 L F
0 g
.66732 1.07562 m
.67221 1.07503 L
s
.38752 .70226 m .37999 .70962 L .38438 .70842 L 0 1 .41 r
F
0 g
.38438 .70842 m
.38823 .71276 L
s
.44631 .51361 m .45085 .50514 L .45265 .50001 L 0 1 .184 r
F
0 g
.54563 .74475 m
.54873 .74901 L
s
.54555 .74465 m
.54563 .74475 L
s
.36637 .71885 m
.36638 .71885 L
s
.22421 .77767 m .21819 .78478 L .22258 .78403 L 0 1 .527 r
F
.22421 .77767 m .21316 .77934 L .21819 .78478 L F
0 g
.21758 .79121 m
.21819 .78478 L
s
.22258 .78403 m
.22843 .78914 L
s
.56084 .542 m .56918 .53685 L .5718 .55139 L 0 .424 .16 r
F
0 g
.56918 .53685 m
.56975 .51671 L
s
.5645 .53285 m
.56918 .53685 L
s
.47228 .72482 m .46583 .73428 L .46986 .7308 L 0 .867 .333 r
F
.54152 .40858 m .53747 .4222 L .53683 .41638 L 0 .271 .104 r
F
.54152 .40858 m .54346 .4244 L .53747 .4222 L F
.54152 .40858 m .5508 .42149 L .54346 .4244 L F
.54152 .40858 m .55547 .41367 L .5508 .42149 L F
0 g
.53589 .40713 m
.54152 .40858 L
s
.50247 .69695 m .49517 .70585 L .49941 .70052 L 0 0 .039 r
F
.50247 .69695 m .49175 .71049 L .49517 .70585 L F
0 g
.50302 .69678 m
.50403 .69509 L
s
.50271 .69689 m
.50382 .6952 L
s
.49031 .71073 m
.49198 .71018 L
s
.49018 .71066 m
.49032 .71053 L
s
.50247 .69695 m .49143 .71135 L .49175 .71049 L 0 0 .039 r
F
0 g
.49468 .70561 m
.49534 .70472 L
s
.50247 .69695 m .49449 .70777 L .49143 .71135 L 0 0 .039 r
F
0 g
.50285 .69707 m
.50302 .69678 L
s
.50262 .69703 m
.50271 .69689 L
s
.4922 .70064 m
.49395 .69953 L
s
.49339 .70972 m
.49402 .70831 L
s
.49259 .70998 m
.49339 .70972 L
s
.50247 .69695 m .49889 .70215 L .49449 .70777 L 0 0 .039 r
F
0 g
.49282 .70809 m
.49468 .70561 L
s
.50247 .69695 m .50231 .69751 L .49889 .70215 L 0 0 .039 r
F
0 g
.50247 .69695 m
.50249 .69692 L
s
.49941 .70052 m
.50072 .69876 L
s
.50222 .69813 m
.50285 .69707 L
s
.50212 .69828 m
.50213 .69826 L
s
.50213 .69826 m
.50222 .69813 L
s
.50235 .69744 m
.50262 .69703 L
s
.50231 .69751 m
.50235 .69744 L
s
.49941 .70052 m
.50085 .69884 L
s
.50085 .69884 m
.50085 .69884 L
s
.50085 .69884 m
.50185 .69767 L
s
.50185 .69767 m
.50185 .69767 L
s
.50185 .69767 m
.50232 .69712 L
s
.50232 .69712 m
.50232 .69712 L
s
.50232 .69712 m
.50232 .69712 L
s
.50232 .69712 m
.50247 .69695 L
s
.50247 .69695 m
.50247 .69695 L
s
.65197 .54266 m
.65274 .54698 L
s
.64999 .53155 m
.65197 .54266 L
s
.50421 .70217 m .49829 .71633 L .50179 .70894 L 0 .699 .296 r
F
.50421 .70217 m .49524 .71976 L .49829 .71633 L F
0 g
.50421 .70217 m
.50443 .70171 L
s
.50411 .70243 m
.50421 .70217 L
s
.50362 .70383 m
.50411 .70243 L
s
.52485 .68873 m
.52485 .68873 L
s
.52461 .68818 m
.52485 .68873 L
s
.52458 .68811 m
.52461 .68818 L
s
.52458 .68811 m
.52458 .68811 L
s
.52458 .68811 m
.52458 .68811 L
s
.52453 .68799 m
.52458 .68811 L
s
.51721 .95791 m .51096 .95796 L .51749 .96455 L 0 .383 .371 r
F
0 g
.50621 .95113 m
.51096 .95796 L
s
.50594 .95476 m
.51096 .95796 L
s
.79727 .59968 m .80391 .59859 L .80853 .60135 L 0 .021 0 r
F
.79727 .59968 m .79909 .59787 L .80391 .59859 L F
0 g
.80092 .59673 m
.80391 .59859 L
s
.55294 1.04199 m
.55315 1.0421 L
s
.48351 .71949 m
.48555 .71594 L
s
.49388 .71262 m .48598 .71521 L .4835 .72132 L 0 .755 .308 r
F
.49272 .70823 m .48248 .71927 L .48598 .71521 L 0 0 .001 r
F
0 g
.48587 .71533 m
.48598 .71521 L
s
.48589 .71526 m
.48598 .71521 L
s
.48538 .71559 m
.48589 .71526 L
s
.49186 .70905 m
.49199 .70893 L
s
.48595 .71523 m
.48598 .71521 L
s
.48021 .72111 m
.48217 .71906 L
s
.48217 .71906 m
.48352 .71765 L
s
.48575 .71578 m
.48576 .71574 L
s
.48537 .71671 m
.48575 .71578 L
s
.41913 .93056 m .40453 .9341 L .40727 .93514 L 0 1 .425 r
F
0 g
.40075 .93655 m
.40727 .93514 L
s
.46494 .74549 m .45385 .74875 L .45532 .75407 L 0 .867 .346 r
F
0 g
.45385 .74875 m
.45578 .7424 L
s
.44983 .74696 m
.45385 .74875 L
s
.45985 .73926 m
.45988 .73928 L
s
.42414 .98145 m .40826 .97978 L .4121 .983 L 0 1 .54 r
F
0 g
.40502 .98222 m
.4121 .983 L
s
.51497 .60006 m
.51565 .59782 L
s
.35226 .96845 m .35186 .97436 L .35488 .97288 L 0 1 .537 r
F
.35226 .96845 m .34447 .97201 L .35186 .97436 L F
0 g
.35186 .97436 m
.35523 .9786 L
s
.36002 .76528 m .35427 .77077 L .35828 .76953 L 0 1 .514 r
F
.36002 .76528 m .34989 .76821 L .35427 .77077 L F
0 g
.35314 .77514 m
.35427 .77077 L
s
.35828 .76953 m
.36305 .77186 L
s
.54893 .64214 m
.54993 .65224 L
s
.45939 .76723 m .44848 .77026 L .45046 .77583 L 0 .86 .357 r
F
.45939 .76723 m .44981 .76368 L .44848 .77026 L F
0 g
.44416 .76828 m
.44848 .77026 L
s
.49177 .70415 m .4846 .71198 L .48883 .70797 L 0 1 .405 r
F
.49177 .70415 m .48106 .71386 L .4846 .71198 L F
.49177 .70415 m .48058 .71238 L .48106 .71386 L F
.49177 .70415 m .48352 .70856 L .48058 .71238 L F
0 g
.49032 .71053 m
.49186 .70905 L
s
.49177 .70415 m .48792 .70495 L .48352 .70856 L 0 1 .405 r
F
0 g
.49189 .70601 m
.49232 .70574 L
s
.48883 .70797 m
.49189 .70601 L
s
.49177 .70415 m .49145 .70306 L .48792 .70495 L 0 1 .405 r
F
0 g
.49177 .70415 m
.49318 .70308 L
s
.48883 .70797 m
.49177 .70415 L
s
.49145 .70306 m
.4936 .70033 L
s
.28544 .95086 m .28381 .95555 L .28742 .95434 L 0 1 .522 r
F
0 g
.28742 .95434 m
.29548 .95571 L
s
.28544 .95086 m .27623 .9537 L .28381 .95555 L 0 1 .522 r
F
0 g
.28381 .95555 m
.28669 .95893 L
s
.45532 .75407 m .44981 .76368 L .45358 .76047 L 0 .903 .358 r
F
.45939 .76723 m .45358 .76047 L .44981 .76368 L 0 .86 .357 r
F
0 g
.44848 .77026 m
.44981 .76368 L
s
.4457 .76184 m
.44981 .76368 L
s
.44578 .9825 m .44843 .98707 L .44984 .98527 L 0 1 .54 r
F
.4633 .98621 m .44984 .98527 L .44843 .98707 L 0 1 .541 r
F
0 g
.44843 .98707 m
.453 .98945 L
s
.44196 .9869 m
.44843 .98707 L
s
.47362 .72943 m
.47561 .72581 L
s
.38752 .70226 m .37651 .7051 L .37999 .70962 L 0 1 .41 r
F
0 g
.3773 .71589 m
.37999 .70962 L
s
.49145 .69799 m
.4929 .69724 L
s
.4929 .69724 m
.49404 .69665 L
s
.4924 .69847 m
.49404 .69665 L
s
.4337 .55137 m .42515 .55876 L .42852 .55791 L 0 1 .328 r
F
.4337 .55137 m .42552 .55361 L .42515 .55876 L F
0 g
.43094 .55862 m
.43358 .55682 L
s
.4337 .55137 m .4294 .54589 L .42552 .55361 L 0 1 .328 r
F
.4337 .55137 m .43458 .53936 L .4294 .54589 L F
.4337 .55137 m .43761 .53835 L .43458 .53936 L F
0 g
.42852 .55791 m
.4337 .55137 L
s
.43358 .55681 m
.4337 .55137 L
s
.43761 .53835 m
.44276 .5314 L
s
.43723 .5435 m
.43761 .53835 L
s
.50475 .63596 m .50615 .6337 L .50659 .62922 L 0 1 .342 r
F
0 g
.50615 .6337 m
.50779 .63597 L
s
.26703 .95656 m .24836 .95135 L .25079 .95524 L 0 1 .529 r
F
.26703 .95656 m .25221 .95037 L .24836 .95135 L F
.26703 .95656 m .26023 .95261 L .25221 .95037 L F
.27623 .9537 m .26023 .95261 L .26703 .95656 L 0 1 .526 r
F
0 g
.26703 .95656 m
.27465 .95856 L
s
.26703 .95656 m
.26927 .96018 L
s
.31929 .96331 m .31829 .96955 L .32162 .96822 L 0 1 .536 r
F
.31929 .96331 m .31075 .96649 L .31829 .96955 L F
0 g
.31829 .96955 m
.32145 .97429 L
s
.46216 .82651 m .45585 .83538 L .46025 .83705 L 0 .773 .378 r
F
0 g
.45585 .83538 m
.45664 .84223 L
s
.42755 .74933 m .42115 .7554 L .42537 .75318 L 0 1 .482 r
F
.42755 .74933 m .41687 .7547 L .42115 .7554 L F
0 g
.41939 .75938 m
.42115 .7554 L
s
.42537 .75318 m
.42978 .75364 L
s
.54773 .74292 m
.54834 .74584 L
s
.54751 .74189 m
.54773 .74292 L
s
.50101 .65867 m .50183 .65716 L .50083 .65386 L 0 1 .373 r
F
0 g
.50123 .65516 m
.50183 .65716 L
s
.50106 .65461 m
.50123 .65516 L
s
.50183 .65716 m
.50406 .6592 L
s
.50693 .42703 m .51858 .41752 L .51873 .42248 L 0 .044 .076 r
F
0 g
.51858 .41752 m
.52337 .40838 L
s
.51352 .41947 m
.51858 .41752 L
s
.38752 .70226 m .37627 .69788 L .37651 .7051 L 0 1 .41 r
F
.38752 .70226 m .37941 .69171 L .37627 .69788 L F
.38752 .70226 m .38384 .6907 L .37941 .69171 L F
.38752 .70226 m .38731 .69523 L .38384 .6907 L F
0 g
.38438 .70842 m
.38752 .70226 L
s
.57294 .4101 m
.57482 .41275 L
s
.57482 .41275 m
.57511 .41315 L
s
.57511 .41315 m
.57536 .4135 L
s
.57536 .4135 m
.57562 .41387 L
s
.5688 .4179 m
.57294 .4101 L
s
.49272 .70823 m .48186 .72031 L .48248 .71927 L 0 0 .001 r
F
0 g
.48032 .72119 m
.48046 .72112 L
s
.48046 .72112 m
.48351 .71949 L
s
.49272 .70823 m .48457 .71772 L .48186 .72031 L 0 0 .001 r
F
0 g
.48006 .72112 m
.4821 .71652 L
s
.49272 .70823 m .48881 .71322 L .48457 .71772 L 0 0 .001 r
F
0 g
.48481 .71595 m
.48538 .71559 L
s
.49272 .70823 m .4923 .70915 L .48881 .71322 L 0 0 .001 r
F
0 g
.49199 .70893 m
.49272 .70823 L
s
.49272 .70823 m
.49282 .70809 L
s
.81724 .68869 m .82009 .70331 L .82465 .70484 L 0 1 .513 r
F
.81724 .68869 m .81691 .69641 L .82009 .70331 L F
0 g
.81546 .70836 m
.82009 .70331 L
s
.45183 .74302 m .44226 .74355 L .44018 .74745 L 0 1 .461 r
F
.45183 .74302 m .44649 .74093 L .44226 .74355 L F
.45183 .74302 m .45059 .74071 L .44649 .74093 L F
.46204 .73536 m .45059 .74071 L .45183 .74302 L 0 1 .449 r
F
0 g
.45183 .74302 m
.45567 .74241 L
s
.44987 .74668 m
.45183 .74302 L
s
.50048 .66554 m
.50069 .66561 L
s
.47227 .72689 m .46583 .73428 L .46986 .7308 L 0 1 .436 r
F
0 g
.47073 .72866 m
.47228 .72482 L
s
.47227 .72689 m .46204 .73536 L .46583 .73428 L 0 1 .436 r
F
0 g
.46206 .73313 m
.46402 .73373 L
s
.47458 .73592 m .46986 .7308 L .46583 .73428 L 0 .83 .333 r
F
.47458 .73592 m .47361 .7315 L .46986 .7308 L F
.47225 .72896 m .46583 .73428 L .46986 .7308 L 0 0 0 r
F
.47458 .73592 m .46583 .73428 L .46373 .74057 L 0 .83 .333 r
F
.47225 .72896 m .46203 .73759 L .46583 .73428 L 0 0 0 r
F
0 g
.47002 .73065 m
.47014 .73055 L
s
.46986 .7308 m
.46993 .73074 L
s
.46993 .73074 m
.47002 .73065 L
s
.47014 .73055 m
.47364 .72736 L
s
.46563 .73468 m
.46575 .73445 L
s
.47024 .73066 m
.47362 .72943 L
s
.46546 .73461 m
.46583 .73428 L
s
.36964 .94115 m .36907 .94462 L .3719 .94312 L 0 1 .474 r
F
.36964 .94115 m .36232 .94475 L .36907 .94462 L F
0 g
.36907 .94462 m
.37201 .94642 L
s
.39179 .9391 m .37616 .94088 L .37885 .94249 L 0 1 .465 r
F
0 g
.3719 .94312 m
.37885 .94249 L
s
.48249 .71744 m .4759 .72528 L .47993 .7214 L 0 1 .422 r
F
.48423 .72509 m .47993 .7214 L .4759 .72528 L 0 .793 .321 r
F
.48423 .72509 m .4835 .72132 L .47993 .7214 L F
.48248 .71927 m .4759 .72528 L .47993 .7214 L 0 0 0 r
F
0 g
.47993 .7214 m
.48 .72135 L
s
.47993 .7214 m
.48009 .72124 L
s
.47993 .7214 m
.4802 .72098 L
s
.34447 .97201 m .32662 .96623 L .32952 .97083 L 0 1 .537 r
F
0 g
.50464 .69468 m
.50529 .69355 L
s
.50363 .69645 m
.50464 .69468 L
s
.50333 .69697 m
.50363 .69645 L
s
.50217 .699 m
.50333 .69697 L
s
.50528 .69355 m
.50529 .69355 L
s
.50453 .69476 m
.50528 .69355 L
s
.50338 .6966 m
.50453 .69476 L
s
.5031 .69704 m
.50338 .6966 L
s
.50217 .69854 m
.5031 .69704 L
s
.40621 .75968 m .39564 .75668 L .39373 .76069 L 0 1 .495 r
F
.40621 .75968 m .40002 .75499 L .39564 .75668 L F
.40621 .75968 m .40455 .75628 L .40002 .75499 L F
.41687 .7547 m .40455 .75628 L .40621 .75968 L 0 1 .489 r
F
0 g
.40429 .76369 m
.40621 .75968 L
s
.40621 .75968 m
.41061 .76068 L
s
.70223 .91919 m .69664 .92129 L .69508 .92432 L 0 1 .519 r
F
0 g
.69508 .92432 m
.69664 .92129 L
s
.68771 .92442 m
.69508 .92432 L
s
.45589 .78961 m .45364 .78412 L .44935 .78241 L 0 .846 .369 r
F
.36514 .78606 m .35388 .7858 L .35281 .78784 L 0 1 .437 r
F
.36514 .78606 m .3579 .78465 L .35388 .7858 L F
.36514 .78606 m .36273 .78477 L .3579 .78465 L F
.37491 .78256 m .36273 .78477 L .36514 .78606 L 0 1 .408 r
F
0 g
.36405 .78809 m
.36514 .78606 L
s
.36514 .78606 m
.36983 .78592 L
s
.54737 .76902 m
.54792 .77522 L
s
.47447 .86431 m .46592 .86732 L .47023 .87325 L 0 .676 .385 r
F
.47447 .86431 m .46418 .86029 L .46592 .86732 L F
0 g
.46119 .86526 m
.46592 .86732 L
s
.38074 .97827 m
.38863 .97927 L
s
.52222 .98188 m
.52318 .98189 L
s
.52318 .98189 m
.52444 .98136 L
s
.52444 .98136 m
.52449 .98134 L
s
.52449 .98134 m
.52523 .98102 L
s
.52523 .98102 m
.52699 .98027 L
s
.52699 .98027 m
.52707 .98024 L
s
.52707 .98024 m
.52708 .98023 L
s
.52708 .98023 m
.52748 .98006 L
s
.48249 .71744 m .47227 .72689 L .4759 .72528 L 0 1 .422 r
F
0 g
.47228 .72482 m
.47424 .72507 L
s
.48423 .72509 m .4759 .72528 L .47361 .7315 L 0 .793 .321 r
F
.48248 .71927 m .47225 .72896 L .4759 .72528 L 0 0 0 r
F
0 g
.48 .72135 m
.48034 .72107 L
s
.47364 .72736 m
.4759 .72528 L
s
.47561 .72581 m
.47565 .72575 L
s
.51738 .67961 m
.51738 .67961 L
s
.42484 .92637 m .42512 .92896 L .42729 .92722 L 0 1 .386 r
F
.42484 .92637 m .41913 .93056 L .42512 .92896 L F
0 g
.42512 .92896 m
.42811 .92957 L
s
.61803 .42341 m .61746 .43125 L .61502 .42493 L 0 .447 .061 r
F
.61803 .42341 m .62443 .4399 L .61746 .43125 L F
.61803 .42341 m .63127 .44509 L .62443 .4399 L F
.61803 .42341 m .63426 .44353 L .63127 .44509 L F
.61803 .42341 m .63141 .43629 L .63426 .44353 L F
0 g
.63132 .43618 m
.63141 .43629 L
s
.63157 .43644 m
.63354 .43834 L
s
.63141 .43629 m
.63157 .43644 L
s
.61135 .41427 m
.61803 .42341 L
s
.62994 .43448 m
.63132 .43618 L
s
.62446 .42768 m
.62994 .43448 L
s
.77618 .88449 m .7746 .8996 L .78133 .89288 L 0 1 .507 r
F
.77618 .88449 m .77067 .89965 L .7746 .8996 L F
0 g
.77292 .90556 m
.7746 .8996 L
s
.50823 .70191 m
.50823 .7019 L
s
.50823 .70192 m
.50823 .7019 L
s
.49092 .69513 m
.49208 .69468 L
s
.49208 .69468 m
.49376 .69401 L
s
.49154 .69616 m
.49376 .69401 L
s
.32967 .77371 m .31879 .7662 L .31735 .77091 L 0 1 .519 r
F
.32967 .77371 m .32292 .76533 L .31879 .7662 L F
.32967 .77371 m .32758 .76855 L .32292 .76533 L F
.33977 .77101 m .32758 .76855 L .32967 .77371 L 0 1 .518 r
F
0 g
.32822 .7784 m
.32967 .77371 L
s
.32967 .77371 m
.33423 .7767 L
s
.5028 .93473 m .49719 .92851 L .49251 .92596 L 0 .482 .39 r
F
.39536 .77461 m .3897 .77797 L .39374 .77625 L 0 1 .322 r
F
.39536 .77461 m .38513 .7787 L .3897 .77797 L F
0 g
.38861 .77976 m
.3897 .77797 L
s
.39374 .77625 m
.39855 .77526 L
s
.50465 .64097 m
.50467 .64021 L
s
.52118 .69162 m
.52219 .69359 L
s
.52219 .69359 m
.52259 .69438 L
s
.52259 .69438 m
.52451 .69812 L
s
.52118 .69162 m
.52118 .69162 L
s
.52118 .69162 m
.52248 .69272 L
s
.52248 .69272 m
.52292 .69309 L
s
.52292 .69309 m
.52458 .69449 L
s
.37651 .7051 m .369 .71248 L .37339 .71135 L 0 1 .419 r
F
0 g
.37339 .71135 m
.3773 .71589 L
s
.4015 .9786 m .38509 .97565 L .38863 .97927 L 0 1 .539 r
F
.48249 .71744 m .47145 .72515 L .47227 .72689 L 0 1 .422 r
F
0 g
.47544 .72575 m
.4759 .72528 L
s
.48249 .71744 m .47401 .72119 L .47145 .72515 L 0 1 .422 r
F
.48249 .71744 m .47825 .71764 L .47401 .72119 L F
.48249 .71744 m .48188 .71603 L .47825 .71764 L F
0 g
.48249 .71744 m
.48481 .71595 L
s
.4802 .72098 m
.48249 .71744 L
s
.47819 .89648 m
.48009 .90091 L
s
.49077 .91161 m .48569 .90555 L .48109 .90325 L 0 .565 .395 r
F
0 g
.48009 .90091 m
.48109 .90325 L
s
.50141 .69872 m
.50141 .69872 L
s
.50141 .69872 m
.50197 .69796 L
s
.50197 .69796 m
.50197 .69796 L
s
.50197 .69796 m
.50197 .69796 L
s
.50197 .69796 m
.50211 .69778 L
s
.50211 .69778 m
.50225 .69758 L
s
.50225 .69758 m
.50225 .69758 L
s
.50225 .69758 m
.50225 .69758 L
s
.50225 .69758 m
.50231 .69751 L
s
.55726 .80517 m
.55797 .80595 L
s
.55797 .80595 m
.5583 .80631 L
s
.5583 .80631 m
.55834 .80635 L
s
.55834 .80635 m
.55869 .80674 L
s
.55709 .80056 m
.5571 .80032 L
s
.55699 .80364 m
.55709 .80056 L
s
.49105 .70137 m .48352 .70856 L .48792 .70495 L 0 1 .404 r
F
.49105 .70137 m .47997 .7101 L .48352 .70856 L F
.49105 .70137 m .47963 .70855 L .47997 .7101 L F
.49105 .70137 m .48276 .70497 L .47963 .70855 L F
.49105 .70137 m .48727 .70176 L .48276 .70497 L F
0 g
.49111 .70324 m
.49145 .70306 L
s
.48792 .70495 m
.49111 .70324 L
s
.49105 .70137 m .49082 .70022 L .48727 .70176 L 0 1 .404 r
F
0 g
.49105 .70137 m
.4922 .70064 L
s
.48792 .70495 m
.49105 .70137 L
s
.49082 .70022 m
.4924 .69847 L
s
.49077 .91161 m .48885 .91923 L .49347 .92155 L 0 .565 .395 r
F
0 g
.48885 .91923 m
.49251 .92596 L
s
.50101 .65867 m .49591 .65588 L .49847 .65812 L 0 1 .373 r
F
.50101 .65867 m .49491 .65257 L .49591 .65588 L F
.50101 .65867 m .49614 .6504 L .49491 .65257 L F
.50101 .65867 m .49868 .65095 L .49614 .6504 L F
.50101 .65867 m .50083 .65386 L .49868 .65095 L F
0 g
.50083 .65386 m
.50106 .65461 L
s
.50083 .65386 m
.50309 .65492 L
s
.50101 .65867 m
.50232 .66239 L
s
.48311 .9838 m .46937 .98587 L .47405 .98762 L 0 1 .536 r
F
0 g
.46785 .9886 m
.47405 .98762 L
s
.53529 .68167 m .54284 .68254 L .53842 .67908 L 0 .444 .255 r
F
0 g
.53609 .68101 m
.53842 .67908 L
s
.53658 .67502 m
.53842 .67908 L
s
.53529 .68167 m .54646 .69518 L .54284 .68254 L 0 .444 .255 r
F
.53529 .68167 m .54685 .70861 L .54646 .69518 L F
.53529 .68167 m .54371 .71121 L .54685 .70861 L F
.53529 .68167 m .53914 .70123 L .54371 .71121 L F
.53529 .68167 m .53553 .68858 L .53914 .70123 L F
0 g
.5352 .68153 m
.53529 .68167 L
s
.53529 .68167 m
.53609 .68101 L
s
.3989 .682 m .39061 .68911 L .39522 .688 L 0 1 .4 r
F
.3989 .682 m .3874 .68465 L .39061 .68911 L F
0 g
.39522 .688 m
.39881 .69228 L
s
.3989 .682 m .38773 .67759 L .3874 .68465 L 0 1 .4 r
F
.3989 .682 m .39142 .67158 L .38773 .67759 L F
.3989 .682 m .39601 .67065 L .39142 .67158 L F
.3989 .682 m .39921 .67511 L .39601 .67065 L F
0 g
.3989 .682 m
.40213 .68627 L
s
.39522 .688 m
.3989 .682 L
s
.45939 .76723 m .45046 .77583 L .45457 .77735 L 0 .86 .357 r
F
0 g
.44935 .78241 m
.45046 .77583 L
s
.46494 .74549 m .45532 .75407 L .45925 .7554 L 0 .867 .346 r
F
0 g
.49459 .71207 m
.49708 .71014 L
s
.78279 .67641 m .79402 .68812 L .79427 .68095 L 0 1 .497 r
F
0 g
.79402 .68812 m
.79725 .69484 L
s
.7904 .69198 m
.79402 .68812 L
s
.4416 .7524 m .43159 .75769 L .4297 .75923 L 0 .879 .205 r
F
.4416 .7524 m .43582 .75525 L .43159 .75769 L F
.4416 .7524 m .44011 .75299 L .43582 .75525 L F
.45181 .74535 m .44011 .75299 L .4416 .7524 L 0 .806 .171 r
F
0 g
.4416 .7524 m
.44546 .74997 L
s
.43971 .75395 m
.4416 .7524 L
s
.45939 .76723 m .45769 .76199 L .45358 .76047 L 0 .86 .357 r
F
0 g
.45358 .76047 m
.45532 .75407 L
s
.4649 .84989 m .46418 .86029 L .46617 .85684 L 0 .743 .388 r
F
.47447 .86431 m .46617 .85684 L .46418 .86029 L 0 .676 .385 r
F
0 g
.46418 .86029 m
.46592 .86732 L
s
.45961 .85841 m
.46418 .86029 L
s
.29483 .94343 m .29305 .94605 L .29666 .94479 L 0 .987 .289 r
F
0 g
.29666 .94479 m
.30457 .94399 L
s
.29483 .94343 m .2856 .94635 L .29305 .94605 L 0 .987 .289 r
F
0 g
.29305 .94605 m
.29577 .94735 L
s
.50498 .70619 m .50466 .7046 L .50179 .70894 L 0 .681 .296 r
F
0 g
.50466 .7046 m
.50481 .7041 L
s
.23527 .77598 m .22916 .7829 L .23355 .78214 L 0 1 .527 r
F
.23527 .77598 m .22421 .77767 L .22916 .7829 L F
0 g
.22843 .78914 m
.22916 .7829 L
s
.23355 .78214 m
.23929 .78704 L
s
.31964 .95189 m .30187 .94953 L .30429 .95252 L 0 1 .515 r
F
.31964 .95189 m .30549 .94833 L .30187 .94953 L F
.31964 .95189 m .31312 .94935 L .30549 .94833 L F
.32819 .94851 m .31312 .94935 L .31964 .95189 L 0 1 .507 r
F
0 g
.31964 .95189 m
.32701 .95272 L
s
.31964 .95189 m
.32202 .95488 L
s
.49388 .71262 m .48762 .72398 L .4914 .71874 L 0 .755 .308 r
F
.49388 .71262 m .48423 .72509 L .48762 .72398 L F
.49388 .71262 m .4835 .72132 L .48423 .72509 L F
0 g
.48274 .71897 m
.48579 .71542 L
s
.48579 .71542 m
.48587 .71533 L
s
.4835 .72132 m
.48525 .717 L
s
.49388 .71262 m
.49459 .71207 L
s
.48024 .7214 m
.4835 .72132 L
s
.37651 .7051 m .3655 .70776 L .369 .71248 L 0 1 .419 r
F
0 g
.36638 .71885 m
.369 .71248 L
s
.46191 .80322 m .45181 .8067 L .45465 .81239 L 0 .797 .368 r
F
.46191 .80322 m .45205 .79983 L .45181 .8067 L F
0 g
.44732 .80482 m
.45181 .8067 L
s
.49784 .66826 m
.4992 .66886 L
s
.75646 .65878 m
.75829 .65748 L
s
.49061 .6921 m
.49147 .69187 L
s
.49147 .69187 m
.49369 .69126 L
s
.49098 .69352 m
.49369 .69126 L
s
.47458 .73592 m .46373 .74057 L .46494 .74549 L 0 .83 .333 r
F
0 g
.45988 .73928 m
.46373 .74057 L
s
.46373 .74057 m
.46579 .73441 L
s
.66505 1.07402 m
.66505 1.07402 L
s
.46204 .73536 m .45284 .73682 L .45059 .74071 L 0 1 .449 r
F
.46204 .73536 m .45707 .73395 L .45284 .73682 L F
.46204 .73536 m .46102 .73332 L .45707 .73395 L F
.47227 .72689 m .46102 .73332 L .46204 .73536 L 0 1 .436 r
F
0 g
.46204 .73536 m
.46583 .73428 L
s
.4598 .73925 m
.46204 .73536 L
s
.48262 .71303 m
.4846 .71198 L
s
.48188 .71603 m
.4846 .71198 L
s
.39921 .67511 m
.40288 .66921 L
s
.48132 .88804 m .47819 .89647 L .48259 .89839 L 0 .628 .392 r
F
.48127 .89741 m .47817 .90125 L .48259 .89839 L 0 1 .227 r
F
.48271 .89828 m .48259 .89839 L .48273 .89829 L F
.48127 .89741 m .48259 .89839 L .48271 .89828 L F
.48271 .89828 m .48259 .89839 L .48273 .89845 L 0 .628 .392 r
F
.48132 .88804 m .48259 .89839 L .48271 .89828 L F
0 g
.47819 .89647 m
.48103 .89771 L
s
.75441 .927 m .75079 .93539 L .75815 .93366 L 0 1 .526 r
F
.75441 .927 m .74703 .934 L .75079 .93539 L F
0 g
.74832 .93911 m
.75079 .93539 L
s
.67778 .93997 m .68185 .94302 L .6881 .93862 L 0 1 .413 r
F
0 g
.67494 .9462 m
.68185 .94302 L
s
.28995 .73578 m
.28995 .73578 L
s
.30366 .73311 m
.30366 .73311 L
s
.2634 .80427 m .25032 .79808 L .24944 .80192 L 0 1 .53 r
F
.2634 .80427 m .25472 .79745 L .25032 .79808 L F
.2634 .80427 m .26033 .80011 L .25472 .79745 L F
.27415 .80212 m .26033 .80011 L .2634 .80427 L 0 1 .527 r
F
0 g
.2625 .80809 m
.2634 .80427 L
s
.2634 .80427 m
.26888 .80666 L
s
.39179 .9391 m .37901 .9394 L .37616 .94088 L 0 1 .465 r
F
.39179 .9391 m .38571 .93864 L .37901 .9394 L F
.39834 .93512 m .38571 .93864 L .39179 .9391 L 0 1 .441 r
F
0 g
.39179 .9391 m
.39823 .9382 L
s
.39179 .9391 m
.39445 .94072 L
s
.49877 .66986 m
.49877 .66986 L
s
.49836 .66983 m
.49877 .66986 L
s
.46603 .47478 m .45892 .48511 L .46065 .48303 L 0 0 0 r
F
.46603 .47478 m .46204 .48037 L .45892 .48511 L F
.46603 .47478 m .46793 .47198 L .46204 .48037 L F
0 g
.46124 .48301 m
.46324 .47998 L
s
.46603 .47478 m .4733 .46375 L .46793 .47198 L 0 0 0 r
F
0 g
.46324 .47998 m
.46603 .47478 L
s
.48311 .9838 m .48719 .9873 L .48779 .98555 L 0 1 .536 r
F
.50039 .98387 m .48779 .98555 L .48719 .9873 L 0 1 .53 r
F
0 g
.48719 .9873 m
.49227 .98835 L
s
.48131 .98819 m
.48719 .9873 L
s
.47227 .72689 m .46342 .72941 L .46102 .73332 L 0 1 .436 r
F
.47227 .72689 m .46766 .72623 L .46342 .72941 L F
0 g
.46986 .7308 m
.46997 .73072 L
s
.47227 .72689 m .47145 .72515 L .46766 .72623 L 0 1 .436 r
F
0 g
.47227 .72689 m
.4759 .72528 L
s
.46986 .7308 m
.47227 .72689 L
s
.69746 1.07593 m .7098 1.07608 L .70702 1.07564 L 0 .864 .315 r
F
.72103 1.07305 m .7098 1.07608 L .71903 1.07517 L 0 .786 .267 r
F
.72103 1.07305 m .70702 1.07564 L .7098 1.07608 L F
0 g
.71398 1.07677 m
.71462 1.07657 L
s
.70415 1.07726 m
.7098 1.07608 L
s
.30894 .79488 m .30159 .79916 L .30683 .79792 L 0 1 .504 r
F
.30894 .79488 m .29569 .7977 L .30159 .79916 L F
0 g
.30028 .8024 m
.30159 .79916 L
s
.30683 .79792 m
.31323 .79901 L
s
.4958 .88954 m
.49982 .88592 L
s
.50475 .63596 m .50659 .62922 L .50579 .6255 L 0 1 .342 r
F
0 g
.50659 .62922 m
.50826 .6303 L
s
.50615 .6337 m
.50659 .62922 L
s
.81724 .68869 m .82465 .70484 L .82835 .70002 L 0 1 .513 r
F
0 g
.82465 .70484 m
.8268 .71234 L
s
.45589 .78961 m .45205 .79983 L .4552 .79635 L 0 .846 .369 r
F
.46191 .80322 m .4552 .79635 L .45205 .79983 L 0 .797 .368 r
F
0 g
.45181 .8067 m
.45205 .79983 L
s
.44776 .79811 m
.45205 .79983 L
s
.7744 .58616 m .78757 .59067 L .78584 .59343 L 0 .199 0 r
F
0 g
.78539 .58589 m
.78757 .59067 L
s
.78757 .59067 m
.79234 .59098 L
s
.50475 .63596 m .50148 .63249 L .50275 .63544 L 0 1 .342 r
F
.50475 .63596 m .50193 .628 L .50148 .63249 L F
.50475 .63596 m .50379 .62498 L .50193 .628 L F
.50475 .63596 m .50579 .6255 L .50379 .62498 L F
0 g
.50467 .64021 m
.50475 .63596 L
s
.44578 .9825 m .43066 .9821 L .43473 .98488 L 0 1 .54 r
F
0 g
.42796 .98467 m
.43473 .98488 L
s
.37015 .7622 m .36431 .76762 L .36832 .76632 L 0 1 .511 r
F
.37015 .7622 m .36002 .76528 L .36431 .76762 L F
0 g
.36305 .77186 m
.36431 .76762 L
s
.36832 .76632 m
.37296 .76843 L
s
.49906 .66244 m .49982 .66093 L .49847 .65812 L 0 1 .377 r
F
0 g
.49982 .66093 m
.50193 .66216 L
s
.6169 1.37723 m
.61695 1.38053 L
s
.49105 .68881 m
.49383 .68841 L
s
.49155 .69003 m
.49383 .68841 L
s
.46216 .82651 m .45908 .82088 L .45468 .81921 L 0 .773 .378 r
F
.49056 .69844 m .48276 .70497 L .48727 .70176 L 0 1 .403 r
F
.49056 .69844 m .47923 .70617 L .48276 .70497 L F
.49056 .69844 m .47903 .70455 L .47923 .70617 L F
.49056 .69844 m .48232 .70123 L .47903 .70455 L F
.49056 .69844 m .4869 .69842 L .48232 .70123 L F
0 g
.49055 .70034 m
.49082 .70022 L
s
.49056 .69844 m .49043 .69723 L .4869 .69842 L 0 1 .403 r
F
0 g
.49056 .69844 m
.49145 .69799 L
s
.49043 .69723 m
.49154 .69616 L
s
.3655 .70777 m .35834 .71509 L .36255 .71408 L 0 1 .428 r
F
0 g
.36255 .71408 m
.36637 .71885 L
s
.54945 .76273 m
.54981 .76321 L
s
.52947 .66532 m .53457 .6699 L .53138 .66884 L 0 .104 .11 r
F
.52947 .66532 m .53768 .66506 L .53457 .6699 L F
.52947 .66532 m .53863 .65756 L .53768 .66506 L F
0 g
.52661 .66939 m
.52947 .66532 L
s
.43824 .74352 m .4317 .74971 L .43592 .74731 L 0 1 .473 r
F
.43824 .74352 m .42755 .74933 L .4317 .74971 L F
0 g
.42978 .75364 m
.4317 .74971 L
s
.43592 .74731 m
.44018 .74745 L
s
.69074 1.07469 m .69746 1.07593 L .70283 1.07501 L 0 .775 .287 r
F
.48423 .72509 m .47361 .7315 L .47458 .73592 L 0 .793 .321 r
F
0 g
.47004 .73083 m
.47361 .7315 L
s
.47361 .7315 m
.47578 .72563 L
s
.79657 .88371 m .80675 .88376 L .80777 .87672 L 0 1 .512 r
F
0 g
.38731 .69523 m
.38732 .69522 L
s
.38732 .69522 m
.39061 .68911 L
s
.5028 .93473 m .50199 .94193 L .50668 .9445 L 0 .482 .39 r
F
.51949 .67828 m .51988 .67693 L .52228 .67621 L 0 .066 .098 r
F
0 g
.51806 .67726 m
.51988 .67693 L
s
.37819 .97393 m .35993 .97043 L .36251 .97477 L 0 1 .538 r
F
0 g
.35488 .97288 m
.36251 .97477 L
s
.49648 .67315 m
.4975 .67306 L
s
.50498 .70619 m .49966 .72233 L .50284 .71378 L 0 .681 .296 r
F
.50498 .70619 m .49678 .72668 L .49966 .72233 L F
.50498 .70619 m .49614 .72394 L .49678 .72668 L F
.50498 .70619 m .49829 .71633 L .49614 .72394 L F
0 g
.49569 .71407 m
.49708 .71014 L
s
.50498 .70619 m .50179 .70894 L .49829 .71633 L 0 .681 .296 r
F
0 g
.50485 .70664 m
.50498 .70619 L
s
.50498 .70619 m
.50627 .70278 L
s
.50179 .70894 m
.50347 .70423 L
s
.50179 .70894 m
.50466 .7046 L
s
.37651 .7051 m .36523 .70035 L .3655 .70776 L 0 1 .419 r
F
0 g
.3655 .70776 m
.369 .71248 L
s
.37651 .7051 m .36835 .69409 L .36523 .70035 L 0 1 .419 r
F
.37651 .7051 m .37278 .69316 L .36835 .69409 L F
.37651 .7051 m .37627 .69788 L .37278 .69316 L F
0 g
.37651 .7051 m
.37999 .70962 L
s
.37339 .71135 m
.37651 .7051 L
s
.7713 .67132 m .7795 .66974 L .77489 .66778 L 0 .965 .489 r
F
0 g
.77467 .668 m
.77489 .66778 L
s
.7713 .67132 m .78279 .67641 L .7795 .66974 L 0 .965 .489 r
F
0 g
.7713 .67132 m
.77467 .668 L
s
.76925 .66718 m
.7713 .67132 L
s
.54575 .67446 m
.54614 .67641 L
s
.54284 .68254 m
.54412 .67898 L
s
.54412 .67898 m
.54575 .67446 L
s
.51045 .59923 m .51332 .59051 L .51558 .5707 L 0 1 .262 r
F
0 g
.51342 .58961 m
.51558 .5707 L
s
.51558 .5707 m
.5176 .57704 L
s
.42927 .56143 m .43029 .55906 L .42852 .55792 L 0 1 .359 r
F
0 g
.43029 .55906 m
.43094 .55862 L
s
.4941 .68551 m
.49418 .68547 L
s
.34447 .97201 m .32995 .96492 L .32662 .96623 L 0 1 .537 r
F
0 g
.32162 .96822 m
.3246 .9692 L
s
.3246 .9692 m
.32952 .97083 L
s
.34447 .97201 m .33761 .9674 L .32995 .96492 L 0 1 .537 r
F
.35226 .96845 m .33761 .9674 L .34447 .97201 L F
0 g
.34447 .97201 m
.35186 .97436 L
s
.34447 .97201 m
.34734 .97659 L
s
.54317 1.00557 m
.5448 1.00852 L
s
.3655 .70777 m .35496 .71016 L .35834 .71509 L 0 1 .428 r
F
0 g
.35591 .72153 m
.35834 .71509 L
s
.52459 .69194 m .53262 .70411 L .52802 .69604 L 0 .512 .268 r
F
0 g
.52451 .69812 m
.52457 .69824 L
s
.52459 .69194 m .53611 .7147 L .53262 .70411 L 0 .512 .268 r
F
.52459 .69194 m .53615 .72074 L .53611 .7147 L F
.52459 .69194 m .53271 .7166 L .53615 .72074 L F
.52459 .69194 m .52808 .70508 L .53271 .7166 L F
0 g
.52457 .69824 m
.52458 .69826 L
s
.52459 .69194 m .52461 .69452 L .52808 .70508 L 0 .512 .268 r
F
0 g
.52458 .69192 m
.52459 .69194 L
s
.52485 .68873 m
.52802 .69604 L
s
.52458 .69449 m
.52461 .69452 L
s
.52474 .69212 m
.52802 .69604 L
s
.52474 .69212 m
.52474 .69212 L
s
.52459 .69194 m
.52474 .69212 L
s
.52459 .69194 m
.52459 .69194 L
s
.50866 .49981 m .51345 .47997 L .5082 .49274 L 0 .887 .118 r
F
0 g
.51345 .47997 m
.51726 .47221 L
s
.41687 .7547 m .4066 .75236 L .40455 .75628 L 0 1 .489 r
F
.41687 .7547 m .41099 .75053 L .4066 .75236 L F
.41687 .7547 m .41539 .75154 L .41099 .75053 L F
.42755 .74933 m .41539 .75154 L .41687 .7547 L 0 1 .482 r
F
0 g
.41482 .75862 m
.41687 .7547 L
s
.41687 .7547 m
.42115 .7554 L
s
.5089 .7044 m
.50891 .7044 L
s
.5089 .70441 m
.50891 .7044 L
s
.48132 .88804 m .47683 .88212 L .4723 .88016 L 0 .628 .392 r
F
0 g
.3874 .68465 m
.39061 .68911 L
s
.49906 .66244 m .49333 .66073 L .49628 .66236 L 0 1 .377 r
F
.49906 .66244 m .49197 .65791 L .49333 .66073 L F
.49906 .66244 m .49312 .65579 L .49197 .65791 L F
.49906 .66244 m .49591 .65588 L .49312 .65579 L F
.49906 .66244 m .49847 .65812 L .49591 .65588 L F
0 g
.49847 .65812 m
.50101 .65867 L
s
.49906 .66244 m
.50069 .66561 L
s
.49847 .65812 m
.49982 .66093 L
s
.79115 .78235 m .79943 .79158 L .80246 .78944 L 0 .468 .352 r
F
0 g
.79385 .79089 m
.79943 .79158 L
s
.79943 .79158 m
.80049 .79527 L
s
.51612 .59273 m
.51613 .5927 L
s
.51613 .5927 m
.5176 .57704 L
s
.49498 .67655 m
.49639 .67623 L
s
.52282 .62507 m .52516 .62095 L .52769 .59333 L 0 1 .255 r
F
.46494 .74549 m .45925 .7554 L .46302 .75185 L 0 .867 .346 r
F
.46833 .75765 m .45925 .7554 L .45769 .76199 L 0 .826 .345 r
F
.46833 .75765 m .46302 .75185 L .45925 .7554 L F
0 g
.45532 .75407 m
.45925 .7554 L
s
.33977 .77101 m .32912 .764 L .32758 .76855 L 0 1 .518 r
F
.33977 .77101 m .33325 .76309 L .32912 .764 L F
.33977 .77101 m .33782 .7661 L .33325 .76309 L F
.34989 .76821 m .33782 .7661 L .33977 .77101 L 0 1 .516 r
F
0 g
.33823 .77555 m
.33977 .77101 L
s
.33977 .77101 m
.34424 .77379 L
s
.51721 .95791 m .51111 .95149 L .5064 .94858 L 0 .383 .371 r
F
0 g
.50199 .94193 m
.5064 .94858 L
s
.48106 .71386 m .47401 .72119 L .47825 .71764 L 0 1 .422 r
F
0 g
.47825 .71764 m
.48188 .71603 L
s
.45181 .74535 m .44217 .75142 L .44011 .75299 L 0 .806 .171 r
F
.45181 .74535 m .44641 .74873 L .44217 .75142 L F
.45181 .74535 m .45054 .74613 L .44641 .74873 L F
.46203 .73759 m .45054 .74613 L .45181 .74535 L 0 0 0 r
F
0 g
.45181 .74535 m
.45546 .74263 L
s
.44975 .74692 m
.45181 .74535 L
s
.48248 .71927 m .47141 .72999 L .47225 .72896 L 0 0 0 r
F
.48248 .71927 m .47397 .72786 L .47141 .72999 L F
.48248 .71927 m .47821 .72399 L .47397 .72786 L F
.48248 .71927 m .48186 .72031 L .47821 .72399 L F
0 g
.48248 .71927 m
.48274 .71897 L
s
.48034 .72107 m
.48248 .71927 L
s
.50428 .69598 m
.50517 .69435 L
s
.5039 .69668 m
.50428 .69598 L
s
.50238 .69947 m
.5039 .69668 L
s
.50517 .69435 m
.50517 .69435 L
s
.50413 .6961 m
.50517 .69435 L
s
.50371 .69679 m
.50413 .6961 L
s
.50224 .69926 m
.50371 .69679 L
s
.49378 .70746 m
.49517 .70585 L
s
.49327 .70805 m
.49378 .70746 L
s
.4923 .70915 m
.49327 .70805 L
s
.41913 .93056 m .40705 .93249 L .40453 .9341 L 0 1 .425 r
F
.41913 .93056 m .41332 .93097 L .40705 .93249 L F
.42484 .92637 m .41332 .93097 L .41913 .93056 L 0 1 .386 r
F
0 g
.41913 .93056 m
.42186 .93161 L
s
.41913 .93056 m
.42512 .92896 L
s
.50866 .49981 m .50449 .50462 L .50482 .50765 L 0 .887 .118 r
F
.50866 .49981 m .5082 .49274 L .50449 .50462 L F
.48106 .71386 m .47035 .72248 L .47401 .72119 L 0 1 .422 r
F
.48106 .71386 m .46971 .72067 L .47035 .72248 L F
.48106 .71386 m .47253 .71689 L .46971 .72067 L F
.48106 .71386 m .47693 .71368 L .47253 .71689 L F
.48106 .71386 m .48058 .71238 L .47693 .71368 L F
0 g
.48106 .71386 m
.48262 .71303 L
s
.47825 .71764 m
.48106 .71386 L
s
.47145 .72515 m
.47401 .72119 L
s
.46191 .80322 m .45465 .81239 L .45887 .81385 L 0 .797 .368 r
F
0 g
.45465 .81239 m
.45468 .81921 L
s
.49031 .69537 m .48232 .70123 L .4869 .69842 L 0 1 .402 r
F
0 g
.49019 .69881 m
.49056 .69844 L
s
.48994 .7006 m
.49055 .70034 L
s
.49031 .69537 m .47885 .70207 L .48232 .70123 L 0 1 .402 r
F
.49031 .69537 m .4788 .70039 L .47885 .70207 L F
0 g
.48727 .70176 m
.48994 .7006 L
s
.49031 .69537 m .48221 .69734 L .4788 .70039 L 0 1 .402 r
F
0 g
.48727 .70176 m
.49019 .69881 L
s
.49031 .69537 m .48681 .69495 L .48221 .69734 L 0 1 .402 r
F
0 g
.49022 .6973 m
.49043 .69723 L
s
.49031 .69537 m .49028 .69411 L .48681 .69495 L 0 1 .402 r
F
0 g
.49031 .69537 m
.49092 .69513 L
s
.49028 .69411 m
.49098 .69352 L
s
.24633 .77426 m .24014 .78099 L .24454 .78022 L 0 1 .526 r
F
.24633 .77426 m .23527 .77598 L .24014 .78099 L F
0 g
.23929 .78704 m
.24014 .78099 L
s
.24454 .78022 m
.25016 .78492 L
s
.44631 .51361 m .45265 .50001 L .4505 .50164 L 0 1 .184 r
F
0 g
.44488 .51906 m
.44631 .51361 L
s
.45265 .50001 m
.45785 .4921 L
s
.45085 .50514 m
.45265 .50001 L
s
.42927 .56143 m .42242 .56461 L .4259 .56381 L 0 1 .359 r
F
0 g
.42791 .56671 m
.43111 .56276 L
s
.42927 .56143 m .42065 .56346 L .42242 .56461 L 0 1 .359 r
F
.42927 .56143 m .42176 .56114 L .42065 .56346 L F
.42927 .56143 m .42514 .55876 L .42176 .56114 L F
.42927 .56143 m .42852 .55792 L .42514 .55876 L F
0 g
.42852 .55792 m
.43029 .55906 L
s
.4259 .56381 m
.42927 .56143 L
s
.42927 .56143 m
.43111 .56275 L
s
.5021 .69832 m .49449 .70777 L .49889 .70215 L 0 0 .042 r
F
.5021 .69832 m .49101 .71258 L .49449 .70777 L F
.5021 .69832 m .49078 .71338 L .49101 .71258 L F
.5021 .69832 m .494 .70954 L .49078 .71338 L F
0 g
.49212 .70937 m
.4923 .70915 L
s
.49174 .70981 m
.49212 .70937 L
s
.491 .71068 m
.49174 .70981 L
s
.49091 .71077 m
.491 .71068 L
s
.5021 .69832 m .49852 .70364 L .494 .70954 L 0 0 .042 r
F
0 g
.49466 .70654 m
.4947 .70649 L
s
.49371 .70783 m
.49466 .70654 L
s
.4947 .70649 m
.49517 .70585 L
s
.5021 .69832 m .50199 .69883 L .49852 .70364 L 0 0 .042 r
F
0 g
.5021 .69832 m
.50212 .69828 L
s
.50196 .69936 m
.50217 .699 L
s
.50187 .69953 m
.50188 .69951 L
s
.50188 .69951 m
.50196 .69936 L
s
.50203 .69876 m
.50217 .69854 L
s
.50199 .69883 m
.50203 .69876 L
s
.49889 .70215 m
.50141 .69872 L
s
.50188 .70038 m
.50238 .69947 L
s
.50196 .69973 m
.50224 .69926 L
s
.50185 .69991 m
.50196 .69973 L
s
.49889 .70215 m
.50151 .69902 L
s
.50151 .69902 m
.50151 .69902 L
s
.50151 .69902 m
.50195 .69849 L
s
.50195 .69849 m
.50195 .69849 L
s
.50195 .69849 m
.50195 .69849 L
s
.50195 .69849 m
.5021 .69832 L
s
.5021 .69832 m
.5021 .69832 L
s
.27639 .94928 m .25801 .94892 L .26031 .95075 L 0 1 .356 r
F
.27639 .94928 m .26187 .94795 L .25801 .94892 L F
.27639 .94928 m .26976 .94811 L .26187 .94795 L F
.2856 .94635 m .26976 .94811 L .27639 .94928 L 0 1 .324 r
F
0 g
.27639 .94928 m
.28404 .94921 L
s
.27639 .94928 m
.27864 .95111 L
s
.47458 .73592 m .46494 .74549 L .46869 .7462 L 0 .83 .333 r
F
.36231 .94475 m .34428 .9454 L .34615 .94791 L 0 1 .49 r
F
0 g
.34615 .94791 m
.34615 .94791 L
s
.46404 .7802 m .45364 .78412 L .45589 .78961 L 0 .815 .357 r
F
.46404 .7802 m .45457 .77735 L .45364 .78412 L F
0 g
.44935 .78241 m
.45364 .78412 L
s
.35496 .71016 m .34783 .71753 L .35203 .71657 L 0 1 .435 r
F
0 g
.35203 .71657 m
.35591 .72153 L
s
.45939 .76723 m .45457 .77735 L .45805 .77382 L 0 .86 .357 r
F
.46404 .7802 m .45805 .77382 L .45457 .77735 L 0 .815 .357 r
F
0 g
.45364 .78412 m
.45457 .77735 L
s
.45046 .77583 m
.45457 .77735 L
s
.46833 .75765 m .45769 .76199 L .45939 .76723 L 0 .826 .345 r
F
0 g
.45769 .76199 m
.45925 .7554 L
s
.45358 .76047 m
.45769 .76199 L
s
.48128 .70953 m
.48352 .70856 L
s
.48058 .71238 m
.48352 .70856 L
s
.72995 .93161 m .7414 .93187 L .73763 .93044 L 0 1 .531 r
F
.72074 .92766 m .72995 .93161 L .73198 .92824 L 0 1 .528 r
F
.49524 .71976 m .4914 .71874 L .48762 .72398 L 0 .728 .308 r
F
.49524 .71976 m .49467 .71693 L .4914 .71874 L F
0 g
.4914 .71874 m
.49388 .71262 L
s
.4914 .71874 m
.49467 .71693 L
s
.49467 .71693 m
.49569 .71407 L
s
.47021 .84049 m .46121 .8441 L .4649 .84989 L 0 .714 .376 r
F
.47021 .84049 m .46025 .83705 L .46121 .8441 L F
0 g
.45664 .84223 m
.46121 .8441 L
s
.49726 .66622 m .49796 .66471 L .49628 .66236 L 0 1 .381 r
F
0 g
.49796 .66471 m
.50048 .66554 L
s
.55112 1.02159 m
.5512 1.02168 L
s
.52761 .98023 m
.52819 .981 L
s
.52757 .98018 m
.52761 .98023 L
s
.52732 .97985 m
.52757 .98018 L
s
.52313 .97434 m
.52352 .97485 L
s
.52443 .97605 m
.52477 .97649 L
s
.52582 .97787 m
.52608 .97821 L
s
.44385 .91963 m .43056 .92468 L .43327 .9251 L 0 1 .357 r
F
0 g
.42729 .92722 m
.43327 .9251 L
s
.53963 .99882 m
.54012 .99945 L
s
.53647 .99468 m
.53894 .99791 L
s
.53894 .99791 m
.53963 .99882 L
s
.54012 .99945 m
.54214 1.0021 L
s
.53647 .99468 m
.53742 .99534 L
s
.53742 .99534 m
.53893 .99639 L
s
.53893 .99639 m
.53979 .99698 L
s
.53979 .99698 m
.53997 .99711 L
s
.44894 .73718 m .44226 .74355 L .44649 .74093 L 0 1 .463 r
F
.44894 .73718 m .43824 .74352 L .44226 .74355 L F
0 g
.44018 .74745 m
.44226 .74355 L
s
.44649 .74093 m
.45059 .74071 L
s
.47447 .86431 m .47023 .87325 L .47464 .87498 L 0 .676 .385 r
F
0 g
.47023 .87325 m
.4723 .88016 L
s
.35496 .71016 m .34442 .7124 L .34783 .71753 L 0 1 .435 r
F
0 g
.34546 .72407 m
.34783 .71753 L
s
.37491 .78256 m .36394 .78289 L .36273 .78477 L 0 1 .408 r
F
.37491 .78256 m .36796 .78168 L .36394 .78289 L F
.37491 .78256 m .37267 .78154 L .36796 .78168 L F
0 g
.37369 .78443 m
.37491 .78256 L
s
.38513 .7787 m .37267 .78153 L .37491 .78256 L 0 1 .369 r
F
0 g
.37491 .78256 m
.37961 .7821 L
s
.48423 .72509 m .47815 .73584 L .48194 .73131 L 0 .793 .321 r
F
.48423 .72509 m .47458 .73592 L .47815 .73584 L F
.51778 .98184 m .51081 .98291 L .50545 .98492 L 0 1 .511 r
F
0 g
.55233 1.03225 m
.55247 1.03216 L
s
.55247 1.03216 m
.55264 1.03206 L
s
.46833 .75765 m .46692 .75281 L .46302 .75185 L 0 .826 .345 r
F
0 g
.46302 .75185 m
.46494 .74549 L
s
.53768 .66506 m .54197 .65248 L .54549 .65318 L 0 .213 .148 r
F
.53768 .66506 m .53863 .65756 L .54197 .65248 L F
0 g
.53995 .64617 m
.54197 .65248 L
s
.53671 .65406 m
.53863 .65756 L
s
.53863 .65756 m
.54197 .65248 L
s
.52275 .45956 m .5339 .44058 L .53451 .44234 L 0 0 .027 r
F
.52275 .45956 m .52887 .44795 L .5339 .44058 L F
0 g
.5339 .44058 m
.53793 .42989 L
s
.52887 .44794 m
.53297 .43819 L
s
.52887 .44795 m
.5339 .44058 L
s
.40603 .77005 m .39993 .77353 L .40415 .77162 L 0 1 .267 r
F
.40603 .77005 m .39536 .77461 L .39993 .77353 L F
0 g
.39855 .77526 m
.39993 .77353 L
s
.40415 .77162 m
.40892 .77029 L
s
.44631 .51361 m .43844 .52234 L .44099 .52098 L 0 1 .184 r
F
.44631 .51361 m .44023 .5172 L .43844 .52234 L F
0 g
.43972 .526 m
.44259 .52214 L
s
.44259 .52214 m
.44488 .51906 L
s
.44631 .51361 m .44518 .509 L .44023 .5172 L 0 1 .184 r
F
.44631 .51361 m .4505 .50164 L .44518 .509 L F
.49726 .66622 m .49096 .66551 L .49426 .66657 L 0 1 .381 r
F
.49726 .66622 m .48927 .66316 L .49096 .66551 L F
.49726 .66622 m .49032 .66107 L .48927 .66316 L F
.49726 .66622 m .49333 .66073 L .49032 .66107 L F
.49726 .66622 m .49628 .66236 L .49333 .66073 L F
0 g
.49628 .66236 m
.49796 .66471 L
s
.49726 .66622 m
.4992 .66886 L
s
.49628 .66236 m
.49906 .66244 L
s
.4903 .69218 m .48221 .69734 L .48681 .69495 L 0 1 .4 r
F
0 g
.49012 .69554 m
.49031 .69537 L
s
.4899 .69741 m
.49022 .6973 L
s
.4903 .69218 m .47883 .69783 L .48221 .69734 L 0 1 .4 r
F
.4903 .69218 m .47893 .6961 L .47883 .69783 L F
0 g
.4869 .69842 m
.4899 .69741 L
s
.4903 .69218 m .48243 .69332 L .47893 .6961 L 0 1 .4 r
F
0 g
.4869 .69842 m
.49012 .69554 L
s
.48681 .69495 m
.49028 .69411 L
s
.4903 .69218 m .48699 .69136 L .48243 .69332 L 0 1 .4 r
F
.4903 .69218 m .49036 .69088 L .48699 .69136 L F
0 g
.4903 .69218 m
.49061 .6921 L
s
.49036 .69088 m
.49155 .69003 L
s
.76424 .92994 m .7677 .93682 L .77404 .9328 L 0 1 .529 r
F
0 g
.76016 .9388 m
.7677 .93682 L
s
.76577 .9408 m
.7677 .93682 L
s
.40004 .66475 m .39142 .67158 L .39601 .67065 L 0 1 .399 r
F
.40004 .66475 m .38863 .66697 L .39142 .67158 L F
0 g
.39601 .67065 m
.39921 .67511 L
s
.40004 .66475 m .38949 .65989 L .38863 .66697 L 0 1 .399 r
F
.40004 .66475 m .39353 .65399 L .38949 .65989 L F
.40004 .66475 m .39805 .65321 L .39353 .65399 L F
.40004 .66475 m .40084 .65782 L .39805 .65321 L F
0 g
.40004 .66475 m
.40288 .66921 L
s
.39601 .67065 m
.40004 .66475 L
s
.40084 .65782 m
.40482 .65201 L
s
.38075 .7588 m .37449 .76426 L .37869 .76283 L 0 1 .508 r
F
.38075 .7588 m .37016 .7622 L .37449 .76426 L F
0 g
.37297 .76843 m
.37449 .76426 L
s
.37869 .76283 m
.38334 .76467 L
s
.51665 .6819 m
.51665 .6819 L
s
.46203 .73759 m .45276 .74447 L .45054 .74613 L 0 0 0 r
F
.46203 .73759 m .457 .74147 L .45276 .74447 L F
.46203 .73759 m .46097 .73852 L .457 .74147 L F
.47225 .72896 m .46097 .73852 L .46203 .73759 L F
0 g
.46203 .73759 m
.46546 .73461 L
s
.46216 .82651 m .46025 .83705 L .46266 .83344 L 0 .773 .378 r
F
.47021 .84049 m .46266 .83344 L .46025 .83705 L 0 .714 .376 r
F
0 g
.46025 .83705 m
.46121 .8441 L
s
.45585 .83538 m
.46025 .83705 L
s
.50584 .71002 m .50549 .70851 L .50284 .71378 L 0 .664 .296 r
F
0 g
.50512 .70925 m
.50549 .70851 L
s
.50549 .70851 m
.50734 .70044 L
s
.52112 .69588 m
.52122 .69612 L
s
.52122 .69612 m
.5217 .69734 L
s
.5217 .69734 m
.52424 .70367 L
s
.52112 .69588 m
.52112 .69588 L
s
.52112 .69588 m
.52124 .69606 L
s
.52124 .69606 m
.52185 .69691 L
s
.52185 .69691 m
.52443 .70053 L
s
.47225 .72896 m .46336 .73669 L .46097 .73852 L 0 0 0 r
F
.47225 .72896 m .4676 .7333 L .46336 .73669 L F
.47225 .72896 m .47141 .72999 L .4676 .7333 L F
0 g
.46997 .73072 m
.47225 .72896 L
s
.47225 .72896 m
.47544 .72575 L
s
.50661 .62034 m .50851 .61717 L .50969 .61269 L 0 1 .27 r
F
0 g
.50851 .61717 m
.51017 .61826 L
s
.47458 .73592 m .46869 .7462 L .47247 .74222 L 0 .83 .333 r
F
.684 1.07353 m .68119 1.07519 L .69074 1.07469 L 0 .705 .261 r
F
0 g
.67221 1.07503 m
.68119 1.07519 L
s
.67587 1.07611 m
.68119 1.07519 L
s
.47035 .72248 m .46342 .72941 L .46766 .72623 L 0 1 .437 r
F
0 g
.46766 .72623 m
.47145 .72515 L
s
.34442 .7124 m .33731 .71983 L .34152 .71893 L 0 1 .442 r
F
0 g
.34152 .71893 m
.34546 .72407 L
s
.46191 .80322 m .45943 .7978 L .4552 .79635 L 0 .797 .368 r
F
.3655 .70777 m .35465 .70255 L .35496 .71016 L 0 1 .428 r
F
.3655 .70777 m .35761 .69623 L .35465 .70255 L F
.3655 .70777 m .36185 .6954 L .35761 .69623 L F
.3655 .70777 m .36523 .70035 L .36185 .6954 L F
0 g
.36255 .71408 m
.3655 .70777 L
s
.77618 .88449 m .77134 .89318 L .77067 .89965 L 0 1 .507 r
F
0 g
.76327 .90549 m
.77067 .89965 L
s
.31075 .96649 m .2926 .95902 L .29519 .9641 L 0 1 .536 r
F
.31075 .96649 m .29622 .95787 L .2926 .95902 L F
.31075 .96649 m .30401 .96108 L .29622 .95787 L F
.31929 .96331 m .30401 .96108 L .31075 .96649 L F
0 g
.31075 .96649 m
.31829 .96955 L
s
.31075 .96649 m
.31331 .97155 L
s
.42755 .74933 m .41757 .74769 L .41539 .75154 L 0 1 .482 r
F
.42755 .74933 m .42197 .74572 L .41757 .74769 L F
.42755 .74933 m .42624 .74642 L .42197 .74572 L F
.43824 .74352 m .42624 .74642 L .42755 .74933 L 0 1 .473 r
F
0 g
.42537 .75318 m
.42755 .74933 L
s
.42755 .74933 m
.4317 .74971 L
s
.75441 .927 m .74858 .93041 L .74703 .934 L 0 1 .526 r
F
0 g
.73915 .93542 m
.74703 .934 L
s
.51949 .67828 m .52344 .68345 L .52101 .68107 L 0 .066 .098 r
F
.51949 .67828 m .52585 .68274 L .52344 .68345 L F
.51949 .67828 m .52663 .67939 L .52585 .68274 L F
.51949 .67828 m .52509 .6766 L .52663 .67939 L F
.51949 .67828 m .52228 .67621 L .52509 .6766 L F
0 g
.51988 .67693 m
.52228 .67621 L
s
.51738 .67961 m
.51949 .67828 L
s
.52044 .67491 m
.52228 .67621 L
s
.45964 .7302 m .45284 .73682 L .45707 .73395 L 0 1 .451 r
F
.45964 .7302 m .44894 .73718 L .45284 .73682 L F
0 g
.45059 .74071 m
.45284 .73682 L
s
.45707 .73395 m
.46102 .73332 L
s
.49524 .71976 m .48762 .72398 L .48541 .73068 L 0 .728 .308 r
F
0 g
.48423 .72509 m
.48762 .72398 L
s
.79727 .59968 m .80853 .60135 L .81059 .60414 L 0 .021 0 r
F
0 g
.80853 .60135 m
.8125 .60415 L
s
.49638 .66817 m .49658 .66771 L .49426 .66657 L 0 1 .383 r
F
0 g
.49658 .66771 m
.49784 .66826 L
s
.47035 .72248 m .45964 .7302 L .46342 .72941 L 0 1 .437 r
F
0 g
.46102 .73332 m
.46342 .72941 L
s
.50963 .70672 m
.50963 .70672 L
s
.50962 .70673 m
.50963 .70672 L
s
.49638 .66817 m .49027 .66698 L .49368 .66786 L 0 1 .383 r
F
.49638 .66817 m .48794 .66583 L .49027 .66698 L F
.49638 .66817 m .48825 .6652 L .48794 .66583 L F
.49638 .66817 m .49096 .66551 L .48825 .6652 L F
.49638 .66817 m .49426 .66657 L .49096 .66551 L F
0 g
.49426 .66657 m
.49427 .66657 L
s
.49427 .66657 m
.49726 .66622 L
s
.49638 .66817 m
.49877 .66986 L
s
.33676 .94516 m .33535 .94916 L .33869 .94775 L 0 1 .498 r
F
0 g
.33869 .94775 m
.34615 .94792 L
s
.33676 .94516 m .32819 .94851 L .33535 .94916 L 0 1 .498 r
F
0 g
.33535 .94916 m
.33804 .95163 L
s
.34442 .7124 m .33387 .71452 L .33731 .71983 L 0 1 .442 r
F
0 g
.335 .72649 m
.33731 .71983 L
s
.4633 .98621 m .45622 .98491 L .44984 .98527 L 0 1 .541 r
F
.46613 .98185 m .4633 .98621 L .46937 .98587 L 0 1 .538 r
F
.46613 .98185 m .45622 .98491 L .4633 .98621 L F
0 g
.4633 .98621 m
.46767 .9885 L
s
.50166 .69928 m
.50166 .69928 L
s
.50166 .69928 m
.50169 .69924 L
s
.50169 .69924 m
.50193 .69891 L
s
.50193 .69891 m
.50193 .69891 L
s
.50193 .69891 m
.50193 .69891 L
s
.50193 .69891 m
.50199 .69883 L
s
.50133 .64158 m .50269 .63934 L .50275 .63544 L 0 1 .352 r
F
0 g
.50269 .63934 m
.50465 .64097 L
s
.52461 .69452 m
.52478 .69504 L
s
.26687 .9609 m .24836 .95135 L .25071 .95707 L 0 1 .536 r
F
.26687 .9609 m .25221 .95037 L .24836 .95135 L F
.26687 .9609 m .26016 .95448 L .25221 .95037 L F
.27606 .95813 m .26016 .95448 L .26687 .9609 L F
0 g
.26687 .9609 m
.27458 .96483 L
s
.26687 .9609 m
.26919 .96659 L
s
.27415 .80212 m .26133 .7965 L .26033 .80011 L 0 1 .527 r
F
.27415 .80212 m .26574 .79586 L .26133 .7965 L F
.27415 .80212 m .27124 .79828 L .26574 .79586 L F
.28492 .79993 m .27124 .79828 L .27415 .80212 L 0 1 .521 r
F
0 g
.27314 .80571 m
.27415 .80212 L
s
.27415 .80212 m
.27953 .80427 L
s
.3874 .68465 m .37941 .69171 L .38384 .6907 L 0 1 .41 r
F
0 g
.38384 .6907 m
.38731 .69523 L
s
.57562 .41387 m
.57582 .41387 L
s
.5748 .41385 m
.57562 .41387 L
s
.57298 .41382 m
.5748 .41385 L
s
.57192 .41604 m
.57298 .41382 L
s
.5704 .41925 m
.57192 .41604 L
s
.53537 .97797 m
.53541 .97796 L
s
.42323 .57619 m .42625 .56877 L .4259 .56381 L 0 1 .367 r
F
0 g
.42625 .56877 m
.42791 .56671 L
s
.49053 .68888 m .48243 .69332 L .48699 .69136 L 0 1 .398 r
F
0 g
.49028 .6922 m
.4903 .69218 L
s
.49053 .68888 m .47918 .69346 L .48243 .69332 L 0 1 .398 r
F
.49053 .68888 m .47942 .69167 L .47918 .69346 L F
0 g
.48681 .69495 m
.49028 .6922 L
s
.49053 .68888 m .48297 .68919 L .47942 .69167 L 0 1 .398 r
F
0 g
.48699 .69136 m
.49036 .69088 L
s
.49053 .68888 m .48746 .68766 L .48297 .68919 L 0 1 .398 r
F
.49053 .68888 m .4907 .68753 L .48746 .68766 L F
0 g
.49053 .68888 m
.49105 .68881 L
s
.4907 .68753 m
.4941 .68551 L
s
.70223 .91919 m .70562 .92594 L .7115 .92353 L 0 1 .519 r
F
0 g
.70384 .92913 m
.70562 .92594 L
s
.69859 .92627 m
.70562 .92594 L
s
.50693 .42703 m .50141 .43934 L .50173 .43555 L 0 .044 .076 r
F
.50693 .42703 m .50648 .43739 L .50141 .43934 L F
0 g
.5007 .43224 m
.5022 .42966 L
s
.50693 .42703 m .51355 .431 L .50648 .43739 L 0 .044 .076 r
F
.50693 .42703 m .51873 .42248 L .51355 .431 L F
0 g
.5022 .42966 m
.50693 .42703 L
s
.47729 .74683 m .46869 .7462 L .46692 .75281 L 0 .793 .333 r
F
.47729 .74683 m .47247 .74222 L .46869 .7462 L F
0 g
.46494 .74549 m
.46869 .7462 L
s
.46404 .7802 m .45589 .78961 L .45994 .79084 L 0 .815 .357 r
F
0 g
.4552 .79635 m
.45589 .78961 L
s
.34989 .76821 m .33945 .7617 L .33782 .7661 L 0 1 .516 r
F
.34989 .76821 m .34359 .76075 L .33945 .7617 L F
.34989 .76821 m .34806 .76354 L .34359 .76075 L F
.36002 .76528 m .34806 .76354 L .34989 .76821 L 0 1 .514 r
F
0 g
.34825 .7726 m
.34989 .76821 L
s
.34989 .76821 m
.35427 .77077 L
s
.49518 .67112 m .49578 .66964 L .49368 .66786 L 0 1 .386 r
F
0 g
.49578 .66964 m
.49836 .66983 L
s
.55869 .41967 m .5556 .43159 L .55451 .42839 L 0 .175 .094 r
F
.55869 .41967 m .56175 .42907 L .5556 .43159 L F
0 g
.55494 .4275 m
.55869 .41967 L
s
.2574 .77251 m .25113 .77906 L .25552 .77828 L 0 1 .526 r
F
.2574 .77251 m .24633 .77426 L .25113 .77906 L F
0 g
.25016 .78492 m
.25113 .77906 L
s
.25552 .77828 m
.26104 .78277 L
s
.46404 .7802 m .46211 .77503 L .45805 .77382 L 0 .815 .357 r
F
0 g
.58185 .70464 m
.58206 .71898 L
s
.58171 .69499 m
.58185 .70464 L
s
.58082 .63375 m
.58088 .63782 L
s
.58065 .62185 m
.58082 .63375 L
s
.58701 1.05924 m
.58763 1.10225 L
s
.58679 1.04418 m
.58701 1.05924 L
s
.58664 1.03432 m
.58679 1.04418 L
s
.58652 1.02563 m
.58664 1.03432 L
s
.58822 1.14293 m
.58828 1.14686 L
s
.58799 1.12671 m
.58822 1.14293 L
s
.58792 1.12213 m
.58799 1.12671 L
s
.58763 1.10225 m
.58792 1.12213 L
s
.57855 .70826 m
.57873 .70093 L
s
.57873 .70093 m
.57913 .6843 L
s
.58019 .64098 m
.58031 .63604 L
s
.58031 .63604 m
.58065 .62185 L
s
.46833 .75765 m .45939 .76723 L .46329 .7682 L 0 .826 .345 r
F
0 g
.45805 .77382 m
.45939 .76723 L
s
.47035 .72248 m .45884 .72809 L .45964 .7302 L 0 1 .437 r
F
.47035 .72248 m .46153 .72434 L .45884 .72809 L F
.47035 .72248 m .46593 .72146 L .46153 .72434 L F
.47035 .72248 m .46971 .72067 L .46593 .72146 L F
0 g
.47035 .72248 m
.47401 .72119 L
s
.46766 .72623 m
.47035 .72248 L
s
.24261 .95282 m
.24265 .95282 L
s
.24265 .95282 m
.24916 .95329 L
s
.47447 .86431 m .47058 .85855 L .46617 .85684 L 0 .676 .385 r
F
.33387 .71452 m .3268 .72202 L .331 .72116 L 0 1 .448 r
F
0 g
.331 .72116 m
.335 .72649 L
s
.64856 .46957 m .65678 .48663 L .65139 .47295 L 0 .058 .175 r
F
.64988 .47026 m .65139 .47295 L .65045 .47056 L F
.64856 .46957 m .65139 .47295 L .64988 .47026 L F
.65678 .48663 m .65793 .4844 L .65474 .47887 L 0 .145 .227 r
F
.65645 .48196 m .65474 .47887 L .65793 .4844 L 0 .235 0 r
F
.64856 .46957 m .65045 .47056 L .64979 .46931 L 0 .058 .175 r
F
.64118 .45671 m .65449 .47846 L .65645 .48196 L 0 .235 0 r
F
.65449 .47846 m .65474 .47887 L .65645 .48196 L F
.64856 .46957 m .66268 .5025 L .65678 .48663 L 0 .058 .175 r
F
.64856 .46957 m .66449 .51005 L .66268 .5025 L F
.64856 .46957 m .661 .50423 L .66449 .51005 L F
.64856 .46957 m .65417 .48687 L .661 .50423 L F
.64118 .45671 m .65528 .48092 L .64854 .47074 L 0 .235 0 r
F
.65319 .47734 m .65645 .48196 L .6559 .48147 L F
.65383 .47843 m .6559 .48147 L .65528 .48092 L F
.65319 .47734 m .6559 .48147 L .65383 .47843 L F
.64118 .45671 m .65645 .48196 L .65645 .48196 L F
.64118 .45671 m .65645 .48196 L .65319 .47734 L F
.65645 .48196 m .65731 .48359 L .65528 .48092 L F
.64958 .47221 m .66763 .49794 L .66538 .49452 L 0 0 .144 r
F
.64854 .47074 m .64992 .47271 L .64958 .47221 L F
.64992 .47271 m .66763 .49794 L .64958 .47221 L F
.65645 .48196 m .65793 .4844 L .65731 .48359 L 0 .235 0 r
F
.66526 .49457 m .66345 .49257 L .66763 .49794 L 0 0 .144 r
F
.65746 .4853 m .65944 .48765 L .65793 .4844 L 0 .145 .227 r
F
.64854 .47074 m .6629 .49177 L .66526 .49457 L 0 0 .144 r
F
.6629 .49177 m .66345 .49257 L .66526 .49457 L F
.65678 .48663 m .66497 .4996 L .65944 .48765 L 0 .145 .227 r
F
.65678 .48663 m .65944 .48765 L .65746 .4853 L F
.64877 .47107 m .65819 .48455 L .64999 .47287 L 0 0 .144 r
F
.64854 .47074 m .64932 .47185 L .64877 .47107 L F
.64932 .47185 m .65819 .48455 L .64877 .47107 L F
.64979 .46931 m .65045 .47056 L .64995 .46928 L 0 .058 .175 r
F
0 g
.64806 .46748 m
.64824 .46825 L
s
.64779 .46723 m
.648 .46785 L
s
.49518 .67112 m .48825 .6716 L .49195 .67196 L 0 1 .386 r
F
.49518 .67112 m .48614 .66982 L .48825 .6716 L F
.49518 .67112 m .48704 .66782 L .48614 .66982 L F
.49518 .67112 m .49027 .66698 L .48704 .66782 L F
.49518 .67112 m .49368 .66786 L .49027 .66698 L F
0 g
.49426 .66657 m
.49604 .66744 L
s
.49604 .66744 m
.49658 .66771 L
s
.49518 .67112 m
.4975 .67306 L
s
.49369 .66786 m
.49638 .66817 L
s
.49368 .66786 m
.49369 .66786 L
s
.49368 .66786 m
.49578 .66964 L
s
.28942 .96169 m
.29519 .9641 L
s
.36231 .94475 m .34839 .94369 L .34428 .9454 L 0 1 .49 r
F
.36231 .94475 m .35613 .94341 L .34839 .94369 L F
0 g
.36231 .94475 m
.36415 .94726 L
s
.36964 .94115 m .35613 .94341 L .36232 .94475 L 0 1 .474 r
F
0 g
.36232 .94475 m
.36907 .94462 L
s
.51001 .55967 m .50694 .54907 L .50726 .56 L 0 1 .241 r
F
.51045 .59923 m .51001 .55967 L .50773 .57946 L 0 1 .262 r
F
.5082 .49274 m .51764 .46896 L .51348 .4772 L 0 .804 .092 r
F
0 g
.51764 .46896 m
.51791 .46832 L
s
.52398 .98019 m
.52486 .9801 L
s
.52486 .9801 m
.52727 .97985 L
s
.52727 .97985 m
.5273 .97985 L
s
.5273 .97985 m
.52732 .97985 L
s
.684 1.07353 m .67481 1.07367 L .66977 1.07431 L 0 .705 .261 r
F
0 g
.66571 1.07406 m
.66977 1.07431 L
s
.50584 .71002 m .50116 .7281 L .50399 .71842 L 0 .664 .296 r
F
.50584 .71002 m .49851 .73338 L .50116 .7281 L F
.50584 .71002 m .4978 .73073 L .49851 .73338 L F
0 g
.49615 .71873 m
.49761 .7171 L
s
.50584 .71002 m .49966 .72233 L .4978 .73073 L 0 .664 .296 r
F
0 g
.49761 .7171 m
.49829 .71633 L
s
.49746 .71926 m
.49829 .71633 L
s
.50584 .71002 m .50284 .71378 L .49966 .72233 L 0 .664 .296 r
F
0 g
.50568 .71076 m
.50584 .71002 L
s
.50584 .71002 m
.50823 .70191 L
s
.50284 .71378 m
.50485 .70664 L
s
.50284 .71378 m
.50512 .70925 L
s
.3874 .68465 m .37635 .68703 L .37941 .69171 L 0 1 .41 r
F
0 g
.37627 .69788 m
.37941 .69171 L
s
.3874 .68465 m .3767 .67979 L .37635 .68703 L 0 1 .41 r
F
.3874 .68465 m .38026 .67373 L .3767 .67979 L F
.3874 .68465 m .38467 .67291 L .38026 .67373 L F
.3874 .68465 m .38773 .67759 L .38467 .67291 L F
0 g
.38384 .6907 m
.3874 .68465 L
s
.47997 .7101 m .47253 .71689 L .47693 .71368 L 0 1 .421 r
F
.47997 .7101 m .46889 .71788 L .47253 .71689 L F
.47997 .7101 m .46843 .71599 L .46889 .71788 L F
.47997 .7101 m .47148 .71241 L .46843 .71599 L F
.47997 .7101 m .47599 .70954 L .47148 .71241 L F
0 g
.47995 .71261 m
.48058 .71238 L
s
.47693 .71368 m
.47995 .71261 L
s
.47997 .7101 m .47963 .70855 L .47599 .70954 L 0 1 .421 r
F
0 g
.47997 .7101 m
.48128 .70953 L
s
.47693 .71368 m
.47997 .7101 L
s
.47729 .74683 m .47616 .74249 L .47247 .74222 L 0 .793 .333 r
F
0 g
.47247 .74222 m
.47458 .73592 L
s
.69663 .92128 m
.69663 .92128 L
s
.68921 .92094 m
.69663 .92128 L
s
.74995 .74551 m .7509 .747 L .75551 .75146 L 0 .043 .154 r
F
.74995 .74551 m .74852 .74445 L .7509 .747 L F
0 g
.75025 .74668 m
.7509 .747 L
s
.74879 .74473 m
.7493 .74528 L
s
.48028 .70581 m
.48276 .70497 L
s
.47963 .70855 m
.48276 .70497 L
s
.48626 .73437 m .48194 .73131 L .47815 .73584 L 0 .76 .32 r
F
.48626 .73437 m .48541 .73068 L .48194 .73131 L F
0 g
.48194 .73131 m
.48423 .72509 L
s
.49101 .68548 m .48297 .68919 L .48746 .68766 L 0 1 .396 r
F
.49101 .68548 m .47989 .68896 L .48297 .68919 L F
.49101 .68548 m .48027 .68712 L .47989 .68896 L F
0 g
.48746 .68766 m
.4907 .68753 L
s
.48699 .69136 m
.49053 .68888 L
s
.49101 .68548 m .48383 .68494 L .48027 .68712 L 0 1 .396 r
F
.49101 .68548 m .48819 .68386 L .48383 .68494 L F
.49101 .68548 m .49127 .68409 L .48819 .68386 L F
0 g
.49101 .68548 m
.49418 .68547 L
s
.48746 .68766 m
.49101 .68548 L
s
.49127 .68409 m
.49472 .68245 L
s
.33387 .71452 m .32333 .71651 L .3268 .72202 L 0 1 .448 r
F
0 g
.32455 .72879 m
.3268 .72202 L
s
.73423 .90751 m .73167 .91912 L .7385 .91358 L 0 1 .503 r
F
.73423 .90751 m .72796 .91934 L .73167 .91912 L F
0 g
.72968 .92361 m
.73167 .91912 L
s
.72389 .57206 m .7373 .56984 L .73501 .58104 L 0 .425 .1 r
F
0 g
.73556 .55757 m
.7373 .56984 L
s
.7373 .56984 m
.74241 .56475 L
s
.50497 .69539 m
.50514 .69506 L
s
.50454 .69622 m
.50497 .69539 L
s
.5023 .70052 m
.50454 .69622 L
s
.502 .7011 m
.5023 .70052 L
s
.50514 .69506 m
.50514 .69506 L
s
.50493 .69542 m
.50514 .69506 L
s
.50443 .6963 m
.50493 .69542 L
s
.50212 .70034 m
.50443 .6963 L
s
.50188 .70078 m
.50212 .70034 L
s
.58604 .55189 m .58958 .55115 L .59494 .5712 L 0 .849 .145 r
F
0 g
.58958 .55115 m
.59202 .56028 L
s
.59202 .56028 m
.59288 .5635 L
s
.59288 .5635 m
.59391 .56736 L
s
.59418 .56834 m
.59494 .5712 L
s
.59391 .56736 m
.59418 .56834 L
s
.59284 .56335 m
.59305 .56151 L
s
.59305 .56151 m
.59382 .55478 L
s
.5949 .56931 m
.59493 .57116 L
s
.59489 .56817 m
.5949 .56931 L
s
.59486 .56646 m
.59489 .56817 L
s
.59485 .56558 m
.59486 .56646 L
s
.59484 .56501 m
.59485 .56558 L
s
.59459 .54799 m
.59484 .56501 L
s
.58942 .5206 m
.58958 .55115 L
s
.59409 .55574 m
.59477 .56086 L
s
.48626 .73437 m .47815 .73584 L .47616 .74249 L 0 .76 .32 r
F
0 g
.47458 .73592 m
.47815 .73584 L
s
.49382 .6748 m .49434 .67333 L .49195 .67196 L 0 1 .389 r
F
0 g
.49434 .67333 m
.49648 .67315 L
s
.31905 .79265 m .31378 .79625 L .31778 .79527 L 0 1 .493 r
F
.31905 .79265 m .30895 .79487 L .31378 .79625 L F
0 g
.31323 .79901 m
.31378 .79625 L
s
.31778 .79527 m
.32311 .79635 L
s
.43824 .74352 m .42855 .74263 L .42624 .74642 L 0 1 .473 r
F
.43824 .74352 m .43295 .74048 L .42855 .74263 L F
.43824 .74352 m .4371 .74086 L .43295 .74048 L F
.44894 .73718 m .4371 .74086 L .43824 .74352 L 0 1 .463 r
F
0 g
.43592 .74731 m
.43824 .74352 L
s
.43824 .74352 m
.44226 .74355 L
s
.49382 .6748 m .48649 .67614 L .49045 .676 L 0 1 .389 r
F
.49382 .6748 m .48409 .67477 L .48649 .67614 L F
.49382 .6748 m .48488 .6728 L .48409 .67477 L F
.49382 .6748 m .48825 .6716 L .48488 .6728 L F
.49382 .6748 m .49195 .67196 L .48825 .6716 L F
0 g
.49195 .67196 m
.49518 .67112 L
s
.49382 .6748 m
.49639 .67623 L
s
.49195 .67196 m
.49434 .67333 L
s
.72492 .6288 m
.72494 .62881 L
s
.49172 .68199 m .48383 .68494 L .48819 .68386 L 0 1 .394 r
F
.49172 .68199 m .48095 .68434 L .48383 .68494 L F
.49172 .68199 m .48147 .68246 L .48095 .68434 L F
0 g
.48819 .68386 m
.49127 .68409 L
s
.49172 .68199 m .48501 .68059 L .48147 .68246 L 0 1 .394 r
F
.49172 .68199 m .4892 .67997 L .48501 .68059 L F
.49172 .68199 m .49207 .68057 L .4892 .67997 L F
0 g
.49172 .68199 m
.49472 .68245 L
s
.48819 .68386 m
.49172 .68199 L
s
.49207 .68057 m
.49546 .67937 L
s
.69665 .57878 m
.70157 .5637 L
s
.32333 .71651 m .31628 .7241 L .32049 .72328 L 0 1 .454 r
F
0 g
.32049 .72328 m
.32455 .72879 L
s
.49266 .67843 m .4931 .67698 L .49045 .676 L 0 1 .392 r
F
0 g
.4931 .67698 m
.49498 .67655 L
s
.47688 .45928 m .48292 .45073 L .48686 .44665 L 0 0 0 r
F
.49524 .71976 m .48953 .73256 L .49303 .72646 L 0 .728 .308 r
F
.49524 .71976 m .48626 .73437 L .48953 .73256 L F
.49524 .71976 m .48541 .73068 L .48626 .73437 L F
0 g
.48541 .73068 m
.48762 .72398 L
s
.49524 .71976 m
.49615 .71873 L
s
.48194 .73131 m
.48541 .73068 L
s
.49266 .67843 m .48501 .68059 L .4892 .67997 L 0 1 .392 r
F
.49266 .67843 m .48236 .67961 L .48501 .68059 L F
0 g
.4892 .67997 m
.49207 .68057 L
s
.49266 .67843 m .48301 .67769 L .48236 .67961 L 0 1 .392 r
F
.49266 .67843 m .48649 .67614 L .48301 .67769 L F
.49266 .67843 m .49045 .676 L .48649 .67614 L F
0 g
.49045 .676 m
.4931 .67698 L
s
.4892 .67997 m
.49266 .67843 L
s
.49266 .67843 m
.49546 .67937 L
s
.49045 .676 m
.49382 .6748 L
s
.47729 .74683 m .46692 .75281 L .46833 .75765 L 0 .793 .333 r
F
0 g
.46692 .75281 m
.46869 .7462 L
s
.46302 .75185 m
.46692 .75281 L
s
.35496 .71016 m .34408 .7046 L .34442 .7124 L 0 1 .435 r
F
.35496 .71016 m .347 .69818 L .34408 .7046 L F
.35496 .71016 m .35125 .69741 L .347 .69818 L F
.35496 .71016 m .35465 .70255 L .35125 .69741 L F
0 g
.35203 .71657 m
.35496 .71016 L
s
.35496 .71016 m
.35834 .71509 L
s
.50003 .56094 m .50645 .53525 L .50613 .52776 L 0 1 .244 r
F
.50003 .56094 m .50384 .54946 L .50645 .53525 L F
0 g
.50645 .53525 m
.50956 .53111 L
s
.39136 .75517 m .38499 .76062 L .3892 .75909 L 0 1 .503 r
F
.39136 .75517 m .38075 .7588 L .38499 .76062 L F
0 g
.38334 .76467 m
.38499 .76062 L
s
.3892 .75909 m
.39372 .76069 L
s
.74612 .58843 m .7538 .57505 L .75836 .57867 L 0 .298 .073 r
F
.74612 .58843 m .74857 .57921 L .7538 .57505 L F
0 g
.75151 .56763 m
.7538 .57505 L
s
.80246 .78944 m .81058 .7983 L .81375 .79584 L 0 .547 .374 r
F
0 g
.8049 .79805 m
.81058 .7983 L
s
.81058 .7983 m
.81153 .80206 L
s
.46849 .81668 m .45908 .82088 L .46216 .82651 L 0 .744 .366 r
F
.46849 .81668 m .45887 .81385 L .45908 .82088 L F
0 g
.45468 .81921 m
.45908 .82088 L
s
.32333 .71651 m .31279 .71841 L .31628 .7241 L 0 1 .454 r
F
0 g
.3141 .73099 m
.31628 .7241 L
s
.50661 .62034 m .50969 .61269 L .50936 .60988 L 0 1 .27 r
F
0 g
.50969 .61269 m
.51136 .61231 L
s
.50851 .61717 m
.50969 .61269 L
s
.45964 .7302 m .44797 .73478 L .44894 .73718 L 0 1 .451 r
F
.45964 .7302 m .45054 .73104 L .44797 .73478 L F
.45964 .7302 m .45493 .72844 L .45054 .73104 L F
.45964 .7302 m .45884 .72809 L .45493 .72844 L F
0 g
.45707 .73395 m
.45964 .7302 L
s
.45964 .7302 m
.46342 .72941 L
s
.47021 .84049 m .4649 .84989 L .46917 .85137 L 0 .714 .376 r
F
0 g
.4649 .84989 m
.46617 .85684 L
s
.44894 .73718 m .43954 .7371 L .4371 .74086 L 0 1 .463 r
F
.44894 .73718 m .44394 .73475 L .43954 .7371 L F
.44894 .73718 m .44797 .73478 L .44394 .73475 L F
0 g
.44649 .74093 m
.44894 .73718 L
s
.44894 .73718 m
.45284 .73682 L
s
.5398 .43569 m .55289 .42335 L .54856 .43264 L 0 .011 .075 r
F
0 g
.55289 .42335 m
.55869 .41967 L
s
.42323 .57619 m .41436 .58295 L .41814 .58227 L 0 1 .367 r
F
0 g
.42141 .58425 m
.42379 .58134 L
s
.42323 .57619 m .41401 .57799 L .41436 .58295 L 0 1 .367 r
F
.42323 .57619 m .41732 .57069 L .41401 .57799 L F
.42323 .57619 m .42242 .56461 L .41732 .57069 L F
.42323 .57619 m .4259 .56381 L .42242 .56461 L F
0 g
.42323 .57619 m
.42379 .58134 L
s
.4259 .56381 m
.42625 .56877 L
s
.50003 .56094 m .50613 .52776 L .50268 .5311 L 0 1 .244 r
F
0 g
.50613 .52776 m
.50911 .5119 L
s
.54873 1.01409 m
.55019 1.01715 L
s
.54839 1.01339 m
.54873 1.01409 L
s
.54791 1.01236 m
.54839 1.01339 L
s
.54791 1.01236 m
.54792 1.01235 L
s
.54843 1.01213 m
.54859 1.01206 L
s
.79427 .68095 m .80547 .69246 L .80576 .68502 L 0 1 .504 r
F
0 g
.80547 .69246 m
.80867 .69926 L
s
.80182 .69665 m
.80547 .69246 L
s
.46582 .90693 m .46683 .90842 L .46832 .90674 L 0 1 .252 r
F
.46582 .90693 m .46179 .91107 L .46683 .90842 L F
.47817 .90125 m .46832 .90674 L .46683 .90842 L 0 1 .273 r
F
0 g
.46683 .90842 m
.46978 .90789 L
s
.5175 .97912 m .51778 .98184 L .52282 .98031 L 0 1 .486 r
F
.5175 .97912 m .51081 .98291 L .51778 .98184 L F
0 g
.51778 .98184 m
.52222 .98188 L
s
.50133 .64158 m .49729 .63922 L .49902 .64153 L 0 1 .352 r
F
.50133 .64158 m .49736 .63532 L .49729 .63922 L F
.50133 .64158 m .49917 .63244 L .49736 .63532 L F
.50133 .64158 m .50148 .63249 L .49917 .63244 L F
.50133 .64158 m .50275 .63544 L .50148 .63249 L F
0 g
.50133 .64158 m
.5016 .64598 L
s
.50275 .63544 m
.50475 .63596 L
s
.50269 .63934 m
.50275 .63544 L
s
.49175 .71049 m .48457 .71772 L .48881 .71322 L 0 0 .011 r
F
0 g
.48881 .71322 m
.49023 .7119 L
s
.48881 .71322 m
.49091 .71077 L
s
.51038 .70886 m
.51038 .70886 L
s
.46191 .80322 m .45887 .81385 L .46167 .8101 L 0 .797 .368 r
F
.46849 .81668 m .46167 .8101 L .45887 .81385 L 0 .744 .366 r
F
0 g
.45887 .81385 m
.45908 .82088 L
s
.45465 .81239 m
.45887 .81385 L
s
.31279 .71841 m .30577 .72609 L .30998 .7253 L 0 1 .459 r
F
0 g
.30998 .7253 m
.3141 .73099 L
s
.77618 .88449 m .78133 .89288 L .78638 .88394 L 0 1 .507 r
F
0 g
.7746 .8996 m
.78133 .89288 L
s
.7805 .89962 m
.78133 .89288 L
s
.72092 .92378 m
.72678 .92008 L
s
.46971 .72067 m
.47253 .71689 L
s
.76847 .76562 m .77846 .77068 L .77387 .76721 L 0 .376 .306 r
F
.76847 .76562 m .77982 .77445 L .77846 .77068 L F
.40239 .64739 m .39353 .65399 L .39805 .65321 L 0 1 .398 r
F
.40239 .64739 m .39117 .64926 L .39353 .65399 L F
0 g
.39805 .65321 m
.40084 .65782 L
s
.40239 .64739 m .39256 .64217 L .39117 .64926 L 0 1 .398 r
F
.40239 .64739 m .39691 .63635 L .39256 .64217 L F
.40239 .64739 m .40132 .63568 L .39691 .63635 L F
.40239 .64739 m .40366 .64042 L .40132 .63568 L F
0 g
.40239 .64739 m
.40482 .65201 L
s
.39805 .65321 m
.40239 .64739 L
s
.40366 .64042 m
.40791 .63467 L
s
.57924 .41394 m .57686 .42519 L .5753 .42086 L 0 .277 .096 r
F
0 g
.57562 .41387 m
.57585 .41419 L
s
.57929 .41903 m .58616 .42134 L .59285 .43052 L 0 .542 .103 r
F
.57929 .41903 m .59097 .44492 L .58363 .4408 L F
.57929 .41903 m .59492 .44049 L .59097 .44492 L F
.57929 .41903 m .59285 .43052 L .59492 .44049 L F
.57924 .41394 m .58346 .42609 L .57686 .42519 L 0 .277 .096 r
F
0 g
.57585 .41419 m
.57765 .41673 L
s
.57924 .41394 m .59068 .42296 L .58346 .42609 L 0 .277 .096 r
F
0 g
.59038 .41546 m
.59134 .41756 L
s
.59134 .41756 m
.59342 .42212 L
s
.58686 .41994 m
.58916 .41529 L
s
.57924 .41394 m .59457 .41603 L .59068 .42296 L 0 .277 .096 r
F
0 g
.57582 .41387 m
.57924 .41394 L
s
.5753 .42086 m
.57924 .41394 L
s
.31279 .71841 m .30225 .72021 L .30577 .72609 L 0 1 .459 r
F
0 g
.30366 .73311 m
.30577 .72609 L
s
.46179 .91107 m .4512 .91564 L .44931 .91739 L 0 1 .319 r
F
.46179 .91107 m .45656 .91293 L .4512 .91564 L F
.46582 .90693 m .45656 .91293 L .46179 .91107 L 0 1 .252 r
F
0 g
.46179 .91107 m
.46683 .90842 L
s
.46179 .91107 m
.4646 .91108 L
s
.78382 .93559 m .79359 .93832 L .79576 .93411 L 0 1 .534 r
F
.36002 .76528 m .34979 .75928 L .34806 .76354 L 0 1 .514 r
F
.36002 .76528 m .35393 .75827 L .34979 .75928 L F
.36002 .76528 m .35832 .76085 L .35393 .75827 L F
.37015 .7622 m .35832 .76085 L .36002 .76528 L 0 1 .511 r
F
0 g
.35828 .76953 m
.36002 .76528 L
s
.36002 .76528 m
.36431 .76762 L
s
.40718 .9747 m .40826 .97978 L .41043 .97818 L 0 1 .539 r
F
.40718 .9747 m .4015 .9786 L .40826 .97978 L F
.42414 .98145 m .41043 .97818 L .40826 .97978 L 0 1 .54 r
F
0 g
.40826 .97978 m
.4121 .983 L
s
.26847 .77073 m .26212 .7771 L .26652 .7763 L 0 1 .526 r
F
.26847 .77073 m .2574 .77251 L .26212 .7771 L F
0 g
.26104 .78277 m
.26212 .7771 L
s
.26652 .7763 m
.27193 .78059 L
s
.38513 .7787 m .37414 .77976 L .37267 .78153 L 0 1 .369 r
F
.38513 .7787 m .37835 .77841 L .37414 .77976 L F
.38513 .7787 m .38306 .77796 L .37835 .77841 L F
.39536 .77461 m .38306 .77796 L .38513 .7787 L 0 1 .322 r
F
0 g
.38365 .78048 m
.38513 .7787 L
s
.38513 .7787 m
.3897 .77797 L
s
.41671 .76512 m .41047 .76866 L .41469 .7666 L 0 .899 .238 r
F
.41671 .76512 m .40603 .77005 L .41047 .76866 L F
0 g
.40892 .77029 m
.41047 .76866 L
s
.41469 .7666 m
.4193 .76497 L
s
.50185 .69956 m .494 .70954 L .49852 .70364 L 0 0 .045 r
F
0 g
.50186 .70137 m
.502 .7011 L
s
.50185 .69956 m .4905 .71452 L .494 .70954 L 0 0 .045 r
F
.50185 .69956 m .49036 .71525 L .4905 .71452 L F
.50185 .69956 m .49371 .71116 L .49036 .71525 L F
0 g
.49023 .7119 m
.49112 .71108 L
s
.49112 .71108 m
.4912 .711 L
s
.50185 .69956 m .4983 .70499 L .49371 .71116 L 0 0 .045 r
F
0 g
.49186 .71034 m
.49371 .70783 L
s
.50185 .69956 m .50179 .70002 L .4983 .70499 L 0 0 .045 r
F
0 g
.50185 .69956 m
.50187 .69953 L
s
.50174 .70063 m
.50175 .70062 L
s
.50175 .70062 m
.50183 .70047 L
s
.50183 .70047 m
.50188 .70038 L
s
.50179 .70002 m
.50183 .69994 L
s
.50183 .69994 m
.50185 .69991 L
s
.49852 .70364 m
.50166 .69928 L
s
.50182 .70144 m
.50186 .70137 L
s
.50175 .701 m
.50177 .70097 L
s
.50177 .70097 m
.50188 .70078 L
s
.49852 .70364 m
.50122 .70033 L
s
.50122 .70033 m
.50169 .69976 L
s
.50169 .69976 m
.5017 .69974 L
s
.5017 .69974 m
.5017 .69974 L
s
.5017 .69974 m
.50185 .69956 L
s
.50185 .69956 m
.50185 .69956 L
s
.28528 .95538 m .28358 .96192 L .28719 .96076 L 0 1 .536 r
F
0 g
.28719 .96076 m
.28942 .96169 L
s
.28528 .95538 m .27606 .95813 L .28358 .96192 L 0 1 .536 r
F
0 g
.28358 .96192 m
.2864 .96714 L
s
.56084 .542 m .56183 .56591 L .55969 .55616 L 0 .424 .16 r
F
.56084 .542 m .56655 .56998 L .56183 .56591 L F
.56084 .542 m .57068 .56562 L .56655 .56998 L F
0 g
.56704 .54731 m
.56706 .55693 L
s
.56084 .542 m .5718 .55139 L .57068 .56562 L 0 .424 .16 r
F
0 g
.55651 .54274 m
.56084 .542 L
s
.46613 .98185 m .46937 .98587 L .47038 .98411 L 0 1 .538 r
F
.48311 .9838 m .47038 .98411 L .46937 .98587 L 0 1 .536 r
F
0 g
.46937 .98587 m
.47405 .98762 L
s
.4633 .98621 m
.46937 .98587 L
s
.47817 .90125 m .47318 .90367 L .46832 .90674 L 0 1 .273 r
F
0 g
.47817 .90125 m
.48009 .90091 L
s
.48127 .89741 m .47318 .90367 L .47817 .90125 L 0 1 .227 r
F
0 g
.47817 .90125 m
.48259 .89839 L
s
.33709 .9333 m .32022 .93673 L .32223 .93732 L 0 .853 .242 r
F
.33709 .9333 m .32385 .93551 L .32022 .93673 L F
.33709 .9333 m .3311 .93404 L .32385 .93551 L F
0 g
.33709 .9333 m
.33907 .9339 L
s
.50679 .71366 m .5064 .71223 L .50399 .71842 L 0 .649 .296 r
F
0 g
.50594 .71342 m
.5064 .71223 L
s
.5064 .71223 m
.50823 .70192 L
s
.52151 .96997 m
.52227 .97098 L
s
.51721 .95791 m .51749 .96455 L .52222 .96748 L 0 .383 .371 r
F
0 g
.51749 .96455 m
.52151 .96997 L
s
.30224 .72021 m .29296 .7284 L .29848 .72742 L 0 1 .463 r
F
0 g
.29848 .72742 m
.30365 .73311 L
s
.53232 .69062 m
.53265 .69137 L
s
.53265 .69137 m
.53335 .69298 L
s
.53232 .69062 m
.53356 .68984 L
s
.53356 .68984 m
.53399 .68956 L
s
.53399 .68956 m
.53553 .68858 L
s
.38863 .66697 m
.39142 .67158 L
s
.38773 .67759 m
.39142 .67158 L
s
.68811 .93862 m .69884 .9348 L .69539 .93509 L 0 1 .456 r
F
.70244 .9261 m .69884 .9348 L .70575 .93038 L 0 1 .473 r
F
.70244 .9261 m .69539 .93509 L .69884 .9348 L F
0 g
.69649 .93811 m
.69884 .9348 L
s
.52097 .69983 m
.52097 .69983 L
s
.59491 .56932 m
.59494 .5712 L
s
.59486 .56646 m
.59491 .56932 L
s
.59484 .56516 m
.59486 .56646 L
s
.59477 .56086 m
.59484 .56516 L
s
.49175 .71049 m .48102 .72182 L .48457 .71772 L 0 0 .011 r
F
.49175 .71049 m .48053 .72279 L .48102 .72182 L F
0 g
.48147 .72071 m
.48186 .72031 L
s
.49175 .71049 m .48347 .72006 L .48053 .72279 L 0 0 .011 r
F
0 g
.48186 .72031 m
.48326 .71897 L
s
.47927 .72292 m
.48076 .72142 L
s
.48076 .72142 m
.48147 .72071 L
s
.49175 .71049 m .48788 .71544 L .48347 .72006 L 0 0 .011 r
F
0 g
.48361 .71864 m
.48457 .71772 L
s
.48326 .71897 m
.48361 .71864 L
s
.49175 .71049 m .49143 .71135 L .48788 .71544 L 0 0 .011 r
F
0 g
.4912 .711 m
.49175 .71049 L
s
.49175 .71049 m
.49186 .71034 L
s
.4015 .9786 m .38761 .97415 L .38509 .97565 L 0 1 .539 r
F
.4015 .9786 m .39464 .97542 L .38761 .97415 L F
.40718 .9747 m .39464 .97542 L .4015 .9786 L F
0 g
.4015 .9786 m
.40826 .97978 L
s
.4015 .9786 m
.40502 .98222 L
s
.24331 .95303 m
.24985 .95496 L
s
.55316 1.04232 m
.55636 1.04557 L
s
.46833 .75765 m .46329 .7682 L .46678 .76425 L 0 .826 .345 r
F
.4722 .76962 m .46329 .7682 L .46211 .77503 L 0 .784 .345 r
F
.4722 .76962 m .46678 .76425 L .46329 .7682 L F
0 g
.45939 .76723 m
.46329 .7682 L
s
.30224 .72021 m .28841 .72245 L .29296 .7284 L 0 1 .463 r
F
0 g
.28995 .73578 m
.29296 .7284 L
s
.47965 .70188 m
.48232 .70123 L
s
.48626 .73437 m .47616 .74249 L .47729 .74683 L 0 .76 .32 r
F
0 g
.47247 .74222 m
.47616 .74249 L
s
.47616 .74249 m
.47815 .73584 L
s
.53571 .68919 m
.53595 .69003 L
s
.53553 .68858 m
.53571 .68919 L
s
.51588 .68409 m
.51588 .68409 L
s
.46613 .98185 m .45196 .98265 L .45622 .98491 L 0 1 .538 r
F
0 g
.44984 .98527 m
.45622 .98491 L
s
.50661 .62034 m .50378 .61897 L .50459 .62111 L 0 1 .27 r
F
.50661 .62034 m .50496 .61448 L .50378 .61897 L F
.50661 .62034 m .50733 .61064 L .50496 .61448 L F
.50661 .62034 m .50936 .60988 L .50733 .61064 L F
0 g
.50579 .6255 m
.50661 .62034 L
s
.47021 .84049 m .46692 .83491 L .46266 .83344 L 0 .714 .376 r
F
.28841 .72245 m .28096 .73049 L .28545 .72972 L 0 1 .469 r
F
0 g
.28545 .72972 m
.28994 .73578 L
s
.34442 .7124 m .3335 .70652 L .33387 .71452 L 0 1 .442 r
F
.34442 .7124 m .3364 .69998 L .3335 .70652 L F
.34442 .7124 m .34064 .69927 L .3364 .69998 L F
.34442 .7124 m .34408 .7046 L .34064 .69927 L F
0 g
.34152 .71893 m
.34442 .7124 L
s
.34442 .7124 m
.34783 .71753 L
s
.51846 .68158 m .51888 .68027 L .52101 .68107 L 0 .094 .101 r
F
0 g
.51738 .67961 m
.51888 .68027 L
s
.5175 .97912 m .50573 .98268 L .51081 .98291 L 0 1 .486 r
F
0 g
.50545 .98492 m
.51081 .98291 L
s
.47923 .70617 m .47148 .71241 L .47599 .70954 L 0 1 .421 r
F
.47923 .70617 m .46789 .7131 L .47148 .71241 L F
.47923 .70617 m .46763 .71114 L .46789 .7131 L F
.47923 .70617 m .47087 .70777 L .46763 .71114 L F
0 g
.47599 .70954 m
.47963 .70855 L
s
.47923 .70617 m .47545 .70523 L .47087 .70777 L 0 1 .421 r
F
.47923 .70617 m .47903 .70455 L .47545 .70523 L F
0 g
.47923 .70617 m
.48028 .70581 L
s
.47599 .70954 m
.47923 .70617 L
s
.47903 .70455 m
.48232 .70123 L
s
.72103 1.07305 m .71181 1.07434 L .70702 1.07564 L 0 .786 .267 r
F
0 g
.69746 1.07593 m
.70702 1.07564 L
s
.46404 .7802 m .45994 .79084 L .46311 .78697 L 0 .815 .357 r
F
.4692 .79299 m .45994 .79084 L .45943 .7978 L 0 .767 .356 r
F
.4692 .79299 m .46311 .78697 L .45994 .79084 L F
0 g
.45589 .78961 m
.45994 .79084 L
s
.28841 .72245 m .27714 .7242 L .28096 .73049 L 0 1 .469 r
F
0 g
.27879 .73788 m
.28096 .73049 L
s
.4692 .79299 m .45943 .7978 L .46191 .80322 L 0 .767 .356 r
F
0 g
.45943 .7978 m
.45994 .79084 L
s
.4552 .79635 m
.45943 .7978 L
s
.50039 .98387 m .49345 .98408 L .48779 .98555 L 0 1 .53 r
F
0 g
.36523 .70035 m
.36523 .70035 L
s
.5246 .69829 m .53271 .7166 L .52808 .70508 L 0 .499 .267 r
F
.5246 .69829 m .53614 .72932 L .53271 .7166 L F
.5246 .69829 m .53608 .73472 L .53614 .72932 L F
.5246 .69829 m .53258 .72787 L .53608 .73472 L F
.5246 .69829 m .52798 .71338 L .53258 .72787 L F
.5246 .69829 m .52456 .70073 L .52798 .71338 L F
0 g
.52458 .69826 m
.5246 .69829 L
s
.52472 .69853 m
.52502 .6991 L
s
.5246 .69829 m
.52472 .69853 L
s
.52443 .70053 m
.52456 .70073 L
s
.4986 .65094 m
.49868 .65095 L
s
.54362 1.00208 m
.54374 1.00203 L
s
.40242 .75113 m .39564 .75668 L .40002 .75499 L 0 1 .498 r
F
.40242 .75113 m .39136 .75517 L .39564 .75668 L F
0 g
.39373 .76069 m
.39564 .75668 L
s
.40002 .75499 m
.40455 .75628 L
s
.4722 .76962 m .46211 .77503 L .46404 .7802 L 0 .784 .345 r
F
0 g
.46211 .77503 m
.46329 .7682 L
s
.45805 .77382 m
.46211 .77503 L
s
.48132 .88804 m .48271 .89828 L .48385 .89504 L 0 .628 .392 r
F
.48271 .89828 m .48273 .89829 L .48283 .89816 L 0 1 .227 r
F
.48271 .89828 m .48273 .89845 L .48283 .89816 L 0 .628 .392 r
F
.48271 .89828 m .48283 .89816 L .48385 .89504 L F
.49281 .89057 m .48494 .896 L .48273 .89829 L 0 1 .228 r
F
.49277 .90285 m .48494 .896 L .48273 .89845 L 0 .54 .384 r
F
.48494 .896 m .48385 .89504 L .48283 .89816 L F
.48494 .896 m .48283 .89816 L .48273 .89829 L 0 1 .228 r
F
.48494 .896 m .48283 .89816 L .48273 .89845 L 0 .54 .384 r
F
.48494 .896 m .48384 .89675 L .48283 .89816 L 0 1 .228 r
F
.48127 .89741 m .48271 .89828 L .48384 .89675 L 0 1 .227 r
F
.48271 .89828 m .48283 .89816 L .48384 .89675 L F
.51091 .60462 m .51329 .60043 L .5152 .5961 L 0 .995 .152 r
F
0 g
.51329 .60043 m
.51497 .60006 L
s
.50278 .70055 m
.5052 .69567 L
s
.50236 .7014 m
.50278 .70055 L
s
.50209 .70194 m
.50236 .7014 L
s
.5052 .69567 m
.5052 .69567 L
s
.50252 .70058 m
.5052 .69567 L
s
.50214 .70128 m
.50252 .70058 L
s
.50197 .70159 m
.50214 .70128 L
s
.50191 .70169 m
.50197 .70159 L
s
.27714 .7242 m .26973 .73237 L .27422 .73162 L 0 1 .473 r
F
0 g
.27422 .73162 m
.27879 .73788 L
s
.28492 .79993 m .27235 .79489 L .27124 .79828 L 0 1 .521 r
F
.28492 .79993 m .27676 .79424 L .27235 .79489 L F
.28492 .79993 m .28215 .79641 L .27676 .79424 L F
.29569 .7977 m .28215 .79641 L .28492 .79993 L 0 1 .515 r
F
0 g
.28379 .8033 m
.28492 .79993 L
s
.28492 .79993 m
.29018 .80183 L
s
.42414 .98145 m .41724 .97889 L .41043 .97818 L 0 1 .54 r
F
.42891 .97733 m .42414 .98145 L .43066 .9821 L 0 1 .539 r
F
.42891 .97733 m .41724 .97889 L .42414 .98145 L F
0 g
.42414 .98145 m
.42796 .98467 L
s
.47729 .74683 m .46833 .75765 L .47202 .75792 L 0 .793 .333 r
F
.4164 .59441 m .41901 .58718 L .41814 .58227 L 0 1 .382 r
F
0 g
.41901 .58718 m
.42141 .58425 L
s
.49277 .90285 m .48273 .89845 L .48569 .90555 L 0 .54 .384 r
F
0 g
.48259 .89839 m
.48273 .89845 L
s
.48109 .90325 m
.48569 .90555 L
s
.48569 .90555 m
.48569 .90555 L
s
.27714 .7242 m .26587 .72588 L .26973 .73237 L 0 1 .473 r
F
0 g
.26763 .73991 m
.26973 .73237 L
s
.45434 1.0581 m .44181 1.05832 L .45066 1.06326 L 0 1 .5 r
F
.45434 1.0581 m .43656 1.05313 L .44181 1.05832 L F
.44887 .91535 m .44931 .91739 L .4512 .91564 L 0 1 .297 r
F
.44887 .91535 m .44385 .91963 L .44931 .91739 L F
0 g
.44931 .91739 m
.45213 .91739 L
s
.37635 .68703 m .36835 .69409 L .37278 .69316 L 0 1 .42 r
F
0 g
.37278 .69316 m
.37627 .69788 L
s
.59624 .42829 m .59492 .44049 L .59285 .43052 L 0 .678 .095 r
F
0 g
.59285 .43052 m
.59362 .43002 L
s
.59624 .42829 m .60174 .45456 L .59492 .44049 L 0 .678 .095 r
F
.59624 .42829 m .60877 .46329 L .60174 .45456 L F
0 g
.60583 .42959 m
.6097 .44199 L
s
.59624 .42829 m .61214 .46099 L .60877 .46329 L 0 .678 .095 r
F
.59624 .42829 m .60962 .44924 L .61214 .46099 L F
.59624 .42829 m .60281 .43526 L .60962 .44924 L F
0 g
.60281 .43526 m
.60551 .43018 L
s
.59342 .42212 m
.59624 .42829 L
s
.59362 .43002 m
.59624 .42829 L
s
.50679 .71366 m .5028 .73364 L .50525 .72283 L 0 .649 .296 r
F
.50679 .71366 m .50039 .73984 L .5028 .73364 L F
.50679 .71366 m .49962 .73729 L .50039 .73984 L F
.50679 .71366 m .50116 .7281 L .49962 .73729 L F
.50679 .71366 m .50399 .71842 L .50116 .7281 L F
0 g
.50659 .71483 m
.50679 .71366 L
s
.50679 .71366 m
.5089 .7044 L
s
.50399 .71842 m
.50568 .71076 L
s
.50399 .71842 m
.50594 .71342 L
s
.26587 .72588 m .25851 .73419 L .263 .73347 L 0 1 .476 r
F
0 g
.263 .73347 m
.26763 .73991 L
s
.46889 .71788 m .46153 .72434 L .46593 .72146 L 0 1 .437 r
F
0 g
.46593 .72146 m
.46971 .72067 L
s
.49277 .90285 m .48569 .90555 L .49077 .91161 L 0 .54 .384 r
F
0 g
.48273 .89845 m
.48569 .90555 L
s
.27623 .9537 m .25801 .94892 L .26023 .95261 L 0 1 .526 r
F
.27623 .9537 m .26187 .94795 L .25801 .94892 L F
.27623 .9537 m .26969 .95 L .26187 .94795 L F
.28544 .95086 m .26969 .95 L .27623 .9537 L 0 1 .522 r
F
0 g
.27623 .9537 m
.28381 .95555 L
s
.27623 .9537 m
.27841 .95738 L
s
.51117 .71079 m
.51117 .71079 L
s
.49678 .72668 m .49303 .72646 L .48953 .73256 L 0 .701 .308 r
F
.49678 .72668 m .49614 .72394 L .49303 .72646 L F
0 g
.49303 .72646 m
.49524 .71976 L
s
.49303 .72646 m
.49614 .72394 L
s
.49614 .72394 m
.49746 .71926 L
s
.48398 .7184 m
.48457 .71772 L
s
.48128 .72152 m
.48398 .7184 L
s
.49077 .91161 m .49347 .92155 L .4941 .91847 L 0 .565 .395 r
F
.50362 .92684 m .49347 .92155 L .49719 .92851 L 0 .464 .381 r
F
.50362 .92684 m .4941 .91847 L .49347 .92155 L F
0 g
.48885 .91923 m
.49347 .92155 L
s
.26587 .72588 m .25461 .72752 L .25851 .73419 L 0 1 .476 r
F
0 g
.25648 .74189 m
.25851 .73419 L
s
.72103 1.07305 m .71903 1.07517 L .72859 1.07351 L 0 .786 .267 r
F
0 g
.71462 1.07657 m
.71903 1.07517 L
s
.7098 1.07608 m
.71903 1.07517 L
s
.45434 1.0581 m .45066 1.06326 L .45828 1.06539 L 0 1 .5 r
F
.25461 .72752 m .24728 .73597 L .25177 .73527 L 0 1 .479 r
F
0 g
.25177 .73527 m
.25648 .74189 L
s
.46849 .81668 m .46216 .82651 L .46628 .82772 L 0 .744 .366 r
F
0 g
.46216 .82651 m
.46266 .83344 L
s
.43376 1.04562 m .42878 1.05052 L .43656 1.05313 L 0 1 .499 r
F
.43376 1.04562 m .42025 1.04505 L .42878 1.05052 L F
0 g
.50111 .70098 m
.50134 .70065 L
s
.50134 .70065 m
.50147 .70047 L
s
.50147 .70047 m
.50147 .70047 L
s
.50147 .70047 m
.50154 .70036 L
s
.50154 .70036 m
.50173 .7001 L
s
.50173 .7001 m
.50173 .7001 L
s
.50173 .7001 m
.50173 .7001 L
s
.50173 .7001 m
.50179 .70002 L
s
.40592 .62991 m .39691 .63635 L .40132 .63568 L 0 1 .396 r
F
.40592 .62991 m .39503 .63154 L .39691 .63635 L F
0 g
.40132 .63568 m
.40366 .64042 L
s
.40592 .62991 m .39693 .62445 L .39503 .63154 L 0 1 .396 r
F
.40592 .62991 m .40154 .61867 L .39693 .62445 L F
.40592 .62991 m .40579 .61806 L .40154 .61867 L F
.40592 .62991 m .40766 .62288 L .40579 .61806 L F
0 g
.40592 .62991 m
.40791 .63467 L
s
.40132 .63568 m
.40592 .62991 L
s
.40766 .62288 m
.41214 .61716 L
s
.25461 .72752 m .24334 .7291 L .24728 .73597 L 0 1 .479 r
F
0 g
.24533 .74383 m
.24728 .73597 L
s
.4722 .76962 m .4706 .76485 L .46678 .76425 L 0 .784 .345 r
F
0 g
.46678 .76425 m
.46833 .75765 L
s
.29467 .94804 m .29283 .95253 L .29644 .95133 L 0 1 .517 r
F
0 g
.29644 .95133 m
.30429 .95252 L
s
.29467 .94804 m .28544 .95086 L .29283 .95253 L 0 1 .517 r
F
0 g
.29283 .95253 m
.29548 .95571 L
s
.21316 .77934 m .19968 .7727 L .20212 .781 L 0 1 .527 r
F
0 g
.20212 .781 m
.20723 .78664 L
s
.24334 .7291 m .23606 .73771 L .24055 .73702 L 0 1 .483 r
F
0 g
.24055 .73702 m
.24533 .74383 L
s
.37015 .7622 m .36014 .75672 L .35832 .76085 L 0 1 .511 r
F
.37015 .7622 m .36428 .75565 L .36014 .75672 L F
.37015 .7622 m .36857 .758 L .36428 .75565 L F
0 g
.36832 .76632 m
.37015 .7622 L
s
.38075 .7588 m .36858 .758 L .37016 .7622 L 0 1 .508 r
F
0 g
.37016 .7622 m
.37449 .76426 L
s
.38472 .97031 m .38509 .97565 L .38761 .97415 L 0 1 .538 r
F
.38472 .97031 m .37819 .97393 L .38509 .97565 L F
0 g
.38509 .97565 m
.38863 .97927 L
s
.24334 .7291 m .23208 .73065 L .23606 .73771 L 0 1 .483 r
F
0 g
.23419 .74573 m
.23606 .73771 L
s
.42891 .97733 m .43066 .9821 L .43245 .98042 L 0 1 .539 r
F
.44578 .9825 m .43245 .98042 L .43066 .9821 L 0 1 .54 r
F
0 g
.43066 .9821 m
.43473 .98488 L
s
.42414 .98145 m
.43066 .9821 L
s
.32917 .79035 m .32379 .79377 L .32779 .79276 L 0 1 .478 r
F
.32917 .79035 m .31905 .79265 L .32379 .79377 L F
0 g
.32311 .79635 m
.32379 .79377 L
s
.32779 .79276 m
.333 .79361 L
s
.46889 .71788 m .4578 .72485 L .46153 .72434 L 0 1 .437 r
F
.46889 .71788 m .45723 .72266 L .4578 .72485 L F
0 g
.45884 .72809 m
.46153 .72434 L
s
.46889 .71788 m .46019 .71908 L .45723 .72266 L 0 1 .437 r
F
.46889 .71788 m .4647 .7165 L .46019 .71908 L F
.46889 .71788 m .46843 .71599 L .4647 .7165 L F
0 g
.46889 .71788 m
.47253 .71689 L
s
.46593 .72146 m
.46889 .71788 L
s
.4164 .59441 m .40738 .60091 L .41141 .6003 L 0 1 .382 r
F
0 g
.41516 .60225 m
.41745 .59942 L
s
.4164 .59441 m .40651 .596 L .40738 .60091 L 0 1 .382 r
F
.4164 .59441 m .40938 .58884 L .40651 .596 L F
.4164 .59441 m .41436 .58295 L .40938 .58884 L F
.4164 .59441 m .41814 .58227 L .41436 .58295 L F
0 g
.4164 .59441 m
.41745 .59942 L
s
.41814 .58227 m
.42323 .57619 L
s
.41814 .58227 m
.41901 .58718 L
s
.23208 .73065 m .22483 .73942 L .22932 .73874 L 0 1 .485 r
F
0 g
.22932 .73874 m
.23419 .74573 L
s
.27955 .76891 m .27312 .77509 L .27752 .77428 L 0 1 .525 r
F
.27955 .76891 m .26847 .77073 L .27312 .77509 L F
0 g
.27193 .78059 m
.27312 .77509 L
s
.27752 .77428 m
.28282 .77836 L
s
.72859 1.07351 m .73613 1.07413 L .74124 1.07252 L 0 .894 .3 r
F
.23208 .73065 m .22081 .73217 L .22483 .73942 L 0 1 .485 r
F
0 g
.22304 .74759 m
.22483 .73942 L
s
.50166 .58613 m .50694 .54907 L .50384 .54946 L 0 1 .264 r
F
.50166 .58613 m .50726 .56 L .50694 .54907 L F
0 g
.50694 .54907 m
.50956 .53111 L
s
.50451 .54938 m
.50694 .54907 L
s
.51132 .87517 m
.51158 .87491 L
s
.74457 .92395 m .7414 .93187 L .74858 .93041 L 0 1 .522 r
F
.74457 .92395 m .73763 .93044 L .7414 .93187 L F
0 g
.73915 .93542 m
.7414 .93187 L
s
.22081 .73217 m .21361 .74109 L .2181 .74042 L 0 1 .488 r
F
0 g
.2181 .74042 m
.22304 .74759 L
s
.22081 .73217 m .20954 .73365 L .21361 .74109 L 0 1 .488 r
F
0 g
.2119 .74942 m
.21361 .74109 L
s
.52339 .97193 m
.52342 .97195 L
s
.52527 .97315 m
.52527 .97315 L
s
.49804 .64712 m .49934 .64491 L .49902 .64153 L 0 1 .363 r
F
0 g
.49934 .64491 m
.5016 .64598 L
s
.20954 .73365 m .20239 .74273 L .20688 .74207 L 0 1 .49 r
F
0 g
.20688 .74207 m
.2119 .74942 L
s
.81375 .79584 m .82172 .80445 L .82503 .80165 L 0 .631 .396 r
F
0 g
.81594 .80462 m
.82172 .80445 L
s
.20954 .73365 m .19828 .73511 L .20239 .74273 L 0 1 .49 r
F
0 g
.20077 .75122 m
.20239 .74273 L
s
.33387 .71452 m .32292 .7083 L .32333 .71651 L 0 1 .448 r
F
.33387 .71452 m .32579 .70165 L .32292 .7083 L F
.33387 .71452 m .33003 .701 L .32579 .70165 L F
.33387 .71452 m .3335 .70652 L .33003 .701 L F
0 g
.331 .72116 m
.33387 .71452 L
s
.33387 .71452 m
.33731 .71983 L
s
.48626 .73437 m .48077 .7462 L .48427 .74102 L 0 .76 .32 r
F
.48626 .73437 m .47729 .74683 L .48077 .7462 L F
0 g
.47936 .69776 m
.48221 .69734 L
s
.7536 .90576 m .76476 .89983 L .76082 .90001 L 0 1 .514 r
F
.74393 .90641 m .7536 .90576 L .75491 .90041 L 0 1 .509 r
F
0 g
.49326 .7092 m
.49449 .70777 L
s
.49241 .71019 m
.49326 .7092 L
s
.49211 .71054 m
.49241 .71019 L
s
.49143 .71135 m
.49211 .71054 L
s
.50362 .92684 m .49719 .92851 L .5028 .93473 L 0 .464 .381 r
F
0 g
.49347 .92155 m
.49719 .92851 L
s
.49251 .92596 m
.49719 .92851 L
s
.48446 .8787 m .47683 .88212 L .48132 .88804 L 0 .601 .38 r
F
.48446 .8787 m .47464 .87498 L .47683 .88212 L F
0 g
.4723 .88016 m
.47683 .88212 L
s
.49838 .54309 m .50564 .51847 L .50531 .51359 L 0 1 .212 r
F
.49838 .54309 m .50268 .5311 L .50564 .51847 L F
0 g
.50564 .51847 m
.50911 .5119 L
s
.37635 .68703 m .3653 .68922 L .36835 .69409 L 0 1 .42 r
F
0 g
.36523 .70035 m
.36835 .69409 L
s
.37635 .68703 m .36565 .6818 L .3653 .68922 L 0 1 .42 r
F
.37635 .68703 m .36923 .67567 L .36565 .6818 L F
.37635 .68703 m .37365 .67492 L .36923 .67567 L F
.37635 .68703 m .3767 .67979 L .37365 .67492 L F
0 g
.37635 .68703 m
.37941 .69171 L
s
.37278 .69316 m
.37635 .68703 L
s
.4106 .61228 m .41279 .60517 L .41141 .6003 L 0 1 .391 r
F
0 g
.41279 .60517 m
.41516 .60225 L
s
.44385 .91963 m .43275 .92303 L .43056 .92468 L 0 1 .357 r
F
.44385 .91963 m .43844 .92087 L .43275 .92303 L F
0 g
.44385 .91963 m
.44653 .92006 L
s
.44887 .91535 m .43844 .92086 L .44385 .91963 L 0 1 .297 r
F
0 g
.44385 .91963 m
.44931 .91739 L
s
.41348 .74676 m .4066 .75236 L .41099 .75053 L 0 1 .492 r
F
.41348 .74676 m .40242 .75113 L .4066 .75236 L F
0 g
.40455 .75628 m
.4066 .75236 L
s
.41099 .75053 m
.41539 .75154 L
s
.46849 .81668 m .46579 .81131 L .46167 .8101 L 0 .744 .366 r
F
0 g
.6076 .4451 m
.60787 .44565 L
s
.60685 .44355 m
.6076 .4451 L
s
.60491 .43958 m
.60685 .44355 L
s
.60281 .43526 m
.60491 .43958 L
s
.43376 1.04562 m .41561 1.03954 L .42025 1.04505 L 0 1 .499 r
F
.47447 .86431 m .47464 .87498 L .47621 .87136 L 0 .676 .385 r
F
.48446 .8787 m .47621 .87136 L .47464 .87498 L 0 .601 .38 r
F
0 g
.47464 .87498 m
.47683 .88212 L
s
.47023 .87325 m
.47464 .87498 L
s
.4106 .61228 m .40154 .61867 L .40579 .61806 L 0 1 .391 r
F
.4106 .61228 m .40016 .6138 L .40154 .61867 L F
0 g
.40579 .61806 m
.40766 .62288 L
s
.4106 .61228 m .40256 .6067 L .40016 .6138 L 0 1 .391 r
F
.4106 .61228 m .40738 .60091 L .40256 .6067 L F
.4106 .61228 m .41141 .6003 L .40738 .60091 L F
0 g
.40579 .61806 m
.4106 .61228 L
s
.4106 .61228 m
.41214 .61716 L
s
.41141 .6003 m
.4164 .59441 L
s
.41141 .6003 m
.41279 .60517 L
s
.24295 .95301 m
.2442 .95366 L
s
.2442 .95366 m
.25071 .95707 L
s
.4049 .93125 m .40453 .9341 L .40705 .93249 L 0 1 .41 r
F
.4049 .93125 m .39834 .93512 L .40453 .9341 L F
0 g
.40453 .9341 m
.40727 .93514 L
s
.49788 .72502 m
.49953 .72252 L
s
.49953 .72252 m
.49966 .72233 L
s
.49949 .72309 m
.49966 .72233 L
s
.69188 .67415 m
.6927 .67407 L
s
.3653 .68922 m
.36835 .69409 L
s
.47729 .74683 m .47202 .75792 L .47552 .75344 L 0 .793 .333 r
F
0 g
.62113 .46228 m
.62117 .46224 L
s
.74995 .74551 m .75551 .75146 L .7601 .75539 L 0 .043 .154 r
F
0 g
.7493 .74528 m
.7509 .747 L
s
.75551 .75146 m
.7571 .75567 L
s
.42741 .75974 m .42103 .7634 L .42525 .76118 L 0 .86 .216 r
F
.42741 .75974 m .41671 .76512 L .42103 .7634 L F
0 g
.4193 .76497 m
.42103 .7634 L
s
.42525 .76118 m
.4297 .75923 L
s
.73423 .90751 m .7385 .91358 L .74393 .90641 L 0 1 .503 r
F
0 g
.73167 .91912 m
.7385 .91358 L
s
.73722 .91889 m
.7385 .91358 L
s
.47688 .45928 m .48686 .44665 L .48608 .44977 L 0 0 0 r
F
0 g
.48686 .44665 m
.49205 .43778 L
s
.48292 .45073 m
.48686 .44665 L
s
.49678 .72668 m .48953 .73256 L .48762 .73984 L 0 .701 .308 r
F
0 g
.48626 .73437 m
.48953 .73256 L
s
.50116 .98028 m .50039 .98387 L .50573 .98268 L 0 1 .517 r
F
.50116 .98028 m .49345 .98408 L .50039 .98387 L F
0 g
.50039 .98387 m
.50545 .98492 L
s
.78279 .67641 m .79101 .67425 L .78641 .67252 L 0 1 .497 r
F
.78279 .67641 m .79427 .68095 L .79101 .67425 L F
0 g
.7795 .66974 m
.78279 .67641 L
s
.51846 .68158 m .52167 .68979 L .51966 .68565 L 0 .094 .101 r
F
.51846 .68158 m .52381 .6906 L .52167 .68979 L F
.51846 .68158 m .52464 .68754 L .52381 .6906 L F
.51846 .68158 m .52344 .68345 L .52464 .68754 L F
.51846 .68158 m .52101 .68107 L .52344 .68345 L F
0 g
.51846 .68158 m
.51854 .68185 L
s
.51665 .6819 m
.51846 .68158 L
s
.51949 .67828 m
.52101 .68107 L
s
.51888 .68027 m
.52101 .68107 L
s
.47554 1.06903 m .46411 1.07023 L .47319 1.07459 L 0 1 .501 r
F
.47554 1.06903 m .45828 1.06539 L .46411 1.07023 L F
.51091 .60462 m .5152 .5961 L .51535 .59451 L 0 .995 .152 r
F
0 g
.5152 .5961 m
.5159 .59514 L
s
.51329 .60043 m
.5152 .5961 L
s
.4692 .79299 m .46707 .78789 L .46311 .78697 L 0 .767 .356 r
F
0 g
.52496 .70221 m
.52504 .70249 L
s
.52476 .70145 m
.52496 .70221 L
s
.52456 .70073 m
.52476 .70145 L
s
.4722 .76962 m .46404 .7802 L .46786 .78081 L 0 .784 .345 r
F
0 g
.46311 .78697 m
.46404 .7802 L
s
.58814 .42406 m
.59285 .43052 L
s
.4692 .79299 m .46191 .80322 L .46588 .80415 L 0 .767 .356 r
F
0 g
.46167 .8101 m
.46191 .80322 L
s
.30408 .94055 m .30209 .94292 L .30571 .94167 L 0 .877 .256 r
F
0 g
.30571 .94167 m
.31339 .94064 L
s
.30408 .94055 m .29483 .94343 L .30209 .94292 L 0 .877 .256 r
F
0 g
.30209 .94292 m
.30457 .94399 L
s
.52074 .70342 m
.52074 .70342 L
s
.47885 .70207 m .47087 .70777 L .47545 .70523 L 0 1 .42 r
F
.47885 .70207 m .46737 .70816 L .47087 .70777 L F
.47885 .70207 m .4673 .70614 L .46737 .70816 L F
.47885 .70207 m .47071 .70297 L .4673 .70614 L F
0 g
.47545 .70523 m
.47903 .70455 L
s
.47885 .70207 m .47531 .70078 L .47071 .70297 L 0 1 .42 r
F
.47885 .70207 m .4788 .70039 L .47531 .70078 L F
0 g
.47885 .70207 m
.47965 .70188 L
s
.47545 .70523 m
.47885 .70207 L
s
.4788 .70039 m
.48221 .69734 L
s
.60123 .42049 m .60807 .42033 L .61502 .42493 L 0 .351 .082 r
F
0 g
.60807 .42033 m
.61135 .41427 L
s
.4578 .72485 m .45054 .73104 L .45493 .72844 L 0 1 .452 r
F
0 g
.45493 .72844 m
.45884 .72809 L
s
.5078 .71705 m .50738 .71572 L .50525 .72283 L 0 .635 .296 r
F
0 g
.50682 .71759 m
.50738 .71572 L
s
.50738 .71572 m
.5089 .70441 L
s
.39536 .77461 m .38467 .77632 L .38306 .77796 L 0 1 .322 r
F
.39536 .77461 m .38888 .77488 L .38467 .77632 L F
.39536 .77461 m .39346 .77414 L .38888 .77488 L F
0 g
.39374 .77625 m
.39536 .77461 L
s
.40603 .77005 m .39347 .77414 L .39536 .77461 L 0 1 .267 r
F
0 g
.39536 .77461 m
.39993 .77353 L
s
.48039 .75753 m .47202 .75792 L .4706 .76485 L 0 .754 .332 r
F
.48039 .75753 m .47552 .75344 L .47202 .75792 L F
0 g
.46833 .75765 m
.47202 .75792 L
s
.65575 .49392 m
.65728 .49942 L
s
.65417 .48687 m
.65547 .49266 L
s
.65547 .49266 m
.65575 .49392 L
s
.46918 .71285 m
.47148 .71241 L
s
.46843 .71599 m
.47148 .71241 L
s
.51198 .7125 m
.51198 .71249 L
s
.70244 .9261 m .70575 .93038 L .71154 .92477 L 0 1 .473 r
F
0 g
.69884 .9348 m
.70575 .93038 L
s
.704 .9345 m
.70575 .93038 L
s
.55612 1.05491 m
.55824 1.05217 L
s
.55849 1.05185 m
.55855 1.05176 L
s
.49097 .71187 m
.49124 .71156 L
s
.49124 .71156 m
.49143 .71135 L
s
.55434 1.0797 m
.55519 1.07085 L
s
.79657 .88371 m .80777 .87672 L .80363 .87677 L 0 1 .512 r
F
.78638 .88394 m .79657 .88371 L .79743 .87693 L 0 1 .51 r
F
.32785 .96016 m .32662 .96623 L .32995 .96492 L 0 1 .536 r
F
.32785 .96016 m .31929 .96331 L .32662 .96623 L F
0 g
.32662 .96623 m
.32952 .97083 L
s
.21316 .77934 m .20121 .7661 L .19968 .7727 L 0 1 .527 r
F
.21316 .77934 m .20571 .76562 L .20121 .7661 L F
.21316 .77934 m .21083 .77131 L .20571 .76562 L F
.22421 .77767 m .21083 .77131 L .21316 .77934 L F
0 g
.21161 .7859 m
.21316 .77934 L
s
.21316 .77934 m
.21819 .78478 L
s
.43548 .53406 m .43972 .526 L .44099 .52098 L 0 1 .269 r
F
0 g
.43458 .53936 m
.43548 .53406 L
s
.37819 .97393 m .36365 .96864 L .35993 .97043 L 0 1 .538 r
F
.37819 .97393 m .37148 .97014 L .36365 .96864 L F
0 g
.37819 .97393 m
.38074 .97827 L
s
.38472 .97031 m .37148 .97014 L .37819 .97393 L 0 1 .538 r
F
0 g
.37819 .97393 m
.38509 .97565 L
s
.50534 .69618 m
.50534 .69618 L
s
.50514 .6966 m
.50534 .69618 L
s
.50477 .69738 m
.50514 .6966 L
s
.5029 .70138 m
.50477 .69738 L
s
.50533 .69618 m
.50534 .69618 L
s
.50509 .69664 m
.50533 .69618 L
s
.50466 .69748 m
.50509 .69664 L
s
.5026 .70143 m
.50466 .69748 L
s
.32333 .71651 m .31233 .70998 L .31279 .71841 L 0 1 .454 r
F
.32333 .71651 m .31518 .7032 L .31233 .70998 L F
.32333 .71651 m .31942 .70259 L .31518 .7032 L F
.32333 .71651 m .32292 .7083 L .31942 .70259 L F
0 g
.32049 .72328 m
.32333 .71651 L
s
.32333 .71651 m
.3268 .72202 L
s
.77067 .66218 m
.77077 .66209 L
s
.76597 .88541 m .76476 .89983 L .77134 .89318 L 0 1 .504 r
F
.76597 .88541 m .76082 .90001 L .76476 .89983 L F
0 g
.76327 .90549 m
.76476 .89983 L
s
.38075 .7588 m .37064 .75396 L .36858 .758 L 0 1 .508 r
F
.38075 .7588 m .37496 .75277 L .37064 .75396 L F
.38075 .7588 m .3793 .75484 L .37496 .75277 L F
.39136 .75517 m .3793 .75484 L .38075 .7588 L 0 1 .503 r
F
0 g
.37869 .76283 m
.38075 .7588 L
s
.38075 .7588 m
.38499 .76062 L
s
.38862 .66697 m .38026 .67373 L .38467 .67291 L 0 1 .411 r
F
.38862 .66697 m .37765 .66893 L .38026 .67373 L F
0 g
.38467 .67291 m
.38773 .67759 L
s
.38862 .66697 m .37857 .6617 L .37765 .66893 L 0 1 .411 r
F
.38862 .66697 m .38253 .65577 L .37857 .6617 L F
.38862 .66697 m .38687 .65508 L .38253 .65577 L F
.38862 .66697 m .38948 .65989 L .38687 .65508 L F
0 g
.38467 .67291 m
.38862 .66697 L
s
.73423 .90751 m .72905 .91438 L .72796 .91934 L 0 1 .503 r
F
0 g
.72678 .92008 m
.72796 .91934 L
s
.49804 .64712 m .49327 .64572 L .49544 .64747 L 0 1 .363 r
F
.49804 .64712 m .49295 .64234 L .49327 .64572 L F
.49804 .64712 m .49469 .63957 L .49295 .64234 L F
.49804 .64712 m .49729 .63922 L .49469 .63957 L F
.49804 .64712 m .49902 .64153 L .49729 .63922 L F
0 g
.49804 .64712 m
.49868 .65095 L
s
.49902 .64153 m
.50133 .64158 L
s
.49902 .64153 m
.49934 .64491 L
s
.4733 .46375 m
.47688 .45928 L
s
.51508 .68614 m
.51508 .68614 L
s
.51508 .68614 m
.51508 .68614 L
s
.42455 .74201 m .41757 .74769 L .42197 .74572 L 0 1 .484 r
F
.42455 .74201 m .41348 .74676 L .41757 .74769 L F
0 g
.41539 .75154 m
.41757 .74769 L
s
.42197 .74572 m
.42624 .74642 L
s
.55182 1.05709 m
.55186 1.05709 L
s
.4578 .72485 m .44672 .73114 L .45054 .73104 L 0 1 .452 r
F
0 g
.44797 .73478 m
.45054 .73104 L
s
.49553 .65586 m
.49591 .65588 L
s
.67778 .93997 m .6881 .93862 L .68962 .93581 L 0 1 .413 r
F
.48102 .72182 m .47397 .72786 L .47821 .72399 L 0 0 0 r
F
0 g
.47821 .72399 m
.47927 .72292 L
s
.29063 .76704 m .28412 .77305 L .28853 .77221 L 0 1 .525 r
F
.29063 .76704 m .27955 .76891 L .28412 .77305 L F
0 g
.28282 .77836 m
.28412 .77305 L
s
.28853 .77221 m
.29372 .77608 L
s
.48039 .75753 m .4791 .75327 L .47552 .75344 L 0 .754 .332 r
F
0 g
.47552 .75344 m
.47729 .74683 L
s
.52774 .67423 m .52846 .67069 L .53138 .66884 L 0 .161 .12 r
F
0 g
.52661 .66939 m
.52846 .67069 L
s
.49678 .72668 m .49169 .74093 L .49488 .73396 L 0 .701 .308 r
F
.49678 .72668 m .48858 .74345 L .49169 .74093 L F
.49678 .72668 m .48762 .73984 L .48858 .74345 L F
0 g
.49678 .72668 m
.49788 .72502 L
s
.51761 .58931 m .52046 .58399 L .52307 .58009 L 0 0 0 r
F
0 g
.52203 .58186 m
.52212 .58174 L
s
.50172 .70067 m .49371 .71116 L .4983 .70499 L 0 0 .048 r
F
0 g
.50174 .7016 m
.50182 .70144 L
s
.50172 .70067 m .49023 .71631 L .49371 .71116 L 0 0 .048 r
F
.50172 .70067 m .49019 .71698 L .49023 .71631 L F
.50172 .70067 m .49363 .71265 L .49019 .71698 L F
0 g
.49037 .71256 m
.49097 .71187 L
s
.49022 .71274 m
.49037 .71256 L
s
.49112 .71243 m
.49253 .71047 L
s
.49253 .71047 m
.49295 .70989 L
s
.50172 .70067 m .49824 .70621 L .49363 .71265 L 0 0 .048 r
F
0 g
.49295 .70989 m
.49449 .70777 L
s
.50173 .70161 m
.50174 .7016 L
s
.50172 .70067 m .5017 .70108 L .49824 .70621 L 0 0 .048 r
F
0 g
.50172 .70067 m
.50174 .70063 L
s
.5017 .70108 m
.50175 .701 L
s
.50083 .7018 m
.50151 .70094 L
s
.50151 .70094 m
.50158 .70085 L
s
.50158 .70085 m
.50158 .70085 L
s
.50158 .70085 m
.50172 .70067 L
s
.50172 .70067 m
.50172 .70067 L
s
.48858 .74345 m .48427 .74102 L .48077 .7462 L 0 .726 .32 r
F
.48858 .74345 m .48762 .73984 L .48427 .74102 L F
0 g
.48427 .74102 m
.48626 .73437 L
s
.48427 .74102 m
.48762 .73984 L
s
.48762 .73984 m
.48953 .73256 L
s
.47943 .69345 m
.48243 .69332 L
s
.47956 .6956 m
.48243 .69332 L
s
.5028 .93473 m .50668 .9445 L .50687 .94159 L 0 .482 .39 r
F
.51692 .9504 m .50668 .9445 L .51111 .95148 L 0 .374 .367 r
F
0 g
.5111 .95148 m
.51111 .95149 L
s
.51692 .9504 m .50687 .94159 L .50668 .9445 L 0 .374 .367 r
F
0 g
.5064 .94858 m
.5111 .95148 L
s
.50199 .94193 m
.50668 .9445 L
s
.53768 .66506 m .54549 .65318 L .54722 .6641 L 0 .213 .148 r
F
0 g
.54549 .65318 m
.54893 .64214 L
s
.63261 .55181 m
.63285 .56835 L
s
.63285 .56835 m
.63289 .57111 L
s
.37697 .93763 m .37616 .94088 L .37901 .9394 L 0 1 .455 r
F
.37697 .93763 m .36964 .94115 L .37616 .94088 L F
0 g
.37616 .94088 m
.37885 .94249 L
s
.63261 .55183 m
.63698 .59613 L
s
.47872 .85439 m .47058 .85855 L .47447 .86431 L 0 .649 .373 r
F
.47872 .85439 m .46917 .85137 L .47058 .85855 L F
0 g
.46617 .85684 m
.47058 .85855 L
s
.44672 .73114 m .43954 .7371 L .44394 .73475 L 0 1 .464 r
F
0 g
.44394 .73475 m
.44797 .73478 L
s
.72074 .92766 m .73198 .92824 L .72821 .92674 L 0 1 .528 r
F
.5175 .97912 m .52282 .98031 L .52259 .97935 L 0 1 .486 r
F
0 g
.51778 .98184 m
.52282 .98031 L
s
.52282 .98031 m
.52398 .98019 L
s
.48858 .74345 m .48077 .7462 L .4791 .75327 L 0 .726 .32 r
F
0 g
.47729 .74683 m
.48077 .7462 L
s
.43563 .73683 m .42855 .74263 L .43295 .74048 L 0 1 .475 r
F
.43563 .73683 m .42455 .74201 L .42855 .74263 L F
0 g
.42624 .74642 m
.42855 .74263 L
s
.43295 .74048 m
.4371 .74086 L
s
.32819 .94851 m .31093 .94655 L .31312 .94935 L 0 1 .507 r
F
.32819 .94851 m .31456 .94537 L .31093 .94655 L F
.32819 .94851 m .32197 .94621 L .31456 .94537 L F
.33676 .94516 m .32197 .94621 L .32819 .94851 L 0 1 .498 r
F
0 g
.32819 .94851 m
.33535 .94916 L
s
.32819 .94851 m
.33034 .9513 L
s
.44672 .73114 m .43563 .73683 L .43954 .7371 L 0 1 .464 r
F
0 g
.4371 .74086 m
.43954 .7371 L
s
.49281 .89057 m .48527 .89566 L .48494 .896 L 0 1 .228 r
F
.49277 .90285 m .48815 .89692 L .48527 .89566 L 0 .54 .384 r
F
.48494 .896 m .48527 .89566 L .48385 .89504 L F
.49277 .90285 m .48527 .89566 L .48494 .896 L F
.49281 .89057 m .48816 .89344 L .48527 .89566 L 0 1 .228 r
F
.48494 .896 m .48527 .89566 L .48384 .89675 L F
.4948 .88757 m .49281 .89057 L .49678 .88754 L 0 .928 .204 r
F
.4948 .88757 m .48816 .89344 L .49281 .89057 L F
0 g
.49281 .89057 m
.4958 .88954 L
s
.47021 .84049 m .46917 .85137 L .47117 .84755 L 0 .714 .376 r
F
.47872 .85439 m .47117 .84755 L .46917 .85137 L 0 .649 .373 r
F
0 g
.46917 .85137 m
.47058 .85855 L
s
.4649 .84989 m
.46917 .85137 L
s
.35226 .96845 m .33496 .96296 L .33761 .9674 L 0 1 .537 r
F
.5078 .71705 m .50455 .7389 L .50658 .72698 L 0 .635 .296 r
F
.5078 .71705 m .50241 .74602 L .50455 .7389 L F
.5078 .71705 m .50159 .74358 L .50241 .74602 L F
.5078 .71705 m .5028 .73364 L .50159 .74358 L F
.5078 .71705 m .50525 .72283 L .5028 .73364 L F
0 g
.50755 .71906 m
.5078 .71705 L
s
.5078 .71705 m
.50963 .70672 L
s
.39834 .93512 m .38328 .93721 L .38571 .93864 L 0 1 .441 r
F
0 g
.37901 .9394 m
.38571 .93864 L
s
.29569 .7977 m .28337 .79325 L .28215 .79641 L 0 1 .515 r
F
.29569 .7977 m .28779 .79258 L .28337 .79325 L F
.29569 .7977 m .29307 .79449 L .28779 .79258 L F
0 g
.29445 .80084 m
.29569 .7977 L
s
.30894 .79488 m .29307 .79449 L .29569 .7977 L 0 1 .504 r
F
0 g
.29569 .7977 m
.30159 .79916 L
s
.52774 .67423 m .53138 .66884 L .53457 .6699 L 0 .161 .12 r
F
.52774 .67423 m .53218 .6846 L .52934 .68019 L F
.52774 .67423 m .53512 .68274 L .53218 .6846 L F
.52774 .67423 m .53618 .67585 L .53512 .68274 L F
.52774 .67423 m .53457 .6699 L .53618 .67585 L F
.52585 .68274 m .53229 .69843 L .52957 .69762 L 0 .2 .13 r
F
.52585 .68274 m .53345 .69242 L .53229 .69843 L F
.52585 .68274 m .53218 .6846 L .53345 .69242 L F
.52585 .68274 m .52934 .68019 L .53218 .6846 L F
.52923 .71171 m .53048 .7067 L .5333 .7138 L 0 .337 .169 r
F
.52923 .71171 m .5333 .7138 L .53582 .72835 L F
.53027 .71423 m .53645 .61142 L .53425 .61138 L 0 .807 .252 r
F
.53027 .71423 m .53671 .64461 L .53645 .61142 L F
0 g
.53645 .61142 m
.53945 .5741 L
s
.53595 .69003 m
.53648 .69189 L
s
.52846 .67069 m
.53138 .66884 L
s
.52947 .66532 m
.53138 .66884 L
s
.4578 .72485 m .44602 .72867 L .44672 .73114 L 0 1 .452 r
F
.4578 .72485 m .44889 .72508 L .44602 .72867 L F
.4578 .72485 m .45341 .72276 L .44889 .72508 L F
.4578 .72485 m .45723 .72266 L .45341 .72276 L F
0 g
.4578 .72485 m
.46153 .72434 L
s
.45493 .72844 m
.4578 .72485 L
s
.48039 .75753 m .4706 .76485 L .4722 .76962 L 0 .754 .332 r
F
0 g
.4706 .76485 m
.47202 .75792 L
s
.46678 .76425 m
.4706 .76485 L
s
.47554 1.06903 m .47319 1.07459 L .48058 1.07616 L 0 1 .501 r
F
.50116 .98028 m .48869 .98306 L .49345 .98408 L 0 1 .517 r
F
0 g
.48779 .98555 m
.49345 .98408 L
s
.75441 .927 m .75815 .93366 L .76424 .92994 L 0 1 .526 r
F
0 g
.75079 .93539 m
.75815 .93366 L
s
.75641 .93745 m
.75815 .93366 L
s
.45281 .49643 m .45803 .48788 L .46065 .48303 L 0 .896 .14 r
F
0 g
.45803 .48788 m
.46124 .48301 L
s
.5398 .43569 m .53604 .44687 L .53543 .44503 L 0 .011 .075 r
F
.5398 .43569 m .54168 .44155 L .53604 .44687 L F
.5398 .43569 m .54856 .43264 L .54168 .44155 L F
.36529 .68922 m .35761 .69623 L .36185 .6954 L 0 1 .429 r
F
0 g
.36185 .6954 m
.36523 .70035 L
s
.42484 .92637 m .41085 .93012 L .41332 .93097 L 0 1 .386 r
F
0 g
.40705 .93249 m
.41332 .93097 L
s
.80576 .68502 m .81691 .69641 L .81724 .68869 L 0 1 .509 r
F
0 g
.81691 .69641 m
.82009 .70331 L
s
.81324 .70092 m
.81691 .69641 L
s
.39117 .64926 m
.39353 .65399 L
s
.38949 .65989 m
.39353 .65399 L
s
.41399 1.03183 m .40776 1.03649 L .41561 1.03954 L 0 1 .498 r
F
.41399 1.03183 m .39963 1.03054 L .40776 1.03649 L F
.31279 .71841 m .30175 .71156 L .30225 .72021 L 0 1 .459 r
F
0 g
.30225 .72021 m
.30577 .72609 L
s
.31279 .71841 m .30456 .70465 L .30175 .71156 L 0 1 .459 r
F
.31279 .71841 m .30881 .70408 L .30456 .70465 L F
.31279 .71841 m .31233 .70998 L .30881 .70408 L F
0 g
.30998 .7253 m
.31279 .71841 L
s
.31279 .71841 m
.31628 .7241 L
s
.48102 .72182 m .47029 .73149 L .47397 .72786 L 0 0 0 r
F
0 g
.47141 .72999 m
.47397 .72786 L
s
.47821 .72399 m
.47974 .72281 L
s
.46974 .73145 m
.47141 .72999 L
s
.2856 .94635 m .26768 .9465 L .26976 .94811 L 0 1 .324 r
F
.2856 .94635 m .27155 .94555 L .26768 .9465 L F
.2856 .94635 m .27924 .94548 L .27155 .94555 L F
.29483 .94343 m .27924 .94548 L .2856 .94635 L 0 .987 .289 r
F
0 g
.2856 .94635 m
.28764 .94794 L
s
.2856 .94635 m
.29305 .94605 L
s
.5128 .71395 m
.5128 .71396 L
s
.43811 .75383 m .43159 .75769 L .43582 .75525 L 0 .799 .185 r
F
.43811 .75383 m .42741 .75974 L .43159 .75769 L F
0 g
.4297 .75923 m
.43159 .75769 L
s
.43582 .75525 m
.44011 .75299 L
s
.22421 .77767 m .21245 .76491 L .21083 .77131 L 0 1 .527 r
F
.22421 .77767 m .21695 .76443 L .21245 .76491 L F
.22421 .77767 m .22199 .76991 L .21695 .76443 L F
.23527 .77598 m .22199 .76991 L .22421 .77767 L F
0 g
.22258 .78403 m
.22421 .77767 L
s
.22421 .77767 m
.22916 .7829 L
s
.39136 .75517 m .38146 .75091 L .3793 .75484 L 0 1 .503 r
F
.39136 .75517 m .38579 .74963 L .38146 .75091 L F
.39136 .75517 m .39003 .75146 L .38579 .74963 L F
0 g
.3892 .75909 m
.39136 .75517 L
s
.40242 .75113 m .39004 .75146 L .39136 .75517 L 0 1 .498 r
F
0 g
.39136 .75517 m
.39564 .75668 L
s
.74457 .92395 m .73898 .92704 L .73763 .93044 L 0 1 .522 r
F
0 g
.72995 .93161 m
.73763 .93044 L
s
.3393 .78795 m .33381 .79122 L .33782 .79017 L 0 1 .459 r
F
.3393 .78795 m .32917 .79035 L .33381 .79122 L F
0 g
.333 .79361 m
.33381 .79122 L
s
.33782 .79017 m
.3429 .79078 L
s
.8087 .60508 m .81547 .60526 L .8201 .60769 L 0 0 0 r
F
.8087 .60508 m .81059 .60414 L .81547 .60526 L F
0 g
.8125 .60415 m
.81547 .60526 L
s
.36185 .96414 m .35993 .97043 L .36365 .96864 L 0 1 .537 r
F
.36185 .96414 m .35226 .96845 L .35993 .97043 L F
0 g
.35993 .97043 m
.36251 .97477 L
s
.47883 .69783 m .47071 .70297 L .47531 .70078 L 0 1 .419 r
F
.47883 .69783 m .46734 .70307 L .47071 .70297 L F
.47883 .69783 m .46747 .70099 L .46734 .70307 L F
.47883 .69783 m .47099 .69804 L .46747 .70099 L F
0 g
.47531 .70078 m
.4788 .70039 L
s
.47883 .69783 m .47557 .69619 L .47099 .69804 L 0 1 .419 r
F
.47883 .69783 m .47893 .6961 L .47557 .69619 L F
0 g
.47883 .69783 m
.47936 .69776 L
s
.47531 .70078 m
.47883 .69783 L
s
.47893 .6961 m
.47956 .6956 L
s
.52411 .42195 m .53112 .41628 L .53683 .41638 L 0 .174 .091 r
F
0 g
.53112 .41628 m
.53589 .40713 L
s
.3767 .67979 m
.38026 .67373 L
s
.53583 .69868 m .54371 .71121 L .53914 .70123 L 0 .398 .252 r
F
.53583 .69868 m .54733 .72773 L .54371 .71121 L F
.53583 .69868 m .54758 .73977 L .54733 .72773 L F
.53583 .69868 m .54424 .73718 L .54758 .73977 L F
.53583 .69868 m .53957 .72172 L .54424 .73718 L F
.53583 .69868 m .53597 .70524 L .53957 .72172 L F
.53512 .68274 m .53618 .67585 L .53939 .67603 L 0 .271 .162 r
F
.53512 .68274 m .53939 .67603 L .54263 .68317 L F
.53512 .68274 m .5394 .70848 L .53649 .6967 L F
.53512 .68274 m .54264 .70868 L .5394 .70848 L F
.53512 .68274 m .54403 .69715 L .54264 .70868 L F
.53512 .68274 m .54263 .68317 L .54403 .69715 L F
.53229 .69843 m .53345 .69242 L .53649 .6967 L 0 .305 .168 r
F
.53229 .69843 m .53582 .72835 L .5333 .7138 L F
.53611 .7147 m .5397 .73996 L .54442 .75965 L 0 .369 .25 r
F
.53611 .7147 m .53615 .72074 L .5397 .73996 L F
.53229 .69843 m .53888 .73272 L .53582 .72835 L 0 .305 .168 r
F
.53611 .7147 m .54424 .73718 L .53957 .72172 L 0 .369 .25 r
F
.53611 .7147 m .54782 .75651 L .54424 .73718 L F
.53611 .7147 m .54791 .76678 L .54782 .75651 L F
.53611 .7147 m .54442 .75965 L .54791 .76678 L F
.53229 .69843 m .54043 .72393 L .53888 .73272 L 0 .305 .168 r
F
.53229 .69843 m .5394 .70848 L .54043 .72393 L F
.53229 .69843 m .53649 .6967 L .5394 .70848 L F
.52923 .71171 m .53582 .72835 L .53633 .74073 L 0 .337 .169 r
F
.52923 .71171 m .53633 .74073 L .53619 .74086 L F
.52923 .71171 m .53636 .74156 L .53599 .74189 L F
.52448 .70425 m .53258 .72787 L .52798 .71338 L 0 .493 .267 r
F
.52448 .70425 m .53592 .74229 L .53258 .72787 L F
.52448 .70425 m .53576 .74697 L .53592 .74229 L F
.52448 .70425 m .53223 .73775 L .53576 .74697 L F
.52448 .70425 m .52771 .72084 L .53223 .73775 L F
.52423 .70975 m .53223 .73775 L .52771 .72084 L 0 .495 .267 r
F
.52423 .70975 m .53544 .75344 L .53223 .73775 L F
.52423 .70975 m .53518 .75738 L .53544 .75344 L F
.52423 .70975 m .53167 .74618 L .53518 .75738 L F
.52423 .70975 m .52728 .72738 L .53167 .74618 L F
.52387 .71471 m .53167 .74618 L .52728 .72738 L 0 .501 .269 r
F
.52387 .71471 m .53471 .76274 L .53167 .74618 L F
.52387 .71471 m .53436 .76595 L .53471 .76274 L F
.52387 .71471 m .53091 .75314 L .53436 .76595 L F
.52387 .71471 m .5267 .73297 L .53091 .75314 L F
.52339 .7191 m .53091 .75314 L .5267 .73297 L 0 .511 .27 r
F
.52339 .7191 m .53375 .77022 L .53091 .75314 L F
.52339 .7191 m .5333 .77272 L .53375 .77022 L F
.52339 .7191 m .52995 .7587 L .5333 .77272 L F
.52923 .71171 m .53194 .74299 L .52985 .72722 L 0 .337 .169 r
F
.52923 .71171 m .53377 .74316 L .53194 .74299 L F
.52279 .72287 m .53255 .77598 L .52995 .7587 L 0 .522 .272 r
F
.52279 .72287 m .53201 .77782 L .53255 .77598 L F
.52279 .72287 m .52881 .76293 L .53201 .77782 L F
.52209 .72602 m .53114 .78014 L .52881 .76293 L 0 .534 .275 r
F
.52209 .72602 m .53052 .78138 L .53114 .78014 L F
.52953 .78285 m .52884 .78356 L .53062 .80043 L 0 .401 .271 r
F
.53114 .78014 m .53052 .78138 L .53263 .79952 L 0 .39 .267 r
F
.52951 .81751 m .53382 .7449 L .53196 .74947 L 0 .661 .255 r
F
.5286 .7459 m .53006 .7458 L .52863 .74615 L 0 .35 .167 r
F
.52597 .72247 m .52991 .74496 L .5286 .7459 L F
.52991 .74496 m .53006 .7458 L .5286 .7459 L F
.52448 .70425 m .52439 .70651 L .52771 .72084 L 0 .493 .267 r
F
.52423 .70975 m .5241 .7118 L .52728 .72738 L 0 .495 .267 r
F
.52387 .71471 m .52369 .71654 L .5267 .73297 L 0 .501 .269 r
F
.52339 .7191 m .52597 .73761 L .52995 .7587 L 0 .511 .27 r
F
.52339 .7191 m .52316 .72068 L .52597 .73761 L F
.52279 .72287 m .52995 .7587 L .52597 .73761 L 0 .522 .272 r
F
.52279 .72287 m .52509 .74133 L .52881 .76293 L F
.52279 .72287 m .52252 .72421 L .52509 .74133 L F
.52209 .72602 m .52881 .76293 L .52509 .74133 L 0 .534 .275 r
F
.52209 .72602 m .52749 .76592 L .53052 .78138 L F
.52209 .72602 m .52409 .74416 L .52749 .76592 L F
.52129 .72854 m .52749 .76592 L .52409 .74416 L 0 .546 .277 r
F
.52129 .72854 m .52953 .78285 L .52749 .76592 L F
.52129 .72854 m .52884 .78356 L .52953 .78285 L F
.52129 .72854 m .52602 .76779 L .52884 .78356 L F
.52381 .6906 m .52675 .70867 L .52471 .69964 L 0 .224 .135 r
F
.52381 .6906 m .52923 .71171 L .52675 .70867 L F
.52164 .69768 m .52597 .72247 L .52377 .71771 L 0 .237 .137 r
F
.52164 .69768 m .5273 .71847 L .52597 .72247 L F
.52164 .69768 m .52675 .70867 L .5273 .71847 L F
.52164 .69768 m .52471 .69964 L .52675 .70867 L F
.52597 .72247 m .5273 .71847 L .52985 .72722 L 0 .35 .167 r
F
.52597 .72247 m .52748 .74734 L .5262 .73728 L F
.52748 .74734 m .52747 .74736 L .5262 .73728 L F
.52041 .73043 m .52774 .78427 L .52602 .76779 L 0 .556 .28 r
F
.5275 .74758 m .52727 .7477 L .52724 .74839 L 0 .685 .257 r
F
.52745 .74842 m .52724 .74839 L .52627 .7704 L F
.5275 .74758 m .52724 .74839 L .52745 .74842 L F
.52041 .73043 m .52698 .78451 L .52774 .78427 L 0 .556 .28 r
F
.52041 .73043 m .5244 .76865 L .52698 .78451 L F
.52614 .80092 m .52749 .74786 L .52627 .7704 L 0 .685 .257 r
F
.52749 .74786 m .5275 .74758 L .52748 .74786 L F
.52749 .74786 m .52748 .74786 L .52627 .7704 L F
.52501 .7481 m .52531 .74864 L .5251 .74873 L 0 .347 .162 r
F
.52209 .72602 m .52178 .7271 L .52409 .74416 L 0 .534 .275 r
F
.52256 .73083 m .52655 .7477 L .52501 .7481 L 0 .347 .162 r
F
.52655 .7477 m .52661 .74794 L .52596 .748 L F
.52655 .7477 m .52596 .748 L .52501 .7481 L F
.52256 .73083 m .52501 .7481 L .52401 .74796 L F
.52129 .72854 m .52297 .74615 L .52602 .76779 L 0 .546 .277 r
F
.52129 .72854 m .52095 .72937 L .52297 .74615 L F
.51841 .73244 m .52267 .7686 L .52042 .74785 L 0 .572 .285 r
F
.51841 .73244 m .52371 .78381 L .52267 .7686 L F
.52041 .73043 m .52602 .76779 L .52297 .74615 L 0 .556 .28 r
F
.52041 .73043 m .52174 .74736 L .5244 .76865 L F
.52041 .73043 m .52003 .73102 L .52174 .74736 L F
.51944 .73173 m .5244 .76865 L .52174 .74736 L 0 .565 .282 r
F
.51944 .73173 m .5258 .78455 L .5244 .76865 L F
.51944 .73173 m .52498 .78436 L .5258 .78455 L F
.51944 .73173 m .52267 .7686 L .52498 .78436 L F
.51944 .73173 m .52042 .74785 L .52267 .7686 L F
.52164 .69768 m .52377 .71771 L .52218 .70741 L 0 .237 .137 r
F
.51938 .70387 m .52256 .73083 L .52067 .72485 L 0 .241 .136 r
F
.51938 .70387 m .52394 .72777 L .52256 .73083 L F
.51938 .70387 m .52377 .71771 L .52394 .72777 L F
.51938 .70387 m .52218 .70741 L .52377 .71771 L F
.52256 .73083 m .52394 .72777 L .5262 .73728 L 0 .347 .162 r
F
.51732 .7326 m .52083 .76773 L .51901 .74766 L 0 .578 .287 r
F
.51732 .7326 m .52152 .78218 L .52083 .76773 L F
.51732 .7326 m .52061 .78131 L .52152 .78218 L F
.51732 .7326 m .51891 .76614 L .52061 .78131 L F
.51841 .73244 m .52285 .78326 L .52371 .78381 L 0 .572 .285 r
F
.51841 .73244 m .52083 .76773 L .52285 .78326 L F
.51841 .73244 m .51901 .74766 L .52083 .76773 L F
.51907 .7812 m .52241 .76128 L .52276 .75073 L 0 .718 .263 r
F
.52272 .75073 m .52276 .75073 L .52277 .75027 L F
.51907 .7812 m .52276 .75073 L .52272 .75073 L F
.51907 .7812 m .52277 .75027 L .52273 .75027 L F
.51618 .73224 m .51923 .77977 L .51891 .76614 L 0 .583 .289 r
F
.51618 .73224 m .5183 .77861 L .51923 .77977 L F
.51907 .7812 m .52274 .75015 L .52166 .75048 L 0 .718 .263 r
F
.52274 .75015 m .52279 .7498 L .52203 .75025 L F
.52274 .75015 m .52203 .75025 L .52166 .75048 L F
.52265 .78902 m .52659 .74839 L .52504 .74959 L 0 .703 .26 r
F
.52659 .74839 m .52661 .74815 L .52627 .74846 L F
.52659 .74839 m .52627 .74846 L .52504 .74959 L F
.52501 .7481 m .5251 .74873 L .52401 .74796 L 0 .347 .162 r
F
.52504 .74959 m .52523 .74867 L .5251 .74873 L 0 .703 .26 r
F
.52661 .74815 m .52663 .74802 L .52504 .74959 L F
.52661 .74794 m .52663 .74802 L .52501 .7481 L 0 .347 .162 r
F
.52663 .74802 m .52531 .74864 L .52501 .7481 L F
.52749 .74756 m .52727 .7477 L .5262 .73728 L 0 .35 .167 r
F
.5275 .74758 m .52727 .7477 L .52749 .74756 L F
.52265 .78902 m .52627 .7704 L .52726 .74794 L 0 .703 .26 r
F
.52265 .78902 m .52726 .74794 L .52725 .74794 L F
.52265 .78902 m .52727 .7477 L .52661 .74815 L F
.52319 .75013 m .52371 .74936 L .5232 .74959 L F
.52318 .75082 m .52409 .74974 L .52319 .75013 L F
.52265 .78902 m .52405 .75068 L .52318 .75082 L F
.52405 .75068 m .52409 .74974 L .52318 .75082 L F
.52054 .75046 m .52057 .75075 L .51977 .75037 L 0 .333 .155 r
F
.51907 .7812 m .52164 .7506 L .52057 .75081 L 0 .718 .263 r
F
.52054 .75046 m .52062 .75072 L .52057 .75075 L 0 .333 .155 r
F
.52062 .75072 m .52062 .75073 L .52057 .75075 L F
.52057 .75075 m .51984 .75085 L .51977 .75037 L F
.51944 .73173 m .51904 .73208 L .52042 .74785 L 0 .565 .282 r
F
.51903 .73706 m .52167 .7503 L .52054 .75046 L 0 .333 .155 r
F
.51903 .73706 m .52054 .75046 L .51977 .75037 L F
.51977 .75037 m .51981 .75102 L .51907 .75039 L F
.5198 .75123 m .51982 .75102 L .51981 .75102 L 0 .718 .263 r
F
.51907 .7812 m .52057 .75075 L .5198 .75123 L F
.52167 .7503 m .52062 .75073 L .52054 .75046 L 0 .333 .155 r
F
.52256 .73083 m .52404 .74837 L .52316 .74848 L 0 .347 .162 r
F
.52256 .73083 m .52319 .74955 L .52238 .74446 L F
.52725 .74794 m .52726 .74794 L .52727 .7477 L 0 .703 .26 r
F
.52256 .73083 m .5262 .73728 L .52727 .7477 L 0 .347 .162 r
F
.52661 .74815 m .52727 .7477 L .52663 .74802 L 0 .703 .26 r
F
.52614 .80092 m .52864 .74841 L .52745 .74947 L 0 .685 .257 r
F
.52663 .74802 m .52727 .7477 L .52783 .75312 L 0 .347 .162 r
F
.52256 .73083 m .52727 .7477 L .52663 .74802 L F
.52774 .78427 m .52698 .78451 L .52843 .8001 L 0 .411 .275 r
F
.52614 .80092 m .53006 .747 L .52864 .74841 L 0 .685 .257 r
F
.52864 .74841 m .52871 .74692 L .52745 .74947 L F
.52748 .74734 m .52874 .74714 L .5275 .74755 L 0 .35 .167 r
F
.52597 .72247 m .52868 .74664 L .52748 .74734 L F
.52868 .74664 m .52874 .74714 L .52748 .74734 L F
.52525 .74866 m .52779 .736 L .52523 .74867 L 0 .703 .26 r
F
.52663 .74802 m .52664 .74784 L .52525 .74866 L F
.52664 .74784 m .52779 .736 L .52525 .74866 L F
.52863 .74615 m .52884 .74685 L .52871 .74692 L 0 .35 .167 r
F
.52867 .74814 m .52883 .74685 L .52865 .74816 L 0 .685 .257 r
F
.53006 .7458 m .53012 .74614 L .52863 .74615 L 0 .35 .167 r
F
.53012 .74614 m .52991 .74626 L .52863 .74615 L F
.53012 .74614 m .52883 .74685 L .52864 .74841 L 0 .685 .257 r
F
.53377 .74316 m .5325 .7444 L .53194 .74299 L 0 .337 .169 r
F
.52614 .80092 m .53196 .74947 L .53198 .74518 L 0 .685 .257 r
F
.52923 .71171 m .53604 .74209 L .53385 .74375 L 0 .337 .169 r
F
.52597 .72247 m .53194 .74299 L .53198 .74513 L 0 .35 .167 r
F
.53009 .74662 m .53198 .74518 L .53198 .74513 L 0 .685 .257 r
F
.53009 .74662 m .53198 .74513 L .53012 .74614 L F
.52614 .80092 m .53198 .74518 L .53009 .74662 L F
.53382 .7449 m .53351 .74497 L .53196 .74947 L 0 .661 .255 r
F
.53388 .7439 m .53263 .74472 L .53196 .74947 L F
.52951 .81751 m .53196 .74947 L .53001 .78478 L F
.52614 .80092 m .53001 .78478 L .53196 .74947 L 0 .685 .257 r
F
.53012 .74614 m .53198 .74513 L .53219 .75794 L 0 .35 .167 r
F
.52597 .72247 m .53198 .74513 L .53012 .74614 L F
.52597 .72247 m .52985 .72722 L .53194 .74299 L F
.53012 .74614 m .53198 .74513 L .53207 .71935 L 0 .685 .257 r
F
.53604 .74209 m .53611 .74239 L .53385 .74375 L 0 .337 .169 r
F
.52951 .81751 m .53611 .74239 L .53388 .7439 L 0 .661 .255 r
F
.53619 .74086 m .53633 .74073 L .53636 .74156 L 0 .337 .169 r
F
.52951 .81751 m .53597 .77091 L .53639 .74221 L 0 .661 .255 r
F
.53599 .74189 m .53636 .74156 L .53639 .74221 L 0 .337 .169 r
F
.53599 .74189 m .53639 .74221 L .53611 .74239 L F
.53611 .74239 m .53639 .74221 L .53644 .73856 L 0 .661 .255 r
F
.52951 .81751 m .53639 .74221 L .53611 .74239 L F
.53611 .74239 m .53639 .74221 L .53646 .74398 L 0 .337 .169 r
F
.53611 .74239 m .53646 .74398 L .53407 .74377 L F
.53611 .74239 m .53407 .74377 L .53385 .74375 L F
.53388 .7439 m .53644 .73856 L .53471 .72977 L 0 .661 .255 r
F
.53385 .74375 m .53409 .74377 L .53388 .7439 L 0 .337 .169 r
F
.53611 .74239 m .53644 .73856 L .53388 .7439 L 0 .661 .255 r
F
.53377 .74316 m .53388 .7439 L .5325 .7444 L 0 .337 .169 r
F
.53388 .7439 m .53263 .74472 L .5325 .7444 L F
.53388 .7439 m .53471 .72977 L .53263 .74467 L 0 .661 .255 r
F
.53388 .7439 m .53263 .74467 L .53263 .74472 L F
.53388 .7439 m .53646 .74398 L .53479 .75021 L 0 .337 .169 r
F
.53409 .74377 m .53646 .74398 L .53388 .7439 L F
.53015 .74628 m .52884 .74686 L .52884 .74685 L 0 .35 .167 r
F
.52991 .74626 m .52884 .74685 L .52863 .74615 L F
.53015 .74628 m .52884 .74685 L .52991 .74626 L F
.53006 .747 m .53012 .74614 L .52864 .74841 L 0 .685 .257 r
F
.53012 .74614 m .53207 .71935 L .52883 .74685 L F
.52883 .74685 m .53207 .71935 L .52881 .74686 L F
.52883 .74685 m .52881 .74686 L .52865 .74816 L F
.53012 .74614 m .53015 .74628 L .52991 .74626 L 0 .35 .167 r
F
.53015 .74628 m .53219 .75794 L .52884 .74686 L F
.52871 .74692 m .53027 .71423 L .52761 .74741 L 0 .685 .257 r
F
.52871 .74692 m .52761 .74741 L .5276 .74752 L F
.52871 .74692 m .5276 .74752 L .52745 .74947 L F
.5275 .74758 m .53041 .76202 L .52783 .75312 L 0 .35 .167 r
F
.5275 .74755 m .5275 .74758 L .5275 .74758 L F
.5275 .74758 m .53041 .76202 L .5275 .74758 L F
.52865 .74816 m .52881 .74686 L .52871 .74692 L 0 .685 .257 r
F
.52864 .74841 m .52867 .74814 L .52865 .74816 L F
.52874 .74714 m .53041 .76202 L .5275 .74755 L 0 .35 .167 r
F
.52663 .74802 m .52727 .7477 L .52728 .74763 L 0 .703 .26 r
F
.52664 .74784 m .52728 .74763 L .52779 .736 L F
.52663 .74802 m .52728 .74763 L .52664 .74784 L F
.51903 .73706 m .52045 .73482 L .52238 .74446 L 0 .333 .155 r
F
.52273 .75027 m .52277 .75027 L .52279 .7498 L 0 .718 .263 r
F
.51903 .73706 m .52238 .74446 L .52276 .74941 L 0 .333 .155 r
F
.51903 .73706 m .52276 .74941 L .52269 .74947 L F
.51903 .73706 m .52279 .7498 L .52167 .7503 L F
.51981 .75102 m .51915 .75128 L .51907 .75039 L F
.51979 .75185 m .51981 .75102 L .51907 .75243 L 0 .718 .263 r
F
.51903 .73706 m .51977 .75037 L .51907 .75039 L 0 .333 .155 r
F
.51938 .70387 m .5203 .7015 L .52218 .70741 L 0 .241 .136 r
F
.51938 .70387 m .52067 .72485 L .51954 .71385 L F
.51704 .70916 m .52045 .73482 L .51903 .73706 L 0 .238 .133 r
F
.51704 .70916 m .52067 .72485 L .52045 .73482 L F
.51704 .70916 m .51954 .71385 L .52067 .72485 L F
.51981 .75102 m .52096 .70391 L .51912 .75129 L 0 .718 .263 r
F
.51981 .75102 m .51912 .75129 L .51907 .75243 L F
.51907 .75243 m .51912 .75129 L .51907 .75131 L F
.51907 .7812 m .51979 .75185 L .51907 .75243 L F
.52152 .78218 m .52061 .78131 L .52096 .79334 L 0 .448 .286 r
F
.51907 .7812 m .52051 .78386 L .52241 .76128 L 0 .718 .263 r
F
.51907 .75131 m .52105 .77322 L .51911 .76344 L 0 .333 .155 r
F
.51907 .75039 m .51915 .75128 L .51907 .75131 L F
.51915 .75128 m .52105 .77322 L .51907 .75131 L F
.51981 .75102 m .51915 .75136 L .51915 .75128 L F
.51907 .75131 m .52096 .70391 L .51908 .72617 L 0 .718 .263 r
F
.51912 .75129 m .52096 .70391 L .51907 .75131 L F
.52269 .74947 m .52276 .74941 L .52279 .7498 L 0 .333 .155 r
F
.52166 .75048 m .52279 .7498 L .52167 .7503 L 0 .718 .263 r
F
.52265 .78902 m .5251 .74873 L .52411 .74917 L 0 .703 .26 r
F
.52663 .74802 m .52523 .74867 L .52504 .74959 L F
.5251 .74873 m .52767 .7669 L .52423 .74912 L 0 .347 .162 r
F
.5251 .74873 m .52423 .74912 L .52419 .74894 L F
.5251 .74873 m .52511 .74859 L .52411 .74917 L 0 .703 .26 r
F
.52411 .74917 m .52512 .74838 L .52411 .7491 L F
.5251 .74873 m .52419 .74894 L .52401 .74796 L 0 .347 .162 r
F
.52511 .74859 m .52512 .74838 L .52411 .74917 L 0 .703 .26 r
F
.52404 .74837 m .52411 .74917 L .52316 .74848 L 0 .347 .162 r
F
.52409 .74974 m .52411 .74917 L .52319 .75013 L 0 .703 .26 r
F
.52411 .74917 m .52391 .74929 L .52316 .74848 L 0 .347 .162 r
F
.52411 .74917 m .52412 .74875 L .52371 .74936 L 0 .703 .26 r
F
.52411 .74917 m .52371 .74936 L .52319 .75013 L F
.52414 .74954 m .5233 .74959 L .52329 .74955 L 0 .347 .162 r
F
.52389 .74927 m .52329 .74955 L .52316 .74848 L F
.52414 .74954 m .52329 .74955 L .52389 .74927 L F
.52411 .74917 m .52414 .74954 L .52391 .74929 L F
.52414 .74954 m .52581 .76932 L .5233 .74959 L F
.52265 .78902 m .5232 .74959 L .52241 .76128 L 0 .703 .26 r
F
.52319 .74955 m .5232 .74959 L .52319 .74955 L 0 .347 .162 r
F
.52319 .74955 m .52319 .74955 L .52238 .74446 L F
.5232 .74959 m .5228 .74995 L .52238 .74446 L F
.5232 .74959 m .52348 .72874 L .52279 .74961 L 0 .703 .26 r
F
.5232 .74959 m .52279 .74961 L .52241 .76128 L F
.52167 .7503 m .52279 .7498 L .52354 .75966 L 0 .333 .155 r
F
.52167 .7503 m .52279 .7498 L .52348 .72874 L 0 .718 .263 r
F
.52057 .75075 m .52348 .72874 L .52286 .70425 L F
.52057 .75081 m .52058 .75074 L .52057 .75075 L F
.52058 .75074 m .52348 .72874 L .52057 .75075 L F
.52164 .7506 m .52167 .7503 L .52077 .75072 L F
.52164 .7506 m .52077 .75072 L .52057 .75081 L F
.52167 .7503 m .52111 .75053 L .52057 .75081 L F
.52167 .7503 m .52354 .75966 L .52062 .75073 L 0 .333 .155 r
F
.52057 .75075 m .52286 .70425 L .51982 .75102 L 0 .718 .263 r
F
.52057 .75075 m .51982 .75102 L .5198 .75123 L F
.51981 .75102 m .51992 .75135 L .51983 .75136 L 0 .333 .155 r
F
.51977 .75037 m .51987 .751 L .51981 .75102 L F
.51987 .751 m .51992 .75135 L .51981 .75102 L F
.51981 .75102 m .52105 .77322 L .51915 .75136 L F
.51981 .75102 m .52286 .70425 L .52096 .70391 L 0 .718 .263 r
F
.51982 .75102 m .52286 .70425 L .51981 .75102 L F
.52168 .75023 m .52348 .72874 L .52057 .75081 L F
.52057 .75075 m .52297 .77203 L .51984 .75085 L 0 .333 .155 r
F
.52167 .7503 m .52168 .75023 L .52111 .75053 L 0 .718 .263 r
F
.52057 .75075 m .52077 .75117 L .52063 .75123 L 0 .333 .155 r
F
.52062 .75073 m .52077 .75117 L .52057 .75075 L F
.51983 .75136 m .52297 .77203 L .52105 .77322 L F
.51992 .75135 m .52297 .77203 L .51983 .75136 L F
.52371 .74936 m .52376 .74928 L .5232 .74959 L 0 .703 .26 r
F
.5232 .74959 m .52581 .76932 L .52354 .75966 L 0 .347 .162 r
F
.52316 .74848 m .52329 .74955 L .5232 .74959 L F
.52329 .74955 m .52581 .76932 L .5232 .74959 L F
.52663 .74802 m .52783 .75312 L .52531 .74864 L F
.52411 .74917 m .52767 .7669 L .52581 .76932 L F
.52401 .74796 m .52423 .74913 L .52411 .74917 L F
.52423 .74913 m .52767 .7669 L .52411 .74917 L F
.52376 .74928 m .52412 .74875 L .52341 .7494 L 0 .703 .26 r
F
.52376 .74928 m .52341 .7494 L .5232 .74959 L F
.52063 .75123 m .52354 .75966 L .52297 .77203 L 0 .333 .155 r
F
.52077 .75117 m .52354 .75966 L .52063 .75123 L F
.5232 .74959 m .52354 .75966 L .5228 .74995 L 0 .347 .162 r
F
.5232 .74959 m .52568 .70627 L .52348 .72874 L 0 .703 .26 r
F
.52412 .74875 m .52568 .70627 L .5232 .74959 L F
.5251 .74873 m .52779 .736 L .52753 .70862 L F
.52523 .74867 m .52779 .736 L .5251 .74873 L F
.5251 .74873 m .52783 .75312 L .52767 .7669 L 0 .347 .162 r
F
.52531 .74864 m .52783 .75312 L .5251 .74873 L F
.5275 .74758 m .52728 .74777 L .52727 .7477 L 0 .35 .167 r
F
.52748 .74734 m .5275 .74758 L .52747 .74736 L F
.5275 .74758 m .52779 .736 L .52727 .7477 L 0 .685 .257 r
F
.52745 .74947 m .52761 .74748 L .5275 .74758 L F
.5275 .74758 m .52783 .75312 L .52728 .74777 L 0 .35 .167 r
F
.5275 .74758 m .53027 .71423 L .52779 .736 L 0 .685 .257 r
F
.52761 .74748 m .53027 .71423 L .5275 .74758 L F
.52411 .7491 m .52753 .70862 L .52568 .70627 L 0 .703 .26 r
F
.52512 .74838 m .52753 .70862 L .52411 .7491 L F
.52871 .74692 m .53207 .71935 L .53027 .71423 L 0 .685 .257 r
F
.52881 .74686 m .53207 .71935 L .52871 .74692 L F
.52871 .74692 m .53219 .75794 L .53041 .76202 L 0 .35 .167 r
F
.52884 .74685 m .53219 .75794 L .52871 .74692 L F
.53382 .7449 m .53388 .7439 L .53351 .74497 L 0 .661 .255 r
F
.53388 .7439 m .53479 .75021 L .53263 .74472 L 0 .337 .169 r
F
.53471 .72977 m .53967 .61485 L .53671 .64461 L 0 .78 .249 r
F
.53768 .66506 m .54263 .68317 L .53939 .67603 L 0 .213 .148 r
F
.53768 .66506 m .546 .67804 L .54263 .68317 L F
.53768 .66506 m .54722 .6641 L .546 .67804 L F
.53471 .72977 m .54178 .61937 L .53967 .61485 L 0 .78 .249 r
F
0 g
.53945 .5741 m
.53967 .61485 L
s
.44578 .9825 m .43894 .98059 L .43245 .98042 L 0 1 .54 r
F
.44961 .9783 m .44578 .9825 L .45196 .98265 L 0 1 .539 r
F
.44961 .9783 m .43894 .98059 L .44578 .9825 L F
0 g
.44578 .9825 m
.44984 .98527 L
s
.50069 .70258 m
.501 .70211 L
s
.501 .70211 m
.50138 .70156 L
s
.50138 .70156 m
.5017 .70108 L
s
.50193 .628 m .50379 .62498 L .50459 .62111 L 0 1 .295 r
F
0 g
.50379 .62498 m
.50579 .6255 L
s
.49491 .65257 m .49614 .6504 L .49544 .64747 L 0 1 .372 r
F
0 g
.49614 .6504 m
.4986 .65094 L
s
.46789 .7131 m .46019 .71908 L .4647 .7165 L 0 1 .437 r
F
0 g
.4647 .7165 m
.46843 .71599 L
s
.50556 .69658 m
.50556 .69658 L
s
.50556 .69658 m
.50556 .69658 L
s
.49262 .66081 m
.49333 .66073 L
s
.46789 .7131 m .45654 .71933 L .46019 .71908 L 0 1 .437 r
F
.46789 .7131 m .45621 .71707 L .45654 .71933 L F
.46789 .7131 m .4594 .71367 L .45621 .71707 L F
.46789 .7131 m .46399 .71138 L .4594 .71367 L F
.46789 .7131 m .46763 .71114 L .46399 .71138 L F
0 g
.46789 .7131 m
.46918 .71285 L
s
.4647 .7165 m
.46789 .7131 L
s
.30224 .72021 m .28785 .71352 L .28841 .72245 L 0 1 .463 r
F
0 g
.28841 .72245 m
.29296 .7284 L
s
.30224 .72021 m .29162 .70629 L .28785 .71352 L 0 1 .463 r
F
.30224 .72021 m .29719 .70559 L .29162 .70629 L F
.30224 .72021 m .30175 .71156 L .29719 .70559 L F
0 g
.29848 .72742 m
.30224 .72021 L
s
.47554 .83 m .46692 .83491 L .47021 .84049 L 0 .687 .364 r
F
.47554 .83 m .46628 .82772 L .46692 .83491 L F
0 g
.46266 .83344 m
.46692 .83491 L
s
.30426 .76465 m .29589 .7708 L .30131 .76974 L 0 1 .524 r
F
.30426 .76465 m .29063 .76704 L .29589 .7708 L F
0 g
.29373 .77608 m
.29589 .7708 L
s
.30131 .76974 m
.30713 .77319 L
s
.4722 .76962 m .46786 .78081 L .47103 .77646 L 0 .784 .345 r
F
.47651 .7814 m .46786 .78081 L .46707 .78789 L 0 .739 .343 r
F
.47651 .7814 m .47103 .77646 L .46786 .78081 L F
0 g
.46404 .7802 m
.46786 .78081 L
s
.36529 .68922 m .3547 .69115 L .35761 .69623 L 0 1 .429 r
F
0 g
.35465 .70255 m
.35761 .69623 L
s
.51692 .9504 m .51111 .95148 L .51721 .95791 L 0 .374 .367 r
F
0 g
.50668 .9445 m
.51111 .95148 L
s
.46849 .81668 m .46628 .82772 L .46869 .82371 L 0 .744 .366 r
F
.47554 .83 m .46869 .82371 L .46628 .82772 L 0 .687 .364 r
F
0 g
.46628 .82772 m
.46692 .83491 L
s
.46216 .82651 m
.46628 .82772 L
s
.42891 .97733 m .41368 .9758 L .41724 .97889 L 0 1 .539 r
F
0 g
.41043 .97818 m
.41724 .97889 L
s
.52757 .71232 m
.52798 .71338 L
s
.52756 .71186 m
.52798 .71338 L
s
.52697 .70292 m
.52808 .70508 L
s
.52555 .69738 m
.52595 .6986 L
s
.52595 .6986 m
.52808 .70508 L
s
.52097 .69983 m
.52186 .70156 L
s
.48102 .72182 m .46963 .73245 L .47029 .73149 L 0 0 0 r
F
.48102 .72182 m .47244 .73028 L .46963 .73245 L F
0 g
.46765 .73326 m
.46974 .73145 L
s
.48102 .72182 m .47685 .72641 L .47244 .73028 L 0 0 0 r
F
0 g
.47077 .73102 m
.47397 .72786 L
s
.48102 .72182 m .48053 .72279 L .47685 .72641 L 0 0 0 r
F
0 g
.48102 .72182 m
.48128 .72152 L
s
.47974 .72281 m
.48102 .72182 L
s
.51761 .58931 m .52307 .58009 L .52372 .5802 L 0 0 0 r
F
0 g
.52307 .58009 m
.52469 .57536 L
s
.52046 .58399 m
.52307 .58009 L
s
.51738 .68475 m .51782 .6835 L .51966 .68565 L 0 .112 .104 r
F
0 g
.51665 .6819 m
.51782 .6835 L
s
.46832 .90674 m
.47318 .90367 L
s
.44672 .73114 m .43482 .7341 L .43563 .73683 L 0 1 .464 r
F
.44672 .73114 m .43759 .73049 L .43482 .7341 L F
.44672 .73114 m .44211 .72839 L .43759 .73049 L F
.44672 .73114 m .44602 .72867 L .44211 .72839 L F
0 g
.44394 .73475 m
.44672 .73114 L
s
.44672 .73114 m
.45054 .73104 L
s
.40603 .77005 m .39534 .77257 L .39347 .77414 L 0 1 .267 r
F
.40603 .77005 m .39973 .77093 L .39534 .77257 L F
.40603 .77005 m .40431 .76985 L .39973 .77093 L F
.41671 .76512 m .40431 .76985 L .40603 .77005 L 0 .899 .238 r
F
0 g
.40415 .77162 m
.40603 .77005 L
s
.40603 .77005 m
.41047 .76866 L
s
.50166 .58613 m .505 .57588 L .50726 .56 L 0 1 .264 r
F
0 g
.50726 .56 m
.51001 .55967 L
s
.47029 .73149 m .46336 .73669 L .4676 .7333 L 0 0 0 r
F
0 g
.4676 .7333 m
.4677 .73324 L
s
.4676 .7333 m
.46765 .73326 L
s
.50886 .72019 m .50843 .71897 L .50658 .72698 L 0 .623 .295 r
F
0 g
.50828 .71963 m
.50843 .71897 L
s
.50525 .72283 m
.50682 .71759 L
s
.50525 .72283 m
.50659 .71483 L
s
.50843 .71897 m
.50962 .70673 L
s
.49838 .54309 m .50531 .51359 L .5015 .51886 L 0 1 .212 r
F
0 g
.50342 .52792 m
.50564 .51847 L
s
.50397 .54878 m
.50645 .53525 L
s
.5049 .52895 m
.50613 .52776 L
s
.50531 .51359 m
.50866 .49981 L
s
.40242 .75113 m .39243 .74759 L .39004 .75146 L 0 1 .498 r
F
.40242 .75113 m .39694 .74614 L .39243 .74759 L F
.40242 .75113 m .40122 .74766 L .39694 .74614 L F
.41348 .74676 m .40122 .74766 L .40242 .75113 L 0 1 .492 r
F
0 g
.40002 .75499 m
.40242 .75113 L
s
.40242 .75113 m
.4066 .75236 L
s
.4948 .88757 m .49678 .88754 L .49744 .88636 L 0 .928 .204 r
F
0 g
.49281 .89057 m
.49678 .88754 L
s
.49678 .88754 m
.49982 .88592 L
s
.48858 .74345 m .4791 .75327 L .48039 .75753 L 0 .726 .32 r
F
0 g
.47552 .75344 m
.4791 .75327 L
s
.4791 .75327 m
.48077 .7462 L
s
.39834 .93512 m .38613 .93577 L .38328 .93721 L 0 1 .441 r
F
.39834 .93512 m .39259 .93487 L .38613 .93577 L F
.4049 .93125 m .39259 .93487 L .39834 .93512 L 0 1 .41 r
F
0 g
.39834 .93512 m
.40453 .9341 L
s
.39834 .93512 m
.40075 .93655 L
s
.40718 .9747 m .39138 .97194 L .39464 .97542 L 0 1 .539 r
F
0 g
.38761 .97415 m
.39464 .97542 L
s
.48385 .89504 m
.48527 .89566 L
s
.70244 .9261 m .69693 .93137 L .69539 .93509 L 0 1 .473 r
F
0 g
.68811 .93862 m
.69539 .93509 L
s
.48127 .89741 m .4706 .90433 L .47318 .90367 L 0 1 .227 r
F
.51091 .60462 m .50854 .60581 L .50887 .60693 L 0 .995 .152 r
F
.51047 .60162 m .51332 .59051 L .51045 .59923 L 0 1 .27 r
F
.51091 .60462 m .51047 .60162 L .50854 .60581 L 0 .995 .152 r
F
.51303 .59766 m .51332 .59051 L .51047 .60162 L 0 1 .27 r
F
.51091 .60462 m .51535 .59451 L .51433 .59566 L 0 .995 .152 r
F
.51089 .65006 m .51536 .60089 L .51433 .59566 L 0 1 .27 r
F
.51302 .59776 m .51433 .59566 L .51332 .59051 L F
.51091 .60462 m .51429 .59576 L .51302 .59776 L 0 .995 .152 r
F
.51429 .59576 m .51433 .59566 L .51302 .59776 L F
.51091 .60462 m .51302 .59776 L .51047 .60162 L F
.51047 .60179 m .51302 .59776 L .51047 .60162 L 0 1 .27 r
F
.51089 .65006 m .51302 .59776 L .51047 .60179 L F
.51089 .65006 m .51433 .59566 L .51302 .59776 L F
.51302 .59776 m .51433 .59566 L .51332 .5968 L 0 .995 .152 r
F
.51089 .65006 m .51047 .60162 L .50853 .62025 L 0 1 .27 r
F
.51047 .60162 m .51045 .59923 L .51019 .60205 L F
.51047 .60162 m .51019 .60205 L .50854 .60581 L 0 .995 .152 r
F
.51047 .60162 m .51019 .60205 L .50853 .62025 L 0 1 .27 r
F
.51047 .60162 m .5102 .60204 L .51019 .60205 L 0 .995 .152 r
F
.51047 .60162 m .51332 .5968 L .51045 .60147 L F
.51302 .59776 m .51303 .59766 L .51047 .60162 L 0 1 .27 r
F
.51302 .59776 m .51332 .5968 L .51047 .60162 L 0 .995 .152 r
F
.51047 .60162 m .51045 .60147 L .5102 .60204 L F
0 g
.50936 .60988 m
.50953 .6093 L
s
.48311 .9838 m .47627 .98322 L .47038 .98411 L 0 1 .536 r
F
.58604 .55189 m .58885 .58629 L .58571 .56689 L 0 .849 .145 r
F
0 g
.58591 .55753 m
.58604 .55189 L
s
.58279 .54105 m
.58604 .55189 L
s
.58511 .58927 m
.58612 .5694 L
s
.52381 .6906 m .53048 .7067 L .52923 .71171 L 0 .224 .135 r
F
.52381 .6906 m .52957 .69762 L .53048 .7067 L F
.53027 .71423 m .53425 .61138 L .53151 .64078 L 0 .807 .252 r
F
0 g
.5335 .61951 m
.53425 .61138 L
s
.53369 .58124 m
.53425 .61138 L
s
.51426 .68804 m
.51426 .68804 L
s
.36529 .68922 m .35507 .68355 L .3547 .69115 L 0 1 .429 r
F
.36529 .68922 m .35852 .67736 L .35507 .68355 L F
.36529 .68922 m .36275 .67672 L .35852 .67736 L F
.36529 .68922 m .36565 .6818 L .36275 .67672 L F
0 g
.36185 .6954 m
.36529 .68922 L
s
.44883 .74726 m .44217 .75142 L .44641 .74873 L 0 0 0 r
F
.44883 .74726 m .43811 .75383 L .44217 .75142 L F
0 g
.44011 .75299 m
.44217 .75142 L
s
.44641 .74873 m
.45054 .74613 L
s
.47651 .7814 m .46707 .78789 L .4692 .79299 L 0 .739 .343 r
F
0 g
.46707 .78789 m
.46786 .78081 L
s
.46311 .78697 m
.46707 .78789 L
s
.43057 .92237 m .43056 .92468 L .43275 .92303 L 0 1 .337 r
F
.43057 .92237 m .42484 .92637 L .43056 .92468 L F
0 g
.43056 .92468 m
.43327 .9251 L
s
.4692 .79299 m .46588 .80415 L .46869 .79996 L 0 .767 .356 r
F
.47484 .80562 m .46588 .80415 L .46579 .81131 L 0 .717 .354 r
F
.47484 .80562 m .46869 .79996 L .46588 .80415 L F
0 g
.46191 .80322 m
.46588 .80415 L
s
.45723 .72266 m
.46019 .71908 L
s
.52666 .57543 m .52992 .56896 L .53321 .566 L 0 0 .061 r
F
0 g
.52992 .56896 m
.53152 .56425 L
s
.74612 .58843 m .75836 .57867 L .75984 .587 L 0 .298 .073 r
F
0 g
.75836 .57867 m
.76296 .57766 L
s
.23527 .77598 m .22369 .76371 L .22199 .76991 L 0 1 .527 r
F
.23527 .77598 m .22819 .76323 L .22369 .76371 L F
.23527 .77598 m .23316 .76849 L .22819 .76323 L F
.24633 .77426 m .23316 .76849 L .23527 .77598 L 0 1 .526 r
F
0 g
.23355 .78214 m
.23527 .77598 L
s
.23527 .77598 m
.24014 .78099 L
s
.46841 .70804 m
.47087 .70777 L
s
.46763 .71114 m
.47087 .70777 L
s
.47029 .73149 m .45956 .73988 L .46336 .73669 L 0 0 0 r
F
0 g
.46097 .73852 m
.46336 .73669 L
s
.45872 .74019 m
.46097 .73852 L
s
.41399 1.03183 m .39565 1.02473 L .39963 1.03054 L 0 1 .498 r
F
.49277 .90285 m .49077 .91161 L .49508 .9135 L 0 .54 .384 r
F
.46582 .90693 m .45404 .91312 L .45656 .91293 L 0 1 .252 r
F
0 g
.4512 .91564 m
.45656 .91293 L
s
.49851 .73338 m .49488 .73396 L .49169 .74093 L 0 .675 .307 r
F
.49851 .73338 m .4978 .73073 L .49488 .73396 L F
0 g
.49488 .73396 m
.49678 .72668 L
s
.49488 .73396 m
.4978 .73073 L
s
.4978 .73073 m
.49949 .72309 L
s
.50362 .92684 m .49845 .92073 L .4941 .91847 L 0 .464 .381 r
F
0 g
.49077 .91161 m
.4941 .91847 L
s
.47484 .80562 m .46579 .81131 L .46849 .81668 L 0 .717 .354 r
F
0 g
.46579 .81131 m
.46588 .80415 L
s
.46167 .8101 m
.46579 .81131 L
s
.48446 .8787 m .48132 .88804 L .48553 .88964 L 0 .601 .38 r
F
0 g
.48132 .88804 m
.48385 .89504 L
s
.48039 .75753 m .4722 .76962 L .47579 .76945 L 0 .754 .332 r
F
.49491 .65257 m .48947 .65201 L .49205 .65326 L 0 1 .372 r
F
.49491 .65257 m .48877 .64908 L .48947 .65201 L F
.49491 .65257 m .49041 .64641 L .48877 .64908 L F
.49491 .65257 m .49327 .64572 L .49041 .64641 L F
.49491 .65257 m .49544 .64747 L .49327 .64572 L F
0 g
.49491 .65257 m
.49591 .65588 L
s
.49544 .64747 m
.49804 .64712 L
s
.49544 .64747 m
.49614 .6504 L
s
.27606 .95813 m .25801 .94892 L .26016 .95448 L 0 1 .536 r
F
0 g
.25225 .95037 m
.25229 .95038 L
s
.27606 .95813 m .26187 .94795 L .25801 .94892 L 0 1 .536 r
F
0 g
.25229 .95038 m
.25869 .95068 L
s
.27606 .95813 m .26962 .95191 L .26187 .94795 L 0 1 .536 r
F
.28528 .95538 m .26962 .95191 L .27606 .95813 L F
0 g
.27606 .95813 m
.28358 .96192 L
s
.27606 .95813 m
.27818 .96366 L
s
.50116 .98028 m .50573 .98268 L .50591 .9813 L 0 1 .517 r
F
.5175 .97912 m .50591 .9813 L .50573 .98268 L 0 1 .486 r
F
0 g
.50573 .98268 m
.51081 .98291 L
s
.50039 .98387 m
.50573 .98268 L
s
.41348 .74676 m .40371 .74387 L .40122 .74766 L 0 1 .492 r
F
.41348 .74676 m .40823 .7423 L .40371 .74387 L F
.41348 .74676 m .41241 .74353 L .40823 .7423 L F
.42455 .74201 m .41241 .74353 L .41348 .74676 L 0 1 .484 r
F
0 g
.41099 .75053 m
.41348 .74676 L
s
.41348 .74676 m
.41757 .74769 L
s
.43548 .53406 m .42719 .54211 L .43011 .54097 L 0 1 .269 r
F
0 g
.43227 .54227 m
.43458 .53936 L
s
.4294 .54589 m
.43227 .54227 L
s
.43548 .53406 m .42845 .53708 L .42719 .54211 L 0 1 .269 r
F
.43548 .53406 m .43306 .52924 L .42845 .53708 L F
.43548 .53406 m .43844 .52234 L .43306 .52924 L F
.43548 .53406 m .44099 .52098 L .43844 .52234 L F
0 g
.44099 .52098 m
.44631 .51361 L
s
.43972 .526 m
.44099 .52098 L
s
.43563 .73683 m .42361 .73903 L .42455 .74201 L 0 1 .475 r
F
.43563 .73683 m .4263 .73538 L .42361 .73903 L F
.43563 .73683 m .43081 .73348 L .4263 .73538 L F
.43563 .73683 m .43482 .7341 L .43081 .73348 L F
0 g
.43295 .74048 m
.43563 .73683 L
s
.43563 .73683 m
.43954 .7371 L
s
.77982 .77445 m .7899 .77866 L .78532 .77558 L 0 .419 .329 r
F
.77982 .77445 m .79115 .78235 L .7899 .77866 L F
.28841 .72245 m .27654 .71503 L .27714 .7242 L 0 1 .469 r
F
.28841 .72245 m .27949 .70773 L .27654 .71503 L F
.28841 .72245 m .28403 .7072 L .27949 .70773 L F
.28841 .72245 m .28785 .71352 L .28403 .7072 L F
0 g
.28545 .72972 m
.28841 .72245 L
s
.48446 .8787 m .48042 .87295 L .47621 .87136 L 0 .601 .38 r
F
.45956 .73988 m .45276 .74447 L .457 .74147 L 0 0 0 r
F
0 g
.457 .74147 m
.45872 .74019 L
s
.48908 .6653 m
.49096 .66551 L
s
.45956 .73988 m .44883 .74726 L .45276 .74447 L 0 0 0 r
F
0 g
.45054 .74613 m
.45131 .74555 L
s
.68327 .91511 m
.68336 .91512 L
s
.78382 .93559 m .79576 .93411 L .79178 .93311 L 0 1 .534 r
F
.77404 .9328 m .78382 .93559 L .7858 .93158 L 0 1 .532 r
F
0 g
.49976 .73089 m
.50116 .7281 L
s
.43376 1.04562 m .43656 1.05313 L .43839 1.05114 L 0 1 .499 r
F
.45434 1.0581 m .43839 1.05114 L .43656 1.05313 L 0 1 .5 r
F
0 g
.43656 1.05313 m
.44181 1.05832 L
s
.42878 1.05052 m
.43656 1.05313 L
s
.47688 .45928 m .47019 .46995 L .47142 .46752 L 0 0 0 r
F
.47688 .45928 m .47414 .46587 L .47019 .46995 L F
0 g
.46793 .47198 m
.47152 .46648 L
s
.47152 .46648 m
.4733 .46375 L
s
.47688 .45928 m .48063 .458 L .47414 .46587 L 0 0 0 r
F
.47688 .45928 m .48608 .44977 L .48063 .458 L F
.35226 .96845 m .3383 .96166 L .33496 .96296 L 0 1 .537 r
F
0 g
.32995 .96492 m
.33305 .96592 L
s
.33305 .96592 m
.33761 .9674 L
s
.35226 .96845 m .34572 .96401 L .3383 .96166 L 0 1 .537 r
F
0 g
.35226 .96845 m
.35488 .97288 L
s
.36185 .96414 m .34572 .96401 L .35226 .96845 L 0 1 .537 r
F
0 g
.35226 .96845 m
.35993 .97043 L
s
.42455 .74201 m .415 .73982 L .41241 .74353 L 0 1 .484 r
F
.42455 .74201 m .41952 .7381 L .415 .73982 L F
.42455 .74201 m .42361 .73903 L .41952 .7381 L F
0 g
.42197 .74572 m
.42455 .74201 L
s
.42455 .74201 m
.42855 .74263 L
s
.44961 .9783 m .45196 .98265 L .45338 .98094 L 0 1 .539 r
F
.46613 .98185 m .45338 .98094 L .45196 .98265 L 0 1 .538 r
F
0 g
.45196 .98265 m
.45622 .98491 L
s
.44578 .9825 m
.45196 .98265 L
s
.50886 .72019 m .5064 .74387 L .50799 .73086 L 0 .623 .295 r
F
.50886 .72019 m .50454 .75191 L .5064 .74387 L F
.50886 .72019 m .50368 .74959 L .50454 .75191 L F
.50886 .72019 m .50455 .7389 L .50368 .74959 L F
.50886 .72019 m .50658 .72698 L .50455 .7389 L F
0 g
.50886 .72019 m
.51038 .70886 L
s
.50658 .72698 m
.50755 .71906 L
s
.50774 .72198 m
.50828 .71963 L
s
.50658 .72698 m
.50774 .72198 L
s
.48492 .97983 m .48311 .9838 L .48869 .98306 L 0 1 .529 r
F
.48492 .97983 m .47627 .98322 L .48311 .9838 L F
0 g
.48311 .9838 m
.48779 .98555 L
s
.54312 1.00096 m
.54374 1.00203 L
s
.47918 .69346 m .47099 .69804 L .47557 .69619 L 0 1 .417 r
F
.47918 .69346 m .4678 .69784 L .47099 .69804 L F
.47918 .69346 m .46812 .69571 L .4678 .69784 L F
0 g
.47557 .69619 m
.47893 .6961 L
s
.47918 .69346 m .47173 .69298 L .46812 .69571 L 0 1 .417 r
F
.47918 .69346 m .47623 .69147 L .47173 .69298 L F
.47918 .69346 m .47942 .69167 L .47623 .69147 L F
0 g
.47918 .69346 m
.47943 .69345 L
s
.47557 .69619 m
.47918 .69346 L
s
.47942 .69167 m
.48297 .68919 L
s
.48924 .66647 m
.49027 .66698 L
s
.48952 .66717 m
.49027 .66698 L
s
.47651 .7814 m .47474 .77671 L .47103 .77646 L 0 .739 .343 r
F
0 g
.47103 .77646 m
.4722 .76962 L
s
.24103 .94682 m .23873 .9538 L .24258 .95282 L 0 1 .536 r
F
.24095 .94865 m .23873 .9538 L .24258 .95282 L 0 1 .53 r
F
.24103 .94682 m .23123 .94911 L .23873 .9538 L 0 1 .536 r
F
.24095 .94865 m .23115 .95091 L .23873 .9538 L 0 1 .53 r
F
.24087 .95048 m .23873 .9538 L .24258 .95282 L 0 1 .384 r
F
0 g
.24258 .95282 m
.24261 .95282 L
s
.24258 .95282 m
.24331 .95303 L
s
.24258 .95282 m
.24295 .95301 L
s
.24087 .95048 m .23107 .9527 L .23873 .9538 L 0 1 .384 r
F
0 g
.23873 .9538 m
.24129 .95967 L
s
.7744 .58616 m .78111 .59357 L .77656 .59097 L 0 .199 0 r
F
.7744 .58616 m .78584 .59343 L .78111 .59357 L F
.49715 1.07789 m .48692 1.08062 L .49615 1.0843 L 0 1 .509 r
F
.49715 1.07789 m .48058 1.07616 L .48692 1.08062 L F
.3547 .69115 m .347 .69818 L .35125 .69741 L 0 1 .437 r
F
0 g
.35125 .69741 m
.35465 .70255 L
s
.80761 .85911 m .80777 .87672 L .81403 .86896 L 0 1 .501 r
F
.80761 .85911 m .80363 .87677 L .80777 .87672 L F
0 g
.80675 .88376 m
.80777 .87672 L
s
.50586 .69687 m
.50586 .69686 L
s
.50586 .69687 m
.50586 .69686 L
s
.47872 .85439 m .47447 .86431 L .47857 .86562 L 0 .649 .373 r
F
0 g
.47447 .86431 m
.47621 .87136 L
s
.76597 .88541 m .76133 .89385 L .76082 .90001 L 0 1 .504 r
F
0 g
.7536 .90576 m
.76082 .90001 L
s
.31465 .76275 m .30847 .76832 L .31259 .76748 L 0 1 .523 r
F
.31465 .76275 m .30426 .76465 L .30847 .76832 L F
0 g
.30713 .77319 m
.30847 .76832 L
s
.31259 .76748 m
.31735 .77091 L
s
.50171 .70164 m .49363 .71265 L .49824 .70621 L 0 0 .051 r
F
.50171 .70164 m .4902 .71796 L .49363 .71265 L F
0 g
.49861 .70454 m
.50111 .70098 L
s
.49872 .70445 m
.50083 .7018 L
s
.50171 .70164 m .49026 .71857 L .4902 .71796 L 0 0 .051 r
F
.50171 .70164 m .49375 .71399 L .49026 .71857 L F
.50171 .70164 m .49834 .70728 L .49375 .71399 L F
.50171 .70164 m .50175 .70199 L .49834 .70728 L F
0 g
.50171 .70164 m
.50173 .70161 L
s
.4983 .70499 m
.49861 .70454 L
s
.4983 .70499 m
.49872 .70445 L
s
.50027 .70354 m
.50041 .70336 L
s
.50041 .70336 m
.50103 .70255 L
s
.50103 .70255 m
.50143 .70202 L
s
.50143 .70202 m
.50171 .70164 L
s
.50175 .70199 m
.50191 .70169 L
s
.49101 .71258 m .48347 .72006 L .48788 .71544 L 0 0 .019 r
F
.49101 .71258 m .47989 .7242 L .48347 .72006 L F
.49101 .71258 m .47954 .72511 L .47989 .7242 L F
.49101 .71258 m .48268 .72224 L .47954 .72511 L F
.49101 .71258 m .48721 .71751 L .48268 .72224 L F
.49101 .71258 m .49078 .71338 L .48721 .71751 L F
0 g
.48788 .71544 m
.4879 .71542 L
s
.4879 .71542 m
.49022 .71274 L
s
.49101 .71258 m
.49112 .71243 L
s
.48788 .71544 m
.48987 .71362 L
s
.48987 .71362 m
.49042 .71312 L
s
.49042 .71312 m
.49062 .71294 L
s
.49062 .71294 m
.49101 .71258 L
s
.51445 .71605 m
.51445 .71606 L
s
.31929 .96331 m .30165 .95615 L .30401 .96108 L 0 1 .536 r
F
.31929 .96331 m .30527 .95501 L .30165 .95615 L F
.31929 .96331 m .31284 .95809 L .30527 .95501 L F
.32785 .96016 m .31284 .95809 L .31929 .96331 L F
0 g
.31929 .96331 m
.32662 .96623 L
s
.31929 .96331 m
.32162 .96822 L
s
.27714 .7242 m .26522 .71647 L .26587 .72588 L 0 1 .473 r
F
.27714 .7242 m .26814 .70902 L .26522 .71647 L F
.27714 .7242 m .27268 .70851 L .26814 .70902 L F
.27714 .7242 m .27654 .71503 L .27268 .70851 L F
0 g
.27422 .73162 m
.27714 .7242 L
s
.27714 .7242 m
.28096 .73049 L
s
.52509 .6766 m
.52774 .67423 L
s
.48858 .74345 m .48374 .75635 L .48692 .75052 L 0 .726 .32 r
F
.48858 .74345 m .48039 .75753 L .48374 .75635 L F
0 g
.70569 .56798 m
.70676 .58633 L
s
.70676 .58633 m
.70676 .58634 L
s
.51738 .68475 m .5198 .6955 L .51823 .68989 L 0 .112 .104 r
F
.51738 .68475 m .52164 .69768 L .5198 .6955 L F
.51738 .68475 m .52252 .69495 L .52164 .69768 L F
.51738 .68475 m .52167 .68979 L .52252 .69495 L F
.51738 .68475 m .51966 .68565 L .52167 .68979 L F
0 g
.51588 .68409 m
.51738 .68475 L
s
.51854 .68185 m
.51966 .68565 L
s
.51782 .6835 m
.51966 .68565 L
s
.45434 1.0581 m .45828 1.06539 L .4596 1.0633 L 0 1 .5 r
F
.47554 1.06903 m .4596 1.0633 L .45828 1.06539 L 0 1 .501 r
F
0 g
.45828 1.06539 m
.46411 1.07023 L
s
.45066 1.06326 m
.45828 1.06539 L
s
.65555 .49038 m
.6584 .49761 L
s
.65417 .48687 m
.65555 .49038 L
s
.6584 .49761 m
.66057 .50313 L
s
.34944 .78544 m .34384 .78857 L .34786 .78748 L 0 1 .436 r
F
.34944 .78544 m .3393 .78795 L .34384 .78857 L F
0 g
.3429 .79078 m
.34384 .78857 L
s
.34786 .78748 m
.35281 .78784 L
s
.24633 .77426 m .23494 .76249 L .23316 .76849 L 0 1 .526 r
F
.24633 .77426 m .23944 .762 L .23494 .76249 L F
.24633 .77426 m .24432 .76705 L .23944 .762 L F
.2574 .77251 m .24432 .76705 L .24633 .77426 L F
0 g
.24454 .78022 m
.24633 .77426 L
s
.24633 .77426 m
.25113 .77906 L
s
.51471 .71627 m
.51471 .71627 L
s
.29857 .95884 m
.30401 .96108 L
s
.47872 .85439 m .47526 .84884 L .47117 .84755 L 0 .649 .373 r
F
.49197 .65791 m .49312 .65579 L .49205 .65326 L 0 1 .382 r
F
0 g
.49312 .65579 m
.49553 .65586 L
s
.48384 .89675 m
.48527 .89566 L
s
.30894 .79488 m .29517 .79143 L .29307 .79449 L 0 1 .504 r
F
.30894 .79488 m .30059 .79058 L .29517 .79143 L F
.30894 .79488 m .3065 .79206 L .30059 .79058 L F
0 g
.30683 .79792 m
.30894 .79488 L
s
.31905 .79265 m .3065 .79206 L .30895 .79487 L 0 1 .493 r
F
0 g
.30895 .79487 m
.31378 .79625 L
s
.39117 .64926 m .38253 .65577 L .38687 .65508 L 0 1 .411 r
F
.39117 .64926 m .38039 .65089 L .38253 .65577 L F
0 g
.38687 .65508 m
.38948 .65989 L
s
.39117 .64926 m .38188 .6437 L .38039 .65089 L 0 1 .411 r
F
.39117 .64926 m .38619 .63787 L .38188 .6437 L F
.39117 .64926 m .39043 .63729 L .38619 .63787 L F
.39117 .64926 m .39256 .64217 L .39043 .63729 L F
0 g
.38687 .65508 m
.39117 .64926 L
s
.39503 .63154 m
.39691 .63635 L
s
.39256 .64217 m
.39691 .63635 L
s
.49851 .73338 m .49169 .74093 L .4901 .74879 L 0 .675 .307 r
F
0 g
.48858 .74345 m
.49169 .74093 L
s
.52275 .45956 m .53451 .44234 L .53005 .45133 L 0 0 .027 r
F
0 g
.53451 .44234 m
.5398 .43569 L
s
.50193 .628 m .49829 .62745 L .49957 .62906 L 0 1 .295 r
F
.50193 .628 m .49909 .62357 L .49829 .62745 L F
.50193 .628 m .50142 .62002 L .49909 .62357 L F
.50193 .628 m .50378 .61897 L .50142 .62002 L F
.50193 .628 m .50459 .62111 L .50378 .61897 L F
0 g
.50148 .63249 m
.50193 .628 L
s
.50459 .62111 m
.50661 .62034 L
s
.50379 .62498 m
.50459 .62111 L
s
.41671 .76512 m .40633 .76837 L .40431 .76985 L 0 .899 .238 r
F
.41671 .76512 m .41072 .76658 L .40633 .76837 L F
.41671 .76512 m .41518 .76519 L .41072 .76658 L F
.42741 .75974 m .41518 .76519 L .41671 .76512 L 0 .86 .216 r
F
0 g
.41469 .7666 m
.41671 .76512 L
s
.41671 .76512 m
.42103 .7634 L
s
.48039 .75753 m .47579 .76945 L .47897 .76446 L 0 .754 .332 r
F
.3547 .69115 m .34411 .69291 L .347 .69818 L 0 1 .437 r
F
0 g
.34408 .7046 m
.347 .69818 L
s
.77077 .66209 m
.77489 .66778 L
s
.51343 .68977 m
.51343 .68977 L
s
.26587 .72588 m .2539 .71786 L .25461 .72752 L 0 1 .476 r
F
.26587 .72588 m .25678 .71024 L .2539 .71786 L F
.26587 .72588 m .26132 .70976 L .25678 .71024 L F
.26587 .72588 m .26522 .71647 L .26132 .70976 L F
0 g
.263 .73347 m
.26587 .72588 L
s
.26587 .72588 m
.26973 .73237 L
s
.49397 .70958 m
.494 .70954 L
s
.49297 .71076 m
.494 .70954 L
s
.49106 .71304 m
.49297 .71076 L
s
.49078 .71338 m
.49106 .71304 L
s
.53471 .72977 m .54169 .65904 L .54178 .61937 L 0 .78 .249 r
F
0 g
.54178 .61937 m
.54495 .57634 L
s
.53645 .61142 m
.5366 .6306 L
s
.42484 .92637 m .41338 .92857 L .41085 .93012 L 0 1 .386 r
F
.42484 .92637 m .41938 .92696 L .41338 .92857 L F
.43057 .92237 m .41938 .92696 L .42484 .92637 L 0 1 .337 r
F
0 g
.42484 .92637 m
.42729 .92722 L
s
.42484 .92637 m
.43056 .92468 L
s
.47554 .83 m .47021 .84049 L .47418 .84148 L 0 .687 .364 r
F
0 g
.47021 .84049 m
.47117 .84755 L
s
.25295 .95058 m
.25934 .95236 L
s
.76162 .75616 m .7624 .75776 L .76699 .76168 L 0 .116 .169 r
F
.76162 .75616 m .7601 .75539 L .7624 .75776 L F
0 g
.7571 .75567 m
.7624 .75776 L
s
.50362 .92684 m .5028 .93473 L .50716 .93702 L 0 .464 .381 r
F
.47651 .7814 m .4692 .79299 L .47291 .79325 L 0 .739 .343 r
F
.60123 .42049 m .61502 .42493 L .61746 .43125 L 0 .351 .082 r
F
0 g
.61502 .42493 m
.61803 .42341 L
s
.60807 .42033 m
.61502 .42493 L
s
.47484 .80562 m .47253 .80059 L .46869 .79996 L 0 .717 .354 r
F
0 g
.46869 .79996 m
.4692 .79299 L
s
.50998 .72305 m .50953 .72194 L .50799 .73086 L 0 .613 .295 r
F
0 g
.50933 .72306 m
.50953 .72194 L
s
.50953 .72194 m
.51038 .70886 L
s
.49851 .73338 m .49409 .74907 L .49692 .74124 L 0 .675 .307 r
F
.49851 .73338 m .49117 .75231 L .49409 .74907 L F
.49851 .73338 m .4901 .74879 L .49117 .75231 L F
0 g
.49851 .73338 m
.49976 .73089 L
s
.45281 .49643 m .46065 .48303 L .45892 .48511 L 0 .896 .14 r
F
0 g
.46065 .48303 m
.46603 .47478 L
s
.45803 .48788 m
.46065 .48303 L
s
.45654 .71933 m .44889 .72508 L .45341 .72276 L 0 1 .452 r
F
0 g
.45341 .72276 m
.45723 .72266 L
s
.41399 1.03183 m .41561 1.03954 L .41796 1.03764 L 0 1 .498 r
F
.43376 1.04562 m .41796 1.03764 L .41561 1.03954 L 0 1 .499 r
F
0 g
.41561 1.03954 m
.42025 1.04505 L
s
.40776 1.03649 m
.41561 1.03954 L
s
.34732 .94111 m .34428 .9454 L .34839 .94369 L 0 1 .482 r
F
.34732 .94111 m .33676 .94516 L .34428 .9454 L F
0 g
.34428 .9454 m
.34615 .94791 L
s
.52666 .57543 m .53321 .566 L .53435 .5685 L 0 0 .061 r
F
0 g
.53321 .566 m
.53474 .55814 L
s
.52992 .56896 m
.53321 .566 L
s
.47554 .83 m .47266 .82468 L .46869 .82371 L 0 .687 .364 r
F
.36964 .94115 m .35384 .94145 L .35613 .94341 L 0 1 .474 r
F
.36964 .94115 m .35698 .94017 L .35384 .94145 L F
.36964 .94115 m .36376 .94005 L .35698 .94017 L F
.37697 .93763 m .36376 .94005 L .36964 .94115 L 0 1 .455 r
F
0 g
.36964 .94115 m
.37616 .94088 L
s
.36964 .94115 m
.3719 .94312 L
s
.47989 .68896 m .47173 .69298 L .47623 .69147 L 0 1 .415 r
F
.47989 .68896 m .46874 .69248 L .47173 .69298 L F
.47989 .68896 m .46925 .69031 L .46874 .69248 L F
0 g
.47623 .69147 m
.47942 .69167 L
s
.47989 .68896 m .47291 .6878 L .46925 .69031 L 0 1 .415 r
F
.47989 .68896 m .47728 .68662 L .47291 .6878 L F
.47989 .68896 m .48027 .68712 L .47728 .68662 L F
0 g
.47989 .68896 m
.48297 .68919 L
s
.47623 .69147 m
.47989 .68896 L
s
.48027 .68712 m
.48383 .68494 L
s
.48383 .76803 m .47579 .76945 L .47474 .77671 L 0 .714 .331 r
F
.48383 .76803 m .47897 .76446 L .47579 .76945 L F
0 g
.4722 .76962 m
.47579 .76945 L
s
.37765 .66893 m .36923 .67567 L .37365 .67492 L 0 1 .421 r
F
0 g
.37365 .67492 m
.3767 .67979 L
s
.44961 .9783 m .43516 .97794 L .43894 .98059 L 0 1 .539 r
F
0 g
.43245 .98042 m
.43894 .98059 L
s
.78584 .59343 m .79909 .59787 L .79727 .59968 L 0 .116 0 r
F
0 g
.79696 .59414 m
.79909 .59787 L
s
.79909 .59787 m
.80391 .59859 L
s
.49197 .65791 m .48592 .65812 L .48889 .65891 L 0 1 .382 r
F
.49197 .65791 m .48485 .65558 L .48592 .65812 L F
.49197 .65791 m .48638 .65301 L .48485 .65558 L F
.49197 .65791 m .48947 .65201 L .48638 .65301 L F
.49197 .65791 m .49205 .65326 L .48947 .65201 L F
0 g
.49197 .65791 m
.49333 .66073 L
s
.49205 .65326 m
.49491 .65257 L
s
.49205 .65326 m
.49312 .65579 L
s
.50125 .70277 m
.50175 .70199 L
s
.51552 .71676 m
.51552 .71678 L
s
.32504 .76077 m .31879 .7662 L .32292 .76533 L 0 1 .522 r
F
.32504 .76077 m .31465 .76275 L .31879 .7662 L F
0 g
.31735 .77091 m
.31879 .7662 L
s
.32292 .76533 m
.32758 .76855 L
s
.50166 .58613 m .50384 .54946 L .50003 .56094 L 0 1 .264 r
F
0 g
.50384 .54946 m
.50451 .54938 L
s
.50384 .54946 m
.50397 .54878 L
s
.76597 .88541 m .77134 .89318 L .77618 .88449 L 0 1 .504 r
F
0 g
.76476 .89983 m
.77134 .89318 L
s
.77067 .89965 m
.77134 .89318 L
s
.81724 .68869 m .82835 .70002 L .82872 .69203 L 0 1 .513 r
F
0 g
.82465 .70484 m
.82835 .70002 L
s
.48492 .97983 m .4719 .98157 L .47627 .98322 L 0 1 .529 r
F
0 g
.47038 .98411 m
.47627 .98322 L
s
.47484 .80562 m .46849 .81668 L .47232 .81731 L 0 .717 .354 r
F
0 g
.46849 .81668 m
.46869 .82371 L
s
.50624 .69704 m
.50624 .69703 L
s
.50624 .69704 m
.50624 .69703 L
s
.47029 .73149 m .45872 .74075 L .45956 .73988 L 0 0 0 r
F
.47029 .73149 m .46141 .73894 L .45872 .74075 L F
.47029 .73149 m .46582 .73564 L .46141 .73894 L F
0 g
.46029 .73926 m
.46336 .73669 L
s
.47029 .73149 m .46963 .73245 L .46582 .73564 L 0 0 0 r
F
0 g
.47029 .73149 m
.47077 .73102 L
s
.4677 .73324 m
.47029 .73149 L
s
.25461 .72752 m .24258 .71921 L .24334 .7291 L 0 1 .479 r
F
.25461 .72752 m .24542 .71142 L .24258 .71921 L F
.25461 .72752 m .24996 .71095 L .24542 .71142 L F
.25461 .72752 m .2539 .71786 L .24996 .71095 L F
0 g
.25177 .73527 m
.25461 .72752 L
s
.25461 .72752 m
.25851 .73419 L
s
.46737 .70816 m .4594 .71367 L .46399 .71138 L 0 1 .437 r
F
.46737 .70816 m .45589 .71365 L .4594 .71367 L F
.46737 .70816 m .45579 .71134 L .45589 .71365 L F
.46737 .70816 m .45918 .70811 L .45579 .71134 L F
0 g
.46399 .71138 m
.46763 .71114 L
s
.46737 .70816 m .46379 .70612 L .45918 .70811 L 0 1 .437 r
F
.46737 .70816 m .4673 .70614 L .46379 .70612 L F
0 g
.46737 .70816 m
.46841 .70804 L
s
.46399 .71138 m
.46737 .70816 L
s
.51692 .9504 m .51126 .94411 L .50687 .94159 L 0 .374 .367 r
F
0 g
.5028 .93473 m
.50687 .94159 L
s
.7347 .92079 m .73198 .92824 L .73898 .92704 L 0 1 .516 r
F
.7347 .92079 m .72821 .92674 L .73198 .92824 L F
0 g
.72995 .93161 m
.73198 .92824 L
s
.29451 .95265 m .2926 .95902 L .29622 .95787 L 0 1 .535 r
F
0 g
.29622 .95787 m
.29857 .95884 L
s
.29451 .95265 m .28528 .95538 L .2926 .95902 L 0 1 .535 r
F
0 g
.2926 .95902 m
.29519 .9641 L
s
.37765 .66893 m .36666 .6707 L .36923 .67567 L 0 1 .421 r
F
.37765 .66893 m .36764 .66332 L .36666 .6707 L F
.37765 .66893 m .37165 .65733 L .36764 .66332 L F
.37765 .66893 m .376 .65673 L .37165 .65733 L F
.37765 .66893 m .37857 .6617 L .376 .65673 L F
0 g
.37765 .66893 m
.38026 .67373 L
s
.37365 .67492 m
.37765 .66893 L
s
.34839 .94369 m
.35613 .94341 L
s
.2574 .77251 m .24619 .76125 L .24432 .76705 L 0 1 .526 r
F
.2574 .77251 m .25069 .76075 L .24619 .76125 L F
.2574 .77251 m .25549 .76558 L .25069 .76075 L F
.26847 .77073 m .25549 .76558 L .2574 .77251 L F
0 g
.25552 .77828 m
.2574 .77251 L
s
.2574 .77251 m
.26212 .7771 L
s
.53514 .98795 m
.53566 .98861 L
s
.53669 .98994 m
.53669 .98994 L
s
.54021 .99448 m
.54086 .99532 L
s
.53514 .98795 m
.53534 .98807 L
s
.53707 .9892 m
.53722 .9893 L
s
.53778 .98967 m
.53987 .99104 L
s
.53773 .98963 m
.53778 .98967 L
s
.4948 .88757 m .48993 .89129 L .48816 .89344 L 0 .928 .204 r
F
.49478 .8931 m .48993 .89129 L .48815 .89692 L 0 .517 .372 r
F
.48993 .89129 m .48553 .88964 L .48705 .89385 L F
.48993 .89129 m .48662 .89341 L .48551 .89466 L 0 .928 .204 r
F
.48993 .89129 m .48666 .88586 L .48553 .88964 L 0 .517 .372 r
F
.4948 .88757 m .49134 .89004 L .48993 .89129 L 0 .928 .204 r
F
.49478 .8931 m .49134 .89004 L .48993 .89129 L 0 .517 .372 r
F
.4913 .89 m .48666 .88586 L .48985 .89115 L F
.49134 .89004 m .49062 .88734 L .48666 .88586 L F
.4948 .88757 m .49209 .88938 L .49134 .89004 L 0 .928 .204 r
F
.49478 .8931 m .49209 .88938 L .49134 .89004 L 0 .517 .372 r
F
.49209 .88938 m .49062 .88734 L .49134 .89004 L F
.49134 .89004 m .49061 .89037 L .48662 .89341 L 0 .928 .204 r
F
.49209 .88938 m .49061 .89037 L .49134 .89004 L F
.4968 .88213 m .49062 .88734 L .49209 .88938 L 0 .497 .36 r
F
.49604 .88626 m .49209 .88938 L .4948 .88757 L 0 .834 .169 r
F
.49723 .8853 m .4948 .88757 L .49843 .88486 L F
.49723 .88531 m .49478 .8931 L .49841 .8941 L 0 .497 .36 r
F
.4968 .88213 m .49604 .88626 L .49723 .88531 L F
.49723 .88531 m .49604 .88626 L .49723 .8853 L 0 .834 .169 r
F
.49604 .88626 m .4948 .88757 L .49723 .8853 L F
.49604 .88626 m .49478 .8931 L .49723 .88531 L 0 .497 .36 r
F
.49679 .88547 m .49604 .88626 L .49723 .88531 L 0 .834 .169 r
F
.49604 .88626 m .49209 .88938 L .49211 .8894 L 0 .497 .36 r
F
.49604 .88626 m .49211 .8894 L .49478 .8931 L F
.4968 .88213 m .49209 .88938 L .49604 .88626 L F
.4961 .8862 m .49209 .88938 L .49604 .88626 L 0 .834 .169 r
F
.49679 .88547 m .49061 .89037 L .49209 .88938 L F
.49679 .88547 m .49209 .88938 L .4961 .8862 L F
.49134 .89004 m .4913 .89 L .48993 .89129 L 0 .517 .372 r
F
.4913 .89 m .48985 .89115 L .48993 .89129 L F
.49134 .89004 m .49128 .89008 L .48993 .89129 L 0 .928 .204 r
F
.49128 .89008 m .48662 .89341 L .48993 .89129 L F
.48993 .89129 m .48705 .89385 L .48708 .89394 L 0 .517 .372 r
F
.48993 .89129 m .48708 .89394 L .48816 .89344 L 0 .928 .204 r
F
.48993 .89129 m .48708 .89394 L .48815 .89692 L 0 .517 .372 r
F
.48993 .89129 m .48551 .89466 L .48708 .89394 L 0 .928 .204 r
F
0 g
.48527 .89566 m
.48531 .89563 L
s
.48531 .89563 m
.48717 .8942 L
s
.45654 .71933 m .44519 .72493 L .44889 .72508 L 0 1 .452 r
F
0 g
.44602 .72867 m
.44889 .72508 L
s
.45654 .71933 m .44478 .72241 L .44519 .72493 L 0 1 .452 r
F
.45654 .71933 m .44792 .71897 L .44478 .72241 L F
.45654 .71933 m .45251 .71692 L .44792 .71897 L F
.45654 .71933 m .45621 .71707 L .45251 .71692 L F
0 g
.45654 .71933 m
.46019 .71908 L
s
.45341 .72276 m
.45654 .71933 L
s
.61243 .45075 m .61214 .46099 L .60962 .44924 L 0 .663 .062 r
F
0 g
.60962 .44924 m
.60993 .44941 L
s
.60787 .44565 m
.60962 .44924 L
s
.61243 .45075 m .61906 .48112 L .61214 .46099 L 0 .663 .062 r
F
.61243 .45075 m .62577 .49618 L .61906 .48112 L F
.61243 .45075 m .62858 .49763 L .62577 .49618 L F
.61243 .45075 m .62562 .48455 L .62858 .49763 L F
0 g
.62574 .47178 m
.63093 .49472 L
s
.61243 .45075 m .6187 .46448 L .62562 .48455 L 0 .663 .062 r
F
0 g
.62283 .46959 m
.6231 .47078 L
s
.62117 .46224 m
.62283 .46959 L
s
.6231 .47078 m
.62332 .47177 L
s
.6097 .44199 m
.61243 .45075 L
s
.60993 .44941 m
.61243 .45075 L
s
.6187 .46448 m
.62113 .46228 L
s
.79427 .68095 m .80252 .67826 L .79792 .67672 L 0 1 .504 r
F
.79427 .68095 m .80576 .68502 L .80252 .67826 L F
.48383 .76803 m .48241 .76385 L .47897 .76446 L 0 .714 .331 r
F
0 g
.47897 .76446 m
.48039 .75753 L
s
.46812 .70305 m
.47071 .70297 L
s
.4673 .70614 m
.47071 .70297 L
s
.49117 .75231 m .48692 .75052 L .48374 .75635 L 0 .692 .319 r
F
.49117 .75231 m .4901 .74879 L .48692 .75052 L F
0 g
.48692 .75052 m
.48858 .74345 L
s
.48692 .75052 m
.4901 .74879 L
s
.4901 .74879 m
.49169 .74093 L
s
.3547 .69115 m .34448 .68512 L .34411 .69291 L 0 1 .437 r
F
.3547 .69115 m .34794 .67884 L .34448 .68512 L F
.3547 .69115 m .35217 .67827 L .34794 .67884 L F
.3547 .69115 m .35507 .68355 L .35217 .67827 L F
0 g
.3547 .69115 m
.35761 .69623 L
s
.35125 .69741 m
.3547 .69115 L
s
.5163 .71691 m
.51631 .71693 L
s
.47849 .7248 m
.47961 .7237 L
s
.47961 .7237 m
.48014 .72317 L
s
.48014 .72317 m
.48053 .72279 L
s
.48226 .72118 m
.48347 .72006 L
s
.48174 .72166 m
.48226 .72118 L
s
.48053 .72279 m
.48174 .72166 L
s
.50998 .72305 m .50831 .74852 L .50946 .73443 L 0 .613 .295 r
F
.50998 .72305 m .50677 .75747 L .50831 .74852 L F
.50998 .72305 m .50587 .75529 L .50677 .75747 L F
.50998 .72305 m .5064 .74387 L .50587 .75529 L F
.50998 .72305 m .50799 .73086 L .5064 .74387 L F
0 g
.50998 .72305 m
.51117 .71079 L
s
.36565 .6818 m
.36923 .67567 L
s
.8087 .60508 m .8201 .60769 L .8221 .60963 L 0 0 0 r
F
0 g
.8201 .60769 m
.82407 .61072 L
s
.49715 1.07789 m .49615 1.0843 L .50325 1.08505 L 0 1 .509 r
F
0 g
.43275 .92303 m
.43844 .92087 L
s
.44887 .91535 m .4361 .92058 L .43844 .92086 L 0 1 .297 r
F
0 g
.43844 .92086 m
.43844 .92086 L
s
.24334 .7291 m .23126 .72052 L .23208 .73065 L 0 1 .483 r
F
.24334 .7291 m .23405 .71256 L .23126 .72052 L F
.24334 .7291 m .2386 .71211 L .23405 .71256 L F
.24334 .7291 m .24258 .71921 L .2386 .71211 L F
0 g
.24055 .73702 m
.24334 .7291 L
s
.24334 .7291 m
.24728 .73597 L
s
.49117 .75231 m .48374 .75635 L .48241 .76385 L 0 .692 .319 r
F
0 g
.48039 .75753 m
.48374 .75635 L
s
.48927 .66316 m .49032 .66107 L .48889 .65891 L 0 1 .39 r
F
0 g
.49032 .66107 m
.49262 .66081 L
s
.51721 .95791 m .52222 .96748 L .52198 .96477 L 0 .383 .371 r
F
0 g
.51749 .96455 m
.52222 .96748 L
s
.52222 .96748 m
.52457 .97072 L
s
.52457 .97072 m
.52486 .97112 L
s
.34411 .69291 m .3364 .69998 L .34064 .69927 L 0 1 .444 r
F
0 g
.34064 .69927 m
.34408 .7046 L
s
.69074 1.07469 m .70283 1.07501 L .70003 1.07461 L 0 .775 .287 r
F
.71344 1.07275 m .70283 1.07501 L .71181 1.07434 L 0 .734 .252 r
F
.71344 1.07275 m .70003 1.07461 L .70283 1.07501 L F
0 g
.70702 1.07564 m
.70755 1.07549 L
s
.69746 1.07593 m
.70283 1.07501 L
s
.45281 .49643 m .44511 .50587 L .44727 .50415 L 0 .896 .14 r
F
.45281 .49643 m .44773 .50101 L .44511 .50587 L F
0 g
.44846 .50446 m
.4505 .50164 L
s
.45281 .49643 m .45339 .49281 L .44773 .50101 L 0 .896 .14 r
F
.45281 .49643 m .45892 .48511 L .45339 .49281 L F
0 g
.4505 .50164 m
.45281 .49643 L
s
.61997 .60735 m
.61997 .60666 L
s
.42741 .75974 m .41733 .76375 L .41518 .76519 L 0 .86 .216 r
F
.42741 .75974 m .42173 .76177 L .41733 .76375 L F
.42741 .75974 m .42605 .76005 L .42173 .76177 L F
.43811 .75383 m .42605 .76005 L .42741 .75974 L 0 .799 .185 r
F
0 g
.42525 .76118 m
.42741 .75974 L
s
.42741 .75974 m
.43159 .75769 L
s
.52097 .69983 m
.52192 .70271 L
s
.28544 .95086 m .26768 .9465 L .26969 .95 L 0 1 .522 r
F
.28544 .95086 m .27155 .94555 L .26768 .9465 L F
.28544 .95086 m .27917 .94742 L .27155 .94555 L F
.29467 .94804 m .27917 .94742 L .28544 .95086 L 0 1 .517 r
F
0 g
.28544 .95086 m
.29283 .95253 L
s
.28544 .95086 m
.28742 .95434 L
s
.48095 .68434 m .47291 .6878 L .47728 .68662 L 0 1 .412 r
F
.48095 .68434 m .47015 .68701 L .47291 .6878 L F
.48095 .68434 m .47084 .68478 L .47015 .68701 L F
0 g
.47728 .68662 m
.48027 .68712 L
s
.48095 .68434 m .47452 .68249 L .47084 .68478 L 0 1 .412 r
F
.48095 .68434 m .47872 .68167 L .47452 .68249 L F
.48095 .68434 m .48147 .68246 L .47872 .68167 L F
0 g
.48095 .68434 m
.48383 .68494 L
s
.47728 .68662 m
.48095 .68434 L
s
.48147 .68246 m
.48501 .68059 L
s
.50003 .56094 m .50268 .5311 L .49838 .54309 L 0 1 .244 r
F
0 g
.50268 .5311 m
.5049 .52895 L
s
.50268 .5311 m
.50342 .52792 L
s
.48383 .76803 m .47474 .77671 L .47651 .7814 L 0 .714 .331 r
F
0 g
.47474 .77671 m
.47579 .76945 L
s
.47103 .77646 m
.47474 .77671 L
s
.5999 .5856 m
.59997 .58607 L
s
.59997 .58607 m
.59997 .58607 L
s
.60091 .59194 m
.602 .59886 L
s
.60091 .59194 m
.60091 .59194 L
s
.60091 .59194 m
.60091 .59194 L
s
.60091 .59194 m
.60091 .59194 L
s
.59997 .58607 m
.60091 .59194 L
s
.38472 .97031 m .36857 .96629 L .37148 .97014 L 0 1 .538 r
F
0 g
.36365 .96864 m
.37148 .97014 L
s
.51708 .71687 m
.51822 .72574 L
s
.51706 .71669 m
.51708 .71687 L
s
.39521 1.01685 m .38779 1.02127 L .39565 1.02473 L 0 1 .495 r
F
.39521 1.01685 m .38013 1.01485 L .38779 1.02127 L F
0 g
.24255 .95278 m
.24258 .95282 L
s
.51248 .69234 m
.5126 .69131 L
s
.51247 .69238 m
.51248 .69234 L
s
.51247 .69241 m
.51247 .69238 L
s
.33544 .75869 m .32912 .764 L .33325 .76309 L 0 1 .52 r
F
.33544 .75869 m .32504 .76077 L .32912 .764 L F
0 g
.32758 .76855 m
.32912 .764 L
s
.33325 .76309 m
.33782 .7661 L
s
.48492 .97983 m .48869 .98306 L .48929 .98149 L 0 1 .529 r
F
.50116 .98028 m .48929 .98149 L .48869 .98306 L 0 1 .517 r
F
0 g
.48869 .98306 m
.49345 .98408 L
s
.48311 .9838 m
.48869 .98306 L
s
.48998 .7143 m
.4904 .71381 L
s
.4904 .71381 m
.49059 .71359 L
s
.49059 .71359 m
.49078 .71338 L
s
.48927 .66316 m .48267 .66405 L .48599 .66443 L 0 1 .39 r
F
.48927 .66316 m .48123 .66189 L .48267 .66405 L F
.48927 .66316 m .48264 .65939 L .48123 .66189 L F
.48927 .66316 m .48592 .65812 L .48264 .65939 L F
.48927 .66316 m .48889 .65891 L .48592 .65812 L F
0 g
.48889 .65891 m
.49197 .65791 L
s
.48927 .66316 m
.49096 .66551 L
s
.48889 .65891 m
.49032 .66107 L
s
.80761 .85911 m .80356 .86924 L .80363 .87677 L 0 1 .501 r
F
0 g
.79657 .88371 m
.80363 .87677 L
s
.51625 .68775 m .51671 .68657 L .51823 .68989 L 0 .121 .105 r
F
0 g
.51671 .68657 m
.51684 .68685 L
s
.51588 .68409 m
.51671 .68657 L
s
.48228 .72144 m
.48347 .72006 L
s
.54618 1.00422 m
.54667 1.00397 L
s
.23208 .73065 m .21993 .7218 L .22081 .73217 L 0 1 .485 r
F
.23208 .73065 m .22268 .71367 L .21993 .7218 L F
.23208 .73065 m .22723 .71323 L .22268 .71367 L F
.23208 .73065 m .23126 .72052 L .22723 .71323 L F
0 g
.22932 .73874 m
.23208 .73065 L
s
.23208 .73065 m
.23606 .73771 L
s
.51612 .59273 m
.51617 .59262 L
s
.51581 .59345 m
.51612 .59273 L
s
.51557 .59402 m
.51581 .59345 L
s
.51541 .59439 m
.51557 .59402 L
s
.51535 .59451 m
.51541 .59439 L
s
.51433 .59566 m
.51473 .59521 L
s
.51473 .59521 m
.51503 .59487 L
s
.51503 .59487 m
.51535 .59451 L
s
.5067 .69708 m
.5067 .69707 L
s
.50669 .69709 m
.5067 .69707 L
s
.53792 .5649 m .54154 .5576 L .54547 .55644 L 0 .148 .102 r
F
0 g
.54154 .5576 m
.54304 .54975 L
s
.55181 1.05709 m .54918 1.06593 L .54787 1.07954 L 0 1 .26 r
F
0 g
.55181 1.05709 m
.55182 1.05709 L
s
.55007 1.0715 m .54918 1.06594 L .55181 1.05711 L 0 0 0 r
F
0 g
.55181 1.05711 m
.55287 1.05667 L
s
.25259 .95057 m
.25391 .95125 L
s
.25391 .95125 m
.26016 .95448 L
s
.35958 .78279 m .35388 .7858 L .3579 .78465 L 0 1 .406 r
F
.35958 .78279 m .34944 .78544 L .35388 .7858 L F
0 g
.35281 .78784 m
.35388 .7858 L
s
.3579 .78465 m
.36273 .78477 L
s
.684 1.07353 m .69074 1.07469 L .69583 1.07405 L 0 .705 .261 r
F
.30392 .94525 m .30187 .94953 L .30549 .94833 L 0 1 .511 r
F
0 g
.30549 .94833 m
.31312 .94935 L
s
.30392 .94525 m .29467 .94804 L .30187 .94953 L 0 1 .511 r
F
0 g
.30187 .94953 m
.30429 .95252 L
s
.26847 .77073 m .25744 .75998 L .25549 .76558 L 0 1 .526 r
F
.26847 .77073 m .26194 .75947 L .25744 .75998 L F
.26847 .77073 m .26667 .76408 L .26194 .75947 L F
.27955 .76891 m .26667 .76408 L .26847 .77073 L 0 1 .525 r
F
0 g
.26652 .7763 m
.26847 .77073 L
s
.26847 .77073 m
.27312 .77509 L
s
.40016 .6138 m
.40154 .61867 L
s
.39693 .62445 m
.40154 .61867 L
s
.36666 .6707 m
.36923 .67567 L
s
.42552 .55361 m .4294 .54589 L .43011 .54097 L 0 1 .331 r
F
0 g
.42515 .55876 m
.42552 .55361 L
s
.48794 .66583 m .48825 .6652 L .48599 .66443 L 0 1 .395 r
F
0 g
.48825 .6652 m
.48908 .6653 L
s
.31905 .79265 m .30777 .78943 L .3065 .79206 L 0 1 .493 r
F
.31905 .79265 m .3119 .78875 L .30777 .78943 L F
.31905 .79265 m .31674 .79013 L .3119 .78875 L F
.32917 .79035 m .31674 .79013 L .31905 .79265 L 0 1 .478 r
F
0 g
.31778 .79527 m
.31905 .79265 L
s
.31905 .79265 m
.32379 .79377 L
s
.50183 .70247 m .49375 .71399 L .49834 .70728 L 0 0 .053 r
F
.50183 .70247 m .49042 .71946 L .49375 .71399 L F
.50183 .70247 m .49058 .72002 L .49042 .71946 L F
.50183 .70247 m .49408 .71519 L .49058 .72002 L F
0 g
.49116 .71358 m
.49397 .70958 L
s
.50183 .70247 m .49859 .70821 L .49408 .71519 L 0 0 .053 r
F
.50183 .70247 m .50191 .70277 L .49859 .70821 L F
0 g
.50183 .70247 m
.50209 .70194 L
s
.49824 .70621 m
.50069 .70258 L
s
.49824 .70621 m
.50027 .70354 L
s
.49999 .70472 m
.50037 .70413 L
s
.50037 .70413 m
.50125 .70277 L
s
.50083 .70384 m
.50139 .70308 L
s
.50139 .70308 m
.50183 .70247 L
s
.50191 .70277 m
.5026 .70143 L
s
.51761 .58931 m .51575 .59368 L .51559 .59347 L 0 0 0 r
F
.51761 .58931 m .51837 .58976 L .51575 .59368 L F
.51761 .58931 m .5217 .58434 L .51837 .58976 L F
.51761 .58931 m .52372 .5802 L .5217 .58434 L F
.34411 .69291 m .3335 .69452 L .3364 .69998 L 0 1 .444 r
F
0 g
.3335 .70652 m
.3364 .69998 L
s
.45956 .73988 m .44783 .74798 L .44883 .74726 L 0 0 0 r
F
.45956 .73988 m .45038 .74639 L .44783 .74798 L F
.45956 .73988 m .45479 .74354 L .45038 .74639 L F
.45956 .73988 m .45872 .74075 L .45479 .74354 L F
0 g
.45956 .73988 m
.46029 .73926 L
s
.457 .74147 m
.45956 .73988 L
s
.72453 .90912 m .72239 .91983 L .72905 .91438 L 0 1 .494 r
F
0 g
.72073 .9237 m
.72239 .91983 L
s
.48794 .66583 m .48173 .66585 L .48515 .66611 L 0 1 .395 r
F
.48794 .66583 m .47947 .66509 L .48173 .66585 L F
.48794 .66583 m .47988 .66433 L .47947 .66509 L F
.48794 .66583 m .48267 .66405 L .47988 .66433 L F
.48794 .66583 m .48599 .66443 L .48267 .66405 L F
0 g
.48599 .66443 m
.48825 .6652 L
s
.48794 .66583 m
.48924 .66647 L
s
.48599 .66443 m
.486 .66443 L
s
.486 .66443 m
.48927 .66316 L
s
.48236 .67961 m .47452 .68249 L .47872 .68167 L 0 1 .408 r
F
.48236 .67961 m .47202 .68141 L .47452 .68249 L F
0 g
.47872 .68167 m
.48147 .68246 L
s
.48236 .67961 m .47289 .67913 L .47202 .68141 L 0 1 .408 r
F
.48236 .67961 m .47654 .67707 L .47289 .67913 L F
.48236 .67961 m .48052 .6766 L .47654 .67707 L F
.48236 .67961 m .48301 .67769 L .48052 .6766 L F
0 g
.48236 .67961 m
.48501 .68059 L
s
.47872 .68167 m
.48236 .67961 L
s
.48301 .67769 m
.48649 .67614 L
s
.65604 .56549 m .65925 .54539 L .65555 .54052 L 0 .548 .271 r
F
0 g
.65555 .54052 m
.65567 .54645 L
s
.655 .53797 m
.65555 .54052 L
s
.52585 .68274 m .52663 .67939 L .52934 .68019 L 0 .2 .13 r
F
.52585 .68274 m .52957 .69762 L .52711 .69054 L F
.52381 .6906 m .52464 .68754 L .52711 .69054 L 0 .224 .135 r
F
.52381 .6906 m .52711 .69054 L .52957 .69762 L F
.52568 .70627 m .5309 .6133 L .52862 .6159 L 0 .83 .256 r
F
.52568 .70627 m .53151 .64078 L .5309 .6133 L F
0 g
.5309 .6133 m
.53369 .58124 L
s
.5309 .6133 m
.53104 .61966 L
s
.22081 .73217 m .2086 .72305 L .20954 .73365 L 0 1 .488 r
F
.22081 .73217 m .21131 .71475 L .2086 .72305 L F
.22081 .73217 m .21586 .71432 L .21131 .71475 L F
.22081 .73217 m .21993 .7218 L .21586 .71432 L F
0 g
.2181 .74042 m
.22081 .73217 L
s
.22081 .73217 m
.22483 .73942 L
s
.49045 .44628 m .49703 .43852 L .50173 .43555 L 0 0 .043 r
F
0 g
.49703 .43852 m
.5007 .43224 L
s
.52411 .42195 m .53683 .41638 L .53747 .4222 L 0 .174 .091 r
F
0 g
.53683 .41638 m
.54152 .40858 L
s
.53112 .41628 m
.53683 .41638 L
s
.44519 .72493 m .43759 .73049 L .44211 .72839 L 0 1 .465 r
F
0 g
.44211 .72839 m
.44602 .72867 L
s
.53441 .97665 m
.53531 .97656 L
s
.50179 .73625 m
.5028 .73364 L
s
.43811 .75383 m .42833 .75863 L .42605 .76005 L 0 .799 .185 r
F
.43811 .75383 m .43274 .75642 L .42833 .75863 L F
.43811 .75383 m .43693 .75436 L .43274 .75642 L F
.44883 .74726 m .43693 .75436 L .43811 .75383 L 0 0 0 r
F
0 g
.43582 .75525 m
.43811 .75383 L
s
.43811 .75383 m
.44217 .75142 L
s
.48614 .66982 m .48704 .66782 L .48515 .66612 L 0 1 .398 r
F
0 g
.48704 .66782 m
.48952 .66717 L
s
.51113 .72559 m .51066 .72461 L .50946 .73443 L 0 .605 .295 r
F
0 g
.51066 .72461 m
.51117 .71079 L
s
.21221 .79898 m .20636 .80423 L .21075 .80362 L 0 1 .538 r
F
.21221 .79898 m .20115 .80026 L .20636 .80423 L F
0 g
.20595 .80898 m
.20636 .80423 L
s
.21075 .80362 m
.21681 .80723 L
s
.52259 .97935 m
.52356 .97904 L
s
.52356 .97904 m
.52372 .97898 L
s
.52372 .97898 m
.52437 .97877 L
s
.52437 .97877 m
.52478 .97863 L
s
.52478 .97863 m
.52542 .97842 L
s
.52542 .97842 m
.52729 .97781 L
s
.48614 .66982 m .47895 .67153 L .48268 .67141 L 0 1 .398 r
F
.48614 .66982 m .47706 .66983 L .47895 .67153 L F
.48614 .66982 m .47826 .66744 L .47706 .66983 L F
.48614 .66982 m .48173 .66585 L .47826 .66744 L F
.48614 .66982 m .48515 .66612 L .48173 .66585 L F
0 g
.48515 .66611 m
.48517 .66611 L
s
.48517 .66611 m
.48794 .66583 L
s
.48614 .66982 m
.48825 .6716 L
s
.48515 .66612 m
.48704 .66782 L
s
.47554 1.06903 m .48058 1.07616 L .48137 1.07388 L 0 1 .501 r
F
.49715 1.07789 m .48137 1.07388 L .48058 1.07616 L 0 1 .509 r
F
0 g
.48058 1.07616 m
.48692 1.08062 L
s
.47319 1.07459 m
.48058 1.07616 L
s
.48409 .67477 m .47654 .67707 L .48052 .6766 L 0 1 .404 r
F
.48409 .67477 m .47433 .67568 L .47654 .67707 L F
0 g
.48052 .6766 m
.48301 .67769 L
s
.48409 .67477 m .47538 .67336 L .47433 .67568 L 0 1 .404 r
F
.48409 .67477 m .47895 .67153 L .47538 .67336 L F
.48409 .67477 m .48268 .67141 L .47895 .67153 L F
.48409 .67477 m .48488 .6728 L .48268 .67141 L F
0 g
.48268 .67141 m
.48614 .66982 L
s
.48409 .67477 m
.48649 .67614 L
s
.48052 .6766 m
.48409 .67477 L
s
.48488 .6728 m
.48825 .6716 L
s
.5429 .68276 m
.54622 .69436 L
s
.53457 .6699 m
.53617 .66741 L
s
.45621 .71707 m
.4594 .71367 L
s
.60123 .42049 m .59959 .42936 L .59759 .42435 L 0 .351 .082 r
F
.60123 .42049 m .60657 .43399 L .59959 .42936 L F
.60123 .42049 m .61385 .43514 L .60657 .43399 L F
.60123 .42049 m .61746 .43125 L .61385 .43514 L F
0 g
.59457 .41603 m
.60123 .42049 L
s
.34584 .7565 m .33945 .7617 L .34359 .76075 L 0 1 .519 r
F
.34584 .7565 m .33544 .75869 L .33945 .7617 L F
0 g
.33782 .7661 m
.33945 .7617 L
s
.34359 .76075 m
.34806 .76354 L
s
.48268 .67141 m
.48488 .6728 L
s
.74457 .92395 m .74858 .93041 L .75441 .927 L 0 1 .522 r
F
0 g
.7414 .93187 m
.74858 .93041 L
s
.74703 .934 m
.74858 .93041 L
s
.5082 .49274 m .50368 .4993 L .504 .50104 L 0 .804 .092 r
F
0 g
.5082 .49274 m
.5082 .49274 L
s
.5082 .49274 m .50775 .48906 L .50368 .4993 L 0 .804 .092 r
F
.5082 .49274 m .51348 .4772 L .50775 .48906 L F
.47651 .7814 m .47291 .79325 L .47573 .78849 L 0 .739 .343 r
F
.48121 .793 m .47291 .79325 L .47253 .80059 L 0 .692 .342 r
F
.48121 .793 m .47573 .78849 L .47291 .79325 L F
0 g
.4692 .79299 m
.47291 .79325 L
s
.44883 .74726 m .43935 .75289 L .43693 .75436 L 0 0 0 r
F
.44883 .74726 m .44376 .7504 L .43935 .75289 L F
.44883 .74726 m .44783 .74798 L .44376 .7504 L F
0 g
.44883 .74726 m
.45276 .74447 L
s
.50039 .73984 m .49962 .73729 L .49692 .74124 L 0 .648 .306 r
F
0 g
.49962 .73729 m
.50116 .7281 L
s
.78638 .88394 m .79743 .87693 L .79329 .87709 L 0 1 .51 r
F
.77618 .88449 m .78638 .88394 L .78708 .87744 L 0 1 .507 r
F
.20954 .73365 m .19727 .72427 L .19828 .73511 L 0 1 .49 r
F
0 g
.19828 .73511 m
.20239 .74273 L
s
.20954 .73365 m .19993 .7158 L .19727 .72427 L 0 1 .49 r
F
.20954 .73365 m .20449 .71538 L .19993 .7158 L F
.20954 .73365 m .2086 .72305 L .20449 .71538 L F
0 g
.20688 .74207 m
.20954 .73365 L
s
.20954 .73365 m
.21361 .74109 L
s
.50039 .73984 m .49692 .74124 L .49409 .74907 L 0 .648 .306 r
F
0 g
.49692 .74124 m
.49851 .73338 L
s
.49692 .74124 m
.49962 .73729 L
s
.51106 .69697 m
.51177 .69266 L
s
.51104 .69706 m
.51106 .69697 L
s
.51103 .69713 m
.51104 .69706 L
s
.51177 .69266 m
.51177 .69266 L
s
.50775 .48906 m .51787 .46832 L .51803 .46831 L 0 0 0 r
F
.50775 .48906 m .51348 .4772 L .51787 .46832 L F
0 g
.51787 .46832 m
.52201 .4585 L
s
.51348 .4772 m
.51787 .46832 L
s
.50722 .69699 m
.50722 .69698 L
s
.50721 .69702 m
.50722 .69698 L
s
.37857 .6617 m
.38253 .65577 L
s
.44519 .72493 m .43384 .72998 L .43759 .73049 L 0 1 .465 r
F
0 g
.43482 .7341 m
.43759 .73049 L
s
.49117 .75231 m .48241 .76385 L .48383 .76803 L 0 .692 .319 r
F
0 g
.47897 .76446 m
.48241 .76385 L
s
.48241 .76385 m
.48374 .75635 L
s
.31335 .9377 m .31114 .93981 L .31477 .93857 L 0 .818 .246 r
F
0 g
.31477 .93857 m
.32223 .93732 L
s
.31335 .9377 m .30408 .94055 L .31114 .93981 L 0 .818 .246 r
F
0 g
.31114 .93981 m
.31339 .94064 L
s
.49736 .63532 m .49917 .63244 L .49957 .62906 L 0 1 .321 r
F
0 g
.49917 .63244 m
.50148 .63249 L
s
.39503 .63154 m .38619 .63787 L .39043 .63729 L 0 1 .41 r
F
.39503 .63154 m .38455 .63296 L .38619 .63787 L F
0 g
.39043 .63729 m
.39256 .64217 L
s
.39503 .63154 m .38661 .62583 L .38455 .63296 L 0 1 .41 r
F
.39503 .63154 m .39122 .62008 L .38661 .62583 L F
.39503 .63154 m .3953 .61954 L .39122 .62008 L F
.39503 .63154 m .39693 .62445 L .3953 .61954 L F
0 g
.39043 .63729 m
.39503 .63154 L
s
.76162 .75616 m .76699 .76168 L .77164 .76493 L 0 .116 .169 r
F
0 g
.76699 .76168 m
.76847 .76562 L
s
.50736 .69705 m
.5074 .69692 L
s
.5074 .69693 m
.5074 .69692 L
s
.51625 .68775 m .51785 .70053 L .51674 .69372 L 0 .121 .105 r
F
.51625 .68775 m .51938 .70387 L .51785 .70053 L F
.51625 .68775 m .5203 .7015 L .51938 .70387 L F
.51625 .68775 m .5198 .6955 L .5203 .7015 L F
.51625 .68775 m .51823 .68989 L .5198 .6955 L F
0 g
.51508 .68614 m
.51625 .68775 L
s
.51738 .68475 m
.51806 .68886 L
s
.51806 .68886 m
.51823 .68989 L
s
.51684 .68685 m
.51823 .68989 L
s
.7347 .92079 m .72936 .92355 L .72821 .92674 L 0 1 .516 r
F
0 g
.72074 .92766 m
.72821 .92674 L
s
.27955 .76891 m .26869 .75868 L .26667 .76408 L 0 1 .525 r
F
.27955 .76891 m .27319 .75815 L .26869 .75868 L F
.27955 .76891 m .27785 .76254 L .27319 .75815 L F
.29063 .76704 m .27785 .76254 L .27955 .76891 L F
0 g
.27752 .77428 m
.27955 .76891 L
s
.27955 .76891 m
.28412 .77305 L
s
.51113 .72559 m .51028 .7528 L .51096 .73766 L 0 .605 .295 r
F
.51113 .72559 m .50908 .76266 L .51028 .7528 L F
.51113 .72559 m .50815 .76063 L .50908 .76266 L F
.51113 .72559 m .50831 .74852 L .50815 .76063 L F
.51113 .72559 m .50946 .73443 L .50831 .74852 L F
0 g
.50799 .73086 m
.50933 .72306 L
s
.50946 .73443 m
.50998 .72305 L
s
.51113 .72559 m
.51198 .71249 L
s
.5103 .72757 m
.51066 .72461 L
s
.50799 .73086 m
.50886 .72019 L
s
.40651 .596 m
.40738 .60091 L
s
.40256 .6067 m
.40738 .60091 L
s
.48121 .793 m .47253 .80059 L .47484 .80562 L 0 .692 .342 r
F
0 g
.47253 .80059 m
.47291 .79325 L
s
.46869 .79996 m
.47253 .80059 L
s
.3335 .69452 m .32579 .70165 L .33003 .701 L 0 1 .45 r
F
0 g
.33003 .701 m
.3335 .70652 L
s
.71823 .57898 m
.72389 .57206 L
s
.72389 .57206 m .72998 .58735 L .72559 .58448 L 0 .425 .1 r
F
.72389 .57206 m .73501 .58104 L .72998 .58735 L F
0 g
.4683 .69787 m
.47099 .69804 L
s
.53262 .70411 m
.53267 .70427 L
s
.53262 .70411 m
.53267 .70412 L
s
.44519 .72493 m .43335 .7272 L .43384 .72998 L 0 1 .465 r
F
.44519 .72493 m .43644 .72374 L .43335 .7272 L F
.44519 .72493 m .44103 .72189 L .43644 .72374 L F
.44519 .72493 m .44478 .72241 L .44103 .72189 L F
0 g
.44519 .72493 m
.44889 .72508 L
s
.44211 .72839 m
.44519 .72493 L
s
.46613 .98185 m .45945 .9806 L .45338 .98094 L 0 1 .538 r
F
.46897 .97779 m .46613 .98185 L .4719 .98157 L 0 1 .534 r
F
.46897 .97779 m .45945 .9806 L .46613 .98185 L F
0 g
.46613 .98185 m
.47038 .98411 L
s
.48383 .76803 m .47651 .7814 L .47996 .78079 L 0 .714 .331 r
F
.79115 .78235 m .80132 .78577 L .79675 .78302 L 0 .468 .352 r
F
.79115 .78235 m .80246 .78944 L .80132 .78577 L F
.35625 .75417 m .34979 .75928 L .35393 .75827 L 0 1 .517 r
F
.35625 .75417 m .34584 .7565 L .34979 .75928 L F
0 g
.34806 .76354 m
.34979 .75928 L
s
.35393 .75827 m
.35832 .76085 L
s
.46734 .70307 m .45918 .70811 L .46379 .70612 L 0 1 .436 r
F
.46734 .70307 m .45584 .70783 L .45918 .70811 L F
.46734 .70307 m .45599 .70547 L .45584 .70783 L F
0 g
.46379 .70612 m
.4673 .70614 L
s
.46734 .70307 m .45954 .70242 L .45599 .70547 L 0 1 .436 r
F
.46734 .70307 m .46412 .70071 L .45954 .70242 L F
.46734 .70307 m .46747 .70099 L .46412 .70071 L F
0 g
.46734 .70307 m
.46812 .70305 L
s
.46379 .70612 m
.46734 .70307 L
s
.46747 .70099 m
.47099 .69804 L
s
.51095 .69382 m
.51095 .69382 L
s
.51433 .59566 m
.51434 .59573 L
s
.51332 .59051 m
.51433 .59566 L
s
.51332 .59051 m
.51342 .58961 L
s
.71741 .92105 m
.71868 .92025 L
s
.71374 .92338 m
.71383 .92332 L
s
.71383 .92332 m
.71741 .92105 L
s
.70244 .9261 m .71154 .92477 L .7131 .92103 L 0 1 .473 r
F
0 g
.71154 .92477 m
.71374 .92338 L
s
.7127 .92123 m
.71277 .92109 L
s
.71376 .92333 m
.71383 .92332 L
s
.71208 .92348 m
.71376 .92333 L
s
.34411 .69291 m .33389 .68653 L .3335 .69452 L 0 1 .444 r
F
.34411 .69291 m .33736 .68015 L .33389 .68653 L F
.34411 .69291 m .34159 .67965 L .33736 .68015 L F
.34411 .69291 m .34448 .68512 L .34159 .67965 L F
0 g
.34411 .69291 m
.347 .69818 L
s
.34064 .69927 m
.34411 .69291 L
s
.47484 .80562 m .47232 .81731 L .47475 .81279 L 0 .717 .354 r
F
.48088 .81812 m .47232 .81731 L .47266 .82468 L 0 .663 .351 r
F
.48088 .81812 m .47475 .81279 L .47232 .81731 L F
0 g
.46849 .81668 m
.47232 .81731 L
s
.43384 .72998 m .4263 .73538 L .43081 .73348 L 0 1 .477 r
F
0 g
.43081 .73348 m
.43482 .7341 L
s
.50801 .69665 m
.50801 .69663 L
s
.508 .69668 m
.50801 .69663 L
s
.30175 .71156 m
.30175 .71156 L
s
.42552 .55361 m .4169 .56103 L .42016 .5601 L 0 1 .331 r
F
.42552 .55361 m .41761 .55611 L .4169 .56103 L F
0 g
.42176 .56114 m
.42258 .56057 L
s
.42258 .56057 m
.42514 .55876 L
s
.42552 .55361 m .42183 .5486 L .41761 .55611 L 0 1 .331 r
F
.42552 .55361 m .42719 .54211 L .42183 .5486 L F
.42552 .55361 m .43011 .54097 L .42719 .54211 L F
0 g
.42016 .5601 m
.42552 .55361 L
s
.43011 .54097 m
.43548 .53406 L
s
.4294 .54589 m
.43011 .54097 L
s
.47872 .85439 m .47857 .86562 L .48014 .86158 L 0 .649 .373 r
F
.48762 .86825 m .47857 .86562 L .48042 .87295 L 0 .577 .368 r
F
.48762 .86825 m .48014 .86158 L .47857 .86562 L F
0 g
.47447 .86431 m
.47857 .86562 L
s
.54087 .99532 m
.54107 .99522 L
s
.54111 .9952 m
.54199 .99475 L
s
.48446 .8787 m .48553 .88964 L .48666 .88586 L 0 .601 .38 r
F
0 g
.48132 .88804 m
.48553 .88964 L
s
.48553 .88964 m
.48683 .89325 L
s
.41288 .9709 m .41368 .9758 L .41585 .97424 L 0 1 .538 r
F
.41288 .9709 m .40718 .9747 L .41368 .9758 L F
.42891 .97733 m .41585 .97424 L .41368 .9758 L 0 1 .539 r
F
0 g
.41368 .9758 m
.41724 .97889 L
s
.50496 .61448 m .50733 .61064 L .50887 .60693 L 0 1 .173 r
F
0 g
.50733 .61064 m
.50936 .60988 L
s
.5688 .4179 m
.57241 .42094 L
s
.57241 .42094 m
.57302 .42145 L
s
.40718 .9747 m .3939 .97047 L .39138 .97194 L 0 1 .539 r
F
.40718 .9747 m .40067 .97166 L .3939 .97047 L F
.41288 .9709 m .40067 .97166 L .40718 .9747 L 0 1 .538 r
F
0 g
.40718 .9747 m
.41368 .9758 L
s
.40718 .9747 m
.41043 .97818 L
s
.67723 1.07243 m .67481 1.07367 L .684 1.07353 L 0 .667 .252 r
F
0 g
.6665 1.07326 m
.67481 1.07367 L
s
.66977 1.07431 m
.67481 1.07367 L
s
.49672 .53081 m .50482 .50765 L .50449 .50462 L 0 1 .173 r
F
.49672 .53081 m .5015 .51886 L .50482 .50765 L F
0 g
.50482 .50765 m
.50866 .49981 L
s
.5029 .51414 m
.50482 .50765 L
s
.47554 .83 m .47418 .84148 L .47619 .8372 L 0 .687 .364 r
F
.483 .84323 m .47418 .84148 L .47526 .84884 L 0 .625 .36 r
F
.483 .84323 m .47619 .8372 L .47418 .84148 L F
0 g
.47021 .84049 m
.47418 .84148 L
s
.39521 1.01685 m .37685 1.00877 L .38013 1.01485 L 0 1 .495 r
F
.48121 .793 m .47928 .78838 L .47573 .78849 L 0 .692 .342 r
F
0 g
.47573 .78849 m
.47651 .7814 L
s
.52149 .96406 m
.52198 .96477 L
s
.51692 .9504 m .51721 .95791 L .52161 .96045 L 0 .374 .367 r
F
0 g
.51721 .95791 m
.52149 .96406 L
s
.74393 .90641 m .75491 .90041 L .75096 .90076 L 0 1 .509 r
F
.73423 .90751 m .74393 .90641 L .74504 .90142 L 0 1 .503 r
F
.39521 1.01685 m .39565 1.02473 L .39848 1.02293 L 0 1 .495 r
F
.41399 1.03183 m .39848 1.02293 L .39565 1.02473 L 0 1 .498 r
F
0 g
.39565 1.02473 m
.39963 1.03054 L
s
.38779 1.02127 m
.39565 1.02473 L
s
.48762 .86825 m .48042 .87295 L .48446 .8787 L 0 .577 .368 r
F
0 g
.47857 .86562 m
.48042 .87295 L
s
.47621 .87136 m
.48042 .87295 L
s
.5175 .97912 m .51096 .97978 L .50591 .9813 L 0 1 .486 r
F
.48088 .81812 m .47266 .82468 L .47554 .83 L 0 .663 .351 r
F
0 g
.47232 .81731 m
.47266 .82468 L
s
.46869 .82371 m
.47266 .82468 L
s
.36974 .77998 m .36394 .78289 L .36796 .78168 L 0 1 .369 r
F
.36974 .77998 m .35958 .78279 L .36394 .78289 L F
0 g
.36273 .78477 m
.36394 .78289 L
s
.36796 .78168 m
.37267 .78154 L
s
.51016 .6948 m
.51016 .6948 L
s
.51009 .69507 m
.51016 .6948 L
s
.51002 .69534 m
.51009 .69507 L
s
.51016 .6948 m
.51016 .69479 L
s
.29483 .94343 m .27737 .94412 L .27924 .94548 L 0 .987 .289 r
F
.29483 .94343 m .28125 .94317 L .27737 .94412 L F
.29483 .94343 m .28874 .94288 L .28125 .94317 L F
.30408 .94055 m .28874 .94288 L .29483 .94343 L 0 .877 .256 r
F
0 g
.29483 .94343 m
.29666 .94479 L
s
.29483 .94343 m
.30209 .94292 L
s
.3335 .69452 m .3229 .69599 L .32579 .70165 L 0 1 .45 r
F
0 g
.32292 .7083 m
.32579 .70165 L
s
.483 .84323 m .47526 .84884 L .47872 .85439 L 0 .625 .36 r
F
0 g
.47418 .84148 m
.47526 .84884 L
s
.47117 .84755 m
.47526 .84884 L
s
.50866 .69626 m
.50868 .69619 L
s
.50863 .69635 m
.50868 .69619 L
s
.43384 .72998 m .42248 .73454 L .4263 .73538 L 0 1 .477 r
F
0 g
.42361 .73903 m
.4263 .73538 L
s
.49117 .75231 m .48702 .7663 L .48985 .75981 L 0 .692 .319 r
F
.49117 .75231 m .48383 .76803 L .48702 .7663 L F
.29063 .76704 m .27994 .75734 L .27785 .76254 L 0 1 .525 r
F
.29063 .76704 m .28445 .75678 L .27994 .75734 L F
.29063 .76704 m .28903 .76095 L .28445 .75678 L F
0 g
.28853 .77221 m
.29063 .76704 L
s
.30426 .76465 m .28903 .76095 L .29063 .76704 L 0 1 .524 r
F
0 g
.29063 .76704 m
.29589 .7708 L
s
.49478 .8931 m .48815 .89692 L .49277 .90285 L 0 .517 .372 r
F
0 g
.48527 .89566 m
.48815 .89692 L
s
.48708 .89394 m
.48815 .89692 L
s
.36666 .75168 m .36014 .75672 L .36428 .75565 L 0 1 .514 r
F
.36666 .75168 m .35625 .75417 L .36014 .75672 L F
0 g
.35832 .76085 m
.36014 .75672 L
s
.36428 .75565 m
.36857 .758 L
s
.5094 .69559 m
.5094 .69558 L
s
.50039 .73984 m .49669 .75698 L .49914 .74828 L 0 .648 .306 r
F
.50039 .73984 m .49399 .76094 L .49669 .75698 L F
.50039 .73984 m .49283 .75751 L .49399 .76094 L F
0 g
.49117 .75231 m
.49242 .75092 L
s
.50039 .73984 m .49409 .74907 L .49283 .75751 L 0 .648 .306 r
F
0 g
.50039 .73984 m
.50179 .73625 L
s
.49242 .75092 m
.49409 .74907 L
s
.32917 .79035 m .31811 .78771 L .31674 .79013 L 0 1 .478 r
F
.32917 .79035 m .32225 .78699 L .31811 .78771 L F
.32917 .79035 m .32699 .78813 L .32225 .78699 L F
.3393 .78795 m .32699 .78813 L .32917 .79035 L 0 1 .459 r
F
0 g
.32779 .79276 m
.32917 .79035 L
s
.32917 .79035 m
.33381 .79122 L
s
.49738 .88639 m
.49744 .88636 L
s
.49744 .88636 m
.50002 .88405 L
s
.50002 .88405 m
.50044 .88368 L
s
.5123 .72779 m .51183 .72695 L .51096 .73766 L 0 .599 .294 r
F
0 g
.51183 .72695 m
.51198 .7125 L
s
.75576 .88676 m .75491 .90041 L .76133 .89385 L 0 1 .5 r
F
.75576 .88676 m .75096 .90076 L .75491 .90041 L F
0 g
.7536 .90576 m
.75491 .90041 L
s
.22328 .79769 m .21734 .80271 L .22173 .8021 L 0 1 .537 r
F
.22328 .79769 m .21221 .79898 L .21734 .80271 L F
0 g
.21681 .80723 m
.21734 .80271 L
s
.22173 .8021 m
.22768 .80548 L
s
.52411 .42195 m .51911 .43405 L .51896 .42956 L 0 .174 .091 r
F
.52411 .42195 m .52485 .43416 L .51911 .43405 L F
.52411 .42195 m .53234 .42983 L .52485 .43416 L F
.52411 .42195 m .53747 .4222 L .53234 .42983 L F
0 g
.51873 .42248 m
.52411 .42195 L
s
.77404 .9328 m .7858 .93158 L .78181 .93055 L 0 1 .532 r
F
.76424 .92994 m .77404 .9328 L .77582 .92899 L 0 1 .529 r
F
.36666 .6707 m .35852 .67736 L .36275 .67672 L 0 1 .431 r
F
0 g
.36275 .67672 m
.36565 .6818 L
s
.33643 .95706 m .33496 .96296 L .3383 .96166 L 0 1 .536 r
F
.33643 .95706 m .32785 .96016 L .33496 .96296 L F
0 g
.33496 .96296 m
.33761 .9674 L
s
.53457 .6699 m
.53599 .67516 L
s
.39126 .96677 m .39138 .97194 L .3939 .97047 L 0 1 .538 r
F
.39126 .96677 m .38472 .97031 L .39138 .97194 L F
0 g
.39138 .97194 m
.39464 .97542 L
s
.49277 .90285 m .49508 .9135 L .49574 .90996 L 0 .54 .384 r
F
.50447 .91776 m .49508 .9135 L .49845 .92073 L 0 .443 .371 r
F
0 g
.4941 .91847 m
.49845 .92073 L
s
.49845 .92073 m
.49845 .92073 L
s
.50447 .91776 m .49574 .90996 L .49508 .9135 L 0 .443 .371 r
F
0 g
.49077 .91161 m
.49508 .9135 L
s
.46963 .73245 m
.47168 .73086 L
s
.33676 .94516 m .32001 .94362 L .32197 .94621 L 0 1 .498 r
F
.33676 .94516 m .32365 .94245 L .32001 .94362 L F
.33676 .94516 m .33084 .94312 L .32365 .94245 L F
0 g
.33676 .94516 m
.33869 .94775 L
s
.34732 .94111 m .33084 .94312 L .33676 .94516 L 0 1 .482 r
F
0 g
.33676 .94516 m
.34428 .9454 L
s
.51896 1.08303 m .51003 1.08912 L .51932 1.09187 L 0 1 .533 r
F
.51896 1.08303 m .50325 1.08505 L .51003 1.08912 L F
.42248 .73454 m .415 .73982 L .41952 .7381 L 0 1 .486 r
F
0 g
.41952 .7381 m
.42361 .73903 L
s
.47989 .7242 m .47244 .73028 L .47685 .72641 L 0 0 0 r
F
0 g
.47685 .72641 m
.47849 .7248 L
s
.50206 .70316 m .49408 .71519 L .49859 .70821 L 0 0 .056 r
F
.50206 .70316 m .49088 .72082 L .49408 .71519 L F
.50206 .70316 m .49113 .72132 L .49088 .72082 L F
.50206 .70316 m .49462 .71624 L .49113 .72132 L F
0 g
.49061 .71436 m
.49116 .71358 L
s
.50206 .70316 m .499 .70899 L .49462 .71624 L 0 0 .056 r
F
.50206 .70316 m .50219 .70339 L .499 .70899 L F
0 g
.50206 .70316 m
.5029 .70138 L
s
.49834 .70728 m
.49999 .70472 L
s
.49834 .70728 m
.49959 .70555 L
s
.49959 .70555 m
.49969 .70542 L
s
.49969 .70542 m
.50083 .70384 L
s
.50105 .70417 m
.50191 .70277 L
s
.50083 .70454 m
.50105 .70417 L
s
.50103 .70467 m
.50206 .70316 L
s
.50219 .70339 m
.50556 .69658 L
s
.53792 .5649 m .54547 .55644 L .5471 .56221 L 0 .148 .102 r
F
0 g
.54547 .55644 m
.54684 .54502 L
s
.54154 .5576 m
.54547 .55644 L
s
.37755 .74889 m .37064 .75396 L .37496 .75277 L 0 1 .511 r
F
.37755 .74889 m .36666 .75168 L .37064 .75396 L F
0 g
.36858 .758 m
.37064 .75396 L
s
.37496 .75277 m
.3793 .75484 L
s
.49736 .63532 m .49296 .63542 L .4947 .6366 L 0 1 .321 r
F
.49736 .63532 m .49336 .63204 L .49296 .63542 L F
.49736 .63532 m .49563 .62872 L .49336 .63204 L F
.49736 .63532 m .49829 .62745 L .49563 .62872 L F
.49736 .63532 m .49957 .62906 L .49829 .62745 L F
0 g
.49729 .63922 m
.49736 .63532 L
s
.49957 .62906 m
.50193 .628 L
s
.49917 .63244 m
.49957 .62906 L
s
.45589 .71365 m .44792 .71897 L .45251 .71692 L 0 1 .453 r
F
0 g
.45251 .71692 m
.45621 .71707 L
s
.60343 .58036 m .6067 .56495 L .61196 .56785 L 0 .633 .172 r
F
0 g
.6067 .56495 m
.61129 .56748 L
s
.41148 .92754 m .41085 .93012 L .41338 .92857 L 0 1 .369 r
F
.41148 .92754 m .4049 .93125 L .41085 .93012 L F
0 g
.41085 .93012 m
.41332 .93097 L
s
.42248 .73454 m .41113 .73868 L .415 .73982 L 0 1 .486 r
F
0 g
.41241 .74353 m
.415 .73982 L
s
.48383 .76803 m .47996 .78079 L .48278 .77529 L 0 .714 .331 r
F
0 g
.49355 .71139 m
.49371 .71116 L
s
.49297 .71226 m
.49355 .71139 L
s
.49292 .71212 m
.49371 .71116 L
s
.49271 .71239 m
.49292 .71212 L
s
.51509 .69054 m .51556 .68945 L .51674 .69372 L 0 .124 .104 r
F
0 g
.51508 .68614 m
.51556 .68945 L
s
.45589 .71365 m .44439 .71858 L .44792 .71897 L 0 1 .453 r
F
.45589 .71365 m .44427 .71601 L .44439 .71858 L F
.45589 .71365 m .44764 .71274 L .44427 .71601 L F
.45589 .71365 m .45226 .71095 L .44764 .71274 L F
.45589 .71365 m .45579 .71134 L .45226 .71095 L F
0 g
.45589 .71365 m
.4594 .71367 L
s
.45251 .71692 m
.45589 .71365 L
s
.5123 .72779 m .51229 .75669 L .51249 .74052 L 0 .599 .294 r
F
.5123 .72779 m .51142 .76745 L .51229 .75669 L F
.5123 .72779 m .51048 .76558 L .51142 .76745 L F
.5123 .72779 m .51028 .7528 L .51048 .76558 L F
.5123 .72779 m .51096 .73766 L .51028 .7528 L F
0 g
.50946 .73443 m
.5103 .72757 L
s
.51096 .73766 m
.51183 .72695 L
s
.5123 .72779 m
.5128 .71395 L
s
.51096 .73766 m
.51113 .72559 L
s
.4905 .71452 m .48268 .72224 L .48721 .71751 L 0 0 .027 r
F
.4905 .71452 m .47912 .72644 L .48268 .72224 L F
.4905 .71452 m .47891 .7273 L .47912 .72644 L F
0 g
.47685 .72641 m
.47813 .72548 L
s
.4905 .71452 m .48221 .7243 L .47891 .7273 L 0 0 .027 r
F
0 g
.47813 .72548 m
.47901 .72485 L
s
.4905 .71452 m .48681 .71944 L .48221 .7243 L 0 0 .027 r
F
0 g
.48016 .72389 m
.48228 .72144 L
s
.4905 .71452 m .49036 .71525 L .48681 .71944 L 0 0 .027 r
F
0 g
.48721 .71751 m
.48998 .7143 L
s
.4905 .71452 m
.49061 .71436 L
s
.49034 .71615 m
.49038 .71609 L
s
.49038 .71609 m
.49085 .71539 L
s
.49036 .71525 m
.49064 .71491 L
s
.48721 .71751 m
.48993 .71504 L
s
.48993 .71504 m
.49023 .71477 L
s
.49023 .71477 m
.4905 .71452 L
s
.42891 .97733 m .42239 .9749 L .41585 .97424 L 0 1 .539 r
F
.43371 .97336 m .42891 .97733 L .43516 .97794 L F
.43371 .97336 m .42239 .9749 L .42891 .97733 L F
0 g
.42891 .97733 m
.43245 .98042 L
s
.72453 .90912 m .72905 .91438 L .73423 .90751 L 0 1 .494 r
F
0 g
.72796 .91934 m
.72905 .91438 L
s
.72239 .91983 m
.72905 .91438 L
s
.45434 1.0581 m .44602 1.05327 L .43839 1.05114 L 0 1 .5 r
F
0 g
.43839 1.05114 m
.44602 1.05327 L
s
.38433 .93419 m .38328 .93721 L .38613 .93577 L 0 1 .429 r
F
.38433 .93419 m .37697 .93763 L .38328 .93721 L F
0 g
.38328 .93721 m
.38571 .93864 L
s
.63418 .44357 m
.63426 .44353 L
s
.41113 .73868 m .40371 .74387 L .40823 .7423 L 0 1 .494 r
F
0 g
.40823 .7423 m
.41241 .74353 L
s
.3229 .69599 m .31518 .7032 L .31942 .70259 L 0 1 .456 r
F
0 g
.31942 .70259 m
.32292 .7083 L
s
.42064 .56346 m .42176 .56114 L .42016 .5601 L 0 1 .37 r
F
0 g
.42065 .56346 m
.42242 .56461 L
s
.38843 .74587 m .38146 .75091 L .38579 .74963 L 0 1 .507 r
F
.38843 .74587 m .37755 .74889 L .38146 .75091 L F
0 g
.3793 .75484 m
.38146 .75091 L
s
.38579 .74963 m
.39003 .75146 L
s
.25085 .94454 m .24836 .95135 L .25221 .95037 L 0 1 .535 r
F
.25077 .94641 m .24836 .95135 L .25221 .95037 L 0 1 .527 r
F
.25085 .94454 m .24103 .94682 L .24836 .95135 L 0 1 .535 r
F
.25077 .94641 m .24095 .94865 L .24836 .95135 L 0 1 .527 r
F
0 g
.24253 .95265 m
.24258 .95282 L
s
.24257 .95279 m
.24258 .95282 L
s
.2507 .94827 m .24836 .95135 L .25221 .95037 L 0 1 .358 r
F
0 g
.25221 .95037 m
.25225 .95037 L
s
.25221 .95037 m
.25295 .95058 L
s
.25221 .95037 m
.25259 .95057 L
s
.2507 .94827 m .24087 .95048 L .24836 .95135 L 0 1 .358 r
F
0 g
.24836 .95135 m
.25071 .95707 L
s
.24809 .95132 m
.24836 .95135 L
s
.24248 .95257 m
.24257 .95279 L
s
.2417 .95058 m
.24248 .95257 L
s
.24253 .95263 m
.24253 .95265 L
s
.24156 .94887 m
.24191 .95025 L
s
.24201 .95061 m
.24253 .95263 L
s
.80761 .85911 m .81403 .86896 L .81825 .85862 L 0 1 .501 r
F
0 g
.80777 .87672 m
.81403 .86896 L
s
.50447 .91776 m .49845 .92073 L .50362 .92684 L 0 .443 .371 r
F
0 g
.49508 .9135 m
.49845 .92073 L
s
.36666 .6707 m .35613 .67219 L .35852 .67736 L 0 1 .431 r
F
0 g
.35507 .68355 m
.35852 .67736 L
s
.36666 .6707 m .35717 .66465 L .35613 .67219 L 0 1 .431 r
F
.36666 .6707 m .36108 .65863 L .35717 .66465 L F
.36666 .6707 m .36525 .65814 L .36108 .65863 L F
.36666 .6707 m .36764 .66332 L .36525 .65814 L F
0 g
.36275 .67672 m
.36666 .6707 L
s
.41113 .73868 m .39978 .74243 L .40371 .74387 L 0 1 .494 r
F
0 g
.40122 .74766 m
.40371 .74387 L
s
.28785 .71352 m
.28786 .71351 L
s
.43384 .72998 m .42192 .73152 L .42248 .73454 L 0 1 .477 r
F
.43384 .72998 m .42495 .72801 L .42192 .73152 L F
.43384 .72998 m .42954 .72636 L .42495 .72801 L F
.43384 .72998 m .43335 .7272 L .42954 .72636 L F
0 g
.43384 .72998 m
.43759 .73049 L
s
.43081 .73348 m
.43384 .72998 L
s
.48759 .77833 m .47996 .78079 L .47928 .78838 L 0 .672 .329 r
F
.48759 .77833 m .48278 .77529 L .47996 .78079 L F
0 g
.47651 .7814 m
.47996 .78079 L
s
.40016 .6138 m .39122 .62008 L .3953 .61954 L 0 1 .406 r
F
.40016 .6138 m .3901 .61519 L .39122 .62008 L F
0 g
.3953 .61954 m
.39693 .62445 L
s
.40016 .6138 m .39269 .60813 L .3901 .61519 L 0 1 .406 r
F
.40016 .6138 m .39756 .60239 L .39269 .60813 L F
.40016 .6138 m .40144 .60181 L .39756 .60239 L F
.40016 .6138 m .40255 .6067 L .40144 .60181 L F
0 g
.3953 .61954 m
.40016 .6138 L
s
.30426 .76465 m .29198 .75583 L .28903 .76095 L 0 1 .524 r
F
.30426 .76465 m .29751 .75512 L .29198 .75583 L F
.30426 .76465 m .30277 .7589 L .29751 .75512 L F
0 g
.30131 .76974 m
.30426 .76465 L
s
.31465 .76275 m .30278 .7589 L .30426 .76465 L 0 1 .523 r
F
0 g
.30426 .76465 m
.30847 .76832 L
s
.39978 .74243 m .39243 .74759 L .39694 .74614 L 0 1 .501 r
F
.39978 .74243 m .38844 .74587 L .39243 .74759 L F
0 g
.39004 .75146 m
.39243 .74759 L
s
.39694 .74614 m
.40122 .74766 L
s
.52426 .71966 m
.52433 .72006 L
s
.52399 .71817 m
.52426 .71966 L
s
.79841 .92449 m .79576 .93411 L .80302 .93128 L 0 1 .529 r
F
.79841 .92449 m .79178 .93311 L .79576 .93411 L F
0 g
.79359 .93832 m
.79576 .93411 L
s
.79697 .8599 m .79743 .87693 L .80356 .86924 L 0 1 .498 r
F
.79697 .8599 m .79329 .87709 L .79743 .87693 L F
0 g
.79657 .88371 m
.79743 .87693 L
s
.38472 .97031 m .37142 .96496 L .36857 .96629 L 0 1 .538 r
F
.38472 .97031 m .37834 .96668 L .37142 .96496 L F
.39126 .96677 m .37834 .96668 L .38472 .97031 L F
0 g
.38472 .97031 m
.38761 .97415 L
s
.38472 .97031 m
.39138 .97194 L
s
.36185 .96414 m .3439 .95951 L .34572 .96401 L 0 1 .537 r
F
0 g
.3383 .96166 m
.34572 .96401 L
s
.48121 .793 m .47484 .80562 L .47839 .80553 L 0 .692 .342 r
F
.42064 .56346 m .41393 .56674 L .41729 .56586 L 0 1 .37 r
F
0 g
.41912 .56854 m
.42242 .56461 L
s
.41732 .57069 m
.41912 .56854 L
s
.42064 .56346 m .41232 .5657 L .41393 .56674 L 0 1 .37 r
F
.42064 .56346 m .41353 .56344 L .41232 .5657 L F
.42064 .56346 m .4169 .56104 L .41353 .56344 L F
.42064 .56346 m .42016 .5601 L .4169 .56104 L F
0 g
.42016 .5601 m
.42176 .56114 L
s
.41729 .56586 m
.42064 .56346 L
s
.46897 .97779 m .4555 .97846 L .45945 .9806 L 0 1 .534 r
F
0 g
.45338 .98094 m
.45945 .9806 L
s
.46897 .97779 m .4719 .98157 L .47291 .97994 L 0 1 .534 r
F
.48492 .97983 m .47291 .97994 L .4719 .98157 L 0 1 .529 r
F
0 g
.4719 .98157 m
.47627 .98322 L
s
.46613 .98185 m
.4719 .98157 L
s
.44478 .72241 m
.44792 .71897 L
s
.46582 .90693 m .45594 .91152 L .45404 .91312 L 0 1 .252 r
F
.46582 .90693 m .46099 .90887 L .45594 .91152 L F
0 g
.46582 .90693 m
.46832 .90674 L
s
.47003 .90315 m .46582 .90693 L .4706 .90433 L 0 .916 .224 r
F
.47003 .90315 m .46099 .90887 L .46582 .90693 L F
.48088 .81812 m .47842 .81314 L .47475 .81279 L 0 .663 .351 r
F
0 g
.47475 .81279 m
.47484 .80562 L
s
.4049 .93125 m .39041 .93364 L .39259 .93487 L 0 1 .41 r
F
0 g
.38613 .93577 m
.39259 .93487 L
s
.28528 .95538 m .26768 .9465 L .26962 .95191 L 0 1 .536 r
F
0 g
.26191 .94795 m
.26195 .94795 L
s
.28528 .95538 m .27155 .94555 L .26768 .9465 L 0 1 .536 r
F
0 g
.26195 .94795 m
.26824 .94808 L
s
.28528 .95538 m .2791 .94936 L .27155 .94555 L 0 1 .536 r
F
.29451 .95265 m .2791 .94936 L .28528 .95538 L 0 1 .535 r
F
0 g
.28528 .95538 m
.2926 .95902 L
s
.28528 .95538 m
.28719 .96076 L
s
.49045 .44628 m .50173 .43555 L .50141 .43934 L 0 0 .043 r
F
0 g
.50173 .43555 m
.50693 .42703 L
s
.49703 .43852 m
.50173 .43555 L
s
.47989 .7242 m .46877 .73386 L .47244 .73028 L 0 0 0 r
F
.47989 .7242 m .4683 .73477 L .46877 .73386 L F
0 g
.46896 .73301 m
.46963 .73245 L
s
.47989 .7242 m .47134 .73256 L .4683 .73477 L 0 0 0 r
F
0 g
.46819 .73366 m
.46896 .73301 L
s
.47989 .7242 m .47588 .72869 L .47134 .73256 L 0 0 0 r
F
0 g
.47168 .73086 m
.47244 .73028 L
s
.47989 .7242 m .47954 .72511 L .47588 .72869 L 0 0 0 r
F
0 g
.47901 .72485 m
.47989 .7242 L
s
.47989 .7242 m
.48016 .72389 L
s
.49399 .76094 m .48985 .75981 L .48702 .7663 L 0 .656 .318 r
F
.49399 .76094 m .49283 .75751 L .48985 .75981 L F
0 g
.48985 .75981 m
.49117 .75231 L
s
.48985 .75981 m
.49283 .75751 L
s
.49283 .75751 m
.49409 .74907 L
s
.50394 .74095 m
.50455 .7389 L
s
.80576 .68502 m .81403 .68185 L .80943 .68046 L 0 1 .509 r
F
.80576 .68502 m .81724 .68869 L .81403 .68185 L F
0 g
.49276 .64585 m
.49327 .64572 L
s
.47003 .90315 m .4706 .90433 L .47215 .9028 L 0 .916 .224 r
F
.48127 .89741 m .47215 .9028 L .4706 .90433 L 0 1 .227 r
F
0 g
.4706 .90433 m
.47318 .90367 L
s
.46582 .90693 m
.4706 .90433 L
s
.43371 .97336 m .43516 .97794 L .43696 .97632 L 0 1 .539 r
F
.44961 .9783 m .43696 .97632 L .43516 .97794 L F
0 g
.43516 .97794 m
.43894 .98059 L
s
.42891 .97733 m
.43516 .97794 L
s
.51045 .59923 m .50773 .57946 L .50805 .59449 L 0 1 .262 r
F
.50496 .61448 m .50175 .61599 L .50257 .61677 L 0 1 .173 r
F
.50496 .61448 m .50329 .61226 L .50175 .61599 L F
.50496 .61448 m .50615 .60809 L .50329 .61226 L F
.50187 .61361 m .50166 .58613 L .49974 .6036 L 0 1 .274 r
F
.50188 .6136 m .50166 .58613 L .50187 .61361 L F
.5029 .61227 m .50166 .58613 L .50188 .61365 L F
.5029 .61227 m .505 .57588 L .50166 .58613 L F
.50294 .61221 m .505 .57588 L .5029 .61227 L F
.50329 .61226 m .50361 .61157 L .5029 .61239 L 0 .846 .126 r
F
.50361 .61168 m .50361 .61157 L .50292 .61267 L 0 1 .274 r
F
.50361 .61157 m .505 .57588 L .50294 .61236 L F
.50361 .61157 m .50294 .61236 L .50292 .61267 L F
.50361 .61157 m .50361 .61156 L .5029 .61239 L 0 .846 .126 r
F
.50361 .61157 m .50773 .57946 L .505 .57588 L 0 1 .274 r
F
.50329 .61226 m .50432 .61066 L .50361 .61157 L 0 .846 .126 r
F
.50361 .61168 m .50362 .61155 L .50361 .61157 L 0 1 .274 r
F
.50362 .61155 m .50773 .57946 L .50361 .61157 L F
.50432 .61066 m .50773 .57946 L .50361 .61168 L F
.50329 .61226 m .50615 .60809 L .50657 .60744 L 0 .846 .126 r
F
.50329 .61226 m .50657 .60744 L .50648 .60756 L F
.50432 .61066 m .50805 .59449 L .50773 .57946 L 0 1 .274 r
F
.50329 .61226 m .50661 .60738 L .50528 .60928 L 0 .846 .126 r
F
.50532 .60923 m .50805 .59449 L .50432 .61066 L 0 1 .274 r
F
.50532 .60923 m .50665 .60731 L .50805 .59449 L F
.50432 .61066 m .50804 .60514 L .50771 .60538 L 0 .846 .126 r
F
.50329 .61226 m .50532 .60923 L .50432 .61066 L F
.50532 .60923 m .50804 .60514 L .50432 .61066 L F
.50496 .61448 m .50887 .60693 L .50854 .60581 L 0 1 .173 r
F
.50496 .61448 m .50854 .60581 L .50615 .60809 L F
.50328 .62022 m .50614 .61197 L .50665 .60731 L 0 1 .274 r
F
.50528 .60928 m .50661 .60738 L .50665 .60731 L 0 .846 .126 r
F
.50528 .60928 m .50665 .60731 L .50532 .60923 L F
.50648 .60756 m .50657 .60744 L .50661 .60738 L F
.50328 .62022 m .50665 .60731 L .50532 .60923 L 0 1 .274 r
F
.50328 .62022 m .50532 .60923 L .50432 .61066 L F
.50532 .60923 m .50665 .60731 L .50804 .60514 L 0 .846 .126 r
F
.50361 .61157 m .50771 .60538 L .50495 .60867 L F
.50432 .61066 m .50771 .60538 L .50361 .61157 L F
.50329 .61226 m .50188 .61365 L .50053 .61556 L F
.49909 .62357 m .50142 .62002 L .50257 .61677 L 0 1 .203 r
F
.49909 .62357 m .50175 .61599 L .49903 .61824 L F
.49909 .62357 m .50257 .61677 L .50175 .61599 L F
.50328 .62022 m .50187 .61361 L .50053 .61663 L 0 1 .274 r
F
.50187 .61361 m .49974 .6036 L .50045 .61528 L F
.50188 .61365 m .50181 .61374 L .5018 .61376 L 0 .846 .126 r
F
.50188 .61365 m .5018 .61376 L .50053 .61556 L F
.50187 .61361 m .50045 .61528 L .50046 .61558 L 0 1 .274 r
F
.50187 .61366 m .50044 .61559 L .50053 .61556 L 0 .846 .126 r
F
.5018 .61376 m .50046 .61558 L .50053 .61663 L 0 1 .274 r
F
.50187 .61361 m .50046 .61558 L .5018 .61376 L F
.5029 .6124 m .50495 .60867 L .50161 .61283 L 0 .846 .126 r
F
.50292 .61267 m .50294 .61221 L .5029 .61227 L 0 1 .274 r
F
.5029 .61239 m .50291 .61238 L .5029 .6124 L 0 .846 .126 r
F
.50291 .61238 m .50495 .60867 L .5029 .6124 L F
.50361 .61156 m .50495 .60867 L .5029 .61239 L F
.50188 .61365 m .50188 .6136 L .50187 .61361 L 0 1 .274 r
F
.49909 .62357 m .49508 .62529 L .49637 .62583 L 0 1 .203 r
F
.49909 .62357 m .49622 .62204 L .49508 .62529 L F
.49909 .62357 m .49903 .61824 L .49622 .62204 L F
.49622 .62204 m .49903 .61824 L .50053 .61556 L 0 .938 .166 r
F
.49642 .62042 m .49974 .6036 L .49668 .60088 L 0 1 .285 r
F
.49451 .62236 m .49668 .60088 L .49337 .61029 L F
.49451 .62236 m .49452 .62234 L .49451 .62236 L 0 .938 .166 r
F
.49622 .62204 m .49642 .62042 L .49451 .62236 L F
.49622 .62204 m .50053 .61556 L .50047 .61558 L F
.49622 .62204 m .50047 .61558 L .50043 .61563 L F
.49622 .62204 m .50046 .61558 L .4983 .61831 L F
.49336 .63204 m .49563 .62872 L .49637 .62583 L 0 1 .259 r
F
.49336 .63204 m .49508 .62529 L .49206 .62752 L F
.49336 .63204 m .49637 .62583 L .49508 .62529 L F
.49622 .62204 m .49184 .62527 L .49314 .62505 L 0 .938 .166 r
F
.49622 .62204 m .49451 .62236 L .49184 .62527 L F
.49451 .62236 m .49337 .61029 L .49192 .62513 L 0 1 .285 r
F
.49451 .62236 m .49333 .62259 L .49192 .62513 L 0 .938 .166 r
F
.49451 .62236 m .49192 .62513 L .49184 .62527 L F
.48933 .63103 m .49206 .62752 L .49314 .62505 L 0 1 .195 r
F
.48933 .63103 m .49314 .62505 L .49184 .62527 L F
.49617 .64013 m .49451 .62236 L .49184 .62595 L 0 1 .285 r
F
.49451 .62236 m .49192 .62513 L .49184 .62595 L F
.49648 .62035 m .49974 .6036 L .49642 .62042 L F
.49622 .62204 m .49829 .61833 L .49642 .62042 L 0 .938 .166 r
F
.4983 .61831 m .49974 .6036 L .49649 .62035 L 0 1 .285 r
F
.49829 .61833 m .4983 .61831 L .49642 .62042 L 0 .938 .166 r
F
.4983 .61831 m .49649 .62035 L .49642 .62068 L 0 1 .285 r
F
.49832 .61807 m .50045 .61541 L .49974 .6036 L F
.4983 .61831 m .49971 .61579 L .49642 .62042 L 0 .938 .166 r
F
.49642 .62042 m .49971 .61579 L .49663 .6188 L F
.49452 .62254 m .49642 .62042 L .49451 .62236 L 0 1 .285 r
F
.49617 .64013 m .49642 .62042 L .49452 .62254 L F
.49642 .62042 m .49668 .60088 L .49451 .62236 L F
.49451 .62236 m .49663 .6188 L .49333 .62259 L 0 .938 .166 r
F
.49452 .62234 m .49663 .6188 L .49451 .62236 L F
.49642 .62042 m .49663 .6188 L .49451 .62236 L F
.49642 .62068 m .49648 .62035 L .49642 .62042 L 0 1 .285 r
F
.49617 .64013 m .4983 .61831 L .49642 .62068 L F
.50043 .61563 m .50047 .61558 L .50046 .61558 L 0 .938 .166 r
F
.49617 .64013 m .50045 .61541 L .49832 .61807 L 0 1 .285 r
F
.4983 .61831 m .50046 .61558 L .49971 .61579 L 0 .938 .166 r
F
.49617 .64013 m .50053 .61663 L .50046 .61558 L 0 1 .285 r
F
.50041 .61565 m .50046 .61558 L .50045 .61541 L F
.49617 .64013 m .50046 .61558 L .50041 .61565 L F
.50178 .61375 m .50161 .61283 L .49971 .61579 L 0 .846 .126 r
F
.50188 .61365 m .50187 .61363 L .50178 .61375 L F
.50187 .61363 m .50161 .61283 L .50178 .61375 L F
.50329 .61226 m .5029 .61239 L .50188 .61365 L F
.5029 .61239 m .5029 .61227 L .50188 .61365 L 0 1 .274 r
F
.5029 .61239 m .50161 .61283 L .50188 .61365 L 0 .846 .126 r
F
.50328 .62022 m .5029 .61239 L .50188 .61365 L 0 1 .274 r
F
.50188 .61365 m .50187 .61366 L .50181 .61374 L 0 .846 .126 r
F
.50187 .61366 m .49971 .61579 L .50044 .61559 L F
.50328 .62022 m .50361 .61168 L .50292 .61267 L 0 1 .274 r
F
.50328 .62022 m .50432 .61066 L .50361 .61168 L F
0 g
.505 .57588 m
.50507 .57598 L
s
.50507 .57598 m
.50773 .57946 L
s
.50773 .57946 m
.51001 .55967 L
s
.50215 .6197 m
.50269 .61945 L
s
.50142 .62002 m
.50215 .6197 L
s
.5037 .619 m
.50378 .61897 L
s
.50378 .61897 m
.50399 .61816 L
s
.50733 .61064 m
.50887 .60693 L
s
.505 .57588 m
.50726 .56 L
s
.3229 .69599 m .31229 .69734 L .31518 .7032 L 0 1 .456 r
F
0 g
.31233 .70998 m
.31518 .7032 L
s
.52666 .57543 m .52534 .58368 L .52469 .58173 L 0 0 .061 r
F
.52666 .57543 m .52865 .5807 L .52534 .58368 L F
.52666 .57543 m .53239 .5748 L .52865 .5807 L F
.52666 .57543 m .53435 .5685 L .53239 .5748 L F
0 g
.52372 .5802 m
.52666 .57543 L
s
.52568 .70627 m .52862 .6159 L .52613 .64365 L 0 .83 .256 r
F
0 g
.52824 .62022 m
.52862 .6159 L
s
.52834 .67644 m
.52934 .68019 L
s
.52509 .6766 m
.52588 .67804 L
s
.52769 .59333 m
.52862 .6159 L
s
.52549 .61731 m
.52769 .59333 L
s
.48759 .77833 m .48605 .77424 L .48278 .77529 L 0 .672 .329 r
F
0 g
.48278 .77529 m
.48383 .76803 L
s
.38037 .77683 m .37414 .77976 L .37835 .77841 L 0 1 .323 r
F
.38037 .77683 m .36974 .77998 L .37414 .77976 L F
0 g
.37267 .78153 m
.37414 .77976 L
s
.37835 .77841 m
.38306 .77796 L
s
.47554 1.06903 m .46699 1.06485 L .4596 1.0633 L 0 1 .501 r
F
0 g
.4596 1.0633 m
.46699 1.06485 L
s
.45434 1.0581 m
.4596 1.0633 L
s
.24103 .94682 m .22506 .94186 L .23123 .94911 L 0 1 .536 r
F
0 g
.23123 .94911 m
.23331 .95041 L
s
.38039 .65089 m .37165 .65733 L .376 .65673 L 0 1 .422 r
F
.38039 .65089 m .36958 .65231 L .37165 .65733 L F
0 g
.376 .65673 m
.37857 .6617 L
s
.38039 .65089 m .37119 .64501 L .36958 .65231 L 0 1 .422 r
F
.38039 .65089 m .37558 .63917 L .37119 .64501 L F
.38039 .65089 m .37983 .63867 L .37558 .63917 L F
.38039 .65089 m .38188 .6437 L .37983 .63867 L F
0 g
.38039 .65089 m
.38253 .65577 L
s
.376 .65673 m
.38039 .65089 L
s
.3335 .69452 m .32329 .68779 L .3229 .69599 L 0 1 .45 r
F
.3335 .69452 m .32677 .6813 L .32329 .68779 L F
.3335 .69452 m .331 .68086 L .32677 .6813 L F
.3335 .69452 m .33389 .68653 L .331 .68086 L F
0 g
.33003 .701 m
.3335 .69452 L
s
.3335 .69452 m
.3364 .69998 L
s
.51348 .72961 m .513 .72893 L .51249 .74052 L 0 .593 .293 r
F
0 g
.5128 .71396 m
.513 .72893 L
s
.67778 .93997 m .68962 .93581 L .68538 .93647 L 0 1 .413 r
F
.69124 .92854 m .68962 .93581 L .69693 .93137 L 0 1 .439 r
F
0 g
.69539 .93509 m
.69693 .93137 L
s
.69124 .92854 m .68538 .93647 L .68962 .93581 L 0 1 .439 r
F
0 g
.6881 .93862 m
.68962 .93581 L
s
.45392 .91144 m .45404 .91312 L .45594 .91152 L 0 1 .243 r
F
.45392 .91144 m .44887 .91535 L .45404 .91312 L F
0 g
.45404 .91312 m
.45656 .91293 L
s
.41401 .57799 m .41732 .57069 L .41729 .56587 L 0 1 .379 r
F
0 g
.41401 .57799 m
.41436 .58295 L
s
.49399 .76094 m .48702 .7663 L .48605 .77424 L 0 .656 .318 r
F
0 g
.48383 .76803 m
.48702 .7663 L
s
.4678 .69784 m .45954 .70242 L .46412 .70071 L 0 1 .435 r
F
.4678 .69784 m .45639 .7019 L .45954 .70242 L F
.4678 .69784 m .45679 .6995 L .45639 .7019 L F
0 g
.46412 .70071 m
.46747 .70099 L
s
.4678 .69784 m .46047 .69662 L .45679 .6995 L 0 1 .435 r
F
.4678 .69784 m .46498 .69519 L .46047 .69662 L F
.4678 .69784 m .46812 .69571 L .46498 .69519 L F
0 g
.4678 .69784 m
.4683 .69787 L
s
.46412 .70071 m
.4678 .69784 L
s
.46812 .69571 m
.47173 .69298 L
s
.78136 .66068 m .78641 .67252 L .79101 .67425 L 0 .975 .493 r
F
.78136 .66068 m .78227 .66671 L .78641 .67252 L F
0 g
.78279 .67641 m
.78641 .67252 L
s
.50887 .60693 m
.50985 .60582 L
s
.51509 .69054 m .51585 .70485 L .51522 .69712 L 0 .124 .104 r
F
.51509 .69054 m .51704 .70916 L .51585 .70485 L F
.51509 .69054 m .51799 .70716 L .51704 .70916 L F
.51509 .69054 m .51785 .70053 L .51799 .70716 L F
.51509 .69054 m .51674 .69372 L .51785 .70053 L F
0 g
.51667 .69344 m
.51674 .69372 L
s
.51663 .6933 m
.51667 .69344 L
s
.51625 .68775 m
.51674 .69372 L
s
.51426 .68804 m
.51509 .69054 L
s
.47203 .73067 m
.47244 .73028 L
s
.46925 .73339 m
.47203 .73067 L
s
.31465 .76275 m .30482 .75415 L .30278 .7589 L 0 1 .523 r
F
.31465 .76275 m .30904 .75358 L .30482 .75415 L F
.31465 .76275 m .31325 .75727 L .30904 .75358 L F
.32504 .76077 m .31325 .75727 L .31465 .76275 L 0 1 .522 r
F
0 g
.31259 .76748 m
.31465 .76275 L
s
.31465 .76275 m
.31879 .7662 L
s
.23435 .7964 m .22833 .80118 L .23272 .80057 L 0 1 .535 r
F
.23435 .7964 m .22328 .79769 L .22833 .80118 L F
0 g
.22768 .80548 m
.22833 .80118 L
s
.23272 .80057 m
.23856 .80371 L
s
.71868 .92025 m
.71873 .91999 L
s
.71344 1.07275 m .70457 1.07365 L .70003 1.07461 L 0 .734 .252 r
F
0 g
.69074 1.07469 m
.70003 1.07461 L
s
.43376 1.04562 m .42574 1.04025 L .41796 1.03764 L 0 1 .499 r
F
0 g
.41796 1.03764 m
.42574 1.04025 L
s
.43376 1.04562 m
.43839 1.05114 L
s
.45579 .71134 m
.45918 .70811 L
s
.3393 .78795 m .32846 .7859 L .32699 .78813 L 0 1 .459 r
F
.3393 .78795 m .33261 .78515 L .32846 .7859 L F
.3393 .78795 m .33725 .78603 L .33261 .78515 L F
.34944 .78544 m .33725 .78603 L .3393 .78795 L 0 1 .436 r
F
0 g
.33782 .79017 m
.3393 .78795 L
s
.3393 .78795 m
.34384 .78857 L
s
.52275 .45956 m .5184 .46902 L .51825 .46861 L 0 0 .027 r
F
0 g
.52275 .45957 m
.52275 .45956 L
s
.52275 .45956 m .52347 .4616 L .5184 .46902 L 0 0 .027 r
F
.52275 .45956 m .53005 .45133 L .52347 .4616 L F
0 g
.52275 .45956 m
.52275 .45956 L
s
.63759 .62639 m
.63782 .6291 L
s
.63289 .57111 m
.63759 .62639 L
s
.63782 .6291 m
.6386 .63835 L
s
.483 .84323 m .47997 .83795 L .47619 .8372 L 0 .625 .36 r
F
.51689 .63686 m .51927 .63189 L .52151 .60788 L 0 1 .263 r
F
.48088 .81812 m .47554 .83 L .47921 .83035 L 0 .663 .351 r
F
0 g
.47554 .83 m
.47619 .8372 L
s
.72481 .91747 m .72254 .92445 L .72936 .92355 L 0 1 .509 r
F
.72481 .91747 m .71876 .92289 L .72254 .92445 L F
0 g
.72074 .92766 m
.72254 .92445 L
s
.60343 .58036 m .61196 .56785 L .61573 .58718 L 0 .633 .172 r
F
0 g
.61146 .55437 m
.61196 .56785 L
s
.61129 .56748 m
.61196 .56785 L
s
.54738 .69468 m
.54916 .69372 L
s
.54646 .69518 m .54685 .70861 L .55065 .73469 L 0 .303 .234 r
F
0 g
.54646 .69518 m
.54738 .69468 L
s
.54622 .69436 m
.54646 .69518 L
s
.48759 .77833 m .47928 .78838 L .48121 .793 L 0 .672 .329 r
F
0 g
.47928 .78838 m
.47996 .78079 L
s
.47573 .78849 m
.47928 .78838 L
s
.50241 .74602 m .50159 .74358 L .49914 .74828 L 0 .622 .305 r
F
0 g
.50159 .74358 m
.5028 .73364 L
s
.41401 .57799 m .40515 .58469 L .4088 .58399 L 0 1 .379 r
F
0 g
.41215 .58557 m
.41436 .58295 L
s
.40938 .58884 m
.41215 .58557 L
s
.41401 .57799 m .40511 .57987 L .40515 .58469 L 0 1 .379 r
F
.41401 .57799 m .40871 .57275 L .40511 .57987 L F
.41401 .57799 m .41393 .56675 L .40871 .57275 L F
.41401 .57799 m .41729 .56587 L .41393 .56675 L F
0 g
.41729 .56587 m
.41732 .57069 L
s
.71344 1.07275 m .71181 1.07434 L .72103 1.07305 L 0 .734 .252 r
F
0 g
.70755 1.07549 m
.71181 1.07434 L
s
.70283 1.07501 m
.71181 1.07434 L
s
.75724 .59454 m .76519 .58368 L .76974 .58674 L 0 .25 .055 r
F
.75724 .59454 m .75984 .587 L .76519 .58368 L F
0 g
.76296 .57766 m
.76519 .58368 L
s
.72859 1.07351 m .74124 1.07252 L .73813 1.07237 L 0 .894 .3 r
F
.72103 1.07305 m .72859 1.07351 L .73344 1.07221 L 0 .786 .267 r
F
.43057 .92237 m .41719 .92631 L .41938 .92696 L 0 1 .337 r
F
0 g
.41338 .92857 m
.41938 .92696 L
s
.2626 .94814 m
.26886 .94979 L
s
.4065 .596 m .39756 .60239 L .40144 .60181 L 0 1 .397 r
F
.4065 .596 m .39697 .59755 L .39756 .60239 L F
0 g
.40144 .60181 m
.40255 .6067 L
s
.4065 .596 m .40008 .5905 L .39697 .59755 L 0 1 .397 r
F
.4065 .596 m .40515 .58469 L .40008 .5905 L F
.4065 .596 m .4088 .58399 L .40515 .58469 L F
.4065 .596 m .40937 .58884 L .4088 .58399 L F
0 g
.4088 .58399 m
.41401 .57799 L
s
.40144 .60181 m
.4065 .596 L
s
.50116 .98028 m .49464 .98029 L .48929 .98149 L 0 1 .517 r
F
.51348 .72961 m .5143 .76013 L .51403 .74297 L 0 .593 .293 r
F
.51348 .72961 m .51379 .77178 L .5143 .76013 L F
.51348 .72961 m .51284 .7701 L .51379 .77178 L F
0 g
.51361 .73285 m
.51361 .73285 L
s
.51358 .73199 m
.51361 .73285 L
s
.51358 .73199 m
.51358 .73199 L
s
.51358 .73198 m
.51358 .73199 L
s
.51357 .7319 m
.51358 .73198 L
s
.51357 .7319 m
.51357 .7319 L
s
.51357 .7319 m
.51357 .7319 L
s
.51353 .7309 m
.51357 .7319 L
s
.51353 .7309 m
.51353 .7309 L
s
.51353 .7309 m
.51353 .7309 L
s
.51351 .73035 m
.51353 .7309 L
s
.51351 .73035 m
.51351 .73035 L
s
.51351 .73035 m
.51351 .73035 L
s
.51349 .72982 m
.51351 .73035 L
s
.51349 .72982 m
.51349 .72982 L
s
.51349 .72982 m
.51349 .72982 L
s
.51363 .71515 m
.51418 .73043 L
s
.51348 .72961 m .51229 .75669 L .51284 .7701 L 0 .593 .293 r
F
.51348 .72961 m .51249 .74052 L .51229 .75669 L F
0 g
.5123 .72779 m
.51249 .74052 L
s
.51348 .72961 m
.51349 .72982 L
s
.51348 .72961 m
.51363 .71515 L
s
.51249 .74052 m
.513 .72893 L
s
.44887 .91535 m .43839 .91897 L .4361 .92058 L 0 1 .297 r
F
.44887 .91535 m .44387 .91673 L .43839 .91897 L F
.45392 .91144 m .44387 .91673 L .44887 .91535 L 0 1 .243 r
F
0 g
.44887 .91535 m
.4512 .91564 L
s
.44887 .91535 m
.45404 .91312 L
s
.52317 .97797 m
.52429 .97793 L
s
.52429 .97793 m
.52504 .9779 L
s
.52504 .9779 m
.52729 .97781 L
s
.48762 .86825 m .48402 .86271 L .48014 .86158 L 0 .577 .368 r
F
0 g
.52383 .72095 m
.52412 .72219 L
s
.42248 .73454 m .41049 .73542 L .41113 .73868 L 0 1 .486 r
F
.42248 .73454 m .41346 .73185 L .41049 .73542 L F
.42248 .73454 m .41805 .73037 L .41346 .73185 L F
.42248 .73454 m .42192 .73152 L .41805 .73037 L F
0 g
.41952 .7381 m
.42248 .73454 L
s
.42248 .73454 m
.4263 .73538 L
s
.4088 .58399 m
.40937 .58884 L
s
.53435 .97658 m
.53516 .97638 L
s
.50241 .74602 m .49914 .74828 L .49669 .75698 L 0 .622 .305 r
F
0 g
.49914 .74828 m
.50039 .73984 L
s
.49914 .74828 m
.50159 .74358 L
s
.50362 .92684 m .50716 .93702 L .50736 .93383 L 0 .464 .381 r
F
.51662 .94222 m .50716 .93702 L .51126 .94411 L 0 .36 .36 r
F
.51662 .94222 m .50736 .93383 L .50716 .93702 L F
0 g
.5028 .93473 m
.50716 .93702 L
s
.31229 .69734 m .30456 .70465 L .30881 .70408 L 0 1 .461 r
F
0 g
.30881 .70408 m
.31233 .70998 L
s
.77325 .76534 m .77387 .76721 L .77846 .77068 L 0 .193 .186 r
F
.77325 .76534 m .77164 .76493 L .77387 .76721 L F
0 g
.76847 .76562 m
.77387 .76721 L
s
.483 .84323 m .47872 .85439 L .4825 .85515 L 0 .625 .36 r
F
0 g
.47872 .85439 m
.48014 .86158 L
s
.32504 .76077 m .31537 .75269 L .31325 .75727 L 0 1 .522 r
F
.32504 .76077 m .31958 .75208 L .31537 .75269 L F
.32504 .76077 m .32373 .75555 L .31958 .75208 L F
.33544 .75869 m .32373 .75555 L .32504 .76077 L 0 1 .52 r
F
0 g
.32292 .76533 m
.32504 .76077 L
s
.32504 .76077 m
.32912 .764 L
s
.50241 .70368 m .49462 .71624 L .499 .70899 L 0 0 .058 r
F
.50241 .70368 m .49158 .72203 L .49462 .71624 L F
.50241 .70368 m .49192 .72247 L .49158 .72203 L F
.50241 .70368 m .49535 .71714 L .49192 .72247 L F
0 g
.49064 .71491 m
.49271 .71239 L
s
.50241 .70368 m .49957 .7096 L .49535 .71714 L 0 0 .058 r
F
0 g
.50184 .704 m
.50219 .70339 L
s
.50041 .70522 m
.50083 .70454 L
s
.50241 .70368 m .50259 .70385 L .49957 .7096 L 0 0 .058 r
F
0 g
.50241 .70368 m
.50556 .69658 L
s
.50009 .70575 m
.50041 .70522 L
s
.49975 .70653 m
.50024 .70581 L
s
.50024 .70581 m
.50103 .70467 L
s
.50259 .70385 m
.50586 .69687 L
s
.51722 .97677 m .5175 .97912 L .52223 .97801 L 0 1 .452 r
F
.51722 .97677 m .51096 .97978 L .5175 .97912 L F
0 g
.5175 .97912 m
.52259 .97935 L
s
.49295 .64234 m .49469 .63957 L .4947 .6366 L 0 1 .345 r
F
0 g
.49703 .63548 m
.49736 .63532 L
s
.49469 .63957 m
.49595 .6394 L
s
.49631 .63935 m
.49729 .63922 L
s
.69124 .92854 m .69693 .93137 L .70244 .9261 L 0 1 .439 r
F
0 g
.68962 .93581 m
.69693 .93137 L
s
.44023 .5172 m .44518 .509 L .44727 .50415 L 0 1 .181 r
F
0 g
.44518 .509 m
.44846 .50446 L
s
.51896 1.08303 m .51932 1.09187 L .52606 1.09101 L 0 1 .533 r
F
.49715 1.07789 m .50325 1.08505 L .50349 1.08236 L 0 1 .509 r
F
.51896 1.08303 m .50349 1.08236 L .50325 1.08505 L 0 1 .533 r
F
0 g
.50325 1.08505 m
.51003 1.08912 L
s
.49615 1.0843 m
.50325 1.08505 L
s
.48868 .71724 m
.49005 .71562 L
s
.49005 .71562 m
.49018 .71547 L
s
.49018 .71547 m
.49036 .71525 L
s
.38188 .6437 m
.38619 .63787 L
s
.80246 .78944 m .81272 .79214 L .80816 .78967 L 0 .547 .374 r
F
.80246 .78944 m .81375 .79584 L .81272 .79214 L F
.46204 .48037 m .46793 .47198 L .47142 .46752 L 0 0 0 r
F
.48762 .86825 m .48446 .8787 L .48834 .87984 L 0 .577 .368 r
F
0 g
.48446 .8787 m
.48666 .88586 L
s
.52804 .67981 m
.52934 .68019 L
s
.32785 .96016 m .31071 .95332 L .31284 .95809 L 0 1 .536 r
F
.4049 .93125 m .39327 .93224 L .39041 .93364 L 0 1 .41 r
F
.4049 .93125 m .39949 .93122 L .39327 .93224 L F
.41148 .92754 m .39949 .93122 L .4049 .93125 L 0 1 .369 r
F
0 g
.4049 .93125 m
.41085 .93012 L
s
.4049 .93125 m
.40705 .93249 L
s
.48127 .89741 m .47673 .89983 L .47215 .9028 L 0 1 .227 r
F
.48439 .89427 m .48127 .89741 L .48551 .89466 L 0 .888 .2 r
F
.48439 .89427 m .47673 .89983 L .48127 .89741 L F
0 g
.48127 .89741 m
.48384 .89675 L
s
.73501 .58104 m .74857 .57921 L .74612 .58843 L 0 .347 .088 r
F
0 g
.74697 .56909 m
.74857 .57921 L
s
.74857 .57921 m
.7538 .57505 L
s
.79841 .92449 m .7929 .92899 L .79178 .93311 L 0 1 .529 r
F
0 g
.78382 .93559 m
.79178 .93311 L
s
.62445 .48116 m
.62525 .48348 L
s
.62415 .48027 m
.62445 .48116 L
s
.62404 .47997 m
.62415 .48027 L
s
.6187 .46448 m
.62404 .47997 L
s
.32785 .96016 m .31434 .95219 L .31071 .95332 L 0 1 .536 r
F
0 g
.30773 .95601 m
.31284 .95809 L
s
.32785 .96016 m .3217 .95513 L .31434 .95219 L 0 1 .536 r
F
.33643 .95706 m .3217 .95513 L .32785 .96016 L F
0 g
.32785 .96016 m
.33496 .96296 L
s
.32785 .96016 m
.32995 .96492 L
s
.75102 1.06831 m .74124 1.07252 L .75033 1.07064 L 0 .876 .271 r
F
.75102 1.06831 m .73813 1.07237 L .74124 1.07252 L F
0 g
.73613 1.07413 m
.74124 1.07252 L
s
.51722 .97677 m .50618 .97937 L .51096 .97978 L 0 1 .452 r
F
0 g
.50591 .9813 m
.51096 .97978 L
s
.31229 .69734 m .30168 .69859 L .30456 .70465 L 0 1 .461 r
F
0 g
.30175 .71156 m
.30456 .70465 L
s
.51465 .73103 m .51418 .73052 L .51403 .74297 L 0 .589 .291 r
F
0 g
.51418 .73114 m
.51418 .73114 L
s
.51418 .73114 m
.51418 .73114 L
s
.51418 .73114 m
.51418 .73079 L
s
.51418 .73079 m
.51418 .73079 L
s
.51418 .73079 m
.51418 .73079 L
s
.51418 .73079 m
.51418 .73052 L
s
.51418 .73043 m
.51418 .73052 L
s
.75576 .88676 m .75132 .89492 L .75096 .90076 L 0 1 .5 r
F
0 g
.74393 .90641 m
.75096 .90076 L
s
.33544 .75869 m .32591 .75113 L .32373 .75555 L 0 1 .52 r
F
.33544 .75869 m .33013 .75048 L .32591 .75113 L F
.33544 .75869 m .33421 .75372 L .33013 .75048 L F
.34584 .7565 m .33421 .75372 L .33544 .75869 L 0 1 .519 r
F
0 g
.33325 .76309 m
.33544 .75869 L
s
.33544 .75869 m
.33945 .7617 L
s
.24095 .94865 m .22487 .94605 L .23115 .95091 L 0 1 .53 r
F
0 g
.24253 .95275 m
.24255 .95278 L
s
.24801 .95131 m
.24809 .95132 L
s
.23115 .95091 m
.23407 .95202 L
s
.25219 .95034 m
.25221 .95037 L
s
.391 .77343 m .38467 .77632 L .38888 .77488 L 0 1 .272 r
F
.391 .77343 m .38037 .77683 L .38467 .77632 L F
0 g
.38306 .77796 m
.38467 .77632 L
s
.38888 .77488 m
.39346 .77414 L
s
.41113 .73868 m .39906 .73893 L .39978 .74243 L 0 1 .494 r
F
.41113 .73868 m .40196 .73531 L .39906 .73893 L F
.41113 .73868 m .40656 .73397 L .40196 .73531 L F
.41113 .73868 m .41049 .73542 L .40656 .73397 L F
0 g
.40823 .7423 m
.41113 .73868 L
s
.41113 .73868 m
.415 .73982 L
s
.51391 .69308 m .51438 .69209 L .51522 .69712 L 0 .12 .104 r
F
0 g
.51426 .68804 m
.51438 .69209 L
s
.79697 .8599 m .79309 .86981 L .79329 .87709 L 0 1 .498 r
F
0 g
.78638 .88394 m
.79329 .87709 L
s
.35613 .67219 m .34794 .67884 L .35217 .67827 L 0 1 .44 r
F
0 g
.35217 .67827 m
.35507 .68355 L
s
.36764 .66332 m
.37165 .65733 L
s
.44439 .71858 m .43644 .72374 L .44103 .72189 L 0 1 .466 r
F
0 g
.44103 .72189 m
.44478 .72241 L
s
.49399 .76094 m .48605 .77424 L .48759 .77833 L 0 .656 .318 r
F
0 g
.48278 .77529 m
.48605 .77424 L
s
.48605 .77424 m
.48702 .7663 L
s
.52438 .68317 m
.52585 .68274 L
s
.52344 .68345 m
.52438 .68317 L
s
.41288 .9709 m .39768 .96831 L .40067 .97166 L 0 1 .538 r
F
0 g
.3939 .97047 m
.40067 .97166 L
s
.37762 1.00076 m .36907 1.0049 L .37685 1.00877 L 0 1 .491 r
F
.37762 1.00076 m .36196 .99805 L .36907 1.0049 L F
0 g
.70223 .91919 m
.70929 .91884 L
s
.70223 .91919 m
.70267 .91721 L
s
.70267 .91721 m
.70294 .916 L
s
.48121 .793 m .47839 .80553 L .48083 .80035 L 0 .692 .342 r
F
.48625 .80445 m .47839 .80553 L .47842 .81314 L 0 .643 .339 r
F
.48625 .80445 m .48083 .80035 L .47839 .80553 L F
0 g
.47484 .80562 m
.47839 .80553 L
s
.51689 .63686 m .51536 .60089 L .51521 .62353 L 0 1 .263 r
F
.51089 .65006 m .51521 .62353 L .51536 .60089 L 0 1 .27 r
F
0 g
.51536 .60089 m
.51608 .59317 L
s
.51434 .59573 m
.51536 .60089 L
s
.30377 .94996 m .30165 .95615 L .30527 .95501 L 0 1 .535 r
F
0 g
.30527 .95501 m
.30773 .95601 L
s
.30377 .94996 m .29451 .95265 L .30165 .95615 L 0 1 .535 r
F
0 g
.30165 .95615 m
.30401 .96108 L
s
.46877 .73386 m .46141 .73894 L .46582 .73564 L 0 0 0 r
F
0 g
.46582 .73564 m
.46709 .73488 L
s
.46582 .73564 m
.46819 .73366 L
s
.24543 .79509 m .23932 .79964 L .24372 .79902 L 0 1 .532 r
F
.24543 .79509 m .23435 .7964 L .23932 .79964 L F
0 g
.23856 .80371 m
.23932 .79964 L
s
.24372 .79902 m
.24944 .80192 L
s
.7347 .92079 m .73898 .92704 L .74457 .92395 L 0 1 .516 r
F
0 g
.73198 .92824 m
.73898 .92704 L
s
.73763 .93044 m
.73898 .92704 L
s
.50241 .74602 m .49947 .76462 L .5015 .75504 L 0 .622 .305 r
F
.50241 .74602 m .49702 .76932 L .49947 .76462 L F
.50241 .74602 m .49578 .766 L .49702 .76932 L F
.50241 .74602 m .49669 .75698 L .49578 .766 L F
0 g
.50241 .74602 m
.50394 .74095 L
s
.48865 .65228 m
.48947 .65201 L
s
.64995 .46928 m
.65045 .47056 L
s
.65045 .47056 m
.65139 .47295 L
s
.65139 .47295 m
.65189 .47421 L
s
.65343 .47813 m
.65361 .47858 L
s
.64858 .46797 m
.64995 .46928 L
s
.36919 .96093 m .36857 .96629 L .37142 .96496 L 0 1 .536 r
F
.36919 .96093 m .36185 .96414 L .36857 .96629 L F
0 g
.36857 .96629 m
.37148 .97014 L
s
.49478 .8931 m .49277 .90285 L .49674 .90435 L 0 .517 .372 r
F
.34584 .7565 m .33646 .74946 L .33421 .75372 L 0 1 .519 r
F
.34584 .7565 m .34068 .74876 L .33646 .74946 L F
.34584 .7565 m .3447 .75178 L .34068 .74876 L F
.35625 .75417 m .3447 .75178 L .34584 .7565 L 0 1 .517 r
F
0 g
.34359 .76075 m
.34584 .7565 L
s
.34584 .7565 m
.34979 .75928 L
s
.51465 .73103 m .51631 .76308 L .51556 .74497 L 0 .589 .291 r
F
.51465 .73103 m .51616 .77561 L .51631 .76308 L F
.51465 .73103 m .51521 .77414 L .51616 .77561 L F
.51465 .73103 m .5143 .76013 L .51521 .77414 L F
0 g
.51512 .7315 m
.51512 .73151 L
s
.51466 .73118 m
.51466 .73118 L
s
.51466 .73118 m
.51466 .73118 L
s
.51466 .73118 m
.51468 .73144 L
s
.51468 .73144 m
.51468 .73144 L
s
.51468 .73144 m
.51468 .73144 L
s
.51468 .73144 m
.51473 .73224 L
s
.51473 .73224 m
.51473 .73224 L
s
.51473 .73224 m
.51473 .73224 L
s
.51473 .73224 m
.51478 .73298 L
s
.51478 .73298 m
.51478 .73298 L
s
.51465 .73103 m .51403 .74297 L .5143 .76013 L 0 .589 .291 r
F
0 g
.51465 .73103 m
.51466 .73118 L
s
.51445 .71605 m
.51465 .73103 L
s
.51445 .71606 m
.51512 .7315 L
s
.51361 .73285 m
.51403 .74297 L
s
.51417 .73186 m
.51418 .73114 L
s
.51417 .73198 m
.51417 .73186 L
s
.51417 .73198 m
.51417 .73198 L
s
.51417 .73199 m
.51417 .73198 L
s
.51416 .73273 m
.51417 .73199 L
s
.51416 .73273 m
.51416 .73273 L
s
.51403 .74297 m
.51416 .73273 L
s
.75576 .88676 m .76133 .89385 L .76597 .88541 L 0 1 .5 r
F
0 g
.75491 .90041 m
.76133 .89385 L
s
.76082 .90001 m
.76133 .89385 L
s
.3229 .69599 m .31269 .68892 L .31229 .69734 L 0 1 .456 r
F
.3229 .69599 m .31617 .6823 L .31269 .68892 L F
.3229 .69599 m .32041 .68191 L .31617 .6823 L F
.3229 .69599 m .32329 .68779 L .32041 .68191 L F
0 g
.31942 .70259 m
.3229 .69599 L
s
.3229 .69599 m
.32579 .70165 L
s
.34944 .78544 m .33882 .78398 L .33725 .78603 L 0 1 .436 r
F
.34944 .78544 m .34297 .78318 L .33882 .78398 L F
.34944 .78544 m .34752 .78381 L .34297 .78318 L F
.35958 .78279 m .34752 .78381 L .34944 .78544 L 0 1 .406 r
F
0 g
.34786 .78748 m
.34944 .78544 L
s
.34944 .78544 m
.35388 .7858 L
s
.56166 .41871 m .55826 .43072 L .55714 .42419 L 0 .38 .103 r
F
.56175 .42907 m .55832 .4389 L .55723 .4361 L 0 .161 .083 r
F
.56166 .41871 m .56481 .43625 L .55826 .43072 L 0 .38 .103 r
F
0 g
.55547 .41367 m
.56166 .41871 L
s
.29467 .94804 m .27737 .94412 L .27917 .94742 L 0 1 .517 r
F
.29467 .94804 m .28125 .94317 L .27737 .94412 L F
.29467 .94804 m .28867 .94485 L .28125 .94317 L F
.30392 .94525 m .28867 .94485 L .29467 .94804 L 0 1 .511 r
F
0 g
.29467 .94804 m
.30187 .94953 L
s
.29467 .94804 m
.29644 .95133 L
s
.51662 .94222 m .51126 .94411 L .51692 .9504 L 0 .36 .36 r
F
0 g
.50716 .93702 m
.51126 .94411 L
s
.50687 .94159 m
.51126 .94411 L
s
.50447 .91776 m .49976 .91178 L .49574 .90996 L 0 .443 .371 r
F
0 g
.49277 .90285 m
.49574 .90996 L
s
.36958 .65231 m
.37165 .65733 L
s
.26225 .94814 m
.26365 .94886 L
s
.26365 .94886 m
.26962 .95191 L
s
.48439 .89427 m .48551 .89466 L .48662 .89341 L 0 .888 .2 r
F
0 g
.48127 .89741 m
.48551 .89466 L
s
.48551 .89466 m
.48708 .89394 L
s
.78136 .66068 m .79101 .67425 L .79377 .67078 L 0 .975 .493 r
F
0 g
.78227 .66671 m
.78641 .67252 L
s
.7795 .66974 m
.78227 .66671 L
s
.79101 .67425 m
.79427 .68095 L
s
.57302 .42145 m
.5753 .42086 L
s
.43371 .97336 m .41912 .97194 L .42239 .9749 L 0 1 .539 r
F
0 g
.41585 .97424 m
.42239 .9749 L
s
.49838 .54309 m .5015 .51886 L .49672 .53081 L 0 1 .212 r
F
0 g
.5015 .51886 m
.5029 .51414 L
s
.5015 .51886 m
.50531 .51359 L
s
.54109 .99317 m
.54199 .99475 L
s
.49295 .64234 m .48784 .64297 L .49002 .6438 L 0 1 .345 r
F
.49295 .64234 m .48784 .64 L .48784 .64297 L F
.49295 .64234 m .49002 .63687 L .48784 .64 L F
.49295 .64234 m .49296 .63542 L .49002 .63687 L F
.49295 .64234 m .4947 .6366 L .49296 .63542 L F
0 g
.49295 .64234 m
.49327 .64572 L
s
.4947 .6366 m
.49504 .63644 L
s
.49469 .63957 m
.4947 .6366 L
s
.46874 .69248 m .46047 .69662 L .46498 .69519 L 0 1 .433 r
F
.46874 .69248 m .45756 .69586 L .46047 .69662 L F
.46874 .69248 m .45819 .69341 L .45756 .69586 L F
0 g
.46498 .69519 m
.46812 .69571 L
s
.46874 .69248 m .46196 .6907 L .45819 .69341 L 0 1 .433 r
F
.46874 .69248 m .46634 .68954 L .46196 .6907 L F
.46874 .69248 m .46925 .69031 L .46634 .68954 L F
0 g
.46874 .69248 m
.47173 .69298 L
s
.46498 .69519 m
.46874 .69248 L
s
.46925 .69031 m
.47291 .6878 L
s
.49672 .53081 m .50449 .50462 L .50031 .51097 L 0 1 .173 r
F
0 g
.50449 .50462 m
.5082 .49274 L
s
.39978 .74243 m .38763 .74212 L .38844 .74587 L 0 1 .501 r
F
0 g
.38844 .74587 m
.39243 .74759 L
s
.39978 .74243 m .39047 .73841 L .38763 .74212 L 0 1 .501 r
F
.39978 .74243 m .39507 .73721 L .39047 .73841 L F
.39978 .74243 m .39906 .73893 L .39507 .73721 L F
0 g
.39694 .74614 m
.39978 .74243 L
s
.39978 .74243 m
.40371 .74387 L
s
.54168 .44155 m .55451 .42839 L .5556 .43159 L 0 .01 .067 r
F
.54168 .44155 m .54856 .43264 L .55451 .42839 L F
0 g
.55451 .42839 m
.55494 .4275 L
s
.54856 .43264 m
.55289 .42335 L
s
.54856 .43264 m
.55451 .42839 L
s
.35625 .75417 m .34701 .74767 L .3447 .75178 L 0 1 .517 r
F
.35625 .75417 m .35123 .74691 L .34701 .74767 L F
.35625 .75417 m .35519 .7497 L .35123 .74691 L F
.36666 .75168 m .35519 .7497 L .35625 .75417 L 0 1 .514 r
F
0 g
.35393 .75827 m
.35625 .75417 L
s
.35625 .75417 m
.36014 .75672 L
s
.37697 .93763 m .3617 .93827 L .36376 .94005 L 0 1 .455 r
F
.37697 .93763 m .36485 .93702 L .3617 .93827 L F
.37697 .93763 m .3714 .93675 L .36485 .93702 L F
.38433 .93419 m .3714 .93675 L .37697 .93763 L 0 1 .429 r
F
0 g
.37697 .93763 m
.38328 .93721 L
s
.37697 .93763 m
.37901 .9394 L
s
.49045 .44628 m .48413 .45721 L .48491 .45429 L 0 0 .043 r
F
.49045 .44628 m .48883 .45423 L .48413 .45721 L F
0 g
.48449 .45218 m
.48608 .44977 L
s
.49045 .44628 m .49589 .44734 L .48883 .45423 L 0 0 .043 r
F
.49045 .44628 m .50141 .43934 L .49589 .44734 L F
0 g
.48608 .44977 m
.49045 .44628 L
s
.72481 .91747 m .71972 .9199 L .71876 .92289 L 0 1 .509 r
F
0 g
.71383 .92332 m
.71876 .92289 L
s
.30167 .69859 m .29162 .70629 L .29719 .70559 L 0 1 .465 r
F
0 g
.29719 .70559 m
.30175 .71156 L
s
.50193 .97713 m .50116 .98028 L .50618 .97937 L 0 1 .498 r
F
.50193 .97713 m .49464 .98029 L .50116 .98028 L F
0 g
.50116 .98028 m
.50591 .9813 L
s
.44439 .71858 m .43288 .72301 L .43644 .72374 L 0 1 .466 r
F
0 g
.43335 .7272 m
.43644 .72374 L
s
.44439 .71858 m .43274 .7202 L .43288 .72301 L 0 1 .466 r
F
.44439 .71858 m .43609 .71689 L .43274 .7202 L F
.44439 .71858 m .44072 .71528 L .43609 .71689 L F
.44439 .71858 m .44427 .71601 L .44072 .71528 L F
0 g
.44439 .71858 m
.44792 .71897 L
s
.44103 .72189 m
.44439 .71858 L
s
.48759 .77833 m .48121 .793 L .48448 .79196 L 0 .672 .329 r
F
.51526 .73164 m .51512 .73152 L .51556 .74497 L 0 .586 .29 r
F
0 g
.51516 .73286 m
.51516 .73286 L
s
.51514 .73222 m
.51516 .73286 L
s
.51514 .73222 m
.51514 .73222 L
s
.51514 .73222 m
.51514 .73222 L
s
.51512 .73161 m
.51514 .73222 L
s
.51512 .73161 m
.51512 .73161 L
s
.51512 .73161 m
.51512 .73161 L
s
.51512 .73152 m
.51512 .73161 L
s
.51512 .73151 m
.51512 .73152 L
s
.51471 .71627 m
.51526 .7316 L
s
.49715 1.07789 m .48846 1.07462 L .48137 1.07388 L 0 1 .509 r
F
0 g
.48137 1.07388 m
.48846 1.07462 L
s
.47554 1.06903 m
.48137 1.07388 L
s
.43656 .91847 m .4361 .92058 L .43839 .91897 L 0 1 .276 r
F
.43656 .91847 m .43057 .92237 L .4361 .92058 L F
0 g
.4361 .92058 m
.43844 .92086 L
s
.48159 .72352 m
.48268 .72224 L
s
.48161 .72322 m
.48268 .72224 L
s
.48094 .72383 m
.48161 .72322 L
s
.48045 .72428 m
.48094 .72383 L
s
.47954 .72511 m
.48045 .72428 L
s
.51391 .69308 m .51382 .70848 L .51366 .70009 L 0 .12 .104 r
F
.51391 .69308 m .51466 .71356 L .51382 .70848 L F
.51391 .69308 m .51562 .71191 L .51466 .71356 L F
.51391 .69308 m .51585 .70485 L .51562 .71191 L F
.51391 .69308 m .51522 .69712 L .51585 .70485 L F
0 g
.51438 .69209 m
.51522 .69712 L
s
.51343 .68977 m
.51391 .69308 L
s
.51509 .69054 m
.51522 .69712 L
s
.51556 .68945 m
.51587 .69056 L
s
.51587 .69056 m
.51663 .6933 L
s
.47876 .72587 m
.47916 .72548 L
s
.47916 .72548 m
.47954 .72511 L
s
.49536 .75892 m
.49669 .75698 L
s
.36666 .75168 m .35757 .74572 L .35519 .7497 L 0 1 .514 r
F
.36666 .75168 m .36179 .7449 L .35757 .74572 L F
.36666 .75168 m .36569 .74745 L .36179 .7449 L F
0 g
.36428 .75565 m
.36666 .75168 L
s
.37755 .74889 m .36569 .74745 L .36666 .75168 L 0 1 .511 r
F
0 g
.36666 .75168 m
.37064 .75396 L
s
.48625 .80445 m .47842 .81314 L .48088 .81812 L 0 .643 .339 r
F
0 g
.47839 .80553 m
.47842 .81314 L
s
.47475 .81279 m
.47842 .81314 L
s
.38843 .74587 m .37666 .74491 L .37755 .74889 L 0 1 .507 r
F
.38843 .74587 m .3793 .74113 L .37666 .74491 L F
.38843 .74587 m .38371 .74009 L .3793 .74113 L F
.38843 .74587 m .38763 .74212 L .38371 .74009 L F
0 g
.38579 .74963 m
.38843 .74587 L
s
.51526 .73164 m .51693 .7639 L .51604 .7455 L 0 .586 .29 r
F
.51526 .73164 m .51738 .77743 L .51693 .7639 L F
.51526 .73164 m .51709 .77702 L .51738 .77743 L F
.51526 .73164 m .51631 .76308 L .51709 .77702 L F
.51526 .73164 m .51556 .74497 L .51631 .76308 L F
0 g
.51533 .73292 m
.51533 .73292 L
s
.5153 .73228 m
.51533 .73292 L
s
.5153 .73228 m
.5153 .73228 L
s
.5153 .73227 m
.5153 .73228 L
s
.51526 .73169 m
.5153 .73227 L
s
.51526 .73169 m
.51526 .73169 L
s
.51526 .73169 m
.51526 .73169 L
s
.51526 .73164 m
.51526 .73169 L
s
.51526 .7316 m
.51526 .73164 L
s
.51471 .71627 m
.51571 .7318 L
s
.51555 .74484 m
.51556 .74497 L
s
.51478 .73298 m
.51555 .74484 L
s
.51516 .73286 m
.51556 .74497 L
s
.51572 .73191 m
.51572 .73192 L
s
.51571 .7318 m
.51572 .73191 L
s
.51631 .71693 m
.5179 .73186 L
s
.5163 .71691 m
.51728 .732 L
s
.53614 .72932 m .54442 .75965 L .5397 .73996 L 0 .355 .249 r
F
.53614 .72932 m .54791 .78075 L .54442 .75965 L F
.53614 .72932 m .54784 .7891 L .54791 .78075 L F
.53614 .72932 m .54423 .77829 L .54784 .7891 L F
.53614 .72932 m .53954 .75565 L .54423 .77829 L F
.53614 .72932 m .53608 .73472 L .53954 .75565 L F
.53888 .73272 m .54043 .72393 L .54383 .73565 L 0 .504 .191 r
F
.53898 .7552 m .53969 .74014 L .53939 .74036 L 0 .744 .247 r
F
.53888 .73272 m .53969 .74014 L .53939 .74036 L 0 .504 .191 r
F
.53888 .73272 m .54006 .73985 L .53969 .74014 L F
.53898 .7552 m .54079 .73932 L .54006 .73985 L 0 .744 .247 r
F
.546 .67804 m .55093 .72351 L .54757 .70347 L 0 .32 .184 r
F
.546 .67804 m .55459 .72062 L .55093 .72351 L F
.54264 .70868 m .54403 .69715 L .54757 .70347 L 0 .443 .191 r
F
.54264 .70868 m .54757 .70347 L .55093 .72351 L F
.5449 .73693 m .5462 .73559 L .54491 .73651 L 0 .688 .246 r
F
.54304 .79278 m .54614 .7366 L .5449 .73693 L F
.54614 .7366 m .5462 .73559 L .5449 .73693 L F
.53888 .73272 m .54383 .73565 L .54402 .73716 L 0 .504 .191 r
F
.54304 .79278 m .54821 .73338 L .54621 .73527 L 0 .688 .246 r
F
.54044 .73809 m .54402 .73716 L .54402 .73716 L 0 .504 .191 r
F
.54304 .79278 m .5449 .73693 L .54385 .7403 L 0 .688 .246 r
F
.5449 .73693 m .54479 .73696 L .54385 .7403 L F
.54491 .73651 m .54401 .73738 L .54385 .7403 L F
.53898 .7552 m .54385 .7403 L .54402 .73716 L 0 .744 .247 r
F
.54044 .7381 m .54402 .73716 L .54079 .73932 L 0 .504 .191 r
F
.54044 .73809 m .54402 .73716 L .54044 .7381 L F
.54264 .70868 m .54621 .73527 L .54491 .73651 L 0 .443 .191 r
F
.53888 .73272 m .54402 .73716 L .54044 .73809 L 0 .504 .191 r
F
.54264 .70868 m .54491 .73651 L .54383 .73565 L 0 .443 .191 r
F
.54491 .73651 m .54402 .73716 L .54383 .73565 L F
.54304 .79278 m .55106 .74371 L .55125 .73048 L 0 .688 .246 r
F
.54304 .79278 m .55125 .73048 L .55121 .73052 L F
.54264 .70868 m .55093 .72351 L .55112 .72756 L 0 .443 .191 r
F
.54264 .70868 m .55112 .72756 L .55047 .72844 L F
.54822 .73323 m .55125 .73042 L .54822 .73324 L F
.54264 .70868 m .55124 .7304 L .54822 .73323 L F
.55124 .7304 m .55125 .73042 L .54822 .73323 L F
.54491 .73651 m .54446 .73684 L .54401 .73738 L 0 .688 .246 r
F
.54304 .79278 m .55056 .73545 L .54797 .73613 L F
.5449 .73693 m .54491 .73651 L .54479 .73696 L F
.54491 .73651 m .54685 .76026 L .54402 .73716 L 0 .443 .191 r
F
.54491 .73651 m .54402 .73716 L .54402 .73716 L F
.54491 .73651 m .54492 .7363 L .54446 .73684 L 0 .688 .246 r
F
.54264 .70868 m .54822 .73323 L .54621 .73527 L 0 .443 .191 r
F
.54822 .73323 m .54822 .73324 L .54621 .73527 L F
.5452 .73631 m .54986 .6692 L .54491 .73651 L 0 .688 .246 r
F
.5462 .73559 m .54621 .73527 L .5452 .73631 L F
.54621 .73527 m .54986 .6692 L .5452 .73631 L F
.54492 .7363 m .54647 .6897 L .54402 .73713 L F
.54492 .7363 m .54402 .73713 L .54401 .73738 L F
.54079 .73932 m .54398 .73718 L .54647 .6897 L 0 .744 .247 r
F
.54398 .73718 m .54402 .73716 L .54402 .73713 L F
.54398 .73718 m .54402 .73713 L .54647 .6897 L F
.55047 .72844 m .55112 .72756 L .55125 .73042 L 0 .443 .191 r
F
.54797 .73613 m .55095 .7307 L .54822 .73324 L 0 .688 .246 r
F
.55056 .73545 m .55125 .73015 L .54797 .73613 L F
.54304 .79278 m .54806 .79038 L .55106 .74371 L F
.54822 .73324 m .55125 .73042 L .55218 .75066 L 0 .443 .191 r
F
.55095 .7307 m .55125 .73015 L .54822 .73324 L 0 .688 .246 r
F
.53898 .7552 m .54402 .73716 L .54079 .73932 L 0 .744 .247 r
F
.53898 .7552 m .54063 .76863 L .54385 .7403 L F
.54079 .73932 m .54402 .73716 L .54685 .76026 L 0 .504 .191 r
F
.54491 .73651 m .55045 .76675 L .54685 .76026 L 0 .443 .191 r
F
.55121 .73052 m .55125 .73048 L .55125 .73015 L 0 .688 .246 r
F
.54822 .73324 m .55125 .73015 L .55181 .69195 L F
.54621 .73528 m .55218 .75066 L .55045 .76675 L 0 .443 .191 r
F
.54821 .73338 m .54822 .73324 L .54621 .73527 L 0 .688 .246 r
F
.54822 .73324 m .55218 .75066 L .54621 .73527 L 0 .443 .191 r
F
.54822 .73324 m .55181 .69195 L .54621 .73527 L 0 .688 .246 r
F
.54621 .73527 m .55045 .76675 L .54491 .73651 L 0 .443 .191 r
F
.54621 .73527 m .55181 .69195 L .54986 .6692 L 0 .688 .246 r
F
.54491 .73651 m .54986 .6692 L .54647 .6897 L F
.54006 .73985 m .54685 .76026 L .54768 .7859 L 0 .504 .191 r
F
.53888 .73272 m .54079 .73932 L .54006 .73985 L F
.54079 .73932 m .54685 .76026 L .54006 .73985 L F
.54006 .73985 m .54647 .6897 L .54688 .64337 L 0 .744 .247 r
F
.54079 .73932 m .54647 .6897 L .54006 .73985 L F
.53969 .74014 m .54688 .64337 L .54487 .63158 L F
.53898 .7552 m .54006 .73985 L .53969 .74014 L F
.54006 .73985 m .54688 .64337 L .53969 .74014 L F
.54006 .73985 m .54007 .7399 L .53969 .74014 L 0 .504 .191 r
F
.53969 .74014 m .54768 .7859 L .54573 .7953 L F
.54007 .7399 m .54768 .7859 L .53969 .74014 L F
.53969 .74014 m .5397 .74003 L .53947 .74029 L 0 .744 .247 r
F
.53969 .74014 m .53947 .74029 L .53939 .74036 L F
.53939 .74036 m .54573 .7953 L .54228 .78329 L 0 .504 .191 r
F
.53969 .74014 m .54573 .7953 L .53939 .74036 L F
.53888 .73272 m .53939 .74036 L .53912 .74053 L F
.53912 .74053 m .54169 .65904 L .53945 .708 L 0 .744 .247 r
F
.53898 .7552 m .53939 .74036 L .53912 .74053 L F
.53939 .74036 m .54169 .65904 L .53912 .74053 L F
.53912 .74053 m .53939 .74036 L .53913 .74066 L 0 .504 .191 r
F
.53913 .74066 m .54228 .78329 L .53966 .75807 L F
.53939 .74036 m .54228 .78329 L .53913 .74066 L F
.53939 .74036 m .54487 .63158 L .54169 .65904 L 0 .744 .247 r
F
.5397 .74003 m .54487 .63158 L .53939 .74036 L F
0 g
.54171 .65154 m
.54178 .61937 L
s
.54487 .63158 m
.54495 .57634 L
s
.54673 .66096 m
.54722 .6641 L
s
.54688 .64337 m
.54964 .60367 L
s
.49399 .76094 m .49058 .77604 L .49302 .76888 L 0 .656 .318 r
F
.49399 .76094 m .48759 .77833 L .49058 .77604 L F
0 g
.49399 .76094 m
.49536 .75892 L
s
.44961 .9783 m .44316 .97647 L .43696 .97632 L 0 1 .539 r
F
.45345 .97432 m .44961 .9783 L .4555 .97846 L 0 1 .536 r
F
.45345 .97432 m .44316 .97647 L .44961 .9783 L F
0 g
.44961 .9783 m
.45338 .98094 L
s
.45584 .70783 m .44764 .71274 L .45226 .71095 L 0 1 .453 r
F
.45584 .70783 m .44431 .71213 L .44764 .71274 L F
.45584 .70783 m .44449 .70952 L .44431 .71213 L F
0 g
.45226 .71095 m
.45579 .71134 L
s
.45584 .70783 m .44806 .7064 L .44449 .70952 L 0 1 .453 r
F
.45584 .70783 m .45266 .70486 L .44806 .7064 L F
.45584 .70783 m .45599 .70547 L .45266 .70486 L F
0 g
.45584 .70783 m
.45918 .70811 L
s
.45226 .71095 m
.45584 .70783 L
s
.37755 .74889 m .36827 .74357 L .36569 .74745 L 0 1 .511 r
F
.37755 .74889 m .37268 .74262 L .36827 .74357 L F
.37755 .74889 m .37666 .74491 L .37268 .74262 L F
0 g
.37496 .75277 m
.37755 .74889 L
s
.37755 .74889 m
.38146 .75091 L
s
.54876 1.08882 m
.55153 1.08888 L
s
.50288 .70405 m .49535 .71714 L .49957 .7096 L 0 0 .062 r
F
0 g
.50135 .70534 m
.50241 .70368 L
s
.50288 .70405 m .49251 .72309 L .49535 .71714 L 0 0 .062 r
F
.50288 .70405 m .49294 .72346 L .49251 .72309 L F
.50288 .70405 m .49628 .71787 L .49294 .72346 L F
0 g
.49085 .71539 m
.49297 .71226 L
s
.50288 .70405 m .50028 .71005 L .49628 .71787 L 0 0 .062 r
F
0 g
.50238 .70424 m
.50259 .70385 L
s
.50143 .70473 m
.50184 .704 L
s
.49859 .70821 m
.49975 .70653 L
s
.49859 .70821 m
.50006 .7058 L
s
.50006 .7058 m
.50009 .70575 L
s
.50288 .70405 m .5031 .70414 L .50028 .71005 L 0 0 .062 r
F
0 g
.50288 .70405 m
.50586 .69687 L
s
.50054 .70628 m
.50143 .70473 L
s
.50184 .70527 m
.50238 .70424 L
s
.50228 .70505 m
.50288 .70405 L
s
.5031 .70414 m
.50624 .69704 L
s
.57666 .55938 m .5805 .55541 L .58571 .56689 L 0 .675 .152 r
F
0 g
.5805 .55541 m
.58102 .5351 L
s
.46877 .73386 m .45765 .74203 L .46141 .73894 L 0 0 0 r
F
0 g
.45872 .74075 m
.46141 .73894 L
s
.45675 .74215 m
.45872 .74075 L
s
.3132 .94249 m .31093 .94655 L .31456 .94537 L 0 1 .503 r
F
0 g
.31456 .94537 m
.32197 .94621 L
s
.3132 .94249 m .30392 .94525 L .31093 .94655 L 0 1 .503 r
F
0 g
.31093 .94655 m
.31312 .94935 L
s
.54918 1.06593 m
.54918 1.06593 L
s
.55007 1.0715 m .54672 1.07286 L .54918 1.06594 L 0 0 0 r
F
0 g
.54918 1.06593 m
.54918 1.06593 L
s
.54918 1.06594 m
.54918 1.06593 L
s
.5062 .74472 m
.5064 .74387 L
s
.77325 .76534 m .77846 .77068 L .78316 .77329 L 0 .193 .186 r
F
0 g
.77846 .77068 m
.77982 .77445 L
s
.35613 .67219 m .34559 .67349 L .34794 .67884 L 0 1 .44 r
F
0 g
.34448 .68512 m
.34794 .67884 L
s
.24087 .95048 m .22468 .95025 L .23107 .9527 L 0 1 .384 r
F
0 g
.23107 .9527 m
.23873 .9538 L
s
.35613 .67219 m .34668 .66578 L .34559 .67349 L 0 1 .44 r
F
.35613 .67219 m .35064 .65969 L .34668 .66578 L F
.35613 .67219 m .35482 .65929 L .35064 .65969 L F
.35613 .67219 m .35717 .66465 L .35482 .65929 L F
0 g
.35613 .67219 m
.35852 .67736 L
s
.35217 .67827 m
.35613 .67219 L
s
.40209 .76955 m .39534 .77257 L .39973 .77093 L 0 .867 .244 r
F
.40209 .76955 m .391 .77343 L .39534 .77257 L F
0 g
.39347 .77414 m
.39534 .77257 L
s
.39973 .77093 m
.40431 .76985 L
s
.48625 .80445 m .48419 .79989 L .48083 .80035 L 0 .643 .339 r
F
0 g
.48083 .80035 m
.48121 .793 L
s
.51618 .73224 m .51572 .73195 L .51604 .7455 L 0 .583 .289 r
F
0 g
.51574 .73286 m
.51574 .73286 L
s
.51573 .73233 m
.51574 .73286 L
s
.51573 .73233 m
.51573 .73233 L
s
.51573 .73233 m
.51573 .73233 L
s
.51572 .73195 m
.51573 .73233 L
s
.51617 .73196 m
.51618 .73214 L
s
.51618 .73214 m
.51618 .73216 L
s
.51572 .73192 m
.51572 .73195 L
s
.51552 .71676 m
.51617 .73196 L
s
.51552 .71678 m
.51683 .73204 L
s
.51533 .73292 m
.516 .74487 L
s
.516 .74487 m
.51604 .7455 L
s
.63397 .51528 m
.63399 .51549 L
s
.54227 .98961 m .53922 .9882 L .53988 .99104 L 0 .315 .327 r
F
0 g
.53988 .99104 m
.54045 .99205 L
s
.30167 .69859 m .28774 .70009 L .29162 .70629 L 0 1 .465 r
F
0 g
.28786 .71351 m
.29162 .70629 L
s
.41399 1.03183 m .40634 1.02597 L .39848 1.02293 L 0 1 .498 r
F
0 g
.39848 1.02293 m
.40634 1.02597 L
s
.41399 1.03183 m
.41796 1.03764 L
s
.77618 .88449 m .78708 .87744 L .78294 .87773 L 0 1 .507 r
F
.76597 .88541 m .77618 .88449 L .77672 .87829 L 0 1 .504 r
F
.37762 1.00076 m .37685 1.00877 L .38015 1.00708 L 0 1 .491 r
F
.39521 1.01685 m .38015 1.00708 L .37685 1.00877 L 0 1 .495 r
F
0 g
.37685 1.00877 m
.38013 1.01485 L
s
.36907 1.0049 m
.37685 1.00877 L
s
.49281 .71391 m
.49363 .71265 L
s
.49237 .7146 m
.49281 .71391 L
s
.4908 .71704 m
.49237 .7146 L
s
.49312 .71328 m
.49363 .71265 L
s
.4925 .71407 m
.49312 .71328 L
s
.49197 .71474 m
.4925 .71407 L
s
.49047 .71663 m
.49197 .71474 L
s
.76424 .92994 m .77582 .92899 L .77182 .92794 L 0 1 .529 r
F
.75441 .927 m .76424 .92994 L .76582 .92633 L 0 1 .526 r
F
.35539 .93809 m .35384 .94145 L .35698 .94017 L 0 1 .466 r
F
0 g
.35698 .94017 m
.36376 .94005 L
s
.35539 .93809 m .34732 .94111 L .35384 .94145 L 0 1 .466 r
F
0 g
.35384 .94145 m
.35613 .94341 L
s
.51045 .60147 m .51332 .5968 L .51559 .59347 L 0 0 0 r
F
0 g
.51378 .59629 m
.51433 .59566 L
s
.50193 .97713 m .4902 .97925 L .49464 .98029 L 0 1 .498 r
F
0 g
.48929 .98149 m
.49464 .98029 L
s
.48088 .81812 m .47921 .83035 L .48122 .8255 L 0 .663 .351 r
F
.48728 .83051 m .47921 .83035 L .47997 .83795 L 0 .604 .348 r
F
.48728 .83051 m .48122 .8255 L .47921 .83035 L F
0 g
.47554 .83 m
.47921 .83035 L
s
.45599 .70547 m
.45954 .70242 L
s
.50283 .70471 m
.5031 .70414 L
s
.51618 .73224 m .51891 .76614 L .51755 .74686 L 0 .583 .289 r
F
0 g
.51706 .71669 m
.51838 .7321 L
s
.51618 .73224 m .51693 .7639 L .5183 .77861 L 0 .583 .289 r
F
0 g
.5179 .73186 m
.51795 .73229 L
s
.51728 .732 m
.51731 .73243 L
s
.51618 .73224 m .51604 .7455 L .51693 .7639 L 0 .583 .289 r
F
0 g
.51626 .733 m
.51626 .733 L
s
.5162 .73246 m
.51626 .733 L
s
.5162 .73246 m
.5162 .73246 L
s
.5162 .73246 m
.5162 .73246 L
s
.51618 .73224 m
.5162 .73246 L
s
.51618 .73216 m
.51618 .73224 L
s
.51686 .73244 m
.51687 .7325 L
s
.51685 .73231 m
.51686 .73244 L
s
.51683 .73204 m
.51685 .73231 L
s
.51574 .73286 m
.51604 .7455 L
s
.25652 .79376 m .25032 .79808 L .25472 .79745 L 0 1 .528 r
F
.25652 .79376 m .24543 .79509 L .25032 .79808 L F
0 g
.24944 .80192 m
.25032 .79808 L
s
.25472 .79745 m
.26033 .80011 L
s
.45716 1.05434 m .44602 1.05327 L .45434 1.0581 L 0 .981 .495 r
F
.45716 1.05434 m .44083 1.04855 L .44602 1.05327 L F
.43757 1.04201 m .43376 1.04562 L .44083 1.04855 L 0 .994 .495 r
F
.43757 1.04201 m .42574 1.04025 L .43376 1.04562 L F
.32264 .93488 m .32022 .93673 L .32385 .93551 L 0 .787 .232 r
F
0 g
.32385 .93551 m
.3311 .93404 L
s
.32264 .93488 m .31335 .9377 L .32022 .93673 L 0 .787 .232 r
F
0 g
.32022 .93673 m
.32223 .93732 L
s
.36185 .96414 m .34802 .95794 L .3439 .95951 L 0 1 .537 r
F
.36185 .96414 m .35572 .95993 L .34802 .95794 L F
0 g
.36185 .96414 m
.36365 .96864 L
s
.36919 .96093 m .35572 .95993 L .36185 .96414 L 0 1 .536 r
F
0 g
.36185 .96414 m
.36857 .96629 L
s
.35958 .78279 m .34919 .78194 L .34752 .78381 L 0 1 .406 r
F
.35958 .78279 m .35334 .78109 L .34919 .78194 L F
.35958 .78279 m .3578 .78145 L .35334 .78109 L F
.36974 .77998 m .3578 .78145 L .35958 .78279 L 0 1 .369 r
F
0 g
.3579 .78465 m
.35958 .78279 L
s
.35958 .78279 m
.36394 .78289 L
s
.48759 .77833 m .48448 .79196 L .48692 .78593 L 0 .672 .329 r
F
.50447 .91776 m .50362 .92684 L .50765 .92868 L 0 .443 .371 r
F
.50775 .48906 m .51803 .46831 L .5135 .47642 L 0 0 0 r
F
0 g
.51803 .46831 m
.52275 .45957 L
s
.81724 .68869 m .82555 .68507 L .82094 .68382 L 0 1 .513 r
F
.81724 .68869 m .82872 .69203 L .82555 .68507 L F
0 g
.71349 .61945 m
.71444 .62018 L
s
.71444 .62018 m
.71495 .62057 L
s
.71495 .62057 m
.71553 .62103 L
s
.71553 .62103 m
.71725 .62235 L
s
.43057 .92237 m .41973 .92483 L .41719 .92631 L 0 1 .337 r
F
.43057 .92237 m .42547 .92315 L .41973 .92483 L F
0 g
.43057 .92237 m
.43275 .92303 L
s
.43656 .91847 m .42547 .92314 L .43057 .92237 L 0 1 .276 r
F
0 g
.43057 .92237 m
.4361 .92058 L
s
.55127 .56123 m .55517 .55417 L .55969 .55616 L 0 .295 .131 r
F
0 g
.55517 .55417 m
.55651 .54274 L
s
.48877 .64908 m .49041 .64641 L .49002 .6438 L 0 1 .366 r
F
0 g
.49041 .64641 m
.49276 .64585 L
s
.46877 .73386 m .45704 .74286 L .45765 .74203 L 0 0 0 r
F
.46877 .73386 m .46 .74108 L .45704 .74286 L F
.46877 .73386 m .46453 .73786 L .46 .74108 L F
0 g
.45837 .74143 m
.46141 .73894 L
s
.46877 .73386 m .4683 .73477 L .46453 .73786 L 0 0 0 r
F
0 g
.46877 .73386 m
.46925 .73339 L
s
.46709 .73488 m
.46877 .73386 L
s
.51271 .69537 m .51319 .69449 L .51366 .70009 L 0 .111 .102 r
F
0 g
.51319 .69449 m
.51343 .68977 L
s
.45765 .74203 m .45038 .74639 L .45479 .74354 L 0 0 0 r
F
0 g
.45479 .74354 m
.45675 .74215 L
s
.44023 .5172 m .43203 .52594 L .4346 .52447 L 0 1 .181 r
F
0 g
.43635 .52502 m
.43844 .52234 L
s
.44023 .5172 m .43412 .52109 L .43203 .52594 L 0 1 .181 r
F
.44023 .5172 m .43947 .51313 L .43412 .52109 L F
.44023 .5172 m .44511 .50587 L .43947 .51313 L F
.44023 .5172 m .44727 .50415 L .44511 .50587 L F
0 g
.43844 .52234 m
.44023 .5172 L
s
.44727 .50415 m
.45281 .49643 L
s
.44518 .509 m
.44727 .50415 L
s
.48492 .97983 m .4785 .97919 L .47291 .97994 L 0 1 .529 r
F
.31229 .69734 m .30208 .68993 L .30168 .69859 L 0 1 .461 r
F
0 g
.30168 .69859 m
.30456 .70465 L
s
.31229 .69734 m .30556 .68318 L .30208 .68993 L 0 1 .461 r
F
.31229 .69734 m .3098 .68284 L .30556 .68318 L F
.31229 .69734 m .31269 .68892 L .3098 .68284 L F
0 g
.30881 .70408 m
.31229 .69734 L
s
.31229 .69734 m
.31518 .7032 L
s
.45716 1.05434 m .45434 1.0581 L .46134 1.06058 L 0 .981 .495 r
F
.43757 1.04201 m .42106 1.03517 L .42574 1.04025 L 0 .994 .495 r
F
.48728 .83051 m .47997 .83795 L .483 .84323 L 0 .604 .348 r
F
0 g
.47921 .83035 m
.47997 .83795 L
s
.47619 .8372 m
.47997 .83795 L
s
.51732 .7326 m .51687 .73251 L .51755 .74686 L 0 .578 .287 r
F
0 g
.51688 .73281 m
.51688 .73281 L
s
.51687 .73251 m
.51688 .73281 L
s
.51687 .7325 m
.51687 .73251 L
s
.81375 .79584 m .82411 .79788 L .81955 .79566 L 0 .631 .396 r
F
.81375 .79584 m .82503 .80165 L .82411 .79788 L F
.39126 .96677 m .37569 .96297 L .37834 .96668 L 0 1 .538 r
F
0 g
.37142 .96496 m
.37834 .96668 L
s
.50454 .75191 m .50368 .74959 L .5015 .75504 L 0 .596 .304 r
F
0 g
.50368 .74959 m
.50455 .7389 L
s
.46204 .48037 m .47142 .46752 L .47019 .46995 L 0 0 0 r
F
0 g
.45892 .48511 m
.46204 .48037 L
s
.47142 .46752 m
.47688 .45928 L
s
.46793 .47198 m
.47142 .46752 L
s
.49023 .71631 m .48221 .7243 L .48681 .71944 L 0 0 .034 r
F
0 g
.49034 .71775 m
.4908 .71704 L
s
.49023 .71631 m .4787 .72856 L .48221 .7243 L 0 0 .034 r
F
.49023 .71631 m .47864 .72937 L .4787 .72856 L F
0 g
.47611 .72846 m
.47706 .72753 L
s
.49023 .71631 m .48206 .72623 L .47864 .72937 L 0 0 .034 r
F
0 g
.47706 .72753 m
.47876 .72587 L
s
.47938 .72613 m
.48105 .72416 L
s
.48105 .72416 m
.48159 .72352 L
s
.49023 .71631 m .48669 .72124 L .48206 .72623 L 0 0 .034 r
F
0 g
.49031 .71779 m
.49034 .71775 L
s
.49023 .71631 m .49019 .71698 L .48669 .72124 L 0 0 .034 r
F
0 g
.49023 .71631 m
.49034 .71615 L
s
.48681 .71944 m
.48868 .71724 L
s
.49019 .71698 m
.49047 .71663 L
s
.48681 .71944 m
.49005 .71647 L
s
.49005 .71647 m
.49023 .71631 L
s
.78806 .92248 m .7858 .93158 L .7929 .92899 L 0 1 .525 r
F
.78806 .92248 m .78181 .93055 L .7858 .93158 L F
0 g
.78382 .93559 m
.7858 .93158 L
s
.45345 .97432 m .4555 .97846 L .45692 .97685 L 0 1 .536 r
F
.46897 .97779 m .45692 .97685 L .4555 .97846 L 0 1 .534 r
F
0 g
.4555 .97846 m
.45945 .9806 L
s
.44961 .9783 m
.4555 .97846 L
s
.79727 .59968 m .81059 .60414 L .8087 .60508 L 0 .021 0 r
F
0 g
.81059 .60414 m
.81547 .60526 L
s
.80853 .60135 m
.81059 .60414 L
s
.47015 .68701 m .46196 .6907 L .46634 .68954 L 0 1 .43 r
F
.47015 .68701 m .45931 .68971 L .46196 .6907 L F
.47015 .68701 m .46018 .68722 L .45931 .68971 L F
0 g
.46634 .68954 m
.46925 .69031 L
s
.47015 .68701 m .46399 .68468 L .46018 .68722 L 0 1 .43 r
F
.47015 .68701 m .46821 .68379 L .46399 .68468 L F
.47015 .68701 m .47084 .68478 L .46821 .68379 L F
0 g
.47015 .68701 m
.47291 .6878 L
s
.46634 .68954 m
.47015 .68701 L
s
.47084 .68478 m
.47452 .68249 L
s
.47003 .90315 m .45886 .90922 L .46099 .90887 L 0 .916 .224 r
F
0 g
.46099 .90887 m
.46099 .90887 L
s
.45594 .91152 m
.46099 .90887 L
s
.28774 .70009 m .27949 .70773 L .28403 .7072 L 0 1 .47 r
F
0 g
.28403 .7072 m
.28785 .71352 L
s
.70677 .58634 m
.71283 .57453 L
s
.41318 .76527 m .40633 .76837 L .41072 .76658 L 0 .833 .224 r
F
.41318 .76527 m .40209 .76955 L .40633 .76837 L F
0 g
.40431 .76985 m
.40633 .76837 L
s
.41072 .76658 m
.41518 .76519 L
s
.43288 .72301 m .42495 .72801 L .42954 .72636 L 0 1 .478 r
F
0 g
.42954 .72636 m
.43335 .7272 L
s
.38455 .63296 m .37558 .63917 L .37983 .63867 L 0 1 .423 r
F
.38455 .63296 m .37405 .63417 L .37558 .63917 L F
0 g
.37983 .63867 m
.38188 .6437 L
s
.38455 .63296 m .37626 .62701 L .37405 .63417 L 0 1 .423 r
F
.38455 .63296 m .38099 .62129 L .37626 .62701 L F
.38455 .63296 m .38508 .62083 L .38099 .62129 L F
.38455 .63296 m .38661 .62583 L .38508 .62083 L F
0 g
.38455 .63296 m
.38619 .63787 L
s
.37983 .63867 m
.38455 .63296 L
s
.49702 .76932 m .49302 .76888 L .49058 .77604 L 0 .62 .316 r
F
.49702 .76932 m .49578 .766 L .49302 .76888 L F
0 g
.49302 .76888 m
.49399 .76094 L
s
.49302 .76888 m
.49578 .766 L
s
.49578 .766 m
.49669 .75698 L
s
.49163 .78844 m .48448 .79196 L .48419 .79989 L 0 .628 .327 r
F
.49163 .78844 m .48692 .78593 L .48448 .79196 L F
0 g
.48121 .793 m
.48448 .79196 L
s
.51732 .7326 m .51755 .74686 L .51891 .76614 L 0 .578 .287 r
F
0 g
.51732 .7326 m
.51735 .73283 L
s
.51731 .73243 m
.51732 .7326 L
s
.51626 .733 m
.51755 .74686 L
s
.51688 .73281 m
.51755 .74686 L
s
.51662 .94222 m .51141 .93605 L .50736 .93383 L 0 .36 .36 r
F
0 g
.50362 .92684 m
.50736 .93383 L
s
.53381 .98108 m
.53434 .98178 L
s
.53836 .98707 m
.53842 .98715 L
s
.53473 .9823 m
.53836 .98707 L
s
.53842 .98715 m
.53921 .9882 L
s
.5347 .98165 m
.53544 .98212 L
s
.53381 .98108 m
.5347 .98165 L
s
.79697 .8599 m .80356 .86924 L .80761 .85911 L 0 1 .498 r
F
0 g
.79743 .87693 m
.80356 .86924 L
s
.80356 .86924 m
.80363 .87677 L
s
.44427 .71601 m
.44764 .71274 L
s
.53792 .5649 m .53721 .57764 L .53606 .57349 L 0 .148 .102 r
F
.53792 .5649 m .54116 .57649 L .53721 .57764 L F
.53792 .5649 m .54526 .5708 L .54116 .57649 L F
.53792 .5649 m .5471 .56221 L .54526 .5708 L F
0 g
.53435 .5685 m
.53792 .5649 L
s
.30408 .94055 m .28707 .94176 L .28874 .94288 L 0 .877 .256 r
F
.30408 .94055 m .29096 .94082 L .28707 .94176 L F
.30408 .94055 m .29826 .9403 L .29096 .94082 L F
.31335 .9377 m .29826 .9403 L .30408 .94055 L 0 .818 .246 r
F
0 g
.30408 .94055 m
.30571 .94167 L
s
.30408 .94055 m
.31114 .93981 L
s
.54069 1.07606 m .53323 1.09461 L .54248 1.09552 L 0 1 .483 r
F
.54069 1.07606 m .52606 1.09101 L .53323 1.09461 L F
.50346 .70423 m .49628 .71787 L .50028 .71005 L 0 0 .065 r
F
0 g
.5017 .70554 m
.50184 .70527 L
s
.50111 .70571 m
.50135 .70534 L
s
.50346 .70423 m .49366 .72397 L .49628 .71787 L 0 0 .065 r
F
.50346 .70423 m .49418 .72427 L .49366 .72397 L F
.50346 .70423 m .49738 .71841 L .49418 .72427 L F
.50346 .70423 m .50112 .71032 L .49738 .71841 L F
.50346 .70423 m .50372 .70426 L .50112 .71032 L F
0 g
.50346 .70423 m
.50624 .69704 L
s
.50147 .70598 m
.5017 .70554 L
s
.50095 .70696 m
.50147 .70598 L
s
.50172 .70599 m
.50228 .70505 L
s
.50258 .70524 m
.50283 .70471 L
s
.50335 .70442 m
.50346 .70423 L
s
.503 .70508 m
.50335 .70442 L
s
.50372 .70426 m
.50669 .69709 L
s
.45765 .74203 m .44652 .74904 L .45038 .74639 L 0 0 0 r
F
0 g
.44783 .74798 m
.45038 .74639 L
s
.44532 .74947 m
.44783 .74798 L
s
.483 .84323 m .4825 .85515 L .48408 .85061 L 0 .625 .36 r
F
.49079 .85642 m .4825 .85515 L .48402 .86271 L 0 .556 .355 r
F
.49079 .85642 m .48408 .85061 L .4825 .85515 L F
0 g
.47872 .85439 m
.4825 .85515 L
s
.65604 .56549 m .66535 .5719 L .65925 .54539 L 0 .548 .271 r
F
0 g
.65925 .54539 m
.66086 .55239 L
s
.65829 .52826 m
.65925 .54539 L
s
.65274 .54698 m
.65604 .56549 L
s
.65567 .54645 m
.65604 .56549 L
s
.51722 .97677 m .52223 .97801 L .522 .97718 L 0 1 .452 r
F
0 g
.5175 .97912 m
.52223 .97801 L
s
.52223 .97801 m
.52317 .97797 L
s
.54449 .99665 m
.54477 .99648 L
s
.78584 .59343 m .79248 .59939 L .78793 .59717 L 0 .116 0 r
F
.78584 .59343 m .79727 .59968 L .79248 .59939 L F
.50003 .56094 m .49575 .55736 L .49655 .56435 L 0 1 .244 r
F
.50003 .56094 m .49838 .54309 L .49575 .55736 L F
.50166 .58613 m .50003 .56094 L .49775 .57686 L 0 1 .264 r
F
0 g
.38661 .62583 m
.39122 .62008 L
s
.51271 .69537 m .51178 .71147 L .51211 .70263 L 0 .111 .102 r
F
.51271 .69537 m .51225 .71713 L .51178 .71147 L F
.51271 .69537 m .51322 .7158 L .51225 .71713 L F
0 g
.51256 .69719 m
.51256 .69719 L
s
.51256 .69719 m
.51256 .69718 L
s
.51256 .69718 m
.51257 .69703 L
s
.51257 .69703 m
.51257 .69703 L
s
.51257 .69703 m
.51257 .69703 L
s
.51257 .69703 m
.51258 .69694 L
s
.51258 .69694 m
.51258 .69693 L
s
.51258 .69693 m
.51258 .69693 L
s
.51258 .69693 m
.51262 .69644 L
s
.51262 .69644 m
.51262 .69644 L
s
.51262 .69644 m
.51262 .69644 L
s
.51262 .69644 m
.51263 .69638 L
s
.51263 .69638 m
.51263 .69638 L
s
.51263 .69638 m
.51263 .69638 L
s
.51263 .69638 m
.51267 .6959 L
s
.51267 .6959 m
.51267 .6959 L
s
.51267 .6959 m
.51267 .6959 L
s
.51267 .6959 m
.51268 .69569 L
s
.51268 .69569 m
.51268 .69569 L
s
.51268 .69569 m
.51268 .69569 L
s
.51268 .69569 m
.5127 .69549 L
s
.5127 .69549 m
.5127 .69549 L
s
.5127 .69549 m
.5127 .69549 L
s
.512 .69658 m
.51247 .69241 L
s
.51271 .69537 m .51382 .70848 L .51322 .7158 L 0 .111 .102 r
F
.51271 .69537 m .51366 .70009 L .51382 .70848 L F
0 g
.51366 .70009 m
.51391 .69308 L
s
.5127 .69549 m
.51271 .69537 L
s
.5126 .69131 m
.51271 .69537 L
s
.51319 .69449 m
.51366 .70009 L
s
.74995 .74551 m .7601 .75539 L .76162 .75616 L 0 .043 .154 r
F
0 g
.7601 .75539 m
.7624 .75776 L
s
.75551 .75146 m
.7601 .75539 L
s
.37762 1.00076 m .35942 .99173 L .36196 .99805 L 0 1 .491 r
F
.50454 .75191 m .5015 .75504 L .49947 .76462 L 0 .596 .304 r
F
0 g
.5015 .75504 m
.50241 .74602 L
s
.5015 .75504 m
.50368 .74959 L
s
.48877 .64908 m .483 .65019 L .48559 .6507 L 0 1 .366 r
F
.48877 .64908 m .48259 .64757 L .483 .65019 L F
.48877 .64908 m .48466 .64459 L .48259 .64757 L F
.48877 .64908 m .48784 .64297 L .48466 .64459 L F
.48877 .64908 m .49002 .6438 L .48784 .64297 L F
0 g
.48877 .64908 m
.48947 .65201 L
s
.49002 .6438 m
.49295 .64234 L
s
.49002 .6438 m
.49041 .64641 L
s
.51841 .73244 m .51798 .73257 L .51901 .74766 L 0 .572 .285 r
F
0 g
.51798 .73257 m
.51799 .73265 L
s
.51799 .73265 m
.51901 .74766 L
s
.51735 .73283 m
.51901 .74766 L
s
.51795 .73229 m
.51798 .73257 L
s
.51838 .7321 m
.51841 .73244 L
s
.28774 .70009 m .27638 .70123 L .27949 .70773 L 0 1 .47 r
F
0 g
.27654 .71503 m
.27949 .70773 L
s
.34559 .67349 m .33736 .68015 L .34159 .67965 L 0 1 .447 r
F
0 g
.34159 .67965 m
.34448 .68512 L
s
.5098 .87537 m
.51157 .87356 L
s
.49702 .76932 m .49058 .77604 L .48998 .78442 L 0 .62 .316 r
F
0 g
.48759 .77833 m
.49058 .77604 L
s
.49163 .78844 m .48998 .78442 L .48692 .78593 L 0 .628 .327 r
F
0 g
.48692 .78593 m
.48759 .77833 L
s
.26069 .94228 m .25801 .94892 L .26187 .94795 L 0 1 .535 r
F
.26061 .94419 m .25801 .94892 L .26187 .94795 L 0 1 .524 r
F
.26054 .94609 m .25801 .94892 L .26187 .94795 L 0 1 .328 r
F
0 g
.26187 .94795 m
.26225 .94814 L
s
.26187 .94795 m
.2626 .94814 L
s
.26187 .94795 m
.26191 .94795 L
s
.26069 .94228 m .25085 .94454 L .25801 .94892 L 0 1 .535 r
F
.26061 .94419 m .25077 .94641 L .25801 .94892 L 0 1 .524 r
F
.26054 .94609 m .2507 .94827 L .25801 .94892 L 0 1 .328 r
F
0 g
.25801 .94892 m
.26016 .95448 L
s
.25774 .94889 m
.25801 .94892 L
s
.25217 .95019 m
.25221 .95037 L
s
.25133 .9466 m
.25167 .94806 L
s
.25174 .94837 m
.25217 .95019 L
s
.25213 .95013 m
.25221 .95037 L
s
.25148 .94834 m
.25213 .95013 L
s
.50142 .62002 m
.50196 .6185 L
s
.48625 .80445 m .48088 .81812 L .48425 .81767 L 0 .643 .339 r
F
0 g
.51842 .73253 m
.51845 .73274 L
s
.51841 .73244 m
.51842 .73253 L
s
.51845 .73274 m
.51903 .73718 L
s
.51692 .9504 m .52161 .96045 L .52136 .95741 L 0 .374 .367 r
F
.53107 .96616 m .52161 .96045 L .52637 .96755 L 0 .316 .336 r
F
0 g
.52637 .96755 m
.52637 .96755 L
s
.52637 .96755 m
.52637 .96755 L
s
.53107 .96616 m .52136 .95741 L .52161 .96045 L 0 .316 .336 r
F
0 g
.52198 .96477 m
.52637 .96755 L
s
.51721 .95791 m
.52161 .96045 L
s
.52161 .96045 m
.52289 .96236 L
s
.52289 .96236 m
.52637 .96755 L
s
.36958 .65231 m .36108 .65863 L .36525 .65814 L 0 1 .433 r
F
0 g
.36525 .65814 m
.36764 .66332 L
s
.48674 .97625 m .48492 .97983 L .4902 .97925 L 0 1 .518 r
F
.48674 .97625 m .4785 .97919 L .48492 .97983 L F
0 g
.48492 .97983 m
.48929 .98149 L
s
.42429 .76051 m .41733 .76375 L .42173 .76177 L 0 .778 .196 r
F
.42429 .76051 m .41318 .76527 L .41733 .76375 L F
0 g
.41518 .76519 m
.41733 .76375 L
s
.42173 .76177 m
.42605 .76005 L
s
.44652 .74904 m .43935 .75289 L .44376 .7504 L 0 0 0 r
F
0 g
.44376 .7504 m
.44532 .74947 L
s
.49079 .85642 m .48402 .86271 L .48762 .86825 L 0 .556 .355 r
F
0 g
.4825 .85515 m
.48402 .86271 L
s
.48014 .86158 m
.48402 .86271 L
s
.47734 1.06507 m .46699 1.06485 L .47554 1.06903 L 0 .991 .495 r
F
.47734 1.06507 m .46134 1.06058 L .46699 1.06485 L F
0 g
.50359 .70455 m
.50372 .70426 L
s
.45345 .97432 m .43967 .97395 L .44316 .97647 L 0 1 .536 r
F
0 g
.43696 .97632 m
.44316 .97647 L
s
.43288 .72301 m .42137 .72697 L .42495 .72801 L 0 1 .478 r
F
0 g
.42192 .73152 m
.42495 .72801 L
s
.41875 1.02837 m .41399 1.03183 L .42106 1.03517 L 0 1 .493 r
F
.41875 1.02837 m .40634 1.02597 L .41399 1.03183 L F
.79284 .66439 m .79792 .67672 L .80252 .67826 L 0 1 .503 r
F
.79284 .66439 m .79377 .67078 L .79792 .67672 L F
0 g
.79427 .68095 m
.79792 .67672 L
s
.54722 .6641 m
.54989 .66199 L
s
.75724 .59454 m .76974 .58674 L .7711 .59355 L 0 .25 .055 r
F
0 g
.76974 .58674 m
.7744 .58616 L
s
.78632 .86103 m .78708 .87744 L .79309 .86981 L 0 1 .494 r
F
.78632 .86103 m .78294 .87773 L .78708 .87744 L F
0 g
.78638 .88394 m
.78708 .87744 L
s
.48728 .83051 m .48468 .82556 L .48122 .8255 L 0 .604 .348 r
F
0 g
.48088 .81812 m
.48122 .8255 L
s
.24103 .94682 m .22348 .93583 L .22506 .94186 L 0 1 .536 r
F
.24103 .94682 m .22757 .93506 L .22348 .93583 L F
.24103 .94682 m .2351 .93978 L .22757 .93506 L F
.25085 .94454 m .2351 .93978 L .24103 .94682 L 0 1 .535 r
F
0 g
.24103 .94682 m
.24147 .94853 L
s
.24103 .94682 m
.24317 .94814 L
s
.36974 .77998 m .35957 .77975 L .3578 .78145 L 0 1 .369 r
F
.36974 .77998 m .36372 .77882 L .35957 .77975 L F
.36974 .77998 m .36808 .77892 L .36372 .77882 L F
0 g
.36796 .78168 m
.36974 .77998 L
s
.38037 .77683 m .36809 .77892 L .36974 .77998 L 0 1 .323 r
F
0 g
.36974 .77998 m
.37414 .77976 L
s
.44652 .74904 m .4354 .75514 L .43935 .75289 L 0 0 0 r
F
0 g
.43669 .75441 m
.43935 .75289 L
s
.43693 .75436 m
.43792 .75376 L
s
.4339 .75585 m
.43577 .75493 L
s
.43591 .75486 m
.43693 .75436 L
s
.48439 .89427 m .47449 .9007 L .47673 .89983 L 0 .888 .2 r
F
0 g
.47215 .9028 m
.47673 .89983 L
s
.26761 .79242 m .26133 .7965 L .26574 .79586 L 0 1 .523 r
F
.26761 .79242 m .25652 .79376 L .26133 .7965 L F
0 g
.26033 .80011 m
.26133 .7965 L
s
.26574 .79586 m
.27124 .79828 L
s
.69124 .92854 m .68607 .93336 L .68538 .93647 L 0 1 .439 r
F
0 g
.67778 .93997 m
.68538 .93647 L
s
.36958 .65231 m .35922 .65344 L .36108 .65863 L 0 1 .433 r
F
.36958 .65231 m .36093 .64602 L .35922 .65344 L F
.36958 .65231 m .36527 .64018 L .36093 .64602 L F
.36958 .65231 m .36934 .63981 L .36527 .64018 L F
.36958 .65231 m .37119 .64501 L .36934 .63981 L F
0 g
.36525 .65814 m
.36958 .65231 L
s
.71384 .92042 m
.71385 .92042 L
s
.43288 .72301 m .42119 .72393 L .42137 .72697 L 0 1 .478 r
F
.43288 .72301 m .42453 .72058 L .42119 .72393 L F
.43288 .72301 m .42916 .71915 L .42453 .72058 L F
.43288 .72301 m .43274 .7202 L .42916 .71915 L F
0 g
.43288 .72301 m
.43644 .72374 L
s
.42954 .72636 m
.43288 .72301 L
s
.51018 .60221 m
.51019 .60205 L
s
.51019 .60205 m
.51022 .60174 L
s
.4354 .75514 m .42833 .75863 L .43274 .75642 L 0 0 0 r
F
.4354 .75514 m .42429 .76051 L .42833 .75863 L F
0 g
.42605 .76005 m
.42833 .75863 L
s
.43274 .75642 m
.4339 .75585 L
s
.50193 .97713 m .50618 .97937 L .50637 .97818 L 0 1 .498 r
F
.51722 .97677 m .50637 .97818 L .50618 .97937 L 0 1 .452 r
F
0 g
.50618 .97937 m
.51096 .97978 L
s
.50116 .98028 m
.50618 .97937 L
s
.53592 .72849 m
.53604 .72895 L
s
.50454 .75191 m .5024 .772 L .504 .76151 L 0 .596 .304 r
F
.50454 .75191 m .50022 .77746 L .5024 .772 L F
.50454 .75191 m .49892 .77423 L .50022 .77746 L F
.50454 .75191 m .49947 .76462 L .49892 .77423 L F
0 g
.50454 .75191 m
.5062 .74472 L
s
.75102 1.06831 m .7423 1.07057 L .73813 1.07237 L 0 .876 .271 r
F
0 g
.72859 1.07351 m
.73813 1.07237 L
s
.48762 .86825 m .48834 .87984 L .48947 .8756 L 0 .577 .368 r
F
.4968 .88213 m .48834 .87984 L .49062 .88734 L 0 .497 .36 r
F
0 g
.48666 .88586 m
.49062 .88734 L
s
.4968 .88213 m .48947 .8756 L .48834 .87984 L 0 .497 .36 r
F
0 g
.48446 .8787 m
.48834 .87984 L
s
.48834 .87984 m
.49062 .88734 L
s
.51152 .69738 m .512 .69661 L .51211 .70263 L 0 .098 .099 r
F
0 g
.51201 .69716 m
.51201 .69716 L
s
.51201 .69716 m
.51201 .69716 L
s
.512 .69707 m
.51201 .69716 L
s
.512 .69707 m
.512 .69707 L
s
.512 .69707 m
.512 .69707 L
s
.512 .6968 m
.512 .69707 L
s
.512 .6968 m
.512 .6968 L
s
.512 .6968 m
.512 .6968 L
s
.512 .69661 m
.512 .6968 L
s
.512 .69661 m
.512 .69658 L
s
.51045 .60147 m .51559 .59347 L .51575 .59368 L 0 0 0 r
F
0 g
.51022 .60174 m
.51045 .59923 L
s
.50805 .59449 m
.51045 .59923 L
s
.51559 .59347 m
.51761 .58931 L
s
.51332 .5968 m
.51559 .59347 L
s
.52096 .70391 m .52516 .62095 L .52282 .62507 L 0 .852 .261 r
F
.52096 .70391 m .52613 .64365 L .52516 .62095 L F
0 g
.52516 .62095 m
.52549 .61731 L
s
.52344 .68345 m
.52464 .68754 L
s
.27638 .70123 m .26814 .70902 L .27268 .70851 L 0 1 .474 r
F
0 g
.27268 .70851 m
.27654 .71503 L
s
.47202 .68141 m .46399 .68468 L .46821 .68379 L 0 1 .426 r
F
.47202 .68141 m .46165 .68346 L .46399 .68468 L F
0 g
.46821 .68379 m
.47084 .68478 L
s
.47202 .68141 m .46274 .68092 L .46165 .68346 L 0 1 .426 r
F
.47202 .68141 m .46656 .67854 L .46274 .68092 L F
.47202 .68141 m .47056 .67791 L .46656 .67854 L F
.47202 .68141 m .47289 .67913 L .47056 .67791 L F
0 g
.47202 .68141 m
.47452 .68249 L
s
.46821 .68379 m
.47202 .68141 L
s
.47289 .67913 m
.47654 .67707 L
s
.49163 .78844 m .48419 .79989 L .48625 .80445 L 0 .628 .327 r
F
0 g
.48419 .79989 m
.48448 .79196 L
s
.48083 .80035 m
.48419 .79989 L
s
.46204 .48037 m .45471 .49011 L .45637 .48814 L 0 0 0 r
F
.46204 .48037 m .4582 .48564 L .45471 .49011 L F
0 g
.45339 .49281 m
.45708 .48768 L
s
.46204 .48037 m .46452 .47772 L .4582 .48564 L 0 0 0 r
F
0 g
.45708 .48768 m
.45892 .48511 L
s
.46204 .48037 m .47019 .46995 L .46452 .47772 L 0 0 0 r
F
.45392 .91144 m .44182 .91665 L .44387 .91673 L 0 1 .243 r
F
0 g
.43839 .91897 m
.44387 .91673 L
s
.48485 .65558 m .48638 .65301 L .48559 .6507 L 0 1 .384 r
F
0 g
.48638 .65301 m
.48865 .65228 L
s
.49838 .54309 m .49373 .54351 L .49454 .54843 L 0 1 .212 r
F
.49838 .54309 m .49672 .53081 L .49373 .54351 L F
.30167 .69859 m .28814 .69113 L .28774 .70009 L 0 1 .465 r
F
0 g
.28774 .70009 m
.29162 .70629 L
s
.30167 .69859 m .29262 .6841 L .28814 .69113 L 0 1 .465 r
F
.30167 .69859 m .2982 .68372 L .29262 .6841 L F
.30167 .69859 m .30207 .68993 L .2982 .68372 L F
0 g
.29719 .70559 m
.30167 .69859 L
s
.70244 .9261 m .7131 .92103 L .70938 .92167 L 0 1 .473 r
F
0 g
.71154 .92477 m
.7131 .92103 L
s
.7131 .92103 m
.71382 .92044 L
s
.71382 .92044 m
.71384 .92042 L
s
.50414 .70424 m .49738 .71841 L .50112 .71032 L 0 0 .069 r
F
0 g
.50053 .7063 m
.50054 .70628 L
s
.50098 .70592 m
.50111 .70571 L
s
.50414 .70424 m .49502 .72466 L .49738 .71841 L 0 0 .069 r
F
.50414 .70424 m .49562 .72488 L .49502 .72466 L F
.50414 .70424 m .49866 .71875 L .49562 .72488 L F
.50414 .70424 m .5021 .71039 L .49866 .71875 L F
0 g
.50105 .70712 m
.50172 .70599 L
s
.499 .70899 m
.50053 .7063 L
s
.499 .70899 m
.50098 .70592 L
s
.50414 .70424 m .50444 .70418 L .5021 .71039 L 0 0 .069 r
F
0 g
.50414 .70424 m
.5067 .69708 L
s
.50412 .70428 m
.50414 .70424 L
s
.50444 .70418 m
.50722 .69699 L
s
.78486 .77332 m .78532 .77558 L .7899 .77866 L 0 .269 .203 r
F
.78486 .77332 m .78316 .77329 L .78532 .77558 L F
0 g
.77982 .77445 m
.78532 .77558 L
s
.29451 .95265 m .27737 .94412 L .2791 .94936 L 0 1 .535 r
F
0 g
.27159 .94555 m
.27162 .94555 L
s
.29451 .95265 m .28125 .94317 L .27737 .94412 L 0 1 .535 r
F
0 g
.27162 .94555 m
.27782 .94549 L
s
.29451 .95265 m .2886 .94683 L .28125 .94317 L 0 1 .535 r
F
.30377 .94996 m .2886 .94683 L .29451 .95265 L F
0 g
.29451 .95265 m
.30165 .95615 L
s
.29451 .95265 m
.29622 .95787 L
s
.35717 .66465 m
.36108 .65863 L
s
.78806 .92248 m .78277 .92666 L .78181 .93055 L 0 1 .525 r
F
0 g
.77404 .9328 m
.78181 .93055 L
s
.34559 .67349 m .33504 .6746 L .33736 .68015 L 0 1 .447 r
F
0 g
.33389 .68653 m
.33736 .68015 L
s
.50854 .60581 m
.51019 .60205 L
s
.50767 .60664 m
.50854 .60581 L
s
.50662 .60765 m
.50767 .60664 L
s
.50828 .75066 m
.50831 .74852 L
s
.47734 1.06507 m .47554 1.06903 L .4824 1.07096 L 0 .991 .495 r
F
.73423 .90751 m .74504 .90142 L .74109 .90195 L 0 1 .503 r
F
.74553 .8886 m .74504 .90142 L .75132 .89492 L 0 1 .495 r
F
.74553 .8886 m .74109 .90195 L .74504 .90142 L F
0 g
.74393 .90641 m
.74504 .90142 L
s
.51896 1.08303 m .52606 1.09101 L .52575 1.08711 L 0 1 .533 r
F
.54069 1.07606 m .52575 1.08711 L .52606 1.09101 L 0 1 .483 r
F
0 g
.52606 1.09101 m
.53323 1.09461 L
s
.51932 1.09187 m
.52606 1.09101 L
s
.27638 .70123 m .26503 .7023 L .26814 .70902 L 0 1 .474 r
F
0 g
.26522 .71647 m
.26814 .70902 L
s
.51152 .69738 m .50975 .71385 L .51056 .70476 L 0 .098 .099 r
F
.51152 .69738 m .50986 .71993 L .50975 .71385 L F
.51152 .69738 m .51081 .7189 L .50986 .71993 L F
.51152 .69738 m .51178 .71147 L .51081 .7189 L F
0 g
.51082 .69843 m
.51103 .69713 L
s
.5115 .69751 m
.5115 .69751 L
s
.5115 .69751 m
.5115 .69751 L
s
.51148 .69772 m
.5115 .69751 L
s
.51148 .69772 m
.51148 .69772 L
s
.51148 .69772 m
.51148 .69772 L
s
.51145 .6979 m
.51148 .69772 L
s
.51145 .6979 m
.51145 .6979 L
s
.51145 .6979 m
.51145 .6979 L
s
.5114 .69833 m
.51145 .6979 L
s
.5114 .69833 m
.5114 .69833 L
s
.5114 .69833 m
.5114 .69833 L
s
.51139 .69841 m
.5114 .69833 L
s
.51139 .69841 m
.51139 .69841 L
s
.51139 .69841 m
.51139 .69841 L
s
.51137 .69857 m
.51139 .69841 L
s
.51137 .69857 m
.51137 .69857 L
s
.51137 .69857 m
.51137 .69857 L
s
.51152 .69738 m .51211 .70263 L .51178 .71147 L 0 .098 .099 r
F
0 g
.5115 .69751 m
.51152 .69738 L
s
.51152 .69738 m
.51177 .69266 L
s
.51211 .70263 m
.51256 .69719 L
s
.51201 .69716 m
.51201 .69753 L
s
.51201 .69753 m
.51201 .69753 L
s
.51201 .69753 m
.51201 .69753 L
s
.51201 .69753 m
.51201 .6976 L
s
.51201 .6976 m
.51201 .6976 L
s
.51201 .6976 m
.51201 .6976 L
s
.51201 .6976 m
.51202 .69773 L
s
.51202 .69773 m
.51202 .69773 L
s
.51202 .69773 m
.51202 .69773 L
s
.51202 .69773 m
.51211 .70263 L
s
.41875 1.02837 m .40223 1.02057 L .40634 1.02597 L 0 1 .493 r
F
.45639 .7019 m .44806 .7064 L .45266 .70486 L 0 1 .452 r
F
.45639 .7019 m .44497 .70558 L .44806 .7064 L F
.45639 .7019 m .44543 .70294 L .44497 .70558 L F
0 g
.45266 .70486 m
.45599 .70547 L
s
.45639 .7019 m .44917 .69998 L .44543 .70294 L 0 1 .452 r
F
.45639 .7019 m .45369 .69867 L .44917 .69998 L F
.45639 .7019 m .45679 .6995 L .45369 .69867 L F
0 g
.45639 .7019 m
.45954 .70242 L
s
.45266 .70486 m
.45639 .7019 L
s
.48674 .97625 m .47443 .97759 L .4785 .97919 L 0 1 .518 r
F
0 g
.47291 .97994 m
.4785 .97919 L
s
.47912 .72644 m .47134 .73256 L .47588 .72869 L 0 0 .003 r
F
0 g
.47588 .72869 m
.47848 .72688 L
s
.47588 .72869 m
.47611 .72846 L
s
.42137 .72697 m .41346 .73185 L .41805 .73037 L 0 1 .489 r
F
0 g
.41805 .73037 m
.42192 .73152 L
s
.50661 .60771 m
.50665 .60731 L
s
.72453 .90912 m .73423 .90751 L .73517 .90291 L 0 1 .494 r
F
.48485 .65558 m .47848 .65713 L .48146 .65735 L 0 1 .384 r
F
.48485 .65558 m .47768 .65481 L .47848 .65713 L F
.48485 .65558 m .47961 .65195 L .47768 .65481 L F
.48485 .65558 m .483 .65019 L .47961 .65195 L F
.48485 .65558 m .48559 .6507 L .483 .65019 L F
0 g
.48485 .65558 m
.48592 .65812 L
s
.48559 .6507 m
.48877 .64908 L
s
.48559 .6507 m
.48638 .65301 L
s
.21221 .79898 m .19858 .79433 L .20115 .80026 L 0 1 .538 r
F
0 g
.20115 .80026 m
.20636 .80423 L
s
.66224 .51736 m .66449 .51005 L .661 .50423 L 0 .306 .289 r
F
0 g
.66057 .50313 m
.661 .50423 L
s
.2717 .94558 m
.2784 .94723 L
s
.45679 .6995 m
.46047 .69662 L
s
.34559 .67349 m .33619 .6667 L .33504 .6746 L 0 1 .447 r
F
.34559 .67349 m .34019 .66053 L .33619 .6667 L F
.34559 .67349 m .34437 .66022 L .34019 .66053 L F
.34559 .67349 m .34668 .66578 L .34437 .66022 L F
0 g
.34559 .67349 m
.34794 .67884 L
s
.34159 .67965 m
.34559 .67349 L
s
.51896 1.08303 m .51022 1.08149 L .50349 1.08236 L 0 1 .533 r
F
0 g
.50349 1.08236 m
.51022 1.08149 L
s
.49715 1.07789 m
.50349 1.08236 L
s
.63712 .54683 m
.63763 .56119 L
s
.63706 .54505 m
.63712 .54683 L
s
.63705 .5448 m
.63706 .54505 L
s
.63697 .54261 m
.63705 .5448 L
s
.63695 .54198 m
.63697 .54261 L
s
.63688 .53998 m
.63695 .54198 L
s
.63687 .53994 m
.63688 .53998 L
s
.52347 .4616 m .53543 .44503 L .53604 .44687 L 0 0 .024 r
F
.52347 .4616 m .53005 .45133 L .53543 .44503 L F
0 g
.53543 .44503 m
.5398 .43569 L
s
.53005 .45133 m
.53451 .44234 L
s
.53005 .45133 m
.53543 .44503 L
s
.54069 1.07606 m .54248 1.09552 L .54875 1.08911 L 0 1 .483 r
F
0 g
.54787 1.07954 m
.54858 1.0721 L
s
.45765 .74203 m .44579 .74974 L .44652 .74904 L 0 0 0 r
F
.45765 .74203 m .44865 .74822 L .44579 .74974 L F
.45765 .74203 m .45319 .74552 L .44865 .74822 L F
0 g
.44752 .74836 m
.45038 .74639 L
s
.45765 .74203 m .45704 .74286 L .45319 .74552 L 0 0 0 r
F
0 g
.45765 .74203 m
.45837 .74143 L
s
.45479 .74354 m
.45765 .74203 L
s
.43757 1.04201 m .44083 1.04855 L .44224 1.04709 L 0 .994 .495 r
F
.45716 1.05434 m .44224 1.04709 L .44083 1.04855 L 0 .981 .495 r
F
0 g
.44083 1.04855 m
.44602 1.05327 L
s
.43376 1.04562 m
.44083 1.04855 L
s
.48728 .83051 m .483 .84323 L .48646 .84331 L 0 .604 .348 r
F
.38037 .77683 m .3701 .77734 L .36809 .77892 L 0 1 .323 r
F
.38037 .77683 m .37444 .77628 L .3701 .77734 L F
.38037 .77683 m .37884 .77606 L .37444 .77628 L F
.391 .77343 m .37884 .77606 L .38037 .77683 L 0 1 .272 r
F
0 g
.37835 .77841 m
.38037 .77683 L
s
.38037 .77683 m
.38467 .77632 L
s
.54227 .98961 m .54024 .98758 L .53922 .9882 L 0 .315 .327 r
F
0 g
.53922 .9882 m
.54024 .98758 L
s
.347 .95332 m .3439 .95951 L .34802 .95794 L 0 1 .535 r
F
.347 .95332 m .33643 .95706 L .3439 .95951 L F
0 g
.3439 .95951 m
.34572 .96401 L
s
.47433 .67568 m .46656 .67854 L .47056 .67791 L 0 1 .42 r
F
.47433 .67568 m .46453 .67709 L .46656 .67854 L F
0 g
.47056 .67791 m
.47289 .67913 L
s
.47433 .67568 m .46583 .67451 L .46453 .67709 L 0 1 .42 r
F
.47433 .67568 m .46962 .67228 L .46583 .67451 L F
.47433 .67568 m .47336 .6719 L .46962 .67228 L F
.47433 .67568 m .47538 .67336 L .47336 .6719 L F
0 g
.47433 .67568 m
.47654 .67707 L
s
.47056 .67791 m
.47433 .67568 L
s
.47538 .67336 m
.47895 .67153 L
s
.24095 .94865 m .22321 .94186 L .22487 .94605 L 0 1 .53 r
F
.24095 .94865 m .22729 .94114 L .22321 .94186 L F
.24095 .94865 m .23491 .94406 L .22729 .94114 L F
.25077 .94641 m .23491 .94406 L .24095 .94865 L 0 1 .527 r
F
0 g
.24095 .94865 m
.2416 .95032 L
s
.24095 .94865 m
.24403 .94977 L
s
.25217 .95031 m
.25219 .95034 L
s
.25766 .94889 m
.25774 .94889 L
s
.49702 .76932 m .48998 .78442 L .49163 .78844 L 0 .62 .316 r
F
0 g
.48998 .78442 m
.49058 .77604 L
s
.48692 .78593 m
.48998 .78442 L
s
.47912 .72644 m .46772 .73611 L .47134 .73256 L 0 0 .003 r
F
.47912 .72644 m .46743 .73699 L .46772 .73611 L F
.47912 .72644 m .47068 .73473 L .46743 .73699 L F
.47912 .72644 m .47529 .73085 L .47068 .73473 L F
.47912 .72644 m .47891 .7273 L .47529 .73085 L F
0 g
.47912 .72644 m
.47938 .72613 L
s
.47848 .72688 m
.47912 .72644 L
s
.49079 .85642 m .48763 .85115 L .48408 .85061 L 0 .556 .355 r
F
0 g
.483 .84323 m
.48408 .85061 L
s
.50474 .70412 m .49866 .71875 L .5021 .71039 L 0 0 .071 r
F
0 g
.50403 .70446 m
.50412 .70428 L
s
.50346 .70486 m
.50359 .70455 L
s
.50474 .70412 m .49622 .72508 L .49866 .71875 L 0 0 .071 r
F
.50474 .70412 m .49643 .72513 L .49622 .72508 L F
.50474 .70412 m .49909 .71881 L .49643 .72513 L F
.50474 .70412 m .50242 .71037 L .49909 .71881 L F
0 g
.50433 .70448 m
.50444 .70418 L
s
.50474 .70412 m .50484 .70409 L .50242 .71037 L 0 0 .071 r
F
0 g
.50474 .70412 m
.50721 .69702 L
s
.50484 .70409 m
.50736 .69705 L
s
.684 1.07353 m .69583 1.07405 L .69302 1.07369 L 0 .705 .261 r
F
.70583 1.07261 m .69583 1.07405 L .70457 1.07365 L 0 .689 .241 r
F
.70583 1.07261 m .69302 1.07369 L .69583 1.07405 L F
0 g
.70003 1.07461 m
.70045 1.07452 L
s
.69074 1.07469 m
.69583 1.07405 L
s
.72481 .91747 m .72936 .92355 L .7347 .92079 L 0 1 .509 r
F
0 g
.72254 .92445 m
.72936 .92355 L
s
.72821 .92674 m
.72936 .92355 L
s
.49766 .88494 m .49841 .8941 L .49908 .88964 L 0 .497 .36 r
F
.4968 .88213 m .49723 .88531 L .49766 .88494 L F
.49723 .88531 m .49841 .8941 L .49766 .88494 L F
.49766 .88494 m .49843 .88486 L .4991 .88405 L 0 .834 .169 r
F
.49679 .88547 m .49723 .88531 L .49766 .88494 L F
.49723 .88531 m .49843 .88486 L .49766 .88494 L F
0 g
.49778 .88535 m
.49843 .88486 L
s
.49843 .88486 m
.5004 .88355 L
s
.4985 .76649 m
.49947 .76462 L
s
.51035 .69913 m .51081 .69846 L .51056 .70476 L 0 .082 .096 r
F
0 g
.51079 .69912 m
.51079 .69912 L
s
.51079 .69912 m
.51079 .69912 L
s
.51079 .69912 m
.51079 .699 L
s
.51079 .699 m
.51079 .699 L
s
.51079 .699 m
.51079 .699 L
s
.51079 .699 m
.51079 .69894 L
s
.51079 .69894 m
.51079 .69894 L
s
.51079 .69894 m
.51079 .69894 L
s
.51079 .69894 m
.51081 .69865 L
s
.51081 .69865 m
.51081 .69865 L
s
.51081 .69865 m
.51081 .69865 L
s
.51081 .69865 m
.51081 .69846 L
s
.51036 .69905 m
.51095 .69382 L
s
.51081 .69846 m
.51082 .69843 L
s
.48123 .66189 m .48264 .65939 L .48146 .65735 L 0 1 .398 r
F
0 g
.48264 .65939 m
.48592 .65812 L
s
.44431 .71213 m .43609 .71689 L .44072 .71528 L 0 1 .467 r
F
0 g
.44072 .71528 m
.44427 .71601 L
s
.39171 .93086 m .39041 .93364 L .39327 .93224 L 0 1 .395 r
F
.39171 .93086 m .38433 .93419 L .39041 .93364 L F
0 g
.39041 .93364 m
.39259 .93487 L
s
.42137 .72697 m .40985 .73052 L .41346 .73185 L 0 1 .489 r
F
0 g
.41049 .73542 m
.41346 .73185 L
s
.27871 .79103 m .27235 .79489 L .27676 .79424 L 0 1 .517 r
F
.27871 .79103 m .26761 .79242 L .27235 .79489 L F
0 g
.27124 .79828 m
.27235 .79489 L
s
.27676 .79424 m
.28215 .79641 L
s
.79284 .66439 m .80252 .67826 L .80527 .67438 L 0 1 .503 r
F
0 g
.80252 .67826 m
.80576 .68502 L
s
.26503 .7023 m .25678 .71024 L .26132 .70976 L 0 1 .477 r
F
0 g
.26132 .70976 m
.26522 .71647 L
s
.26185 .94792 m
.26187 .94795 L
s
.49478 .8931 m .49674 .90435 L .49741 .9004 L 0 .517 .372 r
F
.50533 .9076 m .49674 .90435 L .49976 .91178 L 0 .424 .36 r
F
.50533 .9076 m .49741 .9004 L .49674 .90435 L F
0 g
.49277 .90285 m
.49674 .90435 L
s
.75102 1.06831 m .75033 1.07064 L .75936 1.06798 L 0 .876 .271 r
F
0 g
.74124 1.07252 m
.75033 1.07064 L
s
.58346 .42609 m .59068 .42296 L .59759 .42435 L 0 .253 .081 r
F
0 g
.59068 .42296 m
.59457 .41603 L
s
.41288 .9709 m .40021 .96689 L .39768 .96831 L 0 1 .538 r
F
.41288 .9709 m .40672 .96799 L .40021 .96689 L F
.41859 .96722 m .41288 .9709 L .41912 .97194 L F
.41859 .96722 m .40672 .96799 L .41288 .9709 L F
0 g
.41288 .9709 m
.41585 .97424 L
s
.50988 .87506 m
.51171 .87339 L
s
.48123 .66189 m .47435 .66384 L .47768 .66379 L 0 1 .398 r
F
.48123 .66189 m .47316 .6618 L .47435 .66384 L F
.48123 .66189 m .47492 .65903 L .47316 .6618 L F
.48123 .66189 m .47848 .65713 L .47492 .65903 L F
.48123 .66189 m .48146 .65735 L .47848 .65713 L F
0 g
.47768 .66379 m
.48123 .66189 L
s
.48123 .66189 m
.48267 .66405 L
s
.48146 .65735 m
.48485 .65558 L
s
.48146 .65735 m
.48264 .65939 L
s
.49702 .76932 m .49439 .78557 L .49642 .77771 L 0 .62 .316 r
F
.49702 .76932 m .49163 .78844 L .49439 .78557 L F
0 g
.49702 .76932 m
.4985 .76649 L
s
.50648 .43739 m .51355 .431 L .51896 .42956 L 0 .045 .069 r
F
0 g
.51355 .431 m
.51873 .42248 L
s
.44431 .71213 m .43277 .71596 L .43609 .71689 L 0 1 .467 r
F
.44431 .71213 m .43297 .71312 L .43277 .71596 L F
.44431 .71213 m .43657 .70996 L .43297 .71312 L F
.44431 .71213 m .44117 .70859 L .43657 .70996 L F
.44431 .71213 m .44449 .70952 L .44117 .70859 L F
0 g
.44431 .71213 m
.44764 .71274 L
s
.44072 .71528 m
.44431 .71213 L
s
.39783 .96333 m .39768 .96831 L .40021 .96689 L 0 1 .537 r
F
.39783 .96333 m .39126 .96677 L .39768 .96831 L F
0 g
.39768 .96831 m
.40067 .97166 L
s
.50518 .70394 m .49909 .71881 L .50242 .71037 L 0 0 .075 r
F
0 g
.50469 .70423 m
.50474 .70412 L
s
.50422 .70475 m
.50433 .70448 L
s
.50398 .70456 m
.50403 .70446 L
s
.50342 .70497 m
.50346 .70486 L
s
.50253 .70534 m
.50258 .70524 L
s
.50518 .70394 m .49711 .72523 L .49909 .71881 L 0 0 .075 r
F
.50518 .70394 m .49781 .72532 L .49711 .72523 L F
.50518 .70394 m .50058 .71884 L .49781 .72532 L F
.50518 .70394 m .50357 .71014 L .50058 .71884 L F
0 g
.50483 .70411 m
.50484 .70409 L
s
.50518 .70394 m .50553 .70377 L .50357 .71014 L 0 0 .075 r
F
0 g
.50518 .70394 m
.5074 .69693 L
s
.46705 .73579 m
.46765 .7353 L
s
.46765 .7353 m
.4683 .73477 L
s
.47032 .7333 m
.47134 .73256 L
s
.4698 .73368 m
.47032 .7333 L
s
.4683 .73477 m
.4698 .73368 L
s
.70929 .91884 m
.7097 .91737 L
s
.47706 .66983 m .46962 .67228 L .47336 .6719 L 0 1 .412 r
F
.47706 .66983 m .46794 .67059 L .46962 .67228 L F
0 g
.47336 .6719 m
.47538 .67336 L
s
.47706 .66983 m .46944 .66795 L .46794 .67059 L 0 1 .412 r
F
.47706 .66983 m .47315 .66588 L .46944 .66795 L F
.47706 .66983 m .47659 .66575 L .47315 .66588 L F
.47706 .66983 m .47826 .66744 L .47659 .66575 L F
0 g
.47706 .66983 m
.47895 .67153 L
s
.47336 .6719 m
.47706 .66983 L
s
.47826 .66744 m
.48173 .66585 L
s
.41859 .96722 m .41912 .97194 L .4213 .97043 L 0 1 .538 r
F
.43371 .97336 m .4213 .97043 L .41912 .97194 L 0 1 .539 r
F
0 g
.41912 .97194 m
.42239 .9749 L
s
.41288 .9709 m
.41912 .97194 L
s
.51035 .69913 m .50776 .7157 L .50904 .70649 L 0 .082 .096 r
F
.51035 .69913 m .50749 .72206 L .50776 .7157 L F
.51035 .69913 m .50843 .72129 L .50749 .72206 L F
0 g
.50553 .70377 m
.508 .69668 L
s
.50611 .70337 m
.50801 .69665 L
s
.51035 .69913 m .50975 .71385 L .50843 .72129 L 0 .082 .096 r
F
0 g
.50713 .70247 m
.50866 .69626 L
s
.50653 .70299 m
.50863 .69635 L
s
.50858 .70116 m
.50862 .70102 L
s
.50967 .7 m
.50969 .69987 L
s
.51035 .69913 m .51056 .70476 L .50975 .71385 L 0 .082 .096 r
F
0 g
.51022 .69983 m
.51022 .69982 L
s
.51022 .69982 m
.51022 .69982 L
s
.51022 .69982 m
.51025 .69966 L
s
.51025 .69966 m
.51025 .69966 L
s
.51025 .69966 m
.51026 .69959 L
s
.51026 .69959 m
.51026 .69959 L
s
.51026 .69959 m
.51026 .69959 L
s
.51026 .69959 m
.51032 .69925 L
s
.51032 .69925 m
.51032 .69925 L
s
.51032 .69925 m
.51032 .69925 L
s
.51032 .69925 m
.51035 .69913 L
s
.51035 .69913 m
.51036 .69905 L
s
.50969 .69987 m
.51095 .69382 L
s
.50924 .70037 m
.51016 .69479 L
s
.51056 .70476 m
.51137 .69857 L
s
.51056 .70476 m
.51079 .69912 L
s
.51045 .60147 m .50771 .60538 L .50804 .60514 L 0 0 0 r
F
.51045 .60147 m .50999 .60203 L .50771 .60538 L F
0 g
.50674 .60654 m
.50805 .59449 L
s
.51045 .60147 m .51575 .59368 L .51335 .59734 L 0 0 0 r
F
.51045 .60147 m .51335 .59734 L .50999 .60203 L F
0 g
.50804 .60514 m
.51045 .60147 L
s
.51019 .60205 m
.51045 .60147 L
s
.49184 .71714 m
.49375 .71399 L
s
.49358 .71422 m
.49375 .71399 L
s
.49133 .71717 m
.49358 .71422 L
s
.41875 1.02837 m .42106 1.03517 L .42286 1.03376 L 0 1 .493 r
F
.43757 1.04201 m .42286 1.03376 L .42106 1.03517 L 0 .994 .495 r
F
0 g
.42106 1.03517 m
.42574 1.04025 L
s
.41399 1.03183 m
.42106 1.03517 L
s
.52017 .95554 m
.52037 .95585 L
s
.51662 .94222 m .51692 .9504 L .52098 .95264 L 0 .36 .36 r
F
0 g
.51692 .9504 m
.52017 .95554 L
s
.47947 .66509 m .47988 .66433 L .47768 .66379 L 0 1 .408 r
F
0 g
.47988 .66433 m
.48267 .66405 L
s
.47947 .66509 m .47315 .66588 L .47659 .66575 L 0 1 .408 r
F
.47947 .66509 m .47095 .66534 L .47315 .66588 L F
0 g
.47659 .66575 m
.47826 .66744 L
s
.47947 .66509 m .47146 .6645 L .47095 .66534 L 0 1 .408 r
F
.47947 .66509 m .47435 .66384 L .47146 .6645 L F
.47947 .66509 m .47768 .66379 L .47435 .66384 L F
0 g
.47768 .66379 m
.47988 .66433 L
s
.47659 .66575 m
.47947 .66509 L
s
.47947 .66509 m
.48173 .66585 L
s
.34732 .94111 m .32974 .94053 L .33084 .94312 L 0 1 .482 r
F
0 g
.33084 .94311 m
.33084 .94312 L
s
.42845 .53708 m .43306 .52924 L .4346 .52447 L 0 1 .258 r
F
0 g
.43306 .52924 m
.43635 .52502 L
s
.48625 .80445 m .48425 .81767 L .48628 .81207 L 0 .643 .339 r
F
.49158 .81576 m .48425 .81767 L .48468 .82556 L 0 .59 .336 r
F
.49158 .81576 m .48628 .81207 L .48425 .81767 L F
0 g
.48088 .81812 m
.48425 .81767 L
s
.67723 1.07243 m .684 1.07353 L .6888 1.07318 L 0 .667 .252 r
F
.34732 .94111 m .33422 .93913 L .32974 .94053 L 0 1 .482 r
F
.34732 .94111 m .34176 .93938 L .33422 .93913 L F
0 g
.34732 .94111 m
.34839 .94369 L
s
.35539 .93809 m .34176 .93938 L .34732 .94111 L 0 1 .466 r
F
0 g
.34732 .94111 m
.35384 .94145 L
s
.55788 .80868 m
.55878 .80653 L
s
.37405 .63417 m
.37558 .63917 L
s
.37119 .64501 m
.37558 .63917 L
s
.48674 .97625 m .4902 .97925 L .4908 .97785 L 0 1 .518 r
F
.50193 .97713 m .4908 .97785 L .4902 .97925 L 0 1 .498 r
F
0 g
.4902 .97925 m
.49464 .98029 L
s
.48492 .97983 m
.4902 .97925 L
s
.41808 .924 m .41719 .92631 L .41973 .92483 L 0 1 .317 r
F
.41808 .924 m .41148 .92754 L .41719 .92631 L F
0 g
.41719 .92631 m
.41938 .92696 L
s
.26503 .7023 m .25367 .70332 L .25678 .71024 L 0 1 .477 r
F
0 g
.2539 .71786 m
.25678 .71024 L
s
.78632 .86103 m .78261 .87071 L .78294 .87773 L 0 1 .494 r
F
0 g
.77618 .88449 m
.78294 .87773 L
s
.45716 1.05434 m .46134 1.06058 L .46235 1.05906 L 0 .981 .495 r
F
.47734 1.06507 m .46235 1.05906 L .46134 1.06058 L 0 .991 .495 r
F
0 g
.46134 1.06058 m
.46699 1.06485 L
s
.45434 1.0581 m
.46134 1.06058 L
s
.69124 .92854 m .70244 .9261 L .70315 .92297 L 0 1 .439 r
F
0 g
.70244 .9261 m
.70938 .92167 L
s
.41148 .92754 m .39757 .93018 L .39949 .93122 L 0 1 .369 r
F
0 g
.39327 .93224 m
.39949 .93122 L
s
.78486 .77332 m .7899 .77866 L .79467 .78067 L 0 .269 .203 r
F
0 g
.7899 .77866 m
.79115 .78235 L
s
.50677 .75747 m .50587 .75529 L .504 .76151 L 0 .571 .302 r
F
0 g
.50587 .75529 m
.5064 .74387 L
s
.33504 .6746 m .32677 .6813 L .331 .68086 L 0 1 .454 r
F
0 g
.331 .68086 m
.33389 .68653 L
s
.69622 .91376 m
.69827 .91385 L
s
.43274 .7202 m
.43609 .71689 L
s
.391 .77343 m .38095 .77461 L .37884 .77606 L 0 1 .272 r
F
.391 .77343 m .3853 .77345 L .38095 .77461 L F
.391 .77343 m .3896 .77294 L .3853 .77345 L F
0 g
.38888 .77488 m
.391 .77343 L
s
.40209 .76955 m .38961 .77294 L .391 .77343 L 0 .867 .244 r
F
0 g
.391 .77343 m
.39534 .77257 L
s
.21221 .79898 m .20002 .78964 L .19858 .79433 L 0 1 .538 r
F
.21221 .79898 m .20452 .78935 L .20002 .78964 L F
.21221 .79898 m .20975 .79336 L .20452 .78935 L F
.22328 .79769 m .20975 .79336 L .21221 .79898 L 0 1 .537 r
F
0 g
.21075 .80362 m
.21221 .79898 L
s
.21221 .79898 m
.21734 .80271 L
s
.5092 .7006 m .50966 .70004 L .50904 .70649 L 0 .065 .092 r
F
0 g
.50963 .70037 m
.50963 .70037 L
s
.50963 .70037 m
.50963 .70037 L
s
.50963 .70037 m
.50964 .70024 L
s
.50964 .70024 m
.50964 .70024 L
s
.50964 .70024 m
.50964 .70021 L
s
.50964 .70021 m
.50964 .70021 L
s
.50964 .70021 m
.50964 .70021 L
s
.50964 .70021 m
.50966 .70004 L
s
.50862 .70102 m
.51002 .69534 L
s
.50966 .70004 m
.50967 .7 L
s
.50922 .70051 m
.50924 .70037 L
s
.50755 .7021 m
.5094 .69559 L
s
.50815 .70157 m
.5094 .69558 L
s
.49163 .78844 m .48625 .80445 L .48931 .80295 L 0 .628 .327 r
F
.66224 .51736 m .67113 .52977 L .66449 .51005 L 0 .306 .289 r
F
.66224 .51736 m .67649 .55028 L .67113 .52977 L F
.66224 .51736 m .67775 .56351 L .67649 .55028 L F
.66224 .51736 m .67405 .56057 L .67775 .56351 L F
0 g
.66086 .55239 m
.6619 .55691 L
s
.66224 .51736 m .6674 .54076 L .67405 .56057 L 0 .306 .289 r
F
0 g
.65728 .49942 m
.66224 .51736 L
s
.661 .50423 m
.66224 .51736 L
s
.65829 .52826 m
.66403 .54906 L
s
.42137 .72697 m .40965 .72724 L .40985 .73052 L 0 1 .489 r
F
.42137 .72697 m .41296 .72384 L .40965 .72724 L F
.42137 .72697 m .41759 .72259 L .41296 .72384 L F
.42137 .72697 m .42119 .72393 L .41759 .72259 L F
0 g
.42137 .72697 m
.42495 .72801 L
s
.41805 .73037 m
.42137 .72697 L
s
.54069 1.07606 m .54875 1.08911 L .54786 1.07966 L 0 1 .483 r
F
0 g
.54248 1.09552 m
.54875 1.08911 L
s
.3901 .61519 m .38099 .62129 L .38508 .62083 L 0 1 .421 r
F
.3901 .61519 m .38001 .61638 L .38099 .62129 L F
0 g
.38508 .62083 m
.38661 .62583 L
s
.3901 .61519 m .3828 .60938 L .38001 .61638 L 0 1 .421 r
F
.3901 .61519 m .38782 .60374 L .3828 .60938 L F
.3901 .61519 m .39172 .60322 L .38782 .60374 L F
.3901 .61519 m .39269 .60813 L .39172 .60322 L F
0 g
.3901 .61519 m
.39122 .62008 L
s
.38508 .62083 m
.3901 .61519 L
s
.39269 .60813 m
.39756 .60239 L
s
.39126 .96677 m .37854 .96167 L .37569 .96297 L 0 1 .538 r
F
.39126 .96677 m .38522 .9633 L .37854 .96167 L F
.39783 .96333 m .38522 .9633 L .39126 .96677 L 0 1 .537 r
F
0 g
.39126 .96677 m
.3939 .97047 L
s
.39126 .96677 m
.39768 .96831 L
s
.79841 .92449 m .80302 .93128 L .80874 .92647 L 0 1 .529 r
F
0 g
.79576 .93411 m
.80302 .93128 L
s
.39521 1.01685 m .38802 1.01054 L .38015 1.00708 L 0 1 .495 r
F
0 g
.38015 1.00708 m
.38802 1.01054 L
s
.39521 1.01685 m
.39848 1.02293 L
s
.40985 .73052 m .40196 .73531 L .40656 .73397 L 0 1 .497 r
F
0 g
.40656 .73397 m
.41049 .73542 L
s
.49792 1.07359 m .48846 1.07462 L .49715 1.07789 L 0 1 .502 r
F
.49792 1.07359 m .4824 1.07096 L .48846 1.07462 L F
.50533 .9076 m .49976 .91178 L .50447 .91776 L 0 .424 .36 r
F
0 g
.49674 .90435 m
.49976 .91178 L
s
.49574 .90996 m
.49976 .91178 L
s
.27186 .9457 m
.27341 .94649 L
s
.27341 .94649 m
.2791 .94936 L
s
.50608 .70346 m .50058 .71884 L .50357 .71014 L 0 .007 .079 r
F
0 g
.50513 .70405 m
.50518 .70394 L
s
.50477 .70428 m
.50483 .70411 L
s
.50466 .70431 m
.50469 .70423 L
s
.50392 .70468 m
.50398 .70456 L
s
.50247 .70546 m
.50253 .70534 L
s
.50297 .70513 m
.503 .70508 L
s
.50339 .70503 m
.50342 .70497 L
s
.50608 .70346 m .49891 .72536 L .50058 .71884 L 0 .007 .079 r
F
.50608 .70346 m .49968 .72532 L .49891 .72536 L F
.50608 .70346 m .50222 .71858 L .49968 .72532 L F
0 g
.50028 .71005 m
.5007 .70916 L
s
.50028 .71005 m
.50066 .70935 L
s
.50608 .70346 m .50481 .70967 L .50222 .71858 L 0 .007 .079 r
F
0 g
.5055 .70388 m
.50553 .70377 L
s
.50512 .70408 m
.50513 .70405 L
s
.50475 .70432 m
.50477 .70428 L
s
.50463 .70437 m
.50466 .70431 L
s
.50387 .70478 m
.50392 .70468 L
s
.5024 .70561 m
.50247 .70546 L
s
.50288 .70529 m
.50297 .70513 L
s
.50335 .70513 m
.50339 .70503 L
s
.50608 .70346 m .50646 .70321 L .50481 .70967 L 0 .007 .079 r
F
0 g
.50608 .70346 m
.50611 .70337 L
s
.50607 .70349 m
.50608 .70346 L
s
.33643 .95706 m .3198 .95052 L .3217 .95513 L 0 1 .536 r
F
.71481 .91132 m .71959 .91567 L .72453 .90912 L 0 1 .48 r
F
0 g
.71761 .9173 m
.71959 .91567 L
s
.71894 .91893 m
.71959 .91567 L
s
.5092 .7006 m .50582 .71707 L .50756 .70787 L 0 .065 .092 r
F
0 g
.50653 .70301 m
.50653 .70299 L
s
.50711 .70253 m
.50713 .70247 L
s
.5092 .7006 m .50519 .72358 L .50582 .71707 L 0 .065 .092 r
F
.5092 .7006 m .5061 .72304 L .50519 .72358 L F
.5092 .7006 m .50776 .7157 L .5061 .72304 L F
0 g
.50753 .70221 m
.50755 .7021 L
s
.50646 .70321 m
.50653 .70301 L
s
.5092 .7006 m .50904 .70649 L .50776 .7157 L 0 .065 .092 r
F
0 g
.50912 .70095 m
.50913 .70095 L
s
.50913 .70095 m
.50917 .70073 L
s
.50917 .70073 m
.50917 .70073 L
s
.50917 .70073 m
.50917 .70073 L
s
.50917 .70073 m
.5092 .7006 L
s
.5092 .7006 m
.50922 .70051 L
s
.50904 .70649 m
.51022 .69983 L
s
.50904 .70649 m
.50963 .70037 L
s
.50854 .70135 m
.50855 .7013 L
s
.50855 .7013 m
.50858 .70116 L
s
.50813 .70169 m
.50815 .70157 L
s
.49079 .85642 m .48762 .86825 L .49117 .8688 L 0 .556 .355 r
F
.75441 .927 m .76582 .92633 L .76181 .92525 L 0 1 .526 r
F
.74457 .92395 m .75441 .927 L .7558 .92359 L 0 1 .522 r
F
.28774 .70009 m .27679 .69201 L .27638 .70123 L 0 1 .47 r
F
.28774 .70009 m .2805 .68487 L .27679 .69201 L F
.28774 .70009 m .28504 .68459 L .2805 .68487 L F
.28774 .70009 m .28814 .69113 L .28504 .68459 L F
0 g
.28403 .7072 m
.28774 .70009 L
s
.50646 .70323 m
.50646 .70321 L
s
.24087 .95048 m .22293 .9479 L .22468 .95025 L 0 1 .384 r
F
.24087 .95048 m .22702 .94723 L .22293 .9479 L F
.24087 .95048 m .23472 .94834 L .22702 .94723 L F
.2507 .94827 m .23472 .94834 L .24087 .95048 L 0 1 .358 r
F
0 g
.24087 .95048 m
.24801 .95131 L
s
.24087 .95048 m
.24253 .95275 L
s
.30392 .94525 m .28707 .94176 L .28867 .94485 L 0 1 .511 r
F
.30392 .94525 m .29096 .94082 L .28707 .94176 L F
.30392 .94525 m .29819 .94232 L .29096 .94082 L F
.3132 .94249 m .29819 .94232 L .30392 .94525 L 0 1 .503 r
F
0 g
.30392 .94525 m
.31093 .94655 L
s
.30392 .94525 m
.30549 .94833 L
s
.44652 .74904 m .43454 .75565 L .4354 .75514 L 0 0 0 r
F
.44652 .74904 m .4373 .7543 L .43454 .75565 L F
.44652 .74904 m .44184 .75199 L .4373 .7543 L F
.44652 .74904 m .44579 .74974 L .44184 .75199 L F
0 g
.44652 .74904 m
.44752 .74836 L
s
.44376 .7504 m
.44652 .74904 L
s
.4968 .88213 m .4931 .87657 L .48947 .8756 L 0 .497 .36 r
F
0 g
.48762 .86825 m
.48947 .8756 L
s
.25367 .70332 m .24542 .71142 L .24996 .71095 L 0 1 .48 r
F
0 g
.24996 .71095 m
.2539 .71786 L
s
.40089 1.01356 m .39521 1.01684 L .40223 1.02057 L 0 1 .49 r
F
.40089 1.01356 m .38802 1.01054 L .39521 1.01684 L F
.46897 .97779 m .46269 .97656 L .45692 .97685 L 0 1 .534 r
F
0 g
.47043 .73345 m
.47134 .73256 L
s
.46819 .73565 m
.47043 .73345 L
s
.5081 .7018 m .50854 .70135 L .50756 .70787 L 0 .046 .088 r
F
0 g
.50852 .70146 m
.50852 .70146 L
s
.50852 .70146 m
.50854 .70135 L
s
.5081 .7018 m
.50813 .70169 L
s
.50854 .70135 m
.50854 .70135 L
s
.55127 .56123 m .55969 .55616 L .56183 .56591 L 0 .295 .131 r
F
0 g
.55969 .55616 m
.56084 .542 L
s
.55517 .55417 m
.55969 .55616 L
s
.50706 .70275 m .50222 .71858 L .50481 .70967 L 0 .026 .084 r
F
0 g
.5055 .70389 m
.5055 .70388 L
s
.50512 .70408 m
.50512 .70408 L
s
.50334 .70513 m
.50335 .70513 L
s
.50288 .70529 m
.50288 .70529 L
s
.5024 .70561 m
.5024 .70561 L
s
.50387 .70478 m
.50387 .70478 L
s
.50463 .70437 m
.50463 .70437 L
s
.50475 .70432 m
.50475 .70432 L
s
.50706 .70275 m .50088 .72516 L .50222 .71858 L 0 .026 .084 r
F
.50706 .70275 m .5017 .72499 L .50088 .72516 L F
0 g
.50112 .71032 m
.50121 .71014 L
s
.50112 .71032 m
.50121 .71011 L
s
.49957 .7096 m
.50095 .70696 L
s
.49957 .7096 m
.50105 .70712 L
s
.50706 .70275 m .50397 .71801 L .5017 .72499 L 0 .026 .084 r
F
0 g
.5007 .70916 m
.5024 .70561 L
s
.50066 .70935 m
.50288 .70529 L
s
.50192 .70845 m
.50243 .70727 L
s
.50195 .70864 m
.50254 .70747 L
s
.50251 .7093 m
.50284 .70843 L
s
.50213 .7103 m
.50251 .7093 L
s
.50251 .70941 m
.50288 .70852 L
s
.5021 .71039 m
.50251 .70941 L
s
.50262 .70987 m
.50298 .70893 L
s
.50242 .71037 m
.50262 .70987 L
s
.5021 .71039 m
.50213 .7103 L
s
.50121 .71011 m
.50192 .70845 L
s
.50121 .71014 m
.50195 .70864 L
s
.50706 .70275 m .50615 .70892 L .50397 .71801 L 0 .026 .084 r
F
0 g
.50645 .70328 m
.50646 .70323 L
s
.50605 .70355 m
.50607 .70349 L
s
.50546 .70402 m
.5055 .70389 L
s
.50505 .70424 m
.50512 .70408 L
s
.50419 .70484 m
.50422 .70475 L
s
.50455 .70457 m
.50463 .70437 L
s
.50468 .70451 m
.50475 .70432 L
s
.50706 .70275 m .50747 .7024 L .50615 .70892 L 0 .026 .084 r
F
0 g
.50706 .70275 m
.50711 .70253 L
s
.5081 .7018 m .50397 .71801 L .50615 .70892 L 0 .046 .088 r
F
0 g
.50749 .70232 m
.50753 .70221 L
s
.5081 .7018 m .50298 .7246 L .50397 .71801 L 0 .046 .088 r
F
.5081 .7018 m .50385 .72425 L .50298 .7246 L F
0 g
.50243 .70727 m
.50334 .70513 L
s
.50284 .70843 m
.50328 .70724 L
s
.50288 .70852 m
.50339 .70733 L
s
.50242 .71037 m
.503 .70902 L
s
.5081 .7018 m .50582 .71707 L .50385 .72425 L 0 .046 .088 r
F
0 g
.50357 .71014 m
.50546 .70402 L
s
.503 .70902 m
.50505 .70424 L
s
.50328 .70724 m
.50419 .70484 L
s
.50339 .70733 m
.50455 .70457 L
s
.50298 .70893 m
.50468 .70451 L
s
.50254 .70747 m
.50387 .70478 L
s
.5081 .7018 m .50756 .70787 L .50582 .71707 L 0 .046 .088 r
F
0 g
.50615 .70892 m
.50806 .70196 L
s
.50806 .70196 m
.50806 .70196 L
s
.50806 .70196 m
.5081 .7018 L
s
.50747 .7024 m
.50749 .70232 L
s
.50481 .70967 m
.50702 .70288 L
s
.50702 .70288 m
.50704 .7028 L
s
.50704 .7028 m
.50706 .70275 L
s
.50481 .70967 m
.50643 .70335 L
s
.50643 .70335 m
.50645 .70328 L
s
.50357 .71014 m
.50601 .70366 L
s
.50601 .70366 m
.50605 .70355 L
s
.50756 .70787 m
.50912 .70095 L
s
.5081 .7018 m
.5081 .7018 L
s
.50756 .70787 m
.50852 .70146 L
s
.50615 .70892 m
.50746 .70244 L
s
.50746 .70244 m
.50747 .7024 L
s
.31305 .9473 m .31071 .95332 L .31434 .95219 L 0 1 .535 r
F
.31305 .9473 m .30377 .94996 L .31071 .95332 L F
0 g
.31071 .95332 m
.31284 .95809 L
s
.47182 .97405 m .46897 .97779 L .47443 .97759 L 0 1 .528 r
F
.47182 .97405 m .46269 .97656 L .46897 .97779 L F
0 g
.46897 .97779 m
.47291 .97994 L
s
.49158 .81576 m .48468 .82556 L .48728 .83051 L 0 .59 .336 r
F
0 g
.48425 .81767 m
.48468 .82556 L
s
.48122 .8255 m
.48468 .82556 L
s
.40985 .73052 m .39834 .73368 L .40196 .73531 L 0 1 .497 r
F
0 g
.39906 .73893 m
.40196 .73531 L
s
.53107 .96616 m .52541 .95984 L .52136 .95741 L 0 .316 .336 r
F
0 g
.52136 .95741 m
.52541 .95984 L
s
.52037 .95585 m
.52136 .95741 L
s
.80761 .85911 m .81825 .85862 L .8182 .85104 L 0 1 .501 r
F
.28982 .78961 m .28337 .79325 L .28779 .79258 L 0 1 .509 r
F
.28982 .78961 m .27871 .79103 L .28337 .79325 L F
0 g
.28215 .79641 m
.28337 .79325 L
s
.28779 .79258 m
.29307 .79449 L
s
.33643 .95706 m .32344 .94941 L .3198 .95052 L 0 1 .536 r
F
0 g
.31434 .95219 m
.31692 .95322 L
s
.31692 .95322 m
.3217 .95513 L
s
.33643 .95706 m .33057 .95222 L .32344 .94941 L 0 1 .536 r
F
0 g
.33643 .95706 m
.3383 .96166 L
s
.347 .95332 m .33058 .95222 L .33643 .95706 L 0 1 .535 r
F
0 g
.33643 .95706 m
.3439 .95951 L
s
.49158 .81576 m .48942 .81125 L .48628 .81207 L 0 .59 .336 r
F
0 g
.48625 .80445 m
.48628 .81207 L
s
.50677 .75747 m .504 .76151 L .5024 .772 L 0 .571 .302 r
F
0 g
.504 .76151 m
.50454 .75191 L
s
.504 .76151 m
.50587 .75529 L
s
.64118 .45671 m .64135 .45885 L .63852 .45321 L 0 .235 0 r
F
.64118 .45671 m .64854 .47074 L .64135 .45885 L F
.64118 .45671 m .64757 .46701 L .65474 .47887 L F
0 g
.64757 .46701 m
.64858 .46797 L
s
.64016 .45537 m
.64118 .45671 L
s
.63426 .44353 m
.64118 .45671 L
s
.65361 .47858 m
.65535 .48301 L
s
.54346 .4244 m .5508 .42149 L .55714 .42419 L 0 .268 .095 r
F
0 g
.5508 .42149 m
.55547 .41367 L
s
.77768 .92042 m .77582 .92899 L .78277 .92666 L 0 1 .521 r
F
.77768 .92042 m .77182 .92794 L .77582 .92899 L F
0 g
.77404 .9328 m
.77582 .92899 L
s
.49679 .88547 m .4883 .89179 L .49061 .89037 L 0 .834 .169 r
F
0 g
.48662 .89341 m
.49061 .89037 L
s
.40209 .76955 m .39196 .77155 L .38961 .77294 L 0 .867 .244 r
F
.40209 .76955 m .39648 .7702 L .39196 .77155 L F
.40209 .76955 m .40083 .76934 L .39648 .7702 L F
.41318 .76527 m .40083 .76934 L .40209 .76955 L 0 .833 .224 r
F
0 g
.39973 .77093 m
.40209 .76955 L
s
.40209 .76955 m
.40633 .76837 L
s
.51837 .58976 m .5217 .58434 L .52469 .58173 L 0 0 .025 r
F
0 g
.5217 .58434 m
.52372 .5802 L
s
.25367 .70332 m .2423 .7043 L .24542 .71142 L 0 1 .48 r
F
0 g
.24258 .71921 m
.24542 .71142 L
s
.49163 .78844 m .48931 .80295 L .49134 .79638 L 0 .628 .327 r
F
.33504 .6746 m .32448 .67554 L .32677 .6813 L 0 1 .454 r
F
0 g
.32329 .68779 m
.32677 .6813 L
s
.55476 .72623 m
.55479 .72238 L
s
.55476 .72645 m
.55476 .72623 L
s
.55476 .72652 m
.55476 .72645 L
s
.5547 .73688 m
.55476 .72652 L
s
.54986 .6692 m .55181 .69195 L .55527 .64513 L 0 .831 .236 r
F
0 g
.55181 .69195 m
.55527 .64513 L
s
.55479 .72238 m
.55527 .64513 L
s
.55444 .67136 m
.55512 .66847 L
s
.54986 .6692 m
.5502 .59574 L
s
.65343 .65857 m
.65343 .65857 L
s
.65414 .63628 m
.65419 .63466 L
s
.65292 .67441 m
.65295 .67348 L
s
.44449 .70952 m
.44806 .7064 L
s
.43371 .97336 m .42755 .97104 L .4213 .97043 L 0 1 .539 r
F
.43851 .96958 m .43371 .97336 L .43967 .97395 L 0 1 .537 r
F
.43851 .96958 m .42755 .97104 L .43371 .97336 L F
0 g
.43371 .97336 m
.43696 .97632 L
s
.4902 .71796 m .48206 .72623 L .48669 .72124 L 0 0 .04 r
F
.4902 .71796 m .47865 .73057 L .48206 .72623 L F
.4902 .71796 m .47873 .73136 L .47865 .73057 L F
.4902 .71796 m .48225 .72807 L .47873 .73136 L F
0 g
.48069 .72614 m
.48221 .7243 L
s
.48131 .72511 m
.48221 .7243 L
s
.47891 .7273 m
.4796 .72666 L
s
.4796 .72666 m
.47994 .72636 L
s
.47994 .72636 m
.48131 .72511 L
s
.47896 .72824 m
.48027 .72665 L
s
.48027 .72665 m
.48069 .72614 L
s
.4902 .71796 m .48686 .7229 L .48225 .72807 L 0 0 .04 r
F
.4902 .71796 m .49026 .71857 L .48686 .7229 L F
0 g
.4902 .71796 m
.49031 .71779 L
s
.48669 .72124 m
.48762 .72011 L
s
.48762 .72011 m
.49019 .71698 L
s
.48669 .72124 m
.4902 .71796 L
s
.49026 .71857 m
.49133 .71717 L
s
.71349 .61945 m
.71479 .62143 L
s
.71479 .62143 m
.71479 .62143 L
s
.36919 .96093 m .35347 .95589 L .35572 .95993 L 0 1 .536 r
F
0 g
.34802 .95794 m
.35572 .95993 L
s
.50022 .77746 m .49642 .77771 L .49439 .78557 L 0 .583 .314 r
F
.50022 .77746 m .49892 .77423 L .49642 .77771 L F
0 g
.49642 .77771 m
.49702 .76932 L
s
.49892 .77423 m
.49947 .76462 L
s
.51028 .7528 m
.51029 .75353 L
s
.50677 .75747 m .50544 .77908 L .50659 .76766 L 0 .571 .302 r
F
.50677 .75747 m .50357 .78531 L .50544 .77908 L F
.50677 .75747 m .50221 .7822 L .50357 .78531 L F
.50677 .75747 m .5024 .772 L .50221 .7822 L F
0 g
.50677 .75747 m
.50831 .74852 L
s
.58346 .42609 m .59759 .42435 L .59959 .42936 L 0 .253 .081 r
F
0 g
.59759 .42435 m
.60123 .42049 L
s
.59068 .42296 m
.59759 .42435 L
s
.4354 .75514 m .4233 .7608 L .42429 .76051 L 0 0 0 r
F
.4354 .75514 m .42595 .75952 L .4233 .7608 L F
.4354 .75514 m .43049 .75753 L .42595 .75952 L F
.4354 .75514 m .43454 .75565 L .43049 .75753 L F
0 g
.4354 .75514 m
.43669 .75441 L
s
.42845 .53708 m .41985 .54518 L .42279 .54392 L 0 1 .258 r
F
0 g
.42507 .54468 m
.42719 .54211 L
s
.42845 .53708 m .42137 .54041 L .41985 .54518 L 0 1 .258 r
F
.42845 .53708 m .42636 .53278 L .42137 .54041 L F
.42845 .53708 m .43203 .52594 L .42636 .53278 L F
.42845 .53708 m .4346 .52447 L .43203 .52594 L F
0 g
.42719 .54211 m
.42845 .53708 L
s
.4346 .52447 m
.44023 .5172 L
s
.43306 .52924 m
.4346 .52447 L
s
.22328 .79769 m .21128 .78892 L .20975 .79336 L 0 1 .537 r
F
.22328 .79769 m .21579 .78863 L .21128 .78892 L F
.22328 .79769 m .22093 .7924 L .21579 .78863 L F
.23435 .7964 m .22093 .7924 L .22328 .79769 L 0 1 .535 r
F
0 g
.22173 .8021 m
.22328 .79769 L
s
.22328 .79769 m
.22833 .80118 L
s
.74553 .8886 m .75132 .89492 L .75576 .88676 L 0 1 .495 r
F
0 g
.74504 .90142 m
.75132 .89492 L
s
.75096 .90076 m
.75132 .89492 L
s
.49504 .52251 m .504 .50104 L .50368 .4993 L 0 1 .158 r
F
.49504 .52251 m .50031 .51097 L .504 .50104 L F
0 g
.504 .50104 m
.5082 .49274 L
s
.50244 .50523 m
.504 .50104 L
s
.50031 .51097 m
.50244 .50523 L
s
.67043 1.07136 m .6684 1.07217 L .67723 1.07243 L 0 .618 .243 r
F
0 g
.66765 1.0721 m
.6684 1.07217 L
s
.66752 1.07224 m
.6684 1.07217 L
s
.74553 .8886 m .7413 .89647 L .74109 .90195 L 0 1 .495 r
F
0 g
.73423 .90751 m
.74109 .90195 L
s
.39834 .73368 m .39047 .73841 L .39507 .73721 L 0 1 .504 r
F
0 g
.39507 .73721 m
.39906 .73893 L
s
.41318 .76527 m .40328 .76804 L .40083 .76934 L 0 .833 .224 r
F
.41318 .76527 m .40781 .76651 L .40328 .76804 L F
.41318 .76527 m .41206 .76533 L .40781 .76651 L F
.42429 .76051 m .41206 .76533 L .41318 .76527 L 0 .778 .196 r
F
0 g
.41072 .76658 m
.41318 .76527 L
s
.41318 .76527 m
.41733 .76375 L
s
.32249 .93978 m .32001 .94362 L .32365 .94245 L 0 1 .493 r
F
0 g
.32365 .94245 m
.33084 .94312 L
s
.32249 .93978 m .3132 .94249 L .32001 .94362 L 0 1 .493 r
F
0 g
.32001 .94362 m
.32197 .94621 L
s
.36139 .98365 m .35178 .98746 L .35942 .99173 L 0 1 .487 r
F
.36139 .98365 m .3453 .98019 L .35178 .98746 L F
0 g
.41973 .92483 m
.42547 .92315 L
s
.43656 .91847 m .42363 .92265 L .42547 .92314 L 0 1 .276 r
F
0 g
.42547 .92314 m
.42547 .92314 L
s
.45756 .69586 m .44917 .69998 L .45369 .69867 L 0 1 .45 r
F
.45756 .69586 m .44635 .69896 L .44917 .69998 L F
.45756 .69586 m .4471 .69629 L .44635 .69896 L F
0 g
.45369 .69867 m
.45679 .6995 L
s
.45756 .69586 m .45097 .69347 L .4471 .69629 L 0 1 .45 r
F
.45756 .69586 m .45537 .69239 L .45097 .69347 L F
.45756 .69586 m .45819 .69341 L .45537 .69239 L F
0 g
.45756 .69586 m
.46047 .69662 L
s
.45369 .69867 m
.45756 .69586 L
s
.45819 .69341 m
.46196 .6907 L
s
.35922 .65344 m .35064 .65969 L .35482 .65929 L 0 1 .443 r
F
0 g
.35482 .65929 m
.35717 .66465 L
s
.49792 1.07359 m .49715 1.07789 L .5038 1.07902 L 0 1 .502 r
F
.41148 .92754 m .40043 .92884 L .39757 .93018 L 0 1 .369 r
F
.41148 .92754 m .4064 .9277 L .40043 .92884 L F
.41808 .924 m .4064 .9277 L .41148 .92754 L 0 1 .317 r
F
0 g
.41148 .92754 m
.41719 .92631 L
s
.41148 .92754 m
.41338 .92857 L
s
.42429 .76051 m .41461 .76406 L .41206 .76533 L 0 .778 .196 r
F
.42429 .76051 m .41915 .76232 L .41461 .76406 L F
.42429 .76051 m .4233 .7608 L .41915 .76232 L F
0 g
.42173 .76177 m
.42429 .76051 L
s
.42429 .76051 m
.42833 .75863 L
s
.47825 .72794 m
.47853 .72766 L
s
.47853 .72766 m
.47891 .7273 L
s
.50447 .91776 m .50765 .92868 L .50785 .925 L 0 .443 .371 r
F
.51631 .93281 m .50765 .92868 L .51141 .93605 L 0 .343 .351 r
F
0 g
.50736 .93383 m
.5114 .93605 L
s
.5114 .93605 m
.51141 .93605 L
s
.51631 .93281 m .50785 .925 L .50765 .92868 L 0 .343 .351 r
F
0 g
.50362 .92684 m
.50765 .92868 L
s
.2423 .7043 m .23405 .71256 L .2386 .71211 L 0 1 .483 r
F
0 g
.2386 .71211 m
.24258 .71921 L
s
.64757 .46701 m
.65377 .47726 L
s
.65377 .47726 m
.65445 .47839 L
s
.65445 .47839 m
.65474 .47887 L
s
.54069 1.07606 m .53202 1.08069 L .52575 1.08711 L 0 1 .483 r
F
0 g
.54069 1.07606 m
.54786 1.07966 L
s
.53939 1.07528 m .54069 1.07605 L .54671 1.07287 L 0 1 .527 r
F
.53939 1.07528 m .53202 1.08069 L .54069 1.07605 L F
.78632 .86103 m .79309 .86981 L .79697 .8599 L 0 1 .494 r
F
0 g
.78708 .87744 m
.79309 .86981 L
s
.79309 .86981 m
.79329 .87709 L
s
.80432 .66764 m .80943 .68046 L .81403 .68185 L 0 1 .51 r
F
.80432 .66764 m .80527 .67438 L .80943 .68046 L F
0 g
.80576 .68502 m
.80943 .68046 L
s
.522 .97718 m
.52283 .97697 L
s
.52283 .97697 m
.52352 .9768 L
s
.52352 .9768 m
.52416 .97664 L
s
.52416 .97664 m
.52638 .97609 L
s
.38433 .93419 m .36958 .93517 L .3714 .93675 L 0 1 .429 r
F
.76597 .88541 m .77672 .87829 L .77258 .87874 L 0 1 .504 r
F
.75576 .88676 m .76597 .88541 L .76635 .87954 L 0 1 .5 r
F
.39834 .73368 m .38682 .73651 L .39047 .73841 L 0 1 .504 r
F
0 g
.38763 .74212 m
.39047 .73841 L
s
.33504 .6746 m .32568 .66742 L .32448 .67554 L 0 1 .454 r
F
.33504 .6746 m .32973 .66115 L .32568 .66742 L F
.33504 .6746 m .33391 .66093 L .32973 .66115 L F
.33504 .6746 m .33619 .6667 L .33391 .66093 L F
0 g
.33504 .6746 m
.33736 .68015 L
s
.331 .68086 m
.33504 .6746 L
s
.4959 .79835 m .48931 .80295 L .48942 .81125 L 0 .582 .324 r
F
.4959 .79835 m .49134 .79638 L .48931 .80295 L F
0 g
.48625 .80445 m
.48931 .80295 L
s
.50166 .58613 m .49775 .57686 L .49855 .58656 L 0 1 .264 r
F
0 g
.49974 .6036 m
.50166 .58613 L
s
.49478 .8931 m
.49608 .89671 L
s
.43851 .96958 m .43967 .97395 L .44148 .97241 L 0 1 .537 r
F
.45345 .97432 m .44148 .97241 L .43967 .97395 L 0 1 .536 r
F
0 g
.43967 .97395 m
.44316 .97647 L
s
.43371 .97336 m
.43967 .97395 L
s
.50022 .77746 m .49439 .78557 L .49416 .79441 L 0 .583 .314 r
F
0 g
.49642 .77771 m
.49892 .77423 L
s
.49163 .78844 m
.49439 .78557 L
s
.52096 .70391 m .52282 .62507 L .52061 .65067 L 0 .852 .261 r
F
0 g
.52241 .62985 m
.52282 .62507 L
s
.52216 .68998 m
.52381 .6906 L
s
.52151 .60788 m
.52282 .62507 L
s
.51968 .62755 m
.52151 .60788 L
s
.48728 .83051 m .48646 .84331 L .48804 .83812 L 0 .604 .348 r
F
.49397 .84282 m .48646 .84331 L .48763 .85115 L 0 .541 .343 r
F
.49397 .84282 m .48804 .83812 L .48646 .84331 L F
0 g
.483 .84323 m
.48646 .84331 L
s
.40089 1.01356 m .40223 1.02057 L .40439 1.01923 L 0 1 .49 r
F
.41875 1.02837 m .40439 1.01923 L .40223 1.02057 L 0 1 .493 r
F
0 g
.40223 1.02057 m
.40634 1.02597 L
s
.39521 1.01684 m
.40223 1.02057 L
s
.37654 .95778 m .37569 .96297 L .37854 .96167 L 0 1 .536 r
F
.37654 .95778 m .36919 .96093 L .37569 .96297 L F
0 g
.37569 .96297 m
.37834 .96668 L
s
.27638 .70123 m .26543 .69282 L .26503 .7023 L 0 1 .474 r
F
.27638 .70123 m .26914 .68551 L .26543 .69282 L F
.27638 .70123 m .27368 .68526 L .26914 .68551 L F
.27638 .70123 m .27679 .69201 L .27368 .68526 L F
0 g
.27268 .70851 m
.27638 .70123 L
s
.27638 .70123 m
.27949 .70773 L
s
.38433 .93419 m .37274 .93395 L .36958 .93517 L 0 1 .429 r
F
.38433 .93419 m .37907 .93354 L .37274 .93395 L F
.39171 .93086 m .37907 .93354 L .38433 .93419 L 0 1 .395 r
F
0 g
.38433 .93419 m
.39041 .93364 L
s
.38433 .93419 m
.38613 .93577 L
s
.62443 .4399 m .63127 .44509 L .63852 .45321 L 0 .353 .025 r
F
0 g
.63127 .44509 m
.63418 .44357 L
s
.53872 .73463 m
.53898 .73608 L
s
.53845 .7332 m
.53872 .73463 L
s
.53818 .73172 m
.53845 .7332 L
s
.36139 .98365 m .35942 .99173 L .36315 .99016 L 0 1 .487 r
F
.37762 1.00076 m .36315 .99016 L .35942 .99173 L 0 1 .491 r
F
0 g
.35942 .99173 m
.36196 .99805 L
s
.35178 .98746 m
.35942 .99173 L
s
.40985 .73052 m .39809 .73018 L .39834 .73368 L 0 1 .497 r
F
.40985 .73052 m .40139 .72672 L .39809 .73018 L F
.40985 .73052 m .40602 .72561 L .40139 .72672 L F
.40985 .73052 m .40965 .72724 L .40602 .72561 L F
0 g
.40985 .73052 m
.41346 .73185 L
s
.40656 .73397 m
.40985 .73052 L
s
.40089 1.01356 m .38451 1.00486 L .38802 1.01054 L 0 1 .49 r
F
.2423 .7043 m .23093 .70524 L .23405 .71256 L 0 1 .483 r
F
0 g
.23126 .72052 m
.23405 .71256 L
s
.4959 .79835 m .49416 .79441 L .49134 .79638 L 0 .582 .324 r
F
0 g
.49134 .79638 m
.49163 .78844 L
s
.79646 .78028 m .79675 .78302 L .80132 .78577 L 0 .341 .218 r
F
.79646 .78028 m .79467 .78067 L .79675 .78302 L F
0 g
.79115 .78235 m
.79675 .78302 L
s
.52464 .68754 m
.5258 .68895 L
s
.47734 1.06507 m .4824 1.07096 L .483 1.06935 L 0 .991 .495 r
F
.49792 1.07359 m .483 1.06935 L .4824 1.07096 L 0 1 .502 r
F
0 g
.4824 1.07096 m
.48846 1.07462 L
s
.47554 1.06903 m
.4824 1.07096 L
s
.47182 .97405 m .45905 .97451 L .46269 .97656 L 0 1 .528 r
F
0 g
.45692 .97685 m
.46269 .97656 L
s
.50533 .9076 m .50109 .90179 L .49741 .9004 L 0 .424 .36 r
F
0 g
.49608 .89671 m
.49741 .9004 L
s
.20828 .75914 m .20121 .7661 L .20571 .76562 L 0 1 .528 r
F
.20828 .75914 m .19699 .76011 L .20121 .7661 L F
0 g
.19968 .7727 m
.20121 .7661 L
s
.20571 .76562 m
.21083 .77131 L
s
.35922 .65344 m .34886 .65433 L .35064 .65969 L 0 1 .443 r
F
0 g
.34668 .66578 m
.35064 .65969 L
s
.35922 .65344 m .35066 .64677 L .34886 .65433 L 0 1 .443 r
F
.35922 .65344 m .35507 .64091 L .35066 .64677 L F
.35922 .65344 m .35915 .64065 L .35507 .64091 L F
.35922 .65344 m .36093 .64602 L .35915 .64065 L F
0 g
.35922 .65344 m
.36108 .65863 L
s
.35482 .65929 m
.35922 .65344 L
s
.36347 .93514 m .3617 .93827 L .36485 .93702 L 0 1 .445 r
F
0 g
.36485 .93702 m
.3714 .93675 L
s
.36347 .93514 m .35539 .93809 L .3617 .93827 L 0 1 .445 r
F
0 g
.3617 .93827 m
.36376 .94005 L
s
.30347 .78779 m .29517 .79143 L .30059 .79058 L 0 1 .494 r
F
.30347 .78779 m .28982 .78961 L .29517 .79143 L F
0 g
.29307 .79449 m
.29517 .79143 L
s
.30059 .79058 m
.3065 .79206 L
s
.47414 .46587 m .48063 .458 L .48491 .45429 L 0 0 0 r
F
0 g
.48063 .458 m
.48449 .45218 L
s
.50775 .48906 m .50287 .49621 L .5032 .49723 L 0 0 0 r
F
.50775 .48906 m .5073 .48727 L .50287 .49621 L F
.50775 .48906 m .5135 .47642 L .5073 .48727 L F
.38681 .73651 m .3793 .74113 L .38371 .74009 L 0 1 .51 r
F
0 g
.38371 .74009 m
.38763 .74212 L
s
.57666 .55938 m .5784 .58571 L .57575 .57233 L 0 .675 .152 r
F
.57666 .55938 m .58365 .59735 L .5784 .58571 L F
.57666 .55938 m .58885 .58629 L .58798 .5994 L F
0 g
.58666 .57277 m
.58685 .58186 L
s
.58455 .6005 m
.58468 .59784 L
s
.57666 .55938 m .58571 .56689 L .58885 .58629 L 0 .675 .152 r
F
0 g
.58534 .56607 m
.58571 .56689 L
s
.58571 .56689 m
.58591 .55753 L
s
.5718 .55139 m
.57666 .55938 L
s
.5805 .55541 m
.58534 .56607 L
s
.51722 .97677 m .5111 .97706 L .50637 .97818 L 0 1 .452 r
F
0 g
.50637 .97818 m
.5111 .97706 L
s
.51722 .97677 m
.522 .97718 L
s
.27054 .94005 m .26768 .9465 L .27155 .94555 L 0 1 .535 r
F
.27047 .94199 m .26768 .9465 L .27155 .94555 L 0 1 .52 r
F
.27054 .94005 m .26069 .94228 L .26768 .9465 L 0 1 .535 r
F
.27047 .94199 m .26061 .94419 L .26768 .9465 L 0 1 .52 r
F
0 g
.26184 .94778 m
.26187 .94795 L
s
.26187 .94793 m
.26187 .94795 L
s
.27039 .94393 m .26768 .9465 L .27155 .94555 L 0 .939 .294 r
F
0 g
.27155 .94555 m
.27159 .94555 L
s
.27155 .94555 m
.2717 .94558 L
s
.27155 .94555 m
.27186 .9457 L
s
.27039 .94393 m .26054 .94609 L .26768 .9465 L 0 .939 .294 r
F
0 g
.26768 .9465 m
.26962 .95191 L
s
.26742 .94649 m
.26768 .9465 L
s
.26179 .94771 m
.26187 .94793 L
s
.26126 .94613 m
.26179 .94771 L
s
.26183 .94776 m
.26184 .94778 L
s
.26112 .94435 m
.26144 .94589 L
s
.2615 .94615 m
.26183 .94776 L
s
.25085 .94454 m .2337 .93392 L .2351 .93978 L 0 1 .535 r
F
.25085 .94454 m .23779 .93316 L .2337 .93392 L F
.25085 .94454 m .24515 .93772 L .23779 .93316 L F
.26069 .94228 m .24515 .93772 L .25085 .94454 L F
0 g
.25085 .94454 m
.25306 .94589 L
s
.25085 .94454 m
.25126 .9463 L
s
.70294 .916 m
.7059 .91602 L
s
.32448 .67554 m .31617 .6823 L .32041 .68191 L 0 1 .459 r
F
0 g
.32041 .68191 m
.32329 .68779 L
s
.53248 .97546 m
.53248 .97546 L
s
.53248 .97546 m
.53285 .97544 L
s
.31335 .9377 m .2968 .93943 L .29826 .9403 L 0 .818 .246 r
F
.31335 .9377 m .3007 .93851 L .2968 .93943 L F
.31335 .9377 m .3078 .93777 L .3007 .93851 L F
.32264 .93488 m .3078 .93777 L .31335 .9377 L 0 .787 .232 r
F
0 g
.31335 .9377 m
.31477 .93857 L
s
.31335 .9377 m
.32022 .93673 L
s
.77768 .92042 m .77261 .92427 L .77182 .92794 L 0 1 .521 r
F
0 g
.76424 .92994 m
.77182 .92794 L
s
.47182 .97405 m .47443 .97759 L .47545 .9761 L 0 1 .528 r
F
.48674 .97625 m .47545 .9761 L .47443 .97759 L 0 1 .518 r
F
0 g
.47443 .97759 m
.4785 .97919 L
s
.46897 .97779 m
.47443 .97759 L
s
.21957 .75815 m .21245 .76491 L .21695 .76443 L 0 1 .528 r
F
.21957 .75815 m .20828 .75914 L .21245 .76491 L F
0 g
.21083 .77131 m
.21245 .76491 L
s
.21695 .76443 m
.22199 .76991 L
s
.51896 1.08303 m
.52575 1.08711 L
s
.52575 1.08711 m
.53202 1.08069 L
s
.43277 .71596 m .42453 .72058 L .42916 .71915 L 0 1 .48 r
F
0 g
.42916 .71915 m
.43274 .7202 L
s
.45704 .74286 m
.45955 .74135 L
s
.23435 .7964 m .22254 .7882 L .22093 .7924 L 0 1 .535 r
F
.23435 .7964 m .22705 .78791 L .22254 .7882 L F
.23435 .7964 m .23212 .79143 L .22705 .78791 L F
.24543 .79509 m .23212 .79143 L .23435 .7964 L 0 1 .532 r
F
0 g
.23272 .80057 m
.23435 .7964 L
s
.23435 .7964 m
.23932 .79964 L
s
.41859 .96722 m .404 .96478 L .40672 .96799 L 0 1 .538 r
F
0 g
.40021 .96689 m
.40672 .96799 L
s
.39697 .59755 m .38782 .60374 L .39172 .60322 L 0 1 .412 r
F
.39697 .59755 m .38741 .59898 L .38782 .60374 L F
0 g
.39172 .60322 m
.39269 .60813 L
s
.39697 .59755 m .39076 .5921 L .38741 .59898 L 0 1 .412 r
F
.39697 .59755 m .39602 .58643 L .39076 .5921 L F
.39697 .59755 m .39968 .58574 L .39602 .58643 L F
.39697 .59755 m .40008 .5905 L .39968 .58574 L F
0 g
.39697 .59755 m
.39756 .60239 L
s
.39172 .60322 m
.39697 .59755 L
s
.40008 .5905 m
.40515 .58469 L
s
.38681 .73651 m .37575 .73894 L .3793 .74113 L 0 1 .51 r
F
0 g
.37666 .74491 m
.3793 .74113 L
s
.49397 .84282 m .48763 .85115 L .49079 .85642 L 0 .541 .343 r
F
0 g
.48646 .84331 m
.48763 .85115 L
s
.48408 .85061 m
.48763 .85115 L
s
.54019 .98748 m
.54024 .98758 L
s
.45716 1.05434 m .44924 1.04957 L .44224 1.04709 L 0 .981 .495 r
F
.23093 .70524 m .22268 .71367 L .22723 .71323 L 0 1 .486 r
F
0 g
.22723 .71323 m
.23126 .72052 L
s
.51631 .93281 m .51141 .93605 L .51662 .94221 L 0 .343 .351 r
F
0 g
.50765 .92868 m
.51141 .93605 L
s
.54647 .6897 m
.54688 .64337 L
s
.50648 .43739 m .51896 .42956 L .51911 .43405 L 0 .045 .069 r
F
0 g
.51896 .42956 m
.52411 .42195 L
s
.51355 .431 m
.51896 .42956 L
s
.23086 .75716 m .22369 .76371 L .22819 .76323 L 0 1 .527 r
F
.23086 .75716 m .21957 .75815 L .22369 .76371 L F
0 g
.22199 .76991 m
.22369 .76371 L
s
.22819 .76323 m
.23316 .76849 L
s
.45919 .90784 m .45886 .90922 L .46084 .90775 L 0 .875 .22 r
F
.45919 .90784 m .45392 .91144 L .45886 .90922 L F
.47003 .90315 m .46084 .90775 L .45886 .90922 L 0 .916 .224 r
F
0 g
.45886 .90922 m
.46099 .90887 L
s
.46772 .73611 m .46 .74108 L .46453 .73786 L 0 0 0 r
F
0 g
.46453 .73786 m
.46652 .73677 L
s
.46453 .73786 m
.46705 .73579 L
s
.37404 .63417 m .36527 .64018 L .36934 .63981 L 0 1 .436 r
F
.37404 .63417 m .36397 .63506 L .36527 .64018 L F
0 g
.36934 .63981 m
.37119 .64501 L
s
.37404 .63417 m .36633 .62785 L .36397 .63506 L 0 1 .436 r
F
.37404 .63417 m .37104 .6222 L .36633 .62785 L F
.37404 .63417 m .37497 .62187 L .37104 .6222 L F
.37404 .63417 m .37625 .62701 L .37497 .62187 L F
0 g
.36934 .63981 m
.37404 .63417 L
s
.49158 .81576 m .48728 .83051 L .49043 .8297 L 0 .59 .336 r
F
.45392 .91144 m .44412 .91517 L .44182 .91665 L 0 1 .243 r
F
.45392 .91144 m .4493 .91294 L .44412 .91517 L F
0 g
.45392 .91144 m
.45594 .91152 L
s
.45919 .90784 m .4493 .91294 L .45392 .91144 L 0 .875 .22 r
F
0 g
.45392 .91144 m
.45886 .90922 L
s
.72103 1.07305 m .73344 1.07221 L .73031 1.07214 L 0 .786 .267 r
F
.71344 1.07275 m .72103 1.07305 L .72562 1.07208 L 0 .734 .252 r
F
.77567 .86256 m .77672 .87829 L .78261 .87071 L 0 1 .491 r
F
.77567 .86256 m .77258 .87874 L .77672 .87829 L F
0 g
.77618 .88449 m
.77672 .87829 L
s
.76162 .75616 m .77164 .76493 L .77325 .76534 L 0 .116 .169 r
F
0 g
.77164 .76493 m
.77387 .76721 L
s
.76699 .76168 m
.77164 .76493 L
s
.37575 .73894 m .36827 .74357 L .37268 .74262 L 0 1 .514 r
F
0 g
.37268 .74262 m
.37666 .74491 L
s
.41761 .55611 m .42183 .5486 L .42279 .54392 L 0 1 .33 r
F
0 g
.42183 .5486 m
.42507 .54468 L
s
.70583 1.07261 m .69729 1.07308 L .69302 1.07369 L 0 .689 .241 r
F
0 g
.684 1.07353 m
.69302 1.07369 L
s
.51837 .58976 m .52469 .58173 L .52534 .58368 L 0 0 .025 r
F
0 g
.52469 .58173 m
.52666 .57543 L
s
.5217 .58434 m
.52469 .58173 L
s
.49323 .71636 m
.49408 .71519 L
s
.24215 .75614 m .23494 .76249 L .23944 .762 L 0 1 .527 r
F
.24215 .75614 m .23086 .75716 L .23494 .76249 L F
0 g
.23316 .76849 m
.23494 .76249 L
s
.23944 .762 m
.24432 .76705 L
s
.36919 .96093 m .35662 .95472 L .35347 .95589 L 0 1 .536 r
F
.36919 .96093 m .36336 .95688 L .35662 .95472 L F
.37654 .95778 m .36336 .95688 L .36919 .96093 L F
0 g
.36919 .96093 m
.37142 .96496 L
s
.36919 .96093 m
.37569 .96297 L
s
.50908 .76266 m .50815 .76063 L .50659 .76766 L 0 .547 .301 r
F
0 g
.50762 .76303 m
.50815 .76063 L
s
.50815 .76063 m
.50828 .75066 L
s
.43277 .71596 m .42122 .71936 L .42453 .72058 L 0 1 .48 r
F
0 g
.42119 .72393 m
.42453 .72058 L
s
.43277 .71596 m .42144 .7163 L .42122 .71936 L 0 1 .48 r
F
.43277 .71596 m .42506 .7131 L .42144 .7163 L F
.43277 .71596 m .42966 .7119 L .42506 .7131 L F
.43277 .71596 m .43297 .71312 L .42966 .7119 L F
0 g
.43277 .71596 m
.43609 .71689 L
s
.42916 .71915 m
.43277 .71596 L
s
.4959 .79835 m .48942 .81125 L .49158 .81576 L 0 .582 .324 r
F
0 g
.48931 .80295 m
.48942 .81125 L
s
.48628 .81207 m
.48942 .81125 L
s
.50179 .77353 m
.5024 .772 L
s
.59015 .59538 m
.5902 .59134 L
s
.23093 .70524 m .21955 .70615 L .22268 .71367 L 0 1 .486 r
F
0 g
.21993 .7218 m
.22268 .71367 L
s
.70583 1.07261 m .70457 1.07365 L .71344 1.07275 L 0 .689 .241 r
F
0 g
.70045 1.07452 m
.70457 1.07365 L
s
.69583 1.07405 m
.70457 1.07365 L
s
.80432 .66764 m .81403 .68185 L .81677 .67759 L 0 1 .51 r
F
0 g
.81403 .68185 m
.81724 .68869 L
s
.58596 .62401 m
.58597 .62959 L
s
.58597 .62959 m
.58598 .63568 L
s
.586 .66355 m
.58604 .70724 L
s
.586 .66277 m
.586 .66355 L
s
.586 .65683 m
.586 .66277 L
s
.58599 .65347 m
.586 .65683 L
s
.58599 .65295 m
.58599 .65347 L
s
.58347 .66757 m
.58356 .66578 L
s
.58356 .66578 m
.5839 .65901 L
s
.5839 .65901 m
.58401 .65679 L
s
.58401 .65679 m
.58407 .65566 L
s
.58407 .65566 m
.58411 .6549 L
s
.58529 .63143 m
.58553 .62656 L
s
.58506 .63599 m
.58529 .63143 L
s
.37575 .73894 m .3647 .74112 L .36827 .74357 L 0 1 .514 r
F
0 g
.36569 .74745 m
.36827 .74357 L
s
.43757 1.04201 m .42993 1.03669 L .42286 1.03376 L 0 .994 .495 r
F
.73501 .58104 m .74097 .59363 L .73657 .59127 L 0 .347 .088 r
F
.73501 .58104 m .74612 .58843 L .74097 .59363 L F
.54168 .44155 m .5556 .43159 L .55092 .43956 L 0 .01 .067 r
F
0 g
.5556 .43159 m
.55822 .43052 L
s
.47003 .90315 m .46563 .90514 L .46084 .90775 L 0 .916 .224 r
F
.47425 .9 m .47003 .90315 L .47449 .9007 L 0 .84 .194 r
F
.47425 .9 m .46563 .90514 L .47003 .90315 L F
0 g
.47003 .90315 m
.47215 .9028 L
s
.44773 .50101 m .45339 .49281 L .45637 .48814 L 0 .877 .138 r
F
.32448 .67554 m .31392 .67633 L .31617 .6823 L 0 1 .459 r
F
0 g
.31269 .68892 m
.31617 .6823 L
s
.51868 1.07829 m .51022 1.08149 L .51896 1.08303 L 0 1 .526 r
F
.51868 1.07829 m .5038 1.07902 L .51022 1.08149 L F
.7149 .91398 m .71972 .9199 L .72481 .91747 L 0 1 .499 r
F
0 g
.71385 .92042 m
.71972 .9199 L
s
.71876 .92289 m
.71972 .9199 L
s
.25345 .7551 m .24619 .76125 L .25069 .76075 L 0 1 .527 r
F
.25345 .7551 m .24215 .75614 L .24619 .76125 L F
0 g
.24432 .76705 m
.24619 .76125 L
s
.25069 .76075 m
.25549 .76558 L
s
.26503 .7023 m .25406 .69358 L .25367 .70332 L 0 1 .477 r
F
.26503 .7023 m .25777 .68609 L .25406 .69358 L F
.26503 .7023 m .26232 .68586 L .25777 .68609 L F
.26503 .7023 m .26543 .69282 L .26232 .68586 L F
0 g
.26132 .70976 m
.26503 .7023 L
s
.26503 .7023 m
.26814 .70902 L
s
.79646 .78028 m .80132 .78577 L .80615 .78721 L 0 .341 .218 r
F
0 g
.80132 .78577 m
.80246 .78944 L
s
.49397 .84282 m .49126 .8379 L .48804 .83812 L 0 .541 .343 r
F
0 g
.48728 .83051 m
.48804 .83812 L
s
.76835 .59962 m .77656 .59097 L .78111 .59357 L 0 .193 .033 r
F
.76835 .59962 m .7711 .59355 L .77656 .59097 L F
0 g
.7744 .58616 m
.77656 .59097 L
s
.43851 .96958 m .42457 .96821 L .42755 .97104 L 0 1 .537 r
F
0 g
.4213 .97043 m
.42755 .97104 L
s
.74266 1.06886 m .73344 1.07221 L .7423 1.07057 L 0 .787 .252 r
F
.74266 1.06886 m .73031 1.07214 L .73344 1.07221 L F
0 g
.73813 1.07237 m
.73882 1.07207 L
s
.72859 1.07351 m
.73344 1.07221 L
s
.36469 .74112 m .35757 .74572 L .36179 .7449 L 0 1 .518 r
F
0 g
.36179 .7449 m
.36569 .74745 L
s
.39834 .73368 m .38654 .73277 L .38682 .73651 L 0 1 .504 r
F
0 g
.38682 .73651 m
.39047 .73841 L
s
.39834 .73368 m .38981 .72923 L .38654 .73277 L 0 1 .504 r
F
.39834 .73368 m .39444 .72827 L .38981 .72923 L F
.39834 .73368 m .39809 .73018 L .39444 .72827 L F
0 g
.39507 .73721 m
.39834 .73368 L
s
.39834 .73368 m
.40196 .73531 L
s
.44497 .70558 m .43657 .70996 L .44117 .70859 L 0 1 .467 r
F
.44497 .70558 m .43352 .70886 L .43657 .70996 L F
.44497 .70558 m .43406 .706 L .43352 .70886 L F
0 g
.44117 .70859 m
.44449 .70952 L
s
.44497 .70558 m .43786 .70299 L .43406 .706 L 0 1 .467 r
F
.44497 .70558 m .44239 .70183 L .43786 .70299 L F
.44497 .70558 m .44543 .70294 L .44239 .70183 L F
0 g
.44497 .70558 m
.44806 .7064 L
s
.44117 .70859 m
.44497 .70558 L
s
.26474 .75403 m .25744 .75998 L .26194 .75947 L 0 1 .527 r
F
.26474 .75403 m .25345 .7551 L .25744 .75998 L F
0 g
.25549 .76558 m
.25744 .75998 L
s
.26194 .75947 m
.26667 .76408 L
s
.49672 .53081 m .4917 .53378 L .49251 .53723 L 0 1 .173 r
F
.49672 .53081 m .49504 .52251 L .4917 .53378 L F
.49672 .53081 m .50031 .51097 L .49504 .52251 L F
0 g
.50031 .51097 m
.50449 .50462 L
s
.49336 .63204 m .48859 .63393 L .49034 .63427 L 0 1 .259 r
F
.49336 .63204 m .48933 .63103 L .48859 .63393 L F
.49336 .63204 m .49206 .62752 L .48933 .63103 L F
0 g
.49296 .63542 m
.49336 .63204 L
s
.50022 .77746 m .4984 .79488 L .5 .7863 L 0 .583 .314 r
F
.50022 .77746 m .4959 .79835 L .4984 .79488 L F
.50022 .77746 m .49416 .79441 L .4959 .79835 L F
0 g
.50022 .77746 m
.50179 .77353 L
s
.49416 .79441 m
.49439 .78557 L
s
.49134 .79638 m
.49416 .79441 L
s
.47734 1.06507 m .4692 1.06098 L .46235 1.05906 L 0 .991 .495 r
F
.74995 .74551 m .75924 .7536 L .75455 .74943 L 0 .043 .154 r
F
.74995 .74551 m .76162 .75616 L .75924 .7536 L F
0 g
.75425 .74918 m
.75453 .74942 L
s
.74995 .74551 m
.75425 .74918 L
s
.7475 .74262 m
.74781 .74298 L
s
.74781 .74298 m
.74995 .74551 L
s
.25077 .94641 m .23343 .94007 L .23491 .94406 L 0 1 .527 r
F
.25077 .94641 m .23752 .93935 L .23343 .94007 L F
.25077 .94641 m .24497 .94208 L .23752 .93935 L F
.26061 .94419 m .24497 .94208 L .25077 .94641 L 0 1 .524 r
F
0 g
.25077 .94641 m
.25139 .94812 L
s
.25077 .94641 m
.25402 .94754 L
s
.26183 .9479 m
.26185 .94792 L
s
.26734 .94648 m
.26742 .94649 L
s
.36469 .74112 m .35411 .743 L .35757 .74572 L 0 1 .518 r
F
0 g
.35519 .7497 m
.35757 .74572 L
s
.41761 .55611 m .40871 .56353 L .41199 .56251 L 0 1 .33 r
F
0 g
.41455 .56272 m
.4169 .56104 L
s
.41761 .55611 m .40966 .55885 L .40871 .56353 L 0 1 .33 r
F
.41761 .55611 m .41422 .55158 L .40966 .55885 L F
.41761 .55611 m .41985 .54518 L .41422 .55158 L F
.41761 .55611 m .42279 .54392 L .41985 .54518 L F
0 g
.41199 .56251 m
.41761 .55611 L
s
.4169 .56103 m
.41761 .55611 L
s
.42279 .54392 m
.42845 .53708 L
s
.42183 .5486 m
.42279 .54392 L
s
.31389 .78633 m .30777 .78943 L .3119 .78875 L 0 1 .48 r
F
.31389 .78633 m .30348 .78779 L .30777 .78943 L F
0 g
.3065 .79206 m
.30777 .78943 L
s
.3119 .78875 m
.31674 .79013 L
s
.47425 .9 m .47449 .9007 L .47604 .89943 L 0 .84 .194 r
F
.48439 .89427 m .47604 .89943 L .47449 .9007 L 0 .888 .2 r
F
0 g
.47449 .9007 m
.47673 .89983 L
s
.47003 .90315 m
.47449 .9007 L
s
.53939 1.07528 m .52533 1.08272 L .53202 1.08069 L 0 1 .527 r
F
.24543 .79509 m .23381 .78747 L .23212 .79143 L 0 1 .532 r
F
.24543 .79509 m .23832 .78718 L .23381 .78747 L F
.24543 .79509 m .2433 .79045 L .23832 .78718 L F
.25652 .79376 m .2433 .79045 L .24543 .79509 L 0 1 .528 r
F
0 g
.24372 .79902 m
.24543 .79509 L
s
.24543 .79509 m
.25032 .79808 L
s
.49079 .85642 m .49117 .8688 L .4923 .86399 L 0 .556 .355 r
F
.49883 .8696 m .49117 .8688 L .4931 .87657 L 0 .481 .348 r
F
.49883 .8696 m .4923 .86399 L .49117 .8688 L F
0 g
.48762 .86825 m
.49117 .8688 L
s
.49056 .58775 m .49655 .56435 L .49575 .55736 L 0 1 .277 r
F
.49056 .58775 m .49433 .57736 L .49655 .56435 L F
0 g
.49655 .56435 m
.50003 .56094 L
s
.21955 .70615 m .21131 .71475 L .21586 .71432 L 0 1 .488 r
F
0 g
.21586 .71432 m
.21993 .7218 L
s
.54227 .98961 m
.54286 .99063 L
s
.54382 .99232 m
.54431 .99318 L
s
.54431 .99318 m
.54439 .99332 L
s
.54455 .99341 m
.54512 .99374 L
s
.54439 .99332 m
.54455 .99341 L
s
.27603 .75293 m .26869 .75868 L .27319 .75815 L 0 1 .527 r
F
.27603 .75293 m .26474 .75403 L .26869 .75868 L F
0 g
.26667 .76408 m
.26869 .75868 L
s
.27319 .75815 m
.27785 .76254 L
s
.51229 .75669 m
.51237 .75865 L
s
.30377 .94996 m .28707 .94176 L .2886 .94683 L 0 1 .535 r
F
0 g
.28129 .94317 m
.28132 .94317 L
s
.30377 .94996 m .29096 .94082 L .28707 .94176 L 0 1 .535 r
F
0 g
.28132 .94317 m
.28743 .94293 L
s
.30377 .94996 m .29813 .94434 L .29096 .94082 L 0 1 .535 r
F
.31305 .9473 m .29813 .94434 L .30377 .94996 L F
0 g
.30377 .94996 m
.31071 .95332 L
s
.30377 .94996 m
.30527 .95501 L
s
.50193 .97713 m .49583 .97694 L .4908 .97785 L 0 1 .498 r
F
0 g
.4908 .97785 m
.49583 .97694 L
s
.50193 .97713 m
.50637 .97818 L
s
.53608 .73472 m
.53608 .73472 L
s
.39783 .96333 m .38282 .95973 L .38522 .9633 L 0 1 .537 r
F
0 g
.37854 .96167 m
.38522 .9633 L
s
.35411 .743 m .34701 .74767 L .35123 .74691 L 0 1 .52 r
F
0 g
.35123 .74691 m
.35519 .7497 L
s
.2814 .9432 m
.28796 .94469 L
s
.50533 .9076 m .50447 .91776 L .50816 .91917 L 0 .424 .36 r
F
.78806 .92248 m .7929 .92899 L .79841 .92449 L 0 1 .525 r
F
0 g
.7858 .93158 m
.7929 .92899 L
s
.79178 .93311 m
.7929 .92899 L
s
.55007 1.0715 m .54608 1.07325 L .54672 1.07286 L 0 0 0 r
F
0 g
.54069 1.07605 m
.54668 1.07289 L
s
.54672 1.07286 m
.54918 1.06594 L
s
.53939 1.07528 m .54671 1.07287 L .54607 1.07326 L 0 1 .527 r
F
.45931 .68971 m .45097 .69347 L .45537 .69239 L 0 1 .447 r
F
.45931 .68971 m .44844 .69227 L .45097 .69347 L F
0 g
.45537 .69239 m
.45819 .69341 L
s
.45931 .68971 m .44948 .68957 L .44844 .69227 L 0 1 .447 r
F
.45931 .68971 m .45343 .68689 L .44948 .68957 L F
.45931 .68971 m .45766 .68601 L .45343 .68689 L F
.45931 .68971 m .46018 .68722 L .45766 .68601 L F
0 g
.45931 .68971 m
.46196 .6907 L
s
.45537 .69239 m
.45931 .68971 L
s
.46018 .68722 m
.46399 .68468 L
s
.35411 .743 m .34353 .74471 L .34701 .74767 L 0 1 .52 r
F
0 g
.3447 .75178 m
.34701 .74767 L
s
.40511 .57987 m .39602 .58643 L .39968 .58574 L 0 1 .39 r
F
.40511 .57987 m .39618 .58179 L .39602 .58643 L F
0 g
.39968 .58574 m
.40008 .5905 L
s
.40511 .57987 m .40005 .57492 L .39618 .58179 L 0 1 .39 r
F
.40511 .57987 m .4055 .56905 L .40005 .57492 L F
.40511 .57987 m .40887 .56811 L .4055 .56905 L F
.40511 .57987 m .40871 .57275 L .40887 .56811 L F
0 g
.40871 .57275 m
.41393 .56675 L
s
.40511 .57987 m
.40515 .58469 L
s
.39968 .58574 m
.40511 .57987 L
s
.78136 .66068 m .79377 .67078 L .79284 .66439 L 0 .975 .493 r
F
0 g
.79101 .67425 m
.79377 .67078 L
s
.79377 .67078 m
.79792 .67672 L
s
.28733 .75177 m .27994 .75734 L .28445 .75678 L 0 1 .526 r
F
.28733 .75177 m .27603 .75293 L .27994 .75734 L F
0 g
.27785 .76254 m
.27994 .75734 L
s
.28445 .75678 m
.28903 .76095 L
s
.68269 .93108 m .67976 .93753 L .68606 .93336 L 0 1 .392 r
F
0 g
.68538 .93647 m
.68607 .93336 L
s
.68269 .93108 m .67652 .93828 L .67976 .93753 L 0 1 .392 r
F
0 g
.67777 .93997 m
.67976 .93753 L
s
.38001 .61638 m
.38099 .62129 L
s
.37626 .62701 m
.38099 .62129 L
s
.46772 .73611 m .45632 .74409 L .46 .74108 L 0 0 0 r
F
0 g
.45531 .74405 m
.45704 .74286 L
s
.46772 .73611 m .45595 .74491 L .45632 .74409 L 0 0 0 r
F
.46772 .73611 m .45914 .74315 L .45595 .74491 L F
.46772 .73611 m .46376 .74001 L .45914 .74315 L F
0 g
.45955 .74135 m
.46 .74108 L
s
.46772 .73611 m .46743 .73699 L .46376 .74001 L 0 0 0 r
F
0 g
.46772 .73611 m
.46819 .73565 L
s
.46652 .73677 m
.46772 .73611 L
s
.44258 .91489 m .44182 .91665 L .44412 .91517 L 0 .888 .241 r
F
.44258 .91489 m .43656 .91847 L .44182 .91665 L F
0 g
.44182 .91665 m
.44387 .91673 L
s
.8087 .60508 m .8221 .60963 L .82013 .60977 L 0 0 0 r
F
0 g
.8201 .60769 m
.8221 .60963 L
s
.4598 .74124 m
.46 .74108 L
s
.45703 .74351 m
.4598 .74124 L
s
.34353 .74471 m .33646 .74946 L .34068 .74876 L 0 1 .522 r
F
0 g
.34068 .74876 m
.3447 .75178 L
s
.62443 .4399 m .62356 .44483 L .62112 .43978 L 0 .353 .025 r
F
.62443 .4399 m .63083 .45297 L .62356 .44483 L F
.62443 .4399 m .63807 .45876 L .63083 .45297 L F
.62443 .4399 m .64135 .45885 L .63807 .45876 L F
.62443 .4399 m .63852 .45321 L .64135 .45885 L F
0 g
.63861 .45332 m
.64016 .45537 L
s
.63852 .45321 m
.63861 .45332 L
s
.61746 .43125 m
.62443 .4399 L
s
.63127 .44509 m
.63852 .45321 L
s
.55127 .56123 m .55122 .57835 L .54956 .57159 L 0 .295 .131 r
F
.55127 .56123 m .55576 .58038 L .55122 .57835 L F
.55127 .56123 m .56015 .57631 L .55576 .58038 L F
.55127 .56123 m .56183 .56591 L .56015 .57631 L F
0 g
.5471 .56221 m
.55127 .56123 L
s
.30121 .75026 m .29198 .75583 L .29751 .75512 L 0 1 .526 r
F
.30121 .75026 m .28733 .75177 L .29198 .75583 L F
0 g
.28903 .76095 m
.29198 .75583 L
s
.29751 .75512 m
.30277 .7589 L
s
.34353 .74471 m .33294 .74627 L .33646 .74946 L 0 1 .522 r
F
0 g
.33421 .75372 m
.33646 .74946 L
s
.21955 .70615 m .20816 .70704 L .21131 .71475 L 0 1 .488 r
F
0 g
.2086 .72305 m
.21131 .71475 L
s
.27153 .94552 m
.27155 .94555 L
s
.49766 .88494 m
.49768 .88492 L
s
.49768 .88492 m
.4991 .88405 L
s
.4991 .88405 m
.50011 .88317 L
s
.41232 .5657 m .41353 .56344 L .41199 .56251 L 0 1 .379 r
F
0 g
.41353 .56344 m
.41455 .56272 L
s
.33294 .74627 m .32591 .75113 L .33013 .75048 L 0 1 .523 r
F
0 g
.33013 .75048 m
.33421 .75372 L
s
.6982 .91208 m
.69827 .91385 L
s
.50665 .60731 m
.50804 .60514 L
s
.49056 .58775 m .49575 .55736 L .49197 .56023 L 0 1 .277 r
F
0 g
.49575 .55736 m
.49838 .54309 L
s
.31179 .74902 m .30482 .75415 L .30904 .75358 L 0 1 .525 r
F
.31179 .74902 m .30121 .75026 L .30482 .75415 L F
0 g
.30278 .7589 m
.30482 .75415 L
s
.30904 .75358 m
.31325 .75727 L
s
.50908 .76266 m .50659 .76766 L .50544 .77908 L 0 .547 .301 r
F
0 g
.50659 .76766 m
.50677 .75747 L
s
.50659 .76766 m
.50762 .76303 L
s
.33294 .74627 m .32237 .7477 L .32591 .75113 L 0 1 .523 r
F
0 g
.32373 .75555 m
.32591 .75113 L
s
.41232 .5657 m .4055 .56905 L .40888 .56811 L 0 1 .379 r
F
.41232 .5657 m .40395 .56812 L .4055 .56905 L F
.41232 .5657 m .40526 .56594 L .40395 .56812 L F
0 g
.40871 .57275 m
.40887 .56811 L
s
.41232 .5657 m .40871 .56353 L .40526 .56594 L 0 1 .379 r
F
.41232 .5657 m .41199 .56251 L .40871 .56353 L F
0 g
.40888 .56811 m
.41232 .5657 L
s
.41232 .5657 m
.41393 .56674 L
s
.41199 .56251 m
.41353 .56344 L
s
.32237 .7477 m .31537 .75269 L .31958 .75208 L 0 1 .525 r
F
0 g
.31958 .75208 m
.32373 .75555 L
s
.32237 .7477 m .31179 .74902 L .31537 .75269 L 0 1 .525 r
F
0 g
.31325 .75727 m
.31537 .75269 L
s
.57237 .43221 m
.57686 .42519 L
s
.50648 .43739 m .5006 .4482 L .50093 .44476 L 0 .045 .069 r
F
0 g
.49993 .44147 m
.50141 .43934 L
s
.50648 .43739 m .50603 .44677 L .5006 .4482 L 0 .045 .069 r
F
.50648 .43739 m .51358 .44142 L .50603 .44677 L F
.50648 .43739 m .51911 .43405 L .51358 .44142 L F
0 g
.50141 .43934 m
.50648 .43739 L
s
.74457 .92395 m .7558 .92359 L .75178 .92247 L 0 1 .522 r
F
.7347 .92079 m .74457 .92395 L .74575 .92075 L 0 1 .516 r
F
.50908 .76266 m .50858 .78583 L .50926 .77345 L 0 .547 .301 r
F
.50908 .76266 m .50702 .79288 L .50858 .78583 L F
.50908 .76266 m .50563 .78989 L .50702 .79288 L F
.50908 .76266 m .50544 .77908 L .50563 .78989 L F
0 g
.50908 .76266 m
.51028 .7528 L
s
.36139 .98365 m .34352 .97367 L .3453 .98019 L 0 1 .487 r
F
.51868 1.07829 m .51896 1.08303 L .52533 1.08272 L 0 1 .526 r
F
.32448 .67554 m .31517 .66798 L .31392 .67633 L 0 1 .459 r
F
.32448 .67554 m .31926 .66159 L .31517 .66798 L F
.32448 .67554 m .32345 .66144 L .31926 .66159 L F
.32448 .67554 m .32568 .66742 L .32345 .66144 L F
0 g
.32448 .67554 m
.32677 .6813 L
s
.32041 .68191 m
.32448 .67554 L
s
.49337 .61029 m .49775 .57686 L .49433 .57736 L 0 1 .283 r
F
.49337 .61029 m .49855 .58656 L .49775 .57686 L F
0 g
.49775 .57686 m
.50003 .56094 L
s
.49457 .57598 m
.49655 .56435 L
s
.49525 .57722 m
.49775 .57686 L
s
.51631 .93281 m .51156 .92677 L .50785 .925 L 0 .343 .351 r
F
0 g
.50447 .91776 m
.50785 .925 L
s
.54227 .98961 m
.54257 .98939 L
s
.54168 .44155 m .53759 .45129 L .53697 .44955 L 0 .01 .067 r
F
.54168 .44155 m .54358 .447 L .53759 .45129 L F
.54168 .44155 m .55092 .43956 L .54358 .447 L F
.49883 .8696 m .4931 .87657 L .4968 .88213 L 0 .481 .348 r
F
0 g
.49117 .8688 m
.4931 .87657 L
s
.48947 .8756 m
.4931 .87657 L
s
.36093 .64602 m
.36527 .64018 L
s
.44543 .70294 m
.44917 .69998 L
s
.45345 .97432 m .44739 .97257 L .44148 .97241 L 0 1 .536 r
F
.4573 .9706 m .45345 .97432 L .45905 .97451 L 0 1 .533 r
F
.4573 .9706 m .44739 .97257 L .45345 .97432 L F
0 g
.45345 .97432 m
.45692 .97685 L
s
.53372 .9757 m
.53538 .978 L
s
.53672 .97983 m
.53673 .97985 L
s
.53247 .97398 m
.5327 .9743 L
s
.53673 .97985 m
.53756 .98099 L
s
.53247 .97398 m
.53301 .97431 L
s
.31392 .67633 m .30556 .68318 L .3098 .68284 L 0 1 .464 r
F
0 g
.3098 .68284 m
.31269 .68892 L
s
.80761 .85911 m .8182 .85104 L .81389 .8513 L 0 1 .501 r
F
.79697 .8599 m .80761 .85911 L .80743 .85178 L 0 1 .498 r
F
.37762 1.00076 m .37095 .99404 L .36315 .99016 L 0 1 .491 r
F
0 g
.37762 1.00076 m
.38015 1.00708 L
s
.38417 .99769 m .37762 1.00076 L .38451 1.00486 L 0 1 .486 r
F
.38417 .99769 m .37095 .99404 L .37762 1.00076 L F
.7673 .9183 m .76582 .92633 L .77261 .92427 L 0 1 .515 r
F
.7673 .9183 m .76181 .92525 L .76582 .92633 L F
0 g
.76424 .92994 m
.76582 .92633 L
s
.25367 .70332 m .24269 .6943 L .2423 .7043 L 0 1 .48 r
F
.25367 .70332 m .24639 .68663 L .24269 .6943 L F
.25367 .70332 m .25095 .68642 L .24639 .68663 L F
.25367 .70332 m .25406 .69358 L .25095 .68642 L F
0 g
.24996 .71095 m
.25367 .70332 L
s
.25367 .70332 m
.25678 .71024 L
s
.20816 .70704 m .19993 .7158 L .20449 .71538 L 0 1 .491 r
F
0 g
.20449 .71538 m
.2086 .72305 L
s
.38681 .73651 m .37544 .73496 L .37575 .73894 L 0 1 .51 r
F
.38681 .73651 m .37854 .73137 L .37544 .73496 L F
.38681 .73651 m .38299 .73056 L .37854 .73137 L F
.38681 .73651 m .38654 .73277 L .38299 .73056 L F
0 g
.38371 .74009 m
.38681 .73651 L
s
.32431 .78478 m .31811 .78771 L .32225 .78699 L 0 1 .461 r
F
.32431 .78478 m .31389 .78633 L .31811 .78771 L F
0 g
.31674 .79013 m
.31811 .78771 L
s
.32225 .78699 m
.32699 .78813 L
s
.74612 .58843 m .75984 .587 L .75724 .59454 L 0 .298 .073 r
F
0 g
.75836 .57867 m
.75984 .587 L
s
.75984 .587 m
.76519 .58368 L
s
.47414 .46587 m .48491 .45429 L .48413 .45721 L 0 0 0 r
F
0 g
.48491 .45429 m
.49045 .44628 L
s
.48063 .458 m
.48491 .45429 L
s
.43656 .91847 m .42629 .9212 L .42363 .92265 L 0 1 .276 r
F
.43656 .91847 m .43184 .91941 L .42629 .9212 L F
.44258 .91489 m .43184 .91941 L .43656 .91847 L 0 .888 .241 r
F
0 g
.43656 .91847 m
.43839 .91897 L
s
.43656 .91847 m
.44182 .91665 L
s
.54346 .4244 m .53905 .43553 L .53842 .43041 L 0 .268 .095 r
F
.54346 .4244 m .54541 .43825 L .53905 .43553 L F
.54346 .4244 m .55324 .43675 L .54541 .43825 L F
.54346 .4244 m .55826 .43072 L .55324 .43675 L F
0 g
.5579 .43506 m
.55983 .43205 L
s
.54346 .4244 m .55714 .42419 L .55826 .43072 L 0 .268 .095 r
F
0 g
.53747 .4222 m
.54346 .4244 L
s
.55714 .42419 m
.56166 .41871 L
s
.5508 .42149 m
.55714 .42419 L
s
.25652 .79376 m .24508 .78674 L .2433 .79045 L 0 1 .528 r
F
.25652 .79376 m .24959 .78644 L .24508 .78674 L F
.25652 .79376 m .2545 .78946 L .24959 .78644 L F
.26761 .79242 m .2545 .78946 L .25652 .79376 L 0 1 .523 r
F
0 g
.25472 .79745 m
.25652 .79376 L
s
.25652 .79376 m
.26133 .7965 L
s
.2507 .94827 m .23316 .94622 L .23472 .94834 L 0 1 .358 r
F
.2507 .94827 m .23725 .94556 L .23316 .94622 L F
.2507 .94827 m .24478 .94644 L .23725 .94556 L F
.26054 .94609 m .24478 .94644 L .2507 .94827 L 0 1 .328 r
F
0 g
.2507 .94827 m
.25766 .94889 L
s
.2507 .94827 m
.25217 .95031 L
s
.77567 .86256 m .77212 .872 L .77258 .87874 L 0 1 .491 r
F
0 g
.76597 .88541 m
.77258 .87874 L
s
.50045 .61707 m
.5007 .61686 L
s
.34886 .65433 m .34019 .66053 L .34437 .66022 L 0 1 .451 r
F
0 g
.34437 .66022 m
.34668 .66578 L
s
.49042 .71946 m .48225 .72807 L .48686 .7229 L 0 0 .046 r
F
.49042 .71946 m .47896 .73251 L .48225 .72807 L F
.49042 .71946 m .47919 .73327 L .47896 .73251 L F
.49042 .71946 m .48277 .72981 L .47919 .73327 L F
.49042 .71946 m .4873 .72445 L .48277 .72981 L F
.49042 .71946 m .49058 .72002 L .4873 .72445 L F
0 g
.49042 .71946 m
.49184 .71714 L
s
.48686 .7229 m
.49026 .71857 L
s
.48686 .7229 m
.48948 .72036 L
s
.48948 .72036 m
.49042 .71946 L
s
.49058 .72002 m
.49323 .71636 L
s
.80803 .78639 m .80816 .78967 L .81272 .79214 L 0 .407 .231 r
F
.80803 .78639 m .80615 .78721 L .80816 .78967 L F
0 g
.80246 .78944 m
.80816 .78967 L
s
.4787 .72856 m .47068 .73473 L .47529 .73085 L 0 0 .014 r
F
0 g
.47529 .73085 m
.47825 .72886 L
s
.47529 .73085 m
.47825 .72794 L
s
.4787 .72856 m .46715 .73829 L .47068 .73473 L 0 0 .014 r
F
.4787 .72856 m .46706 .73915 L .46715 .73829 L F
.4787 .72856 m .47047 .73685 L .46706 .73915 L F
.4787 .72856 m .47511 .73293 L .47047 .73685 L F
.4787 .72856 m .47864 .72937 L .47511 .73293 L F
0 g
.4787 .72856 m
.47896 .72824 L
s
.47825 .72886 m
.4787 .72856 L
s
.43297 .71312 m
.43657 .70996 L
s
.51693 .97464 m .51722 .97677 L .52163 .97599 L 0 1 .413 r
F
.51693 .97464 m .5111 .97706 L .51722 .97677 L F
.41875 1.02837 m .41148 1.02257 L .40439 1.01923 L 0 1 .493 r
F
.49158 .81576 m .49043 .8297 L .49202 .82366 L 0 .59 .336 r
F
.49716 .82693 m .49043 .8297 L .49126 .8379 L 0 .533 .332 r
F
.49716 .82693 m .49202 .82366 L .49043 .8297 L F
0 g
.48728 .83051 m
.49043 .8297 L
s
.20816 .70704 m .19678 .7079 L .19993 .7158 L 0 1 .491 r
F
0 g
.19727 .72427 m
.19993 .7158 L
s
.42122 .71936 m .41296 .72384 L .41759 .72259 L 0 1 .491 r
F
0 g
.41759 .72259 m
.42119 .72393 L
s
.4959 .79835 m .49158 .81576 L .49441 .81379 L 0 .582 .324 r
F
.49397 .84282 m .49079 .85642 L .49401 .85622 L 0 .541 .343 r
F
.5073 .48727 m .51825 .46861 L .5184 .46902 L 0 0 0 r
F
.5073 .48727 m .5135 .47642 L .51825 .46861 L F
0 g
.51825 .46861 m
.52275 .45956 L
s
.5135 .47642 m
.51803 .46831 L
s
.5135 .47642 m
.51825 .46861 L
s
.49792 1.07359 m .5038 1.07902 L .50398 1.07725 L 0 1 .502 r
F
.51868 1.07829 m .50398 1.07725 L .5038 1.07902 L 0 1 .526 r
F
0 g
.5038 1.07902 m
.51022 1.08149 L
s
.49715 1.07789 m
.5038 1.07902 L
s
.28156 .94332 m
.28321 .94414 L
s
.28321 .94414 m
.2886 .94683 L
s
.51662 .94222 m .52098 .95264 L .52073 .94933 L 0 .36 .36 r
F
0 g
.51692 .9504 m
.52098 .95264 L
s
.52098 .95264 m
.52541 .95984 L
s
.8158 .6705 m .82094 .68382 L .82555 .68507 L 0 1 .516 r
F
.8158 .6705 m .81677 .67759 L .82094 .68382 L F
0 g
.81724 .68869 m
.82094 .68382 L
s
.52251 .97601 m
.52374 .97603 L
s
.52374 .97603 m
.52638 .97608 L
s
.51693 .97464 m .50665 .97647 L .5111 .97706 L 0 1 .413 r
F
.68269 .93108 m .68606 .93336 L .69124 .92854 L 0 1 .392 r
F
0 g
.67976 .93753 m
.68606 .93336 L
s
.51837 .58976 m .51614 .59643 L .51598 .59495 L 0 0 .025 r
F
.51837 .58976 m .51914 .59382 L .51614 .59643 L F
.51837 .58976 m .52296 .58885 L .51914 .59382 L F
.51837 .58976 m .52534 .58368 L .52296 .58885 L F
0 g
.51575 .59368 m
.51837 .58976 L
s
.65528 .48092 m
.65599 .48364 L
s
.65678 .48663 m .67116 .51433 L .66497 .4996 L 0 .145 .227 r
F
.65678 .48663 m .6732 .5221 L .67116 .51433 L F
.65678 .48663 m .66972 .51771 L .6732 .5221 L F
.65678 .48663 m .66268 .5025 L .66972 .51771 L F
0 g
.65535 .48301 m
.65678 .48663 L
s
.65599 .48364 m
.65678 .48663 L
s
.38417 .99769 m .38451 1.00486 L .38703 1.0036 L 0 1 .486 r
F
.40089 1.01356 m .38703 1.0036 L .38451 1.00486 L 0 1 .49 r
F
0 g
.38451 1.00486 m
.38802 1.01054 L
s
.37762 1.00076 m
.38451 1.00486 L
s
.72453 .90912 m .73517 .90291 L .73121 .90365 L 0 1 .494 r
F
.7353 .89102 m .73517 .90291 L .7413 .89647 L 0 1 .487 r
F
.7353 .89102 m .73121 .90365 L .73517 .90291 L F
0 g
.73423 .90751 m
.73517 .90291 L
s
.48784 .64 m .49002 .63687 L .49034 .63427 L 0 1 .31 r
F
0 g
.49002 .63687 m
.49296 .63542 L
s
.50357 .78531 m .5 .7863 L .4984 .79488 L 0 .545 .311 r
F
.50357 .78531 m .50221 .7822 L .5 .7863 L F
0 g
.5 .7863 m
.50022 .77746 L
s
.5 .7863 m
.50221 .7822 L
s
.50221 .7822 m
.5024 .772 L
s
.35539 .93809 m .34015 .9373 L .34176 .93938 L 0 1 .466 r
F
.35539 .93809 m .34357 .93626 L .34015 .9373 L F
.35539 .93809 m .35011 .9366 L .34357 .93626 L F
.36347 .93514 m .35011 .9366 L .35539 .93809 L 0 1 .445 r
F
0 g
.35539 .93809 m
.3617 .93827 L
s
.35539 .93809 m
.35698 .94017 L
s
.31392 .67633 m .30335 .67699 L .30556 .68318 L 0 1 .464 r
F
0 g
.30208 .68993 m
.30556 .68318 L
s
.44139 1.03854 m .43757 1.04201 L .44435 1.04494 L 0 .956 .489 r
F
.44139 1.03854 m .42993 1.03669 L .43757 1.04201 L F
0 g
.43757 1.04201 m
.44224 1.04709 L
s
.48439 .89427 m .48029 .89667 L .47604 .89943 L 0 .888 .2 r
F
.48752 .89196 m .48439 .89427 L .4883 .89179 L 0 0 0 r
F
.48752 .89196 m .48029 .89667 L .48439 .89427 L F
0 g
.48439 .89427 m
.48662 .89341 L
s
.79727 .59968 m .80385 .60437 L .7993 .60247 L 0 .021 0 r
F
.79727 .59968 m .8087 .60508 L .80385 .60437 L F
0 g
.36315 .99016 m
.37095 .99404 L
s
.53248 .97546 m
.53274 .97541 L
s
.49504 .52251 m .50368 .4993 L .49915 .50616 L 0 1 .158 r
F
0 g
.50368 .4993 m
.50775 .48906 L
s
.4959 .79835 m .49441 .81379 L .496 .80666 L 0 .582 .324 r
F
.49883 .8696 m .49559 .86433 L .4923 .86399 L 0 .481 .348 r
F
0 g
.49079 .85642 m
.4923 .86399 L
s
.44139 1.03854 m .42555 1.03169 L .42993 1.03669 L 0 .956 .489 r
F
0 g
.42286 1.03376 m
.42993 1.03669 L
s
.53306 .68404 m
.53327 .68391 L
s
.45999 1.05077 m .44924 1.04957 L .45716 1.05434 L 0 .937 .488 r
F
.45999 1.05077 m .44435 1.04494 L .44924 1.04957 L F
0 g
.44224 1.04709 m
.44924 1.04957 L
s
.45632 .74409 m .44865 .74822 L .45319 .74552 L 0 0 0 r
F
0 g
.45319 .74552 m
.45415 .74508 L
s
.45319 .74552 m
.45531 .74405 L
s
.3132 .94249 m .2968 .93943 L .29819 .94232 L 0 1 .503 r
F
.3132 .94249 m .3007 .93851 L .2968 .93943 L F
.3132 .94249 m .30773 .93983 L .3007 .93851 L F
.32249 .93978 m .30773 .93983 L .3132 .94249 L 0 1 .493 r
F
0 g
.3132 .94249 m
.32001 .94362 L
s
.3132 .94249 m
.31456 .94537 L
s
.50274 .97426 m .50193 .97713 L .50665 .97647 L 0 1 .473 r
F
.50274 .97426 m .49583 .97694 L .50193 .97713 L F
.52347 .4616 m .53604 .44687 L .53124 .45498 L 0 0 .024 r
F
0 g
.53604 .44687 m
.54168 .44155 L
s
.50619 .89609 m .49841 .8941 L .50109 .90179 L 0 .408 .349 r
F
.50619 .89609 m .49908 .88964 L .49841 .8941 L F
0 g
.49478 .8931 m
.49841 .8941 L
s
.37575 .73894 m .36435 .7369 L .3647 .74112 L 0 1 .514 r
F
0 g
.3647 .74112 m
.36827 .74357 L
s
.37575 .73894 m .36742 .73321 L .36435 .7369 L 0 1 .514 r
F
.37575 .73894 m .37187 .7325 L .36742 .73321 L F
.37575 .73894 m .37544 .73496 L .37187 .7325 L F
0 g
.37268 .74262 m
.37575 .73894 L
s
.37575 .73894 m
.3793 .74113 L
s
.49792 1.07359 m .48965 1.07047 L .483 1.06935 L 0 1 .502 r
F
.58346 .42609 m .58075 .4348 L .57919 .43117 L 0 .253 .081 r
F
.58346 .42609 m .58769 .43621 L .58075 .4348 L F
.58346 .42609 m .59536 .43445 L .58769 .43621 L F
.58346 .42609 m .59959 .42936 L .59536 .43445 L F
0 g
.57686 .42519 m
.58346 .42609 L
s
.57919 .43117 m
.58346 .42609 L
s
.4573 .9706 m .45905 .97451 L .46047 .97301 L 0 1 .533 r
F
.47182 .97405 m .46047 .97301 L .45905 .97451 L 0 1 .528 r
F
0 g
.45905 .97451 m
.46269 .97656 L
s
.45345 .97432 m
.45905 .97451 L
s
.33473 .78314 m .32846 .7859 L .33261 .78515 L 0 1 .437 r
F
.33473 .78314 m .32431 .78478 L .32846 .7859 L F
0 g
.32699 .78813 m
.32846 .7859 L
s
.33261 .78515 m
.33725 .78603 L
s
.49337 .61029 m .49668 .60088 L .49855 .58656 L 0 1 .283 r
F
0 g
.49668 .60088 m
.49855 .58656 L
s
.49855 .58656 m
.50166 .58613 L
s
.44773 .50101 m .45637 .48814 L .45471 .49011 L 0 .877 .138 r
F
0 g
.44511 .50587 m
.44773 .50101 L
s
.45637 .48814 m
.4582 .48564 L
s
.45339 .49281 m
.45637 .48814 L
s
.3991 .92767 m .39757 .93018 L .40043 .92884 L 0 1 .353 r
F
.3991 .92767 m .39171 .93086 L .39757 .93018 L F
0 g
.39757 .93018 m
.39949 .93122 L
s
.51089 .65006 m .51329 .64465 L .51521 .62353 L 0 1 .27 r
F
.46165 .68346 m .45343 .68689 L .45766 .68601 L 0 1 .443 r
F
.46165 .68346 m .45123 .68551 L .45343 .68689 L F
0 g
.45766 .68601 m
.46018 .68722 L
s
.46165 .68346 m .45254 .68278 L .45123 .68551 L 0 1 .443 r
F
.46165 .68346 m .45653 .68022 L .45254 .68278 L F
.46165 .68346 m .46055 .67954 L .45653 .68022 L F
.46165 .68346 m .46274 .68092 L .46055 .67954 L F
0 g
.46165 .68346 m
.46399 .68468 L
s
.45766 .68601 m
.46165 .68346 L
s
.46274 .68092 m
.46656 .67854 L
s
.71481 .91132 m .72453 .90912 L .72528 .90494 L 0 1 .48 r
F
.49716 .82693 m .4949 .82248 L .49202 .82366 L 0 .533 .332 r
F
0 g
.49158 .81576 m
.49202 .82366 L
s
.26761 .79242 m .25636 .78599 L .2545 .78946 L 0 1 .523 r
F
.26761 .79242 m .26087 .78569 L .25636 .78599 L F
.26761 .79242 m .2657 .78845 L .26087 .78569 L F
.27871 .79103 m .2657 .78845 L .26761 .79242 L 0 1 .517 r
F
0 g
.26574 .79586 m
.26761 .79242 L
s
.26761 .79242 m
.27235 .79489 L
s
.44773 .50101 m .43984 .51009 L .44192 .50842 L 0 .877 .138 r
F
0 g
.44309 .50847 m
.44511 .50587 L
s
.44773 .50101 m .44283 .50541 L .43984 .51009 L 0 .877 .138 r
F
0 g
.43947 .51313 m
.44309 .50847 L
s
.44773 .50101 m .4489 .49751 L .44283 .50541 L 0 .877 .138 r
F
.44773 .50101 m .45471 .49011 L .4489 .49751 L F
.45999 1.05077 m .45716 1.05434 L .46386 1.05684 L 0 .937 .488 r
F
0 g
.45716 1.05434 m
.46235 1.05906 L
s
.34886 .65433 m .33848 .65497 L .34019 .66053 L 0 1 .451 r
F
0 g
.33619 .6667 m
.34019 .66053 L
s
.34886 .65433 m .34038 .64725 L .33848 .65497 L 0 1 .451 r
F
.34886 .65433 m .34487 .64134 L .34038 .64725 L F
.34886 .65433 m .34895 .6412 L .34487 .64134 L F
.34886 .65433 m .35066 .64677 L .34895 .6412 L F
0 g
.34886 .65433 m
.35064 .65969 L
s
.34437 .66022 m
.34886 .65433 L
s
.2423 .7043 m .23131 .69499 L .23093 .70524 L 0 1 .483 r
F
.2423 .7043 m .23501 .68714 L .23131 .69499 L F
.2423 .7043 m .23957 .68694 L .23501 .68714 L F
.2423 .7043 m .24269 .6943 L .23957 .68694 L F
0 g
.2386 .71211 m
.2423 .7043 L
s
.2423 .7043 m
.24542 .71142 L
s
.347 .95332 m .32953 .94759 L .33058 .95222 L 0 1 .535 r
F
.80803 .78639 m .81272 .79214 L .81761 .79305 L 0 .407 .231 r
F
0 g
.81272 .79214 m
.81375 .79584 L
s
.48773 .57107 m .49454 .54843 L .49373 .54351 L 0 1 .268 r
F
.48773 .57107 m .49197 .56023 L .49454 .54843 L F
0 g
.49454 .54843 m
.49838 .54309 L
s
.49425 .71694 m
.49462 .71624 L
s
.49283 .71965 m
.49425 .71694 L
s
.51142 .76745 m .51048 .76558 L .50926 .77345 L 0 .525 .299 r
F
0 g
.51029 .75353 m
.51048 .76558 L
s
.42122 .71936 m .40967 .72234 L .41296 .72384 L 0 1 .491 r
F
0 g
.40965 .72724 m
.41296 .72384 L
s
.53027 .71423 m .53151 .64078 L .53004 .6804 L 0 .807 .252 r
F
.52568 .70627 m .53004 .6804 L .53151 .64078 L 0 .83 .256 r
F
0 g
.53104 .61966 m
.53151 .64078 L
s
.53151 .64078 m
.5335 .61951 L
s
.48674 .97625 m .48073 .97552 L .47545 .9761 L 0 1 .518 r
F
0 g
.47545 .9761 m
.48073 .97552 L
s
.48674 .97625 m
.4908 .97785 L
s
.32234 .94469 m .3198 .95052 L .32344 .94941 L 0 1 .534 r
F
.32234 .94469 m .31305 .9473 L .3198 .95052 L F
0 g
.3198 .95052 m
.3217 .95513 L
s
.42122 .71936 m .4099 .71907 L .40967 .72234 L 0 1 .491 r
F
.42122 .71936 m .41353 .71584 L .4099 .71907 L F
.42122 .71936 m .41814 .71479 L .41353 .71584 L F
.42122 .71936 m .42144 .7163 L .41814 .71479 L F
0 g
.42122 .71936 m
.42453 .72058 L
s
.41759 .72259 m
.42122 .71936 L
s
.7673 .9183 m .76244 .92181 L .76181 .92525 L 0 1 .515 r
F
0 g
.75441 .927 m
.76181 .92525 L
s
.47414 .46587 m .46709 .47578 L .46833 .47349 L 0 0 0 r
F
.47414 .46587 m .47138 .47206 L .46709 .47578 L F
0 g
.46852 .47224 m
.47019 .46995 L
s
.47414 .46587 m .47833 .46482 L .47138 .47206 L 0 0 0 r
F
.47414 .46587 m .48413 .45721 L .47833 .46482 L F
0 g
.47019 .46995 m
.47414 .46587 L
s
.52865 .5807 m .53239 .5748 L .53606 .57349 L 0 .041 .08 r
F
0 g
.53239 .5748 m
.53435 .5685 L
s
.53471 .72977 m .53671 .64461 L .53484 .68931 L 0 .78 .249 r
F
0 g
.53604 .72895 m
.53614 .72932 L
s
.53027 .71423 m .53484 .68931 L .53671 .64461 L 0 .807 .252 r
F
0 g
.5366 .6306 m
.53671 .64461 L
s
.53671 .64461 m
.53967 .61485 L
s
.42353 1.02501 m .41875 1.02837 L .42555 1.03169 L 0 .981 .488 r
F
.42353 1.02501 m .41148 1.02257 L .41875 1.02837 L F
0 g
.41875 1.02837 m
.42286 1.03376 L
s
.49716 .82693 m .49126 .8379 L .49397 .84282 L 0 .533 .332 r
F
0 g
.49043 .8297 m
.49126 .8379 L
s
.48804 .83812 m
.49126 .8379 L
s
.50274 .97426 m .49172 .97582 L .49583 .97694 L 0 1 .473 r
F
0 g
.53904 .73799 m
.53904 .73799 L
s
.53684 .7314 m
.53904 .73799 L
s
.53614 .72932 m
.53684 .7314 L
s
.77567 .86256 m .78261 .87071 L .78632 .86103 L 0 1 .491 r
F
0 g
.77672 .87829 m
.78261 .87071 L
s
.78261 .87071 m
.78294 .87773 L
s
.53756 .981 m
.53777 .98084 L
s
.48137 .72687 m
.48206 .72623 L
s
.47943 .72865 m
.48137 .72687 L
s
.4794 .72867 m
.47943 .72865 L
s
.47917 .72889 m
.4794 .72867 L
s
.47864 .72937 m
.47917 .72889 L
s
.4573 .9706 m .4442 .97016 L .44739 .97257 L 0 1 .533 r
F
0 g
.44148 .97241 m
.44739 .97257 L
s
.50357 .78531 m .4984 .79488 L .49855 .80421 L 0 .545 .311 r
F
0 g
.4959 .79835 m
.4984 .79488 L
s
.22887 .93588 m
.23509 .93978 L
s
.35508 .95054 m .35347 .95589 L .35662 .95472 L 0 1 .535 r
F
.35508 .95054 m .347 .95332 L .35347 .95589 L F
0 g
.35347 .95589 m
.35572 .95993 L
s
.59015 .59538 m
.5908 .59363 L
s
.48784 .64 m .48237 .64205 L .48456 .64222 L 0 1 .31 r
F
.48784 .64 m .48269 .63945 L .48237 .64205 L F
.48784 .64 m .48531 .63615 L .48269 .63945 L F
.48784 .64 m .48859 .63393 L .48531 .63615 L F
.48784 .64 m .49034 .63427 L .48859 .63393 L F
0 g
.48784 .64 m
.48784 .64297 L
s
.49034 .63427 m
.49336 .63204 L
s
.49002 .63687 m
.49034 .63427 L
s
.8158 .6705 m .82555 .68507 L .82827 .68046 L 0 1 .516 r
F
0 g
.82555 .68507 m
.82872 .69203 L
s
.45632 .74409 m .44491 .75077 L .44865 .74822 L 0 0 0 r
F
0 g
.44579 .74974 m
.44865 .74822 L
s
.44357 .751 m
.44579 .74974 L
s
.48752 .89196 m .4883 .89179 L .48942 .89088 L 0 0 0 r
F
.49679 .88547 m .48942 .89088 L .4883 .89179 L 0 .834 .169 r
F
0 g
.4883 .89179 m
.49061 .89037 L
s
.48439 .89427 m
.4883 .89179 L
s
.66535 .5719 m .6685 .55557 L .6648 .55185 L 0 .548 .287 r
F
0 g
.6648 .55185 m
.66493 .5566 L
s
.6619 .55691 m
.66518 .57117 L
s
.66403 .54906 m
.6648 .55185 L
s
.6279 .49204 m .62858 .49763 L .62562 .48455 L 0 .436 0 r
F
0 g
.62642 .48717 m
.62758 .49099 L
s
.62574 .48495 m
.62642 .48717 L
s
.62567 .48472 m
.62574 .48495 L
s
.62562 .48455 m
.62567 .48472 L
s
.62525 .48348 m
.62562 .48455 L
s
.61906 .48112 m .63296 .51762 L .63281 .52135 L 0 .505 .022 r
F
.6279 .49204 m .63559 .52493 L .63016 .5038 L 0 .436 0 r
F
.62944 .50021 m .63016 .5038 L .62998 .50309 L F
.6279 .49204 m .63016 .5038 L .62944 .50021 L F
.63559 .52493 m .63595 .52548 L .63301 .51519 L 0 0 .095 r
F
.63296 .51762 m .63301 .51519 L .63595 .52548 L 0 .505 .022 r
F
.61906 .48112 m .63194 .51257 L .63296 .51762 L F
.63194 .51257 m .63301 .51519 L .63296 .51762 L F
.63296 .51762 m .63595 .52548 L .63406 .52299 L F
.63296 .51762 m .63406 .52299 L .63281 .52135 L F
.62816 .49421 m .62998 .50309 L .62858 .49763 L 0 .436 0 r
F
.6279 .49204 m .62998 .50309 L .62816 .49421 L F
0 g
.62332 .47177 m
.62726 .48922 L
s
.62726 .48922 m
.62752 .49039 L
s
.62752 .49039 m
.6279 .49204 L
s
.62758 .49099 m
.62762 .49111 L
s
.62762 .49111 m
.6279 .49204 L
s
.36469 .74112 m .35372 .73854 L .35411 .743 L 0 1 .518 r
F
.36469 .74112 m .35662 .73475 L .35372 .73854 L F
.36469 .74112 m .36089 .73417 L .35662 .73475 L F
.36469 .74112 m .36434 .7369 L .36089 .73417 L F
0 g
.36179 .7449 m
.36469 .74112 L
s
.26069 .94228 m .24394 .93202 L .24515 .93772 L 0 1 .535 r
F
.26069 .94228 m .24803 .93127 L .24394 .93202 L F
.26069 .94228 m .25522 .93567 L .24803 .93127 L F
.27054 .94005 m .25522 .93567 L .26069 .94228 L F
0 g
.26069 .94228 m
.26297 .94366 L
s
.26069 .94228 m
.26106 .94408 L
s
.38417 .99769 m .36808 .98811 L .37095 .99404 L 0 1 .486 r
F
0 g
.66449 .51005 m
.66591 .51426 L
s
.66268 .5025 m
.66428 .50916 L
s
.66428 .50916 m
.66449 .51005 L
s
.41808 .924 m .40474 .92687 L .4064 .9277 L 0 1 .317 r
F
0 g
.40043 .92884 m
.4064 .9277 L
s
.50619 .89609 m .50109 .90179 L .50533 .9076 L 0 .408 .349 r
F
0 g
.49841 .8941 m
.50109 .90179 L
s
.49741 .9004 m
.50109 .90179 L
s
.47425 .9 m .46382 .90572 L .46563 .90514 L 0 .84 .194 r
F
0 g
.46084 .90775 m
.46563 .90514 L
s
.34176 .93938 m
.34176 .93938 L
s
.71479 .62143 m
.71837 .62277 L
s
.50036 .80807 m .49441 .81379 L .4949 .82248 L 0 .533 .321 r
F
.50036 .80807 m .496 .80666 L .49441 .81379 L F
0 g
.49158 .81576 m
.49441 .81379 L
s
.58343 .61855 m
.58472 .611 L
s
.5826 .62336 m
.58343 .61855 L
s
.58472 .611 m
.58679 .59884 L
s
.76835 .59962 m .78111 .59357 L .78237 .59908 L 0 .193 .033 r
F
0 g
.78111 .59357 m
.78584 .59343 L
s
.34516 .78137 m .33882 .78398 L .34297 .78318 L 0 1 .407 r
F
.34516 .78137 m .33473 .78314 L .33882 .78398 L F
0 g
.33725 .78603 m
.33882 .78398 L
s
.34297 .78318 m
.34752 .78381 L
s
.45919 .90784 m .44763 .91304 L .4493 .91294 L 0 .875 .22 r
F
0 g
.4493 .91294 m
.4493 .91294 L
s
.44412 .91517 m
.4493 .91294 L
s
.46636 .73787 m
.46681 .7375 L
s
.46681 .7375 m
.46743 .73699 L
s
.46977 .73537 m
.47068 .73473 L
s
.46933 .73567 m
.46977 .73537 L
s
.46859 .73619 m
.46933 .73567 L
s
.46743 .73699 m
.46859 .73619 L
s
.28042 .93784 m .27737 .94412 L .28125 .94317 L 0 1 .534 r
F
.28035 .93982 m .27737 .94412 L .28125 .94317 L 0 1 .515 r
F
.28042 .93784 m .27054 .94005 L .27737 .94412 L 0 1 .534 r
F
.28035 .93982 m .27047 .94199 L .27737 .94412 L 0 1 .515 r
F
0 g
.27154 .94553 m
.27155 .94555 L
s
.27152 .94537 m
.27155 .94555 L
s
.28027 .9418 m .27737 .94412 L .28125 .94317 L 0 .839 .261 r
F
0 g
.28125 .94317 m
.28129 .94317 L
s
.28125 .94317 m
.2814 .9432 L
s
.28125 .94317 m
.28156 .94332 L
s
.28027 .9418 m .27039 .94393 L .27737 .94412 L 0 .839 .261 r
F
0 g
.27737 .94412 m
.2791 .94936 L
s
.27711 .94411 m
.27737 .94412 L
s
.27152 .94536 m
.27152 .94537 L
s
.27092 .94213 m
.27122 .94375 L
s
.27126 .94395 m
.27152 .94536 L
s
.27148 .94531 m
.27154 .94553 L
s
.27106 .94395 m
.27148 .94531 L
s
.31392 .67633 m .30465 .6684 L .30335 .67699 L 0 1 .464 r
F
0 g
.30335 .67699 m
.30556 .68318 L
s
.31392 .67633 m .30878 .66187 L .30465 .6684 L 0 1 .464 r
F
.31392 .67633 m .31297 .66178 L .30878 .66187 L F
.31392 .67633 m .31517 .66798 L .31297 .66178 L F
0 g
.31392 .67633 m
.31617 .6823 L
s
.3098 .68284 m
.31392 .67633 L
s
.74266 1.06886 m .73425 1.0707 L .73031 1.07214 L 0 .787 .252 r
F
0 g
.72103 1.07305 m
.73031 1.07214 L
s
.50036 .80807 m .49855 .80421 L .496 .80666 L 0 .533 .321 r
F
0 g
.4959 .79835 m
.496 .80666 L
s
.30335 .67699 m .29262 .6841 L .2982 .68372 L 0 1 .468 r
F
0 g
.2982 .68372 m
.30207 .68993 L
s
.40441 .95999 m .404 .96478 L .40654 .96341 L 0 1 .537 r
F
.40441 .95999 m .39783 .96333 L .404 .96478 L F
.41859 .96722 m .40654 .96341 L .404 .96478 L 0 1 .538 r
F
0 g
.404 .96478 m
.40672 .96799 L
s
.42353 1.02501 m .40765 1.01725 L .41148 1.02257 L 0 .981 .488 r
F
0 g
.40439 1.01923 m
.41148 1.02257 L
s
.5197 .94755 m
.52073 .94933 L
s
.51631 .93281 m .51662 .94221 L .52034 .944 L 0 .343 .351 r
F
0 g
.51662 .94222 m
.5197 .94755 L
s
.47915 1.06144 m .4692 1.06098 L .47734 1.06507 L 0 .937 .486 r
F
.47915 1.06144 m .46386 1.05684 L .4692 1.06098 L F
0 g
.46235 1.05906 m
.4692 1.06098 L
s
.50489 .664 m .50614 .61197 L .50328 .62022 L 0 1 .278 r
F
.50489 .664 m .50853 .62025 L .50614 .61197 L F
0 g
.50614 .61197 m
.50661 .60771 L
s
.38001 .61638 m .37104 .6222 L .37497 .62187 L 0 1 .436 r
F
.38001 .61638 m .37032 .61725 L .37104 .6222 L F
0 g
.37497 .62187 m
.37625 .62701 L
s
.38001 .61638 m .3733 .61031 L .37032 .61725 L 0 1 .436 r
F
.38001 .61638 m .37835 .60482 L .3733 .61031 L F
.38001 .61638 m .38209 .60442 L .37835 .60482 L F
.38001 .61638 m .3828 .60938 L .38209 .60442 L F
0 g
.37497 .62187 m
.38001 .61638 L
s
.69124 .92854 m .70315 .92297 L .69857 .92408 L 0 1 .439 r
F
.70286 .91495 m .70315 .92297 L .7101 .91751 L 0 1 .457 r
F
0 g
.70938 .92167 m
.71011 .91751 L
s
.70286 .91495 m .69857 .92408 L .70315 .92297 L 0 1 .457 r
F
0 g
.70244 .9261 m
.70315 .92297 L
s
.70315 .92297 m
.7101 .91751 L
s
.27871 .79103 m .26764 .78522 L .2657 .78845 L 0 1 .517 r
F
.27871 .79103 m .27215 .7849 L .26764 .78522 L F
.27871 .79103 m .2769 .7874 L .27215 .7849 L F
.28982 .78961 m .2769 .7874 L .27871 .79103 L 0 1 .509 r
F
0 g
.27676 .79424 m
.27871 .79103 L
s
.27871 .79103 m
.28337 .79325 L
s
.44635 .69896 m .43786 .70299 L .44239 .70183 L 0 1 .466 r
F
.44635 .69896 m .43511 .70172 L .43786 .70299 L F
0 g
.44239 .70183 m
.44543 .70294 L
s
.44635 .69896 m .43599 .69886 L .43511 .70172 L 0 1 .466 r
F
.44635 .69896 m .43995 .69599 L .43599 .69886 L F
.44635 .69896 m .44436 .69501 L .43995 .69599 L F
.44635 .69896 m .4471 .69629 L .44436 .69501 L F
0 g
.44635 .69896 m
.44917 .69998 L
s
.44239 .70183 m
.44635 .69896 L
s
.42499 .92054 m .42363 .92265 L .42629 .9212 L 0 .976 .259 r
F
.42499 .92054 m .41808 .924 L .42363 .92265 L F
0 g
.42363 .92265 m
.42547 .92314 L
s
.41859 .96722 m .41279 .96445 L .40654 .96341 L 0 1 .538 r
F
.42432 .9637 m .41859 .96722 L .42457 .96821 L 0 1 .537 r
F
.42432 .9637 m .41279 .96445 L .41859 .96722 L F
0 g
.41859 .96722 m
.4213 .97043 L
s
.33394 .93652 m .32974 .94053 L .33422 .93913 L 0 1 .477 r
F
0 g
.33422 .93913 m
.34176 .93938 L
s
.33394 .93652 m .32249 .93978 L .32974 .94053 L 0 1 .477 r
F
0 g
.32974 .94053 m
.33084 .94311 L
s
.35411 .743 m .3431 .74 L .34353 .74471 L 0 1 .52 r
F
.35411 .743 m .34597 .73608 L .3431 .74 L F
.35411 .743 m .35023 .73557 L .34597 .73608 L F
.35411 .743 m .35372 .73854 L .35023 .73557 L F
0 g
.35123 .74691 m
.35411 .743 L
s
.35411 .743 m
.35757 .74572 L
s
.39783 .96333 m .38568 .95846 L .38282 .95973 L 0 1 .537 r
F
.39783 .96333 m .39211 .96 L .38568 .95846 L F
.40441 .95999 m .39211 .96 L .39783 .96333 L F
0 g
.39783 .96333 m
.404 .96478 L
s
.39783 .96333 m
.40021 .96689 L
s
.37654 .95778 m .36135 .95299 L .36336 .95688 L 0 1 .536 r
F
0 g
.35662 .95472 m
.36336 .95688 L
s
.51142 .76745 m .51177 .79222 L .51198 .77886 L 0 .525 .299 r
F
.51142 .76745 m .51055 .80012 L .51177 .79222 L F
.51142 .76745 m .50913 .79726 L .51055 .80012 L F
.51142 .76745 m .50858 .78583 L .50913 .79726 L F
.51142 .76745 m .50926 .77345 L .50858 .78583 L F
0 g
.51142 .76745 m
.51229 .75669 L
s
.50908 .76266 m
.50926 .77345 L
s
.50926 .77345 m
.51048 .76558 L
s
.47 .73542 m
.47068 .73473 L
s
.4694 .73602 m
.47 .73542 L
s
.46761 .73783 m
.4694 .73602 L
s
.48865 .97291 m .48674 .97625 L .49172 .97582 L 0 1 .503 r
F
.48865 .97291 m .48073 .97552 L .48674 .97625 L F
.51617 .70559 m .51927 .63189 L .51689 .63686 L 0 .872 .266 r
F
.51617 .70559 m .52061 .65067 L .51927 .63189 L F
0 g
.51927 .63189 m
.51968 .62755 L
s
.5198 .6955 m
.5203 .7015 L
s
.5198 .6955 m
.52092 .69682 L
s
.23093 .70524 m .21992 .69566 L .21955 .70615 L 0 1 .486 r
F
.23093 .70524 m .22362 .68762 L .21992 .69566 L F
.23093 .70524 m .22817 .68743 L .22362 .68762 L F
.23093 .70524 m .23131 .69499 L .22817 .68743 L F
0 g
.22723 .71323 m
.23093 .70524 L
s
.23093 .70524 m
.23405 .71256 L
s
.75576 .88676 m .76635 .87954 L .76221 .88016 L 0 1 .5 r
F
.74553 .8886 m .75576 .88676 L .75598 .88125 L 0 1 .495 r
F
.68269 .93108 m .67777 .93552 L .67652 .93828 L 0 1 .392 r
F
0 g
.6743 .93939 m
.67652 .93828 L
s
.49766 .88494 m
.49766 .88496 L
s
.49883 .8696 m .4968 .88213 L .50009 .88248 L 0 .481 .348 r
F
0 g
.4968 .88213 m
.49766 .88494 L
s
.77768 .92042 m .78277 .92666 L .78806 .92248 L 0 1 .521 r
F
0 g
.77582 .92899 m
.78277 .92666 L
s
.78181 .93055 m
.78277 .92666 L
s
.38741 .59898 m
.38782 .60374 L
s
.3828 .60938 m
.38782 .60374 L
s
.45632 .74409 m .44446 .75146 L .44491 .75077 L 0 0 0 r
F
.45632 .74409 m .44759 .75004 L .44446 .75146 L F
.45632 .74409 m .45221 .74745 L .44759 .75004 L F
0 g
.44588 .75011 m
.44865 .74822 L
s
.45632 .74409 m .45595 .74491 L .45221 .74745 L 0 0 0 r
F
0 g
.45632 .74409 m
.45703 .74351 L
s
.45415 .74508 m
.45632 .74409 L
s
.81958 .79179 m .81955 .79566 L .82411 .79788 L 0 .467 .245 r
F
.81958 .79179 m .81761 .79305 L .81955 .79566 L F
0 g
.81375 .79584 m
.81955 .79566 L
s
.77325 .76534 m .78316 .77329 L .78486 .77332 L 0 .193 .186 r
F
0 g
.78316 .77329 m
.78532 .77558 L
s
.77846 .77068 m
.78316 .77329 L
s
.40967 .72234 m .40139 .72672 L .40602 .72561 L 0 1 .5 r
F
0 g
.40602 .72561 m
.40965 .72724 L
s
.42432 .9637 m .42457 .96821 L .42676 .96677 L 0 1 .537 r
F
.43851 .96958 m .42676 .96677 L .42457 .96821 L F
0 g
.42457 .96821 m
.42755 .97104 L
s
.41859 .96722 m
.42457 .96821 L
s
.32264 .93488 m .30655 .93714 L .3078 .93777 L 0 .787 .232 r
F
.32264 .93488 m .31045 .93624 L .30655 .93714 L F
.32264 .93488 m .31736 .93527 L .31045 .93624 L F
0 g
.32264 .93488 m
.32385 .93551 L
s
.81551 .83217 m .8182 .85104 L .8236 .84244 L 0 1 .488 r
F
.81551 .83217 m .81389 .8513 L .8182 .85104 L F
0 g
.8182 .85104 m
.81825 .85862 L
s
.44491 .75077 m .4373 .7543 L .44184 .75199 L 0 0 0 r
F
0 g
.44184 .75199 m
.44357 .751 L
s
.36397 .63506 m .35507 .64091 L .35915 .64065 L 0 1 .447 r
F
0 g
.35915 .64065 m
.36093 .64602 L
s
.7353 .89102 m .7413 .89647 L .74553 .8886 L 0 1 .487 r
F
0 g
.73517 .90291 m
.7413 .89647 L
s
.74109 .90195 m
.7413 .89647 L
s
.43352 .70886 m .42506 .7131 L .42966 .7119 L 0 1 .48 r
F
0 g
.42966 .7119 m
.43297 .71312 L
s
.46453 .67709 m .45653 .68022 L .46055 .67954 L 0 1 .436 r
F
.46453 .67709 m .45469 .67867 L .45653 .68022 L F
0 g
.46055 .67954 m
.46274 .68092 L
s
.46453 .67709 m .45625 .67591 L .45469 .67867 L 0 1 .436 r
F
.46453 .67709 m .46025 .67346 L .45625 .67591 L F
.46453 .67709 m .464 .67295 L .46025 .67346 L F
.46453 .67709 m .46583 .67451 L .464 .67295 L F
0 g
.46453 .67709 m
.46656 .67854 L
s
.46055 .67954 m
.46453 .67709 L
s
.46583 .67451 m
.46962 .67228 L
s
.48259 .64757 m .48466 .64459 L .48456 .64222 L 0 1 .351 r
F
0 g
.48466 .64459 m
.48784 .64297 L
s
.4471 .69629 m
.45097 .69347 L
s
.50357 .78531 m .50258 .80397 L .50372 .79464 L 0 .545 .311 r
F
.50357 .78531 m .50036 .80807 L .50258 .80397 L F
.50357 .78531 m .49855 .80421 L .50036 .80807 L F
0 g
.50357 .78531 m
.50544 .77908 L
s
.4984 .79488 m
.49855 .80421 L
s
.496 .80666 m
.49855 .80421 L
s
.39171 .93086 m .37748 .93216 L .37907 .93354 L 0 1 .395 r
F
.34353 .74471 m .33248 .7413 L .33294 .74627 L 0 1 .522 r
F
.34353 .74471 m .33532 .73723 L .33248 .7413 L F
.34353 .74471 m .33958 .73679 L .33532 .73723 L F
.34353 .74471 m .3431 .74 L .33958 .73679 L F
0 g
.34068 .74876 m
.34353 .74471 L
s
.34353 .74471 m
.34701 .74767 L
s
.3556 .77945 m .34919 .78194 L .35334 .78109 L 0 1 .37 r
F
.3556 .77945 m .34516 .78137 L .34919 .78194 L F
0 g
.34752 .78381 m
.34919 .78194 L
s
.35334 .78109 m
.3578 .78145 L
s
.51868 1.07829 m .52533 1.08272 L .5251 1.08077 L 0 1 .526 r
F
.53939 1.07528 m .5251 1.08077 L .52533 1.08272 L 0 1 .527 r
F
0 g
.51896 1.08303 m
.52533 1.08272 L
s
.52533 1.08272 m
.53202 1.08069 L
s
.47915 1.06144 m .47734 1.06507 L .48389 1.06705 L 0 .937 .486 r
F
0 g
.47734 1.06507 m
.483 1.06935 L
s
.43352 .70886 m .42205 .71173 L .42506 .7131 L 0 1 .48 r
F
.43352 .70886 m .42266 .70868 L .42205 .71173 L F
.43352 .70886 m .42652 .70563 L .42266 .70868 L F
.43352 .70886 m .43106 .70462 L .42652 .70563 L F
.43352 .70886 m .43406 .706 L .43106 .70462 L F
0 g
.43352 .70886 m
.43657 .70996 L
s
.42966 .7119 m
.43352 .70886 L
s
.36397 .63506 m .35388 .63565 L .35507 .64091 L 0 1 .447 r
F
.36397 .63506 m .35638 .62837 L .35388 .63565 L F
.36397 .63506 m .36121 .62276 L .35638 .62837 L F
.36397 .63506 m .36514 .62258 L .36121 .62276 L F
.36397 .63506 m .36633 .62785 L .36514 .62258 L F
0 g
.36397 .63506 m
.36527 .64018 L
s
.35915 .64065 m
.36397 .63506 L
s
.26061 .94419 m .24367 .93829 L .24497 .94208 L 0 1 .524 r
F
.26061 .94419 m .24777 .93759 L .24367 .93829 L F
.26061 .94419 m .25504 .94012 L .24777 .93759 L F
.27047 .94199 m .25504 .94012 L .26061 .94419 L 0 1 .52 r
F
0 g
.26061 .94419 m
.2612 .94594 L
s
.26061 .94419 m
.26406 .94532 L
s
.27152 .9455 m
.27153 .94552 L
s
.27703 .94411 m
.27711 .94411 L
s
.74266 1.06886 m .7423 1.07057 L .75102 1.06831 L 0 .787 .252 r
F
0 g
.73882 1.07207 m
.7423 1.07057 L
s
.73344 1.07221 m
.7423 1.07057 L
s
.30335 .67699 m .28946 .6777 L .29262 .6841 L 0 1 .468 r
F
0 g
.28814 .69113 m
.29262 .6841 L
s
.50619 .89609 m .50241 .89049 L .49908 .88964 L 0 .408 .349 r
F
0 g
.49766 .88496 m
.49908 .88964 L
s
.37158 .93228 m .36958 .93517 L .37274 .93395 L 0 1 .418 r
F
0 g
.37274 .93395 m
.37907 .93354 L
s
.37158 .93228 m .36347 .93514 L .36958 .93517 L 0 1 .418 r
F
0 g
.36958 .93517 m
.3714 .93675 L
s
.44139 1.03854 m .44435 1.04494 L .44576 1.04354 L 0 .956 .489 r
F
.45999 1.05077 m .44576 1.04354 L .44435 1.04494 L 0 .937 .488 r
F
0 g
.44435 1.04494 m
.44924 1.04957 L
s
.43757 1.04201 m
.44435 1.04494 L
s
.79284 .66439 m .80527 .67438 L .80432 .66764 L 0 1 .503 r
F
0 g
.80252 .67826 m
.80527 .67438 L
s
.80527 .67438 m
.80943 .68046 L
s
.52073 .94933 m
.52444 .95151 L
s
.52444 .95151 m
.52444 .95151 L
s
.7347 .92079 m .74575 .92075 L .74173 .91958 L 0 1 .516 r
F
.72481 .91747 m .7347 .92079 L .73569 .91779 L 0 1 .509 r
F
.49397 .84282 m .49401 .85622 L .49514 .85067 L 0 .541 .343 r
F
.50087 .85509 m .49401 .85622 L .49559 .86433 L 0 .472 .337 r
F
.50087 .85509 m .49514 .85067 L .49401 .85622 L F
0 g
.49079 .85642 m
.49401 .85622 L
s
.48773 .57107 m .49373 .54351 L .48959 .54795 L 0 1 .268 r
F
0 g
.4927 .55687 m
.49454 .54843 L
s
.4948 .55808 m
.49575 .55736 L
s
.49373 .54351 m
.49672 .53081 L
s
.7353 .89102 m .73126 .89856 L .73121 .90365 L 0 1 .487 r
F
0 g
.72453 .90912 m
.73121 .90365 L
s
.76501 .86455 m .76635 .87954 L .77212 .872 L 0 1 .486 r
F
.76501 .86455 m .76221 .88016 L .76635 .87954 L F
0 g
.76597 .88541 m
.76635 .87954 L
s
.39171 .93086 m .38065 .93099 L .37748 .93216 L 0 1 .395 r
F
.39171 .93086 m .38675 .93043 L .38065 .93099 L F
.3991 .92767 m .38675 .93043 L .39171 .93086 L 0 1 .353 r
F
0 g
.39171 .93086 m
.39757 .93018 L
s
.39171 .93086 m
.39327 .93224 L
s
.49337 .61029 m .49433 .57736 L .49056 .58775 L 0 1 .283 r
F
0 g
.49433 .57736 m
.49525 .57722 L
s
.49433 .57736 m
.49457 .57598 L
s
.33294 .74627 m .32185 .74247 L .32237 .7477 L 0 1 .523 r
F
.33294 .74627 m .32467 .73824 L .32185 .74247 L F
.33294 .74627 m .32893 .73786 L .32467 .73824 L F
.33294 .74627 m .33248 .7413 L .32893 .73786 L F
0 g
.33013 .75048 m
.33294 .74627 L
s
.33294 .74627 m
.33646 .74946 L
s
.28982 .78961 m .27892 .78442 L .2769 .7874 L 0 1 .509 r
F
.28982 .78961 m .28343 .78409 L .27892 .78442 L F
.28982 .78961 m .28811 .78632 L .28343 .78409 L F
0 g
.28779 .79258 m
.28982 .78961 L
s
.30347 .78779 m .28811 .78632 L .28982 .78961 L 0 1 .494 r
F
0 g
.28982 .78961 m
.29517 .79143 L
s
.347 .95332 m .33402 .94626 L .32953 .94759 L 0 1 .535 r
F
0 g
.32344 .94941 m
.32595 .9504 L
s
.32595 .9504 m
.33057 .95222 L
s
.347 .95332 m .34151 .94872 L .33402 .94626 L 0 1 .535 r
F
0 g
.347 .95332 m
.34802 .95794 L
s
.35508 .95054 m .34151 .94872 L .347 .95332 L 0 1 .535 r
F
0 g
.347 .95332 m
.35347 .95589 L
s
.44491 .75077 m .4335 .75642 L .4373 .7543 L 0 0 0 r
F
0 g
.43454 .75565 m
.4373 .7543 L
s
.43183 .75691 m
.43454 .75565 L
s
.48865 .97291 m .47701 .97392 L .48073 .97552 L 0 1 .503 r
F
.42353 1.02501 m .42555 1.03169 L .42735 1.03033 L 0 .981 .488 r
F
.44139 1.03854 m .42735 1.03033 L .42555 1.03169 L 0 .956 .489 r
F
0 g
.42555 1.03169 m
.42993 1.03669 L
s
.41875 1.02837 m
.42555 1.03169 L
s
.48259 .64757 m .47648 .64978 L .47909 .64979 L 0 1 .351 r
F
.48259 .64757 m .47638 .64741 L .47648 .64978 L F
.48259 .64757 m .47886 .64427 L .47638 .64741 L F
.48259 .64757 m .48237 .64205 L .47886 .64427 L F
.48259 .64757 m .48456 .64222 L .48237 .64205 L F
0 g
.48259 .64757 m
.483 .65019 L
s
.48456 .64222 m
.48784 .64 L
s
.48456 .64222 m
.48466 .64459 L
s
.40089 1.01356 m .39405 1.00733 L .38703 1.0036 L 0 1 .49 r
F
.33848 .65497 m .32973 .66115 L .33391 .66093 L 0 1 .458 r
F
0 g
.33391 .66093 m
.33619 .6667 L
s
.51693 .97464 m .52163 .97599 L .52138 .97524 L 0 1 .413 r
F
0 g
.52163 .97599 m
.52251 .97601 L
s
.51722 .97677 m
.52163 .97599 L
s
.50036 .80807 m .4949 .82248 L .49716 .82693 L 0 .533 .321 r
F
0 g
.49441 .81379 m
.4949 .82248 L
s
.49202 .82366 m
.4949 .82248 L
s
.81958 .79179 m .82411 .79788 L .82906 .79828 L 0 .467 .245 r
F
0 g
.82411 .79788 m
.82503 .80165 L
s
.75689 .9161 m .7558 .92359 L .76244 .92181 L 0 1 .507 r
F
.75689 .9161 m .75178 .92247 L .7558 .92359 L F
0 g
.75441 .927 m
.7558 .92359 L
s
.40659 1.01036 m .40089 1.01356 L .40765 1.01725 L 0 1 .485 r
F
.40659 1.01036 m .39405 1.00733 L .40089 1.01356 L F
0 g
.40089 1.01356 m
.40439 1.01923 L
s
.40967 .72234 m .3981 .72494 L .40139 .72672 L 0 1 .5 r
F
0 g
.39809 .73018 m
.40139 .72672 L
s
.50533 .9076 m .50816 .91917 L .50836 .91505 L 0 .424 .36 r
F
.516 .92226 m .50816 .91917 L .51156 .92677 L 0 .329 .341 r
F
.516 .92226 m .50836 .91505 L .50816 .91917 L F
0 g
.50447 .91776 m
.50816 .91917 L
s
.67723 1.07243 m .6888 1.07318 L .68598 1.07286 L 0 .667 .252 r
F
.69819 1.07263 m .6888 1.07318 L .69729 1.07308 L 0 .63 .226 r
F
.69819 1.07263 m .68598 1.07286 L .6888 1.07318 L F
0 g
.69302 1.07369 m
.69333 1.07364 L
s
.684 1.07353 m
.6888 1.07318 L
s
.38392 .95473 m .38282 .95973 L .38568 .95846 L 0 1 .536 r
F
.38392 .95473 m .37654 .95778 L .38282 .95973 L F
0 g
.38282 .95973 m
.38522 .9633 L
s
.68204 .61204 m
.68206 .61202 L
s
.32237 .7477 m .31123 .74352 L .31179 .74902 L 0 1 .525 r
F
.32237 .7477 m .31401 .73912 L .31123 .74352 L F
.32237 .7477 m .31827 .73878 L .31401 .73912 L F
.32237 .7477 m .32185 .74247 L .31827 .73878 L F
0 g
.31958 .75208 m
.32237 .7477 L
s
.32237 .7477 m
.32591 .75113 L
s
.51631 .76309 m
.51631 .76308 L
s
.51626 .76721 m
.51631 .76309 L
s
.51631 .76308 m
.51649 .76628 L
s
.51649 .76628 m
.51708 .77693 L
s
.42144 .7163 m
.42506 .7131 L
s
.50274 .97426 m .50665 .97647 L .50684 .97539 L 0 1 .473 r
F
.51693 .97464 m .50684 .97539 L .50665 .97647 L 0 1 .413 r
F
0 g
.50665 .97647 m
.5111 .97706 L
s
.50193 .97713 m
.50665 .97647 L
s
.36605 .77736 m .35957 .77975 L .36372 .77882 L 0 1 .326 r
F
.36605 .77736 m .3556 .77945 L .35957 .77975 L F
0 g
.3578 .78145 m
.35957 .77975 L
s
.36372 .77882 m
.36808 .77892 L
s
.48752 .89196 m .47839 .89777 L .48029 .89667 L 0 0 0 r
F
0 g
.47604 .89943 m
.48029 .89667 L
s
.79697 .8599 m .80743 .85178 L .80312 .85216 L 0 1 .498 r
F
.78632 .86103 m .79697 .8599 L .79666 .85284 L 0 1 .494 r
F
.41808 .924 m .40761 .92559 L .40474 .92687 L 0 1 .317 r
F
.41808 .924 m .41333 .92436 L .40761 .92559 L F
0 g
.41808 .924 m
.41973 .92483 L
s
.42499 .92054 m .41334 .92436 L .41808 .924 L 0 .976 .259 r
F
0 g
.41808 .924 m
.42363 .92265 L
s
.52164 .69768 m .52252 .69495 L .52471 .69964 L 0 .237 .137 r
F
0 g
.522 .6918 m
.52252 .69495 L
s
.49716 .82693 m .49397 .84282 L .49685 .84164 L 0 .533 .332 r
F
.52347 .4616 m .51877 .47034 L .51862 .46976 L 0 0 .024 r
F
.52347 .4616 m .52419 .46399 L .51877 .47034 L F
.52347 .4616 m .53124 .45498 L .52419 .46399 L F
.21955 .70615 m .20852 .6963 L .20816 .70704 L 0 1 .488 r
F
.21955 .70615 m .21221 .68808 L .20852 .6963 L F
.21955 .70615 m .21677 .6879 L .21221 .68808 L F
.21955 .70615 m .21992 .69566 L .21677 .6879 L F
0 g
.21586 .71432 m
.21955 .70615 L
s
.21955 .70615 m
.22268 .71367 L
s
.52865 .5807 m .53606 .57349 L .53721 .57764 L 0 .041 .08 r
F
0 g
.53606 .57349 m
.53792 .5649 L
s
.53239 .5748 m
.53606 .57349 L
s
.28123 .94314 m
.28125 .94317 L
s
.78136 .66068 m .79284 .66439 L .78869 .65855 L 0 .975 .493 r
F
0 g
.78136 .66068 m
.78262 .65907 L
s
.77891 .65729 m
.78136 .66068 L
s
.77781 .65577 m
.77891 .65729 L
s
.77723 .65495 m
.77781 .65577 L
s
.49088 .72082 m .48277 .72981 L .4873 .72445 L 0 0 .052 r
F
.49088 .72082 m .47964 .73438 L .48277 .72981 L F
.49088 .72082 m .48001 .73511 L .47964 .73438 L F
0 g
.4789 .73025 m
.4799 .72898 L
s
.4895 .72148 m
.49058 .72002 L
s
.49088 .72082 m .48361 .73146 L .48001 .73511 L 0 0 .052 r
F
0 g
.4799 .72898 m
.48007 .72877 L
s
.48007 .72877 m
.48206 .72623 L
s
.49088 .72082 m .48802 .72588 L .48361 .73146 L 0 0 .052 r
F
.49088 .72082 m .49113 .72132 L .48802 .72588 L F
0 g
.49088 .72082 m
.49408 .71519 L
s
.4873 .72445 m
.48848 .72285 L
s
.48848 .72285 m
.4895 .72148 L
s
.4873 .72445 m
.48957 .72215 L
s
.48957 .72215 m
.49088 .72082 L
s
.49113 .72132 m
.49462 .71624 L
s
.59977 .58578 m
.60051 .58468 L
s
.59843 .58778 m
.59977 .58578 L
s
.60051 .58468 m
.60051 .58468 L
s
.60343 .58036 m .60666 .60448 L .60339 .59734 L 0 .633 .172 r
F
0 g
.60339 .59734 m
.60343 .58036 L
s
.60341 .58037 m
.60342 .58036 L
s
.60051 .58468 m
.60341 .58037 L
s
.60343 .58036 m .61196 .60743 L .60666 .60448 L 0 .633 .172 r
F
.60343 .58036 m .61575 .6042 L .61196 .60743 L F
.60343 .58036 m .61573 .58718 L .61575 .6042 L F
0 g
.60343 .58036 m
.60343 .58036 L
s
.51868 1.07829 m .51036 1.07694 L .50398 1.07725 L 0 1 .526 r
F
.31179 .74902 m .30061 .74447 L .30121 .75026 L 0 1 .525 r
F
0 g
.30121 .75026 m
.30482 .75415 L
s
.31179 .74902 m .30336 .7399 L .30061 .74447 L 0 1 .525 r
F
.31179 .74902 m .30762 .7396 L .30336 .7399 L F
.31179 .74902 m .31123 .74352 L .30762 .7396 L F
0 g
.30904 .75358 m
.31179 .74902 L
s
.31179 .74902 m
.31537 .75269 L
s
.35066 .64677 m
.35507 .64091 L
s
.55444 .67136 m
.55505 .68087 L
s
.60657 .43399 m .61385 .43514 L .62112 .43978 L 0 .304 .059 r
F
0 g
.61385 .43514 m
.61746 .43125 L
s
.34668 .96557 m .34352 .97367 L .34765 .97225 L 0 1 .482 r
F
.34668 .96557 m .3361 .969 L .34352 .97367 L F
.36139 .98365 m .34765 .97225 L .34352 .97367 L 0 1 .487 r
F
0 g
.34352 .97367 m
.3453 .98019 L
s
.46794 .67059 m .46025 .67346 L .464 .67295 L 0 1 .426 r
F
.46794 .67059 m .45878 .67174 L .46025 .67346 L F
0 g
.464 .67295 m
.46583 .67451 L
s
.46794 .67059 m .46058 .66894 L .45878 .67174 L 0 1 .426 r
F
.46794 .67059 m .46453 .66657 L .46058 .66894 L F
.46794 .67059 m .46798 .66623 L .46453 .66657 L F
.46794 .67059 m .46944 .66795 L .46798 .66623 L F
0 g
.46794 .67059 m
.46962 .67228 L
s
.464 .67295 m
.46794 .67059 L
s
.46944 .66795 m
.47315 .66588 L
s
.55007 1.0715 m .54751 1.07267 L .54608 1.07325 L 0 0 0 r
F
0 g
.53821 .74761 m
.539 .75241 L
s
.53707 .7407 m
.53821 .74761 L
s
.53608 .73472 m
.53707 .7407 L
s
.34668 .96557 m .33031 .96135 L .3361 .969 L 0 1 .482 r
F
0 g
.3361 .969 m
.34352 .97367 L
s
.40967 .72234 m .39835 .72146 L .3981 .72494 L 0 1 .5 r
F
.40967 .72234 m .402 .71818 L .39835 .72146 L F
.40967 .72234 m .40661 .71729 L .402 .71818 L F
.40967 .72234 m .4099 .71907 L .40661 .71729 L F
0 g
.40967 .72234 m
.41296 .72384 L
s
.40602 .72561 m
.40967 .72234 L
s
.30121 .75026 m .28667 .74562 L .28733 .75177 L 0 1 .526 r
F
0 g
.28733 .75177 m
.29198 .75583 L
s
.30121 .75026 m .29037 .74073 L .28667 .74562 L 0 1 .526 r
F
.30121 .75026 m .29596 .74039 L .29037 .74073 L F
.30121 .75026 m .30061 .74447 L .29596 .74039 L F
0 g
.29751 .75512 m
.30121 .75026 L
s
.49455 .71882 m
.49521 .71744 L
s
.49521 .71744 m
.49535 .71714 L
s
.49482 .71796 m
.49535 .71714 L
s
.4335 .75642 m .42595 .75952 L .43049 .75753 L 0 0 0 r
F
0 g
.43049 .75753 m
.43183 .75691 L
s
.57995 .43573 m
.5808 .43691 L
s
.31305 .9473 m .2968 .93943 L .29813 .94434 L 0 1 .535 r
F
0 g
.29101 .94082 m
.29104 .94082 L
s
.31305 .9473 m .3007 .93851 L .2968 .93943 L 0 1 .535 r
F
0 g
.29104 .94082 m
.29706 .94039 L
s
.29112 .94085 m
.29754 .94219 L
s
.31305 .9473 m .30767 .94189 L .3007 .93851 L 0 1 .535 r
F
.32234 .94469 m .30767 .94189 L .31305 .9473 L 0 1 .534 r
F
0 g
.31305 .9473 m
.3198 .95052 L
s
.31305 .9473 m
.31434 .95219 L
s
.81551 .83217 m .81274 .84323 L .81389 .8513 L 0 1 .488 r
F
0 g
.80761 .85911 m
.81389 .8513 L
s
.47768 .65481 m .47961 .65195 L .47909 .64979 L 0 1 .382 r
F
0 g
.47961 .65195 m
.483 .65019 L
s
.67043 1.07136 m .67723 1.07243 L .68175 1.0724 L 0 .618 .243 r
F
.51089 .65006 m .50853 .62025 L .50884 .63958 L 0 1 .27 r
F
.50489 .664 m .50884 .63958 L .50853 .62025 L 0 1 .278 r
F
0 g
.50614 .61197 m
.50853 .62025 L
s
.50853 .62025 m
.51018 .60221 L
s
.51379 .77178 m .51284 .7701 L .51198 .77886 L 0 .504 .296 r
F
0 g
.51237 .75865 m
.51284 .7701 L
s
.45999 1.05077 m .46386 1.05684 L .46487 1.0554 L 0 .937 .488 r
F
.47915 1.06144 m .46487 1.0554 L .46386 1.05684 L 0 .937 .486 r
F
0 g
.46386 1.05684 m
.4692 1.06098 L
s
.45716 1.05434 m
.46386 1.05684 L
s
.28733 .75177 m .27532 .74648 L .27603 .75293 L 0 1 .526 r
F
.28733 .75177 m .2782 .74144 L .27532 .74648 L F
.28733 .75177 m .28276 .74118 L .2782 .74144 L F
.28733 .75177 m .28667 .74562 L .28276 .74118 L F
0 g
.28445 .75678 m
.28733 .75177 L
s
.50087 .85509 m .49559 .86433 L .49883 .8696 L 0 .472 .337 r
F
0 g
.49401 .85622 m
.49559 .86433 L
s
.4923 .86399 m
.49559 .86433 L
s
.75102 1.06831 m .75936 1.06798 L .76359 1.06617 L 0 .876 .271 r
F
.20828 .75914 m .19587 .75161 L .19699 .76011 L 0 1 .528 r
F
0 g
.19699 .76011 m
.20121 .7661 L
s
.27603 .75293 m .26397 .74729 L .26474 .75403 L 0 1 .527 r
F
.27603 .75293 m .26681 .74204 L .26397 .74729 L F
.27603 .75293 m .27137 .7418 L .26681 .74204 L F
.27603 .75293 m .27532 .74648 L .27137 .7418 L F
0 g
.27319 .75815 m
.27603 .75293 L
s
.27603 .75293 m
.27994 .75734 L
s
.26054 .94609 m .2434 .94457 L .24478 .94644 L 0 1 .328 r
F
.26054 .94609 m .24751 .94392 L .2434 .94457 L F
.26054 .94609 m .25486 .94457 L .24751 .94392 L F
.27039 .94393 m .25486 .94457 L .26054 .94609 L 0 .939 .294 r
F
0 g
.26054 .94609 m
.26734 .94648 L
s
.26054 .94609 m
.26183 .9479 L
s
.51693 .7639 m
.51693 .7639 L
s
.51693 .7639 m
.51721 .77239 L
s
.51827 .77832 m
.5183 .77861 L
s
.51822 .77773 m
.51827 .77832 L
s
.51693 .7639 m
.51699 .76457 L
s
.5172 .76683 m
.51771 .77231 L
s
.51699 .76457 m
.5172 .76683 L
s
.51771 .77231 m
.51822 .77773 L
s
.44258 .91489 m .43028 .91913 L .43184 .91941 L 0 .888 .241 r
F
0 g
.42629 .9212 m
.43184 .91941 L
s
.20828 .75914 m .19844 .74508 L .19587 .75161 L 0 1 .528 r
F
.20828 .75914 m .203 .74489 L .19844 .74508 L F
.20828 .75914 m .20722 .75093 L .203 .74489 L F
.21957 .75815 m .20722 .75093 L .20828 .75914 L F
0 g
.20571 .76562 m
.20828 .75914 L
s
.20828 .75914 m
.21245 .76491 L
s
.43851 .96958 m .43274 .96735 L .42676 .96677 L 0 1 .537 r
F
.44334 .966 m .43851 .96958 L .4442 .97016 L 0 1 .535 r
F
.44334 .966 m .43274 .96735 L .43851 .96958 L F
0 g
.43851 .96958 m
.44148 .97241 L
s
.37697 .77493 m .3701 .77734 L .37444 .77628 L 0 .947 .275 r
F
.37697 .77493 m .36605 .77735 L .3701 .77734 L F
0 g
.36809 .77892 m
.3701 .77734 L
s
.37444 .77628 m
.37884 .77606 L
s
.26474 .75403 m .25262 .74806 L .25345 .7551 L 0 1 .527 r
F
.26474 .75403 m .25542 .74259 L .25262 .74806 L F
.26474 .75403 m .25998 .74238 L .25542 .74259 L F
.26474 .75403 m .26397 .74729 L .25998 .74238 L F
0 g
.26194 .75947 m
.26474 .75403 L
s
.26474 .75403 m
.26869 .75868 L
s
.21957 .75815 m .20984 .7446 L .20722 .75093 L 0 1 .528 r
F
.21957 .75815 m .2144 .74441 L .20984 .7446 L F
.21957 .75815 m .21857 .75023 L .2144 .74441 L F
.23086 .75716 m .21857 .75023 L .21957 .75815 L 0 1 .527 r
F
0 g
.21695 .76443 m
.21957 .75815 L
s
.21957 .75815 m
.22369 .76371 L
s
.30335 .67699 m .29083 .66877 L .28946 .6777 L 0 1 .468 r
F
0 g
.28946 .6777 m
.29262 .6841 L
s
.30335 .67699 m .29599 .66202 L .29083 .66877 L 0 1 .468 r
F
.30335 .67699 m .3015 .66197 L .29599 .66202 L F
.30335 .67699 m .30465 .6684 L .3015 .66197 L F
0 g
.2982 .68372 m
.30335 .67699 L
s
.23086 .75716 m .22124 .74412 L .21857 .75023 L 0 1 .527 r
F
.23086 .75716 m .2258 .74393 L .22124 .74412 L F
.23086 .75716 m .22992 .74953 L .2258 .74393 L F
.24215 .75614 m .22992 .74953 L .23086 .75716 L F
0 g
.22819 .76323 m
.23086 .75716 L
s
.23086 .75716 m
.23494 .76249 L
s
.25345 .7551 m .24127 .7488 L .24215 .75614 L 0 1 .527 r
F
.25345 .7551 m .24403 .74312 L .24127 .7488 L F
.25345 .7551 m .24859 .74292 L .24403 .74312 L F
.25345 .7551 m .25262 .74806 L .24859 .74292 L F
0 g
.25069 .76075 m
.25345 .7551 L
s
.25345 .7551 m
.25744 .75998 L
s
.24215 .75614 m .23264 .74363 L .22992 .74953 L 0 1 .527 r
F
.24215 .75614 m .23719 .74343 L .23264 .74363 L F
.24215 .75614 m .24127 .7488 L .23719 .74343 L F
0 g
.23944 .762 m
.24215 .75614 L
s
.24215 .75614 m
.24619 .76125 L
s
.47768 .65481 m .471 .6572 L .474 .65706 L 0 1 .382 r
F
0 g
.47563 .65866 m
.47848 .65713 L
s
.47768 .65481 m .47048 .65504 L .471 .6572 L 0 1 .382 r
F
.47768 .65481 m .47279 .65203 L .47048 .65504 L F
.47768 .65481 m .47648 .64978 L .47279 .65203 L F
.47768 .65481 m .47909 .64979 L .47648 .64978 L F
0 g
.47768 .65481 m
.47848 .65713 L
s
.47909 .64979 m
.48259 .64757 L
s
.47909 .64979 m
.47961 .65195 L
s
.4335 .75642 m .42209 .76125 L .42595 .75952 L 0 0 0 r
F
0 g
.42359 .76058 m
.42595 .75952 L
s
.4233 .7608 m
.42432 .76031 L
s
.42012 .76197 m
.42221 .7612 L
s
.42227 .76118 m
.4233 .7608 L
s
.66268 .5025 m
.66762 .51319 L
s
.66762 .51319 m
.6694 .51702 L
s
.47182 .97405 m .46595 .97281 L .46047 .97301 L 0 1 .528 r
F
0 g
.46047 .97301 m
.46595 .97281 L
s
.47182 .97405 m
.47545 .9761 L
s
.49868 1.06999 m .48965 1.07047 L .49792 1.07359 L 0 .985 .485 r
F
.49868 1.06999 m .48389 1.06705 L .48965 1.07047 L F
0 g
.483 1.06935 m
.48965 1.07047 L
s
.28946 .6777 m .2805 .68487 L .28504 .68459 L 0 1 .472 r
F
0 g
.28504 .68459 m
.28814 .69113 L
s
.50087 .85509 m .49809 .85019 L .49514 .85067 L 0 .472 .337 r
F
0 g
.49397 .84282 m
.49514 .85067 L
s
.37654 .95778 m .3645 .95185 L .36135 .95299 L 0 1 .536 r
F
.37654 .95778 m .37102 .95391 L .3645 .95185 L F
.38392 .95473 m .37102 .95391 L .37654 .95778 L F
0 g
.37654 .95778 m
.37854 .96167 L
s
.37654 .95778 m
.38282 .95973 L
s
.47095 .66534 m .46453 .66657 L .46798 .66623 L 0 1 .421 r
F
.47095 .66534 m .46239 .66616 L .46453 .66657 L F
0 g
.46798 .66623 m
.46944 .66795 L
s
.47095 .66534 m .463 .66528 L .46239 .66616 L 0 1 .421 r
F
.47095 .66534 m .46598 .66439 L .463 .66528 L F
.47095 .66534 m .46933 .6641 L .46598 .66439 L F
.47095 .66534 m .47146 .6645 L .46933 .6641 L F
0 g
.47095 .66534 m
.47315 .66588 L
s
.46798 .66623 m
.47095 .66534 L
s
.47146 .6645 m
.47435 .66384 L
s
.30347 .78779 m .29098 .78351 L .28811 .78632 L 0 1 .494 r
F
.30347 .78779 m .29653 .78308 L .29098 .78351 L F
.30347 .78779 m .30189 .78491 L .29653 .78308 L F
0 g
.30059 .79058 m
.30347 .78779 L
s
.31389 .78633 m .30189 .78491 L .30348 .78779 L 0 1 .48 r
F
0 g
.30348 .78779 m
.30777 .78943 L
s
.43412 .52109 m .43947 .51313 L .44192 .50842 L 0 1 .181 r
F
0 g
.43203 .52594 m
.43412 .52109 L
s
.47316 .6618 m .47492 .65903 L .474 .65706 L 0 1 .405 r
F
0 g
.47492 .65903 m
.47563 .65866 L
s
.49056 .58775 m .49197 .56023 L .48773 .57107 L 0 1 .277 r
F
0 g
.49197 .56023 m
.4948 .55808 L
s
.49197 .56023 m
.4927 .55687 L
s
.47316 .6618 m .46598 .66439 L .46933 .66409 L 0 1 .405 r
F
.47316 .6618 m .46505 .66242 L .46598 .66439 L F
0 g
.46933 .6641 m
.47146 .6645 L
s
.47316 .6618 m .46716 .65949 L .46505 .66242 L 0 1 .405 r
F
.47316 .6618 m .471 .6572 L .46716 .65949 L F
.47316 .6618 m .474 .65706 L .471 .6572 L F
0 g
.46933 .66409 m
.47316 .6618 L
s
.47316 .6618 m
.47435 .66384 L
s
.474 .65706 m
.47768 .65481 L
s
.474 .65706 m
.47492 .65903 L
s
.40659 1.01036 m .39081 1.00174 L .39405 1.00733 L 0 1 .485 r
F
0 g
.38703 1.0036 m
.39405 1.00733 L
s
.33848 .65497 m .32808 .65538 L .32973 .66115 L 0 1 .458 r
F
0 g
.32568 .66742 m
.32973 .66115 L
s
.3981 .72494 m .38981 .72923 L .39444 .72827 L 0 1 .507 r
F
0 g
.39444 .72827 m
.39809 .73018 L
s
.516 .92226 m .51156 .92677 L .51631 .93281 L 0 .329 .341 r
F
0 g
.50816 .91917 m
.51156 .92677 L
s
.50785 .925 m
.51156 .92677 L
s
.43406 .706 m
.43786 .70299 L
s
.33848 .65497 m .33008 .64745 L .32808 .65538 L 0 1 .458 r
F
.33848 .65497 m .33465 .64148 L .33008 .64745 L F
.33848 .65497 m .33874 .64146 L .33465 .64148 L F
.33848 .65497 m .34038 .64725 L .33874 .64146 L F
0 g
.33848 .65497 m
.34019 .66053 L
s
.33391 .66093 m
.33848 .65497 L
s
.49679 .88547 m .49306 .88817 L .48942 .89088 L 0 .834 .169 r
F
.4988 .88448 m .49679 .88547 L .50009 .88318 L 0 0 0 r
F
.4988 .88448 m .49306 .88817 L .49679 .88547 L F
.48865 .97291 m .49172 .97582 L .49236 .97451 L 0 1 .503 r
F
.50274 .97426 m .49236 .97451 L .49172 .97582 L 0 1 .473 r
F
0 g
.49172 .97582 m
.49583 .97694 L
s
.48674 .97625 m
.49172 .97582 L
s
.42209 .76125 m .41461 .76406 L .41915 .76232 L 0 0 0 r
F
0 g
.41915 .76232 m
.42012 .76197 L
s
.3879 .77223 m .38095 .77461 L .3853 .77345 L 0 .833 .248 r
F
.3879 .77223 m .37697 .77493 L .38095 .77461 L F
0 g
.37884 .77606 m
.38095 .77461 L
s
.3853 .77345 m
.3896 .77294 L
s
.49206 .62752 m
.49227 .62737 L
s
.75689 .9161 m .75224 .91926 L .75178 .92247 L 0 1 .507 r
F
0 g
.74457 .92395 m
.75178 .92247 L
s
.4748 .97049 m .47182 .97405 L .47701 .97392 L 0 1 .519 r
F
.4748 .97049 m .46595 .97281 L .47182 .97405 L F
.40659 1.01036 m .40765 1.01725 L .40982 1.01595 L 0 1 .485 r
F
.42353 1.02501 m .40982 1.01595 L .40765 1.01725 L 0 .981 .488 r
F
0 g
.40765 1.01725 m
.41148 1.02257 L
s
.40089 1.01356 m
.40765 1.01725 L
s
.49688 .60106 m
.49974 .6036 L
s
.49668 .60088 m
.49688 .60106 L
s
.50702 .79288 m .50372 .79464 L .50258 .80397 L 0 .507 .308 r
F
.50702 .79288 m .50563 .78989 L .50372 .79464 L F
0 g
.50357 .78531 m
.50372 .79464 L
s
.50372 .79464 m
.50563 .78989 L
s
.50544 .77908 m
.50563 .78989 L
s
.22704 .92897 m .22348 .93583 L .22757 .93506 L 0 1 .535 r
F
0 g
.22757 .93506 m
.22887 .93588 L
s
.22704 .92897 m .21668 .93072 L .22348 .93583 L 0 1 .535 r
F
0 g
.22348 .93583 m
.22498 .94155 L
s
.42432 .9637 m .41034 .96138 L .41279 .96445 L 0 1 .537 r
F
0 g
.40654 .96341 m
.41279 .96445 L
s
.42209 .76125 m .41069 .76542 L .41461 .76406 L 0 0 0 r
F
0 g
.41245 .76481 m
.41461 .76406 L
s
.41206 .76533 m
.41461 .76406 L
s
.40843 .76634 m
.41206 .76533 L
s
.20816 .70704 m .19712 .69692 L .19678 .7079 L 0 1 .491 r
F
0 g
.19678 .7079 m
.19993 .7158 L
s
.20816 .70704 m .2008 .68852 L .19712 .69692 L 0 1 .491 r
F
.20816 .70704 m .20537 .68835 L .2008 .68852 L F
.20816 .70704 m .20852 .6963 L .20537 .68835 L F
0 g
.20449 .71538 m
.20816 .70704 L
s
.20816 .70704 m
.21131 .71475 L
s
.36139 .98365 m .35531 .97653 L .34765 .97225 L 0 1 .487 r
F
0 g
.36139 .98365 m
.36315 .99016 L
s
.36874 .98082 m .36139 .98365 L .36808 .98811 L 0 1 .482 r
F
.36874 .98082 m .35531 .97653 L .36139 .98365 L F
0 g
.29127 .94097 m
.29302 .94183 L
s
.29302 .94183 m
.29813 .94434 L
s
.44491 .75077 m .43297 .75694 L .4335 .75642 L 0 0 0 r
F
.44491 .75077 m .43604 .75572 L .43297 .75694 L F
.44491 .75077 m .44066 .75358 L .43604 .75572 L F
0 g
.43473 .75573 m
.4373 .7543 L
s
.44491 .75077 m .44446 .75146 L .44066 .75358 L 0 0 0 r
F
0 g
.44491 .75077 m
.44588 .75011 L
s
.44184 .75199 m
.44491 .75077 L
s
.36633 .62785 m
.37104 .6222 L
s
.39929 .76905 m .39196 .77155 L .39648 .7702 L 0 .8 .23 r
F
.39929 .76905 m .3879 .77223 L .39196 .77155 L F
0 g
.38961 .77294 m
.39196 .77155 L
s
.39648 .7702 m
.40083 .76934 L
s
.52568 .70627 m .52613 .64365 L .52508 .6783 L 0 .83 .256 r
F
.52096 .70391 m .52508 .6783 L .52613 .64365 L 0 .852 .261 r
F
0 g
.52613 .64365 m
.52824 .62022 L
s
.52516 .62095 m
.52613 .64365 L
s
.52381 .6906 m
.52471 .69964 L
s
.52252 .69495 m
.52318 .69635 L
s
.52318 .69635 m
.52471 .69964 L
s
.41069 .76542 m .40328 .76804 L .40781 .76651 L 0 .75 .205 r
F
0 g
.40781 .76651 m
.40843 .76634 L
s
.44334 .966 m .4442 .97016 L .44602 .9687 L 0 1 .535 r
F
.4573 .9706 m .44602 .9687 L .4442 .97016 L 0 1 .533 r
F
0 g
.4442 .97016 m
.44739 .97257 L
s
.43851 .96958 m
.4442 .97016 L
s
.36874 .98082 m .36808 .98811 L .37093 .98695 L 0 1 .482 r
F
.38417 .99769 m .37093 .98695 L .36808 .98811 L 0 1 .486 r
F
0 g
.36808 .98811 m
.37095 .99404 L
s
.36139 .98365 m
.36808 .98811 L
s
.5465 .68614 m
.54665 .68859 L
s
.51785 .70053 m
.51938 .70387 L
s
.51785 .70053 m
.51785 .70054 L
s
.41069 .76542 m .39929 .76905 L .40328 .76804 L 0 .75 .205 r
F
0 g
.40083 .76934 m
.40328 .76804 L
s
.50619 .89609 m .50533 .9076 L .50867 .90847 L 0 .408 .349 r
F
0 g
.39602 .58643 m
.39618 .58179 L
s
.39076 .5921 m
.39602 .58643 L
s
.51379 .77178 m .51498 .79822 L .51471 .78382 L 0 .504 .296 r
F
.51379 .77178 m .51411 .80701 L .51498 .79822 L F
0 g
.5143 .76013 m
.51518 .7737 L
s
.51379 .77178 m .51268 .8043 L .51411 .80701 L 0 .504 .296 r
F
.51379 .77178 m .51177 .79222 L .51268 .8043 L F
.51379 .77178 m .51198 .77886 L .51177 .79222 L F
0 g
.51142 .76745 m
.51198 .77886 L
s
.51379 .77178 m
.51384 .77237 L
s
.51379 .77178 m
.5143 .76013 L
s
.51198 .77886 m
.51284 .7701 L
s
.28946 .6777 m .27815 .67818 L .2805 .68487 L 0 1 .472 r
F
0 g
.27679 .69201 m
.2805 .68487 L
s
.23916 .934 m
.24515 .93772 L
s
.76501 .86455 m .76162 .87375 L .76221 .88016 L 0 1 .486 r
F
0 g
.75576 .88676 m
.76221 .88016 L
s
.46715 .73829 m .45914 .74315 L .46376 .74001 L 0 0 0 r
F
0 g
.46376 .74001 m
.46627 .73873 L
s
.46376 .74001 m
.46636 .73787 L
s
.76162 .75616 m .77095 .76298 L .76627 .75941 L 0 .116 .169 r
F
.76162 .75616 m .77325 .76534 L .77095 .76298 L F
.68269 .93108 m .69124 .92854 L .69251 .92577 L 0 1 .392 r
F
.31389 .78633 m .30387 .78248 L .30189 .78491 L 0 1 .48 r
F
.31389 .78633 m .30809 .78211 L .30387 .78248 L F
.31389 .78633 m .31239 .78377 L .30809 .78211 L F
.32431 .78478 m .31239 .78377 L .31389 .78633 L 0 1 .461 r
F
0 g
.3119 .78875 m
.31389 .78633 L
s
.31389 .78633 m
.31811 .78771 L
s
.3981 .72494 m .38653 .72719 L .38981 .72923 L 0 1 .507 r
F
0 g
.38654 .73277 m
.38981 .72923 L
s
.7475 .74262 m
.74819 .74375 L
s
.71701 .61043 m .72559 .58448 L .72998 .58735 L 0 .297 .105 r
F
.71701 .61043 m .72004 .59431 L .72559 .58448 L F
0 g
.72389 .57206 m
.72559 .58448 L
s
.50036 .80807 m .49971 .82449 L .50086 .81677 L 0 .533 .321 r
F
.50036 .80807 m .49716 .82693 L .49971 .82449 L F
.44844 .69227 m .43995 .69599 L .44436 .69501 L 0 1 .463 r
F
.44844 .69227 m .43754 .69457 L .43995 .69599 L F
0 g
.44436 .69501 m
.4471 .69629 L
s
.44844 .69227 m .43875 .69171 L .43754 .69457 L 0 1 .463 r
F
.44844 .69227 m .44283 .68896 L .43875 .69171 L F
.44844 .69227 m .44708 .68815 L .44283 .68896 L F
.44844 .69227 m .44948 .68957 L .44708 .68815 L F
0 g
.44844 .69227 m
.45097 .69347 L
s
.44436 .69501 m
.44844 .69227 L
s
.50975 .87518 m
.51186 .87318 L
s
.44948 .68957 m
.45343 .68689 L
s
.49868 1.06999 m .49792 1.07359 L .50426 1.07486 L 0 .985 .485 r
F
0 g
.49792 1.07359 m
.50398 1.07725 L
s
.40441 .95999 m .38997 .95658 L .39211 .96 L 0 1 .537 r
F
0 g
.38568 .95846 m
.39211 .96 L
s
.49716 .82693 m .49685 .84164 L .498 .83515 L 0 .533 .332 r
F
.48883 .45423 m .49589 .44734 L .50093 .44476 L 0 0 .035 r
F
0 g
.49589 .44734 m
.49993 .44147 L
s
.47865 .73057 m .47047 .73685 L .47511 .73293 L 0 0 .024 r
F
.47865 .73057 m .46706 .74043 L .47047 .73685 L F
.47865 .73057 m .46717 .74128 L .46706 .74043 L F
.47865 .73057 m .47071 .73892 L .46717 .74128 L F
.47865 .73057 m .47533 .73493 L .47071 .73892 L F
.47865 .73057 m .47873 .73136 L .47533 .73493 L F
0 g
.47865 .73057 m
.4789 .73025 L
s
.47511 .73293 m
.47864 .72937 L
s
.47511 .73293 m
.47865 .73057 L
s
.5073 .48727 m .5184 .46902 L .51353 .47671 L 0 0 0 r
F
0 g
.5184 .46902 m
.52347 .4616 L
s
.63778 .56531 m .64751 .61918 L .64066 .56208 L 0 .122 .176 r
F
0 g
.63763 .56119 m
.63778 .56531 L
s
.63698 .59613 m
.6394 .62058 L
s
.63731 .56055 m
.63778 .56531 L
s
.38741 .59898 m .37835 .60482 L .38209 .60442 L 0 1 .428 r
F
.38741 .59898 m .37822 .60013 L .37835 .60482 L F
0 g
.38209 .60442 m
.3828 .60938 L
s
.38741 .59898 m .3818 .59347 L .37822 .60013 L 0 1 .428 r
F
.38741 .59898 m .38712 .58802 L .3818 .59347 L F
.38741 .59898 m .39064 .58741 L .38712 .58802 L F
.38741 .59898 m .39076 .5921 L .39064 .58741 L F
0 g
.38209 .60442 m
.38741 .59898 L
s
.52485 .43416 m .53234 .42983 L .53842 .43041 L 0 .168 .082 r
F
0 g
.53234 .42983 m
.53747 .4222 L
s
.67052 .62635 m
.67057 .626 L
s
.6709 .62357 m
.67104 .62254 L
s
.67135 .62022 m
.67135 .62022 L
s
.6705 .62646 m
.67052 .62635 L
s
.67032 .62783 m
.67034 .62767 L
s
.67034 .62767 m
.67034 .62767 L
s
.67034 .62767 m
.67036 .62749 L
s
.67043 .627 m
.6705 .62646 L
s
.32249 .93978 m .30655 .93714 L .30773 .93983 L 0 1 .493 r
F
.32249 .93978 m .31045 .93624 L .30655 .93714 L F
.32249 .93978 m .31729 .93738 L .31045 .93624 L F
0 g
.32249 .93978 m
.32365 .94245 L
s
.33394 .93652 m .3173 .93738 L .32249 .93978 L 0 1 .477 r
F
0 g
.32249 .93978 m
.32974 .94053 L
s
.50999 .60203 m .51335 .59734 L .51598 .59495 L 0 0 0 r
F
0 g
.51335 .59734 m
.51575 .59368 L
s
.516 .92226 m .51172 .91637 L .50836 .91505 L 0 .329 .341 r
F
0 g
.50533 .9076 m
.50836 .91505 L
s
.27054 .94005 m .25419 .93015 L .25522 .93567 L 0 1 .535 r
F
.27054 .94005 m .25829 .9294 L .25419 .93015 L F
.27054 .94005 m .26531 .93365 L .25829 .9294 L F
.28042 .93784 m .26531 .93365 L .27054 .94005 L 0 1 .534 r
F
0 g
.27054 .94005 m
.27088 .9419 L
s
.27054 .94005 m
.2729 .94145 L
s
.49883 .8696 m .50009 .88248 L .50077 .87739 L 0 .481 .348 r
F
0 g
.4968 .88213 m
.50009 .88248 L
s
.50009 .88248 m
.50025 .88303 L
s
.50025 .88303 m
.50025 .88304 L
s
.36347 .93514 m .34871 .93472 L .35011 .9366 L 0 1 .445 r
F
.36347 .93514 m .35214 .9337 L .34871 .93472 L F
.36347 .93514 m .35847 .93389 L .35214 .9337 L F
.37158 .93228 m .35847 .93389 L .36347 .93514 L 0 1 .418 r
F
0 g
.36347 .93514 m
.36958 .93517 L
s
.36347 .93514 m
.36485 .93702 L
s
.50292 .83801 m .49685 .84164 L .49809 .85019 L 0 .472 .326 r
F
.50292 .83801 m .498 .83515 L .49685 .84164 L F
0 g
.49397 .84282 m
.49685 .84164 L
s
.52173 .69917 m
.52199 .70409 L
s
.7673 .9183 m .77261 .92427 L .77768 .92042 L 0 1 .515 r
F
0 g
.76582 .92633 m
.77261 .92427 L
s
.77182 .92794 m
.77261 .92427 L
s
.79841 .92449 m .80874 .92647 L .80991 .92232 L 0 1 .529 r
F
.4748 .97049 m .46266 .9708 L .46595 .97281 L 0 1 .519 r
F
.50702 .79288 m .50258 .80397 L .50311 .81381 L 0 .507 .308 r
F
0 g
.50036 .80807 m
.50258 .80397 L
s
.76501 .86455 m .77212 .872 L .77567 .86256 L 0 1 .486 r
F
0 g
.76635 .87954 m
.77212 .872 L
s
.77212 .872 m
.77258 .87874 L
s
.80452 .83344 m .80743 .85178 L .81274 .84323 L 0 1 .484 r
F
.80452 .83344 m .80312 .85216 L .80743 .85178 L F
0 g
.80743 .85178 m
.80761 .85911 L
s
.51617 .70559 m .51689 .63686 L .51498 .66024 L 0 .872 .266 r
F
0 g
.51652 .64138 m
.51689 .63686 L
s
.51521 .62353 m
.51689 .63686 L
s
.46715 .73829 m .45558 .74613 L .45914 .74315 L 0 0 0 r
F
.46715 .73829 m .45546 .74694 L .45558 .74613 L F
0 g
.45443 .74594 m
.45504 .74553 L
s
.46715 .73829 m .45886 .74522 L .45546 .74694 L 0 0 0 r
F
0 g
.45595 .74491 m
.45783 .74387 L
s
.45783 .74387 m
.45825 .74364 L
s
.45504 .74553 m
.45595 .74491 L
s
.46715 .73829 m .4635 .74212 L .45886 .74522 L 0 0 0 r
F
0 g
.45825 .74364 m
.45914 .74315 L
s
.46715 .73829 m .46706 .73915 L .4635 .74212 L 0 0 0 r
F
0 g
.46715 .73829 m
.46761 .73783 L
s
.46627 .73873 m
.46715 .73829 L
s
.70286 .91495 m .69844 .92065 L .69857 .92408 L 0 1 .457 r
F
0 g
.69844 .92065 m
.69857 .92408 L
s
.69124 .92854 m
.69857 .92408 L
s
.53939 1.07528 m .53112 1.07758 L .5251 1.08077 L 0 1 .527 r
F
.32431 .78478 m .31444 .78154 L .31239 .78377 L 0 1 .461 r
F
.32431 .78478 m .31867 .78115 L .31444 .78154 L F
.32431 .78478 m .3229 .78254 L .31867 .78115 L F
.33473 .78314 m .3229 .78254 L .32431 .78478 L 0 1 .437 r
F
0 g
.32225 .78699 m
.32431 .78478 L
s
.32431 .78478 m
.32846 .7859 L
s
.47915 1.06144 m .48389 1.06705 L .48449 1.06559 L 0 .937 .486 r
F
.49868 1.06999 m .48449 1.06559 L .48389 1.06705 L 0 .985 .485 r
F
0 g
.48389 1.06705 m
.48965 1.07047 L
s
.47734 1.06507 m
.48389 1.06705 L
s
.42205 .71173 m .41353 .71584 L .41814 .71479 L 0 1 .492 r
F
0 g
.41814 .71479 m
.42144 .7163 L
s
.52865 .5807 m .52698 .5904 L .52632 .58739 L 0 .041 .08 r
F
.52865 .5807 m .53066 .58909 L .52698 .5904 L F
.52865 .5807 m .5349 .58433 L .53066 .58909 L F
.52865 .5807 m .53721 .57764 L .5349 .58433 L F
0 g
.52534 .58368 m
.52865 .5807 L
s
.78486 .77332 m .79467 .78067 L .79646 .78028 L 0 .269 .203 r
F
0 g
.79467 .78067 m
.79675 .78302 L
s
.7899 .77866 m
.79467 .78067 L
s
.43412 .52109 m .42577 .52965 L .42824 .52817 L 0 1 .181 r
F
0 g
.43003 .52835 m
.43203 .52594 L
s
.43412 .52109 m .42822 .52494 L .42577 .52965 L 0 1 .181 r
F
0 g
.42636 .53278 m
.43003 .52835 L
s
.43412 .52109 m .43397 .51717 L .42822 .52494 L 0 1 .181 r
F
.43412 .52109 m .43984 .51009 L .43397 .51717 L F
.43412 .52109 m .44192 .50842 L .43984 .51009 L F
0 g
.43947 .51313 m
.44192 .50842 L
s
.44192 .50842 m
.44773 .50101 L
s
.51891 .76614 m
.51907 .7729 L
s
.51891 .76614 m
.51907 .76757 L
s
.4818 .72849 m
.48225 .72807 L
s
.44334 .966 m .43004 .96466 L .43274 .96735 L 0 1 .535 r
F
0 g
.42676 .96677 m
.43274 .96735 L
s
.56655 .56998 m .57068 .56562 L .57575 .57233 L 0 .508 .14 r
F
0 g
.57068 .56562 m
.5718 .55139 L
s
.3981 .72494 m .38679 .72349 L .38653 .72719 L 0 1 .507 r
F
0 g
.38653 .72719 m
.38981 .72923 L
s
.3981 .72494 m .39045 .72016 L .38679 .72349 L 0 1 .507 r
F
.3981 .72494 m .39507 .71941 L .39045 .72016 L F
.3981 .72494 m .39835 .72146 L .39507 .71941 L F
0 g
.3981 .72494 m
.40139 .72672 L
s
.39444 .72827 m
.3981 .72494 L
s
.4582 .48564 m .46452 .47772 L .46833 .47349 L 0 0 0 r
F
0 g
.46452 .47772 m
.46852 .47224 L
s
.29031 .93566 m .28707 .94176 L .29096 .94082 L 0 1 .534 r
F
.29024 .93768 m .28707 .94176 L .29096 .94082 L 0 1 .508 r
F
.29031 .93566 m .28042 .93784 L .28707 .94176 L 0 1 .534 r
F
.29024 .93768 m .28035 .93982 L .28707 .94176 L 0 1 .508 r
F
0 g
.28124 .94315 m
.28125 .94317 L
s
.28122 .94299 m
.28125 .94317 L
s
.29017 .93971 m .28707 .94176 L .29096 .94082 L 0 .787 .25 r
F
0 g
.29096 .94082 m
.29101 .94082 L
s
.29096 .94082 m
.29112 .94085 L
s
.29096 .94082 m
.29127 .94097 L
s
.29017 .93971 m .28027 .9418 L .28707 .94176 L 0 .787 .25 r
F
0 g
.28707 .94176 m
.2886 .94683 L
s
.28682 .94176 m
.28707 .94176 L
s
.28122 .94298 m
.28122 .94299 L
s
.28074 .93993 m
.28101 .94164 L
s
.28103 .9418 m
.28122 .94298 L
s
.28119 .94294 m
.28124 .94315 L
s
.28088 .9418 m
.28119 .94294 L
s
.4988 .88448 m .50009 .88318 L .50075 .88283 L 0 0 0 r
F
0 g
.49679 .88547 m
.50009 .88318 L
s
.50009 .88318 m
.50025 .88304 L
s
.38652 .72719 m .37854 .73137 L .38299 .73056 L 0 1 .513 r
F
0 g
.38299 .73056 m
.38654 .73277 L
s
.27815 .67818 m .26914 .68551 L .27368 .68526 L 0 1 .476 r
F
0 g
.27368 .68526 m
.27679 .69201 L
s
.32808 .65538 m .31926 .66159 L .32345 .66144 L 0 1 .464 r
F
0 g
.32345 .66144 m
.32568 .66742 L
s
.49504 .52251 m .4897 .52708 L .49049 .52943 L 0 1 .158 r
F
0 g
.49504 .52251 m
.49504 .52251 L
s
.49504 .52251 m .49342 .51709 L .4897 .52708 L 0 1 .158 r
F
.49504 .52251 m .49915 .50616 L .49342 .51709 L F
.45999 1.05077 m .45246 1.04604 L .44576 1.04354 L 0 .937 .488 r
F
0 g
.61591 .58798 m
.61848 .59982 L
s
.61591 .58798 m
.61591 .58798 L
s
.61573 .58718 m
.61591 .58798 L
s
.61848 .59982 m
.6191 .60264 L
s
.6191 .60264 m
.62015 .60748 L
s
.61573 .58718 m
.61575 .6042 L
s
.49522 .72033 m
.49628 .71787 L
s
.44139 1.03854 m .43414 1.03327 L .42735 1.03033 L 0 .956 .489 r
F
.72481 .91747 m .73569 .91779 L .73166 .91656 L 0 1 .509 r
F
.7149 .91398 m .72481 .91747 L .72561 .91468 L 0 1 .499 r
F
.71344 1.07275 m .72562 1.07208 L .72248 1.07208 L 0 .734 .252 r
F
.70583 1.07261 m .71344 1.07275 L .71777 1.07214 L 0 .689 .241 r
F
.50292 .83801 m .50059 .83359 L .498 .83515 L 0 .472 .326 r
F
0 g
.49716 .82693 m
.498 .83515 L
s
.80432 .66764 m .81677 .67759 L .8158 .6705 L 0 1 .51 r
F
0 g
.81403 .68185 m
.81677 .67759 L
s
.81677 .67759 m
.82094 .68382 L
s
.77947 .60386 m .78793 .59717 L .79248 .59939 L 0 .123 .007 r
F
.77947 .60386 m .78237 .59908 L .78793 .59717 L F
0 g
.78584 .59343 m
.78793 .59717 L
s
.53107 .96616 m
.53429 .97096 L
s
.53429 .97096 m
.53476 .97167 L
s
.53476 .97167 m
.53533 .97251 L
s
.53533 .97251 m
.53584 .97328 L
s
.53107 .96616 m
.5348 .96835 L
s
.60657 .43399 m .62112 .43978 L .62356 .44483 L 0 .304 .059 r
F
0 g
.62112 .43978 m
.62443 .4399 L
s
.61385 .43514 m
.62112 .43978 L
s
.40395 .56812 m
.4055 .56905 L
s
.38417 .99769 m .37782 .99105 L .37093 .98695 L 0 1 .486 r
F
.39073 .99469 m .38417 .99769 L .39081 1.00174 L 0 1 .481 r
F
.39073 .99469 m .37782 .99105 L .38417 .99769 L F
0 g
.38417 .99769 m
.38703 1.0036 L
s
.4748 .97049 m .47701 .97392 L .47808 .9725 L 0 1 .519 r
F
.48865 .97291 m .47808 .9725 L .47701 .97392 L 0 1 .503 r
F
0 g
.47701 .97392 m
.48073 .97552 L
s
.47182 .97405 m
.47701 .97392 L
s
.4335 .75642 m .42148 .76156 L .42209 .76125 L 0 0 0 r
F
.4335 .75642 m .42448 .76045 L .42148 .76156 L F
.4335 .75642 m .4291 .75867 L .42448 .76045 L F
.4335 .75642 m .43297 .75694 L .4291 .75867 L F
0 g
.4335 .75642 m
.43473 .75573 L
s
.43049 .75753 m
.4335 .75642 L
s
.48487 .55883 m .49251 .53723 L .4917 .53378 L 0 1 .258 r
F
.48487 .55883 m .48959 .54795 L .49251 .53723 L F
0 g
.49251 .53723 m
.49672 .53081 L
s
.49087 .54327 m
.49251 .53723 L
s
.53203 .74811 m
.5321 .7485 L
s
.53201 .74727 m
.53219 .74783 L
s
.34765 .97225 m
.35531 .97653 L
s
.51616 .77561 m .51521 .77414 L .51471 .78382 L 0 .485 .294 r
F
0 g
.51518 .7737 m
.51521 .77414 L
s
.74646 .91381 m .74575 .92075 L .75224 .91926 L 0 1 .497 r
F
.74646 .91381 m .74173 .91958 L .74575 .92075 L F
0 g
.74457 .92395 m
.74575 .92075 L
s
.3338 .94155 m .32953 .94759 L .33402 .94626 L 0 1 .533 r
F
.3338 .94155 m .32235 .94469 L .32953 .94759 L F
0 g
.32953 .94759 m
.33058 .95222 L
s
.32235 .94469 m
.32953 .94759 L
s
.32235 .9447 m
.32344 .94941 L
s
.50087 .85509 m .49883 .8696 L .50178 .86913 L 0 .472 .337 r
F
0 g
.49883 .8696 m
.50077 .87739 L
s
.50702 .79288 m .50687 .81284 L .50756 .80271 L 0 .507 .308 r
F
.50702 .79288 m .50497 .8176 L .50687 .81284 L F
.50702 .79288 m .50311 .81381 L .50497 .8176 L F
0 g
.50702 .79288 m
.50858 .78583 L
s
.40526 .56594 m
.40871 .56353 L
s
.42205 .71173 m .41057 .7142 L .41353 .71584 L 0 1 .492 r
F
0 g
.4099 .71907 m
.41353 .71584 L
s
.42205 .71173 m .41125 .71097 L .41057 .7142 L 0 1 .492 r
F
.42205 .71173 m .41516 .70789 L .41125 .71097 L F
.42205 .71173 m .41971 .70704 L .41516 .70789 L F
.42205 .71173 m .42266 .70868 L .41971 .70704 L F
0 g
.42205 .71173 m
.42506 .7131 L
s
.41814 .71479 m
.42205 .71173 L
s
.45852 .74367 m
.45914 .74315 L
s
.45627 .74555 m
.45852 .74367 L
s
.73427 1.06964 m .72562 1.07208 L .73425 1.0707 L 0 .744 .239 r
F
.73427 1.06964 m .72248 1.07208 L .72562 1.07208 L F
0 g
.73031 1.07214 m
.73092 1.07192 L
s
.72103 1.07305 m
.72562 1.07208 L
s
.69819 1.07263 m .68999 1.07262 L .68598 1.07286 L 0 .63 .226 r
F
0 g
.67723 1.07243 m
.68598 1.07286 L
s
.33473 .78314 m .32502 .78052 L .3229 .78254 L 0 1 .437 r
F
.33473 .78314 m .32925 .78008 L .32502 .78052 L F
.33473 .78314 m .33342 .7812 L .32925 .78008 L F
.34516 .78137 m .33342 .7812 L .33473 .78314 L 0 1 .407 r
F
0 g
.33261 .78515 m
.33473 .78314 L
s
.33473 .78314 m
.33882 .78398 L
s
.69819 1.07263 m .69729 1.07308 L .70583 1.07261 L 0 .63 .226 r
F
0 g
.6888 1.07318 m
.69729 1.07308 L
s
.69333 1.07364 m
.69729 1.07308 L
s
.81551 .83217 m .8236 .84244 L .82651 .8312 L 0 1 .488 r
F
0 g
.8182 .85104 m
.8236 .84244 L
s
.50497 .8176 m .50086 .81677 L .49971 .82449 L 0 .483 .316 r
F
.50497 .8176 m .50311 .81381 L .50086 .81677 L F
0 g
.50036 .80807 m
.50086 .81677 L
s
.50086 .81677 m
.50311 .81381 L
s
.50258 .80397 m
.50311 .81381 L
s
.54825 1.07634 m .55007 1.0715 L .55142 1.07232 L 0 0 0 r
F
.54825 1.07634 m .54751 1.07267 L .55007 1.0715 L F
0 g
.55007 1.0715 m
.55253 1.06456 L
s
.35388 .63565 m .34487 .64134 L .34895 .6412 L 0 1 .458 r
F
0 g
.34895 .6412 m
.35066 .64677 L
s
.38652 .72719 m .37541 .72904 L .37854 .73137 L 0 1 .513 r
F
0 g
.37544 .73496 m
.37854 .73137 L
s
.5184 1.07532 m .51036 1.07694 L .51868 1.07829 L 0 1 .488 r
F
.5184 1.07532 m .50426 1.07486 L .51036 1.07694 L F
0 g
.50398 1.07725 m
.51036 1.07694 L
s
.51631 .93281 m .52034 .944 L .52008 .9402 L 0 .343 .351 r
F
0 g
.51662 .94221 m
.52034 .944 L
s
.52034 .944 m
.52444 .95151 L
s
.66535 .5719 m .67469 .57765 L .6685 .55557 L 0 .548 .287 r
F
0 g
.6685 .55557 m
.66993 .56068 L
s
.6674 .54076 m
.6685 .55557 L
s
.45919 .90784 m .45003 .91168 L .44763 .91304 L 0 .875 .22 r
F
.45919 .90784 m .45499 .90945 L .45003 .91168 L F
.46447 .90482 m .45919 .90784 L .46382 .90572 L 0 .788 .188 r
F
.46447 .90482 m .45499 .90945 L .45919 .90784 L F
0 g
.45919 .90784 m
.46084 .90775 L
s
.50706 .88285 m .50241 .89049 L .50619 .89609 L 0 .398 .338 r
F
0 g
.5003 .88321 m
.50241 .89049 L
s
.49908 .88964 m
.50241 .89049 L
s
.36318 .94782 m .36135 .95299 L .3645 .95185 L 0 1 .534 r
F
.36318 .94782 m .35508 .95054 L .36135 .95299 L F
0 g
.36135 .95299 m
.36336 .95688 L
s
.50497 .8176 m .49971 .82449 L .50059 .83359 L 0 .483 .316 r
F
0 g
.49716 .82693 m
.49971 .82449 L
s
.49342 .51709 m .5032 .49723 L .50287 .49621 L 0 1 .155 r
F
.49342 .51709 m .49915 .50616 L .5032 .49723 L F
0 g
.5032 .49723 m
.50775 .48906 L
s
.49915 .50616 m
.50368 .4993 L
s
.49915 .50616 m
.5032 .49723 L
s
.34668 .96557 m .32933 .95466 L .33031 .96135 L 0 1 .482 r
F
.49158 .72203 m .48361 .73146 L .48802 .72588 L 0 0 .058 r
F
.49158 .72203 m .48068 .73619 L .48361 .73146 L F
.49158 .72203 m .48119 .73689 L .48068 .73619 L F
.49158 .72203 m .48477 .73303 L .48119 .73689 L F
0 g
.47873 .73136 m
.4818 .72849 L
s
.49158 .72203 m .48901 .72718 L .48477 .73303 L 0 0 .058 r
F
.49158 .72203 m .49192 .72247 L .48901 .72718 L F
0 g
.49158 .72203 m
.49283 .71965 L
s
.4892 .72415 m
.49113 .72132 L
s
.48802 .72588 m
.4892 .72415 L
s
.48802 .72588 m
.48937 .72442 L
s
.48937 .72442 m
.49158 .72203 L
s
.49192 .72247 m
.49482 .71796 L
s
.27047 .94199 m .25393 .93654 L .25504 .94012 L 0 1 .52 r
F
.27047 .94199 m .25803 .93585 L .25393 .93654 L F
.27047 .94199 m .26513 .93819 L .25803 .93585 L F
.28035 .93982 m .26513 .93819 L .27047 .94199 L 0 1 .515 r
F
0 g
.27047 .94199 m
.27415 .94312 L
s
.27047 .94199 m
.27102 .9438 L
s
.28122 .94313 m
.28123 .94314 L
s
.28674 .94176 m
.28682 .94176 L
s
.28946 .6777 m .27956 .66897 L .27815 .67818 L 0 1 .472 r
F
.28946 .6777 m .28399 .66205 L .27956 .66897 L F
.28946 .6777 m .28848 .66205 L .28399 .66205 L F
.28946 .6777 m .29083 .66877 L .28848 .66205 L F
0 g
.28504 .68459 m
.28946 .6777 L
s
.46447 .90482 m .46382 .90572 L .46581 .90449 L 0 .788 .188 r
F
.47425 .9 m .46581 .90449 L .46382 .90572 L 0 .84 .194 r
F
0 g
.46382 .90572 m
.46563 .90514 L
s
.45919 .90784 m
.46382 .90572 L
s
.27815 .67818 m .26682 .67859 L .26914 .68551 L 0 1 .476 r
F
0 g
.26543 .69282 m
.26914 .68551 L
s
.71481 .91132 m .72528 .90494 L .72132 .90593 L 0 1 .48 r
F
.72506 .89411 m .72528 .90494 L .73126 .89856 L 0 1 .478 r
F
.72506 .89411 m .72132 .90593 L .72528 .90494 L F
0 g
.72453 .90912 m
.72528 .90494 L
s
.54825 1.07634 m .54511 1.07441 L .54751 1.07267 L 0 0 0 r
F
0 g
.54659 1.07334 m
.54751 1.07267 L
s
.54608 1.07325 m
.54751 1.07267 L
s
.4988 .88448 m .4911 .88983 L .49306 .88817 L 0 0 0 r
F
0 g
.48942 .89088 m
.49306 .88817 L
s
.50489 .664 m .50328 .62022 L .50171 .63893 L 0 1 .278 r
F
.40652 .92464 m .40474 .92687 L .40761 .92559 L 0 1 .301 r
F
.40652 .92464 m .3991 .92767 L .40474 .92687 L F
0 g
.40474 .92687 m
.4064 .9277 L
s
.36874 .98082 m .35311 .97039 L .35531 .97653 L 0 1 .482 r
F
.50292 .83801 m .49809 .85019 L .50087 .85509 L 0 .472 .326 r
F
0 g
.49685 .84164 m
.49809 .85019 L
s
.49514 .85067 m
.49809 .85019 L
s
.44887 .91158 m .44763 .91304 L .45003 .91168 L 0 .828 .216 r
F
.44887 .91158 m .44258 .91489 L .44763 .91304 L F
0 g
.44763 .91304 m
.4493 .91294 L
s
.53828 .75099 m
.53899 .75363 L
s
.53739 .74774 m
.53828 .75099 L
s
.53642 .74414 m
.53739 .74774 L
s
.43511 .70172 m .42652 .70563 L .43106 .70462 L 0 1 .48 r
F
.43511 .70172 m .42386 .70412 L .42652 .70563 L F
0 g
.43106 .70462 m
.43406 .706 L
s
.43511 .70172 m .42485 .7011 L .42386 .70412 L 0 1 .48 r
F
.43511 .70172 m .42891 .69819 L .42485 .7011 L F
.43511 .70172 m .43333 .69735 L .42891 .69819 L F
.43511 .70172 m .43599 .69886 L .43333 .69735 L F
0 g
.43511 .70172 m
.43786 .70299 L
s
.43106 .70462 m
.43511 .70172 L
s
.80452 .83344 m .80187 .84431 L .80312 .85216 L 0 1 .484 r
F
0 g
.79697 .8599 m
.80312 .85216 L
s
.47915 1.06144 m .47142 1.05738 L .46487 1.0554 L 0 .937 .486 r
F
.78632 .86103 m .79666 .85284 L .79235 .85336 L 0 1 .494 r
F
.77567 .86256 m .78632 .86103 L .78588 .85426 L 0 1 .491 r
F
.32808 .65538 m .31768 .65559 L .31926 .66159 L 0 1 .464 r
F
0 g
.31517 .66798 m
.31926 .66159 L
s
.39073 .99469 m .39081 1.00174 L .39334 1.00051 L 0 1 .481 r
F
.40659 1.01036 m .39334 1.00051 L .39081 1.00174 L 0 1 .485 r
F
0 g
.39081 1.00174 m
.39405 1.00733 L
s
.38417 .99769 m
.39081 1.00174 L
s
.34516 .78137 m .3356 .77938 L .33342 .7812 L 0 1 .407 r
F
.34516 .78137 m .33984 .77889 L .3356 .77938 L F
.34516 .78137 m .34394 .77974 L .33984 .77889 L F
.3556 .77945 m .34394 .77974 L .34516 .78137 L 0 1 .37 r
F
0 g
.34297 .78318 m
.34516 .78137 L
s
.34516 .78137 m
.34919 .78194 L
s
.35388 .63565 m .34378 .6359 L .34487 .64134 L 0 1 .458 r
F
.35388 .63565 m .34642 .62851 L .34378 .6359 L F
.35388 .63565 m .35136 .62293 L .34642 .62851 L F
.35388 .63565 m .3553 .62291 L .35136 .62293 L F
.35388 .63565 m .35638 .62837 L .3553 .62291 L F
0 g
.35388 .63565 m
.35507 .64091 L
s
.34895 .6412 m
.35388 .63565 L
s
.34038 .64725 m
.34487 .64134 L
s
.8087 .60508 m .81523 .60865 L .81068 .60702 L 0 0 0 r
F
.8087 .60508 m .82013 .60977 L .81523 .60865 L F
0 g
.50985 .87557 m
.51187 .87322 L
s
.51693 .97464 m .51125 .9746 L .50684 .97539 L 0 1 .413 r
F
0 g
.52138 .97524 m
.52222 .97508 L
s
.52222 .97508 m
.523 .97494 L
s
.523 .97494 m
.52306 .97493 L
s
.52306 .97493 m
.52544 .9745 L
s
.66535 .5719 m .67924 .60346 L .67469 .57765 L 0 .548 .287 r
F
0 g
.66493 .5566 m
.66535 .5719 L
s
.66518 .57117 m
.66535 .5719 L
s
.63586 .51921 m
.63609 .5205 L
s
.63609 .5205 m
.63673 .52417 L
s
.63673 .52417 m
.63756 .52898 L
s
.63756 .52898 m
.63778 .53024 L
s
.63778 .53024 m
.63779 .53027 L
s
.64232 .55629 m
.64272 .55863 L
s
.64169 .55268 m
.64232 .55629 L
s
.64165 .55245 m
.64169 .55268 L
s
.6414 .55102 m
.64165 .55245 L
s
.64001 .54302 m
.64001 .54306 L
s
.64022 .54424 m
.6414 .55102 L
s
.6339 .51514 m
.63405 .51544 L
s
.63405 .51544 m
.63417 .51571 L
s
.63479 .51699 m
.63513 .5177 L
s
.63444 .51626 m
.63479 .51699 L
s
.63417 .51571 m
.63435 .51608 L
s
.63435 .51608 m
.63444 .51626 L
s
.63535 .51814 m
.6357 .51887 L
s
.6357 .51887 m
.63572 .51891 L
s
.63513 .5177 m
.63535 .51814 L
s
.63572 .51891 m
.63586 .51921 L
s
.53809 1.07648 m .53939 1.07528 L .54511 1.07441 L 0 1 .426 r
F
.53584 1.07683 m .53112 1.07758 L .53546 1.07637 L F
.53584 1.07683 m .52474 1.07849 L .53112 1.07758 L F
.53809 1.07648 m .53584 1.07683 L .53939 1.07528 L F
.53809 1.07648 m .5353 1.0769 L .53584 1.07683 L F
.5353 1.0769 m .52474 1.07849 L .53584 1.07683 L F
.53584 1.07683 m .53546 1.07637 L .53939 1.07528 L F
.53809 1.07648 m .52451 1.07741 L .52474 1.07849 L F
.53809 1.07648 m .53022 1.07655 L .52451 1.07741 L F
.53338 1.07714 m .52415 1.07621 L .53022 1.07655 L 0 .603 .247 r
F
.53655 1.07772 m .53256 1.07724 L .53338 1.07714 L F
.53256 1.07724 m .52415 1.07621 L .53338 1.07714 L F
.53678 1.07777 m .53656 1.07774 L .53655 1.07772 L F
.53394 1.07742 m .52415 1.07621 L .53398 1.07741 L F
.53656 1.07774 m .53394 1.07742 L .53655 1.07772 L F
.53394 1.07742 m .53398 1.07741 L .53655 1.07772 L F
.53678 1.07777 m .52392 1.07569 L .52415 1.07621 L F
.53678 1.07777 m .52932 1.07635 L .52392 1.07569 L F
.53238 1.0777 m .52356 1.07514 L .52932 1.07635 L 0 .394 .202 r
F
.53546 1.07907 m .5317 1.07782 L .53238 1.0777 L F
.5317 1.07782 m .52356 1.07514 L .53238 1.0777 L F
0 g
.53939 1.07528 m
.54607 1.07326 L
s
.5251 1.08077 m
.5268 1.07987 L
s
.5268 1.07987 m
.52884 1.07878 L
s
.52884 1.07878 m
.53106 1.07761 L
s
.44258 .91489 m .43295 .91781 L .43028 .91913 L 0 .888 .241 r
F
.44258 .91489 m .43823 .91599 L .43295 .91781 L F
0 g
.44258 .91489 m
.44412 .91517 L
s
.44887 .91158 m .43823 .91599 L .44258 .91489 L 0 .828 .216 r
F
0 g
.44258 .91489 m
.44763 .91304 L
s
.55874 .80772 m
.55885 .80742 L
s
.55805 .80957 m
.55871 .8078 L
s
.55871 .8078 m
.55874 .80772 L
s
.60657 .43399 m .60463 .44024 L .60261 .43617 L 0 .304 .059 r
F
.60657 .43399 m .61193 .44491 L .60463 .44024 L F
.60657 .43399 m .61963 .44703 L .61193 .44491 L F
.60657 .43399 m .62356 .44483 L .61963 .44703 L F
0 g
.59959 .42936 m
.60657 .43399 L
s
.42353 1.02501 m .41663 1.01928 L .40982 1.01595 L 0 .981 .488 r
F
.35508 .95054 m .33995 .94452 L .34151 .94872 L 0 1 .535 r
F
.37541 .72904 m .36742 .73321 L .37187 .7325 L 0 1 .518 r
F
0 g
.37187 .7325 m
.37544 .73496 L
s
.42209 .76125 m .40999 .7655 L .41069 .76542 L 0 0 0 r
F
.42209 .76125 m .41293 .76443 L .40999 .7655 L F
.42209 .76125 m .41755 .76292 L .41293 .76443 L F
.42209 .76125 m .42148 .76156 L .41755 .76292 L F
0 g
.42209 .76125 m
.42359 .76058 L
s
.5184 1.07532 m .51868 1.07829 L .52474 1.07849 L 0 1 .488 r
F
0 g
.52078 1.0791 m
.5251 1.08077 L
s
.51868 1.07829 m
.52078 1.0791 L
s
.5162 .77604 m
.51627 .77678 L
s
.51627 .77678 m
.51656 .77968 L
s
.51656 .77968 m
.51677 .78177 L
s
.51616 .77561 m .51471 .78382 L .51498 .79822 L 0 .485 .294 r
F
0 g
.51616 .77561 m
.5162 .77604 L
s
.51616 .77561 m
.51626 .76721 L
s
.51384 .77237 m
.51471 .78382 L
s
.51471 .78382 m
.51521 .77414 L
s
.32808 .65538 m .31978 .64742 L .31768 .65559 L 0 1 .464 r
F
.32808 .65538 m .32443 .64135 L .31978 .64742 L F
.32808 .65538 m .32852 .64143 L .32443 .64135 L F
.32808 .65538 m .33008 .64745 L .32852 .64143 L F
0 g
.32808 .65538 m
.32973 .66115 L
s
.32345 .66144 m
.32808 .65538 L
s
.4573 .9706 m .45164 .96889 L .44602 .9687 L 0 1 .533 r
F
0 g
.4573 .9706 m
.46047 .97301 L
s
.46134 .96701 m .4573 .9706 L .46266 .9708 L 0 1 .527 r
F
.46134 .96701 m .45164 .96889 L .4573 .9706 L F
.53471 .72977 m .53945 .708 L .54169 .65904 L 0 .78 .249 r
F
0 g
.54169 .65904 m
.54171 .65154 L
s
.54169 .65904 m
.54487 .63158 L
s
.23926 .93999 m
.24497 .94208 L
s
.29095 .9408 m
.29096 .94082 L
s
.52147 .78121 m
.52152 .78218 L
s
.5212 .77559 m
.52147 .78121 L
s
.52151 .77294 m
.52159 .77358 L
s
.52159 .77358 m
.52258 .7812 L
s
.56332 .66528 m
.56732 .67562 L
s
.56327 .66516 m
.56332 .66528 L
s
.74553 .8886 m .75598 .88125 L .75183 .88207 L 0 1 .495 r
F
.7353 .89102 m .74553 .8886 L .7456 .88349 L 0 1 .487 r
F
.74612 .58843 m .75197 .59878 L .74757 .59684 L 0 .298 .073 r
F
.74612 .58843 m .75724 .59454 L .75197 .59878 L F
.37032 .61725 m .36121 .62276 L .36514 .62258 L 0 1 .451 r
F
.37032 .61725 m .36062 .61775 L .36121 .62276 L F
0 g
.36514 .62258 m
.36633 .62785 L
s
.37032 .61725 m .36379 .61088 L .36062 .61775 L 0 1 .451 r
F
.37032 .61725 m .36898 .60554 L .36379 .61088 L F
.37032 .61725 m .37273 .60529 L .36898 .60554 L F
.37032 .61725 m .3733 .61031 L .37273 .60529 L F
0 g
.37032 .61725 m
.37104 .6222 L
s
.36514 .62258 m
.37032 .61725 L
s
.34268 .9341 m .34015 .9373 L .34357 .93626 L 0 1 .46 r
F
0 g
.34357 .93626 m
.35011 .9366 L
s
.34268 .9341 m .33394 .93652 L .34015 .9373 L 0 1 .46 r
F
0 g
.34015 .9373 m
.34176 .93938 L
s
.38392 .95473 m .36924 .95017 L .37102 .95391 L 0 1 .536 r
F
0 g
.3645 .95185 m
.37102 .95391 L
s
.53597 .97314 m
.53664 .97238 L
s
.53584 .97328 m
.53597 .97314 L
s
.47425 .9 m .47029 .90203 L .46581 .90449 L 0 .84 .194 r
F
.47849 .89763 m .47425 .9 L .47839 .89777 L 0 0 0 r
F
.47849 .89763 m .47029 .90203 L .47425 .9 L F
0 g
.47425 .9 m
.47604 .89943 L
s
.3556 .77945 m .34619 .7781 L .34394 .77974 L 0 1 .37 r
F
.3556 .77945 m .35043 .77755 L .34619 .7781 L F
.3556 .77945 m .35446 .77813 L .35043 .77755 L F
.36605 .77736 m .35446 .77813 L .3556 .77945 L 0 1 .326 r
F
0 g
.35334 .78109 m
.3556 .77945 L
s
.3556 .77945 m
.35957 .77975 L
s
.79284 .66439 m .80016 .66167 L .79557 .66047 L 0 1 .503 r
F
0 g
.7952 .66101 m
.79557 .66047 L
s
.79284 .66439 m .80432 .66764 L .80016 .66167 L 0 1 .503 r
F
0 g
.79284 .66439 m
.7952 .66101 L
s
.79027 .66077 m
.79284 .66439 L
s
.78924 .65932 m
.79027 .66077 L
s
.78869 .65855 m
.78924 .65932 L
s
.74646 .91381 m .74203 .91661 L .74173 .91958 L 0 1 .497 r
F
0 g
.7347 .92079 m
.74173 .91958 L
s
.50999 .60203 m .51598 .59495 L .51614 .59643 L 0 0 0 r
F
0 g
.51598 .59495 m
.51837 .58976 L
s
.51335 .59734 m
.51598 .59495 L
s
.40761 .92559 m
.41333 .92436 L
s
.42499 .92054 m .41202 .9237 L .41334 .92436 L 0 .976 .259 r
F
0 g
.41334 .92436 m
.41334 .92436 L
s
.52726 1.07813 m
.531 1.07759 L
s
.42137 .54041 m .42636 .53278 L .42824 .52817 L 0 1 .243 r
F
0 g
.41985 .54518 m
.42137 .54041 L
s
.44602 .9687 m
.45164 .96889 L
s
.48883 .45423 m .50093 .44476 L .5006 .4482 L 0 0 .035 r
F
0 g
.50093 .44476 m
.50648 .43739 L
s
.49589 .44734 m
.50093 .44476 L
s
.45123 .68551 m .44283 .68896 L .44708 .68815 L 0 1 .459 r
F
.45123 .68551 m .44079 .68741 L .44283 .68896 L F
0 g
.44708 .68815 m
.44948 .68957 L
s
.45123 .68551 m .44231 .68454 L .44079 .68741 L 0 1 .459 r
F
.45123 .68551 m .44647 .6819 L .44231 .68454 L F
.45123 .68551 m .4505 .68123 L .44647 .6819 L F
.45123 .68551 m .45254 .68278 L .4505 .68123 L F
0 g
.45123 .68551 m
.45343 .68689 L
s
.44708 .68815 m
.45123 .68551 L
s
.45254 .68278 m
.45653 .68022 L
s
.39073 .99469 m .37521 .98523 L .37782 .99105 L 0 1 .481 r
F
0 g
.37093 .98695 m
.37782 .99105 L
s
.27039 .94393 m .25366 .94295 L .25486 .94457 L 0 .939 .294 r
F
.27039 .94393 m .25777 .94231 L .25366 .94295 L F
.27039 .94393 m .26496 .94273 L .25777 .94231 L F
.28027 .9418 m .26496 .94273 L .27039 .94393 L 0 .839 .261 r
F
0 g
.27039 .94393 m
.27703 .94411 L
s
.27039 .94393 m
.27152 .9455 L
s
.70204 .6169 m
.70332 .61888 L
s
.70077 .61686 m
.70204 .6169 L
s
.26682 .67859 m .25777 .68609 L .26232 .68586 L 0 1 .479 r
F
0 g
.26232 .68586 m
.26543 .69282 L
s
.23741 .92723 m .2337 .93392 L .23779 .93316 L 0 1 .534 r
F
0 g
.23779 .93316 m
.23916 .934 L
s
.23741 .92723 m .22704 .92897 L .2337 .93392 L 0 1 .534 r
F
0 g
.2337 .93392 m
.2351 .93978 L
s
.39618 .58179 m .38712 .58802 L .39064 .58741 L 0 1 .4 r
F
.39618 .58179 m .38758 .58357 L .38712 .58802 L F
0 g
.39064 .58741 m
.39076 .5921 L
s
.39618 .58179 m .39172 .57703 L .38758 .58357 L 0 1 .4 r
F
.39618 .58179 m .39727 .57141 L .39172 .57703 L F
.39618 .58179 m .40052 .57046 L .39727 .57141 L F
.39618 .58179 m .40005 .57492 L .40052 .57046 L F
0 g
.40005 .57492 m
.4055 .56905 L
s
.39064 .58741 m
.39618 .58179 L
s
.75435 .86709 m .75598 .88125 L .76162 .87375 L 0 1 .481 r
F
.75435 .86709 m .75183 .88207 L .75598 .88125 L F
0 g
.75576 .88676 m
.75598 .88125 L
s
.54116 .57649 m .54526 .5708 L .54956 .57159 L 0 .215 .104 r
F
0 g
.54526 .5708 m
.5471 .56221 L
s
.51582 .70579 m
.51585 .70485 L
s
.37541 .72904 m .36429 .73062 L .36742 .73321 L 0 1 .518 r
F
0 g
.36435 .7369 m
.36742 .73321 L
s
.49617 .64013 m .499 .63229 L .50053 .61663 L 0 1 .285 r
F
0 g
.50053 .61663 m
.50328 .62022 L
s
.38652 .72719 m .37568 .72513 L .37541 .72904 L 0 1 .513 r
F
.38652 .72719 m .37921 .72174 L .37568 .72513 L F
.38652 .72719 m .38365 .72116 L .37921 .72174 L F
.38652 .72719 m .38678 .72349 L .38365 .72116 L F
0 g
.38299 .73056 m
.38652 .72719 L
s
.3991 .92767 m .38541 .92926 L .38675 .93043 L 0 1 .353 r
F
.67413 .93429 m .67777 .93552 L .68269 .93108 L 0 1 .331 r
F
0 g
.67416 .93792 m
.67777 .93552 L
s
.67652 .93828 m
.67777 .93552 L
s
.516 .92226 m .51631 .93281 L .51968 .93415 L 0 .329 .341 r
F
0 g
.51631 .93281 m
.52008 .9402 L
s
.3797 .92952 m .37748 .93216 L .38065 .93099 L 0 1 .384 r
F
0 g
.38065 .93099 m
.38675 .93043 L
s
.3797 .92952 m .37158 .93228 L .37748 .93216 L 0 1 .384 r
F
0 g
.37748 .93216 m
.37907 .93354 L
s
.75724 .59454 m .7711 .59355 L .76835 .59962 L 0 .25 .055 r
F
0 g
.7711 .59355 m
.77656 .59097 L
s
.76974 .58674 m
.7711 .59355 L
s
.50274 .97426 m .49708 .97385 L .49236 .97451 L 0 1 .473 r
F
.35508 .95054 m .34337 .94353 L .33995 .94452 L 0 1 .535 r
F
0 g
.33402 .94626 m
.33766 .94745 L
s
.33766 .94745 m
.34151 .94872 L
s
.35508 .95054 m .34986 .94612 L .34337 .94353 L 0 1 .535 r
F
.36318 .94782 m .34986 .94612 L .35508 .95054 L 0 1 .534 r
F
0 g
.35508 .95054 m
.36135 .95299 L
s
.35508 .95054 m
.35662 .95472 L
s
.41069 .76542 m .3985 .76887 L .39929 .76905 L 0 .75 .205 r
F
.41069 .76542 m .40138 .76778 L .3985 .76887 L F
.41069 .76542 m .406 .76651 L .40138 .76778 L F
.41069 .76542 m .40999 .7655 L .406 .76651 L F
0 g
.41069 .76542 m
.41245 .76481 L
s
.40781 .76651 m
.41069 .76542 L
s
.36605 .77736 m .35679 .77665 L .35446 .77813 L 0 1 .326 r
F
.36605 .77736 m .36102 .77602 L .35679 .77665 L F
.36605 .77736 m .365 .77632 L .36102 .77602 L F
0 g
.36372 .77882 m
.36605 .77736 L
s
.37697 .77493 m .365 .77632 L .36605 .77735 L 0 .947 .275 r
F
0 g
.36605 .77735 m
.3701 .77734 L
s
.43599 .69886 m
.43995 .69599 L
s
.4962 .72154 m
.49738 .71841 L
s
.4697 .73736 m
.47047 .73685 L
s
.46845 .73821 m
.4697 .73736 L
s
.46796 .73854 m
.46845 .73821 L
s
.46706 .73915 m
.46796 .73854 L
s
.46939 .73798 m
.47047 .73685 L
s
.46892 .73848 m
.46939 .73798 L
s
.77723 .65495 m
.77863 .65301 L
s
.22668 .93692 m .22321 .94186 L .22729 .94114 L 0 1 .528 r
F
0 g
.22729 .94114 m
.23491 .94406 L
s
.22668 .93692 m .21631 .93852 L .22321 .94186 L 0 1 .528 r
F
0 g
.22321 .94186 m
.22487 .94605 L
s
.5384 .97392 m .53665 .97402 L .53585 .97437 L 0 .73 .242 r
F
.4582 .48564 m .46833 .47349 L .46709 .47578 L 0 0 0 r
F
0 g
.46833 .47349 m
.47414 .46587 L
s
.46452 .47772 m
.46833 .47349 L
s
.47849 .89763 m .47839 .89777 L .47995 .89682 L 0 0 0 r
F
.48752 .89196 m .47995 .89682 L .47839 .89777 L F
0 g
.47839 .89777 m
.48029 .89667 L
s
.47425 .9 m
.47839 .89777 L
s
.41101 .95679 m .41034 .96138 L .41289 .96006 L 0 1 .536 r
F
.41101 .95679 m .40441 .95999 L .41034 .96138 L F
.42432 .9637 m .41289 .96006 L .41034 .96138 L 0 1 .537 r
F
0 g
.41034 .96138 m
.41279 .96445 L
s
.50497 .8176 m .50059 .83359 L .50292 .83801 L 0 .483 .316 r
F
0 g
.498 .83515 m
.50059 .83359 L
s
.49971 .82449 m
.50059 .83359 L
s
.50999 .60203 m .50687 .60753 L .50721 .6064 L 0 0 0 r
F
.50999 .60203 m .50952 .60513 L .50687 .60753 L F
0 g
.50588 .60756 m
.50771 .60538 L
s
.50999 .60203 m .51337 .6008 L .50952 .60513 L 0 0 0 r
F
.50999 .60203 m .51614 .59643 L .51337 .6008 L F
0 g
.50771 .60538 m
.50999 .60203 L
s
.32234 .94469 m .30655 .93714 L .30767 .94189 L 0 1 .534 r
F
0 g
.30075 .9385 m
.30078 .9385 L
s
.32234 .94469 m .31045 .93624 L .30655 .93714 L 0 1 .534 r
F
0 g
.30078 .9385 m
.30672 .93788 L
s
.30086 .93854 m
.30716 .93972 L
s
.32234 .94469 m .31723 .93948 L .31045 .93624 L 0 1 .534 r
F
0 g
.32234 .94469 m
.32235 .9447 L
s
.3338 .94155 m .31723 .93948 L .32235 .94469 L 0 1 .533 r
F
0 g
.32235 .94469 m
.32235 .94469 L
s
.44522 1.03523 m .43414 1.03327 L .44139 1.03854 L 0 .91 .483 r
F
.44522 1.03523 m .43006 1.02834 L .43414 1.03327 L F
0 g
.42735 1.03033 m
.43414 1.03327 L
s
.44522 1.03523 m .44139 1.03854 L .44788 1.04149 L 0 .91 .483 r
F
0 g
.44139 1.03854 m
.44576 1.04354 L
s
.24947 .93215 m
.25522 .93567 L
s
.54358 .447 m .55723 .4361 L .55832 .4389 L 0 0 .055 r
F
.54358 .447 m .55092 .43956 L .55723 .4361 L F
0 g
.55092 .43956 m
.55249 .4369 L
s
.55723 .4361 m
.5579 .43506 L
s
.55092 .43956 m
.55723 .4361 L
s
.37697 .77493 m .36753 .77497 L .365 .77632 L 0 .947 .275 r
F
.37697 .77493 m .37196 .77421 L .36753 .77497 L F
.37697 .77493 m .37601 .77419 L .37196 .77421 L F
.3879 .77223 m .37601 .77419 L .37697 .77493 L 0 .833 .248 r
F
0 g
.37444 .77628 m
.37697 .77493 L
s
.37697 .77493 m
.38095 .77461 L
s
.51738 .77743 m .51709 .77702 L .51743 .78829 L 0 .474 .291 r
F
0 g
.51715 .77925 m
.51743 .78829 L
s
.51709 .77728 m
.51715 .77925 L
s
.51709 .77702 m
.51709 .77728 L
s
.51742 .78828 m
.51743 .78829 L
s
.51709 .78493 m
.51742 .78828 L
s
.51721 .77239 m
.51737 .77722 L
s
.51737 .77722 m
.51738 .77743 L
s
.51708 .77693 m
.51709 .77702 L
s
.72506 .89411 m .73126 .89856 L .7353 .89102 L 0 1 .478 r
F
0 g
.72528 .90494 m
.73126 .89856 L
s
.73121 .90365 m
.73126 .89856 L
s
.521 .7037 m
.52107 .70393 L
s
.49868 1.06999 m .50426 1.07486 L .50444 1.07342 L 0 .985 .485 r
F
.5184 1.07532 m .50444 1.07342 L .50426 1.07486 L 0 1 .488 r
F
0 g
.50426 1.07486 m
.51036 1.07694 L
s
.49792 1.07359 m
.50426 1.07486 L
s
.39929 .76905 m .38702 .77177 L .3879 .77223 L 0 .8 .23 r
F
.39929 .76905 m .38983 .77062 L .38702 .77177 L F
0 g
.3879 .77223 m
.39196 .77155 L
s
.39929 .76905 m .39445 .76954 L .38983 .77062 L 0 .8 .23 r
F
.39929 .76905 m .3985 .76887 L .39445 .76954 L F
0 g
.39648 .7702 m
.39929 .76905 L
s
.39929 .76905 m
.40328 .76804 L
s
.40441 .95999 m .39283 .95536 L .38997 .95658 L 0 1 .537 r
F
.40441 .95999 m .39903 .95682 L .39283 .95536 L F
.41101 .95679 m .39903 .95682 L .40441 .95999 L 0 1 .536 r
F
0 g
.40441 .95999 m
.41034 .96138 L
s
.40441 .95999 m
.40654 .96341 L
s
.42266 .70868 m
.42652 .70563 L
s
.45558 .74613 m .44759 .75004 L .45221 .74745 L 0 0 0 r
F
0 g
.45221 .74745 m
.45401 .74674 L
s
.45221 .74745 m
.45443 .74594 L
s
.79841 .92449 m .80991 .92232 L .80571 .92163 L 0 1 .529 r
F
.78806 .92248 m .79841 .92449 L .7994 .92057 L 0 1 .525 r
F
.3879 .77223 m .37861 .77297 L .37601 .77419 L 0 .833 .248 r
F
.3879 .77223 m .38304 .77209 L .37861 .77297 L F
.3879 .77223 m .38702 .77177 L .38304 .77209 L F
0 g
.3853 .77345 m
.3879 .77223 L
s
.26682 .67859 m .25549 .67895 L .25777 .68609 L 0 1 .479 r
F
0 g
.25406 .69358 m
.25777 .68609 L
s
.50619 .89609 m .50867 .90847 L .50887 .9038 L 0 .408 .349 r
F
.51569 .91022 m .50867 .90847 L .51172 .91637 L 0 .321 .332 r
F
.51569 .91022 m .50887 .9038 L .50867 .90847 L F
0 g
.50533 .9076 m
.50867 .90847 L
s
.42137 .54041 m .41267 .54843 L .41551 .54711 L 0 1 .243 r
F
0 g
.4178 .54751 m
.41985 .54518 L
s
.42137 .54041 m .41455 .54382 L .41267 .54843 L 0 1 .243 r
F
0 g
.41422 .55158 m
.4178 .54751 L
s
.42137 .54041 m .4199 .53636 L .41455 .54382 L 0 1 .243 r
F
.42137 .54041 m .42577 .52965 L .4199 .53636 L F
.42137 .54041 m .42824 .52817 L .42577 .52965 L F
0 g
.42824 .52817 m
.43412 .52109 L
s
.42636 .53278 m
.42824 .52817 L
s
.48773 .57107 m .48959 .54795 L .48487 .55883 L 0 1 .268 r
F
0 g
.48959 .54795 m
.49087 .54327 L
s
.48959 .54795 m
.49373 .54351 L
s
.36429 .73062 m .35662 .73475 L .36089 .73417 L 0 1 .522 r
F
0 g
.36089 .73417 m
.36434 .7369 L
s
.3991 .92767 m .38858 .92814 L .38541 .92926 L 0 1 .353 r
F
.3991 .92767 m .39446 .92746 L .38858 .92814 L F
.40652 .92464 m .39446 .92746 L .3991 .92767 L 0 1 .301 r
F
0 g
.3991 .92767 m
.40474 .92687 L
s
.3991 .92767 m
.40043 .92884 L
s
.59817 .60246 m
.59843 .58778 L
s
.59816 .60304 m
.59817 .60246 L
s
.75689 .9161 m .76244 .92181 L .7673 .9183 L 0 1 .507 r
F
0 g
.7558 .92359 m
.76244 .92181 L
s
.76181 .92525 m
.76244 .92181 L
s
.49206 .62752 m
.49221 .62718 L
s
.52485 .43416 m .53842 .43041 L .53905 .43553 L 0 .168 .082 r
F
0 g
.53842 .43041 m
.54346 .4244 L
s
.53234 .42983 m
.53842 .43041 L
s
.51055 .80012 m .50756 .80271 L .50687 .81284 L 0 .469 .304 r
F
.51055 .80012 m .50913 .79726 L .50756 .80271 L F
0 g
.50702 .79288 m
.50756 .80271 L
s
.50756 .80271 m
.50913 .79726 L
s
.50858 .78583 m
.50913 .79726 L
s
.49056 .58775 m .48549 .58413 L .48677 .59066 L 0 1 .277 r
F
.49056 .58775 m .48773 .57107 L .48549 .58413 L F
.49337 .61029 m .49056 .58775 L .48867 .6021 L 0 1 .283 r
F
.42833 1.02179 m .42353 1.02501 L .43006 1.02834 L 0 .942 .482 r
F
.42833 1.02179 m .41663 1.01928 L .42353 1.02501 L F
0 g
.42353 1.02501 m
.42735 1.03033 L
s
.4582 .48564 m .45052 .49485 L .4522 .49298 L 0 0 0 r
F
0 g
.45298 .49231 m
.45471 .49011 L
s
.4582 .48564 m .45433 .49063 L .45052 .49485 L 0 0 0 r
F
.4582 .48564 m .4611 .48312 L .45433 .49063 L F
.4582 .48564 m .46709 .47578 L .4611 .48312 L F
.31768 .65559 m .30878 .66187 L .31297 .66178 L 0 1 .469 r
F
0 g
.31297 .66178 m
.31517 .66798 L
s
.51738 .77743 m
.51739 .77756 L
s
.51739 .77756 m
.51753 .77943 L
s
.51753 .77943 m
.51827 .78958 L
s
.46282 1.04746 m .45246 1.04604 L .45999 1.05077 L 0 .881 .479 r
F
.46282 1.04746 m .44788 1.04149 L .45246 1.04604 L F
0 g
.44576 1.04354 m
.45246 1.04604 L
s
.79646 .78028 m .80615 .78721 L .80803 .78639 L 0 .341 .218 r
F
0 g
.80615 .78721 m
.80816 .78967 L
s
.80132 .78577 m
.80615 .78721 L
s
.5073 .48727 m .50208 .49444 L .50239 .49501 L 0 0 0 r
F
0 g
.50729 .48728 m
.5073 .48727 L
s
.5073 .48727 m .50686 .48658 L .50208 .49444 L 0 0 0 r
F
.5073 .48727 m .51353 .47671 L .50686 .48658 L F
0 g
.5073 .48728 m
.5073 .48727 L
s
.48883 .45423 m .48215 .46403 L .48294 .46138 L 0 0 .035 r
F
0 g
.48258 .45924 m
.48413 .45721 L
s
.48883 .45423 m .48721 .46145 L .48215 .46403 L 0 0 .035 r
F
.48883 .45423 m .49473 .45535 L .48721 .46145 L F
.48883 .45423 m .5006 .4482 L .49473 .45535 L F
0 g
.48413 .45721 m
.48883 .45423 L
s
.71701 .61043 m .72998 .58735 L .73086 .59948 L 0 .297 .105 r
F
0 g
.72004 .59431 m
.72559 .58448 L
s
.71823 .57898 m
.72004 .5943 L
s
.72004 .5943 m
.72004 .59431 L
s
.72998 .58735 m
.73501 .58104 L
s
.27815 .67818 m .26828 .6691 L .26682 .67859 L 0 1 .476 r
F
.27815 .67818 m .27275 .66199 L .26828 .6691 L F
.27815 .67818 m .27725 .66202 L .27275 .66199 L F
.27815 .67818 m .27956 .66897 L .27725 .66202 L F
0 g
.27368 .68526 m
.27815 .67818 L
s
.27815 .67818 m
.2805 .68487 L
s
.53634 .75078 m
.53789 .7609 L
s
.53627 .75034 m
.53634 .75078 L
s
.41057 .7142 m .402 .71818 L .40661 .71729 L 0 1 .502 r
F
0 g
.40661 .71729 m
.4099 .71907 L
s
.52485 .43416 m .5195 .44435 L .51934 .44038 L 0 .168 .082 r
F
.52485 .43416 m .5256 .44495 L .5195 .44435 L F
.52485 .43416 m .53356 .44176 L .5256 .44495 L F
.52485 .43416 m .53905 .43553 L .53356 .44176 L F
0 g
.51911 .43405 m
.52485 .43416 L
s
.53717 .4492 m
.54168 .44155 L
s
.53867 .97393 m
.53956 .97397 L
s
.46134 .96701 m .44881 .96654 L .45164 .96889 L 0 1 .527 r
F
.46134 .96701 m .46266 .9708 L .46415 .96935 L F
.4748 .97049 m .46415 .96935 L .46266 .9708 L 0 1 .519 r
F
0 g
.46266 .9708 m
.46595 .97281 L
s
.4573 .9706 m
.46266 .9708 L
s
.43193 .91737 m .43028 .91913 L .43295 .91781 L 0 .847 .238 r
F
.43193 .91737 m .42499 .92054 L .43028 .91913 L F
0 g
.43028 .91913 m
.43184 .91941 L
s
.64135 .45885 m
.64854 .47074 L
s
.64124 .45885 m
.64135 .45885 L
s
.63807 .45876 m
.64124 .45885 L
s
.3733 .61031 m
.37835 .60482 L
s
.301 .93866 m
.30286 .93956 L
s
.30286 .93956 m
.30767 .94189 L
s
.79352 .83506 m .79666 .85284 L .80187 .84431 L 0 1 .48 r
F
.79352 .83506 m .79235 .85336 L .79666 .85284 L F
0 g
.79666 .85284 m
.79697 .8599 L
s
.42432 .9637 m .41888 .96105 L .41289 .96006 L 0 1 .537 r
F
.43007 .96036 m .42432 .9637 L .43004 .96466 L 0 1 .535 r
F
.43007 .96036 m .41888 .96105 L .42432 .9637 L F
0 g
.42432 .9637 m
.42676 .96677 L
s
.77947 .60386 m .79248 .59939 L .79364 .60376 L 0 .123 .007 r
F
0 g
.79248 .59939 m
.79727 .59968 L
s
.48487 .55883 m .4917 .53378 L .48719 .53915 L 0 1 .258 r
F
0 g
.4917 .53378 m
.49504 .52251 L
s
.5237 .78361 m
.52371 .78381 L
s
.52491 .7839 m
.52495 .78419 L
s
.5247 .78246 m
.52491 .7839 L
s
.52437 .78018 m
.52468 .78231 L
s
.52468 .78231 m
.5247 .78246 L
s
.36429 .73062 m .35364 .73191 L .35662 .73475 L 0 1 .522 r
F
0 g
.35372 .73854 m
.35662 .73475 L
s
.75193 .75266 m .75455 .74943 L .75924 .7536 L 0 .194 0 r
F
.75193 .75266 m .75142 .74902 L .75455 .74943 L F
0 g
.75453 .74942 m
.75455 .74943 L
s
.75142 .74902 m
.75455 .74943 L
s
.74819 .74375 m
.75142 .74902 L
s
.49868 1.06999 m .49083 1.06685 L .48449 1.06559 L 0 .985 .485 r
F
.39131 .95178 m .38997 .95658 L .39283 .95536 L 0 1 .535 r
F
.39131 .95178 m .38392 .95473 L .38997 .95658 L F
0 g
.38997 .95658 m
.39211 .96 L
s
.50087 .85509 m .50178 .86913 L .50245 .86322 L 0 .472 .337 r
F
.50793 .86738 m .50178 .86913 L .50375 .87754 L 0 .397 .328 r
F
0 g
.50077 .87739 m
.50375 .87754 L
s
.50793 .86738 m .50245 .86322 L .50178 .86913 L 0 .397 .328 r
F
0 g
.49883 .8696 m
.50178 .86913 L
s
.50178 .86913 m
.50375 .87754 L
s
.42833 1.02179 m .41309 1.01404 L .41663 1.01928 L 0 .942 .482 r
F
0 g
.40982 1.01595 m
.41663 1.01928 L
s
.46282 1.04746 m .45999 1.05077 L .46639 1.05333 L 0 .881 .479 r
F
0 g
.45999 1.05077 m
.46487 1.0554 L
s
.5341 .69333 m
.53482 .69435 L
s
.40394 .56812 m .39728 .5714 L .40053 .57046 L 0 1 .385 r
F
.40394 .56812 m .39589 .57055 L .39728 .5714 L F
.40394 .56812 m .39729 .56847 L .39589 .57055 L F
0 g
.40005 .57492 m
.40052 .57046 L
s
.40394 .56812 m .40072 .56613 L .39729 .56847 L 0 1 .385 r
F
.40394 .56812 m .40388 .56508 L .40072 .56613 L F
.40394 .56812 m .40526 .56594 L .40388 .56508 L F
0 g
.40053 .57046 m
.40394 .56812 L
s
.50292 .83801 m .50087 .85509 L .50347 .85354 L 0 .472 .326 r
F
.7149 .91398 m .72561 .91468 L .72157 .91338 L 0 1 .499 r
F
.40966 .55885 m .41422 .55158 L .41551 .54711 L 0 1 .323 r
F
0 g
.40871 .56353 m
.40966 .55885 L
s
.72506 .89411 m .72122 .90129 L .72132 .90593 L 0 1 .478 r
F
0 g
.72122 .90129 m
.72132 .90593 L
s
.71481 .91132 m
.72132 .90593 L
s
.80452 .83344 m .81274 .84323 L .81551 .83217 L 0 1 .484 r
F
0 g
.80743 .85178 m
.81274 .84323 L
s
.81274 .84323 m
.81389 .8513 L
s
.28042 .93784 m .26446 .92829 L .26531 .93365 L 0 1 .534 r
F
.28042 .93784 m .26857 .92756 L .26446 .92829 L F
.28042 .93784 m .27542 .93166 L .26857 .92756 L F
.29031 .93566 m .27542 .93166 L .28042 .93784 L F
0 g
.28042 .93784 m
.28286 .93927 L
s
.28042 .93784 m
.28071 .93974 L
s
.8158 .6705 m .82827 .68046 L .82729 .67304 L 0 1 .516 r
F
0 g
.82555 .68507 m
.82827 .68046 L
s
.57237 .43221 m
.57919 .43117 L
s
.40966 .55885 m .40072 .56612 L .40388 .56508 L 0 1 .323 r
F
.40966 .55885 m .402 .56166 L .40072 .56612 L F
0 g
.40388 .56508 m
.40526 .56594 L
s
.40966 .55885 m .40688 .55466 L .402 .56166 L 0 1 .323 r
F
.40966 .55885 m .41267 .54843 L .40688 .55466 L F
.40966 .55885 m .41551 .54711 L .41267 .54843 L F
0 g
.40388 .56508 m
.40966 .55885 L
s
.41551 .54711 m
.42137 .54041 L
s
.41422 .55158 m
.41551 .54711 L
s
.43007 .96036 m .43004 .96466 L .43223 .96328 L 0 1 .535 r
F
.44334 .966 m .43223 .96328 L .43004 .96466 L F
0 g
.43004 .96466 m
.43274 .96735 L
s
.42432 .9637 m
.43004 .96466 L
s
.55826 .43072 m
.56444 .43594 L
s
.56444 .43594 m
.56481 .43625 L
s
.6036 .63141 m
.6036 .6312 L
s
.6036 .63108 m
.6036 .63066 L
s
.35638 .62837 m
.36121 .62276 L
s
.73602 .9114 m .73569 .91779 L .74203 .91661 L 0 1 .483 r
F
.73602 .9114 m .73166 .91656 L .73569 .91779 L F
0 g
.7347 .92079 m
.73569 .91779 L
s
.52419 .46399 m .53697 .44955 L .53759 .45129 L 0 0 .016 r
F
.52419 .46399 m .53124 .45498 L .53697 .44955 L F
0 g
.53697 .44955 m
.53717 .4492 L
s
.53124 .45498 m
.53604 .44687 L
s
.53124 .45498 m
.53697 .44955 L
s
.73427 1.06964 m .72617 1.07104 L .72248 1.07208 L 0 .744 .239 r
F
0 g
.71344 1.07275 m
.72248 1.07208 L
s
.22704 .92897 m .21167 .92311 L .21668 .93072 L 0 1 .535 r
F
0 g
.21668 .93072 m
.22348 .93583 L
s
.49251 .72309 m .48477 .73303 L .48901 .72718 L 0 .008 .064 r
F
.49251 .72309 m .48206 .73793 L .48477 .73303 L F
.49251 .72309 m .48271 .73862 L .48206 .73793 L F
.49251 .72309 m .48623 .7345 L .48271 .73862 L F
.49251 .72309 m .49026 .72835 L .48623 .7345 L F
.49251 .72309 m .49294 .72346 L .49026 .72835 L F
0 g
.49251 .72309 m
.49455 .71882 L
s
.49092 .7241 m
.49192 .72247 L
s
.49129 .72451 m
.49251 .72309 L
s
.49294 .72346 m
.49628 .71787 L
s
.50706 .88285 m .50619 .89609 L .50918 .89626 L 0 .398 .338 r
F
.25549 .67895 m .24639 .68663 L .25095 .68642 L 0 1 .481 r
F
0 g
.25095 .68642 m
.25406 .69358 L
s
.37541 .72904 m .36457 .72647 L .36429 .73062 L 0 1 .518 r
F
0 g
.36429 .73062 m
.36742 .73321 L
s
.37541 .72904 m .36811 .723 L .36457 .72647 L 0 1 .518 r
F
.37541 .72904 m .37255 .72254 L .36811 .723 L F
.37541 .72904 m .37568 .72513 L .37255 .72254 L F
0 g
.37187 .7325 m
.37541 .72904 L
s
.37541 .72904 m
.37854 .73137 L
s
.5183 .77978 m
.5183 .77861 L
s
.51827 .78958 m
.5183 .77978 L
s
.45558 .74613 m .44401 .75251 L .44759 .75004 L 0 0 0 r
F
0 g
.44446 .75146 m
.44759 .75004 L
s
.44249 .75256 m
.44446 .75146 L
s
.35364 .73191 m .34597 .73608 L .35023 .73557 L 0 1 .524 r
F
0 g
.35023 .73557 m
.35372 .73854 L
s
.40659 1.01036 m .4001 1.00421 L .39334 1.00051 L 0 1 .485 r
F
.31768 .65559 m .30727 .65562 L .30878 .66187 L 0 1 .469 r
F
0 g
.30465 .6684 m
.30878 .66187 L
s
.48865 .97291 m .48307 .97207 L .47808 .9725 L 0 1 .503 r
F
.58363 .4408 m .59097 .44492 L .59802 .45421 L 0 .502 .089 r
F
0 g
.59097 .44492 m
.59492 .44049 L
s
.59492 .44049 m
.59645 .44365 L
s
.50497 .8176 m .50517 .83506 L .50585 .82671 L 0 .483 .316 r
F
.50497 .8176 m .50292 .83801 L .50517 .83506 L F
.51569 .91022 m .51172 .91637 L .516 .92226 L 0 .321 .332 r
F
0 g
.50867 .90847 m
.51172 .91637 L
s
.50836 .91505 m
.51172 .91637 L
s
.38392 .95473 m .37241 .94906 L .36924 .95017 L 0 1 .536 r
F
.38392 .95473 m .3787 .95102 L .37241 .94906 L F
.39131 .95178 m .3787 .95102 L .38392 .95473 L 0 1 .535 r
F
0 g
.38392 .95473 m
.38568 .95846 L
s
.38392 .95473 m
.38997 .95658 L
s
.41057 .7142 m .39908 .71629 L .402 .71818 L 0 1 .502 r
F
0 g
.39835 .72146 m
.402 .71818 L
s
.41057 .7142 m .39982 .71287 L .39908 .71629 L 0 1 .502 r
F
.41057 .7142 m .40379 .70977 L .39982 .71287 L F
.41057 .7142 m .40834 .70907 L .40379 .70977 L F
.41057 .7142 m .41125 .71097 L .40834 .70907 L F
0 g
.41057 .7142 m
.41353 .71584 L
s
.40661 .71729 m
.41057 .7142 L
s
.45558 .74613 m .44385 .75322 L .44401 .75251 L 0 0 0 r
F
.45558 .74613 m .44723 .75189 L .44385 .75322 L F
.45558 .74613 m .45188 .74941 L .44723 .75189 L F
0 g
.44494 .75187 m
.44759 .75004 L
s
.45558 .74613 m .45546 .74694 L .45188 .74941 L 0 0 0 r
F
0 g
.45558 .74613 m
.45627 .74555 L
s
.45401 .74674 m
.45558 .74613 L
s
.48933 .63103 m .48419 .63406 L .48596 .63384 L 0 1 .195 r
F
.48933 .63103 m .48527 .63158 L .48419 .63406 L F
0 g
.48618 .63556 m
.48859 .63393 L
s
.48525 .63144 m .48867 .6021 L .48497 .60274 L 0 1 .297 r
F
.48526 .63271 m .48542 .63129 L .48525 .63144 L F
.48542 .63129 m .48867 .6021 L .48525 .63144 L F
.48542 .63129 m .48994 .61083 L .48867 .6021 L F
.48526 .63271 m .4856 .63113 L .48542 .63129 L F
.4856 .63113 m .48994 .61083 L .48542 .63129 L F
.48933 .63103 m .48861 .62855 L .48527 .63158 L 0 1 .195 r
F
.48861 .62855 m .4886 .62852 L .48801 .62906 L F
.48861 .62855 m .48801 .62906 L .48527 .63158 L F
.48933 .63103 m .49184 .62527 L .49136 .62567 L F
.48858 .62845 m .49136 .62567 L .48848 .62394 L 0 1 .295 r
F
.4886 .62852 m .48858 .62845 L .48619 .63062 L 0 1 .195 r
F
.4886 .62852 m .48598 .6308 L .48595 .63083 L F
.48801 .62906 m .48595 .63083 L .48527 .63158 L F
.4886 .62852 m .48595 .63083 L .48801 .62906 L F
.4856 .63113 m .48848 .62394 L .48994 .61083 L 0 1 .297 r
F
.48526 .63271 m .48595 .63083 L .4856 .63113 L F
.48595 .63083 m .48848 .62394 L .4856 .63113 L F
.48269 .63945 m .48531 .63615 L .48596 .63384 L 0 1 .261 r
F
.48269 .63945 m .48596 .63384 L .48419 .63406 L F
.48922 .65913 m .48858 .62845 L .48526 .63271 L 0 1 .295 r
F
.48857 .62818 m .48848 .62394 L .48595 .63083 L F
.48555 .63124 m .48847 .62807 L .48988 .62593 L 0 .946 .181 r
F
.48527 .63158 m .48595 .63083 L .48555 .63124 L F
.48595 .63083 m .48847 .62807 L .48555 .63124 L F
.48858 .62845 m .48857 .62818 L .48595 .63083 L 0 1 .295 r
F
.48619 .63062 m .4862 .6306 L .48612 .63068 L 0 1 .195 r
F
.48858 .62845 m .48595 .63083 L .48526 .63271 L 0 1 .295 r
F
.48612 .63068 m .48847 .62807 L .48598 .6308 L 0 1 .195 r
F
.4862 .6306 m .48847 .62807 L .48612 .63068 L F
.48858 .62845 m .49136 .62567 L .48847 .62807 L F
.48933 .63103 m .49136 .62567 L .48858 .62845 L F
.48858 .62845 m .49153 .62577 L .49136 .62567 L 0 1 .295 r
F
.48922 .65913 m .49184 .62595 L .49153 .62577 L F
.48922 .65913 m .49153 .62577 L .48858 .62845 L F
.48858 .62845 m .48847 .62807 L .48619 .63062 L 0 1 .195 r
F
.75435 .86709 m .75113 .87601 L .75183 .88207 L 0 1 .481 r
F
0 g
.74553 .8886 m
.75183 .88207 L
s
.46447 .90482 m .45363 .90979 L .45499 .90945 L 0 .788 .188 r
F
0 g
.45003 .91168 m
.45499 .90945 L
s
.65806 .48467 m
.65944 .48765 L
s
.77325 .76534 m .78264 .77103 L .77797 .76796 L 0 .193 .186 r
F
.77325 .76534 m .78486 .77332 L .78264 .77103 L F
.42499 .92054 m .41503 .92246 L .41202 .9237 L 0 .976 .259 r
F
.42499 .92054 m .4206 .9211 L .41503 .92246 L F
.43193 .91737 m .4206 .9211 L .42499 .92054 L 0 .847 .238 r
F
0 g
.42499 .92054 m
.42629 .9212 L
s
.42499 .92054 m
.43028 .91913 L
s
.49862 .71883 m
.49866 .71875 L
s
.49866 .71875 m
.49866 .71875 L
s
.49748 .72112 m
.49862 .71883 L
s
.49864 .7188 m
.49866 .71875 L
s
.49654 .72425 m
.49793 .72064 L
s
.49793 .72064 m
.49864 .7188 L
s
.30022 .93352 m .2968 .93943 L .3007 .93851 L 0 1 .533 r
F
.30015 .93558 m .2968 .93943 L .3007 .93851 L 0 1 .5 r
F
.30022 .93352 m .29031 .93566 L .2968 .93943 L 0 1 .533 r
F
.30015 .93558 m .29024 .93768 L .2968 .93943 L 0 1 .5 r
F
0 g
.29096 .94081 m
.29096 .94082 L
s
.29094 .94064 m
.29096 .94082 L
s
.30008 .93765 m .2968 .93943 L .3007 .93851 L 0 .758 .238 r
F
0 g
.3007 .93851 m
.30075 .9385 L
s
.3007 .93851 m
.30086 .93854 L
s
.3007 .93851 m
.301 .93866 L
s
.30008 .93765 m .29017 .93971 L .2968 .93943 L 0 .758 .238 r
F
0 g
.2968 .93943 m
.29813 .94434 L
s
.29655 .93944 m
.2968 .93943 L
s
.29094 .94063 m
.29094 .94064 L
s
.29058 .93777 m
.29081 .93957 L
s
.29082 .93968 m
.29094 .94063 L
s
.29091 .9406 m
.29096 .94081 L
s
.2907 .93968 m
.29091 .9406 L
s
.35477 .96303 m .35311 .97039 L .35626 .96934 L 0 1 .477 r
F
.35477 .96303 m .34668 .96557 L .35311 .97039 L F
0 g
.34668 .96557 m
.34765 .97225 L
s
.36874 .98082 m .35626 .96934 L .35311 .97039 L 0 1 .482 r
F
0 g
.34669 .96558 m
.35311 .97039 L
s
.35311 .97039 m
.35531 .97653 L
s
.45469 .67867 m .44647 .6819 L .4505 .68123 L 0 1 .45 r
F
.45469 .67867 m .44481 .68023 L .44647 .6819 L F
0 g
.4505 .68123 m
.45254 .68278 L
s
.45469 .67867 m .44663 .67735 L .44481 .68023 L 0 1 .45 r
F
.45469 .67867 m .45083 .67478 L .44663 .67735 L F
.45469 .67867 m .4546 .67425 L .45083 .67478 L F
.45469 .67867 m .45625 .67591 L .4546 .67425 L F
0 g
.45469 .67867 m
.45653 .68022 L
s
.4505 .68123 m
.45469 .67867 L
s
.45625 .67591 m
.46025 .67346 L
s
.35364 .73191 m .34299 .73299 L .34597 .73608 L 0 1 .524 r
F
0 g
.3431 .74 m
.34597 .73608 L
s
.51664 .9728 m .51125 .9746 L .51693 .97464 L 0 .992 .369 r
F
.51664 .9728 m .50713 .97387 L .51125 .9746 L F
0 g
.50684 .97539 m
.51125 .9746 L
s
.48773 .57107 m .48228 .57068 L .48357 .57556 L 0 1 .268 r
F
.48773 .57107 m .48487 .55883 L .48228 .57068 L F
.48096 1.05822 m .47142 1.05738 L .47915 1.06144 L 0 .86 .471 r
F
.48096 1.05822 m .46639 1.05333 L .47142 1.05738 L F
0 g
.46487 1.0554 m
.47142 1.05738 L
s
.4123 1.00727 m .40659 1.01036 L .41309 1.01404 L 0 .973 .48 r
F
.4123 1.00727 m .4001 1.00421 L .40659 1.01036 L F
0 g
.40659 1.01036 m
.40982 1.01595 L
s
.51055 .80012 m .50687 .81284 L .50778 .82322 L 0 .469 .304 r
F
0 g
.50497 .8176 m
.50687 .81284 L
s
.51664 .9728 m .51693 .97464 L .52101 .97418 L 0 .992 .369 r
F
0 g
.51693 .97464 m
.52138 .97524 L
s
.47896 .73251 m .47071 .73892 L .47533 .73493 L 0 0 .034 r
F
.47896 .73251 m .46747 .74256 L .47071 .73892 L F
.47896 .73251 m .46776 .74342 L .46747 .74256 L F
.47896 .73251 m .47141 .74099 L .46776 .74342 L F
0 g
.4675 .73996 m
.46892 .73848 L
s
.47896 .73251 m .47596 .7369 L .47141 .74099 L 0 0 .034 r
F
.47896 .73251 m .47919 .73327 L .47596 .7369 L F
0 g
.47533 .73493 m
.47873 .73136 L
s
.47896 .73251 m
.48225 .72807 L
s
.47533 .73493 m
.47896 .73251 L
s
.75435 .86709 m .76162 .87375 L .76501 .86455 L 0 1 .481 r
F
0 g
.75598 .88125 m
.76162 .87375 L
s
.76162 .87375 m
.76221 .88016 L
s
.52559 .78215 m
.52572 .78365 L
s
.52509 .77646 m
.5255 .78115 L
s
.5255 .78115 m
.52559 .78215 L
s
.52541 .77482 m
.52623 .77986 L
s
.50793 .86738 m .50509 .86246 L .50245 .86322 L 0 .397 .328 r
F
0 g
.50087 .85509 m
.50245 .86322 L
s
.4826 .72997 m
.48277 .72981 L
s
.47919 .73327 m
.4826 .72997 L
s
.50355 .97176 m .50274 .97426 L .50713 .97387 L 0 1 .441 r
F
.50355 .97176 m .49708 .97385 L .50274 .97426 L F
0 g
.50274 .97426 m
.50684 .97539 L
s
.52096 .70391 m .52061 .65067 L .52 .68086 L 0 .852 .261 r
F
.51617 .70559 m .52 .68086 L .52061 .65067 L 0 .872 .266 r
F
0 g
.51927 .63189 m
.52061 .65067 L
s
.52061 .65067 m
.52241 .62985 L
s
.5203 .7015 m
.52095 .70355 L
s
.34378 .6359 m .33465 .64148 L .33874 .64146 L 0 1 .466 r
F
0 g
.33874 .64146 m
.34038 .64725 L
s
.25549 .67895 m .24414 .67928 L .24639 .68663 L 0 1 .481 r
F
0 g
.24269 .6943 m
.24639 .68663 L
s
.60174 .45456 m .60009 .4625 L .59802 .45421 L 0 .598 .074 r
F
.60174 .45456 m .60725 .47622 L .60009 .4625 L F
.60174 .45456 m .61473 .4862 L .60725 .47622 L F
0 g
.61214 .46099 m
.61507 .46949 L
s
.60174 .45456 m .61844 .4865 L .61473 .4862 L 0 .598 .074 r
F
.60174 .45456 m .61593 .47696 L .61844 .4865 L F
.60174 .45456 m .60877 .46329 L .61593 .47696 L F
0 g
.60877 .46329 m
.61214 .46099 L
s
.59645 .44365 m
.60174 .45456 L
s
.73427 1.06964 m .73425 1.0707 L .74266 1.06886 L 0 .744 .239 r
F
0 g
.73092 1.07192 m
.73425 1.0707 L
s
.72562 1.07208 m
.73425 1.0707 L
s
.79352 .83506 m .791 .84575 L .79235 .85336 L 0 1 .48 r
F
0 g
.78632 .86103 m
.79235 .85336 L
s
.51055 .80012 m .51125 .82147 L .51146 .81049 L 0 .469 .304 r
F
.51055 .80012 m .50967 .82693 L .51125 .82147 L F
.51055 .80012 m .50778 .82322 L .50967 .82693 L F
0 g
.51055 .80012 m
.51177 .79222 L
s
.34668 .96557 m .33381 .9534 L .32933 .95466 L 0 1 .482 r
F
.34668 .96557 m .34126 .95808 L .33381 .9534 L F
0 g
.34668 .96557 m
.34668 .96557 L
s
.35477 .96303 m .34126 .95808 L .34668 .96557 L 0 1 .477 r
F
0 g
.34668 .96557 m
.34669 .96558 L
s
.36874 .98082 m .36296 .97381 L .35626 .96934 L 0 1 .482 r
F
.37611 .97807 m .36874 .98082 L .37521 .98523 L 0 1 .477 r
F
.37611 .97807 m .36296 .97381 L .36874 .98082 L F
0 g
.36874 .98082 m
.37093 .98695 L
s
.51569 .91022 m .51188 .90455 L .50887 .9038 L 0 .321 .332 r
F
0 g
.50887 .9038 m
.51188 .90455 L
s
.50619 .89609 m
.50887 .9038 L
s
.54825 1.07634 m .55142 1.07232 L .55065 1.0746 L 0 0 0 r
F
0 g
.55007 1.0715 m
.55142 1.07232 L
s
.31768 .65559 m .30946 .64718 L .30727 .65562 L 0 1 .469 r
F
0 g
.30727 .65562 m
.30878 .66187 L
s
.31768 .65559 m .31419 .64098 L .30946 .64718 L 0 1 .469 r
F
.31768 .65559 m .31828 .64115 L .31419 .64098 L F
.31768 .65559 m .31978 .64742 L .31828 .64115 L F
0 g
.31768 .65559 m
.31926 .66159 L
s
.31297 .66178 m
.31768 .65559 L
s
.58363 .4408 m .58092 .4498 L .57932 .44288 L 0 .502 .089 r
F
0 g
.57932 .44288 m
.5804 .44236 L
s
.58363 .4408 m .58798 .45914 L .58092 .4498 L 0 .502 .089 r
F
.58363 .4408 m .59579 .46463 L .58798 .45914 L F
.58363 .4408 m .60009 .4625 L .59579 .46463 L F
.58363 .4408 m .59802 .45421 L .60009 .4625 L F
0 g
.59589 .4514 m
.59802 .45421 L
s
.59855 .45426 m
.60174 .45456 L
s
.59802 .45421 m
.59855 .45426 L
s
.5804 .44236 m
.58363 .4408 L
s
.5808 .43691 m
.58363 .4408 L
s
.59097 .44492 m
.59589 .4514 L
s
.28035 .93982 m .2642 .93482 L .26513 .93819 L 0 1 .515 r
F
.28035 .93982 m .26831 .93414 L .2642 .93482 L F
.28035 .93982 m .27524 .93629 L .26831 .93414 L F
.29024 .93768 m .27524 .93629 L .28035 .93982 L 0 1 .508 r
F
0 g
.28035 .93982 m
.28085 .94168 L
s
.28035 .93982 m
.28428 .94095 L
s
.29094 .94079 m
.29095 .9408 L
s
.29647 .93944 m
.29655 .93944 L
s
.37158 .93228 m .35729 .93221 L .35847 .93389 L 0 1 .418 r
F
.37158 .93228 m .36072 .93123 L .35729 .93221 L F
.37158 .93228 m .36686 .93126 L .36072 .93123 L F
.3797 .92952 m .36686 .93126 L .37158 .93228 L 0 1 .384 r
F
0 g
.37158 .93228 m
.37748 .93216 L
s
.37158 .93228 m
.37274 .93395 L
s
.49707 .72359 m
.49754 .72248 L
s
.49754 .72248 m
.49909 .71881 L
s
.49909 .71881 m
.49909 .71881 L
s
.49823 .7216 m
.49909 .71881 L
s
.4982 .72167 m
.49823 .7216 L
s
.50292 .83801 m .50347 .85354 L .50415 .84657 L 0 .472 .326 r
F
.48752 .89196 m .48387 .89433 L .47995 .89682 L 0 0 0 r
F
.49066 .89069 m .48752 .89196 L .4911 .88983 L F
.49066 .89069 m .48387 .89433 L .48752 .89196 L F
.54825 1.07634 m .54447 1.07556 L .54511 1.07441 L F
0 g
.54511 1.07441 m
.54659 1.07334 L
s
.53809 1.07648 m .54511 1.07441 L .54447 1.07556 L 0 1 .426 r
F
0 g
.53939 1.07528 m
.54511 1.07441 L
s
.68269 .93108 m .69251 .92577 L .68902 .9269 L 0 1 .392 r
F
.69373 .91851 m .69251 .92577 L .69844 .92065 L 0 1 .421 r
F
.69373 .91851 m .68902 .9269 L .69251 .92577 L F
0 g
.69124 .92854 m
.69251 .92577 L
s
.52197 .97425 m
.52255 .97429 L
s
.52255 .97429 m
.52287 .97432 L
s
.52287 .97432 m
.52544 .9745 L
s
.50355 .97176 m .49331 .97268 L .49708 .97385 L 0 1 .441 r
F
0 g
.49236 .97451 m
.49708 .97385 L
s
.47849 .89763 m .46881 .90285 L .47029 .90203 L 0 0 0 r
F
0 g
.46581 .90449 m
.47029 .90203 L
s
.52058 .7904 m
.52096 .79334 L
s
.42833 1.02179 m .43006 1.02834 L .43187 1.02703 L 0 .942 .482 r
F
.44522 1.03523 m .43187 1.02703 L .43006 1.02834 L 0 .91 .483 r
F
0 g
.43006 1.02834 m
.43414 1.03327 L
s
.42353 1.02501 m
.43006 1.02834 L
s
.33365 .94659 m .32933 .95466 L .33381 .9534 L 0 1 .478 r
F
.33365 .94659 m .3222 .9496 L .32933 .95466 L F
0 g
.32933 .95466 m
.33031 .96135 L
s
.5348 .96836 m
.53664 .97238 L
s
.34299 .73299 m .33532 .73723 L .33958 .73679 L 0 1 .526 r
F
0 g
.33958 .73679 m
.3431 .74 L
s
.51133 .71017 m .51329 .64465 L .51089 .65006 L 0 .89 .272 r
F
.51133 .71017 m .51498 .66024 L .51329 .64465 L F
0 g
.51329 .64465 m
.51521 .62353 L
s
.5184 1.07532 m .52474 1.07849 L .52451 1.07741 L 0 1 .488 r
F
0 g
.52474 1.07849 m
.52726 1.07813 L
s
.51868 1.07829 m
.52474 1.07849 L
s
.37611 .97807 m .37521 .98523 L .37806 .98409 L 0 1 .477 r
F
.39073 .99469 m .37806 .98409 L .37521 .98523 L 0 1 .481 r
F
0 g
.37521 .98523 m
.37782 .99105 L
s
.36874 .98082 m
.37521 .98523 L
s
.49342 .51709 m .50287 .49621 L .49799 .50308 L 0 1 .155 r
F
0 g
.50287 .49621 m
.50729 .48728 L
s
.44522 1.03523 m .44788 1.04149 L .4493 1.04016 L 0 .91 .483 r
F
.46282 1.04746 m .4493 1.04016 L .44788 1.04149 L 0 .881 .479 r
F
0 g
.44788 1.04149 m
.45246 1.04604 L
s
.44139 1.03854 m
.44788 1.04149 L
s
.73602 .9114 m .73179 .91383 L .73166 .91656 L 0 1 .483 r
F
0 g
.72481 .91747 m
.73166 .91656 L
s
.43754 .69457 m .42891 .69819 L .43333 .69735 L 0 1 .478 r
F
.43754 .69457 m .42662 .69657 L .42891 .69819 L F
0 g
.43333 .69735 m
.43599 .69886 L
s
.43754 .69457 m .42798 .69357 L .42662 .69657 L 0 1 .478 r
F
.43754 .69457 m .4322 .69079 L .42798 .69357 L F
.43754 .69457 m .43646 .69009 L .4322 .69079 L F
.43754 .69457 m .43875 .69171 L .43646 .69009 L F
0 g
.43754 .69457 m
.43995 .69599 L
s
.43333 .69735 m
.43754 .69457 L
s
.62438 .61361 m
.62465 .61639 L
s
.62636 .63424 m
.6269 .63985 L
s
.62616 .63212 m
.62636 .63424 L
s
.626 .63045 m
.62616 .63212 L
s
.62438 .61361 m
.62447 .61598 L
s
.53005 .69776 m
.53016 .6978 L
s
.52957 .69762 m
.53005 .69776 L
s
.52957 .69762 m
.5302 .70391 L
s
.26682 .67859 m .25699 .66918 L .25549 .67895 L 0 1 .479 r
F
.26682 .67859 m .2615 .66187 L .25699 .66918 L F
.26682 .67859 m .266 .66192 L .2615 .66187 L F
.26682 .67859 m .26828 .6691 L .266 .66192 L F
0 g
.26232 .68586 m
.26682 .67859 L
s
.26682 .67859 m
.26914 .68551 L
s
.54116 .57649 m .54956 .57159 L .55122 .57835 L 0 .215 .104 r
F
0 g
.54956 .57159 m
.55127 .56123 L
s
.54526 .5708 m
.54956 .57159 L
s
.48096 1.05822 m .47915 1.06144 L .48539 1.06354 L 0 .86 .471 r
F
0 g
.47915 1.06144 m
.48449 1.06559 L
s
.49337 .61029 m .48867 .6021 L .48994 .61083 L 0 1 .283 r
F
0 g
.48994 .61083 m
.49337 .61029 L
s
.48867 .6021 m
.49056 .58775 L
s
.49192 .62513 m
.49192 .62509 L
s
.49192 .62509 m
.49193 .62498 L
s
.49193 .62498 m
.49337 .61029 L
s
.43295 .91781 m
.43823 .91599 L
s
.44887 .91158 m .43705 .9159 L .43823 .91599 L 0 .828 .216 r
F
0 g
.43823 .91599 m
.43823 .91599 L
s
.34299 .73299 m .33235 .7339 L .33532 .73723 L 0 1 .526 r
F
0 g
.33248 .7413 m
.33532 .73723 L
s
.4123 1.00727 m .39713 .9987 L .4001 1.00421 L 0 .973 .48 r
F
0 g
.39334 1.00051 m
.4001 1.00421 L
s
.33394 .93652 m .31699 .93476 L .3173 .93738 L 0 1 .477 r
F
.33394 .93652 m .32179 .93368 L .31699 .93476 L F
.33394 .93652 m .32907 .93444 L .32179 .93368 L F
0 g
.33394 .93652 m
.33422 .93913 L
s
.34268 .9341 m .32907 .93444 L .33394 .93652 L 0 1 .46 r
F
0 g
.33394 .93652 m
.34015 .9373 L
s
.77567 .86256 m .78588 .85426 L .78157 .85494 L 0 1 .491 r
F
.76501 .86455 m .77567 .86256 L .7751 .85611 L 0 1 .486 r
F
0 g
.24962 .93823 m
.25504 .94012 L
s
.5297 .97325 m .53109 .97427 L .53481 .97387 L 0 .751 .269 r
F
0 g
.53109 .97427 m
.53426 .97393 L
s
.53109 .97427 m
.53449 .97434 L
s
.50489 .664 m .50729 .65836 L .50884 .63958 L 0 1 .278 r
F
.67113 .52977 m .6732 .5221 L .66972 .51771 L 0 .348 .311 r
F
0 g
.6694 .51702 m
.66972 .51771 L
s
.24781 .92552 m .24394 .93202 L .24803 .93127 L 0 1 .534 r
F
0 g
.24803 .93127 m
.24947 .93215 L
s
.24781 .92552 m .23741 .92723 L .24394 .93202 L 0 1 .534 r
F
0 g
.24394 .93202 m
.24515 .93772 L
s
.6339 .51514 m
.63398 .51546 L
s
.63398 .51546 m
.63406 .51578 L
s
.63406 .51578 m
.63437 .51699 L
s
.63437 .51699 m
.63485 .51884 L
s
.63485 .51884 m
.63634 .52464 L
s
.63634 .52464 m
.63807 .53135 L
s
.63807 .53135 m
.63819 .53185 L
s
.63819 .53185 m
.63869 .53379 L
s
.63869 .53379 m
.6388 .53422 L
s
.6388 .53422 m
.63957 .53722 L
s
.63957 .53722 m
.63964 .5375 L
s
.63964 .5375 m
.63971 .53776 L
s
.67113 .52977 m .67999 .53921 L .6732 .5221 L 0 .348 .311 r
F
.67113 .52977 m .68558 .55766 L .67999 .53921 L F
.67113 .52977 m .687 .56977 L .68558 .55766 L F
.67113 .52977 m .6833 .56745 L .687 .56977 L F
0 g
.66993 .56068 m
.67118 .56512 L
s
.67113 .52977 m .67649 .55028 L .6833 .56745 L 0 .348 .311 r
F
0 g
.6674 .54076 m
.67325 .55821 L
s
.66591 .51426 m
.67113 .52977 L
s
.66972 .51771 m
.67113 .52977 L
s
.67118 .56512 m
.67355 .57359 L
s
.56655 .56998 m .56721 .58954 L .56505 .58022 L 0 .508 .14 r
F
0 g
.56709 .57012 m
.56713 .587 L
s
.56655 .56998 m .57231 .59634 L .56721 .58954 L 0 .508 .14 r
F
.56655 .56998 m .57693 .59603 L .57231 .59634 L F
.56655 .56998 m .5784 .58571 L .57693 .59603 L F
0 g
.56713 .58919 m
.56732 .67562 L
s
.56655 .56998 m .57575 .57233 L .5784 .58571 L 0 .508 .14 r
F
0 g
.57068 .56562 m
.57575 .57233 L
s
.56183 .56591 m
.56655 .56998 L
s
.57575 .57233 m
.57666 .55938 L
s
.80803 .78639 m .81761 .79305 L .81958 .79179 L 0 .407 .231 r
F
0 g
.81272 .79214 m
.81761 .79305 L
s
.81761 .79305 m
.81955 .79566 L
s
.75102 1.06831 m .76359 1.06617 L .76016 1.06641 L 0 .876 .271 r
F
.74266 1.06886 m .75102 1.06831 L .75501 1.06686 L 0 .787 .252 r
F
.36429 .73062 m .35393 .72752 L .35364 .73191 L 0 1 .522 r
F
.36429 .73062 m .35733 .72396 L .35393 .72752 L F
.36429 .73062 m .36159 .72362 L .35733 .72396 L F
.36429 .73062 m .36457 .72647 L .36159 .72362 L F
0 g
.36089 .73417 m
.36429 .73062 L
s
.41101 .95679 m .39714 .95355 L .39903 .95682 L 0 1 .536 r
F
0 g
.39283 .95536 m
.39903 .95682 L
s
.43007 .96036 m .4167 .95812 L .41888 .96105 L 0 1 .535 r
F
0 g
.41289 .96006 m
.41888 .96105 L
s
.42386 .70412 m .41516 .70789 L .41971 .70704 L 0 1 .492 r
F
0 g
.41971 .70704 m
.42266 .70868 L
s
.34378 .6359 m .33367 .63582 L .33465 .64148 L 0 1 .466 r
F
0 g
.33008 .64745 m
.33465 .64148 L
s
.34378 .6359 m .33645 .62825 L .33367 .63582 L 0 1 .466 r
F
.34378 .6359 m .3415 .62268 L .33645 .62825 L F
.34378 .6359 m .34544 .62283 L .3415 .62268 L F
.34378 .6359 m .34642 .62851 L .34544 .62283 L F
0 g
.34378 .6359 m
.34487 .64134 L
s
.33874 .64146 m
.34378 .6359 L
s
.44401 .75251 m .43604 .75572 L .44066 .75358 L 0 0 0 r
F
0 g
.44066 .75358 m
.44118 .75341 L
s
.44066 .75358 m
.44249 .75256 L
s
.33365 .94659 m .31717 .94159 L .3222 .9496 L 0 1 .478 r
F
0 g
.3222 .9496 m
.32933 .95466 L
s
.49056 .96995 m .48865 .97291 L .49331 .97268 L 0 1 .483 r
F
.49056 .96995 m .48307 .97207 L .48865 .97291 L F
0 g
.48865 .97291 m
.49236 .97451 L
s
.44334 .966 m .43794 .96386 L .43223 .96328 L 0 1 .535 r
F
0 g
.44334 .966 m
.44602 .9687 L
s
.44839 .96252 m .44334 .966 L .44881 .96654 L 0 1 .531 r
F
.44839 .96252 m .43794 .96386 L .44334 .966 L F
.67043 1.07136 m .68175 1.0724 L .67892 1.07211 L 0 .618 .243 r
F
.69052 1.0728 m .68175 1.0724 L .68999 1.07262 L 0 .556 .207 r
F
.69052 1.0728 m .67892 1.07211 L .68175 1.0724 L F
0 g
.68598 1.07286 m
.6862 1.07285 L
s
.6862 1.07285 m
.68854 1.07271 L
s
.67723 1.07243 m
.68175 1.0724 L
s
.53733 .76137 m
.53759 .76246 L
s
.53618 .75655 m
.53733 .76137 L
s
.48531 .63615 m
.48561 .63506 L
s
.48531 .63615 m
.48573 .63586 L
s
.24414 .67928 m .23501 .68714 L .23957 .68694 L 0 1 .484 r
F
0 g
.23957 .68694 m
.24269 .6943 L
s
.53845 .97444 m
.53862 .97477 L
s
.5088 .84901 m .50347 .85354 L .50509 .86246 L 0 .407 .318 r
F
.5088 .84901 m .50415 .84657 L .50347 .85354 L F
0 g
.50087 .85509 m
.50347 .85354 L
s
.78806 .92248 m .7994 .92057 L .7952 .91987 L 0 1 .525 r
F
0 g
.79841 .92449 m
.80519 .92183 L
s
.77768 .92042 m .78806 .92248 L .78888 .91879 L 0 1 .521 r
F
.42386 .70412 m .41258 .70615 L .41516 .70789 L 0 1 .492 r
F
.42386 .70412 m .41368 .70296 L .41258 .70615 L F
.42386 .70412 m .41784 .70005 L .41368 .70296 L F
.42386 .70412 m .42227 .69935 L .41784 .70005 L F
.42386 .70412 m .42485 .7011 L .42227 .69935 L F
0 g
.42386 .70412 m
.42652 .70563 L
s
.41971 .70704 m
.42386 .70412 L
s
.43875 .69171 m
.44283 .68896 L
s
.33235 .7339 m .32467 .73824 L .32893 .73786 L 0 1 .527 r
F
0 g
.32893 .73786 m
.33248 .7413 L
s
.80432 .66764 m .81163 .66438 L .80704 .66334 L 0 1 .51 r
F
.80432 .66764 m .8158 .6705 L .81163 .66438 L F
0 g
.80016 .66167 m
.80432 .66764 L
s
.23706 .93535 m .23343 .94007 L .23752 .93935 L 0 1 .526 r
F
0 g
.23752 .93935 m
.23926 .93999 L
s
.23706 .93535 m .22668 .93692 L .23343 .94007 L 0 1 .526 r
F
0 g
.23343 .94007 m
.23491 .94406 L
s
.50967 .82693 m .50585 .82671 L .50517 .83506 L 0 .43 .311 r
F
.50967 .82693 m .50778 .82322 L .50585 .82671 L F
0 g
.50497 .8176 m
.50585 .82671 L
s
.50585 .82671 m
.50778 .82322 L
s
.50687 .81284 m
.50778 .82322 L
s
.75193 .75266 m .75924 .7536 L .76317 .75903 L 0 .194 0 r
F
0 g
.75924 .7536 m
.75988 .75449 L
s
.75924 .7536 m
.76162 .75616 L
s
.30727 .65562 m .29599 .66202 L .3015 .66197 L 0 1 .472 r
F
0 g
.3015 .66197 m
.30465 .6684 L
s
.46706 .74043 m .45886 .74522 L .4635 .74212 L 0 0 .003 r
F
0 g
.4635 .74212 m
.46706 .73915 L
s
.4123 1.00727 m .41309 1.01404 L .41527 1.01278 L 0 .973 .48 r
F
.42833 1.02179 m .41527 1.01278 L .41309 1.01404 L 0 .942 .482 r
F
0 g
.41309 1.01404 m
.41663 1.01928 L
s
.40659 1.01036 m
.41309 1.01404 L
s
.53644 .97334 m .53482 .97387 L .53665 .97402 L 0 .669 .233 r
F
0 g
.53636 .974 m
.53665 .97402 L
s
.53658 .97405 m
.53665 .97402 L
s
.39908 .71629 m .39045 .72016 L .39507 .71941 L 0 1 .51 r
F
0 g
.39507 .71941 m
.39835 .72146 L
s
.30069 .93849 m
.3007 .93851 L
s
.28027 .9418 m .26394 .94136 L .26496 .94273 L 0 .839 .261 r
F
.28027 .9418 m .26806 .94073 L .26394 .94136 L F
.28027 .9418 m .27507 .94092 L .26806 .94073 L F
.29017 .93971 m .27507 .94092 L .28027 .9418 L 0 .787 .25 r
F
0 g
.28027 .9418 m
.28674 .94176 L
s
.28027 .9418 m
.28122 .94313 L
s
.74646 .91381 m .75224 .91926 L .75689 .9161 L 0 1 .497 r
F
0 g
.74575 .92075 m
.75224 .91926 L
s
.75178 .92247 m
.75224 .91926 L
s
.69373 .91851 m .69844 .92065 L .70285 .91495 L 0 1 .421 r
F
0 g
.69251 .92577 m
.69844 .92065 L
s
.61424 .47374 m
.61433 .47391 L
s
.61398 .47325 m
.61424 .47374 L
s
.61333 .47199 m
.61398 .47325 L
s
.60877 .46329 m
.61333 .47199 L
s
.5184 1.07532 m .5105 1.07362 L .50444 1.07342 L 0 1 .488 r
F
.22632 .9449 m .22293 .9479 L .22702 .94723 L 0 1 .366 r
F
0 g
.22702 .94723 m
.23472 .94834 L
s
.22632 .9449 m .21595 .94634 L .22293 .9479 L 0 1 .366 r
F
0 g
.22293 .9479 m
.22468 .95025 L
s
.49066 .89069 m .4911 .88983 L .49222 .88935 L 0 0 0 r
F
.4988 .88448 m .49222 .88935 L .4911 .88983 L F
0 g
.4911 .88983 m
.49306 .88817 L
s
.48752 .89196 m
.4911 .88983 L
s
.33235 .7339 m .32169 .73466 L .32467 .73824 L 0 1 .527 r
F
0 g
.32185 .74247 m
.32467 .73824 L
s
.37129 .9452 m .36924 .95017 L .37241 .94906 L 0 1 .534 r
F
.37129 .9452 m .36318 .94782 L .36924 .95017 L F
0 g
.36924 .95017 m
.37102 .95391 L
s
.5088 .84901 m .50643 .84462 L .50415 .84657 L 0 .407 .318 r
F
0 g
.50292 .83801 m
.50415 .84657 L
s
.51914 .59382 m .52296 .58885 L .52632 .58739 L 0 0 .049 r
F
0 g
.52296 .58885 m
.52534 .58368 L
s
.45878 .67174 m .45083 .67478 L .4546 .67425 L 0 1 .438 r
F
.45878 .67174 m .44957 .67301 L .45083 .67478 L F
0 g
.4546 .67425 m
.45625 .67591 L
s
.45878 .67174 m .45168 .67011 L .44957 .67301 L 0 1 .438 r
F
.45878 .67174 m .45586 .6676 L .45168 .67011 L F
.45878 .67174 m .45933 .66716 L .45586 .6676 L F
.45878 .67174 m .46058 .66894 L .45933 .66716 L F
0 g
.45878 .67174 m
.46025 .67346 L
s
.4546 .67425 m
.45878 .67174 L
s
.46058 .66894 m
.46453 .66657 L
s
.25981 .93032 m
.26531 .93365 L
s
.50967 .82693 m .50517 .83506 L .50643 .84462 L 0 .43 .311 r
F
0 g
.50292 .83801 m
.50517 .83506 L
s
.49056 .96995 m .47968 .97049 L .48307 .97207 L 0 1 .483 r
F
0 g
.47808 .9725 m
.48307 .97207 L
s
.46706 .74043 m .45546 .74818 L .45886 .74522 L 0 0 .003 r
F
.46706 .74043 m .45558 .74902 L .45546 .74818 L F
.46706 .74043 m .45915 .74733 L .45558 .74902 L F
.46706 .74043 m .46377 .74424 L .45915 .74733 L F
.46706 .74043 m .46717 .74128 L .46377 .74424 L F
0 g
.46706 .74043 m
.4675 .73996 L
s
.4635 .74212 m
.46706 .74043 L
s
.34254 .93923 m .33995 .94452 L .34337 .94353 L 0 1 .533 r
F
.34254 .93923 m .3338 .94155 L .33995 .94452 L F
0 g
.33995 .94452 m
.34151 .94872 L
s
.50047 .71927 m
.50058 .71884 L
s
.50012 .72064 m
.50047 .71927 L
s
.49943 .72334 m
.50012 .72064 L
s
.50025 .71961 m
.50058 .71884 L
s
.49926 .72194 m
.50025 .71961 L
s
.46282 1.04746 m .46639 1.05333 L .4674 1.05201 L 0 .881 .479 r
F
.48096 1.05822 m .4674 1.05201 L .46639 1.05333 L 0 .86 .471 r
F
0 g
.46639 1.05333 m
.47142 1.05738 L
s
.45999 1.05077 m
.46639 1.05333 L
s
.52064 .7823 m
.52065 .78244 L
s
.52065 .78244 m
.5207 .78434 L
s
.5207 .78434 m
.52075 .78593 L
s
.52075 .78593 m
.52096 .79334 L
s
.3173 .93737 m
.3173 .93738 L
s
.24414 .67928 m .23278 .67958 L .23501 .68714 L 0 1 .484 r
F
0 g
.23131 .69499 m
.23501 .68714 L
s
.54647 .6897 m
.54986 .6692 L
s
.37822 .60013 m .36898 .60554 L .37273 .60529 L 0 1 .445 r
F
.37822 .60013 m .36901 .60094 L .36898 .60554 L F
0 g
.37273 .60529 m
.3733 .61031 L
s
.37822 .60013 m .37281 .59456 L .36901 .60094 L 0 1 .445 r
F
.37822 .60013 m .37831 .58939 L .37281 .59456 L F
.37822 .60013 m .38184 .58887 L .37831 .58939 L F
.37822 .60013 m .3818 .59347 L .38184 .58887 L F
0 g
.37822 .60013 m
.37835 .60482 L
s
.37273 .60529 m
.37822 .60013 L
s
.36318 .94782 m .34852 .94208 L .34986 .94612 L 0 1 .534 r
F
0 g
.53847 .97424 m
.53875 .9738 L
s
.53884 .97366 m
.53886 .97363 L
s
.53897 .97346 m
.53906 .97332 L
s
.50161 .61283 m .50495 .60867 L .50721 .6064 L 0 0 0 r
F
0 g
.50495 .60867 m
.50588 .60756 L
s
.48269 .63945 m .47686 .64234 L .47907 .6421 L 0 1 .261 r
F
0 g
.47979 .64368 m
.48237 .64205 L
s
.48269 .63945 m .4775 .64003 L .47686 .64234 L 0 1 .261 r
F
.48269 .63945 m .48057 .63671 L .4775 .64003 L F
.48269 .63945 m .48419 .63406 L .48057 .63671 L F
0 g
.48237 .64205 m
.48269 .63945 L
s
.35144 .93176 m .34871 .93472 L .35214 .9337 L 0 1 .438 r
F
0 g
.35214 .9337 m
.35847 .93389 L
s
.35144 .93176 m .34268 .9341 L .34871 .93472 L 0 1 .438 r
F
0 g
.34871 .93472 m
.35011 .9366 L
s
.44401 .75251 m .43243 .75774 L .43604 .75572 L 0 0 0 r
F
0 g
.43297 .75694 m
.43604 .75572 L
s
.43056 .75801 m
.43297 .75694 L
s
.50792 .87854 m .50175 .88273 L .50374 .88041 L 0 0 0 r
F
0 g
.50075 .88283 m
.50374 .88041 L
s
.20701 .78483 m .20002 .78964 L .20452 .78935 L 0 1 .538 r
F
.20701 .78483 m .1957 .7853 L .20002 .78964 L F
0 g
.19858 .79433 m
.20002 .78964 L
s
.20452 .78935 m
.20975 .79336 L
s
.43223 .96328 m
.43794 .96386 L
s
.41125 .71097 m
.41516 .70789 L
s
.4748 .97049 m .46936 .96922 L .46415 .96935 L 0 1 .519 r
F
.44283 .50541 m .4489 .49751 L .4522 .49298 L 0 .867 .14 r
F
0 g
.4489 .49751 m
.45298 .49231 L
s
.53383 .96453 m
.5341 .96496 L
s
.79352 .83506 m .80187 .84431 L .80452 .83344 L 0 1 .48 r
F
0 g
.79666 .85284 m
.80187 .84431 L
s
.80187 .84431 m
.80312 .85216 L
s
.32169 .73466 m .31401 .73912 L .31827 .73878 L 0 1 .528 r
F
0 g
.31827 .73878 m
.32185 .74247 L
s
.49366 .72397 m .48623 .7345 L .49026 .72835 L 0 .034 .069 r
F
.49366 .72397 m .48378 .73962 L .48623 .7345 L F
.49366 .72397 m .48456 .74028 L .48378 .73962 L F
.49366 .72397 m .48798 .73587 L .48456 .74028 L F
.49366 .72397 m .49175 .72936 L .48798 .73587 L F
0 g
.49231 .72461 m
.49294 .72346 L
s
.48901 .72718 m
.49025 .72572 L
s
.49025 .72572 m
.49129 .72451 L
s
.48901 .72718 m
.48957 .72627 L
s
.48957 .72627 m
.49092 .7241 L
s
.49366 .72397 m .49418 .72427 L .49175 .72936 L 0 .034 .069 r
F
0 g
.49366 .72397 m
.49522 .72033 L
s
.49418 .72427 m
.49738 .71841 L
s
.516 .92226 m .51968 .93415 L .51942 .92989 L 0 .329 .341 r
F
.5267 .93717 m .51968 .93415 L .52343 .94194 L 0 .278 .313 r
F
0 g
.52008 .9402 m
.52343 .94194 L
s
.5267 .93717 m .51942 .92989 L .51968 .93415 L 0 .278 .313 r
F
0 g
.51631 .93281 m
.51968 .93415 L
s
.51968 .93415 m
.52343 .94194 L
s
.37611 .97807 m .361 .96778 L .36296 .97381 L 0 1 .477 r
F
0 g
.35626 .96934 m
.36296 .97381 L
s
.67413 .93429 m .68269 .93108 L .68377 .92881 L 0 1 .331 r
F
.44839 .96252 m .44881 .96654 L .45072 .96513 L 0 1 .531 r
F
.46134 .96701 m .45072 .96513 L .44881 .96654 L 0 1 .527 r
F
0 g
.44881 .96654 m
.45164 .96889 L
s
.44334 .966 m
.44881 .96654 L
s
.77118 1.06139 m .76359 1.06617 L .77219 1.06344 L 0 .926 .262 r
F
.77118 1.06139 m .76016 1.06641 L .76359 1.06617 L F
0 g
.75936 1.06798 m
.76359 1.06617 L
s
.49945 1.06711 m .49083 1.06685 L .49868 1.06999 L 0 .855 .454 r
F
.49945 1.06711 m .48539 1.06354 L .49083 1.06685 L F
0 g
.48449 1.06559 m
.49083 1.06685 L
s
.78253 .83711 m .78588 .85426 L .791 .84575 L 0 1 .475 r
F
.78253 .83711 m .78157 .85494 L .78588 .85426 L F
0 g
.78588 .85426 m
.78632 .86103 L
s
.35364 .73191 m .34329 .72836 L .34299 .73299 L 0 1 .524 r
F
.35364 .73191 m .3467 .72468 L .34329 .72836 L F
.35364 .73191 m .35095 .72442 L .3467 .72468 L F
.35364 .73191 m .35393 .72752 L .35095 .72442 L F
0 g
.35023 .73557 m
.35364 .73191 L
s
.35364 .73191 m
.35662 .73475 L
s
.57609 .44017 m
.57932 .44288 L
s
.68114 .61674 m
.68114 .61674 L
s
.68177 .61347 m
.68205 .61198 L
s
.32169 .73466 m .31104 .73529 L .31401 .73912 L 0 1 .528 r
F
0 g
.31123 .74352 m
.31401 .73912 L
s
.64338 .57467 m
.64412 .57894 L
s
.63974 .55367 m
.64044 .55771 L
s
.64172 .56508 m
.64338 .57467 L
s
.64044 .55771 m
.64172 .56508 L
s
.63943 .55189 m
.63974 .55367 L
s
.64502 .58409 m
.64506 .5843 L
s
.64412 .57894 m
.64502 .58409 L
s
.64506 .5843 m
.64591 .58923 L
s
.63943 .55189 m
.63977 .55477 L
s
.63977 .55477 m
.64054 .56108 L
s
.64054 .56108 m
.64066 .56208 L
s
.72555 .90886 m .72561 .91468 L .73179 .91383 L 0 1 .464 r
F
.72555 .90886 m .72157 .91338 L .72561 .91468 L F
0 g
.72481 .91747 m
.72561 .91468 L
s
.22704 .92897 m .2111 .91697 L .21167 .92311 L 0 1 .535 r
F
.22704 .92897 m .21539 .91643 L .2111 .91697 L F
.22704 .92897 m .22222 .92158 L .21539 .91643 L F
.23741 .92723 m .22222 .92158 L .22704 .92897 L 0 1 .534 r
F
0 g
.22704 .92897 m
.22757 .93506 L
s
.22704 .92897 m
.2337 .93392 L
s
.51704 .70916 m .51799 .70716 L .51954 .71385 L 0 .238 .133 r
F
0 g
.51785 .70054 m
.51799 .70716 L
s
.51938 .70387 m
.51954 .71385 L
s
.78869 .65855 m
.79054 .65541 L
s
.39073 .99469 m .38472 .98815 L .37806 .98409 L 0 1 .481 r
F
.39731 .99179 m .39073 .99469 L .39713 .9987 L 0 1 .476 r
F
.39731 .99179 m .38472 .98815 L .39073 .99469 L F
0 g
.39073 .99469 m
.39334 1.00051 L
s
.39908 .71629 m .38758 .71801 L .39045 .72016 L 0 1 .51 r
F
0 g
.38679 .72349 m
.39045 .72016 L
s
.64102 .5651 m
.64117 .56637 L
s
.64073 .56272 m
.64102 .5651 L
s
.64066 .56208 m
.64073 .56272 L
s
.64257 .57805 m
.64361 .58668 L
s
.64252 .57759 m
.64257 .57805 L
s
.64204 .57365 m
.64252 .57759 L
s
.64117 .56637 m
.64204 .57365 L
s
.36062 .61775 m .35136 .62293 L .3553 .62291 L 0 1 .465 r
F
0 g
.3553 .62291 m
.35638 .62837 L
s
.50686 .48658 m .51862 .46976 L .51877 .47034 L 0 0 0 r
F
.50686 .48658 m .51353 .47671 L .51862 .46976 L F
0 g
.51862 .46976 m
.52347 .4616 L
s
.51353 .47671 m
.5184 .46902 L
s
.51353 .47671 m
.51862 .46976 L
s
.3818 .59347 m
.38712 .58802 L
s
.51498 .79822 m
.51591 .80755 L
s
.21832 .78436 m .21128 .78892 L .21579 .78863 L 0 1 .536 r
F
.21832 .78436 m .20701 .78483 L .21128 .78892 L F
0 g
.20975 .79336 m
.21128 .78892 L
s
.21579 .78863 m
.22093 .7924 L
s
.41429 .92168 m .41202 .9237 L .41503 .92246 L 0 .875 .253 r
F
.41429 .92168 m .40652 .92464 L .41202 .9237 L F
0 g
.41202 .9237 m
.41334 .92436 L
s
.53608 .76362 m
.53663 .76746 L
s
.54116 .57649 m .54011 .58911 L .53895 .58433 L 0 .215 .104 r
F
.54116 .57649 m .54444 .58992 L .54011 .58911 L F
.54116 .57649 m .54903 .58622 L .54444 .58992 L F
.54116 .57649 m .55122 .57835 L .54903 .58622 L F
0 g
.53721 .57764 m
.54116 .57649 L
s
.45414 .74785 m
.4546 .74753 L
s
.4546 .74753 m
.45546 .74694 L
s
.45806 .74563 m
.45886 .74522 L
s
.45802 .74565 m
.45806 .74563 L
s
.45693 .7462 m
.45802 .74565 L
s
.45546 .74694 m
.45693 .7462 L
s
.51411 .80701 m .51268 .8043 L .51146 .81049 L 0 .431 .3 r
F
0 g
.51177 .79222 m
.51268 .8043 L
s
.52152 .78218 m
.52161 .78286 L
s
.52161 .78286 m
.52187 .78463 L
s
.52187 .78463 m
.52208 .78611 L
s
.52208 .78611 m
.5221 .78624 L
s
.5221 .78624 m
.52259 .7896 L
s
.25549 .67895 m .24569 .66924 L .24414 .67928 L 0 1 .481 r
F
.25549 .67895 m .25024 .66173 L .24569 .66924 L F
.25549 .67895 m .25475 .66179 L .25024 .66173 L F
.25549 .67895 m .25699 .66918 L .25475 .66179 L F
0 g
.25095 .68642 m
.25549 .67895 L
s
.25549 .67895 m
.25777 .68609 L
s
.30727 .65562 m .29359 .65546 L .29599 .66202 L 0 1 .472 r
F
0 g
.29083 .66877 m
.29599 .66202 L
s
.70942 .90943 m
.70983 .90943 L
s
.70799 .90942 m
.70942 .90943 L
s
.70554 .9094 m
.70799 .90942 L
s
.39908 .71629 m .38838 .71439 L .38758 .71801 L 0 1 .51 r
F
0 g
.38758 .71801 m
.39045 .72016 L
s
.39908 .71629 m .3924 .71127 L .38838 .71439 L 0 1 .51 r
F
.39908 .71629 m .39695 .71071 L .3924 .71127 L F
.39908 .71629 m .39982 .71287 L .39695 .71071 L F
0 g
.39908 .71629 m
.402 .71818 L
s
.39507 .71941 m
.39908 .71629 L
s
.50706 .88285 m .50918 .89626 L .50939 .89088 L 0 .398 .338 r
F
0 g
.50619 .89609 m
.50918 .89626 L
s
.50918 .89626 m
.51188 .90455 L
s
.5391 .97369 m
.53935 .97368 L
s
.53935 .97368 m
.53937 .97368 L
s
.35477 .96303 m .33975 .95176 L .34126 .95808 L 0 1 .477 r
F
0 g
.33381 .9534 m
.34126 .95808 L
s
.50355 .97176 m .50713 .97387 L .50732 .97293 L 0 1 .441 r
F
.51664 .9728 m .50732 .97293 L .50713 .97387 L 0 .992 .369 r
F
0 g
.50713 .97387 m
.51125 .9746 L
s
.50274 .97426 m
.50713 .97387 L
s
.36062 .61775 m .35091 .61781 L .35136 .62293 L 0 1 .465 r
F
.36062 .61775 m .35425 .61096 L .35091 .61781 L F
.36062 .61775 m .35959 .60578 L .35425 .61096 L F
.36062 .61775 m .36335 .60574 L .35959 .60578 L F
.36062 .61775 m .36379 .61088 L .36335 .60574 L F
0 g
.36062 .61775 m
.36121 .62276 L
s
.3553 .62291 m
.36062 .61775 L
s
.61201 .8167 m
.61267 .83508 L
s
.60828 .71252 m
.60844 .71687 L
s
.60649 .66256 m
.60649 .66256 L
s
.60844 .71687 m
.60844 .71687 L
s
.60889 .72966 m
.60983 .75566 L
s
.60844 .71687 m
.60889 .72966 L
s
.60983 .75566 m
.61103 .78942 L
s
.61103 .78942 m
.61201 .8167 L
s
.60604 .65349 m
.60604 .65349 L
s
.31104 .73529 m .30336 .7399 L .30762 .7396 L 0 1 .528 r
F
0 g
.30762 .7396 m
.31123 .74352 L
s
.46239 .66616 m .45586 .6676 L .45934 .66716 L 0 1 .432 r
F
.46239 .66616 m .45379 .66724 L .45586 .6676 L F
.46239 .66616 m .4545 .66632 L .45379 .66724 L F
0 g
.45933 .66716 m
.46058 .66894 L
s
.46239 .66616 m .45757 .66533 L .4545 .66632 L 0 1 .432 r
F
.46239 .66616 m .46094 .66492 L .45757 .66533 L F
.46239 .66616 m .463 .66528 L .46094 .66492 L F
0 g
.46239 .66616 m
.46453 .66657 L
s
.45934 .66716 m
.46239 .66616 L
s
.463 .66528 m
.46598 .66439 L
s
.44839 .96252 m .4356 .96125 L .43794 .96386 L 0 1 .531 r
F
.7906 .60739 m .7993 .60247 L .80385 .60437 L 0 .041 0 r
F
.7906 .60739 m .79364 .60376 L .7993 .60247 L F
0 g
.79727 .59968 m
.7993 .60247 L
s
.47638 .64741 m .47886 .64427 L .47907 .6421 L 0 1 .327 r
F
0 g
.47886 .64427 m
.47979 .64368 L
s
.7353 .89102 m .7456 .88349 L .74145 .88455 L 0 1 .487 r
F
.74369 .87027 m .7456 .88349 L .75113 .87601 L 0 1 .474 r
F
.74369 .87027 m .74145 .88455 L .7456 .88349 L F
0 g
.74553 .8886 m
.7456 .88349 L
s
.81551 .83217 m .82651 .8312 L .82537 .82308 L 0 1 .488 r
F
.51411 .80701 m .51146 .81049 L .51125 .82147 L 0 .431 .3 r
F
0 g
.51055 .80012 m
.51146 .81049 L
s
.51146 .81049 m
.51268 .8043 L
s
.5088 .84901 m .50509 .86246 L .50793 .86738 L 0 .407 .318 r
F
0 g
.50347 .85354 m
.50509 .86246 L
s
.50245 .86322 m
.50509 .86246 L
s
.39131 .95178 m .37716 .94744 L .3787 .95102 L 0 1 .535 r
F
0 g
.37241 .94906 m
.3787 .95102 L
s
.4778 .96728 m .4748 .97049 L .47968 .97049 L 0 1 .506 r
F
.4778 .96728 m .46936 .96922 L .4748 .97049 L F
0 g
.4748 .97049 m
.47808 .9725 L
s
.50216 .71884 m
.50222 .71858 L
s
.5017 .7211 m
.50216 .71884 L
s
.50118 .7237 m
.5017 .7211 L
s
.50206 .71901 m
.50222 .71858 L
s
.50077 .72242 m
.50206 .71901 L
s
.49066 .89069 m .48231 .89568 L .48387 .89433 L 0 0 0 r
F
0 g
.47995 .89682 m
.48387 .89433 L
s
.36318 .94782 m .35195 .94112 L .34852 .94208 L 0 1 .534 r
F
0 g
.34337 .94353 m
.34603 .94459 L
s
.34603 .94459 m
.34986 .94612 L
s
.36318 .94782 m .35824 .94359 L .35195 .94112 L 0 1 .534 r
F
.37129 .9452 m .35824 .94359 L .36318 .94782 L F
0 g
.36318 .94782 m
.36924 .95017 L
s
.36318 .94782 m
.3645 .95185 L
s
.23278 .67958 m .22362 .68762 L .22817 .68743 L 0 1 .486 r
F
0 g
.22817 .68743 m
.23131 .69499 L
s
.44401 .75251 m .43224 .7583 L .43243 .75774 L 0 0 0 r
F
.44401 .75251 m .43559 .75723 L .43224 .7583 L F
.44401 .75251 m .44024 .75524 L .43559 .75723 L F
0 g
.4336 .75709 m
.43604 .75572 L
s
.44401 .75251 m .44385 .75322 L .44024 .75524 L 0 0 0 r
F
0 g
.44401 .75251 m
.44494 .75187 L
s
.44118 .75341 m
.44401 .75251 L
s
.29031 .93566 m .27474 .92647 L .27542 .93166 L 0 1 .534 r
F
.29031 .93566 m .27886 .92575 L .27474 .92647 L F
.29031 .93566 m .28554 .92969 L .27886 .92575 L F
.30022 .93352 m .28554 .92969 L .29031 .93566 L 0 1 .533 r
F
0 g
.29031 .93566 m
.29056 .93761 L
s
.29031 .93566 m
.29284 .93713 L
s
.38784 .92689 m .38541 .92926 L .38858 .92814 L 0 1 .34 r
F
.38784 .92689 m .3797 .92952 L .38541 .92926 L F
0 g
.38541 .92926 m
.38675 .93043 L
s
.72506 .89411 m .7353 .89102 L .73522 .88636 L 0 1 .478 r
F
.81958 .79179 m .82906 .79828 L .83112 .79658 L 0 .467 .245 r
F
0 g
.82411 .79788 m
.82906 .79828 L
s
.51664 .9728 m .52101 .97418 L .52076 .97353 L 0 .992 .369 r
F
0 g
.52101 .97418 m
.52197 .97425 L
s
.51693 .97464 m
.52101 .97418 L
s
.31104 .73529 m .30039 .73582 L .30336 .7399 L 0 1 .528 r
F
0 g
.30061 .74447 m
.30336 .7399 L
s
.3338 .94155 m .31699 .93476 L .31723 .93948 L 0 1 .533 r
F
0 g
.31052 .93623 m
.31055 .93623 L
s
.30727 .65562 m .29591 .64664 L .29359 .65546 L 0 1 .472 r
F
.30727 .65562 m .30169 .64026 L .29591 .64664 L F
0 g
.29359 .65546 m
.29599 .66202 L
s
.30727 .65562 m .30707 .64059 L .30169 .64026 L 0 1 .472 r
F
.30727 .65562 m .30946 .64718 L .30707 .64059 L F
0 g
.3015 .66197 m
.30727 .65562 L
s
.22964 .78389 m .22254 .7882 L .22705 .78791 L 0 1 .534 r
F
.22964 .78389 m .21832 .78436 L .22254 .7882 L F
0 g
.22093 .7924 m
.22254 .7882 L
s
.22705 .78791 m
.23212 .79143 L
s
.50706 .88285 m
.50939 .89088 L
s
.50706 .88285 m
.5097 .88211 L
s
.40652 .92464 m .39335 .9265 L .39446 .92746 L 0 1 .301 r
F
0 g
.38858 .92814 m
.39446 .92746 L
s
.42485 .7011 m
.42891 .69819 L
s
.50951 .71521 m
.50975 .71385 L
s
.51819 .92714 m
.51909 .92916 L
s
.51569 .91022 m .516 .92226 L .51902 .92303 L 0 .321 .332 r
F
0 g
.516 .92226 m
.51819 .92714 L
s
.43243 .75774 m .42448 .76045 L .4291 .75867 L 0 0 0 r
F
0 g
.4291 .75867 m
.43056 .75801 L
s
.48129 .61233 m .48677 .59066 L .48549 .58413 L 0 1 .299 r
F
.48129 .61233 m .48497 .60274 L .48677 .59066 L F
0 g
.48677 .59066 m
.49056 .58775 L
s
.46505 .66242 m .45757 .66533 L .46094 .66492 L 0 1 .41 r
F
.46505 .66242 m .45689 .66339 L .45757 .66533 L F
0 g
.46094 .66492 m
.463 .66528 L
s
.46505 .66242 m .45936 .66039 L .45689 .66339 L 0 1 .41 r
F
.46505 .66242 m .46347 .65789 L .45936 .66039 L F
.46505 .66242 m .46649 .65755 L .46347 .65789 L F
.46505 .66242 m .46716 .65949 L .46649 .65755 L F
0 g
.46505 .66242 m
.46598 .66439 L
s
.46094 .66492 m
.46505 .66242 L
s
.46716 .65949 m
.471 .6572 L
s
.47638 .64741 m .46993 .65025 L .47255 .64997 L 0 1 .327 r
F
0 g
.47377 .65143 m
.47648 .64978 L
s
.47638 .64741 m .47013 .64808 L .46993 .65025 L 0 1 .327 r
F
.47638 .64741 m .47303 .6449 L .47013 .64808 L F
.47638 .64741 m .47686 .64234 L .47303 .6449 L F
.47638 .64741 m .47907 .6421 L .47686 .64234 L F
0 g
.47638 .64741 m
.47648 .64978 L
s
.47907 .6421 m
.48269 .63945 L
s
.47886 .64427 m
.47907 .6421 L
s
.48199 .54978 m .49049 .52943 L .4897 .52708 L 0 1 .25 r
F
.48199 .54978 m .48719 .53915 L .49049 .52943 L F
0 g
.49049 .52943 m
.49504 .52251 L
s
.4891 .53352 m
.49049 .52943 L
s
.48719 .53915 m
.4891 .53352 L
s
.69373 .91851 m .68953 .9238 L .68902 .9269 L 0 1 .421 r
F
0 g
.68269 .93108 m
.68902 .9269 L
s
.62356 .44483 m
.63083 .45297 L
s
.61963 .44703 m
.62356 .44483 L
s
.49945 1.06711 m .49868 1.06999 L .50471 1.07152 L 0 .855 .454 r
F
0 g
.49868 1.06999 m
.50444 1.07342 L
s
.81014 .91297 m .80991 .92232 L .81643 .91911 L 0 1 .522 r
F
.81014 .91297 m .80571 .92163 L .80991 .92232 L F
0 g
.80874 .92647 m
.80991 .92232 L
s
.45792 .74604 m
.45886 .74522 L
s
.45611 .74761 m
.45792 .74604 L
s
.47138 .47206 m .47833 .46482 L .48294 .46138 L 0 0 0 r
F
0 g
.47833 .46482 m
.48258 .45924 L
s
.49056 .96995 m .49331 .97268 L .49394 .97153 L 0 1 .483 r
F
.50355 .97176 m .49394 .97153 L .49331 .97268 L 0 1 .441 r
F
0 g
.49331 .97268 m
.49708 .97385 L
s
.48865 .97291 m
.49331 .97268 L
s
.49896 .67829 m .499 .63229 L .49617 .64013 L 0 1 .285 r
F
.49896 .67829 m .50171 .63893 L .499 .63229 L F
0 g
.499 .63229 m
.50053 .61663 L
s
.58769 .43621 m .59536 .43445 L .60261 .43617 L 0 .217 .062 r
F
0 g
.59536 .43445 m
.59959 .42936 L
s
.67469 .57765 m .67775 .56351 L .67405 .56057 L 0 .565 .304 r
F
0 g
.67405 .56057 m
.6742 .56467 L
s
.67325 .55821 m
.67405 .56057 L
s
.44522 1.03523 m .43836 1.02999 L .43187 1.02703 L 0 .91 .483 r
F
.39731 .99179 m .39713 .9987 L .39967 .99752 L 0 1 .476 r
F
.4123 1.00727 m .39967 .99752 L .39713 .9987 L 0 .973 .48 r
F
0 g
.39713 .9987 m
.4001 1.00421 L
s
.39073 .99469 m
.39713 .9987 L
s
.30038 .73582 m .29037 .74073 L .29596 .74039 L 0 1 .528 r
F
0 g
.29596 .74039 m
.30061 .74447 L
s
.5341 .96496 m
.53427 .9647 L
s
.34299 .73299 m .33264 .729 L .33235 .7339 L 0 1 .526 r
F
.34299 .73299 m .33606 .72518 L .33264 .729 L F
.34299 .73299 m .34031 .72501 L .33606 .72518 L F
.34299 .73299 m .34329 .72836 L .34031 .72501 L F
0 g
.33958 .73679 m
.34299 .73299 L
s
.34299 .73299 m
.34597 .73608 L
s
.71246 .89898 m .7147 .90787 L .72122 .90129 L 0 1 .461 r
F
0 g
.7147 .90787 m
.72122 .90129 L
s
.7147 .90787 m
.7148 .91113 L
s
.47048 .65504 m .47279 .65203 L .47255 .64997 L 0 1 .376 r
F
0 g
.47279 .65203 m
.47377 .65143 L
s
.72555 .90886 m .72154 .91089 L .72157 .91338 L 0 1 .464 r
F
0 g
.72154 .91089 m
.72157 .91338 L
s
.7149 .91398 m
.72157 .91338 L
s
.47048 .65504 m .46347 .65789 L .46649 .65755 L 0 1 .376 r
F
.47048 .65504 m .46323 .65584 L .46347 .65789 L F
0 g
.46649 .65755 m
.46716 .65949 L
s
.47048 .65504 m .46593 .65276 L .46323 .65584 L 0 1 .376 r
F
.47048 .65504 m .46993 .65025 L .46593 .65276 L F
.47048 .65504 m .47255 .64997 L .46993 .65025 L F
0 g
.46649 .65755 m
.47048 .65504 L
s
.47048 .65504 m
.471 .6572 L
s
.47255 .64997 m
.47638 .64741 L
s
.47255 .64997 m
.47279 .65203 L
s
.23278 .67958 m .22142 .67986 L .22362 .68762 L 0 1 .486 r
F
0 g
.21992 .69566 m
.22362 .68762 L
s
.24095 .78342 m .23381 .78747 L .23832 .78718 L 0 1 .531 r
F
.24095 .78342 m .22964 .78389 L .23381 .78747 L F
0 g
.23212 .79143 m
.23381 .78747 L
s
.23832 .78718 m
.2433 .79045 L
s
.50378 .71925 m
.50397 .71801 L
s
.50341 .72173 m
.50378 .71925 L
s
.5031 .72378 m
.50341 .72173 L
s
.50339 .7198 m
.50397 .71801 L
s
.50232 .72308 m
.50339 .7198 L
s
.33367 .63582 m .32443 .64135 L .32852 .64143 L 0 1 .472 r
F
0 g
.32852 .64143 m
.33008 .64745 L
s
.46282 1.04746 m .4557 1.04272 L .4493 1.04016 L 0 .881 .479 r
F
0 g
.34642 .62851 m
.35136 .62293 L
s
.39731 .99179 m .38235 .98242 L .38472 .98815 L 0 1 .476 r
F
0 g
.37806 .98409 m
.38472 .98815 L
s
.78253 .83711 m .78013 .8476 L .78157 .85494 L 0 1 .475 r
F
0 g
.77567 .86256 m
.78157 .85494 L
s
.50603 .44677 m .51358 .44142 L .51934 .44038 L 0 .036 .06 r
F
0 g
.51358 .44142 m
.51911 .43405 L
s
.70583 1.07261 m .71777 1.07214 L .71462 1.07221 L 0 .689 .241 r
F
.69819 1.07263 m .70583 1.07261 L .70989 1.07238 L 0 .63 .226 r
F
.50967 .82693 m .50643 .84462 L .5088 .84901 L 0 .43 .311 r
F
0 g
.50415 .84657 m
.50643 .84462 L
s
.50517 .83506 m
.50643 .84462 L
s
.51133 .71017 m .51089 .65006 L .50932 .67135 L 0 .89 .272 r
F
0 g
.50884 .63958 m
.51089 .65006 L
s
.30038 .73582 m .2864 .7364 L .29037 .74073 L 0 1 .528 r
F
0 g
.28667 .74562 m
.29037 .74073 L
s
.50775 .71582 m
.50776 .7157 L
s
.50639 .72177 m
.50649 .72132 L
s
.50771 .71589 m
.50776 .7157 L
s
.48129 .61233 m .48549 .58413 L .48143 .58671 L 0 1 .299 r
F
0 g
.48619 .60253 m
.48867 .6021 L
s
.48525 .60085 m
.48677 .59066 L
s
.48549 .58413 m
.48773 .57107 L
s
.51704 .70916 m .51747 .73028 L .51682 .71905 L 0 .238 .133 r
F
.51704 .70916 m .51903 .73706 L .51747 .73028 L F
0 g
.51585 .70485 m
.51704 .70916 L
s
.51799 .70716 m
.51954 .71385 L
s
.47011 .73932 m
.47071 .73892 L
s
.46717 .74128 m
.47011 .73932 L
s
.4778 .96728 m .4664 .96728 L .46936 .96922 L 0 1 .506 r
F
0 g
.46415 .96935 m
.46936 .96922 L
s
.3338 .94155 m .32179 .93368 L .31699 .93476 L 0 1 .533 r
F
0 g
.31079 .9364 m
.31257 .93726 L
s
.3338 .94155 m .329 .9366 L .32179 .93368 L 0 1 .533 r
F
0 g
.3338 .94155 m
.33402 .94626 L
s
.34254 .93923 m .329 .9366 L .3338 .94155 L 0 1 .533 r
F
0 g
.3338 .94155 m
.33995 .94452 L
s
.7276 .61288 m .73657 .59127 L .74097 .59363 L 0 .266 .093 r
F
.7276 .61288 m .73086 .59948 L .73657 .59127 L F
0 g
.73501 .58104 m
.73657 .59127 L
s
.43243 .75774 m .42084 .76207 L .42448 .76045 L 0 0 0 r
F
0 g
.42148 .76156 m
.42448 .76045 L
s
.41865 .76254 m
.42148 .76156 L
s
.43193 .91737 m .41956 .92067 L .4206 .9211 L 0 .847 .238 r
F
0 g
.41503 .92246 m
.4206 .9211 L
s
.31015 .93143 m .30655 .93714 L .31045 .93624 L 0 1 .532 r
F
.31015 .93143 m .30022 .93352 L .30655 .93714 L F
0 g
.3007 .9385 m
.3007 .93851 L
s
.31009 .93353 m .30655 .93714 L .31045 .93624 L 0 1 .49 r
F
.31009 .93353 m .30015 .93558 L .30655 .93714 L F
0 g
.30068 .93833 m
.3007 .93851 L
s
.31002 .93564 m .30655 .93714 L .31045 .93624 L 0 .718 .223 r
F
0 g
.31045 .93624 m
.31064 .93627 L
s
.31045 .93624 m
.31079 .9364 L
s
.31045 .93624 m
.31052 .93623 L
s
.31002 .93564 m .30008 .93765 L .30655 .93714 L 0 .718 .223 r
F
0 g
.30655 .93714 m
.30767 .94189 L
s
.3063 .93716 m
.30655 .93714 L
s
.30068 .93832 m
.30068 .93833 L
s
.30043 .93565 m
.30061 .93754 L
s
.30061 .93761 m
.30068 .93832 L
s
.30066 .9383 m
.3007 .9385 L
s
.30053 .93761 m
.30066 .9383 L
s
.52305 .78695 m
.52326 .79086 L
s
.55823 .81065 m
.55868 .80924 L
s
.55868 .80924 m
.55893 .80844 L
s
.38758 .71801 m .37921 .72174 L .38365 .72116 L 0 1 .517 r
F
0 g
.38365 .72116 m
.38678 .72349 L
s
.48096 1.05822 m .48539 1.06354 L .48599 1.06227 L 0 .86 .471 r
F
.49945 1.06711 m .48599 1.06227 L .48539 1.06354 L 0 .855 .454 r
F
0 g
.48539 1.06354 m
.49083 1.06685 L
s
.47915 1.06144 m
.48539 1.06354 L
s
.50553 .72011 m
.50582 .71707 L
s
.50533 .7222 m
.50553 .72011 L
s
.50562 .71781 m
.50582 .71707 L
s
.50474 .721 m
.50562 .71781 L
s
.50412 .72329 m
.50474 .721 L
s
.72586 1.07068 m .71777 1.07214 L .72617 1.07104 L 0 .685 .221 r
F
.72586 1.07068 m .71462 1.07221 L .71777 1.07214 L F
0 g
.72248 1.07208 m
.723 1.07194 L
s
.71344 1.07275 m
.71777 1.07214 L
s
.78486 .77332 m .79431 .77799 L .78964 .77533 L 0 .269 .203 r
F
.78486 .77332 m .79646 .78028 L .79431 .77799 L F
.22668 .93692 m .21118 .93332 L .21631 .93852 L 0 1 .528 r
F
0 g
.21631 .93852 m
.22321 .94186 L
s
.48848 .62394 m
.48994 .61083 L
s
.51941 1.07567 m
.52451 1.07741 L
s
.51917 1.07559 m
.51941 1.07567 L
s
.52451 1.07741 m
.52538 1.07728 L
s
.52538 1.07728 m
.52602 1.07719 L
s
.52602 1.07719 m
.52859 1.0768 L
s
.44283 .50541 m .43461 .5142 L .4367 .51257 L 0 .867 .14 r
F
0 g
.43804 .51226 m
.43984 .51009 L
s
.44283 .50541 m .4379 .50967 L .43461 .5142 L 0 .867 .14 r
F
.44283 .50541 m .44439 .502 L .4379 .50967 L F
.44283 .50541 m .45052 .49485 L .44439 .502 L F
.44283 .50541 m .4522 .49298 L .45052 .49485 L F
0 g
.4489 .49751 m
.45216 .49303 L
s
.43984 .51009 m
.44283 .50541 L
s
.40652 .92464 m .39653 .92544 L .39335 .9265 L 0 1 .301 r
F
.40652 .92464 m .40218 .92464 L .39653 .92544 L F
0 g
.40652 .92464 m
.40761 .92559 L
s
.41429 .92168 m .40218 .92464 L .40652 .92464 L 0 .875 .253 r
F
0 g
.40652 .92464 m
.41202 .9237 L
s
.77768 .92042 m .78888 .91879 L .78467 .91806 L 0 1 .521 r
F
0 g
.78806 .92248 m
.79461 .92008 L
s
.7673 .9183 m .77768 .92042 L .77834 .91696 L 0 1 .515 r
F
.50161 .61283 m .49765 .61747 L .49847 .61661 L 0 0 0 r
F
.50161 .61283 m .49991 .6152 L .49765 .61747 L F
0 g
.49766 .61779 m
.49971 .61579 L
s
.50161 .61283 m .50375 .6113 L .49991 .6152 L 0 0 0 r
F
0 g
.49971 .61579 m
.50043 .61467 L
s
.50161 .61283 m .50687 .60753 L .50375 .6113 L 0 0 0 r
F
.50161 .61283 m .50721 .6064 L .50687 .60753 L F
0 g
.50495 .60867 m
.50721 .6064 L
s
.50721 .6064 m
.50999 .60203 L
s
.51914 .59382 m .52632 .58739 L .52698 .5904 L 0 0 .049 r
F
0 g
.52632 .58739 m
.52865 .5807 L
s
.52296 .58885 m
.52632 .58739 L
s
.55804 .80961 m
.55805 .80957 L
s
.48487 .55883 m .47905 .56055 L .48035 .56425 L 0 1 .258 r
F
.48487 .55883 m .48199 .54979 L .47905 .56055 L F
.48487 .55883 m .48719 .53915 L .48199 .54979 L F
0 g
.48719 .53915 m
.4917 .53378 L
s
.29024 .93768 m .27449 .93313 L .27524 .93629 L 0 1 .508 r
F
.29024 .93768 m .27861 .93246 L .27449 .93313 L F
.29024 .93768 m .28537 .93442 L .27861 .93246 L F
.30015 .93558 m .28537 .93442 L .29024 .93768 L 0 1 .5 r
F
0 g
.29024 .93768 m
.29068 .9396 L
s
.29024 .93768 m
.29448 .93881 L
s
.30068 .93848 m
.30069 .93849 L
s
.30622 .93717 m
.3063 .93716 L
s
.44079 .68741 m .4322 .69079 L .43646 .69009 L 0 1 .473 r
F
.44079 .68741 m .43031 .68908 L .4322 .69079 L F
0 g
.43646 .69009 m
.43875 .69171 L
s
.44079 .68741 m .43204 .6861 L .43031 .68908 L 0 1 .473 r
F
.44079 .68741 m .43637 .68342 L .43204 .6861 L F
.44079 .68741 m .44042 .68283 L .43637 .68342 L F
.44079 .68741 m .44231 .68454 L .44042 .68283 L F
0 g
.44079 .68741 m
.44283 .68896 L
s
.43646 .69009 m
.44079 .68741 L
s
.25821 .92382 m .25419 .93015 L .25829 .9294 L 0 1 .533 r
F
0 g
.25829 .9294 m
.25981 .93032 L
s
.25821 .92382 m .24781 .92552 L .25419 .93015 L 0 1 .533 r
F
0 g
.25419 .93015 m
.25522 .93567 L
s
.25227 .78294 m .24508 .78674 L .24959 .78644 L 0 1 .527 r
F
.25227 .78294 m .24095 .78342 L .24508 .78674 L F
0 g
.2433 .79045 m
.24508 .78674 L
s
.24959 .78644 m
.2545 .78946 L
s
.50939 .89088 m
.51204 .89086 L
s
.49342 .51709 m .48771 .52229 L .48851 .52402 L 0 1 .155 r
F
.49342 .51709 m .49178 .5133 L .48771 .52229 L F
.49342 .51709 m .49799 .50308 L .49178 .5133 L F
.2864 .7364 m .2782 .74144 L .28276 .74118 L 0 1 .528 r
F
0 g
.28276 .74118 m
.28667 .74562 L
s
.5267 .93717 m .52242 .93117 L .51942 .92989 L 0 .278 .313 r
F
0 g
.51909 .92916 m
.51942 .92989 L
s
.42833 1.02179 m .4218 1.0161 L .41527 1.01278 L 0 .942 .482 r
F
.69052 1.0728 m .68999 1.07262 L .69819 1.07263 L 0 .556 .207 r
F
0 g
.68555 1.0725 m
.68999 1.07262 L
s
.51411 .80701 m .51252 .83244 L .51443 .83607 L 0 .431 .3 r
F
0 g
.51412 .80714 m
.51538 .81795 L
s
.51411 .80701 m .51125 .82147 L .51252 .83244 L 0 .431 .3 r
F
0 g
.51411 .80701 m
.51498 .79822 L
s
.51411 .80701 m
.51412 .80714 L
s
.48308 .732 m
.48361 .73146 L
s
.56418 .43671 m
.56481 .43625 L
s
.69052 1.0728 m .68266 1.07228 L .67892 1.07211 L 0 .556 .207 r
F
0 g
.67043 1.07136 m
.67892 1.07211 L
s
.44231 .68454 m
.44647 .6819 L
s
.33365 .94659 m .31699 .93476 L .31717 .94159 L 0 1 .478 r
F
0 g
.31257 .93726 m
.31711 .93942 L
s
.31064 .93627 m
.31081 .9363 L
s
.31081 .9363 m
.31705 .93734 L
s
.31055 .93623 m
.31069 .93621 L
s
.31069 .93621 m
.317 .93532 L
s
.71157 .62114 m
.7123 .6213 L
s
.7123 .6213 m
.71443 .62232 L
s
.5297 .97325 m .53481 .97387 L .53413 .97356 L 0 .751 .269 r
F
.53644 .97334 m .53413 .97356 L .53482 .97387 L 0 .669 .233 r
F
0 g
.26 .9365 m
.26513 .93819 L
s
.81014 .91297 m .8058 .91763 L .80571 .92163 L 0 1 .522 r
F
0 g
.80519 .92183 m
.80571 .92163 L
s
.64854 .47074 m .64999 .47287 L .64627 .46728 L 0 0 .144 r
F
.64854 .47074 m .66538 .49452 L .65819 .48455 L F
.64854 .47074 m .65528 .48092 L .66345 .49257 L F
0 g
.65944 .48765 m
.66497 .4996 L
s
.64757 .46926 m
.64854 .47074 L
s
.50489 .664 m .50171 .63893 L .5025 .65566 L 0 1 .278 r
F
.49896 .67829 m .5025 .65566 L .50171 .63893 L 0 1 .285 r
F
0 g
.499 .63229 m
.50171 .63893 L
s
.50171 .63893 m
.50328 .62022 L
s
.53601 .76862 m
.53622 .76961 L
s
.73602 .9114 m .74203 .91661 L .74646 .91381 L 0 1 .483 r
F
0 g
.73569 .91779 m
.74203 .91661 L
s
.74173 .91958 m
.74203 .91661 L
s
.2864 .7364 m .27501 .73679 L .2782 .74144 L 0 1 .528 r
F
0 g
.27532 .74648 m
.2782 .74144 L
s
.29359 .65546 m .28399 .66205 L .28848 .66205 L 0 1 .476 r
F
0 g
.28848 .66205 m
.29083 .66877 L
s
.54358 .447 m .55832 .4389 L .5533 .44564 L 0 0 .055 r
F
0 g
.55832 .4389 m
.56274 .43777 L
s
.49502 .72466 m .48798 .73587 L .49175 .72936 L 0 .058 .075 r
F
.49502 .72466 m .48582 .74124 L .48798 .73587 L F
.49502 .72466 m .48672 .74186 L .48582 .74124 L F
.49502 .72466 m .49001 .73712 L .48672 .74186 L F
.49502 .72466 m .49348 .73021 L .49001 .73712 L F
0 g
.49376 .72514 m
.49418 .72427 L
s
.49026 .72835 m
.49246 .72551 L
s
.49246 .72551 m
.49366 .72397 L
s
.49026 .72835 m
.49144 .72619 L
s
.49144 .72619 m
.49231 .72461 L
s
.49502 .72466 m .49562 .72488 L .49348 .73021 L 0 .058 .075 r
F
0 g
.49502 .72466 m
.4962 .72154 L
s
.49562 .72488 m
.49748 .72112 L
s
.65155 .61446 m
.65242 .61935 L
s
.65243 .61943 m
.65336 .62468 L
s
.65344 .62513 m
.65357 .62589 L
s
.65384 .6274 m
.65406 .62867 L
s
.65512 .63466 m
.65556 .63717 L
s
.65124 .6127 m
.65155 .61446 L
s
.65124 .6127 m
.65131 .61661 L
s
.41101 .95679 m .40001 .95237 L .39714 .95355 L 0 1 .536 r
F
.41101 .95679 m .40596 .95376 L .40001 .95237 L F
.41763 .95375 m .41101 .95679 L .4167 .95812 L 0 1 .534 r
F
.41763 .95375 m .40596 .95376 L .41101 .95679 L F
0 g
.41101 .95679 m
.41289 .96006 L
s
.54358 .447 m .53914 .4553 L .53852 .45375 L 0 0 .055 r
F
.54358 .447 m .54548 .45181 L .53914 .4553 L F
.54358 .447 m .5533 .44564 L .54548 .45181 L F
.41763 .95375 m .4167 .95812 L .41925 .95686 L 0 1 .534 r
F
.43007 .96036 m .41925 .95686 L .4167 .95812 L 0 1 .535 r
F
0 g
.4167 .95812 m
.41888 .96105 L
s
.41101 .95679 m
.4167 .95812 L
s
.33235 .7339 m .32199 .72948 L .32169 .73466 L 0 1 .527 r
F
.33235 .7339 m .32541 .72551 L .32199 .72948 L F
.33235 .7339 m .32967 .7254 L .32541 .72551 L F
.33235 .7339 m .33264 .729 L .32967 .7254 L F
0 g
.32893 .73786 m
.33235 .7339 L
s
.33235 .7339 m
.33532 .73723 L
s
.45517 .90879 m .45363 .90979 L .45604 .90864 L 0 0 0 r
F
.45517 .90879 m .44887 .91158 L .45363 .90979 L F
.46447 .90482 m .45604 .90864 L .45363 .90979 L 0 .788 .188 r
F
0 g
.45363 .90979 m
.45499 .90945 L
s
.50967 .82693 m .51073 .84553 L .51094 .83649 L 0 .43 .311 r
F
.50967 .82693 m .5088 .84901 L .51073 .84553 L F
0 g
.50967 .82693 m
.51125 .82147 L
s
.24746 .93379 m .24367 .93829 L .24777 .93759 L 0 1 .522 r
F
0 g
.24777 .93759 m
.24962 .93823 L
s
.24746 .93379 m .23706 .93535 L .24367 .93829 L 0 1 .522 r
F
0 g
.24367 .93829 m
.24497 .94208 L
s
.22142 .67986 m .21221 .68808 L .21677 .6879 L 0 1 .489 r
F
0 g
.21677 .6879 m
.21992 .69566 L
s
.52371 .78381 m
.52382 .78448 L
s
.52382 .78448 m
.52386 .78471 L
s
.24414 .67928 m .23437 .66927 L .23278 .67958 L 0 1 .484 r
F
.24414 .67928 m .23896 .66157 L .23437 .66927 L F
.24414 .67928 m .24347 .66163 L .23896 .66157 L F
.24414 .67928 m .24569 .66924 L .24347 .66163 L F
0 g
.23957 .68694 m
.24414 .67928 L
s
.24414 .67928 m
.24639 .68663 L
s
.65528 .48092 m
.66203 .49055 L
s
.66203 .49055 m
.66281 .49166 L
s
.26359 .78245 m .25636 .78599 L .26087 .78569 L 0 1 .521 r
F
.26359 .78245 m .25227 .78294 L .25636 .78599 L F
0 g
.2545 .78946 m
.25636 .78599 L
s
.26087 .78569 m
.2657 .78845 L
s
.76372 .76211 m .76627 .75941 L .77095 .76298 L 0 .116 0 r
F
.76372 .76211 m .76317 .75903 L .76627 .75941 L F
0 g
.76162 .75616 m
.76627 .75941 L
s
.66042 .60397 m
.66077 .60551 L
s
.66042 .60397 m
.66049 .6084 L
s
.47964 .73438 m .47141 .74099 L .47596 .7369 L 0 0 .042 r
F
.47964 .73438 m .46836 .74472 L .47141 .74099 L F
.47964 .73438 m .46885 .7456 L .46836 .74472 L F
.47964 .73438 m .47255 .74307 L .46885 .7456 L F
.47964 .73438 m .47698 .73883 L .47255 .74307 L F
.47964 .73438 m .48001 .73511 L .47698 .73883 L F
0 g
.47964 .73438 m
.48277 .72981 L
s
.47596 .7369 m
.47919 .73327 L
s
.47596 .7369 m
.47964 .73438 L
s
.48001 .73511 m
.48308 .732 L
s
.42084 .76207 m .41293 .76443 L .41755 .76292 L 0 0 0 r
F
0 g
.41755 .76292 m
.41865 .76254 L
s
.74369 .87027 m .75113 .87601 L .75435 .86709 L 0 1 .474 r
F
0 g
.7456 .88349 m
.75113 .87601 L
s
.75113 .87601 m
.75183 .88207 L
s
.53947 .97383 m
.53962 .97406 L
s
.54001 .97464 m
.54021 .97495 L
s
.54021 .97495 m
.5405 .97539 L
s
.53938 .9737 m
.53947 .97383 L
s
.53937 .97368 m
.53938 .9737 L
s
.53913 .97333 m
.53921 .97345 L
s
.44887 .91158 m .43983 .91468 L .43705 .9159 L 0 .828 .216 r
F
.44887 .91158 m .4449 .91282 L .43983 .91468 L F
.45517 .90879 m .4449 .91282 L .44887 .91158 L 0 0 0 r
F
0 g
.44887 .91158 m
.45363 .90979 L
s
.44887 .91158 m
.45003 .91168 L
s
.39872 .94895 m .39714 .95355 L .40001 .95237 L 0 1 .534 r
F
.39872 .94895 m .39131 .95178 L .39714 .95355 L F
0 g
.39714 .95355 m
.39903 .95682 L
s
.27501 .73679 m .26681 .74204 L .27137 .7418 L 0 1 .528 r
F
0 g
.27137 .7418 m
.27532 .74648 L
s
.4778 .96728 m .47968 .97049 L .48076 .96922 L 0 1 .506 r
F
.49056 .96995 m .48076 .96922 L .47968 .97049 L 0 1 .483 r
F
0 g
.47968 .97049 m
.48307 .97207 L
s
.4748 .97049 m
.47968 .97049 L
s
.38758 .71801 m .37652 .71933 L .37921 .72174 L 0 1 .517 r
F
0 g
.37568 .72513 m
.37921 .72174 L
s
.51812 1.07358 m .5105 1.07362 L .5184 1.07532 L 0 .834 .409 r
F
.51812 1.07358 m .50471 1.07152 L .5105 1.07362 L F
0 g
.50444 1.07342 m
.5105 1.07362 L
s
.8158 .6705 m .82311 .66676 L .81852 .66585 L 0 1 .516 r
F
.8158 .6705 m .82729 .67304 L .82311 .66676 L F
.46447 .90482 m .46069 .90651 L .45604 .90864 L 0 .788 .188 r
F
.46978 .9025 m .46447 .90482 L .46881 .90285 L 0 0 0 r
F
.46978 .9025 m .46069 .90651 L .46447 .90482 L F
0 g
.46456 .9048 m
.46581 .90449 L
s
.33367 .63582 m .32354 .63543 L .32443 .64135 L 0 1 .472 r
F
0 g
.31978 .64742 m
.32443 .64135 L
s
.33367 .63582 m .32647 .62761 L .32354 .63543 L 0 1 .472 r
F
.33367 .63582 m .33163 .62198 L .32647 .62761 L F
.33367 .63582 m .33558 .62231 L .33163 .62198 L F
.33367 .63582 m .33645 .62825 L .33558 .62231 L F
0 g
.33367 .63582 m
.33465 .64148 L
s
.32852 .64143 m
.33367 .63582 L
s
.79054 .65541 m
.79557 .66047 L
s
.36379 .61088 m
.36898 .60554 L
s
.41258 .70615 m .40379 .70977 L .40834 .70907 L 0 1 .503 r
F
0 g
.40834 .70907 m
.41125 .71097 L
s
.58769 .43621 m .60261 .43617 L .60463 .44024 L 0 .217 .062 r
F
0 g
.60261 .43617 m
.60657 .43399 L
s
.59536 .43445 m
.60261 .43617 L
s
.74369 .87027 m .74062 .8789 L .74145 .88455 L 0 1 .474 r
F
0 g
.7353 .89102 m
.74145 .88455 L
s
.23671 .94348 m .23316 .94622 L .23725 .94556 L 0 .997 .338 r
F
0 g
.23725 .94556 m
.24478 .94644 L
s
.23671 .94348 m .22632 .9449 L .23316 .94622 L 0 .997 .338 r
F
0 g
.23316 .94622 m
.23472 .94834 L
s
.53644 .97334 m .53909 .97369 L .53827 .9735 L 0 .669 .233 r
F
0 g
.53875 .9738 m
.53909 .97369 L
s
.76501 .86455 m .7751 .85611 L .77079 .85698 L 0 1 .486 r
F
.75435 .86709 m .76501 .86455 L .76432 .85846 L 0 1 .481 r
F
.77118 1.06139 m .7634 1.06437 L .76016 1.06641 L 0 .926 .262 r
F
0 g
.75102 1.06831 m
.76016 1.06641 L
s
.27501 .73679 m .26361 .73714 L .26681 .74204 L 0 1 .528 r
F
0 g
.26397 .74729 m
.26681 .74204 L
s
.52419 .46399 m .53759 .45129 L .53243 .45849 L 0 0 .016 r
F
0 g
.53759 .45129 m
.54358 .447 L
s
.48096 1.05822 m .47365 1.0541 L .4674 1.05201 L 0 .86 .471 r
F
.76835 .59962 m .78237 .59908 L .77947 .60386 L 0 .193 .033 r
F
0 g
.78237 .59908 m
.78793 .59717 L
s
.78111 .59357 m
.78237 .59908 L
s
.51914 .59382 m .51654 .6014 L .51638 .5992 L 0 0 .049 r
F
.51914 .59382 m .51991 .59993 L .51654 .6014 L F
.51914 .59382 m .52424 .59578 L .51991 .59993 L F
.51914 .59382 m .52698 .5904 L .52424 .59578 L F
0 g
.51614 .59643 m
.51914 .59382 L
s
.34268 .9341 m .32815 .93228 L .32907 .93444 L 0 1 .46 r
F
.34268 .9341 m .33182 .93149 L .32815 .93228 L F
.34268 .9341 m .33806 .93227 L .33182 .93149 L F
.35144 .93176 m .33806 .93227 L .34268 .9341 L 0 1 .438 r
F
0 g
.34268 .9341 m
.34871 .93472 L
s
.34268 .9341 m
.34357 .93626 L
s
.54825 1.07634 m .54582 1.07639 L .54447 1.07556 L 0 0 0 r
F
.4988 .88448 m .49552 .88705 L .49222 .88935 L F
.50081 .88491 m .4988 .88448 L .50175 .88273 L F
.50081 .88491 m .49552 .88705 L .4988 .88448 L F
0 g
.4988 .88448 m
.50075 .88283 L
s
.36288 .96056 m .361 .96778 L .36416 .96675 L 0 1 .472 r
F
.36288 .96056 m .35477 .96303 L .361 .96778 L F
.37611 .97807 m .36416 .96675 L .361 .96778 L 0 1 .477 r
F
0 g
.361 .96778 m
.36296 .97381 L
s
.27017 .92852 m
.27542 .93166 L
s
.27492 .78193 m .26764 .78522 L .27215 .7849 L 0 1 .513 r
F
.27492 .78193 m .26359 .78245 L .26764 .78522 L F
0 g
.2657 .78845 m
.26764 .78522 L
s
.27215 .7849 m
.2769 .7874 L
s
.81551 .83217 m .82537 .82308 L .82093 .82352 L 0 1 .488 r
F
.80452 .83344 m .81551 .83217 L .81427 .82427 L 0 1 .484 r
F
.78253 .83711 m .791 .84575 L .79352 .83506 L 0 1 .475 r
F
0 g
.78588 .85426 m
.791 .84575 L
s
.791 .84575 m
.79235 .85336 L
s
.42084 .76207 m .40926 .76566 L .41293 .76443 L 0 0 0 r
F
0 g
.4109 .76511 m
.41293 .76443 L
s
.40999 .7655 m
.41108 .7651 L
s
.40676 .76631 m
.40999 .7655 L
s
.46134 .96701 m .45609 .96533 L .45072 .96513 L 0 1 .527 r
F
.35477 .96303 m .34318 .95083 L .33975 .95176 L 0 1 .477 r
F
.35477 .96303 m .34962 .95566 L .34318 .95083 L F
.36288 .96056 m .34962 .95566 L .35477 .96303 L 0 1 .472 r
F
0 g
.35477 .96303 m
.361 .96778 L
s
.35477 .96303 m
.35626 .96934 L
s
.3797 .92952 m .36589 .92979 L .36686 .93126 L 0 1 .384 r
F
.3797 .92952 m .36933 .92885 L .36589 .92979 L F
.3797 .92952 m .37526 .92874 L .36933 .92885 L F
.38784 .92689 m .37526 .92874 L .3797 .92952 L 0 1 .34 r
F
0 g
.3797 .92952 m
.38541 .92926 L
s
.3797 .92952 m
.38065 .93099 L
s
.39131 .95178 m .38033 .94637 L .37716 .94744 L 0 1 .535 r
F
.39131 .95178 m .3864 .94824 L .38033 .94637 L F
.39872 .94895 m .3864 .94824 L .39131 .95178 L 0 1 .534 r
F
0 g
.39131 .95178 m
.39283 .95536 L
s
.39131 .95178 m
.39714 .95355 L
s
.46978 .9025 m .46881 .90285 L .4708 .90191 L 0 0 0 r
F
.47849 .89763 m .4708 .90191 L .46881 .90285 L F
0 g
.46881 .90285 m
.47029 .90203 L
s
.46447 .90482 m
.46881 .90285 L
s
.22142 .67986 m .21004 .68012 L .21221 .68808 L 0 1 .489 r
F
0 g
.20852 .6963 m
.21221 .68808 L
s
.29017 .93971 m .27424 .9398 L .27507 .94092 L 0 .787 .25 r
F
.29017 .93971 m .27836 .93919 L .27424 .9398 L F
.29017 .93971 m .2852 .93915 L .27836 .93919 L F
.30008 .93765 m .2852 .93915 L .29017 .93971 L 0 .758 .238 r
F
0 g
.29017 .93971 m
.29647 .93944 L
s
.29017 .93971 m
.29094 .94079 L
s
.7906 .60739 m .80385 .60437 L .80491 .60773 L 0 .041 0 r
F
0 g
.80385 .60437 m
.8087 .60508 L
s
.26361 .73714 m .25542 .74259 L .25998 .74238 L 0 1 .528 r
F
0 g
.25998 .74238 m
.26397 .74729 L
s
.23741 .92723 m .22182 .91562 L .22222 .92158 L 0 1 .534 r
F
.23741 .92723 m .22611 .91509 L .22182 .91562 L F
.23741 .92723 m .2328 .92007 L .22611 .91509 L F
.24781 .92552 m .2328 .92007 L .23741 .92723 L F
0 g
.23741 .92723 m
.23779 .93316 L
s
.23741 .92723 m
.24394 .93202 L
s
.63317 .51551 m
.6337 .51756 L
s
.6337 .51756 m
.63379 .51791 L
s
.62848 .49758 m
.62858 .49763 L
s
.46539 .96373 m .46134 .96701 L .4664 .96728 L 0 1 .519 r
F
.46539 .96373 m .45609 .96533 L .46134 .96701 L F
0 g
.46134 .96701 m
.46415 .96935 L
s
.59859 .59895 m
.59908 .60204 L
s
.60236 .6228 m
.6025 .62366 L
s
.6025 .62366 m
.60385 .63224 L
s
.59853 .60264 m
.59859 .59895 L
s
.71267 .90548 m .71481 .91114 L .72153 .91089 L 0 .989 .43 r
F
0 g
.71481 .91114 m
.7149 .91398 L
s
.43243 .75774 m .42062 .76244 L .42084 .76207 L 0 0 0 r
F
.43243 .75774 m .42394 .76152 L .42062 .76244 L F
.43243 .75774 m .4286 .75992 L .42394 .76152 L F
0 g
.42226 .76144 m
.42448 .76045 L
s
.43243 .75774 m .43224 .7583 L .4286 .75992 L 0 0 0 r
F
0 g
.43243 .75774 m
.4336 .75709 L
s
.4291 .75867 m
.43243 .75774 L
s
.5355 .77429 m
.53566 .77544 L
s
.47729 .59672 m .48357 .57556 L .48228 .57068 L 0 1 .302 r
F
.47729 .59672 m .48143 .58671 L .48357 .57556 L F
0 g
.48357 .57556 m
.48773 .57107 L
s
.48211 .58319 m
.48357 .57556 L
s
.31044 .93623 m
.31045 .93624 L
s
.5088 .84901 m .50793 .86738 L .51021 .86544 L 0 .407 .318 r
F
0 g
.50793 .86738 m
.5099 .8758 L
s
.29359 .65546 m .28243 .6552 L .28399 .66205 L 0 1 .476 r
F
0 g
.27956 .66897 m
.28399 .66205 L
s
.75724 .59454 m .76297 .60301 L .75857 .60142 L 0 .25 .055 r
F
.75724 .59454 m .76835 .59962 L .76297 .60301 L F
.63083 .45297 m .63807 .45877 L .64627 .46728 L 0 .247 0 r
F
.41258 .70615 m .40128 .7078 L .40379 .70977 L 0 1 .503 r
F
0 g
.39982 .71287 m
.40379 .70977 L
s
.41258 .70615 m .4025 .70446 L .40128 .7078 L 0 1 .503 r
F
.41258 .70615 m .40675 .70154 L .4025 .70446 L F
.41258 .70615 m .41119 .70098 L .40675 .70154 L F
.41258 .70615 m .41368 .70296 L .41119 .70098 L F
0 g
.41258 .70615 m
.41516 .70789 L
s
.40834 .70907 m
.41258 .70615 L
s
.26361 .73714 m .25222 .73745 L .25542 .74259 L 0 1 .528 r
F
0 g
.25262 .74806 m
.25542 .74259 L
s
.38758 .71801 m .37738 .71552 L .37652 .71933 L 0 1 .517 r
F
.38758 .71801 m .38131 .71236 L .37738 .71552 L F
.38758 .71801 m .38569 .71197 L .38131 .71236 L F
.38758 .71801 m .38837 .7144 L .38569 .71197 L F
0 g
.38365 .72116 m
.38758 .71801 L
s
.32169 .73466 m .31134 .72983 L .31104 .73529 L 0 1 .528 r
F
.32169 .73466 m .31476 .72569 L .31134 .72983 L F
.32169 .73466 m .31902 .72563 L .31476 .72569 L F
.32169 .73466 m .32199 .72948 L .31902 .72563 L F
0 g
.31827 .73878 m
.32169 .73466 L
s
.32169 .73466 m
.32467 .73824 L
s
.43007 .96036 m .42498 .95782 L .41925 .95686 L 0 1 .535 r
F
0 g
.43007 .96036 m
.43223 .96328 L
s
.4361 .95708 m .43007 .96035 L .4356 .96125 L 0 1 .533 r
F
.4361 .95708 m .42499 .95782 L .43007 .96035 L F
.51466 .71356 m .51562 .71191 L .51682 .71905 L 0 .231 .128 r
F
0 g
.51562 .71191 m
.51582 .70579 L
s
.5258 .78455 m .52498 .78436 L .52606 .79871 L 0 .423 .279 r
F
0 g
.52504 .78511 m
.52606 .79871 L
s
.52498 .78436 m
.52504 .78511 L
s
.52386 .78471 m
.52595 .79801 L
s
.52595 .79801 m
.52606 .79871 L
s
.52572 .78365 m
.5258 .78455 L
s
.52495 .78419 m
.52498 .78436 L
s
.28625 .78137 m .27892 .78442 L .28343 .78409 L 0 1 .502 r
F
.28625 .78137 m .27492 .78193 L .27892 .78442 L F
0 g
.2769 .7874 m
.27892 .78442 L
s
.28343 .78409 m
.28811 .78632 L
s
.43917 .91445 m .43705 .9159 L .43983 .91468 L 0 .779 .212 r
F
.43917 .91445 m .43193 .91737 L .43705 .9159 L F
0 g
.43705 .9159 m
.43823 .91599 L
s
.38758 .58357 m .37831 .58939 L .38184 .58887 L 0 1 .405 r
F
.38758 .58357 m .37896 .58522 L .37831 .58939 L F
0 g
.3818 .59347 m
.38184 .58887 L
s
.38758 .58357 m .38336 .57914 L .37896 .58522 L 0 1 .405 r
F
.38758 .58357 m .38912 .57384 L .38336 .57914 L F
.38758 .58357 m .39239 .57285 L .38912 .57384 L F
.38758 .58357 m .39172 .57703 L .39239 .57285 L F
0 g
.39172 .57703 m
.39727 .57141 L
s
.38712 .58802 m
.38758 .58357 L
s
.38184 .58887 m
.38758 .58357 L
s
.44907 1.03212 m .43836 1.02999 L .44522 1.03523 L 0 .857 .474 r
F
.44907 1.03212 m .43458 1.02512 L .43836 1.02999 L F
0 g
.43187 1.02703 m
.43836 1.02999 L
s
.47138 .47206 m .48294 .46138 L .48215 .46403 L 0 0 0 r
F
0 g
.48294 .46138 m
.48883 .45423 L
s
.47833 .46482 m
.48294 .46138 L
s
.43314 1.01871 m .42833 1.02179 L .43458 1.02512 L 0 .897 .475 r
F
.43314 1.01871 m .4218 1.0161 L .42833 1.02179 L F
0 g
.42833 1.02179 m
.43187 1.02703 L
s
.51812 1.07358 m .5184 1.07532 L .52415 1.07621 L 0 .834 .409 r
F
0 g
.5184 1.07532 m
.51917 1.07559 L
s
.25222 .73745 m .24403 .74312 L .24859 .74292 L 0 1 .528 r
F
0 g
.24859 .74292 m
.25262 .74806 L
s
.40926 .76566 m .40138 .76778 L .406 .76651 L 0 0 0 r
F
0 g
.5097 .88211 m
.51204 .89086 L
s
.44907 1.03212 m .44522 1.03523 L .45143 1.03823 L 0 .857 .474 r
F
0 g
.44522 1.03523 m
.4493 1.04016 L
s
.37611 .97807 m .37064 .97116 L .36416 .96675 L 0 1 .477 r
F
.3835 .9754 m .37611 .97807 L .38235 .98242 L 0 1 .471 r
F
.3835 .9754 m .37064 .97116 L .37611 .97807 L F
0 g
.37611 .97807 m
.37806 .98409 L
s
.49184 .62527 m
.49192 .62513 L
s
.49122 .62578 m
.49136 .62567 L
s
.49136 .62567 m
.49184 .62527 L
s
.70758 .91124 m
.70983 .90946 L
s
.69373 .91851 m .70285 .91495 L .70339 .91183 L 0 1 .421 r
F
0 g
.70286 .91495 m
.70758 .91124 L
s
.79932 .9118 m .7994 .92057 L .8058 .91763 L 0 1 .517 r
F
.79932 .9118 m .7952 .91987 L .7994 .92057 L F
0 g
.79841 .92449 m
.7994 .92057 L
s
.3424 .94437 m .33975 .95176 L .34318 .95083 L 0 1 .473 r
F
.3424 .94437 m .33365 .94659 L .33975 .95176 L F
0 g
.33975 .95176 m
.34126 .95808 L
s
.33366 .9466 m
.33975 .95176 L
s
.33365 .94659 m
.33381 .9534 L
s
.45546 .74818 m .44723 .75189 L .45188 .74941 L 0 0 0 r
F
0 g
.45188 .74941 m
.45414 .74785 L
s
.77153 .83965 m .7751 .85611 L .78013 .8476 L 0 1 .469 r
F
.77153 .83965 m .77079 .85698 L .7751 .85611 L F
0 g
.7751 .85611 m
.77567 .86256 L
s
.42662 .69657 m .41784 .70005 L .42227 .69935 L 0 1 .491 r
F
.42662 .69657 m .41566 .69823 L .41784 .70005 L F
0 g
.42227 .69935 m
.42485 .7011 L
s
.42662 .69657 m .41719 .6951 L .41566 .69823 L 0 1 .491 r
F
.42662 .69657 m .42154 .69232 L .41719 .6951 L F
.42662 .69657 m .42581 .69174 L .42154 .69232 L F
.42662 .69657 m .42798 .69357 L .42581 .69174 L F
0 g
.42662 .69657 m
.42891 .69819 L
s
.42227 .69935 m
.42662 .69657 L
s
.4123 1.00727 m .40617 1.00119 L .39967 .99752 L 0 .973 .48 r
F
.25222 .73745 m .24082 .73774 L .24403 .74312 L 0 1 .528 r
F
0 g
.24127 .7488 m
.24403 .74312 L
s
.61906 .48112 m .61844 .4865 L .61593 .47696 L 0 .505 .022 r
F
0 g
.61593 .47696 m
.61611 .47721 L
s
.61433 .47391 m
.61593 .47696 L
s
.61906 .48112 m .62568 .50552 L .61844 .4865 L 0 .505 .022 r
F
.61906 .48112 m .63281 .52135 L .62568 .50552 L F
.61906 .48112 m .62577 .49618 L .63301 .51519 L F
0 g
.62984 .50252 m
.62998 .50309 L
s
.62858 .49763 m
.62984 .50252 L
s
.62998 .50309 m
.63016 .5038 L
s
.63016 .5038 m
.63317 .51551 L
s
.62591 .49625 m
.62605 .49633 L
s
.62605 .49633 m
.62848 .49758 L
s
.62577 .49618 m
.62591 .49625 L
s
.61507 .46949 m
.61906 .48112 L
s
.61611 .47721 m
.61906 .48112 L
s
.43314 1.01871 m .41854 1.01093 L .4218 1.0161 L 0 .897 .475 r
F
0 g
.41527 1.01278 m
.4218 1.0161 L
s
.37652 .71933 m .36811 .723 L .37255 .72254 L 0 1 .522 r
F
0 g
.37255 .72254 m
.37568 .72513 L
s
.5088 .84901 m .51021 .86544 L .51042 .85794 L 0 .407 .318 r
F
0 g
.624 .72112 m
.62404 .72427 L
s
.62374 .70171 m
.62375 .70242 L
s
.62375 .70242 m
.62376 .70284 L
s
.62377 .70347 m
.62385 .70975 L
s
.62393 .71548 m
.624 .72112 L
s
.6237 .69875 m
.62371 .69956 L
s
.62373 .70082 m
.62374 .70171 L
s
.47888 .63655 m .48155 .63338 L .47982 .62547 L 0 1 .309 r
F
.47886 .63681 m .47938 .63615 L .47888 .63655 L F
.47938 .63615 m .48155 .63338 L .47888 .63655 L F
.48505 .63164 m .48497 .60274 L .48129 .61233 L 0 1 .297 r
F
.48469 .63196 m .48129 .61233 L .47982 .62547 L F
.48527 .63158 m .48506 .63166 L .48469 .63196 L 0 .946 .181 r
F
.48526 .63271 m .48506 .63166 L .48469 .63196 L 0 1 .297 r
F
.48506 .63166 m .48129 .61233 L .48469 .63196 L F
.48527 .63158 m .4847 .63196 L .48363 .63292 L 0 .946 .181 r
F
.4835 .63303 m .47982 .62547 L .48155 .63338 L 0 1 .297 r
F
.4847 .63196 m .48469 .63196 L .48363 .63292 L 0 .946 .181 r
F
.48469 .63196 m .48359 .63294 L .48363 .63292 L F
.48526 .63271 m .48469 .63196 L .4835 .63303 L 0 1 .297 r
F
.48469 .63196 m .47982 .62547 L .4835 .63303 L F
.47961 .63618 m .48155 .63338 L .47886 .63681 L 0 1 .309 r
F
.4775 .64003 m .4812 .63508 L .47883 .63719 L 0 1 .215 r
F
.4812 .63511 m .4812 .63508 L .47881 .63733 L 0 1 .309 r
F
.4812 .63508 m .48155 .63338 L .47905 .63699 L F
.4812 .63508 m .47905 .63699 L .47881 .63733 L F
.47881 .63733 m .47961 .63618 L .47886 .63681 L F
.47742 .65382 m .48052 .64552 L .48142 .63491 L F
.4812 .63511 m .48142 .63491 L .48155 .63338 L F
.47742 .65382 m .48142 .63491 L .4812 .63511 L F
.48469 .63196 m .48434 .63219 L .48359 .63294 L 0 .946 .181 r
F
.48434 .63219 m .47976 .63517 L .48342 .63305 L F
.48434 .63219 m .48342 .63305 L .48359 .63294 L F
.47883 .63719 m .48154 .63463 L .47976 .63517 L 0 1 .215 r
F
.4812 .63508 m .48154 .63463 L .47883 .63719 L F
.48469 .63196 m .4849 .63171 L .48434 .63219 L 0 .946 .181 r
F
.48506 .63166 m .4849 .63171 L .48469 .63196 L F
.4849 .63171 m .48484 .62965 L .48118 .63304 L F
.48506 .63166 m .48525 .63146 L .48505 .63164 L 0 1 .297 r
F
.48527 .63158 m .48525 .63151 L .48506 .63166 L 0 .946 .181 r
F
.48526 .63271 m .48525 .63151 L .48506 .63166 L 0 1 .297 r
F
.48525 .63151 m .48525 .63146 L .48506 .63166 L F
.48525 .63146 m .48497 .60274 L .48505 .63164 L F
.48506 .63166 m .48524 .63145 L .4849 .63171 L 0 .946 .181 r
F
.48525 .63151 m .48524 .63145 L .48506 .63166 L F
.48524 .63145 m .48484 .62965 L .4849 .63171 L F
.48434 .63219 m .48118 .63304 L .47976 .63517 L F
.4849 .63171 m .48118 .63304 L .48434 .63219 L F
.4775 .64003 m .48057 .63671 L .48144 .63485 L 0 1 .215 r
F
.48126 .63501 m .48144 .63485 L .48154 .63463 L F
.4775 .64003 m .48144 .63485 L .48126 .63501 L F
.47386 .64088 m .47587 .62629 L .47232 .63529 L 0 1 .309 r
F
.4775 .64003 m .47658 .63894 L .47386 .64088 L 0 1 .215 r
F
.4775 .64003 m .47132 .64333 L .47354 .64287 L F
.4775 .64003 m .47386 .64088 L .47132 .64333 L F
.47386 .64088 m .47232 .63529 L .47171 .64249 L 0 1 .309 r
F
.47386 .64088 m .47228 .64125 L .47171 .64249 L 0 1 .215 r
F
.47386 .64088 m .47171 .64249 L .47132 .64333 L F
.47013 .64808 m .47303 .6449 L .47354 .64287 L 0 1 .298 r
F
.47013 .64808 m .47354 .64287 L .47132 .64333 L F
.47742 .65382 m .47386 .64088 L .47129 .64745 L 0 1 .309 r
F
.47386 .64088 m .47171 .64249 L .47129 .64745 L F
.47742 .65382 m .47658 .63894 L .47386 .64088 L F
.47658 .63894 m .47587 .62629 L .47386 .64088 L F
.47386 .64088 m .47658 .63894 L .47382 .64089 L 0 1 .215 r
F
.47382 .64089 m .47579 .63801 L .47228 .64125 L F
.47658 .63894 m .47579 .63801 L .47382 .64089 L F
.47658 .63894 m .47982 .62547 L .47587 .62629 L 0 1 .309 r
F
.4766 .63919 m .47667 .63888 L .47658 .63894 L F
.47667 .63888 m .47982 .62547 L .47658 .63894 L F
.4775 .64003 m .47883 .63719 L .47658 .63894 L 0 1 .215 r
F
.47883 .63719 m .47982 .62547 L .4766 .63919 L 0 1 .309 r
F
.47658 .63894 m .47976 .63517 L .47579 .63801 L 0 1 .215 r
F
.47883 .63719 m .47976 .63517 L .47658 .63894 L F
.47667 .63888 m .47667 .63888 L .47658 .63894 L 0 1 .309 r
F
.47742 .65382 m .47883 .63719 L .4766 .63919 L F
.47742 .65382 m .4812 .63511 L .47881 .63733 L F
.48299 .63345 m .47976 .63517 L .48154 .63463 L 0 .946 .181 r
F
.48363 .63292 m .48342 .63305 L .48299 .63345 L F
.48342 .63305 m .47976 .63517 L .48299 .63345 L F
0 g
.48497 .60274 m
.48525 .60085 L
s
.48497 .60274 m
.48619 .60253 L
s
.30017 .78061 m .29098 .78351 L .29653 .78308 L 0 1 .484 r
F
.30017 .78061 m .28625 .78137 L .29098 .78351 L F
0 g
.28811 .78632 m
.29098 .78351 L
s
.29653 .78308 m
.30189 .78491 L
s
.47138 .47206 m .46398 .48114 L .46523 .47906 L 0 0 0 r
F
0 g
.46548 .47775 m
.46709 .47578 L
s
.47138 .47206 m .4686 .4777 L .46398 .48114 L 0 0 0 r
F
.47138 .47206 m .47601 .47102 L .4686 .4777 L F
.47138 .47206 m .48215 .46403 L .47601 .47102 L F
0 g
.46709 .47578 m
.47138 .47206 L
s
.49622 .72508 m .49001 .73712 L .49348 .73021 L 0 .072 .078 r
F
0 g
.49392 .72624 m
.49502 .72466 L
s
.49622 .72508 m .48763 .74246 L .49001 .73712 L 0 .072 .078 r
F
.49622 .72508 m .48793 .74265 L .48763 .74246 L F
.49622 .72508 m .49069 .73748 L .48793 .74265 L F
.49622 .72508 m .49406 .73043 L .49069 .73748 L F
0 g
.49343 .72696 m
.49392 .72624 L
s
.49279 .72719 m
.4928 .72717 L
s
.4928 .72717 m
.49308 .72658 L
s
.49308 .72658 m
.49376 .72514 L
s
.49622 .72508 m .49643 .72513 L .49406 .73043 L 0 .072 .078 r
F
0 g
.49622 .72508 m
.49654 .72425 L
s
.4951 .72618 m
.49562 .72488 L
s
.49643 .72513 m
.49707 .72359 L
s
.40926 .76566 m .39768 .76865 L .40138 .76778 L 0 0 0 r
F
0 g
.3985 .76887 m
.40138 .76778 L
s
.35131 .93698 m .34852 .94208 L .35195 .94112 L 0 1 .532 r
F
.35131 .93698 m .34254 .93923 L .34852 .94208 L F
0 g
.34852 .94208 m
.34986 .94612 L
s
.4361 .95708 m .4356 .96125 L .4379 .95991 L 0 1 .533 r
F
.44839 .96252 m .4379 .95991 L .4356 .96125 L 0 1 .531 r
F
0 g
.4356 .96125 m
.43794 .96386 L
s
.43007 .96035 m
.4356 .96125 L
s
.21004 .68012 m .2008 .68852 L .20537 .68835 L 0 1 .491 r
F
0 g
.20537 .68835 m
.20852 .6963 L
s
.5258 .78455 m
.5259 .78515 L
s
.5259 .78515 m
.5262 .78692 L
s
.52756 .79498 m
.52843 .8001 L
s
.52419 .46399 m .51915 .47183 L .519 .47122 L 0 0 .016 r
F
.52419 .46399 m .52492 .46636 L .51915 .47183 L F
.52419 .46399 m .53243 .45849 L .52492 .46636 L F
0 g
.58885 .58629 m
.59232 .59933 L
s
.59232 .59933 m
.59278 .60107 L
s
.59278 .60107 m
.59392 .60536 L
s
.59392 .60536 m
.59426 .60665 L
s
.58798 .5994 m
.58885 .58629 L
s
.48199 .54978 m .4897 .52708 L .48486 .53297 L 0 1 .25 r
F
0 g
.4897 .52708 m
.49342 .51709 L
s
.49617 .64013 m .49184 .62595 L .4931 .63741 L 0 1 .285 r
F
0 g
.48885 .62416 m
.49136 .62567 L
s
.48848 .62394 m
.48885 .62416 L
s
.48922 .65913 m .4931 .63741 L .49184 .62595 L 0 1 .295 r
F
0 g
.49136 .62567 m
.49184 .62595 L
s
.49184 .62595 m
.49192 .62513 L
s
.24082 .73774 m .23264 .74363 L .23719 .74343 L 0 1 .528 r
F
0 g
.23719 .74343 m
.24127 .7488 L
s
.70007 .61904 m
.70332 .61888 L
s
.43193 .91737 m .42257 .91953 L .41956 .92067 L 0 .847 .238 r
F
.43193 .91737 m .42788 .91811 L .42257 .91953 L F
0 g
.43193 .91737 m
.43295 .91781 L
s
.43917 .91445 m .42788 .91811 L .43193 .91737 L 0 .779 .212 r
F
0 g
.43193 .91737 m
.43705 .9159 L
s
.36021 .9295 m .35729 .93221 L .36072 .93123 L 0 1 .411 r
F
0 g
.36072 .93123 m
.36686 .93126 L
s
.36021 .9295 m .35144 .93176 L .35729 .93221 L 0 1 .411 r
F
0 g
.35729 .93221 m
.35847 .93389 L
s
.46567 1.04441 m .4557 1.04272 L .46282 1.04746 L 0 .813 .468 r
F
.46567 1.04441 m .45143 1.03823 L .4557 1.04272 L F
0 g
.4493 1.04016 m
.4557 1.04272 L
s
.42822 .52494 m .43397 .51717 L .4367 .51257 L 0 1 .183 r
F
0 g
.43397 .51717 m
.43804 .51226 L
s
.3835 .9754 m .38235 .98242 L .38522 .98132 L 0 1 .471 r
F
.39731 .99179 m .38522 .98132 L .38235 .98242 L 0 1 .476 r
F
0 g
.38235 .98242 m
.38472 .98815 L
s
.37611 .97807 m
.38235 .98242 L
s
.31104 .73529 m .30069 .73007 L .30039 .73582 L 0 1 .528 r
F
0 g
.30039 .73582 m
.30336 .7399 L
s
.31104 .73529 m .30411 .72574 L .30069 .73007 L 0 1 .528 r
F
.31104 .73529 m .30837 .72573 L .30411 .72574 L F
.31104 .73529 m .31134 .72983 L .30837 .72573 L F
0 g
.30762 .7396 m
.31104 .73529 L
s
.31104 .73529 m
.31401 .73912 L
s
.51617 .70559 m .51498 .66024 L .51483 .68657 L 0 .872 .266 r
F
.51133 .71017 m .51483 .68657 L .51498 .66024 L 0 .89 .272 r
F
0 g
.51329 .64465 m
.51498 .66024 L
s
.51498 .66024 m
.51652 .64138 L
s
.51664 .9728 m .5114 .97247 L .50732 .97293 L 0 .992 .369 r
F
0 g
.50732 .97293 m
.5114 .97247 L
s
.23278 .67958 m .22305 .66929 L .22142 .67986 L 0 1 .486 r
F
.23278 .67958 m .22766 .66139 L .22305 .66929 L F
.23278 .67958 m .23218 .66146 L .22766 .66139 L F
.23278 .67958 m .23437 .66927 L .23218 .66146 L F
0 g
.22817 .68743 m
.23278 .67958 L
s
.23278 .67958 m
.23501 .68714 L
s
.77118 1.06139 m .77219 1.06344 L .78025 1.06003 L 0 .926 .262 r
F
0 g
.76359 1.06617 m
.77219 1.06344 L
s
.24082 .73774 m .22941 .73801 L .23264 .74363 L 0 1 .528 r
F
0 g
.22992 .74953 m
.23264 .74363 L
s
.29359 .65546 m .28485 .64607 L .28243 .6552 L 0 1 .476 r
F
.29359 .65546 m .28996 .63944 L .28485 .64607 L F
.29359 .65546 m .29435 .63977 L .28996 .63944 L F
.29359 .65546 m .2959 .64664 L .29435 .63977 L F
0 g
.28848 .66205 m
.29359 .65546 L
s
.37129 .9452 m .3571 .93971 L .35824 .94359 L 0 1 .534 r
F
.50603 .44677 m .51934 .44038 L .5195 .44435 L 0 .036 .06 r
F
0 g
.51934 .44038 m
.52485 .43416 L
s
.51358 .44142 m
.51934 .44038 L
s
.66497 .4996 m .66763 .49794 L .66345 .49257 L 0 .228 .281 r
F
0 g
.66281 .49166 m
.66345 .49257 L
s
.66497 .4996 m .6757 .51218 L .66763 .49794 L 0 .228 .281 r
F
.66497 .4996 m .68228 .52579 L .6757 .51218 L F
.66497 .4996 m .68378 .53281 L .68228 .52579 L F
.66497 .4996 m .67922 .52857 L .68378 .53281 L F
.66497 .4996 m .67116 .51434 L .67922 .52857 L F
0 g
.6732 .5221 m
.67466 .52578 L
s
.67466 .52578 m
.67999 .53921 L
s
.67116 .51433 m
.67303 .52148 L
s
.67303 .52148 m
.6732 .5221 L
s
.66345 .49257 m
.66497 .4996 L
s
.46539 .96373 m .45358 .96309 L .45609 .96533 L 0 1 .519 r
F
0 g
.45072 .96513 m
.45609 .96533 L
s
.51443 .83607 m .51094 .83649 L .51073 .84553 L 0 .377 .304 r
F
.51443 .83607 m .51252 .83244 L .51094 .83649 L F
0 g
.50967 .82693 m
.51094 .83649 L
s
.51125 .82147 m
.51252 .83244 L
s
.31078 .77995 m .30387 .78248 L .30809 .78211 L 0 1 .465 r
F
.31078 .77995 m .30017 .78061 L .30387 .78248 L F
0 g
.30189 .78491 m
.30387 .78248 L
s
.30809 .78211 m
.31239 .78377 L
s
.53514 .77692 m
.53546 .77844 L
s
.49945 1.06711 m .50471 1.07152 L .5049 1.07042 L 0 .855 .454 r
F
.51812 1.07358 m .5049 1.07042 L .50471 1.07152 L 0 .834 .409 r
F
0 g
.50471 1.07152 m
.5105 1.07362 L
s
.49868 1.06999 m
.50471 1.07152 L
s
.39768 .76865 m .38983 .77062 L .39445 .76954 L 0 .718 .212 r
F
0 g
.39445 .76954 m
.3985 .76887 L
s
.76372 .76211 m .77095 .76298 L .7749 .76752 L 0 .116 0 r
F
0 g
.77095 .76298 m
.77155 .76367 L
s
.77095 .76298 m
.77325 .76534 L
s
.30022 .93352 m .28504 .92468 L .28554 .92969 L 0 1 .533 r
F
.30022 .93352 m .28917 .92398 L .28504 .92468 L F
.30022 .93352 m .29568 .92777 L .28917 .92398 L F
.31015 .93143 m .29568 .92777 L .30022 .93352 L 0 1 .532 r
F
0 g
.30022 .93352 m
.30041 .93553 L
s
.30022 .93352 m
.30285 .93503 L
s
.51538 .81795 m
.51562 .81601 L
s
.67469 .57765 m .68405 .58258 L .67775 .56351 L 0 .565 .304 r
F
0 g
.67649 .55028 m
.67775 .56351 L
s
.67649 .55028 m
.68244 .56528 L
s
.67469 .57765 m .68876 .60515 L .68405 .58258 L 0 .565 .304 r
F
0 g
.6742 .56467 m
.67469 .57765 L
s
.67355 .57359 m
.67469 .57765 L
s
.33365 .94659 m .32179 .93368 L .31699 .93476 L 0 1 .478 r
F
.33365 .94659 m .32894 .93876 L .32179 .93368 L F
0 g
.33365 .94659 m
.33365 .94659 L
s
.3424 .94437 m .32894 .93876 L .33365 .94659 L 0 1 .473 r
F
0 g
.33365 .94659 m
.33366 .9466 L
s
.51466 .71356 m .51421 .73424 L .51406 .72311 L 0 .231 .128 r
F
.51466 .71356 m .51542 .74147 L .51421 .73424 L F
.51466 .71356 m .51687 .73991 L .51542 .74147 L F
.51466 .71356 m .51747 .73028 L .51687 .73991 L F
.51466 .71356 m .51682 .71905 L .51747 .73028 L F
0 g
.51382 .70848 m
.51466 .71356 L
s
.51682 .71905 m
.51704 .70916 L
s
.51562 .71191 m
.51682 .71905 L
s
.49178 .5133 m .50239 .49501 L .50208 .49444 L 0 .96 .154 r
F
.49178 .5133 m .49799 .50308 L .50239 .49501 L F
0 g
.50239 .49501 m
.5073 .48728 L
s
.49799 .50308 m
.50287 .49621 L
s
.49799 .50308 m
.50239 .49501 L
s
.70891 .90701 m
.70981 .90938 L
s
.5099 .8758 m
.5109 .87536 L
s
.5109 .87536 m
.51112 .87526 L
s
.51112 .87526 m
.51187 .87493 L
s
.47849 .89763 m .47496 .89967 L .4708 .90191 L 0 0 0 r
F
.48274 .8962 m .47849 .89763 L .48231 .89568 L F
.48274 .8962 m .47496 .89967 L .47849 .89763 L F
0 g
.47849 .89763 m
.47995 .89682 L
s
.70981 .90938 m
.70983 .90946 L
s
.70918 .9069 m
.70918 .9069 L
s
.41804 1.00431 m .4123 1.00727 L .41854 1.01093 L 0 .934 .473 r
F
.41804 1.00431 m .40617 1.00119 L .4123 1.00727 L F
0 g
.4123 1.00727 m
.41527 1.01278 L
s
.37943 .94267 m .37716 .94744 L .38033 .94637 L 0 1 .533 r
F
.37943 .94267 m .37129 .9452 L .37716 .94744 L F
0 g
.37716 .94744 m
.3787 .95102 L
s
.49333 .62259 m .49663 .6188 L .49847 .61661 L 0 .832 .136 r
F
0 g
.49663 .6188 m
.49766 .61779 L
s
.7673 .9183 m .77834 .91696 L .77412 .91621 L 0 1 .515 r
F
0 g
.77768 .92042 m
.78402 .91828 L
s
.75689 .9161 m .7673 .9183 L .76779 .91507 L 0 1 .507 r
F
.22941 .73801 m .22124 .74412 L .2258 .74393 L 0 1 .528 r
F
0 g
.2258 .74393 m
.22992 .74953 L
s
.39768 .76865 m .3861 .77115 L .38983 .77062 L 0 .718 .212 r
F
0 g
.38702 .77177 m
.38983 .77062 L
s
.37652 .71933 m .36546 .72035 L .36811 .723 L 0 1 .522 r
F
0 g
.36457 .72647 m
.36811 .723 L
s
.21004 .68012 m .19865 .68037 L .2008 .68852 L 0 1 .491 r
F
0 g
.19712 .69692 m
.2008 .68852 L
s
.72586 1.07068 m .71807 1.07159 L .71462 1.07221 L 0 .685 .221 r
F
0 g
.70583 1.07261 m
.71462 1.07221 L
s
.50603 .44677 m .49979 .45612 L .50012 .45307 L 0 .036 .06 r
F
0 g
.49917 .44994 m
.5006 .4482 L
s
.50603 .44677 m .50558 .45509 L .49979 .45612 L 0 .036 .06 r
F
.50603 .44677 m .5136 .45066 L .50558 .45509 L F
.50603 .44677 m .5195 .44435 L .5136 .45066 L F
0 g
.5006 .4482 m
.50603 .44677 L
s
.41763 .95375 m .40433 .95065 L .40596 .95376 L 0 1 .534 r
F
0 g
.40001 .95237 m
.40596 .95376 L
s
.46539 .96373 m .4664 .96728 L .46789 .96597 L 0 1 .519 r
F
.4778 .96728 m .46789 .96597 L .4664 .96728 L 0 1 .506 r
F
0 g
.4664 .96728 m
.46936 .96922 L
s
.46134 .96701 m
.4664 .96728 L
s
.45546 .74818 m .44384 .75432 L .44723 .75189 L 0 0 0 r
F
.45546 .74818 m .44397 .75508 L .44384 .75432 L F
0 g
.44212 .75419 m
.44271 .75386 L
s
.44271 .75386 m
.44385 .75322 L
s
.45546 .74818 m .44756 .75385 L .44397 .75508 L 0 0 0 r
F
0 g
.44385 .75322 m
.44626 .75227 L
s
.44626 .75227 m
.44642 .75221 L
s
.44642 .75221 m
.44723 .75189 L
s
.45546 .74818 m .45219 .75145 L .44756 .75385 L 0 0 0 r
F
.45546 .74818 m .45558 .74902 L .45219 .75145 L F
0 g
.45546 .74818 m
.45611 .74761 L
s
.45188 .74941 m
.45546 .74818 L
s
.51664 .9728 m
.52076 .97353 L
s
.52076 .97353 m
.52176 .97343 L
s
.52176 .97343 m
.52197 .9734 L
s
.52197 .9734 m
.52261 .97333 L
s
.52261 .97333 m
.52448 .97313 L
s
.32139 .77921 m .31444 .78154 L .31867 .78115 L 0 1 .441 r
F
.32139 .77921 m .31078 .77995 L .31444 .78154 L F
0 g
.31239 .78377 m
.31444 .78154 L
s
.31867 .78115 m
.3229 .78254 L
s
.50355 .97176 m .49833 .97114 L .49394 .97153 L 0 1 .441 r
F
0 g
.49394 .97153 m
.49833 .97114 L
s
.50355 .97176 m
.50732 .97293 L
s
.22668 .93692 m .21053 .92907 L .21118 .93332 L 0 1 .528 r
F
.22668 .93692 m .21481 .92863 L .21053 .92907 L F
.22668 .93692 m .22175 .932 L .21481 .92863 L F
.23706 .93535 m .22175 .932 L .22668 .93692 L 0 1 .526 r
F
0 g
.22668 .93692 m
.22729 .94114 L
s
.22668 .93692 m
.23343 .94007 L
s
.50081 .88491 m .50175 .88273 L .50242 .88296 L 0 0 0 r
F
.50792 .87854 m .50242 .88296 L .50175 .88273 L F
0 g
.50175 .88273 m
.50374 .88041 L
s
.4988 .88448 m
.50175 .88273 L
s
.35091 .61781 m .3415 .62268 L .34544 .62283 L 0 1 .477 r
F
0 g
.34544 .62283 m
.34642 .62851 L
s
.46567 1.04441 m .46282 1.04746 L .46893 1.05011 L 0 .813 .468 r
F
0 g
.46282 1.04746 m
.4674 1.05201 L
s
.5099 .87622 m
.51112 .87526 L
s
.51112 .87526 m
.51213 .87447 L
s
.28243 .6552 m .27275 .66199 L .27725 .66202 L 0 1 .478 r
F
0 g
.27725 .66202 m
.27956 .66897 L
s
.51569 .91022 m .51902 .92303 L .51875 .91815 L 0 .321 .332 r
F
0 g
.516 .92226 m
.51902 .92303 L
s
.32354 .63543 m .31419 .64098 L .31828 .64115 L 0 1 .476 r
F
0 g
.31828 .64115 m
.31978 .64742 L
s
.32907 .93444 m
.32907 .93444 L
s
.79932 .9118 m .79515 .91611 L .7952 .91987 L 0 1 .517 r
F
0 g
.79461 .92008 m
.7952 .91987 L
s
.7276 .61288 m .74097 .59363 L .74169 .6037 L 0 .266 .093 r
F
0 g
.74097 .59363 m
.74612 .58843 L
s
.47729 .59672 m .48228 .57068 L .47787 .57458 L 0 1 .302 r
F
0 g
.48505 .58441 m
.48549 .58413 L
s
.48228 .57068 m
.48487 .55883 L
s
.52784 .79381 m
.52843 .8001 L
s
.22941 .73801 m .21801 .73827 L .22124 .74412 L 0 1 .528 r
F
0 g
.21857 .75023 m
.22124 .74412 L
s
.41925 .95686 m
.42498 .95782 L
s
.49711 .72523 m .49069 .73748 L .49406 .73043 L 0 .089 .082 r
F
0 g
.49301 .72755 m
.49343 .72696 L
s
.49711 .72523 m .48895 .74321 L .49069 .73748 L 0 .089 .082 r
F
.49711 .72523 m .49001 .74377 L .48895 .74321 L F
.49711 .72523 m .49307 .73853 L .49001 .74377 L F
0 g
.49232 .72817 m
.49279 .72719 L
s
.49175 .72936 m
.49232 .72817 L
s
.49175 .72936 m
.49301 .72755 L
s
.49711 .72523 m .49608 .731 L .49307 .73853 L 0 .089 .082 r
F
0 g
.49637 .72526 m
.49643 .72513 L
s
.49609 .72533 m
.49622 .72508 L
s
.49442 .72786 m
.4951 .72618 L
s
.49711 .72523 m .49781 .72532 L .49608 .731 L 0 .089 .082 r
F
0 g
.49711 .72523 m
.4982 .72167 L
s
.49561 .72621 m
.49609 .72533 L
s
.49781 .72532 m
.49926 .72194 L
s
.44481 .68023 m .43637 .68342 L .44042 .68283 L 0 1 .464 r
F
.44481 .68023 m .43489 .68164 L .43637 .68342 L F
0 g
.44042 .68283 m
.44231 .68454 L
s
.44481 .68023 m .43697 .67868 L .43489 .68164 L 0 1 .464 r
F
.44481 .68023 m .44137 .67608 L .43697 .67868 L F
.44481 .68023 m .44516 .67557 L .44137 .67608 L F
.44481 .68023 m .44663 .67735 L .44516 .67557 L F
0 g
.44481 .68023 m
.44647 .6819 L
s
.44042 .68283 m
.44481 .68023 L
s
.44663 .67735 m
.45083 .67478 L
s
.53678 1.07777 m .53022 1.07655 L .53809 1.07648 L 0 .603 .247 r
F
.3861 .77115 m .37861 .77297 L .38304 .77209 L 0 .765 .235 r
F
0 g
.38304 .77209 m
.38702 .77177 L
s
.63083 .45297 m .631 .45751 L .62779 .45243 L 0 .247 0 r
F
.63083 .45297 m .63923 .46607 L .631 .45751 L F
.63083 .45297 m .64698 .47236 L .63923 .46607 L F
.63083 .45297 m .64999 .47287 L .64698 .47236 L F
.63083 .45297 m .64627 .46728 L .64999 .47287 L F
0 g
.63807 .45877 m
.64627 .46728 L
s
.49945 1.06711 m .49202 1.06379 L .48599 1.06227 L 0 .855 .454 r
F
.72555 .90886 m .73179 .91383 L .73602 .9114 L 0 1 .464 r
F
0 g
.72561 .91468 m
.73179 .91383 L
s
.73166 .91656 m
.73179 .91383 L
s
.50081 .88491 m .49391 .88901 L .49552 .88705 L 0 0 0 r
F
0 g
.49222 .88935 m
.49552 .88705 L
s
.33201 .77835 m .32502 .78052 L .32925 .78008 L 0 1 .411 r
F
.33201 .77835 m .32139 .77921 L .32502 .78052 L F
0 g
.3229 .78254 m
.32502 .78052 L
s
.32925 .78008 m
.33342 .7812 L
s
.53448 .7817 m
.53497 .78548 L
s
.30038 .73582 m .2867 .73026 L .2864 .7364 L 0 1 .528 r
F
0 g
.2864 .7364 m
.29037 .74073 L
s
.30038 .73582 m .29112 .72567 L .2867 .73026 L 0 1 .528 r
F
.30038 .73582 m .29672 .72571 L .29112 .72567 L F
.30038 .73582 m .30068 .73007 L .29672 .72571 L F
0 g
.29596 .74039 m
.30038 .73582 L
s
.26864 .92216 m .26446 .92829 L .26857 .92756 L 0 1 .533 r
F
.26864 .92216 m .25821 .92382 L .26446 .92829 L F
0 g
.26446 .92829 m
.26531 .93365 L
s
.26857 .92756 m
.27017 .92852 L
s
.50686 .48658 m .51877 .47034 L .51355 .47746 L 0 0 0 r
F
0 g
.51877 .47034 m
.52419 .46399 L
s
.51443 .83607 m .51073 .84553 L .51236 .85559 L 0 .377 .304 r
F
0 g
.51094 .83649 m
.51252 .83244 L
s
.5088 .84901 m
.51073 .84553 L
s
.42798 .69357 m
.4322 .69079 L
s
.3861 .77115 m .37499 .77315 L .37861 .77297 L 0 .765 .235 r
F
0 g
.37601 .77419 m
.37861 .77297 L
s
.42084 .76207 m .409 .76581 L .40926 .76566 L 0 0 0 r
F
.42084 .76207 m .41229 .76496 L .409 .76581 L F
.42084 .76207 m .41695 .76367 L .41229 .76496 L F
.42084 .76207 m .42062 .76244 L .41695 .76367 L F
0 g
.42084 .76207 m
.42226 .76144 L
s
.41755 .76292 m
.42084 .76207 L
s
.21801 .73827 m .20984 .7446 L .2144 .74441 L 0 1 .528 r
F
0 g
.2144 .74441 m
.21857 .75023 L
s
.41804 1.00431 m .40347 .99577 L .40617 1.00119 L 0 .934 .473 r
F
0 g
.39967 .99752 m
.40617 1.00119 L
s
.79646 .78028 m .80595 .78404 L .8013 .78172 L 0 .341 .218 r
F
.79646 .78028 m .80803 .78639 L .80595 .78404 L F
.36288 .96056 m .34833 .94946 L .34962 .95566 L 0 1 .472 r
F
0 g
.34318 .95083 m
.34962 .95566 L
s
.49896 .67829 m .49617 .64013 L .49498 .65697 L 0 1 .285 r
F
0 g
.51569 .91022 m
.51684 .9132 L
s
.51684 .9132 m
.51875 .91815 L
s
.34263 .77736 m .3356 .77938 L .33984 .77889 L 0 1 .374 r
F
.34263 .77736 m .33201 .77835 L .3356 .77938 L F
0 g
.33342 .7812 m
.3356 .77938 L
s
.33984 .77889 m
.34394 .77974 L
s
.77153 .83965 m .76926 .84994 L .77079 .85698 L 0 1 .469 r
F
0 g
.76501 .86455 m
.77079 .85698 L
s
.44688 .75214 m
.44723 .75189 L
s
.44472 .75369 m
.44688 .75214 L
s
.52876 .78998 m
.52984 .79602 L
s
.4361 .95708 m .42317 .955 L .42499 .95782 L 0 1 .533 r
F
.37499 .77315 m .36753 .77497 L .37196 .77421 L 0 .796 .252 r
F
0 g
.37196 .77421 m
.37601 .77419 L
s
.3835 .9754 m .3689 .96524 L .37064 .97116 L 0 1 .471 r
F
0 g
.36416 .96675 m
.37064 .97116 L
s
.51211 .87438 m
.51214 .87451 L
s
.51474 .85997 m .51042 .85794 L .51021 .86544 L 0 .341 .309 r
F
0 g
.51021 .86544 m
.51211 .87438 L
s
.50793 .86738 m
.51021 .86544 L
s
.21801 .73827 m .20659 .73853 L .20984 .7446 L 0 1 .528 r
F
0 g
.20722 .75093 m
.20984 .7446 L
s
.72586 1.07068 m .72617 1.07104 L .73427 1.06964 L 0 .685 .221 r
F
0 g
.723 1.07194 m
.72617 1.07104 L
s
.71777 1.07214 m
.72617 1.07104 L
s
.67413 .93429 m .68377 .92881 L .68027 .93022 L 0 1 .331 r
F
.6846 .92286 m .68377 .92881 L .68953 .9238 L 0 1 .372 r
F
.6846 .92286 m .68027 .93022 L .68377 .92881 L F
0 g
.68269 .93108 m
.68377 .92881 L
s
.37499 .77315 m .36388 .77484 L .36753 .77497 L 0 .796 .252 r
F
0 g
.365 .77632 m
.36753 .77497 L
s
.54541 .43825 m .55324 .43675 L .55994 .43982 L 0 .257 .085 r
F
0 g
.55822 .43903 m
.55832 .4389 L
s
.55324 .43675 m
.55826 .43072 L
s
.35325 .7762 m .34619 .7781 L .35043 .77755 L 0 1 .329 r
F
.35325 .7762 m .34263 .77736 L .34619 .7781 L F
0 g
.34394 .77974 m
.34619 .7781 L
s
.35043 .77755 m
.35446 .77813 L
s
.42822 .52494 m .41955 .53343 L .42204 .53191 L 0 1 .183 r
F
0 g
.42403 .53164 m
.42577 .52965 L
s
.42822 .52494 m .42229 .52883 L .41955 .53343 L 0 1 .183 r
F
.42822 .52494 m .42843 .52117 L .42229 .52883 L F
.42822 .52494 m .43461 .5142 L .42843 .52117 L F
.42822 .52494 m .4367 .51257 L .43461 .5142 L F
0 g
.43397 .51717 m
.4367 .51257 L
s
.42577 .52965 m
.42822 .52494 L
s
.4367 .51257 m
.44283 .50541 L
s
.36388 .77484 m .35679 .77665 L .36102 .77602 L 0 .893 .281 r
F
0 g
.36102 .77602 m
.365 .77632 L
s
.35091 .61781 m .34118 .61737 L .3415 .62268 L 0 1 .477 r
F
.35091 .61781 m .34471 .61044 L .34118 .61737 L F
.35091 .61781 m .35019 .6054 L .34471 .61044 L F
.35091 .61781 m .35395 .60563 L .35019 .6054 L F
.35091 .61781 m .35425 .61096 L .35395 .60563 L F
0 g
.35091 .61781 m
.35136 .62293 L
s
.34544 .62283 m
.35091 .61781 L
s
.36388 .77484 m .35325 .7762 L .35679 .77665 L 0 .893 .281 r
F
0 g
.35446 .77813 m
.35679 .77665 L
s
.67906 .5675 m
.68208 .57661 L
s
.67775 .56351 m
.67906 .5675 L
s
.80452 .83344 m .81427 .82427 L .80984 .82484 L 0 1 .484 r
F
.79352 .83506 m .80452 .83344 L .80318 .82579 L 0 1 .48 r
F
.48129 .61233 m .48143 .58671 L .47729 .59672 L 0 1 .299 r
F
0 g
.48143 .58671 m
.48505 .58441 L
s
.48143 .58671 m
.48211 .58319 L
s
.48274 .8962 m .48231 .89568 L .48388 .89511 L 0 0 0 r
F
.49066 .89069 m .48388 .89511 L .48231 .89568 L F
0 g
.48231 .89568 m
.48387 .89433 L
s
.47849 .89763 m
.48231 .89568 L
s
.51474 .85997 m .51236 .85559 L .51042 .85794 L 0 .341 .309 r
F
0 g
.5088 .84901 m
.51042 .85794 L
s
.41368 .70296 m
.41784 .70005 L
s
.33645 .62825 m
.3415 .62268 L
s
.46747 .74256 m .45915 .74733 L .46377 .74424 L 0 0 .016 r
F
.46747 .74256 m .45594 .75031 L .45915 .74733 L F
.46747 .74256 m .45631 .75119 L .45594 .75031 L F
.46747 .74256 m .46001 .74952 L .45631 .75119 L F
.46747 .74256 m .46457 .7464 L .46001 .74952 L F
.46747 .74256 m .46776 .74342 L .46457 .7464 L F
0 g
.46377 .74424 m
.46717 .74128 L
s
.46747 .74256 m
.47071 .73892 L
s
.46377 .74424 m
.46747 .74256 L
s
.27044 .9348 m
.27524 .93629 L
s
.37129 .9452 m .36054 .93879 L .3571 .93971 L 0 1 .534 r
F
0 g
.35195 .94112 m
.35464 .94218 L
s
.35464 .94218 m
.35824 .94359 L
s
.37129 .9452 m .36663 .94114 L .36054 .93879 L 0 1 .534 r
F
.37943 .94267 m .36663 .94114 L .37129 .9452 L 0 1 .533 r
F
0 g
.37129 .9452 m
.37241 .94906 L
s
.37129 .9452 m
.37716 .94744 L
s
.25787 .93227 m .25393 .93654 L .25803 .93585 L 0 1 .518 r
F
0 g
.25803 .93585 m
.26 .9365 L
s
.25787 .93227 m .24746 .93379 L .25393 .93654 L 0 1 .518 r
F
0 g
.25393 .93654 m
.25504 .94012 L
s
.20659 .73853 m .19844 .74508 L .203 .74489 L 0 1 .528 r
F
0 g
.203 .74489 m
.20722 .75093 L
s
.43314 1.01871 m .43458 1.02512 L .43639 1.02388 L 0 .897 .475 r
F
.44907 1.03212 m .43639 1.02388 L .43458 1.02512 L 0 .857 .474 r
F
0 g
.43458 1.02512 m
.43836 1.02999 L
s
.42833 1.02179 m
.43458 1.02512 L
s
.30015 .93558 m .2848 .93148 L .28537 .93442 L 0 1 .5 r
F
.30015 .93558 m .28893 .93083 L .2848 .93148 L F
.30015 .93558 m .29551 .93259 L .28893 .93083 L F
.31009 .93353 m .29551 .93259 L .30015 .93558 L 0 1 .49 r
F
0 g
.30015 .93558 m
.30052 .93756 L
s
.30015 .93558 m
.30475 .93671 L
s
.46978 .9025 m .45965 .90711 L .46069 .90651 L 0 0 0 r
F
0 g
.45604 .90864 m
.46069 .90651 L
s
.58769 .43621 m .58466 .44277 L .58309 .43978 L 0 .217 .062 r
F
.58769 .43621 m .59194 .4445 L .58466 .44277 L F
.58769 .43621 m .60006 .44382 L .59194 .4445 L F
.58769 .43621 m .60463 .44024 L .60006 .44382 L F
0 g
.58075 .4348 m
.58769 .43621 L
s
.53416 .78401 m
.53484 .78744 L
s
.53678 1.07777 m .53809 1.07648 L .5435 1.07715 L 0 .603 .247 r
F
0 g
.53809 1.07648 m
.54447 1.07556 L
s
.28243 .6552 m .27126 .65488 L .27275 .66199 L 0 1 .478 r
F
0 g
.26828 .6691 m
.27275 .66199 L
s
.37652 .71933 m .36637 .71633 L .36546 .72035 L 0 1 .522 r
F
0 g
.36546 .72035 m
.36811 .723 L
s
.37652 .71933 m .37035 .71311 L .36637 .71633 L 0 1 .522 r
F
.37652 .71933 m .37473 .71285 L .37035 .71311 L F
.37652 .71933 m .37738 .71552 L .37473 .71285 L F
0 g
.37652 .71933 m
.37921 .72174 L
s
.37255 .72254 m
.37652 .71933 L
s
.34254 .93923 m .32815 .93228 L .329 .9366 L 0 1 .533 r
F
.34254 .93923 m .33182 .93149 L .32815 .93228 L F
.34254 .93923 m .33799 .93447 L .33182 .93149 L F
.35131 .93698 m .33799 .93447 L .34254 .93923 L 0 1 .532 r
F
0 g
.34254 .93923 m
.34852 .94208 L
s
.34254 .93923 m
.34337 .94353 L
s
.52929 .7878 m
.52988 .79339 L
s
.20659 .73853 m .19518 .73878 L .19844 .74508 L 0 1 .528 r
F
0 g
.19587 .75161 m
.19844 .74508 L
s
.36546 .72035 m .35733 .72396 L .36159 .72362 L 0 1 .526 r
F
0 g
.36159 .72362 m
.36457 .72647 L
s
.48278 1.0554 m .47365 1.0541 L .48096 1.05822 L 0 .762 .451 r
F
.48278 1.0554 m .46893 1.05011 L .47365 1.0541 L F
0 g
.4674 1.05201 m
.47365 1.0541 L
s
.51225 .71713 m .51322 .7158 L .51406 .72311 L 0 .22 .121 r
F
0 g
.51322 .7158 m
.51382 .70848 L
s
.39601 .92441 m .39335 .9265 L .39653 .92544 L 0 .961 .289 r
F
.39601 .92441 m .38784 .92689 L .39335 .9265 L F
0 g
.39335 .9265 m
.39446 .92746 L
s
.39589 .57055 m .38912 .57384 L .39239 .57285 L 0 1 .383 r
F
.39589 .57055 m .38779 .57313 L .38912 .57384 L F
.39589 .57055 m .38928 .57119 L .38779 .57313 L F
0 g
.39172 .57703 m
.39238 .57291 L
s
.39238 .57291 m
.39239 .57285 L
s
.39589 .57055 m .39279 .56889 L .38928 .57119 L 0 1 .383 r
F
.39589 .57055 m .39597 .56776 L .39279 .56889 L F
.39589 .57055 m .39729 .56847 L .39597 .56776 L F
0 g
.39589 .57055 m
.39728 .5714 L
s
.39239 .57285 m
.39589 .57055 L
s
.39729 .56847 m
.40072 .56613 L
s
.55576 .58038 m .56015 .57631 L .56505 .58022 L 0 .342 .117 r
F
0 g
.56015 .57631 m
.56183 .56591 L
s
.32244 .92677 m .31699 .93476 L .32179 .93368 L 0 1 .474 r
F
.32238 .92893 m .31699 .93476 L .32179 .93368 L 0 1 .532 r
F
.32231 .93109 m .31699 .93476 L .32179 .93368 L 0 1 .474 r
F
.32244 .92677 m .31022 .92932 L .31699 .93476 L F
.32238 .92893 m .31016 .93143 L .31699 .93476 L 0 1 .532 r
F
.32231 .93109 m .31009 .93353 L .31699 .93476 L 0 1 .474 r
F
0 g
.31699 .93476 m
.31717 .94159 L
s
.32179 .93368 m
.32186 .93369 L
s
.32186 .93369 m
.32196 .9337 L
s
.32196 .9337 m
.32202 .93371 L
s
.31044 .93618 m
.31045 .93623 L
s
.31045 .93623 m
.31045 .93624 L
s
.31044 .93604 m
.31045 .93624 L
s
.31015 .93143 m
.31028 .9335 L
s
.31029 .93357 m
.31044 .93601 L
s
.31044 .93601 m
.31044 .93604 L
s
.31016 .93143 m
.3132 .93291 L
s
.45517 .90879 m .44402 .91299 L .4449 .91282 L 0 0 0 r
F
0 g
.43983 .91468 m
.4449 .91282 L
s
.74266 1.06886 m .75501 1.06686 L .75157 1.06721 L 0 .787 .252 r
F
.73427 1.06964 m .74266 1.06886 L .74641 1.0678 L 0 .744 .239 r
F
.72506 .89411 m .73522 .88636 L .73106 .8877 L 0 1 .478 r
F
.73302 .87421 m .73522 .88636 L .74062 .8789 L 0 1 .466 r
F
.73302 .87421 m .73106 .8877 L .73522 .88636 L F
0 g
.73522 .88636 m
.7353 .89102 L
s
.82013 .80294 m .82537 .82308 L .82984 .8137 L 0 1 .476 r
F
.82013 .80294 m .82093 .82352 L .82537 .82308 L F
0 g
.82537 .82308 m
.82651 .8312 L
s
.39872 .94895 m .38509 .94481 L .3864 .94824 L 0 1 .534 r
F
0 g
.38033 .94637 m
.3864 .94824 L
s
.48452 .73348 m
.48477 .73303 L
s
.48189 .73614 m
.48477 .73303 L
s
.24711 .94209 m .2434 .94457 L .24751 .94392 L 0 .912 .306 r
F
0 g
.24751 .94392 m
.25486 .94457 L
s
.24711 .94209 m .23671 .94348 L .2434 .94457 L 0 .912 .306 r
F
0 g
.2434 .94457 m
.24478 .94644 L
s
.49056 .96995 m .48542 .96899 L .48076 .96922 L 0 1 .483 r
F
0 g
.48076 .96922 m
.48542 .96899 L
s
.49056 .96995 m
.49394 .97153 L
s
.32213 .93382 m
.32213 .93382 L
s
.32213 .93382 m
.32501 .93498 L
s
.32501 .93498 m
.329 .9366 L
s
.32199 .93376 m
.32213 .93382 L
s
.32179 .93368 m
.32199 .93376 L
s
.53343 .78923 m
.53426 .79587 L
s
.24781 .92552 m .23254 .91429 L .2328 .92007 L 0 1 .534 r
F
.24781 .92552 m .23684 .91376 L .23254 .91429 L F
.24781 .92552 m .24339 .91858 L .23684 .91376 L F
.25821 .92382 m .24339 .91858 L .24781 .92552 L 0 1 .533 r
F
0 g
.24781 .92552 m
.24803 .93127 L
s
.24781 .92552 m
.25419 .93015 L
s
.36901 .60094 m .35959 .60578 L .36335 .60574 L 0 1 .463 r
F
.36901 .60094 m .35978 .60127 L .35959 .60578 L F
0 g
.36335 .60574 m
.36379 .61088 L
s
.36901 .60094 m .3638 .59521 L .35978 .60127 L 0 1 .463 r
F
.36901 .60094 m .36947 .5904 L .3638 .59521 L F
.36901 .60094 m .37301 .59004 L .36947 .5904 L F
.36901 .60094 m .37281 .59456 L .37301 .59004 L F
0 g
.36898 .60554 m
.36901 .60094 L
s
.36335 .60574 m
.36901 .60094 L
s
.52994 .78506 m
.53 .78537 L
s
.53227 .7976 m
.53263 .79952 L
s
.32354 .63543 m .31341 .63476 L .31419 .64098 L 0 1 .476 r
F
0 g
.30946 .64718 m
.31419 .64098 L
s
.49333 .62259 m .48857 .62661 L .48988 .62593 L 0 .832 .136 r
F
0 g
.48847 .62807 m
.48959 .62713 L
s
.49333 .62259 m .49042 .62442 L .48857 .62661 L 0 .832 .136 r
F
0 g
.48959 .62713 m
.49122 .62578 L
s
.49333 .62259 m .4942 .62082 L .49042 .62442 L 0 .832 .136 r
F
.49333 .62259 m .49765 .61747 L .4942 .62082 L F
.49333 .62259 m .49847 .61661 L .49765 .61747 L F
0 g
.49663 .6188 m
.49829 .61683 L
s
.49192 .62513 m
.49333 .62259 L
s
.2864 .7364 m .2753 .73033 L .27501 .73679 L 0 1 .528 r
F
.2864 .7364 m .27894 .72552 L .2753 .73033 L F
.2864 .7364 m .2835 .72559 L .27894 .72552 L F
.2864 .7364 m .28669 .73026 L .2835 .72559 L F
0 g
.28276 .74118 m
.2864 .7364 L
s
.44907 1.03212 m .45143 1.03823 L .45285 1.03699 L 0 .857 .474 r
F
.46567 1.04441 m .45285 1.03699 L .45143 1.03823 L 0 .813 .468 r
F
0 g
.45143 1.03823 m
.4557 1.04272 L
s
.44522 1.03523 m
.45143 1.03823 L
s
.41804 1.00431 m .41854 1.01093 L .42073 1.00973 L 0 .934 .473 r
F
.43314 1.01871 m .42073 1.00973 L .41854 1.01093 L 0 .897 .475 r
F
0 g
.41854 1.01093 m
.4218 1.0161 L
s
.4123 1.00727 m
.41854 1.01093 L
s
.5297 .97325 m
.53406 .97356 L
s
.53644 .97334 m .53482 .97334 L .53413 .97356 L 0 .669 .233 r
F
0 g
.53434 .97349 m
.53482 .97334 L
s
.32354 .63543 m .31647 .62663 L .31341 .63476 L 0 1 .476 r
F
0 g
.31341 .63476 m
.31419 .64098 L
s
.32354 .63543 m .32175 .62089 L .31647 .62663 L 0 1 .476 r
F
.32354 .63543 m .3257 .62137 L .32175 .62089 L F
.32354 .63543 m .32647 .62761 L .3257 .62137 L F
0 g
.32354 .63543 m
.32443 .64135 L
s
.31828 .64115 m
.32354 .63543 L
s
.39653 .92544 m
.40218 .92464 L
s
.41429 .92168 m .40141 .92387 L .40218 .92464 L 0 .875 .253 r
F
0 g
.40218 .92464 m
.40218 .92464 L
s
.53321 .79086 m
.53424 .79621 L
s
.53235 .79707 m
.53263 .79952 L
s
.22142 .67986 m .2117 .6693 L .21004 .68012 L 0 1 .489 r
F
.22142 .67986 m .21635 .66121 L .2117 .6693 L F
.22142 .67986 m .22088 .66128 L .21635 .66121 L F
.22142 .67986 m .22305 .66929 L .22088 .66128 L F
0 g
.21677 .6879 m
.22142 .67986 L
s
.22142 .67986 m
.22362 .68762 L
s
.40128 .7078 m .3924 .71127 L .39695 .71071 L 0 1 .512 r
F
0 g
.39695 .71071 m
.39982 .71287 L
s
.70765 .90703 m
.70891 .90701 L
s
.22632 .9449 m .21069 .94357 L .21595 .94634 L 0 1 .366 r
F
0 g
.21595 .94634 m
.22293 .9479 L
s
.77153 .83965 m .78013 .8476 L .78253 .83711 L 0 1 .469 r
F
0 g
.7751 .85611 m
.78013 .8476 L
s
.78013 .8476 m
.78157 .85494 L
s
.6846 .92286 m .68953 .9238 L .69373 .91851 L 0 1 .372 r
F
0 g
.68377 .92881 m
.68953 .9238 L
s
.68902 .9269 m
.68953 .9238 L
s
.50651 .7168 m .50729 .65836 L .50489 .664 L 0 .904 .278 r
F
.50651 .7168 m .50932 .67135 L .50729 .65836 L F
0 g
.50729 .65836 m
.50884 .63958 L
s
.50649 .72132 m
.50771 .71589 L
s
.28056 .92676 m
.28554 .92969 L
s
.48419 .63406 m
.48474 .63281 L
s
.48178 .63583 m
.48419 .63406 L
s
.48131 .63617 m
.48178 .63583 L
s
.78848 .91061 m .78888 .91879 L .79515 .91611 L 0 1 .51 r
F
.78848 .91061 m .78467 .91806 L .78888 .91879 L F
0 g
.78806 .92248 m
.78888 .91879 L
s
.44839 .96252 m .44339 .96045 L .4379 .95991 L 0 1 .531 r
F
.45347 .95931 m .44839 .96252 L .45358 .96309 L 0 1 .526 r
F
.45347 .95931 m .44339 .96045 L .44839 .96252 L F
0 g
.44839 .96252 m
.45072 .96513 L
s
.5252 .92461 m .52242 .93117 L .5267 .93717 L 0 .272 .306 r
F
0 g
.51902 .92303 m
.52242 .93117 L
s
.51942 .92989 m
.52242 .93117 L
s
.42207 .91899 m .41956 .92067 L .42257 .91953 L 0 .804 .235 r
F
.42207 .91899 m .41429 .92168 L .41956 .92067 L F
0 g
.41956 .92067 m
.4206 .9211 L
s
.39731 .99179 m .39163 .98533 L .38522 .98132 L 0 1 .476 r
F
.40391 .98899 m .39731 .99179 L .40347 .99577 L 0 .969 .469 r
F
.40391 .98899 m .39163 .98533 L .39731 .99179 L F
0 g
.39731 .99179 m
.39967 .99752 L
s
.64767 1.06714 m
.64774 1.06716 L
s
.79975 .65206 m .80704 .66334 L .81163 .66438 L 0 1 .503 r
F
.79975 .65206 m .80195 .65807 L .80704 .66334 L F
0 g
.80432 .66764 m
.80704 .66334 L
s
.48922 .65913 m .49198 .65163 L .4931 .63741 L 0 1 .295 r
F
0 g
.4931 .63741 m
.49617 .64013 L
s
.36546 .72035 m .35486 .72105 L .35733 .72396 L 0 1 .526 r
F
0 g
.35393 .72752 m
.35733 .72396 L
s
.49891 .72536 m .49307 .73853 L .49608 .731 L 0 .112 .088 r
F
0 g
.49631 .72659 m
.49711 .72523 L
s
.49554 .7271 m
.49637 .72526 L
s
.49513 .72712 m
.49561 .72621 L
s
.49891 .72536 m .49167 .74456 L .49307 .73853 L 0 .112 .088 r
F
.49891 .72536 m .49282 .74504 L .49167 .74456 L F
.49891 .72536 m .49567 .73935 L .49282 .74504 L F
0 g
.49406 .73043 m
.49408 .7304 L
s
.49348 .73021 m
.49411 .72903 L
s
.49401 .72888 m
.49442 .72786 L
s
.49348 .7302 m
.49401 .72888 L
s
.49348 .73021 m
.49348 .7302 L
s
.49891 .72536 m .4983 .73131 L .49567 .73935 L 0 .112 .088 r
F
0 g
.49766 .72582 m
.49781 .72532 L
s
.49891 .72536 m .49968 .72532 L .4983 .73131 L 0 .112 .088 r
F
0 g
.49891 .72536 m
.49943 .72334 L
s
.49968 .72532 m
.50077 .72242 L
s
.40926 .76566 m .39738 .76855 L .39768 .76865 L 0 0 0 r
F
.40926 .76566 m .40064 .76771 L .39738 .76855 L F
.40926 .76566 m .4053 .76668 L .40064 .76771 L F
.40926 .76566 m .409 .76581 L .4053 .76668 L F
0 g
.40926 .76566 m
.4109 .76511 L
s
.54642 1.07964 m .54582 1.07639 L .54825 1.07634 L 0 0 0 r
F
.54642 1.07964 m .54351 1.07715 L .54582 1.07639 L F
0 g
.54447 1.07556 m
.54582 1.07639 L
s
.51225 .71713 m .51095 .73699 L .51128 .72619 L 0 .22 .121 r
F
.51225 .71713 m .51179 .74439 L .51095 .73699 L F
0 g
.51085 .71865 m
.51178 .71147 L
s
.51225 .71713 m .51324 .74339 L .51179 .74439 L 0 .22 .121 r
F
.51225 .71713 m .51421 .73424 L .51324 .74339 L F
.51225 .71713 m .51406 .72311 L .51421 .73424 L F
0 g
.51406 .72311 m
.51466 .71356 L
s
.5122 .71759 m
.51225 .71713 L
s
.51178 .71147 m
.51225 .71713 L
s
.51322 .7158 m
.51406 .72311 L
s
.41455 .54382 m .4199 .53636 L .42204 .53191 L 0 1 .229 r
F
0 g
.4199 .53636 m
.42403 .53164 L
s
.80174 .61033 m .81068 .60702 L .81523 .60865 L 0 0 0 r
F
.80174 .61033 m .80491 .60773 L .81068 .60702 L F
0 g
.8087 .60508 m
.81068 .60702 L
s
.52754 .70964 m
.52923 .71171 L
s
.402 .56166 m .39279 .56889 L .39597 .56776 L 0 1 .304 r
F
.402 .56166 m .3943 .56471 L .39279 .56889 L F
0 g
.39597 .56776 m
.39729 .56847 L
s
.402 .56166 m .39951 .55801 L .3943 .56471 L 0 1 .304 r
F
.402 .56166 m .40555 .55191 L .39951 .55801 L F
.402 .56166 m .40841 .55048 L .40555 .55191 L F
.402 .56166 m .40688 .55466 L .40841 .55048 L F
0 g
.40072 .56612 m
.402 .56166 L
s
.39597 .56776 m
.402 .56166 L
s
.68282 1.07311 m .67466 1.07168 L .68266 1.07228 L 0 0 0 r
F
.68282 1.07311 m .67182 1.07141 L .67466 1.07168 L F
0 g
.67043 1.07136 m
.67255 1.07152 L
s
.20701 .78483 m .19444 .7792 L .1957 .7853 L 0 1 .538 r
F
0 g
.1957 .7853 m
.20002 .78964 L
s
.48278 1.0554 m .48096 1.05822 L .4869 1.06049 L 0 .762 .451 r
F
0 g
.48096 1.05822 m
.48599 1.06227 L
s
.53066 .58909 m .5349 .58433 L .53895 .58433 L 0 .113 .083 r
F
0 g
.5349 .58433 m
.53721 .57764 L
s
.82013 .80294 m .81868 .8149 L .82093 .82352 L 0 1 .476 r
F
0 g
.81551 .83217 m
.82093 .82352 L
s
.30008 .93765 m .28455 .93829 L .2852 .93915 L 0 .758 .238 r
F
.30008 .93765 m .28868 .9377 L .28455 .93829 L F
.30008 .93765 m .29535 .93742 L .28868 .9377 L F
.31002 .93564 m .29535 .93742 L .30008 .93765 L 0 .718 .223 r
F
0 g
.30008 .93765 m
.30622 .93717 L
s
.30008 .93765 m
.30068 .93848 L
s
.53644 .97334 m
.53827 .9735 L
s
.53827 .9735 m
.53868 .97347 L
s
.53868 .97347 m
.53957 .97343 L
s
.27501 .73679 m .2639 .73036 L .26361 .73714 L 0 1 .528 r
F
.27501 .73679 m .26754 .72532 L .2639 .73036 L F
.27501 .73679 m .2721 .7254 L .26754 .72532 L F
.27501 .73679 m .2753 .73033 L .2721 .7254 L F
0 g
.27137 .7418 m
.27501 .73679 L
s
.27501 .73679 m
.2782 .74144 L
s
.76209 1.06306 m .75501 1.06686 L .7634 1.06437 L 0 .825 .246 r
F
.76209 1.06306 m .75157 1.06721 L .75501 1.06686 L F
0 g
.76016 1.06641 m
.76085 1.06598 L
s
.75102 1.06831 m
.75501 1.06686 L
s
.48068 .73619 m .47255 .74307 L .47698 .73883 L 0 .003 .051 r
F
.48068 .73619 m .46973 .74694 L .47255 .74307 L F
.48068 .73619 m .47041 .74784 L .46973 .74694 L F
.48068 .73619 m .47412 .74519 L .47041 .74784 L F
.48068 .73619 m .47839 .74075 L .47412 .74519 L F
0 g
.4776 .73807 m
.4781 .73746 L
s
.47698 .73883 m
.4776 .73807 L
s
.48068 .73619 m .48119 .73689 L .47839 .74075 L 0 .003 .051 r
F
0 g
.48068 .73619 m
.48361 .73146 L
s
.4781 .73746 m
.48001 .73511 L
s
.47698 .73883 m
.47875 .73756 L
s
.47875 .73756 m
.48068 .73619 L
s
.48119 .73689 m
.48189 .73614 L
s
.32244 .92677 m .306 .92098 L .31022 .92932 L 0 1 .474 r
F
0 g
.31022 .92932 m
.3123 .93099 L
s
.54642 1.07964 m .54825 1.07634 L .5495 1.07741 L 0 0 0 r
F
0 g
.54825 1.07634 m
.55065 1.0746 L
s
.67006 .61582 m
.67008 .61645 L
s
.67028 .62603 m
.67028 .62648 L
s
.67028 .62648 m
.67029 .62687 L
s
.67029 .62687 m
.6703 .62707 L
s
.35144 .93176 m .33733 .93032 L .33806 .93227 L 0 1 .438 r
F
.35144 .93176 m .34101 .92956 L .33733 .93032 L F
.35144 .93176 m .34706 .93018 L .34101 .92956 L F
.36021 .9295 m .34706 .93018 L .35144 .93176 L 0 1 .411 r
F
0 g
.35144 .93176 m
.35729 .93221 L
s
.35144 .93176 m
.35214 .9337 L
s
.20701 .78483 m .19692 .77464 L .19444 .7792 L 0 1 .538 r
F
.20701 .78483 m .2015 .77468 L .19692 .77464 L F
.20701 .78483 m .20582 .77906 L .2015 .77468 L F
.21832 .78436 m .20582 .77906 L .20701 .78483 L 0 1 .536 r
F
0 g
.20452 .78935 m
.20701 .78483 L
s
.20701 .78483 m
.21128 .78892 L
s
.41455 .54382 m .40555 .55191 L .40841 .55048 L 0 1 .229 r
F
0 g
.41079 .55045 m
.41267 .54843 L
s
.41455 .54382 m .40769 .54746 L .40555 .55191 L 0 1 .229 r
F
0 g
.40688 .55466 m
.41079 .55045 L
s
.41455 .54382 m .4134 .5401 L .40769 .54746 L 0 1 .229 r
F
.41455 .54382 m .41955 .53343 L .4134 .5401 L F
.41455 .54382 m .42204 .53191 L .41955 .53343 L F
0 g
.40841 .55048 m
.41455 .54382 L
s
.41267 .54843 m
.41455 .54382 L
s
.42204 .53191 m
.42822 .52494 L
s
.4199 .53636 m
.42204 .53191 L
s
.40688 .55466 m
.40841 .55048 L
s
.28243 .6552 m .27378 .64543 L .27126 .65488 L 0 1 .478 r
F
.28243 .6552 m .27898 .63859 L .27378 .64543 L F
.28243 .6552 m .28337 .63894 L .27898 .63859 L F
.28243 .6552 m .28485 .64607 L .28337 .63894 L F
0 g
.28243 .6552 m
.28399 .66205 L
s
.27725 .66202 m
.28243 .6552 L
s
.51214 .87451 m
.51214 .87451 L
s
.51214 .87451 m
.51214 .87451 L
s
.75435 .86709 m .76432 .85846 L .76001 .85956 L 0 1 .481 r
F
.74369 .87027 m .75435 .86709 L .75354 .8614 L 0 1 .474 r
F
0 g
.75435 .86709 m
.75981 .85981 L
s
.50686 .48658 m .5013 .49339 L .50161 .49374 L 0 0 0 r
F
.50686 .48658 m .50642 .4864 L .5013 .49339 L F
.50686 .48658 m .51355 .47746 L .50642 .4864 L F
0 g
.471 .74126 m
.47141 .74099 L
s
.46776 .74342 m
.471 .74126 L
s
.48274 .8962 m .47381 .90076 L .47496 .89967 L 0 0 0 r
F
0 g
.4708 .90191 m
.47496 .89967 L
s
.51812 1.07358 m .52415 1.07621 L .52392 1.07569 L 0 .834 .409 r
F
0 g
.5184 1.07532 m
.52415 1.07621 L
s
.68947 .62211 m
.69002 .61992 L
s
.69002 .61992 m
.69055 .61784 L
s
.69055 .61784 m
.69071 .61721 L
s
.69146 .61422 m
.69175 .61305 L
s
.68941 .62235 m
.68944 .62223 L
s
.68944 .62223 m
.68947 .62211 L
s
.40128 .7078 m .38997 .70906 L .3924 .71127 L 0 1 .512 r
F
0 g
.38838 .71439 m
.3924 .71127 L
s
.40128 .7078 m .3913 .70557 L .38997 .70906 L 0 1 .512 r
F
.40128 .7078 m .39564 .70265 L .3913 .70557 L F
.40128 .7078 m .40008 .70225 L .39564 .70265 L F
.40128 .7078 m .4025 .70446 L .40008 .70225 L F
0 g
.40128 .7078 m
.40379 .70977 L
s
.39695 .71071 m
.40128 .7078 L
s
.5044 .96951 m .50355 .97176 L .50761 .9716 L 0 .991 .405 r
F
.5044 .96951 m .49833 .97114 L .50355 .97176 L F
.77549 .77001 m .77797 .76796 L .78264 .77103 L 0 .03 0 r
F
.77549 .77001 m .7749 .76752 L .77797 .76796 L F
0 g
.77325 .76534 m
.77797 .76796 L
s
.60022 .6008 m
.60091 .60004 L
s
.59816 .60304 m
.60022 .6008 L
s
.60091 .60004 m
.60091 .60004 L
s
.60091 .60004 m
.60339 .59734 L
s
.32189 .93375 m
.32196 .9338 L
s
.32179 .93368 m
.32189 .93375 L
s
.3424 .94437 m .32815 .93228 L .32894 .93876 L 0 1 .473 r
F
0 g
.32196 .9338 m
.32894 .93876 L
s
.32202 .93371 m
.32218 .93372 L
s
.32218 .93372 m
.32841 .93437 L
s
.50952 .60513 m .51337 .6008 L .51638 .5992 L 0 0 .005 r
F
0 g
.51337 .6008 m
.51614 .59643 L
s
.27126 .65488 m .2615 .66187 L .266 .66192 L 0 1 .48 r
F
0 g
.266 .66192 m
.26828 .6691 L
s
.51633 .97117 m .5114 .97247 L .51664 .9728 L 0 .808 .324 r
F
.51633 .97117 m .50761 .9716 L .5114 .97247 L F
0 g
.66406 1.07037 m
.67182 1.07141 L
s
.66406 1.07039 m
.66754 1.07101 L
s
.75689 .9161 m .76779 .91507 L .76356 .9143 L 0 1 .507 r
F
.74646 .91381 m .75689 .9161 L .75721 .91311 L 0 1 .497 r
F
.5044 .96951 m .49491 .96989 L .49833 .97114 L 0 .991 .405 r
F
.44384 .75432 m .43559 .75723 L .44024 .75524 L 0 0 0 r
F
0 g
.44024 .75524 m
.44212 .75419 L
s
.78848 .91061 m .78449 .91456 L .78467 .91806 L 0 1 .51 r
F
0 g
.78402 .91828 m
.78467 .91806 L
s
.21832 .78436 m .20835 .77475 L .20582 .77906 L 0 1 .536 r
F
.21832 .78436 m .21292 .7748 L .20835 .77475 L F
.21832 .78436 m .2172 .77893 L .21292 .7748 L F
.22964 .78389 m .2172 .77893 L .21832 .78436 L 0 1 .534 r
F
0 g
.21579 .78863 m
.21832 .78436 L
s
.21832 .78436 m
.22254 .7882 L
s
.67413 .93429 m
.6786 .93132 L
s
.53128 .70871 m
.53182 .71007 L
s
.81014 .91297 m .81643 .91911 L .82095 .91411 L 0 1 .522 r
F
0 g
.80991 .92232 m
.81643 .91911 L
s
.51633 .97117 m .51664 .9728 L .52037 .97262 L 0 .808 .324 r
F
0 g
.21636 .91716 m
.22222 .92158 L
s
.40391 .98899 m .38952 .9797 L .39163 .98533 L 0 .969 .469 r
F
0 g
.38522 .98132 m
.39163 .98533 L
s
.44957 .67301 m .44137 .67608 L .44516 .67557 L 0 1 .448 r
F
.44957 .67301 m .44033 .67424 L .44137 .67608 L F
0 g
.44516 .67557 m
.44663 .67735 L
s
.44957 .67301 m .44273 .67128 L .44033 .67424 L 0 1 .448 r
F
.44957 .67301 m .44716 .66871 L .44273 .67128 L F
.44957 .67301 m .45064 .66826 L .44716 .66871 L F
.44957 .67301 m .45168 .67011 L .45064 .66826 L F
0 g
.44957 .67301 m
.45083 .67478 L
s
.44516 .67557 m
.44957 .67301 L
s
.45168 .67011 m
.45586 .6676 L
s
.73302 .87421 m .74062 .8789 L .74369 .87027 L 0 1 .466 r
F
0 g
.73522 .88636 m
.74062 .8789 L
s
.74062 .8789 m
.74145 .88455 L
s
.51443 .83607 m .51236 .85559 L .51474 .85997 L 0 .377 .304 r
F
0 g
.51443 .83607 m
.51506 .83288 L
s
.51073 .84553 m
.51236 .85559 L
s
.51042 .85794 m
.51236 .85559 L
s
.50986 .71993 m .51081 .7189 L .51128 .72619 L 0 .207 .114 r
F
0 g
.51081 .7189 m
.51085 .71865 L
s
.51443 .83607 m
.51462 .83725 L
s
.51462 .83725 m
.51486 .83873 L
s
.51577 .84434 m
.51606 .84613 L
s
.45846 .74765 m
.45915 .74733 L
s
.45558 .74902 m
.45846 .74765 L
s
.38997 .70906 m
.3924 .71127 L
s
.35486 .72105 m .3467 .72468 L .35095 .72442 L 0 1 .528 r
F
0 g
.35095 .72442 m
.35393 .72752 L
s
.46567 1.04441 m .46893 1.05011 L .46994 1.0489 L 0 .813 .468 r
F
.48278 1.0554 m .46994 1.0489 L .46893 1.05011 L 0 .762 .451 r
F
0 g
.46893 1.05011 m
.47365 1.0541 L
s
.46282 1.04746 m
.46893 1.05011 L
s
.49896 .67829 m .50132 .67254 L .5025 .65566 L 0 1 .285 r
F
.45347 .95931 m .45358 .96309 L .45549 .96179 L 0 1 .526 r
F
.46539 .96373 m .45549 .96179 L .45358 .96309 L 0 1 .519 r
F
0 g
.45358 .96309 m
.45609 .96533 L
s
.44839 .96252 m
.45358 .96309 L
s
.37281 .59456 m
.37831 .58939 L
s
.40391 .98899 m .40347 .99577 L .40601 .99463 L 0 .969 .469 r
F
.41804 1.00431 m .40601 .99463 L .40347 .99577 L 0 .934 .473 r
F
0 g
.40347 .99577 m
.40617 1.00119 L
s
.39731 .99179 m
.40347 .99577 L
s
.26361 .73714 m .2525 .73035 L .25222 .73745 L 0 1 .528 r
F
.26361 .73714 m .25614 .72508 L .2525 .73035 L F
.26361 .73714 m .2607 .72518 L .25614 .72508 L F
.26361 .73714 m .2639 .73036 L .2607 .72518 L F
0 g
.25998 .74238 m
.26361 .73714 L
s
.26361 .73714 m
.26681 .74204 L
s
.76055 .84278 m .76432 .85846 L .76926 .84994 L 0 1 .463 r
F
.76055 .84278 m .76001 .85956 L .76432 .85846 L F
0 g
.76432 .85846 m
.76501 .86455 L
s
.71267 .90548 m .72153 .91089 L .72555 .90886 L 0 .989 .43 r
F
0 g
.71481 .91114 m
.72153 .91089 L
s
.41429 .92168 m .40474 .92284 L .40141 .92387 L 0 .875 .253 r
F
.41429 .92168 m .41027 .9219 L .40474 .92284 L F
.42207 .91899 m .41027 .9219 L .41429 .92168 L 0 .804 .235 r
F
0 g
.41429 .92168 m
.41503 .92246 L
s
.41429 .92168 m
.41956 .92067 L
s
.45433 .49063 m .4611 .48312 L .46523 .47906 L 0 0 0 r
F
0 g
.4611 .48312 m
.46548 .47775 L
s
.22964 .78389 m .21978 .77488 L .2172 .77893 L 0 1 .534 r
F
.22964 .78389 m .22435 .77494 L .21978 .77488 L F
.22964 .78389 m .22858 .77881 L .22435 .77494 L F
.24095 .78342 m .22858 .77881 L .22964 .78389 L 0 1 .531 r
F
0 g
.22705 .78791 m
.22964 .78389 L
s
.22964 .78389 m
.23381 .78747 L
s
.23706 .93535 m .22125 .92796 L .22175 .932 L 0 1 .526 r
F
.23706 .93535 m .22554 .92752 L .22125 .92796 L F
.23706 .93535 m .23233 .9307 L .22554 .92752 L F
.24746 .93379 m .23233 .9307 L .23706 .93535 L 0 1 .522 r
F
0 g
.23706 .93535 m
.23752 .93935 L
s
.23706 .93535 m
.24367 .93829 L
s
.39768 .76865 m .38576 .77077 L .3861 .77115 L 0 .718 .212 r
F
.39768 .76865 m .38899 .76989 L .38576 .77077 L F
0 g
.3861 .77115 m
.38983 .77062 L
s
.39768 .76865 m .39365 .76908 L .38899 .76989 L 0 .718 .212 r
F
.39768 .76865 m .39738 .76855 L .39365 .76908 L F
0 g
.39445 .76954 m
.39768 .76865 L
s
.39768 .76865 m
.40138 .76778 L
s
.49256 .96726 m .49056 .96995 L .49491 .96989 L 0 1 .458 r
F
.49256 .96726 m .48542 .96899 L .49056 .96995 L F
.47326 .58469 m .48035 .56425 L .47905 .56055 L 0 1 .306 r
F
.47326 .58469 m .47787 .57458 L .48035 .56425 L F
0 g
.48035 .56425 m
.48487 .55883 L
s
.47899 .56989 m
.48035 .56425 L
s
.51812 1.07358 m .51064 1.0713 L .5049 1.07042 L 0 .834 .409 r
F
.50088 .72516 m .49567 .73935 L .4983 .73131 L 0 .133 .093 r
F
0 g
.4985 .72618 m
.49891 .72536 L
s
.49601 .7271 m
.49631 .72659 L
s
.49728 .72706 m
.49766 .72582 L
s
.50088 .72516 m .49462 .7457 L .49567 .73935 L 0 .133 .093 r
F
.50088 .72516 m .49587 .74608 L .49462 .7457 L F
0 g
.49411 .72903 m
.49513 .72712 L
s
.49408 .7304 m
.49554 .7271 L
s
.50088 .72516 m .49847 .73988 L .49587 .74608 L 0 .133 .093 r
F
0 g
.49608 .731 m
.49728 .72706 L
s
.49406 .73043 m
.49601 .7271 L
s
.50088 .72516 m .50067 .73128 L .49847 .73988 L 0 .133 .093 r
F
0 g
.49959 .72571 m
.49968 .72532 L
s
.50088 .72516 m .5017 .72499 L .50067 .73128 L 0 .133 .093 r
F
0 g
.50088 .72516 m
.50118 .7237 L
s
.5017 .72499 m
.50232 .72308 L
s
.54541 .43825 m .54065 .44713 L .54001 .4427 L 0 .257 .085 r
F
.54541 .43825 m .54737 .45022 L .54065 .44713 L F
0 g
.53898 .45314 m
.54275 .4481 L
s
.54548 .45181 m .5533 .44564 L .55996 .44279 L 0 0 .039 r
F
.54548 .45181 m .55996 .44279 L .56095 .44494 L F
.54548 .45181 m .56095 .44494 L .56077 .44529 L F
.54541 .43825 m .55994 .43982 L .56097 .44499 L 0 .257 .085 r
F
.55564 .45078 m .55838 .44794 L .55568 .45078 L 0 0 .039 r
F
.55838 .44794 m .55832 .44803 L .55568 .45078 L F
.54548 .45181 m .56077 .44529 L .55564 .45078 L F
.56077 .44529 m .56099 .44506 L .56106 .44542 L 0 .257 .085 r
F
.56077 .44529 m .56106 .44517 L .55564 .45078 L 0 0 .039 r
F
.54737 .45022 m .55568 .44989 L .55666 .45035 L 0 .238 .071 r
F
.5474 .45588 m .55561 .45082 L .55541 .45121 L 0 0 .019 r
F
.55533 .45201 m .55678 .45041 L .5557 .45184 L F
.5474 .45588 m .55605 .45084 L .55533 .45201 L F
.55605 .45084 m .55678 .45041 L .55533 .45201 L F
.55299 .45588 m .56387 .45796 L .55813 .46107 L 0 .238 .071 r
F
.54548 .45181 m .55564 .45078 L .5474 .45588 L 0 0 .039 r
F
.55564 .45078 m .55568 .45078 L .55561 .45082 L F
.55564 .45078 m .55561 .45082 L .5474 .45588 L F
.54919 .45967 m .55299 .45588 L .54934 .46043 L 0 .238 .071 r
F
.5557 .45184 m .55678 .45041 L .56275 .4532 L F
.5557 .45184 m .5562 .45193 L .55442 .45353 L F
.5562 .45193 m .56275 .4532 L .55442 .45353 L F
.55475 .45368 m .56275 .4532 L .56387 .45796 L F
.55442 .45353 m .555 .4535 L .55475 .45368 L F
.555 .4535 m .56275 .4532 L .55475 .45368 L F
.5474 .45588 m .55224 .45547 L .54866 .45803 L 0 0 .019 r
F
.54898 .45857 m .55174 .45616 L .54919 .45967 L 0 .238 .071 r
F
.55224 .45547 m .55255 .45545 L .54866 .45803 L 0 0 .019 r
F
.55174 .45616 m .55299 .45588 L .54919 .45967 L 0 .238 .071 r
F
.55255 .45545 m .55299 .45588 L .55174 .45616 L F
.55255 .45545 m .55442 .45353 L .55299 .45588 L F
.55224 .45547 m .55274 .45526 L .55255 .45545 L 0 0 .019 r
F
.5474 .45588 m .55442 .45353 L .55224 .45547 L F
.55442 .45353 m .56387 .45796 L .55299 .45588 L 0 .238 .071 r
F
.55442 .45353 m .56381 .45038 L .55224 .45547 L 0 0 .019 r
F
.5474 .45588 m .5557 .45184 L .55442 .45353 L F
.54737 .45022 m .55442 .45353 L .55255 .45545 L 0 .238 .071 r
F
.55255 .45545 m .56381 .45038 L .55808 .45498 L 0 0 .019 r
F
.55274 .45526 m .56381 .45038 L .55255 .45545 L F
.55299 .45588 m .55813 .46107 L .55058 .46052 L 0 .238 .071 r
F
.55299 .45588 m .55058 .46052 L .54934 .46043 L F
.55255 .45545 m .55808 .45498 L .55014 .45755 L 0 0 .019 r
F
.55255 .45545 m .55014 .45755 L .54866 .45803 L F
.55238 .45527 m .55255 .45545 L .55174 .45616 L 0 .238 .071 r
F
.54737 .45022 m .55238 .45527 L .55174 .45616 L F
.54866 .45803 m .55014 .45755 L .54898 .45857 L 0 0 .019 r
F
.54737 .45022 m .55174 .45616 L .54898 .45857 L 0 .238 .071 r
F
.54898 .45857 m .55808 .45498 L .54933 .45917 L 0 0 .019 r
F
.55014 .45755 m .55808 .45498 L .54898 .45857 L F
.55442 .45353 m .56271 .44842 L .56381 .45038 L F
.5557 .45184 m .56271 .44842 L .55442 .45353 L F
.54737 .45022 m .5557 .45184 L .55442 .45353 L 0 .238 .071 r
F
.55541 .45121 m .55568 .45078 L .55678 .45041 L 0 0 .019 r
F
.55561 .45082 m .55568 .45078 L .55541 .45121 L F
.5557 .45184 m .55678 .45041 L .56271 .44842 L F
.55561 .45182 m .55666 .45035 L .55678 .45041 L 0 .238 .071 r
F
.55561 .45182 m .55678 .45041 L .5557 .45184 L F
.54737 .45022 m .55666 .45035 L .55561 .45182 L F
.55838 .44794 m .56106 .44517 L .55832 .44803 L 0 0 .039 r
F
.56077 .44529 m .56097 .44499 L .56099 .44506 L 0 .257 .085 r
F
.56077 .44529 m .56095 .44494 L .56097 .44499 L 0 0 .039 r
F
.54541 .43825 m .56097 .44499 L .56077 .44529 L 0 .257 .085 r
F
.56077 .44529 m .56097 .44499 L .56106 .44517 L 0 0 .039 r
F
.54541 .43825 m .56077 .44529 L .55568 .44989 L 0 .257 .085 r
F
.56077 .44529 m .56106 .44542 L .56045 .44593 L F
.56077 .44529 m .56045 .44593 L .55568 .44989 L F
.54541 .43825 m .55568 .44989 L .54737 .45022 L F
0 g
.53905 .43553 m
.54541 .43825 L
s
.55324 .43675 m
.55994 .43982 L
s
.55994 .43982 m
.56185 .43842 L
s
.56185 .43842 m
.56418 .43671 L
s
.45347 .95931 m .44136 .95797 L .44339 .96045 L 0 1 .526 r
F
0 g
.4379 .95991 m
.44339 .96045 L
s
.42257 .91953 m
.42788 .91811 L
s
.43917 .91445 m .4272 .91789 L .42788 .91811 L 0 .779 .212 r
F
0 g
.42788 .91811 m
.42788 .91811 L
s
.38784 .92689 m .3745 .92748 L .37526 .92874 L 0 1 .34 r
F
.38784 .92689 m .37795 .9266 L .3745 .92748 L F
.38784 .92689 m .38368 .92634 L .37795 .9266 L F
.39601 .92441 m .38368 .92634 L .38784 .92689 L 0 .961 .289 r
F
0 g
.38784 .92689 m
.39335 .9265 L
s
.38784 .92689 m
.38858 .92814 L
s
.48199 .54978 m .47588 .55295 L .47714 .55571 L 0 1 .25 r
F
0 g
.48199 .54979 m
.48199 .54979 L
s
.48199 .54978 m .4792 .54319 L .47588 .55295 L 0 1 .25 r
F
.48199 .54978 m .48486 .53297 L .4792 .54319 L F
.79975 .65206 m .81163 .66438 L .81338 .66037 L 0 1 .503 r
F
0 g
.80195 .65807 m
.80704 .66334 L
s
.80016 .66167 m
.80195 .65807 L
s
.81163 .66438 m
.8158 .6705 L
s
.36288 .96056 m .35176 .94855 L .34833 .94946 L 0 1 .472 r
F
.36288 .96056 m .358 .95331 L .35176 .94855 L F
.371 .95817 m .36288 .96056 L .3689 .96524 L 0 1 .467 r
F
.371 .95817 m .358 .95331 L .36288 .96056 L F
0 g
.36288 .96056 m
.36416 .96675 L
s
.4778 .96728 m .47278 .96597 L .46789 .96597 L 0 1 .506 r
F
0 g
.46789 .96597 m
.47278 .96597 L
s
.4778 .96728 m
.48076 .96922 L
s
.67032 .62786 m
.67049 .62762 L
s
.67049 .62762 m
.67053 .62756 L
s
.67053 .62756 m
.67066 .62738 L
s
.67112 .62673 m
.67171 .6259 L
s
.35425 .61096 m
.35959 .60578 L
s
.24095 .78342 m .2312 .77502 L .22858 .77881 L 0 1 .531 r
F
.24095 .78342 m .23577 .77507 L .2312 .77502 L F
.24095 .78342 m .23995 .77868 L .23577 .77507 L F
.25227 .78294 m .23995 .77868 L .24095 .78342 L 0 1 .527 r
F
0 g
.23832 .78718 m
.24095 .78342 L
s
.24095 .78342 m
.24508 .78674 L
s
.50986 .71993 m .5077 .73875 L .50852 .72842 L 0 .207 .114 r
F
.50986 .71993 m .50816 .74611 L .5077 .73875 L F
0 g
.50751 .72161 m
.50775 .71582 L
s
.50986 .71993 m .50961 .74556 L .50816 .74611 L 0 .207 .114 r
F
0 g
.50848 .72102 m
.50951 .71521 L
s
.50986 .71993 m .51095 .73699 L .50961 .74556 L 0 .207 .114 r
F
0 g
.50968 .72102 m
.50979 .72036 L
s
.50986 .71993 m .51128 .72619 L .51095 .73699 L 0 .207 .114 r
F
0 g
.51081 .7189 m
.51128 .72619 L
s
.50979 .72036 m
.50986 .71993 L
s
.50975 .71385 m
.50986 .71993 L
s
.51128 .72619 m
.5122 .71759 L
s
.36546 .72035 m .35583 .71681 L .35486 .72105 L 0 1 .526 r
F
.36546 .72035 m .3597 .71353 L .35583 .71681 L F
.36546 .72035 m .3639 .7134 L .3597 .71353 L F
.36546 .72035 m .36637 .71633 L .3639 .7134 L F
0 g
.36159 .72362 m
.36546 .72035 L
s
.80889 .80458 m .81427 .82427 L .81868 .8149 L 0 1 .471 r
F
.80889 .80458 m .80984 .82484 L .81427 .82427 L F
0 g
.81427 .82427 m
.81551 .83217 L
s
.371 .95817 m .3689 .96524 L .37207 .96425 L 0 1 .467 r
F
.3835 .9754 m .37207 .96425 L .3689 .96524 L 0 1 .471 r
F
0 g
.3689 .96524 m
.37064 .97116 L
s
.36288 .96056 m
.3689 .96524 L
s
.43031 .68908 m .42154 .69232 L .42581 .69174 L 0 1 .485 r
F
.43031 .68908 m .4198 .69046 L .42154 .69232 L F
0 g
.42581 .69174 m
.42798 .69357 L
s
.43031 .68908 m .42174 .68739 L .4198 .69046 L 0 1 .485 r
F
.43031 .68908 m .42624 .68472 L .42174 .68739 L F
.43031 .68908 m .4303 .68423 L .42624 .68472 L F
.43031 .68908 m .43204 .6861 L .4303 .68423 L F
0 g
.43031 .68908 m
.4322 .69079 L
s
.42581 .69174 m
.43031 .68908 L
s
.5216 .97277 m
.52248 .97288 L
s
.52248 .97288 m
.52448 .97313 L
s
.21004 .68012 m .20035 .6693 L .19865 .68037 L 0 1 .491 r
F
0 g
.19865 .68037 m
.2008 .68852 L
s
.21004 .68012 m .20503 .66102 L .20035 .6693 L 0 1 .491 r
F
.21004 .68012 m .20956 .6611 L .20503 .66102 L F
.21004 .68012 m .2117 .6693 L .20956 .6611 L F
0 g
.20537 .68835 m
.21004 .68012 L
s
.21004 .68012 m
.21221 .68808 L
s
.80803 .78639 m .81758 .78932 L .81293 .78729 L 0 .407 .231 r
F
.80803 .78639 m .81958 .79179 L .81758 .78932 L F
.73302 .87421 m .73011 .8825 L .73106 .8877 L 0 1 .466 r
F
0 g
.73011 .8825 m
.73106 .8877 L
s
.72506 .89411 m
.73106 .8877 L
s
.79352 .83506 m .80318 .82579 L .79875 .82649 L 0 1 .48 r
F
.78253 .83711 m .79352 .83506 L .79209 .82768 L 0 1 .475 r
F
.31015 .93143 m .29536 .92293 L .29568 .92777 L 0 1 .532 r
F
.31015 .93143 m .29949 .92225 L .29536 .92293 L F
.31015 .93143 m .30584 .92589 L .29949 .92225 L F
0 g
.31015 .93143 m
.31015 .93143 L
s
.32238 .92893 m .30584 .92589 L .31016 .93143 L 0 1 .532 r
F
0 g
.31016 .93143 m
.31016 .93143 L
s
.35117 .94222 m .34833 .94946 L .35176 .94855 L 0 1 .468 r
F
.35117 .94222 m .3424 .94437 L .34833 .94946 L F
0 g
.34833 .94946 m
.34962 .95566 L
s
.49256 .96726 m .4824 .9674 L .48542 .96899 L 0 1 .458 r
F
0 g
.6531 .67929 m
.65334 .67617 L
s
.65422 .6643 m
.65422 .6643 L
s
.31341 .63476 m .30169 .64026 L .30707 .64059 L 0 1 .478 r
F
0 g
.30707 .64059 m
.30946 .64718 L
s
.27126 .65488 m .26008 .65453 L .2615 .66187 L 0 1 .48 r
F
0 g
.25699 .66918 m
.2615 .66187 L
s
.35486 .72105 m .34426 .72152 L .3467 .72468 L 0 1 .528 r
F
0 g
.34329 .72836 m
.3467 .72468 L
s
.27908 .92052 m .27474 .92647 L .27886 .92575 L 0 1 .532 r
F
.27908 .92052 m .26864 .92216 L .27474 .92647 L F
0 g
.27474 .92647 m
.27542 .93166 L
s
.27886 .92575 m
.28056 .92676 L
s
.6846 .92286 m .68062 .92767 L .68027 .93022 L 0 1 .372 r
F
0 g
.6786 .93132 m
.68027 .93022 L
s
.40615 .94628 m .40433 .95065 L .40721 .94953 L 0 1 .533 r
F
.40615 .94628 m .39872 .94895 L .40433 .95065 L F
.41763 .95375 m .40721 .94953 L .40433 .95065 L 0 1 .534 r
F
0 g
.40433 .95065 m
.40596 .95376 L
s
.49066 .89069 m .48746 .89297 L .48388 .89511 L 0 0 0 r
F
.49382 .89071 m .49066 .89069 L .49391 .88901 L F
.49382 .89071 m .48746 .89297 L .49066 .89069 L F
0 g
.49066 .89069 m
.49222 .88935 L
s
.50023 1.06486 m .49202 1.06379 L .49945 1.06711 L 0 .688 .412 r
F
.50023 1.06486 m .4869 1.06049 L .49202 1.06379 L F
0 g
.48599 1.06227 m
.49202 1.06379 L
s
.25222 .73745 m .24109 .73032 L .24082 .73774 L 0 1 .528 r
F
.25222 .73745 m .24472 .72482 L .24109 .73032 L F
.25222 .73745 m .24929 .72493 L .24472 .72482 L F
.25222 .73745 m .2525 .73035 L .24929 .72493 L F
0 g
.24859 .74292 m
.25222 .73745 L
s
.25222 .73745 m
.25542 .74259 L
s
.25227 .78294 m .24263 .77516 L .23995 .77868 L 0 1 .527 r
F
.25227 .78294 m .2472 .77521 L .24263 .77516 L F
.25227 .78294 m .25133 .77856 L .2472 .77521 L F
.26359 .78245 m .25133 .77856 L .25227 .78294 L 0 1 .521 r
F
0 g
.24959 .78644 m
.25227 .78294 L
s
.25227 .78294 m
.25636 .78599 L
s
.63262 .51418 m
.63301 .51519 L
s
.63185 .51215 m
.63262 .51418 L
s
.63159 .51147 m
.63185 .51215 L
s
.62577 .49618 m
.63159 .51147 L
s
.48129 .61233 m .47548 .60883 L .47722 .61495 L 0 1 .299 r
F
.48129 .61233 m .47729 .59672 L .47548 .60883 L F
0 g
.47982 .62547 m
.48129 .61233 L
s
.41763 .95375 m .41292 .95086 L .40721 .94953 L 0 1 .534 r
F
0 g
.41763 .95375 m
.41925 .95686 L
s
.42457 .95078 m .41763 .95375 L .42317 .955 L 0 1 .532 r
F
.42457 .95078 m .41292 .95086 L .41763 .95375 L F
.36009 .93482 m .3571 .93971 L .36054 .93879 L F
.36009 .93482 m .35131 .93698 L .3571 .93971 L F
0 g
.3571 .93971 m
.35824 .94359 L
s
.49178 .5133 m .50208 .49444 L .49686 .50113 L 0 .96 .154 r
F
0 g
.50208 .49444 m
.50686 .48658 L
s
.44907 1.03212 m .4426 1.02688 L .43639 1.02388 L 0 .857 .474 r
F
.41566 .69823 m .40675 .70154 L .41119 .70098 L 0 1 .502 r
F
0 g
.41119 .70098 m
.41368 .70296 L
s
.39872 .94895 m .38827 .9438 L .38509 .94481 L 0 1 .534 r
F
.39872 .94895 m .39412 .94557 L .38827 .9438 L F
.40615 .94628 m .39412 .94557 L .39872 .94895 L 0 1 .533 r
F
0 g
.39872 .94895 m
.40433 .95065 L
s
.39872 .94895 m
.40001 .95237 L
s
.36901 .92734 m .36589 .92979 L .36933 .92885 L 0 1 .376 r
F
0 g
.36933 .92885 m
.37526 .92874 L
s
.36901 .92734 m .36021 .9295 L .36589 .92979 L 0 1 .376 r
F
0 g
.36589 .92979 m
.36686 .93126 L
s
.3861 .77115 m .3746 .7725 L .37499 .77315 L 0 .765 .235 r
F
.3861 .77115 m .37766 .77156 L .3746 .7725 L F
.3861 .77115 m .38214 .77095 L .37766 .77156 L F
.3861 .77115 m .38575 .77077 L .38214 .77095 L F
0 g
.38304 .77209 m
.3861 .77115 L
s
.50749 .72206 m .50843 .72129 L .50852 .72842 L 0 .191 .108 r
F
0 g
.50843 .72129 m
.50844 .72164 L
s
.50843 .72129 m
.50848 .72102 L
s
.61193 .44491 m .61963 .44703 L .62779 .45243 L 0 .235 .025 r
F
.52371 .90986 m .51835 .91022 L .5214 .91882 L 0 .272 .301 r
F
0 g
.51875 .91815 m
.5214 .91882 L
s
.52371 .90986 m .51808 .90454 L .51835 .91022 L 0 .272 .301 r
F
0 g
.51569 .91022 m
.51835 .91022 L
s
.51835 .91022 m
.5214 .91882 L
s
.44384 .75432 m .43221 .75919 L .43559 .75723 L 0 0 0 r
F
0 g
.43224 .7583 m
.43559 .75723 L
s
.43012 .75924 m
.43224 .7583 L
s
.52568 .70627 m .52753 .70862 L .53004 .6804 L 0 .83 .256 r
F
0 g
.52753 .70862 m
.53004 .6804 L
s
.26359 .78245 m .25405 .77529 L .25133 .77856 L 0 1 .521 r
F
.26359 .78245 m .25862 .77534 L .25405 .77529 L F
.26359 .78245 m .26271 .77842 L .25862 .77534 L F
.27492 .78193 m .26271 .77842 L .26359 .78245 L 0 1 .513 r
F
0 g
.26087 .78569 m
.26359 .78245 L
s
.26359 .78245 m
.26764 .78522 L
s
.50298 .7246 m .49847 .73988 L .50067 .73128 L 0 .154 .098 r
F
0 g
.50071 .72556 m
.50088 .72516 L
s
.49839 .72641 m
.4985 .72618 L
s
.49945 .72634 m
.49959 .72571 L
s
.50298 .7246 m .49779 .74654 L .49847 .73988 L 0 .154 .098 r
F
.50298 .7246 m .49911 .74678 L .49779 .74654 L F
0 g
.49608 .731 m
.49839 .72641 L
s
.50298 .7246 m .50142 .74004 L .49911 .74678 L 0 .154 .098 r
F
0 g
.4983 .73131 m
.49945 .72634 L
s
.4983 .73131 m
.50071 .72556 L
s
.50298 .7246 m .50319 .73085 L .50142 .74004 L 0 .154 .098 r
F
0 g
.50166 .72525 m
.5017 .72499 L
s
.50298 .7246 m .50385 .72425 L .50319 .73085 L 0 .154 .098 r
F
0 g
.50298 .7246 m
.5031 .72378 L
s
.50385 .72425 m
.50412 .72329 L
s
.3424 .94437 m .33182 .93149 L .32815 .93228 L 0 1 .473 r
F
.3424 .94437 m .33793 .93667 L .33182 .93149 L F
.35117 .94222 m .33793 .93667 L .3424 .94437 L 0 1 .468 r
F
0 g
.3424 .94437 m
.34318 .95083 L
s
.3424 .94437 m
.34833 .94946 L
s
.52824 .97238 m .5297 .97325 L .53307 .97314 L 0 .673 .251 r
F
.42457 .95078 m .42317 .955 L .42584 .95376 L 0 1 .532 r
F
.4361 .95708 m .42584 .95376 L .42317 .955 L 0 1 .533 r
F
0 g
.42317 .955 m
.42499 .95782 L
s
.41763 .95375 m
.42317 .955 L
s
.2683 .93077 m .2642 .93482 L .26831 .93414 L 0 1 .513 r
F
0 g
.26831 .93414 m
.27044 .9348 L
s
.2683 .93077 m .25787 .93227 L .2642 .93482 L 0 1 .513 r
F
0 g
.2642 .93482 m
.26513 .93819 L
s
.41566 .69823 m .40468 .69952 L .40675 .70154 L 0 1 .502 r
F
.41566 .69823 m .40637 .69628 L .40468 .69952 L F
.41566 .69823 m .41086 .69352 L .40637 .69628 L F
.41566 .69823 m .41514 .69308 L .41086 .69352 L F
.41566 .69823 m .41719 .6951 L .41514 .69308 L F
0 g
.41566 .69823 m
.41784 .70005 L
s
.41119 .70098 m
.41566 .69823 L
s
.50749 .72206 m .50451 .73971 L .50582 .72993 L 0 .191 .108 r
F
0 g
.50523 .72319 m
.50533 .7222 L
s
.50617 .72274 m
.50639 .72177 L
s
.50749 .72206 m .5046 .74691 L .50451 .73971 L 0 .191 .108 r
F
.50749 .72206 m .50602 .7467 L .5046 .74691 L F
.50749 .72206 m .5077 .73875 L .50602 .7467 L F
0 g
.50741 .72244 m
.50742 .7224 L
s
.50749 .72206 m .50852 .72842 L .5077 .73875 L 0 .191 .108 r
F
0 g
.50742 .7224 m
.50749 .72206 L
s
.50749 .72206 m
.50751 .72161 L
s
.50852 .72842 m
.50968 .72102 L
s
.50844 .72164 m
.50852 .72842 L
s
.43314 1.01871 m .42699 1.01306 L .42073 1.00973 L 0 .897 .475 r
F
.44384 .75432 m .43236 .75983 L .43221 .75919 L 0 0 0 r
F
.44384 .75432 m .43596 .75891 L .43236 .75983 L F
0 g
.43331 .75855 m
.43559 .75723 L
s
.44384 .75432 m .4406 .75705 L .43596 .75891 L 0 0 0 r
F
.44384 .75432 m .44397 .75508 L .4406 .75705 L F
0 g
.44384 .75432 m
.44472 .75369 L
s
.44024 .75524 m
.44384 .75432 L
s
.43204 .6861 m
.43637 .68342 L
s
.77549 .77001 m .78264 .77103 L .78661 .77475 L 0 .03 0 r
F
0 g
.78264 .77103 m
.7832 .77156 L
s
.52096 .70391 m .52286 .70425 L .52508 .6783 L 0 .852 .261 r
F
0 g
.52286 .70425 m
.52508 .6783 L
s
.52508 .6783 m
.52568 .70627 L
s
.77763 .90938 m .77834 .91696 L .78449 .91456 L 0 1 .5 r
F
.77763 .90938 m .77412 .91621 L .77834 .91696 L F
0 g
.77768 .92042 m
.77834 .91696 L
s
.69373 .91851 m .70339 .91183 L .69968 .91338 L 0 1 .421 r
F
0 g
.70285 .91495 m
.70339 .91183 L
s
.70339 .91183 m
.70765 .90703 L
s
.25821 .92382 m .24328 .91297 L .24339 .91858 L 0 1 .533 r
F
.25821 .92382 m .24758 .91245 L .24328 .91297 L F
.25821 .92382 m .25399 .91711 L .24758 .91245 L F
.26864 .92216 m .25399 .91711 L .25821 .92382 L F
0 g
.25821 .92382 m
.25829 .9294 L
s
.25821 .92382 m
.26446 .92829 L
s
.34118 .61737 m .33163 .62198 L .33558 .62231 L 0 1 .486 r
F
0 g
.33558 .62231 m
.33645 .62825 L
s
.48154 .63463 m
.48299 .63345 L
s
.48299 .63345 m
.4835 .63303 L
s
.48527 .63158 m .48857 .62661 L .48484 .62965 L 0 .946 .181 r
F
.48527 .63158 m .48988 .62593 L .48857 .62661 L F
0 g
.48847 .62807 m
.48988 .62593 L
s
.48988 .62593 m
.49333 .62259 L
s
.80174 .61033 m .81523 .60865 L .81619 .61111 L 0 0 0 r
F
0 g
.81523 .60865 m
.82013 .60977 L
s
.80889 .80458 m .80753 .81641 L .80984 .82484 L 0 1 .471 r
F
0 g
.80452 .83344 m
.80984 .82484 L
s
.27492 .78193 m .26548 .77542 L .26271 .77842 L 0 1 .513 r
F
.27492 .78193 m .27005 .77546 L .26548 .77542 L F
.27492 .78193 m .27409 .77826 L .27005 .77546 L F
.28625 .78137 m .27409 .77826 L .27492 .78193 L 0 1 .502 r
F
0 g
.27215 .7849 m
.27492 .78193 L
s
.27492 .78193 m
.27892 .78442 L
s
.37943 .94267 m .36571 .93743 L .36663 .94114 L 0 1 .533 r
F
0 g
.36054 .93879 m
.36663 .94114 L
s
.28091 .93313 m
.28537 .93442 L
s
.50519 .72358 m .5061 .72304 L .50582 .72993 L 0 .173 .103 r
F
0 g
.5061 .72304 m
.50617 .72274 L
s
.50519 .72358 m .50142 .74004 L .50319 .73085 L 0 .173 .103 r
F
0 g
.50297 .72461 m
.50298 .7246 L
s
.50166 .72528 m
.50166 .72525 L
s
.50519 .72358 m .50113 .747 L .50142 .74004 L 0 .173 .103 r
F
.50519 .72358 m .5025 .74704 L .50113 .747 L F
0 g
.50067 .73128 m
.50166 .72528 L
s
.50519 .72358 m .50451 .73971 L .5025 .74704 L 0 .173 .103 r
F
.50519 .72358 m .50582 .72993 L .50451 .73971 L F
0 g
.50519 .72358 m
.50523 .72319 L
s
.50582 .72993 m
.50741 .72244 L
s
.50582 .72993 m
.5061 .72304 L
s
.4792 .54319 m .48851 .52402 L .48771 .52229 L 0 1 .244 r
F
.4792 .54319 m .48486 .53297 L .48851 .52402 L F
0 g
.48851 .52402 m
.49342 .51709 L
s
.48486 .53297 m
.4897 .52708 L
s
.48486 .53297 m
.48851 .52402 L
s
.24082 .73774 m .22968 .73028 L .22941 .73801 L 0 1 .528 r
F
.24082 .73774 m .2333 .72455 L .22968 .73028 L F
.24082 .73774 m .23787 .72466 L .2333 .72455 L F
.24082 .73774 m .24109 .73032 L .23787 .72466 L F
0 g
.23719 .74343 m
.24082 .73774 L
s
.24082 .73774 m
.24403 .74312 L
s
.48093 .96433 m .4778 .96728 L .4824 .9674 L 0 1 .49 r
F
.48093 .96433 m .47278 .96597 L .4778 .96728 L F
.69819 1.07263 m .70989 1.07238 L .70673 1.07253 L 0 .63 .226 r
F
.69052 1.0728 m .69819 1.07263 L .70198 1.0728 L 0 .556 .207 r
F
.37499 .77315 m .36345 .77389 L .36388 .77484 L 0 .796 .252 r
F
0 g
.36388 .77484 m
.36753 .77497 L
s
.37499 .77315 m .36648 .77283 L .36345 .77389 L 0 .796 .252 r
F
.37499 .77315 m .37095 .77236 L .36648 .77283 L F
.37499 .77315 m .3746 .7725 L .37095 .77236 L F
0 g
.37196 .77421 m
.37499 .77315 L
s
.37499 .77315 m
.37861 .77297 L
s
.48721 .46145 m .49473 .45535 L .50012 .45307 L 0 0 .025 r
F
0 g
.49473 .45535 m
.49917 .44994 L
s
.45379 .66724 m .44716 .66871 L .45065 .66826 L 0 1 .441 r
F
.45379 .66724 m .44515 .66836 L .44716 .66871 L F
.45379 .66724 m .44596 .66743 L .44515 .66836 L F
0 g
.45066 .6683 m
.45168 .67011 L
s
.45064 .66826 m
.45066 .6683 L
s
.45379 .66724 m .44911 .6664 L .44596 .66743 L 0 1 .441 r
F
.45379 .66724 m .4525 .66596 L .44911 .6664 L F
.45379 .66724 m .4545 .66632 L .4525 .66596 L F
0 g
.45379 .66724 m
.45586 .6676 L
s
.45065 .66826 m
.45379 .66724 L
s
.4545 .66632 m
.45757 .66533 L
s
.46567 1.04441 m .45895 1.03963 L .45285 1.03699 L 0 .813 .468 r
F
.71742 1.07199 m .70989 1.07238 L .71807 1.07159 L 0 .607 .198 r
F
0 g
.71462 1.07221 m
.71523 1.0721 L
s
.71742 1.07199 m .70673 1.07253 L .70989 1.07238 L 0 .607 .198 r
F
0 g
.70583 1.07261 m
.70989 1.07238 L
s
.34426 .72152 m .33606 .72518 L .34031 .72501 L 0 1 .53 r
F
0 g
.34031 .72501 m
.34329 .72836 L
s
.60463 .44024 m
.61193 .44491 L
s
.60006 .44382 m
.60463 .44024 L
s
.25753 .94073 m .25366 .94295 L .25777 .94231 L 0 .821 .274 r
F
0 g
.25777 .94231 m
.26496 .94273 L
s
.25753 .94073 m .24711 .94209 L .25366 .94295 L 0 .821 .274 r
F
0 g
.25366 .94295 m
.25486 .94457 L
s
.28625 .78137 m .2769 .77552 L .27409 .77826 L 0 1 .502 r
F
.28625 .78137 m .28147 .77555 L .2769 .77552 L F
.28625 .78137 m .28548 .77806 L .28147 .77555 L F
0 g
.28343 .78409 m
.28625 .78137 L
s
.30017 .78061 m .28548 .77806 L .28625 .78137 L 0 1 .484 r
F
0 g
.28625 .78137 m
.29098 .78351 L
s
.77947 .60386 m .79364 .60376 L .7906 .60739 L 0 .123 .007 r
F
0 g
.79364 .60376 m
.7993 .60247 L
s
.79248 .59939 m
.79364 .60376 L
s
.22632 .9449 m .20995 .94122 L .21069 .94357 L 0 1 .366 r
F
.22632 .9449 m .21424 .94087 L .20995 .94122 L F
.22632 .9449 m .22126 .94245 L .21424 .94087 L F
.23671 .94348 m .22126 .94245 L .22632 .9449 L 0 .997 .338 r
F
0 g
.22632 .9449 m
.22702 .94723 L
s
.22632 .9449 m
.23316 .94622 L
s
.3835 .9754 m .37833 .9686 L .37207 .96425 L 0 1 .471 r
F
.3909 .97283 m .3835 .9754 L .38952 .9797 L 0 1 .465 r
F
.3909 .97283 m .37833 .9686 L .3835 .9754 L F
0 g
.3835 .9754 m
.38522 .98132 L
s
.76055 .84278 m .75839 .85285 L .76001 .85956 L 0 1 .463 r
F
0 g
.75839 .85285 m
.76001 .85956 L
s
.75981 .85981 m
.76001 .85956 L
s
.50792 .87854 m .50506 .88116 L .50242 .88296 L 0 0 0 r
F
.50651 .7168 m .50489 .664 L .50368 .6834 L 0 .904 .278 r
F
0 g
.5025 .65566 m
.50489 .664 L
s
.31009 .93353 m .29512 .92987 L .29551 .93259 L 0 1 .49 r
F
.31009 .93353 m .29926 .92924 L .29512 .92987 L F
.31009 .93353 m .30568 .93082 L .29926 .92924 L F
0 g
.31009 .93353 m
.31044 .93618 L
s
.32231 .93109 m .30568 .93082 L .31009 .93353 L 0 1 .474 r
F
0 g
.31009 .93353 m
.31699 .93476 L
s
.73821 .61486 m .74757 .59684 L .75197 .59878 L 0 .227 .079 r
F
.73821 .61486 m .74169 .6037 L .74757 .59684 L F
0 g
.74612 .58843 m
.74757 .59684 L
s
.47729 .59672 m .47787 .57458 L .47326 .58469 L 0 1 .302 r
F
0 g
.47787 .57458 m
.47899 .56989 L
s
.47787 .57458 m
.48228 .57068 L
s
.53438 .97289 m .53482 .97334 L .53644 .97334 L 0 .593 .22 r
F
.53438 .97289 m .53307 .97314 L .53482 .97334 L F
.50023 1.06486 m .49945 1.06711 L .50517 1.06898 L 0 .688 .412 r
F
0 g
.49945 1.06711 m
.5049 1.07042 L
s
.38997 .70906 m .38131 .71236 L .38569 .71197 L 0 1 .519 r
F
0 g
.38569 .71197 m
.38837 .7144 L
s
.30017 .78061 m .28911 .77557 L .28548 .77806 L 0 1 .484 r
F
.30017 .78061 m .29472 .77558 L .28911 .77557 L F
.30017 .78061 m .29946 .77774 L .29472 .77558 L F
0 g
.29653 .78308 m
.30017 .78061 L
s
.31078 .77995 m .29946 .77774 L .30017 .78061 L 0 1 .465 r
F
0 g
.30017 .78061 m
.30387 .78248 L
s
.31341 .63476 m .30009 .63358 L .30169 .64026 L 0 1 .478 r
F
0 g
.29591 .64664 m
.30169 .64026 L
s
.31341 .63476 m .30334 .62498 L .30009 .63358 L 0 1 .478 r
F
.31341 .63476 m .30969 .61912 L .30334 .62498 L F
.31341 .63476 m .31488 .61992 L .30969 .61912 L F
.31341 .63476 m .31647 .62663 L .31488 .61992 L F
0 g
.30707 .64059 m
.31341 .63476 L
s
.36388 .77484 m .35278 .77496 L .35325 .7762 L 0 .893 .281 r
F
.36388 .77484 m .35563 .77377 L .35278 .77496 L F
.36388 .77484 m .35991 .77343 L .35563 .77377 L F
.36388 .77484 m .36345 .77389 L .35991 .77343 L F
0 g
.36102 .77602 m
.36388 .77484 L
s
.53066 .58909 m .53895 .58433 L .54011 .58911 L 0 .113 .083 r
F
0 g
.53895 .58433 m
.54116 .57649 L
s
.5349 .58433 m
.53895 .58433 L
s
.48922 .65913 m .48526 .63271 L .48413 .64694 L 0 1 .295 r
F
0 g
.4835 .63303 m
.48526 .63271 L
s
.61642 .6047 m
.61894 .60658 L
s
.61642 .6047 m
.61642 .6047 L
s
.61575 .6042 m
.61642 .6047 L
s
.61904 .60665 m
.62131 .60835 L
s
.61894 .60658 m
.61904 .60665 L
s
.48565 .73572 m
.48623 .7345 L
s
.50877 .8815 m .50792 .87854 L .51021 .87753 L 0 0 0 r
F
.50877 .8815 m .50506 .88116 L .50792 .87854 L F
0 g
.50792 .87854 m
.5099 .87622 L
s
.53438 .97289 m .53644 .97334 L .537 .97324 L 0 .593 .22 r
F
.38758 .94027 m .38509 .94481 L .38827 .9438 L 0 1 .532 r
F
.38758 .94027 m .37943 .94267 L .38509 .94481 L F
0 g
.38509 .94481 m
.3864 .94824 L
s
.53678 1.07777 m .5435 1.07715 L .54286 1.07811 L 0 .603 .247 r
F
0 g
.53809 1.07648 m
.5435 1.07715 L
s
.54642 1.07964 m .54286 1.07811 L .54351 1.07715 L 0 0 0 r
F
0 g
.54351 1.07715 m
.54582 1.07639 L
s
.68282 1.07311 m .68266 1.07228 L .69052 1.0728 L 0 0 0 r
F
0 g
.67466 1.07168 m
.68266 1.07228 L
s
.76209 1.06306 m .75459 1.06558 L .75157 1.06721 L 0 .825 .246 r
F
0 g
.74266 1.06886 m
.75157 1.06721 L
s
.26008 .65453 m .25024 .66173 L .25475 .66179 L 0 1 .482 r
F
0 g
.25475 .66179 m
.25699 .66918 L
s
.31078 .77995 m .30214 .77557 L .29946 .77774 L 0 1 .465 r
F
.31078 .77995 m .30642 .77554 L .30214 .77557 L F
.31078 .77995 m .31012 .77742 L .30642 .77554 L F
.32139 .77921 m .31012 .77742 L .31078 .77995 L 0 1 .441 r
F
0 g
.30809 .78211 m
.31078 .77995 L
s
.31078 .77995 m
.31444 .78154 L
s
.29098 .92503 m
.29568 .92777 L
s
.50952 .60513 m .50603 .61119 L .50637 .60959 L 0 0 .005 r
F
.50952 .60513 m .50905 .6096 L .50603 .61119 L F
0 g
.50499 .6098 m
.50687 .60753 L
s
.50952 .60513 m .5134 .60585 L .50905 .6096 L 0 0 .005 r
F
.50952 .60513 m .51654 .6014 L .5134 .60585 L F
.50952 .60513 m .51638 .5992 L .51654 .6014 L F
0 g
.50687 .60753 m
.50952 .60513 L
s
.51638 .5992 m
.51914 .59382 L
s
.51337 .6008 m
.51638 .5992 L
s
.68282 1.07311 m .67531 1.07202 L .67182 1.07141 L 0 0 0 r
F
0 g
.67182 1.07141 m
.67182 1.07141 L
s
.4025 .70446 m
.40675 .70154 L
s
.27126 .65488 m .2627 .64477 L .26008 .65453 L 0 1 .48 r
F
.27126 .65488 m .26797 .63769 L .2627 .64477 L F
.27126 .65488 m .27237 .63805 L .26797 .63769 L F
.27126 .65488 m .27378 .64543 L .27237 .63805 L F
0 g
.27126 .65488 m
.27275 .66199 L
s
.266 .66192 m
.27126 .65488 L
s
.35325 .7762 m .34211 .77581 L .34263 .77736 L 0 1 .329 r
F
.35325 .7762 m .34493 .77446 L .34211 .77581 L F
.35325 .7762 m .34921 .77421 L .34493 .77446 L F
.35325 .7762 m .35278 .77496 L .34921 .77421 L F
0 g
.35043 .77755 m
.35325 .7762 L
s
.35325 .7762 m
.35679 .77665 L
s
.22941 .73801 m .21826 .73024 L .21801 .73827 L 0 1 .528 r
F
.22941 .73801 m .22187 .72428 L .21826 .73024 L F
.22941 .73801 m .22645 .72439 L .22187 .72428 L F
.22941 .73801 m .22968 .73028 L .22645 .72439 L F
0 g
.2258 .74393 m
.22941 .73801 L
s
.22941 .73801 m
.23264 .74363 L
s
.82013 .80294 m .82984 .8137 L .83138 .8016 L 0 1 .476 r
F
0 g
.82537 .82308 m
.82984 .8137 L
s
.76055 .84278 m .76926 .84994 L .77153 .83965 L 0 1 .463 r
F
0 g
.76432 .85846 m
.76926 .84994 L
s
.76926 .84994 m
.77079 .85698 L
s
.30009 .63358 m
.30169 .64026 L
s
.34426 .72152 m .33366 .72177 L .33606 .72518 L 0 1 .53 r
F
0 g
.33264 .729 m
.33606 .72518 L
s
.52371 .90986 m .52038 .90438 L .51808 .90454 L 0 .272 .301 r
F
0 g
.51662 .90006 m
.51808 .90454 L
s
.79932 .9118 m .8058 .91763 L .81014 .91297 L 0 1 .517 r
F
0 g
.7994 .92057 m
.8058 .91763 L
s
.80571 .92163 m
.8058 .91763 L
s
.32139 .77921 m .31284 .77547 L .31012 .77742 L 0 1 .441 r
F
.32139 .77921 m .31711 .77541 L .31284 .77547 L F
.32139 .77921 m .32078 .77701 L .31711 .77541 L F
.33201 .77835 m .32078 .77701 L .32139 .77921 L 0 1 .411 r
F
0 g
.31867 .78115 m
.32139 .77921 L
s
.32139 .77921 m
.32502 .78052 L
s
.48093 .96433 m .47019 .96407 L .47278 .96597 L 0 1 .49 r
F
.49382 .89071 m .49391 .88901 L .49503 .88906 L 0 0 0 r
F
.50081 .88491 m .49503 .88906 L .49391 .88901 L F
0 g
.49391 .88901 m
.49552 .88705 L
s
.49066 .89069 m
.49391 .88901 L
s
.371 .95817 m .35692 .94723 L .358 .95331 L 0 1 .467 r
F
0 g
.35176 .94855 m
.358 .95331 L
s
.45433 .49063 m .44631 .49926 L .44799 .49755 L 0 0 0 r
F
0 g
.44886 .49679 m
.45052 .49485 L
s
.45433 .49063 m .45044 .4952 L .44631 .49926 L 0 0 0 r
F
.45433 .49063 m .45765 .48806 L .45044 .4952 L F
.45433 .49063 m .46398 .48114 L .45765 .48806 L F
.45433 .49063 m .46523 .47906 L .46398 .48114 L F
0 g
.4611 .48312 m
.46523 .47906 L
s
.46523 .47906 m
.47138 .47206 L
s
.34263 .77736 m .33144 .77648 L .33201 .77835 L 0 1 .374 r
F
.34263 .77736 m .33423 .77495 L .33144 .77648 L F
.34263 .77736 m .33851 .77477 L .33423 .77495 L F
.34263 .77736 m .34211 .77581 L .33851 .77477 L F
0 g
.33984 .77889 m
.34263 .77736 L
s
.34263 .77736 m
.34619 .7781 L
s
.33201 .77835 m .32353 .77527 L .32078 .77701 L 0 1 .411 r
F
.33201 .77835 m .32781 .77516 L .32353 .77527 L F
.33201 .77835 m .33144 .77648 L .32781 .77516 L F
0 g
.32925 .78008 m
.33201 .77835 L
s
.33201 .77835 m
.3356 .77938 L
s
.74646 .91381 m .75721 .91311 L .75298 .91231 L 0 1 .497 r
F
.73602 .9114 m .74646 .91381 L .74662 .91106 L 0 1 .483 r
F
.77763 .90938 m .77381 .91297 L .77412 .91621 L 0 1 .5 r
F
0 g
.7673 .9183 m
.77412 .91621 L
s
.35131 .93698 m .33733 .93032 L .33799 .93447 L 0 1 .532 r
F
.34118 .61737 m .33145 .61638 L .33163 .62198 L 0 1 .486 r
F
0 g
.32647 .62761 m
.33163 .62198 L
s
.34118 .61737 m .33516 .60924 L .33145 .61638 L 0 1 .486 r
F
.34118 .61737 m .34078 .60428 L .33516 .60924 L F
.34118 .61737 m .34454 .60482 L .34078 .60428 L F
.34118 .61737 m .34471 .61044 L .34454 .60482 L F
0 g
.34118 .61737 m
.3415 .62268 L
s
.33558 .62231 m
.34118 .61737 L
s
.45689 .66339 m .44912 .6664 L .4525 .66596 L 0 1 .411 r
F
.45689 .66339 m .44869 .66447 L .44912 .6664 L F
0 g
.4525 .66596 m
.4545 .66632 L
s
.45689 .66339 m .45151 .66145 L .44869 .66447 L 0 1 .411 r
F
.45689 .66339 m .45591 .65887 L .45151 .66145 L F
.45689 .66339 m .45894 .65845 L .45591 .65887 L F
.45689 .66339 m .45936 .66039 L .45894 .65845 L F
0 g
.45689 .66339 m
.45757 .66533 L
s
.4525 .66596 m
.45689 .66339 L
s
.45936 .66039 m
.46347 .65789 L
s
.48278 1.0554 m .4869 1.06049 L .4875 1.0594 L 0 .762 .451 r
F
.50023 1.06486 m .4875 1.0594 L .4869 1.06049 L 0 .688 .412 r
F
0 g
.4869 1.06049 m
.49202 1.06379 L
s
.48096 1.05822 m
.4869 1.06049 L
s
.72307 .62505 m
.72579 .62607 L
s
.7258 .62607 m
.72705 .62569 L
s
.51606 .84613 m
.51623 .84547 L
s
.55576 .58038 m .56505 .58022 L .56721 .58954 L 0 .342 .117 r
F
0 g
.56505 .58022 m
.56655 .56998 L
s
.56015 .57631 m
.56505 .58022 L
s
.3909 .97283 m .38952 .9797 L .39239 .97864 L 0 1 .465 r
F
.40391 .98899 m .39239 .97864 L .38952 .9797 L 0 .969 .469 r
F
0 g
.38952 .9797 m
.39163 .98533 L
s
.3835 .9754 m
.38952 .9797 L
s
.35131 .93698 m .34101 .92956 L .33733 .93032 L 0 1 .532 r
F
0 g
.33209 .93162 m
.33413 .9326 L
s
.33413 .9326 m
.33799 .93447 L
s
.35131 .93698 m .347 .93242 L .34101 .92956 L 0 1 .532 r
F
.36009 .93482 m .347 .93242 L .35131 .93698 L F
0 g
.35131 .93698 m
.3571 .93971 L
s
.35131 .93698 m
.35195 .94112 L
s
.75193 .75266 m .76317 .75903 L .76372 .76211 L 0 .194 0 r
F
0 g
.75988 .75449 m
.76317 .75903 L
s
.76317 .75903 m
.76627 .75941 L
s
.8111 .65395 m .81852 .66585 L .82311 .66676 L 0 1 .512 r
F
.8111 .65395 m .81338 .66037 L .81852 .66585 L F
0 g
.8158 .6705 m
.81852 .66585 L
s
.5044 .96951 m .50761 .9716 L .50782 .97076 L 0 .991 .405 r
F
.51633 .97117 m .50782 .97076 L .50761 .9716 L 0 .808 .324 r
F
0 g
.50761 .9716 m
.5114 .97247 L
s
.50355 .97176 m
.50761 .9716 L
s
.47729 .59672 m .47111 .59587 L .47286 .60066 L 0 1 .302 r
F
.47729 .59672 m .47326 .58469 L .47111 .59587 L F
.35486 .72105 m .34528 .71704 L .34426 .72152 L 0 1 .528 r
F
.35486 .72105 m .34919 .71366 L .34528 .71704 L F
.35486 .72105 m .3534 .71364 L .34919 .71366 L F
.35486 .72105 m .35583 .71681 L .3534 .71364 L F
0 g
.35095 .72442 m
.35486 .72105 L
s
.35486 .72105 m
.35733 .72396 L
s
.51474 .85997 m
.51526 .86237 L
s
.51526 .86237 m
.51591 .86542 L
s
.51474 .85997 m
.51633 .85592 L
s
.22713 .91585 m
.2328 .92007 L
s
.47326 .58469 m .47905 .56055 L .47428 .56526 L 0 1 .306 r
F
0 g
.47905 .56055 m
.48199 .54979 L
s
.48142 .63489 m
.48154 .63463 L
s
.41804 1.00431 m .41226 .99828 L .40601 .99463 L 0 .934 .473 r
F
0 g
.51522 .88034 m
.5156 .88175 L
s
.53433 .95606 m
.53501 .95775 L
s
.53501 .95775 m
.53574 .95957 L
s
.45517 .90879 m .44682 .91196 L .44402 .91299 L 0 0 0 r
F
.45517 .90879 m .4516 .91016 L .44682 .91196 L F
.4615 .90664 m .45517 .90879 L .45965 .90711 L F
.4615 .90664 m .4516 .91016 L .45517 .90879 L F
0 g
.45573 .90869 m
.45604 .90864 L
s
.55576 .58038 m .55539 .59494 L .55372 .58836 L 0 .342 .117 r
F
.55576 .58038 m .56031 .59889 L .55539 .59494 L F
.55576 .58038 m .56519 .59757 L .56031 .59889 L F
.55576 .58038 m .56721 .58954 L .56519 .59757 L F
0 g
.55122 .57835 m
.55576 .58038 L
s
.49256 .96726 m .49491 .96989 L .49558 .96885 L 0 1 .458 r
F
.5044 .96951 m .49558 .96885 L .49491 .96989 L 0 .991 .405 r
F
0 g
.49491 .96989 m
.49833 .97114 L
s
.49056 .96995 m
.49491 .96989 L
s
.5282 .94029 m
.5289 .94174 L
s
.5289 .94174 m
.53006 .94414 L
s
.5252 .92461 m .5267 .93717 L .52936 .93786 L 0 .272 .306 r
F
0 g
.5267 .93717 m
.5282 .94029 L
s
.43221 .75919 m .42394 .76152 L .4286 .75992 L 0 0 0 r
F
0 g
.4286 .75992 m
.43012 .75924 L
s
.4361 .95708 m .43138 .95466 L .42584 .95376 L 0 1 .533 r
F
.44214 .95406 m .4361 .95708 L .44136 .95797 L 0 1 .529 r
F
.44214 .95406 m .43138 .95466 L .4361 .95708 L F
0 g
.4361 .95708 m
.4379 .95991 L
s
.4615 .90664 m .45965 .90711 L .46207 .90622 L 0 0 0 r
F
.46978 .9025 m .46207 .90622 L .45965 .90711 L F
0 g
.45965 .90711 m
.46069 .90651 L
s
.45517 .90879 m
.45965 .90711 L
s
.79766 .80658 m .80318 .82579 L .80753 .81641 L 0 1 .465 r
F
.79766 .80658 m .79875 .82649 L .80318 .82579 L F
0 g
.80318 .82579 m
.80452 .83344 L
s
.32244 .92677 m .30664 .91405 L .306 .92098 L 0 1 .474 r
F
.76835 .59962 m .77398 .60649 L .76957 .60519 L 0 .193 .033 r
F
.76835 .59962 m .77947 .60386 L .77398 .60649 L F
0 g
.69834 .91453 m
.69968 .91338 L
s
.69783 .91497 m
.69834 .91453 L
s
.6846 .92286 m .69373 .91851 L .6941 .91595 L 0 1 .372 r
F
0 g
.69373 .91851 m
.6941 .91595 L
s
.69373 .91851 m
.69783 .91497 L
s
.33178 .9249 m .32815 .93228 L .33182 .93149 L 0 1 .469 r
F
.33178 .9249 m .32245 .92677 L .32815 .93228 L F
.33171 .9271 m .32815 .93228 L .33182 .93149 L 0 1 .531 r
F
.33165 .92931 m .32815 .93228 L .33182 .93149 L 0 1 .456 r
F
0 g
.33182 .93149 m
.33209 .93162 L
s
.33182 .93149 m
.33199 .93151 L
s
.33171 .9271 m .32238 .92893 L .32815 .93228 L 0 1 .531 r
F
.33165 .92931 m .32232 .93109 L .32815 .93228 L 0 1 .456 r
F
0 g
.32815 .93228 m
.32894 .93876 L
s
.53066 .58909 m .52864 .59863 L .52797 .59522 L 0 .113 .083 r
F
.53066 .58909 m .5327 .59864 L .52864 .59863 L F
.53066 .58909 m .53744 .59525 L .5327 .59864 L F
.53066 .58909 m .54011 .58911 L .53744 .59525 L F
0 g
.52698 .5904 m
.53066 .58909 L
s
.52157 .86759 m
.52189 .86709 L
s
.21801 .73827 m .20683 .7302 L .20659 .73853 L 0 1 .528 r
F
.21801 .73827 m .21044 .72401 L .20683 .7302 L F
.21801 .73827 m .21501 .72412 L .21044 .72401 L F
.21801 .73827 m .21826 .73024 L .21501 .72412 L F
0 g
.2144 .74441 m
.21801 .73827 L
s
.21801 .73827 m
.22124 .74412 L
s
.37943 .94267 m .36916 .93655 L .36571 .93743 L 0 1 .533 r
F
.37943 .94267 m .37504 .9388 L .36916 .93655 L F
.38758 .94027 m .37504 .9388 L .37943 .94267 L 0 1 .532 r
F
0 g
.37943 .94267 m
.38033 .94637 L
s
.37943 .94267 m
.38509 .94481 L
s
.31002 .93564 m .29488 .93682 L .29535 .93742 L 0 .718 .223 r
F
.31002 .93564 m .29902 .93625 L .29488 .93682 L F
.31002 .93564 m .30552 .93574 L .29902 .93625 L F
0 g
.31002 .93564 m
.31044 .93623 L
s
.49382 .89071 m .48624 .89463 L .48746 .89297 L 0 0 0 r
F
0 g
.48388 .89511 m
.48746 .89297 L
s
.40721 .94953 m
.41292 .95086 L
s
.44644 .91199 m .44402 .91299 L .44682 .91196 L 0 0 0 r
F
.44644 .91199 m .43917 .91445 L .44402 .91299 L F
0 g
.44402 .91299 m
.4449 .91282 L
s
.42457 .95078 m .41164 .94787 L .41292 .95086 L 0 1 .532 r
F
.3909 .97283 m .37683 .96279 L .37833 .9686 L 0 1 .465 r
F
0 g
.37207 .96425 m
.37833 .9686 L
s
.81958 .79179 m .83112 .79658 L .82952 .7944 L 0 .467 .245 r
F
.82946 .79437 m .82952 .7944 L .8295 .79433 L 0 1 .476 r
F
.82839 .79378 m .8295 .79433 L .82914 .79294 L F
.82839 .79378 m .82952 .7944 L .82919 .79396 L 0 .467 .245 r
F
.81958 .79179 m .82952 .7944 L .82839 .79378 L F
.82013 .80294 m .83138 .8016 L .82952 .7944 L 0 1 .476 r
F
.82013 .80294 m .82952 .7944 L .82946 .79437 L F
.82013 .80294 m .8295 .79433 L .82839 .79378 L F
.81958 .79179 m .82839 .79378 L .82455 .79218 L 0 .467 .245 r
F
.82013 .80294 m .82839 .79378 L .82462 .79351 L 0 1 .476 r
F
.82839 .79378 m .82914 .79294 L .82718 .79319 L F
.82839 .79378 m .82718 .79319 L .82462 .79351 L F
.82839 .79378 m .82725 .79321 L .82718 .79319 L 0 .467 .245 r
F
.82839 .79378 m .82718 .79319 L .82455 .79218 L F
.82839 .79378 m .82919 .79396 L .82725 .79321 L F
.46539 .96373 m .46055 .96207 L .45549 .96179 L 0 1 .519 r
F
0 g
.45549 .96179 m
.46055 .96207 L
s
.46539 .96373 m
.46789 .96597 L
s
.26008 .65453 m .24888 .65416 L .25024 .66173 L 0 1 .482 r
F
0 g
.24569 .66924 m
.25024 .66173 L
s
.71118 .62191 m
.71443 .62232 L
s
.51633 .97117 m .52037 .97262 L .52011 .97205 L 0 .808 .324 r
F
0 g
.52037 .97262 m
.5216 .97277 L
s
.51664 .9728 m
.52037 .97262 L
s
.33366 .72177 m .32541 .72551 L .32967 .7254 L 0 1 .531 r
F
0 g
.32967 .7254 m
.33264 .729 L
s
.24746 .93379 m .23198 .92687 L .23233 .9307 L 0 1 .522 r
F
.24746 .93379 m .23628 .92645 L .23198 .92687 L F
.24746 .93379 m .24292 .92942 L .23628 .92645 L F
.25787 .93227 m .24292 .92942 L .24746 .93379 L 0 1 .518 r
F
0 g
.24746 .93379 m
.24777 .93759 L
s
.24746 .93379 m
.25393 .93654 L
s
.38997 .70906 m .37909 .70992 L .38131 .71236 L 0 1 .519 r
F
0 g
.37738 .71552 m
.38131 .71236 L
s
.51133 .71017 m .50932 .67135 L .50964 .69441 L 0 .89 .272 r
F
.50651 .7168 m .50964 .69441 L .50932 .67135 L 0 .904 .278 r
F
0 g
.50729 .65836 m
.50932 .67135 L
s
.50932 .67135 m
.51089 .65006 L
s
.5404 .9733 m
.54059 .9733 L
s
.53433 .95606 m
.53442 .95568 L
s
.43797 1.0158 m .43314 1.01871 L .43912 1.02207 L 0 .847 .466 r
F
.43797 1.0158 m .42699 1.01306 L .43314 1.01871 L F
0 g
.43314 1.01871 m
.43639 1.02388 L
s
.48278 1.0554 m .47588 1.05117 L .46994 1.0489 L 0 .762 .451 r
F
.38997 .70906 m .38053 .70627 L .37909 .70992 L 0 1 .519 r
F
.38997 .70906 m .38481 .70336 L .38053 .70627 L F
.38997 .70906 m .38909 .70312 L .38481 .70336 L F
.38997 .70906 m .3913 .70557 L .38909 .70312 L F
0 g
.38569 .71197 m
.38997 .70906 L
s
.41719 .6951 m
.42154 .69232 L
s
.54642 1.07964 m .5495 1.07741 L .54873 1.07888 L 0 0 0 r
F
0 g
.54825 1.07634 m
.5495 1.07741 L
s
.52392 1.07569 m
.526 1.07594 L
s
.49316 .69271 m .49198 .65163 L .48922 .65913 L 0 1 .292 r
F
.49316 .69271 m .49498 .65697 L .49198 .65163 L F
0 g
.49198 .65163 m
.4931 .63741 L
s
.43797 1.0158 m .42402 1.00796 L .42699 1.01306 L 0 .847 .466 r
F
0 g
.42073 1.00973 m
.42699 1.01306 L
s
.52492 .46636 m .53852 .45375 L .53914 .4553 L 0 0 .003 r
F
.52492 .46636 m .53243 .45849 L .53852 .45375 L F
0 g
.53852 .45375 m
.53898 .45314 L
s
.53243 .45849 m
.53759 .45129 L
s
.53243 .45849 m
.53852 .45375 L
s
.45293 1.02921 m .4426 1.02688 L .44907 1.03212 L 0 .796 .463 r
F
.45293 1.02921 m .43912 1.02207 L .4426 1.02688 L F
0 g
.43639 1.02388 m
.4426 1.02688 L
s
.49178 .5133 m .48577 .51874 L .48653 .52003 L 0 .96 .154 r
F
0 g
.49178 .51331 m
.49178 .5133 L
s
.49178 .5133 m .4902 .51063 L .48577 .51874 L 0 .96 .154 r
F
.49178 .5133 m .49686 .50113 L .4902 .51063 L F
0 g
.49178 .5133 m
.49178 .5133 L
s
.46323 .65584 m .45591 .65887 L .45894 .65845 L 0 1 .365 r
F
.46323 .65584 m .45594 .65689 L .45591 .65887 L F
0 g
.45894 .65845 m
.45936 .66039 L
s
.46323 .65584 m .45903 .65382 L .45594 .65689 L 0 1 .365 r
F
.46323 .65584 m .46333 .65121 L .45903 .65382 L F
.46323 .65584 m .46598 .65078 L .46333 .65121 L F
.46323 .65584 m .46593 .65276 L .46598 .65078 L F
0 g
.46593 .65276 m
.46993 .65025 L
s
.46323 .65584 m
.46347 .65789 L
s
.45894 .65845 m
.46323 .65584 L
s
.52923 .71171 m
.52958 .72033 L
s
.76209 1.06306 m .7634 1.06437 L .77118 1.06139 L 0 .825 .246 r
F
0 g
.76085 1.06598 m
.7634 1.06437 L
s
.75501 1.06686 m
.7634 1.06437 L
s
.43917 .91445 m .43036 .91684 L .4272 .91789 L 0 .779 .212 r
F
.43917 .91445 m .43549 .91537 L .43036 .91684 L F
.44644 .91199 m .43549 .91537 L .43917 .91445 L 0 0 0 r
F
0 g
.43917 .91445 m
.43983 .91468 L
s
.43917 .91445 m
.44402 .91299 L
s
.40455 .92201 m .40141 .92387 L .40474 .92284 L 0 .812 .252 r
F
.40455 .92201 m .39601 .9244 L .40141 .92387 L F
0 g
.40141 .92387 m
.40218 .92464 L
s
.78253 .83711 m .79209 .82768 L .78766 .82856 L 0 1 .475 r
F
.77153 .83965 m .78253 .83711 L .78101 .83003 L 0 1 .469 r
F
0 g
.51802 .86497 m
.51832 .86654 L
s
.51633 .85592 m
.51653 .85699 L
s
.37896 .58522 m .36947 .5904 L .37301 .59004 L 0 1 .399 r
F
.37896 .58522 m .3703 .58664 L .36947 .5904 L F
0 g
.37281 .59456 m
.37301 .59004 L
s
.37896 .58522 m .37496 .58126 L .3703 .58664 L 0 1 .399 r
F
.37896 .58522 m .38092 .57643 L .37496 .58126 L F
.37896 .58522 m .38421 .57537 L .38092 .57643 L F
.37896 .58522 m .38336 .57914 L .38421 .57537 L F
0 g
.37831 .58939 m
.37896 .58522 L
s
.37301 .59004 m
.37896 .58522 L
s
.45594 .75031 m .44756 .75385 L .45219 .75145 L 0 0 0 r
F
0 g
.45219 .75145 m
.45558 .74902 L
s
.44214 .95406 m .44136 .95797 L .44366 .95673 L 0 1 .529 r
F
.45347 .95931 m .44366 .95673 L .44136 .95797 L 0 1 .526 r
F
0 g
.44136 .95797 m
.44339 .96045 L
s
.4361 .95708 m
.44136 .95797 L
s
.46963 .96068 m .46539 .96373 L .47019 .96407 L 0 1 .508 r
F
.46963 .96068 m .46056 .96207 L .46539 .96373 L F
0 g
.33182 .93149 m
.33196 .9316 L
s
.35117 .94222 m .33733 .93032 L .33793 .93667 L 0 1 .468 r
F
0 g
.33196 .9316 m
.33793 .93667 L
s
.33199 .93151 m
.33212 .93153 L
s
.33212 .93153 m
.33751 .9322 L
s
.20659 .73853 m .1954 .73015 L .19518 .73878 L 0 1 .528 r
F
0 g
.19518 .73878 m
.19844 .74508 L
s
.20659 .73853 m .19899 .72374 L .1954 .73015 L 0 1 .528 r
F
.20659 .73853 m .20357 .72385 L .19899 .72374 L F
.20659 .73853 m .20683 .7302 L .20357 .72385 L F
0 g
.203 .74489 m
.20659 .73853 L
s
.20659 .73853 m
.20984 .7446 L
s
.48206 .73793 m .47412 .74519 L .47839 .74075 L 0 .041 .059 r
F
.48206 .73793 m .47156 .74923 L .47412 .74519 L F
.48206 .73793 m .47242 .75017 L .47156 .74923 L F
.48206 .73793 m .47612 .74735 L .47242 .75017 L F
.48206 .73793 m .48017 .74265 L .47612 .74735 L F
0 g
.47839 .74075 m
.47942 .73996 L
s
.47839 .74075 m
.47882 .74015 L
s
.48206 .73793 m .48271 .73862 L .48017 .74265 L 0 .041 .059 r
F
0 g
.48206 .73793 m
.48452 .73348 L
s
.47882 .74015 m
.48119 .73689 L
s
.47942 .73996 m
.48206 .73793 L
s
.48271 .73862 m
.48623 .7345 L
s
.46978 .9025 m .46641 .90424 L .46207 .90622 L 0 0 0 r
F
.47511 .90104 m .46978 .9025 L .47381 .90076 L F
.47511 .90104 m .46641 .90424 L .46978 .9025 L F
0 g
.46978 .9025 m
.4708 .90191 L
s
.5222 .89223 m .51768 .89523 L .52038 .90438 L 0 .28 .298 r
F
0 g
.51706 .8955 m
.51768 .89523 L
s
.78723 .77664 m .78964 .77533 L .79431 .77799 L 0 0 0 r
F
.78723 .77664 m .78661 .77475 L .78964 .77533 L F
0 g
.78526 .77349 m
.78964 .77533 L
s
.5784 .58571 m
.58365 .59735 L
s
.57693 .59603 m
.5784 .58571 L
s
.40615 .94628 m .39305 .94232 L .39412 .94557 L 0 1 .533 r
F
0 g
.38827 .9438 m
.39412 .94557 L
s
.48093 .96433 m .4824 .9674 L .48352 .96623 L 0 1 .49 r
F
.49256 .96726 m .48352 .96623 L .4824 .9674 L 0 1 .458 r
F
0 g
.4824 .9674 m
.48542 .96899 L
s
.4778 .96728 m
.4824 .9674 L
s
.21589 .91029 m .2111 .91697 L .21539 .91643 L 0 1 .534 r
F
.21589 .91029 m .20506 .91147 L .2111 .91697 L F
0 g
.2111 .91697 m
.21167 .92311 L
s
.21539 .91643 m
.21636 .91716 L
s
.36021 .9295 m .34653 .92844 L .34706 .93018 L 0 1 .411 r
F
.36021 .9295 m .35021 .92771 L .34653 .92844 L F
.36021 .9295 m .35608 .92816 L .35021 .92771 L F
.36901 .92734 m .35608 .92816 L .36021 .9295 L 0 1 .376 r
F
0 g
.36021 .9295 m
.36589 .92979 L
s
.36021 .9295 m
.36072 .93123 L
s
.45293 1.02921 m .44907 1.03212 L .45499 1.03518 L 0 .796 .463 r
F
0 g
.44907 1.03212 m
.45285 1.03699 L
s
.42379 1.00148 m .41804 1.00431 L .42402 1.00796 L 0 .89 .465 r
F
.42379 1.00148 m .41226 .99828 L .41804 1.00431 L F
0 g
.41804 1.00431 m
.42073 1.00973 L
s
.47013 .64808 m .46333 .65121 L .46598 .65078 L 0 1 .298 r
F
.47013 .64808 m .46384 .64917 L .46333 .65121 L F
0 g
.46593 .65276 m
.46598 .65078 L
s
.47013 .64808 m .46716 .64604 L .46384 .64917 L 0 1 .298 r
F
.47013 .64808 m .47132 .64333 L .46716 .64604 L F
0 g
.46993 .65025 m
.47013 .64808 L
s
.46598 .65078 m
.47013 .64808 L
s
.33366 .72177 m .32305 .72183 L .32541 .72551 L 0 1 .531 r
F
0 g
.32199 .72948 m
.32541 .72551 L
s
.79766 .80658 m .79638 .81828 L .79875 .82649 L 0 1 .465 r
F
0 g
.79352 .83506 m
.79875 .82649 L
s
.43221 .75919 m .42057 .76306 L .42394 .76152 L 0 0 0 r
F
0 g
.42062 .76244 m
.42394 .76152 L
s
.41813 .76328 m
.42062 .76244 L
s
.62602 .72713 m
.62626 .73103 L
s
.62748 .75102 m
.62833 .76508 L
s
.62889 .77419 m
.62901 .77616 L
s
.51784 1.0726 m .51064 1.0713 L .51812 1.07358 L 0 .54 .31 r
F
.51784 1.0726 m .50517 1.06898 L .51064 1.0713 L F
0 g
.5049 1.07042 m
.51064 1.0713 L
s
.62486 .77206 m
.62488 .77291 L
s
.51617 .70559 m .51809 .70448 L .52 .68086 L 0 .872 .266 r
F
0 g
.52 .68086 m
.52096 .70391 L
s
.62381 .70701 m
.62393 .71003 L
s
.62444 .72364 m
.62452 .72572 L
s
.62416 .7161 m
.62444 .72364 L
s
.62631 .77318 m
.62642 .77606 L
s
.62642 .77606 m
.62703 .79228 L
s
.62703 .79228 m
.62711 .79435 L
s
.62711 .79435 m
.62792 .81584 L
s
.68 .53921 m .68378 .53281 L .67922 .52857 L 0 .414 .334 r
F
0 g
.67116 .51434 m
.67922 .52857 L
s
.68 .53921 m .69163 .54839 L .68378 .53281 L 0 .414 .334 r
F
.68 .53921 m .69752 .56492 L .69163 .54839 L F
.68 .53921 m .69829 .57559 L .69752 .56492 L F
.68 .53921 m .69342 .57326 L .69829 .57559 L F
.68 .53921 m .68558 .55766 L .69342 .57326 L F
0 g
.67922 .52857 m
.68 .53921 L
s
.49896 .67829 m .49498 .65697 L .49624 .6716 L 0 1 .285 r
F
.49316 .69271 m .49624 .6716 L .49498 .65697 L 0 1 .292 r
F
0 g
.49198 .65163 m
.49498 .65697 L
s
.49498 .65697 m
.49617 .64013 L
s
.50877 .8815 m .50342 .88385 L .50506 .88116 L 0 0 0 r
F
0 g
.50242 .88296 m
.50506 .88116 L
s
.8111 .65395 m .82311 .66676 L .82481 .66236 L 0 1 .512 r
F
0 g
.82311 .66676 m
.82729 .67304 L
s
.28953 .91893 m .28504 .92468 L .28917 .92398 L 0 1 .532 r
F
.28953 .91893 m .27908 .92052 L .28504 .92468 L F
0 g
.28504 .92468 m
.28554 .92969 L
s
.28917 .92398 m
.29098 .92503 L
s
.46836 .74472 m .46001 .74952 L .46457 .7464 L 0 0 .027 r
F
.46836 .74472 m .45704 .75256 L .46001 .74952 L F
.46836 .74472 m .45765 .75351 L .45704 .75256 L F
.46836 .74472 m .46144 .75183 L .45765 .75351 L F
.46836 .74472 m .46589 .74864 L .46144 .75183 L F
.46836 .74472 m .46885 .7456 L .46589 .74864 L F
0 g
.46836 .74472 m
.47141 .74099 L
s
.46457 .7464 m
.46776 .74342 L
s
.46457 .7464 m
.46836 .74472 L
s
.76676 .9081 m .76779 .91507 L .77381 .91297 L 0 1 .488 r
F
.76676 .9081 m .76356 .9143 L .76779 .91507 L F
0 g
.7673 .9183 m
.76779 .91507 L
s
.68405 .58258 m .687 .56977 L .6833 .56745 L 0 .593 .321 r
F
0 g
.6833 .56745 m
.6835 .57163 L
s
.68244 .56528 m
.6833 .56745 L
s
.35978 .60127 m .35019 .6054 L .35395 .60563 L 0 1 .484 r
F
0 g
.35395 .60563 m
.35425 .61096 L
s
.32244 .92677 m .31172 .91317 L .30664 .91405 L 0 1 .474 r
F
.32244 .92677 m .3185 .91863 L .31172 .91317 L F
0 g
.32224 .92891 m
.32244 .92677 L
s
.33178 .9249 m .3185 .91863 L .32245 .92677 L 0 1 .469 r
F
0 g
.32245 .92677 m
.32429 .92856 L
s
.69952 .91097 m
.69968 .91338 L
s
.80889 .80458 m .81868 .8149 L .82013 .80294 L 0 1 .471 r
F
0 g
.81427 .82427 m
.81868 .8149 L
s
.81868 .8149 m
.82093 .82352 L
s
.55125 .73042 m
.55181 .69195 L
s
.42379 1.00148 m .40983 .99295 L .41226 .99828 L 0 .89 .465 r
F
0 g
.40601 .99463 m
.41226 .99828 L
s
.5256 .44495 m .53356 .44176 L .54001 .4427 L 0 .154 .071 r
F
0 g
.53356 .44176 m
.53905 .43553 L
s
.53083 .94342 m
.53085 .94333 L
s
.61193 .44491 m .61077 .45058 L .60812 .44642 L 0 .235 .025 r
F
.61193 .44491 m .61897 .456 L .61077 .45058 L F
.61193 .44491 m .62723 .45906 L .61897 .456 L F
.61193 .44491 m .631 .45751 L .62723 .45906 L F
0 g
.62821 .4525 m
.63083 .45297 L
s
.61193 .44491 m .62779 .45243 L .631 .45751 L 0 .235 .025 r
F
0 g
.62779 .45243 m
.62821 .4525 L
s
.61963 .44703 m
.62779 .45243 L
s
.48721 .46145 m .50012 .45307 L .49979 .45612 L 0 0 .025 r
F
0 g
.50012 .45307 m
.50603 .44677 L
s
.49473 .45535 m
.50012 .45307 L
s
.42207 .91899 m .40975 .92137 L .41027 .9219 L 0 .804 .235 r
F
0 g
.40474 .92284 m
.41027 .9219 L
s
.74369 .87027 m .75354 .8614 L .74923 .86277 L 0 1 .474 r
F
0 g
.74882 .86331 m
.74923 .86277 L
s
.75354 .8614 m
.75435 .86709 L
s
.73302 .87421 m .74369 .87027 L .74276 .86505 L 0 1 .466 r
F
0 g
.74369 .87027 m
.74882 .86331 L
s
.38336 .57914 m
.38912 .57384 L
s
.45594 .75031 m .4444 .75628 L .44756 .75385 L 0 0 0 r
F
.45594 .75031 m .44483 .75712 L .4444 .75628 L F
.45594 .75031 m .44859 .75598 L .44483 .75712 L F
.45594 .75031 m .45316 .75362 L .44859 .75598 L F
.45594 .75031 m .45631 .75119 L .45316 .75362 L F
0 g
.45594 .75031 m
.45915 .74733 L
s
.45219 .75145 m
.45594 .75031 L
s
.51776 .88827 m
.51935 .88721 L
s
.26864 .92216 m .25403 .91168 L .25399 .91711 L 0 1 .533 r
F
.26864 .92216 m .25834 .91117 L .25403 .91168 L F
.26864 .92216 m .2646 .91567 L .25834 .91117 L F
.27908 .92052 m .2646 .91567 L .26864 .92216 L 0 1 .532 r
F
0 g
.26857 .92756 m
.26864 .92216 L
s
.26864 .92216 m
.27474 .92647 L
s
.47511 .90104 m .47381 .90076 L .47581 .90017 L 0 0 0 r
F
.48274 .8962 m .47581 .90017 L .47381 .90076 L F
0 g
.47381 .90076 m
.47496 .89967 L
s
.46978 .9025 m
.47381 .90076 L
s
.53027 .71423 m .53207 .71935 L .53484 .68931 L 0 .807 .252 r
F
0 g
.53004 .6804 m
.53027 .71423 L
s
.53272 .71233 m
.5333 .7138 L
s
.533 .70925 m
.5333 .7138 L
s
.75354 .8614 m
.75839 .85285 L
s
.34426 .72152 m .33472 .71703 L .33366 .72177 L 0 1 .53 r
F
.34426 .72152 m .33868 .71352 L .33472 .71703 L F
.34426 .72152 m .34288 .71361 L .33868 .71352 L F
.34426 .72152 m .34528 .71704 L .34288 .71361 L F
0 g
.34031 .72501 m
.34426 .72152 L
s
.34426 .72152 m
.3467 .72468 L
s
.48721 .46145 m .48017 .47013 L .48096 .46778 L 0 0 .025 r
F
0 g
.48065 .46574 m
.48215 .46403 L
s
.48721 .46145 m .48557 .46785 L .48017 .47013 L 0 0 .025 r
F
.48721 .46145 m .49356 .46246 L .48557 .46785 L F
.48721 .46145 m .49979 .45612 L .49356 .46246 L F
0 g
.48215 .46403 m
.48721 .46145 L
s
.43489 .68164 m .42624 .68472 L .4303 .68423 L 0 1 .474 r
F
.43489 .68164 m .42494 .68283 L .42624 .68472 L F
0 g
.4303 .68423 m
.43204 .6861 L
s
.43489 .68164 m .42727 .67981 L .42494 .68283 L 0 1 .474 r
F
.43489 .68164 m .43188 .67722 L .42727 .67981 L F
.43489 .68164 m .43568 .67678 L .43188 .67722 L F
.43489 .68164 m .43697 .67868 L .43568 .67678 L F
0 g
.43489 .68164 m
.43637 .68342 L
s
.4303 .68423 m
.43489 .68164 L
s
.30008 .63358 m .28996 .63944 L .29435 .63977 L 0 1 .479 r
F
0 g
.29435 .63977 m
.2959 .64664 L
s
.35978 .60127 m .35053 .60091 L .35019 .6054 L 0 1 .484 r
F
.35978 .60127 m .35477 .59515 L .35053 .60091 L F
.35978 .60127 m .36061 .59077 L .35477 .59515 L F
.35978 .60127 m .36416 .59071 L .36061 .59077 L F
.35978 .60127 m .3638 .59521 L .36416 .59071 L F
0 g
.35959 .60578 m
.35978 .60127 L
s
.35395 .60563 m
.35978 .60127 L
s
.46853 1.04164 m .45895 1.03963 L .46567 1.04441 L 0 .733 .453 r
F
.46853 1.04164 m .45499 1.03518 L .45895 1.03963 L F
0 g
.45285 1.03699 m
.45895 1.03963 L
s
.27875 .92932 m .27449 .93313 L .27861 .93246 L 0 1 .507 r
F
.27875 .92932 m .2683 .93077 L .27449 .93313 L F
0 g
.27449 .93313 m
.27524 .93629 L
s
.27861 .93246 m
.28091 .93313 L
s
.71701 .61043 m .73086 .59948 L .7276 .61288 L 0 .297 .105 r
F
0 g
.72998 .58735 m
.73086 .59948 L
s
.73086 .59948 m
.73657 .59127 L
s
.71992 .8803 m .72411 .89028 L .73011 .8825 L 0 1 .453 r
F
.71992 .8803 m .719 .89238 L .72411 .89028 L F
0 g
.72411 .89028 m
.72505 .89411 L
s
.51801 .86708 m
.51832 .86654 L
s
.44214 .95406 m .42985 .95199 L .43138 .95466 L 0 1 .529 r
F
0 g
.42584 .95376 m
.43138 .95466 L
s
.32305 .72183 m .31476 .72569 L .31902 .72563 L 0 1 .531 r
F
0 g
.31902 .72563 m
.32199 .72948 L
s
.44683 .7541 m
.44756 .75385 L
s
.44397 .75508 m
.44683 .7541 L
s
.24888 .65416 m .23896 .66157 L .24347 .66163 L 0 1 .484 r
F
0 g
.24347 .66163 m
.24569 .66924 L
s
.43697 .67868 m
.44137 .67608 L
s
.71742 1.07199 m .70994 1.07236 L .70673 1.07253 L 0 .607 .198 r
F
0 g
.69819 1.07263 m
.70673 1.07253 L
s
.62493 .62744 m
.62902 .63898 L
s
.62902 .63898 m
.6303 .64259 L
s
.5184 .88325 m
.51935 .88721 L
s
.46963 .96068 m .45842 .9599 L .46056 .96207 L 0 1 .508 r
F
0 g
.52712 .82556 m
.52751 .82799 L
s
.50877 .8815 m .51021 .87753 L .51041 .87881 L 0 0 0 r
F
.51475 .87544 m .51041 .87881 L .51021 .87753 L F
0 g
.51021 .87753 m
.51214 .87451 L
s
.50792 .87854 m
.51021 .87753 L
s
.50642 .4864 m .519 .47122 L .51915 .47183 L 0 0 0 r
F
.50642 .4864 m .51355 .47746 L .519 .47122 L F
0 g
.519 .47122 m
.52419 .46399 L
s
.51355 .47746 m
.51877 .47034 L
s
.51355 .47746 m
.519 .47122 L
s
.5394 .70848 m
.53944 .70848 L
s
.5394 .70848 m
.53944 .70907 L
s
.78848 .91061 m .79515 .91611 L .79932 .9118 L 0 1 .51 r
F
0 g
.78888 .91879 m
.79515 .91611 L
s
.79515 .91611 m
.7952 .91987 L
s
.47232 .63529 m .47722 .61495 L .47548 .60883 L 0 1 .315 r
F
.47232 .63529 m .47587 .62629 L .47722 .61495 L F
0 g
.47722 .61495 m
.48129 .61233 L
s
.47587 .62629 m
.47982 .62547 L
s
.47587 .62629 m
.47722 .61495 L
s
.43221 .75919 m .42073 .76352 L .42057 .76306 L 0 0 0 r
F
.43221 .75919 m .42434 .7628 L .42073 .76352 L F
0 g
.42188 .76246 m
.42394 .76152 L
s
.43221 .75919 m .42899 .76137 L .42434 .7628 L 0 0 0 r
F
.43221 .75919 m .43236 .75983 L .42899 .76137 L F
0 g
.43221 .75919 m
.43331 .75855 L
s
.4286 .75992 m
.43221 .75919 L
s
.73821 .61486 m .75197 .59878 L .75253 .60713 L 0 .227 .079 r
F
0 g
.75197 .59878 m
.75724 .59454 L
s
.23671 .94348 m .22068 .94035 L .22126 .94245 L 0 .997 .338 r
F
.23671 .94348 m .22497 .94001 L .22068 .94035 L F
.23671 .94348 m .23185 .94135 L .22497 .94001 L F
.24711 .94209 m .23185 .94135 L .23671 .94348 L 0 .912 .306 r
F
0 g
.23671 .94348 m
.23725 .94556 L
s
.23671 .94348 m
.2434 .94457 L
s
.40391 .98899 m .39856 .98263 L .39239 .97864 L 0 .969 .469 r
F
.52824 .97238 m .53307 .97314 L .53235 .97289 L 0 .673 .251 r
F
0 g
.5297 .97325 m
.53307 .97314 L
s
.53438 .97289 m .53235 .97289 L .53307 .97314 L 0 .593 .22 r
F
0 g
.53307 .97314 m
.53482 .97334 L
s
.68339 .62131 m
.6848 .62035 L
s
.48142 .63491 m
.48142 .63489 L
s
.26008 .65453 m .25159 .64409 L .24888 .65416 L 0 1 .482 r
F
.26008 .65453 m .25694 .6368 L .25159 .64409 L F
.26008 .65453 m .26135 .63716 L .25694 .6368 L F
.26008 .65453 m .2627 .64477 L .26135 .63716 L F
0 g
.25475 .66179 m
.26008 .65453 L
s
.26008 .65453 m
.2615 .66187 L
s
.29144 .9315 m
.29551 .93259 L
s
.76676 .9081 m .76311 .91132 L .76356 .9143 L 0 1 .488 r
F
0 g
.75689 .9161 m
.76356 .9143 L
s
.4792 .54319 m .48771 .52229 L .48252 .52827 L 0 1 .244 r
F
0 g
.48771 .52229 m
.49178 .51331 L
s
.73602 .9114 m .74662 .91106 L .74238 .91021 L 0 1 .483 r
F
.72555 .90886 m .73602 .9114 L .73601 .9089 L 0 1 .464 r
F
.37909 .70992 m .37035 .71311 L .37473 .71285 L 0 1 .525 r
F
0 g
.37473 .71285 m
.37738 .71552 L
s
.26797 .93941 m .26394 .94136 L .26806 .94073 L 0 .761 .255 r
F
0 g
.26806 .94073 m
.27507 .94092 L
s
.26797 .93941 m .25753 .94073 L .26394 .94136 L 0 .761 .255 r
F
0 g
.26394 .94136 m
.26496 .94273 L
s
.47237 .74319 m
.47255 .74307 L
s
.46885 .7456 m
.47237 .74319 L
s
.39601 .92441 m .38314 .92531 L .38368 .92634 L 0 .961 .289 r
F
.43021 .91653 m .4272 .91789 L .43036 .91684 L 0 .73 .208 r
F
.43021 .91653 m .42207 .91899 L .4272 .91789 L F
0 g
.4272 .91789 m
.42788 .91811 L
s
.51784 1.0726 m .51812 1.07358 L .52356 1.07514 L 0 .54 .31 r
F
0 g
.51812 1.07358 m
.52392 1.07569 L
s
.78723 .77664 m .79431 .77799 L .79829 .78095 L 0 0 0 r
F
0 g
.79431 .77799 m
.79483 .77838 L
s
.79639 .78021 m
.79646 .78028 L
s
.79646 .78028 m
.79697 .78044 L
s
.32305 .72183 m .31243 .72174 L .31476 .72569 L 0 1 .531 r
F
0 g
.31134 .72983 m
.31476 .72569 L
s
.41054 .98632 m .40391 .98899 L .40983 .99295 L 0 .93 .462 r
F
.41054 .98632 m .39856 .98263 L .40391 .98899 L F
0 g
.40391 .98899 m
.40601 .99463 L
s
.23793 .91457 m
.24339 .91858 L
s
.35996 .94015 m .35692 .94723 L .36036 .94636 L 0 1 .462 r
F
.35996 .94015 m .35117 .94222 L .35692 .94723 L F
.371 .95817 m .36036 .94636 L .35692 .94723 L 0 1 .467 r
F
0 g
.35692 .94723 m
.358 .95331 L
s
.71742 1.07199 m .71807 1.07159 L .72586 1.07068 L 0 .607 .198 r
F
0 g
.71021 1.07235 m
.71807 1.07159 L
s
.46853 1.04164 m .46567 1.04441 L .47147 1.04718 L 0 .733 .453 r
F
0 g
.46567 1.04441 m
.46994 1.0489 L
s
.42057 .76306 m .41229 .76496 L .41695 .76367 L 0 0 0 r
F
0 g
.41695 .76367 m
.41813 .76328 L
s
.4379 .50967 m .44439 .502 L .44799 .49755 L 0 .867 .146 r
F
0 g
.44439 .502 m
.44886 .49679 L
s
.56791 .44413 m .57592 .44036 L .58309 .43978 L 0 .096 .049 r
F
0 g
.57592 .44036 m
.58075 .4348 L
s
.77118 1.06139 m .78025 1.06003 L .78354 1.05797 L 0 .926 .262 r
F
.67545 .9281 m .67501 .93256 L .68062 .92767 L 0 1 .301 r
F
0 g
.67501 .93256 m
.68062 .92767 L
s
.68027 .93022 m
.68062 .92767 L
s
.67413 .93429 m
.67501 .93256 L
s
.32238 .92893 m .30641 .92113 L .30584 .92589 L 0 1 .532 r
F
.32238 .92893 m .31149 .92032 L .30641 .92113 L F
.32238 .92893 m .31834 .92367 L .31149 .92032 L F
0 g
.32211 .93109 m
.32238 .92893 L
s
.33171 .9271 m .31834 .92367 L .32238 .92893 L 0 1 .531 r
F
0 g
.32238 .92893 m
.32517 .93055 L
s
.6394 .62064 m
.6395 .63482 L
s
.63951 .63535 m
.63953 .63896 L
s
.6394 .62058 m
.6394 .62064 L
s
.82952 .7944 m
.83112 .79658 L
s
.39601 .92441 m .3866 .92448 L .38314 .92531 L 0 .961 .289 r
F
.39601 .92441 m .39212 .92409 L .3866 .92448 L F
0 g
.39601 .92441 m
.39653 .92544 L
s
.40455 .92201 m .39212 .92409 L .39601 .9244 L 0 .812 .252 r
F
0 g
.39601 .9244 m
.40141 .92387 L
s
.33145 .61638 m .32175 .62089 L .3257 .62137 L 0 1 .489 r
F
0 g
.3257 .62137 m
.32647 .62761 L
s
.78643 .80901 m .79209 .82768 L .79638 .81828 L 0 1 .459 r
F
.78643 .80901 m .78766 .82856 L .79209 .82768 L F
0 g
.79209 .82768 m
.79352 .83506 L
s
.71992 .8803 m .73011 .8825 L .73302 .87421 L 0 1 .453 r
F
0 g
.72411 .89028 m
.73011 .8825 L
s
.36889 .93276 m .36571 .93743 L .36916 .93655 L 0 1 .531 r
F
.36889 .93276 m .36009 .93482 L .36571 .93743 L F
0 g
.36571 .93743 m
.36663 .94114 L
s
.34471 .61044 m
.35019 .6054 L
s
.371 .95817 m .3664 .95105 L .36036 .94636 L 0 1 .467 r
F
.37915 .95588 m .371 .95817 L .37683 .96279 L 0 1 .46 r
F
.37915 .95588 m .3664 .95105 L .371 .95817 L F
0 g
.371 .95817 m
.37207 .96425 L
s
.43797 1.0158 m .43912 1.02207 L .44094 1.0209 L 0 .847 .466 r
F
.45293 1.02921 m .44094 1.0209 L .43912 1.02207 L 0 .796 .463 r
F
0 g
.43912 1.02207 m
.4426 1.02688 L
s
.43314 1.01871 m
.43912 1.02207 L
s
.47232 .63529 m .47548 .60883 L .47118 .61128 L 0 1 .315 r
F
0 g
.47548 .60883 m
.47729 .59672 L
s
.65319 .67818 m
.65359 .68462 L
s
.35117 .94222 m .34101 .92956 L .33733 .93032 L 0 1 .468 r
F
.35117 .94222 m .34694 .93466 L .34101 .92956 L F
.35996 .94015 m .34694 .93466 L .35117 .94222 L 0 1 .462 r
F
0 g
.35117 .94222 m
.35692 .94723 L
s
.35117 .94222 m
.35176 .94855 L
s
.46963 .96068 m .47019 .96407 L .47176 .96285 L 0 1 .508 r
F
.48093 .96433 m .47176 .96285 L .47019 .96407 L 0 1 .49 r
F
0 g
.47019 .96407 m
.47278 .96597 L
s
.46539 .96373 m
.47019 .96407 L
s
.50023 1.06486 m .50517 1.06898 L .50535 1.06816 L 0 .688 .412 r
F
.51784 1.0726 m .50535 1.06816 L .50517 1.06898 L 0 .54 .31 r
F
0 g
.50517 1.06898 m
.51064 1.0713 L
s
.49945 1.06711 m
.50517 1.06898 L
s
.40468 .69952 m .39564 .70265 L .40008 .70225 L 0 1 .511 r
F
0 g
.40008 .70225 m
.4025 .70446 L
s
.42379 1.00148 m .42402 1.00796 L .42621 1.00681 L 0 .89 .465 r
F
.43797 1.0158 m .42621 1.00681 L .42402 1.00796 L 0 .847 .466 r
F
0 g
.42402 1.00796 m
.42699 1.01306 L
s
.41804 1.00431 m
.42402 1.00796 L
s
.37782 .9253 m .3745 .92748 L .37795 .9266 L 0 1 .332 r
F
0 g
.37795 .9266 m
.38368 .92634 L
s
.37782 .9253 m .36901 .92734 L .3745 .92748 L 0 1 .332 r
F
0 g
.3745 .92748 m
.37526 .92874 L
s
.68444 .61925 m
.68518 .62149 L
s
.67924 .60346 m
.68066 .60775 L
s
.68194 .61165 m
.68254 .61346 L
s
.68373 .61709 m
.68373 .61709 L
s
.67924 .60346 m
.67936 .60756 L
s
.67948 .61177 m
.67952 .61342 L
s
.67961 .61653 m
.67961 .61653 L
s
.49991 .6152 m .50375 .6113 L .50637 .60959 L 0 0 0 r
F
0 g
.50375 .6113 m
.50499 .6098 L
s
.73427 1.06964 m .74641 1.0678 L .74296 1.06826 L 0 .744 .239 r
F
.72586 1.07068 m .73427 1.06964 L .73778 1.06902 L 0 .685 .221 r
F
.53438 .97289 m .537 .97324 L .53614 .97309 L 0 .593 .22 r
F
0 g
.53644 .97334 m
.537 .97324 L
s
.52111 .85531 m
.52117 .85562 L
s
.48722 .73776 m
.48741 .7373 L
s
.48741 .7373 m
.48798 .73587 L
s
.48576 .73873 m
.48798 .73587 L
s
.24888 .65416 m .23767 .65378 L .23896 .66157 L 0 1 .484 r
F
0 g
.23437 .66927 m
.23896 .66157 L
s
.52377 .71771 m
.52442 .71912 L
s
.52378 .71816 m
.52389 .72459 L
s
.52377 .71771 m
.52378 .71816 L
s
.37915 .95588 m .37683 .96279 L .38001 .96184 L 0 1 .46 r
F
.3909 .97283 m .38001 .96184 L .37683 .96279 L 0 1 .465 r
F
0 g
.37683 .96279 m
.37833 .9686 L
s
.371 .95817 m
.37683 .96279 L
s
.68405 .58258 m .69343 .58668 L .687 .56977 L 0 .593 .321 r
F
.68405 .58258 m .6983 .60694 L .69343 .58668 L F
0 g
.6835 .57163 m
.68405 .58258 L
s
.68208 .57661 m
.68405 .58258 L
s
.30008 .63358 m .28922 .63246 L .28996 .63944 L 0 1 .479 r
F
0 g
.28485 .64607 m
.28996 .63944 L
s
.50023 1.06486 m .49321 1.06127 L .4875 1.0594 L 0 .688 .412 r
F
.5222 .89223 m .52038 .90438 L .52371 .90986 L 0 .28 .298 r
F
0 g
.51808 .90454 m
.52038 .90438 L
s
.51768 .89523 m
.52038 .90438 L
s
.4615 .90664 m .45102 .91059 L .4516 .91016 L 0 0 0 r
F
0 g
.44682 .91196 m
.4516 .91016 L
s
.31243 .72174 m .30411 .72574 L .30837 .72573 L 0 1 .531 r
F
0 g
.30837 .72573 m
.31134 .72983 L
s
.41054 .98632 m .39671 .97709 L .39856 .98263 L 0 .93 .462 r
F
0 g
.39239 .97864 m
.39856 .98263 L
s
.79766 .80658 m .80753 .81641 L .80889 .80458 L 0 1 .465 r
F
0 g
.80318 .82579 m
.80753 .81641 L
s
.80753 .81641 m
.80984 .82484 L
s
.42057 .76306 m .40893 .76611 L .41229 .76496 L 0 0 0 r
F
0 g
.409 .76581 m
.41229 .76496 L
s
.40617 .76648 m
.409 .76581 L
s
.56791 .44413 m .58309 .43978 L .58466 .44277 L 0 .096 .049 r
F
0 g
.58309 .43978 m
.58769 .43621 L
s
.57592 .44036 m
.58309 .43978 L
s
.40468 .69952 m .39368 .70044 L .39564 .70265 L 0 1 .511 r
F
.40468 .69952 m .39553 .6971 L .39368 .70044 L F
.40468 .69952 m .40014 .69436 L .39553 .6971 L F
.40468 .69952 m .40443 .69407 L .40014 .69436 L F
.40468 .69952 m .40637 .69628 L .40443 .69407 L F
0 g
.40468 .69952 m
.40675 .70154 L
s
.40008 .70225 m
.40468 .69952 L
s
.37909 .70992 m .36821 .71044 L .37035 .71311 L 0 1 .525 r
F
0 g
.36637 .71633 m
.37035 .71311 L
s
.42207 .91899 m .41309 .92044 L .40975 .92137 L 0 .804 .235 r
F
.42207 .91899 m .41838 .91942 L .41309 .92044 L F
0 g
.42207 .91899 m
.42257 .91953 L
s
.43021 .91653 m .41838 .91942 L .42207 .91899 L 0 .73 .208 r
F
0 g
.42207 .91899 m
.4272 .91789 L
s
.22673 .90913 m .22182 .91562 L .22611 .91509 L 0 1 .534 r
F
.22673 .90913 m .21589 .91029 L .22182 .91562 L F
0 g
.22182 .91562 m
.22222 .92158 L
s
.22611 .91509 m
.22713 .91585 L
s
.38758 .94027 m .37433 .93526 L .37504 .9388 L 0 1 .532 r
F
0 g
.36916 .93655 m
.37504 .9388 L
s
.33366 .72177 m .32416 .71681 L .32305 .72183 L 0 1 .531 r
F
.33366 .72177 m .32815 .71316 L .32416 .71681 L F
.33366 .72177 m .33236 .71333 L .32815 .71316 L F
.33366 .72177 m .33472 .71703 L .33236 .71333 L F
0 g
.32967 .7254 m
.33366 .72177 L
s
.33366 .72177 m
.33606 .72518 L
s
.74762 .8568 m
.74923 .86277 L
s
.25787 .93227 m .24273 .92581 L .24292 .92942 L 0 1 .518 r
F
.25787 .93227 m .24704 .9254 L .24273 .92581 L F
.25787 .93227 m .25353 .92817 L .24704 .9254 L F
.2683 .93077 m .25353 .92817 L .25787 .93227 L 0 1 .513 r
F
0 g
.25787 .93227 m
.25803 .93585 L
s
.25787 .93227 m
.2642 .93482 L
s
.50175 .72489 m .50132 .67254 L .49896 .67829 L 0 .914 .284 r
F
.50175 .72489 m .50368 .6834 L .50132 .67254 L F
0 g
.50132 .67254 m
.5025 .65566 L
s
.50067 .73128 m
.50297 .72461 L
s
.50319 .73085 m
.50519 .72358 L
s
.50319 .73085 m
.50385 .72425 L
s
.30008 .63358 m .29263 .62346 L .28922 .63246 L 0 1 .479 r
F
.30008 .63358 m .29837 .61724 L .29263 .62346 L F
.30008 .63358 m .30261 .61797 L .29837 .61724 L F
.30008 .63358 m .30334 .62498 L .30261 .61797 L F
0 g
.29435 .63977 m
.30008 .63358 L
s
.5179 .87178 m
.51832 .87159 L
s
.3913 .70557 m
.39564 .70265 L
s
.4692 .57524 m .47714 .55571 L .47588 .55295 L 0 1 .313 r
F
.4692 .57524 m .47428 .56526 L .47714 .55571 L F
0 g
.47714 .55571 m
.48199 .54978 L
s
.47595 .55966 m
.47714 .55571 L
s
.47428 .56526 m
.47595 .55966 L
s
.45293 1.02921 m .45499 1.03518 L .45642 1.03403 L 0 .796 .463 r
F
.46853 1.04164 m .45642 1.03403 L .45499 1.03518 L 0 .733 .453 r
F
0 g
.45499 1.03518 m
.45895 1.03963 L
s
.44907 1.03212 m
.45499 1.03518 L
s
.47326 .58469 m .46671 .58561 L .46847 .58943 L 0 1 .306 r
F
.47326 .58469 m .4692 .57524 L .46671 .58561 L F
.47326 .58469 m .47428 .56526 L .4692 .57524 L F
0 g
.47428 .56526 m
.47905 .56055 L
s
.75298 1.06506 m .74641 1.0678 L .75459 1.06558 L 0 .778 .23 r
F
.75298 1.06506 m .74296 1.06826 L .74641 1.0678 L F
0 g
.75157 1.06721 m
.75218 1.06688 L
s
.74266 1.06886 m
.74641 1.0678 L
s
.36009 .93482 m .34653 .92844 L .347 .93242 L 0 1 .532 r
F
.78643 .80901 m .78523 .82057 L .78766 .82856 L 0 1 .459 r
F
0 g
.78253 .83711 m
.78766 .82856 L
s
.75587 .90677 m .75721 .91311 L .76311 .91132 L 0 1 .471 r
F
.75587 .90677 m .75298 .91231 L .75721 .91311 L F
0 g
.75689 .9161 m
.75721 .91311 L
s
.69916 .62185 m
.69973 .62008 L
s
.69973 .62008 m
.70171 .61393 L
s
.69909 .62207 m
.69916 .62185 L
s
.45347 .95931 m .44886 .95731 L .44366 .95673 L 0 1 .526 r
F
0 g
.45347 .95931 m
.45549 .96179 L
s
.45877 .95631 m .45347 .95931 L .45842 .9599 L 0 1 .519 r
F
.45877 .95631 m .44886 .95731 L .45347 .95931 L F
.31243 .72174 m .30182 .72153 L .30411 .72574 L 0 1 .531 r
F
0 g
.30069 .73007 m
.30411 .72574 L
s
.47511 .90104 m .46569 .90512 L .46641 .90424 L 0 0 0 r
F
0 g
.46207 .90622 m
.46641 .90424 L
s
.48922 .65913 m .48413 .64694 L .48585 .65712 L 0 1 .295 r
F
.4825 .67739 m .48413 .64694 L .48052 .64552 L 0 1 .304 r
F
.4825 .67739 m .48585 .65712 L .48413 .64694 L F
0 g
.48413 .64694 m
.48526 .63271 L
s
.51633 .97117 m .51155 .97058 L .50782 .97076 L 0 .808 .324 r
F
.32231 .93109 m .30617 .92822 L .30568 .93082 L 0 1 .474 r
F
.32231 .93109 m .31126 .92748 L .30617 .92822 L F
.32231 .93109 m .31819 .92871 L .31126 .92748 L F
0 g
.32179 .93368 m
.32231 .93109 L
s
.33165 .92931 m .31819 .92871 L .32232 .93109 L 0 1 .456 r
F
0 g
.32232 .93109 m
.32815 .93228 L
s
.4846 1.05298 m .47588 1.05117 L .48278 1.0554 L 0 .649 .426 r
F
.4846 1.05298 m .47147 1.04718 L .47588 1.05117 L F
0 g
.46994 1.0489 m
.47588 1.05117 L
s
.41054 .98632 m .40983 .99295 L .41238 .99185 L 0 .93 .462 r
F
.42379 1.00148 m .41238 .99185 L .40983 .99295 L 0 .89 .465 r
F
0 g
.40983 .99295 m
.41226 .99828 L
s
.40391 .98899 m
.40983 .99295 L
s
.64249 .55651 m
.64272 .55863 L
s
.64218 .55375 m
.64249 .55651 L
s
.64211 .55314 m
.64218 .55375 L
s
.64197 .5519 m
.64211 .55314 L
s
.64147 .5474 m
.64197 .5519 L
s
.64128 .5457 m
.64147 .5474 L
s
.4198 .69046 m .41086 .69352 L .41514 .69308 L 0 1 .496 r
F
.4198 .69046 m .40925 .69151 L .41086 .69352 L F
0 g
.41514 .69308 m
.41719 .6951 L
s
.4198 .69046 m .4114 .68837 L .40925 .69151 L 0 1 .496 r
F
.4198 .69046 m .41607 .68574 L .4114 .68837 L F
.4198 .69046 m .42014 .68537 L .41607 .68574 L F
.4198 .69046 m .42174 .68739 L .42014 .68537 L F
0 g
.4198 .69046 m
.42154 .69232 L
s
.41514 .69308 m
.4198 .69046 L
s
.5044 .96951 m .49964 .96869 L .49558 .96885 L 0 .991 .405 r
F
.31318 .9062 m .30664 .91405 L .31172 .91317 L 0 1 .47 r
F
.31318 .9062 m .30031 .90825 L .30664 .91405 L F
0 g
.306 .92098 m
.30664 .91405 L
s
.48274 .8962 m .47965 .89821 L .47581 .90017 L 0 0 0 r
F
.48701 .89595 m .48274 .8962 L .48624 .89463 L F
.48701 .89595 m .47965 .89821 L .48274 .8962 L F
0 g
.48274 .8962 m
.48388 .89511 L
s
.44366 .95673 m
.44886 .95731 L
s
.37909 .70992 m .36974 .70662 L .36821 .71044 L 0 1 .525 r
F
0 g
.36821 .71044 m
.37035 .71311 L
s
.37909 .70992 m .37411 .70368 L .36974 .70662 L 0 1 .525 r
F
.37909 .70992 m .37839 .7036 L .37411 .70368 L F
.37909 .70992 m .38053 .70627 L .37839 .7036 L F
0 g
.37909 .70992 m
.38131 .71236 L
s
.37473 .71285 m
.37909 .70992 L
s
.53013 .93219 m .52936 .93787 L .53091 .9431 L 0 .223 .277 r
F
0 g
.53085 .94333 m
.53091 .9431 L
s
.33145 .61638 m .3217 .61489 L .32175 .62089 L 0 1 .489 r
F
0 g
.31647 .62663 m
.32175 .62089 L
s
.33145 .61638 m .32561 .60736 L .3217 .61489 L 0 1 .489 r
F
.33145 .61638 m .33137 .60236 L .32561 .60736 L F
.33145 .61638 m .33513 .60322 L .33137 .60236 L F
.33145 .61638 m .33516 .60924 L .33513 .60322 L F
0 g
.33145 .61638 m
.33163 .62198 L
s
.3257 .62137 m
.33145 .61638 L
s
.41394 .94367 m .41164 .94787 L .41466 .94678 L 0 1 .531 r
F
.41394 .94367 m .40616 .94628 L .41164 .94787 L F
.42457 .95078 m .41466 .94678 L .41164 .94787 L 0 1 .532 r
F
0 g
.41164 .94787 m
.41292 .95086 L
s
.5252 .92461 m .52936 .93786 L .52862 .93278 L 0 .272 .306 r
F
0 g
.5252 .92461 m
.52862 .93278 L
s
.5267 .93717 m
.52936 .93786 L
s
.5252 .92461 m
.52751 .92447 L
s
.54642 1.07964 m .54411 1.07918 L .54286 1.07811 L 0 0 0 r
F
.40615 .94628 m .39623 .94136 L .39305 .94232 L 0 1 .533 r
F
.40615 .94628 m .40186 .94306 L .39623 .94136 L F
0 g
.40615 .94628 m
.40721 .94953 L
s
.41394 .94367 m .40186 .94306 L .40616 .94628 L 0 1 .531 r
F
0 g
.40616 .94628 m
.41164 .94787 L
s
.71246 .89898 m
.71257 .89887 L
s
.71245 .89887 m
.71246 .89898 L
s
.34112 .92311 m .33733 .93032 L .34101 .92956 L 0 1 .463 r
F
.34112 .92311 m .33178 .9249 L .33733 .93032 L F
0 g
.34124 .92967 m
.34127 .92968 L
s
.34112 .92957 m
.34118 .92958 L
s
.33182 .93144 m
.33182 .93149 L
s
.33182 .9313 m
.33182 .93149 L
s
.34106 .92535 m .33733 .93032 L .34101 .92956 L 0 1 .53 r
F
.341 .92759 m .33733 .93032 L .34101 .92956 L 0 1 .435 r
F
.34106 .92535 m .33171 .9271 L .33733 .93032 L 0 1 .53 r
F
.341 .92759 m .33165 .92931 L .33733 .93032 L 0 1 .435 r
F
0 g
.33733 .93032 m
.33793 .93667 L
s
.33182 .93135 m
.33182 .93149 L
s
.33179 .92715 m
.33181 .92928 L
s
.33181 .92933 m
.33182 .93135 L
s
.33177 .92933 m
.33182 .9313 L
s
.34101 .92956 m
.34124 .92967 L
s
.34101 .92956 m
.34105 .92956 L
s
.34105 .92956 m
.34112 .92957 L
s
.50081 .88491 m .498 .8873 L .49503 .88906 L 0 0 0 r
F
.50284 .88715 m .50081 .88491 L .50342 .88385 L F
.50284 .88715 m .498 .8873 L .50081 .88491 L F
0 g
.50081 .88491 m
.50242 .88296 L
s
.36009 .93482 m .35021 .92771 L .34653 .92844 L 0 1 .532 r
F
0 g
.34127 .92968 m
.34339 .93069 L
s
.34339 .93069 m
.347 .93242 L
s
.36009 .93482 m .35603 .93045 L .35021 .92771 L 0 1 .532 r
F
.36889 .93276 m .35603 .93045 L .36009 .93482 L 0 1 .531 r
F
0 g
.36009 .93482 m
.36571 .93743 L
s
.36009 .93482 m
.36054 .93879 L
s
.4379 .50967 m .42934 .51812 L .43145 .51658 L 0 .867 .146 r
F
0 g
.43288 .51615 m
.43461 .5142 L
s
.4379 .50967 m .43294 .51366 L .42934 .51812 L 0 .867 .146 r
F
.4379 .50967 m .43985 .50617 L .43294 .51366 L F
.4379 .50967 m .44631 .49926 L .43985 .50617 L F
.4379 .50967 m .44799 .49755 L .44631 .49926 L F
0 g
.44439 .502 m
.44776 .49783 L
s
.43461 .5142 m
.4379 .50967 L
s
.53013 .93219 m .52862 .93278 L .52936 .93787 L 0 .223 .277 r
F
0 g
.52936 .93787 m
.53091 .9431 L
s
.77153 .83965 m .78101 .83003 L .77657 .83111 L 0 1 .469 r
F
.76055 .84278 m .77153 .83965 L .76992 .83291 L 0 1 .463 r
F
0 g
.3217 .61489 m
.32175 .62089 L
s
.49316 .69271 m .48922 .65913 L .48843 .67443 L 0 1 .292 r
F
.5256 .44495 m .51988 .45337 L .51973 .44992 L 0 .154 .071 r
F
.5256 .44495 m .52635 .45432 L .51988 .45337 L F
.5256 .44495 m .5348 .45212 L .52635 .45432 L F
.5256 .44495 m .54065 .44713 L .5348 .45212 L F
.5256 .44495 m .54001 .4427 L .54065 .44713 L F
0 g
.5195 .44435 m
.5256 .44495 L
s
.54001 .4427 m
.54541 .43825 L
s
.53356 .44176 m
.54001 .4427 L
s
.6751 1.07354 m .66755 1.07101 L .67531 1.07202 L 0 0 0 r
F
.6751 1.07354 m .6647 1.07075 L .66755 1.07101 L F
0 g
.66754 1.07101 m
.66755 1.07101 L
s
.67182 1.07141 m
.67188 1.07142 L
s
.33178 .9249 m .31844 .91203 L .3185 .91863 L 0 1 .469 r
F
.44644 .91199 m .43509 .91541 L .43549 .91537 L 0 0 0 r
F
0 g
.43036 .91684 m
.43549 .91537 L
s
.23767 .65378 m .22766 .66139 L .23218 .66146 L 0 1 .487 r
F
0 g
.23218 .66146 m
.23437 .66927 L
s
.37915 .95588 m .36553 .94509 L .3664 .95105 L 0 1 .46 r
F
0 g
.36036 .94636 m
.3664 .95105 L
s
.46719 .62069 m .47286 .60066 L .47111 .59587 L 0 1 .322 r
F
.46719 .62069 m .47118 .61128 L .47286 .60066 L F
0 g
.47286 .60066 m
.47729 .59672 L
s
.47176 .60761 m
.47286 .60066 L
s
.3638 .59521 m
.36947 .5904 L
s
.3 .91738 m .29536 .92293 L .29949 .92225 L 0 1 .531 r
F
.3 .91738 m .28953 .91893 L .29536 .92293 L F
0 g
.29536 .92293 m
.29568 .92777 L
s
.29949 .92225 m
.30346 .92453 L
s
.30346 .92453 m
.30584 .92589 L
s
.45946 .74976 m
.46001 .74952 L
s
.45631 .75119 m
.45946 .74976 L
s
.77763 .90938 m .78449 .91456 L .78848 .91061 L 0 1 .5 r
F
0 g
.77834 .91696 m
.78449 .91456 L
s
.78449 .91456 m
.78467 .91806 L
s
.40893 .76611 m .40064 .76771 L .4053 .76668 L 0 0 0 r
F
0 g
.4053 .76668 m
.40617 .76648 L
s
.8014 .78287 m .8013 .78172 L .80595 .78404 L 0 0 0 r
F
.79966 .78208 m .8013 .78172 L .8014 .78287 L F
.79965 .78209 m .79829 .78095 L .8013 .78172 L F
.79864 .78163 m .79829 .78095 L .79965 .78209 L F
.79967 .78218 m .79863 .78831 L .80201 .79716 L 0 1 .452 r
F
.79964 .78217 m .79863 .78831 L .79967 .78218 L F
.79864 .78163 m .79863 .78831 L .79965 .78209 L F
.8014 .78287 m .80201 .79716 L .80653 .79632 L F
.79965 .78209 m .80201 .79716 L .8014 .78287 L F
.8014 .78287 m .80653 .79632 L .80979 .78666 L F
.8014 .78287 m .80979 .78666 L .80992 .78627 L F
.8014 .78287 m .80982 .78621 L .80992 .78627 L 0 0 0 r
F
.8014 .78287 m .80595 .78404 L .80982 .78621 L F
.8014 .78287 m .80992 .78627 L .80996 .78617 L 0 1 .452 r
F
.8014 .78287 m .80992 .78627 L .80996 .7863 L 0 0 0 r
F
.79895 .78224 m .8014 .78287 L .80996 .7863 L F
.79965 .78209 m .79964 .78217 L .79967 .78218 L 0 1 .452 r
F
.79865 .77564 m .79864 .78163 L .79965 .78209 L F
.79895 .78224 m .79965 .78209 L .8014 .78287 L 0 0 0 r
F
.79965 .78209 m .79966 .78208 L .8014 .78287 L F
.79895 .78224 m .79864 .78163 L .79965 .78209 L F
.79865 .77564 m .79965 .78209 L .8014 .78287 L 0 1 .452 r
F
.79865 .77564 m .8014 .78287 L .80996 .78617 L F
0 g
.79802 .78075 m
.79864 .78093 L
s
.4902 .51063 m .50161 .49374 L .5013 .49339 L 0 .927 .158 r
F
.4902 .51063 m .49686 .50113 L .50161 .49374 L F
0 g
.50161 .49374 m
.50686 .48658 L
s
.49686 .50113 m
.50208 .49444 L
s
.49686 .50113 m
.50161 .49374 L
s
.58685 .61879 m .58942 .63127 L .58653 .63426 L 0 .248 .155 r
F
0 g
.58406 .63519 m
.58448 .63271 L
s
.58285 .64227 m
.58322 .64014 L
s
.5827 .64316 m
.58285 .64227 L
s
.58644 .62119 m
.58685 .61879 L
s
.39368 .70044 m
.39564 .70265 L
s
.53546 1.07907 m .52932 1.07635 L .53678 1.07777 L 0 .394 .202 r
F
0 g
.52011 .97205 m
.52316 .97195 L
s
.52321 .97195 m
.52348 .97194 L
s
.38779 .57313 m .38093 .57643 L .38421 .57537 L 0 1 .361 r
F
.38779 .57313 m .37964 .57594 L .38093 .57643 L F
.38779 .57313 m .38123 .57422 L .37964 .57594 L F
0 g
.38336 .57914 m
.3842 .57542 L
s
.3842 .57542 m
.38421 .57537 L
s
.38779 .57313 m .38481 .57197 L .38123 .57422 L 0 1 .361 r
F
.38779 .57313 m .38801 .5707 L .38481 .57197 L F
.38779 .57313 m .38928 .57119 L .38801 .5707 L F
0 g
.38779 .57313 m
.38912 .57384 L
s
.38421 .57537 m
.38779 .57313 L
s
.38928 .57119 m
.39279 .56889 L
s
.27908 .92052 m .2648 .91042 L .2646 .91567 L 0 1 .532 r
F
.27908 .92052 m .26911 .90992 L .2648 .91042 L F
.27908 .92052 m .27523 .91426 L .26911 .90992 L F
.28953 .91893 m .27523 .91426 L .27908 .92052 L F
0 g
.27886 .92575 m
.27908 .92052 L
s
.27908 .92052 m
.28504 .92468 L
s
.39575 .93801 m .39305 .94232 L .39623 .94136 L 0 1 .531 r
F
.39575 .93801 m .38758 .94027 L .39305 .94232 L F
0 g
.39305 .94232 m
.39412 .94557 L
s
.30181 .72153 m .29112 .72567 L .29672 .72571 L 0 1 .531 r
F
0 g
.29672 .72571 m
.30068 .73007 L
s
.49991 .6152 m .49557 .6202 L .4964 .61901 L 0 0 0 r
F
.49991 .6152 m .49819 .61848 L .49557 .6202 L F
0 g
.49557 .61949 m
.49765 .61747 L
s
.49991 .6152 m .50253 .61501 L .49819 .61848 L 0 0 0 r
F
.49991 .6152 m .50603 .61119 L .50253 .61501 L F
.49991 .6152 m .50637 .60959 L .50603 .61119 L F
0 g
.50375 .6113 m
.50637 .60959 L
s
.49765 .61747 m
.49991 .6152 L
s
.50637 .60959 m
.50952 .60513 L
s
.49256 .96726 m .48788 .96617 L .48352 .96623 L 0 1 .458 r
F
.42457 .95078 m .4202 .94802 L .41466 .94678 L 0 1 .532 r
F
.43153 .94804 m .42457 .95078 L .42985 .95199 L 0 1 .53 r
F
.43153 .94804 m .4202 .94802 L .42457 .95078 L F
0 g
.42457 .95078 m
.42584 .95376 L
s
.4792 .54319 m .47273 .54698 L .474 .54921 L 0 1 .244 r
F
.4792 .54319 m .47639 .53799 L .47273 .54698 L F
.4792 .54319 m .48252 .52827 L .47639 .53799 L F
.3909 .97283 m .38604 .96614 L .38001 .96184 L 0 1 .465 r
F
.39834 .97038 m .3909 .97283 L .39671 .97709 L 0 .966 .458 r
F
.39834 .97038 m .38604 .96614 L .3909 .97283 L F
0 g
.3909 .97283 m
.39239 .97864 L
s
.75587 .90677 m .7524 .90959 L .75298 .91231 L 0 1 .471 r
F
0 g
.74646 .91381 m
.75298 .91231 L
s
.72555 .90886 m .73601 .9089 L .73176 .908 L 0 1 .464 r
F
.71267 .90548 m .72555 .90886 L .72465 .90643 L 0 .989 .43 r
F
0 g
.66467 1.07074 m
.66468 1.07074 L
s
.66424 1.07066 m
.66467 1.07074 L
s
.66407 1.07063 m
.66424 1.07066 L
s
.71992 .8803 m .7172 .88811 L .719 .89238 L 0 1 .453 r
F
0 g
.7172 .88811 m
.719 .89238 L
s
.71407 .89736 m
.719 .89238 L
s
.4846 1.05298 m .48278 1.0554 L .48841 1.05789 L 0 .649 .426 r
F
0 g
.48278 1.0554 m
.4875 1.0594 L
s
.76372 .76211 m .7749 .76752 L .77549 .77001 L 0 .116 0 r
F
0 g
.77155 .76367 m
.7749 .76752 L
s
.7749 .76752 m
.77797 .76796 L
s
.33178 .9249 m .32232 .91138 L .31844 .91203 L 0 1 .469 r
F
0 g
.31172 .91317 m
.31258 .91386 L
s
.31258 .91386 m
.3185 .91863 L
s
.33178 .9249 m .32804 .91691 L .32232 .91138 L 0 1 .469 r
F
.34112 .92311 m .32804 .91691 L .33178 .9249 L 0 1 .463 r
F
0 g
.33178 .9249 m
.33179 .92709 L
s
.33178 .9249 m
.33366 .92674 L
s
.24888 .65416 m .24047 .64343 L .23767 .65378 L 0 1 .484 r
F
.24888 .65416 m .2459 .63592 L .24047 .64343 L F
.24888 .65416 m .25032 .63627 L .2459 .63592 L F
.24888 .65416 m .25159 .64409 L .25032 .63627 L F
0 g
.24347 .66163 m
.24888 .65416 L
s
.24888 .65416 m
.25024 .66173 L
s
.42057 .76306 m .4091 .76637 L .40893 .76611 L 0 0 0 r
F
.42057 .76306 m .41272 .76576 L .4091 .76637 L F
0 g
.41043 .76559 m
.41229 .76496 L
s
.42057 .76306 m .41737 .76468 L .41272 .76576 L 0 0 0 r
F
.42057 .76306 m .42073 .76352 L .41737 .76468 L F
0 g
.42057 .76306 m
.42188 .76246 L
s
.41695 .76367 m
.42057 .76306 L
s
.28922 .63246 m .27898 .63859 L .28337 .63894 L 0 1 .48 r
F
0 g
.28337 .63894 m
.28485 .64607 L
s
.34101 .92956 m
.34114 .92967 L
s
.35996 .94015 m .34653 .92844 L .34694 .93466 L 0 1 .462 r
F
0 g
.34114 .92967 m
.34694 .93466 L
s
.34118 .92958 m
.34131 .92959 L
s
.34131 .92959 m
.34664 .93013 L
s
.51133 .71017 m .51327 .70803 L .51483 .68657 L 0 .89 .272 r
F
.3682 .71044 m .3597 .71353 L .3639 .7134 L 0 1 .53 r
F
0 g
.3639 .7134 m
.36637 .71633 L
s
.7906 .60739 m .80491 .60773 L .80174 .61033 L 0 .041 0 r
F
0 g
.80491 .60773 m
.81068 .60702 L
s
.80385 .60437 m
.80491 .60773 L
s
.48378 .73962 m .47612 .74735 L .48017 .74265 L 0 .076 .066 r
F
.48378 .73962 m .47385 .75162 L .47612 .74735 L F
.48378 .73962 m .47488 .7526 L .47385 .75162 L F
.48378 .73962 m .47851 .74956 L .47488 .7526 L F
.48378 .73962 m .48231 .74453 L .47851 .74956 L F
0 g
.48078 .74214 m
.48118 .7418 L
s
.4806 .74229 m
.48078 .74214 L
s
.48017 .74265 m
.4806 .74229 L
s
.48017 .74265 m
.4813 .74086 L
s
.48378 .73962 m .48456 .74028 L .48231 .74453 L 0 .076 .066 r
F
0 g
.48378 .73962 m
.48565 .73572 L
s
.4813 .74086 m
.48271 .73862 L
s
.48118 .7418 m
.48378 .73962 L
s
.48456 .74028 m
.48576 .73873 L
s
.45877 .95631 m .4472 .95493 L .44886 .95731 L 0 1 .519 r
F
.28921 .9279 m .2848 .93148 L .28893 .93083 L 0 1 .499 r
F
.28921 .9279 m .27875 .92932 L .2848 .93148 L F
0 g
.2848 .93148 m
.28537 .93442 L
s
.28893 .93083 m
.29144 .9315 L
s
.68558 .55766 m
.687 .56977 L
s
.52116 .85488 m
.52117 .85562 L
s
.68558 .55766 m
.69196 .57036 L
s
.4825 .67739 m .48052 .64552 L .47742 .65382 L 0 1 .304 r
F
0 g
.48052 .64552 m
.48413 .64694 L
s
.48052 .64552 m
.48142 .63491 L
s
.32305 .72183 m .31359 .71642 L .31243 .72174 L 0 1 .531 r
F
.32305 .72183 m .31763 .7126 L .31359 .71642 L F
.32305 .72183 m .32184 .71285 L .31763 .7126 L F
.32305 .72183 m .32416 .71681 L .32184 .71285 L F
0 g
.31902 .72563 m
.32305 .72183 L
s
.32305 .72183 m
.32541 .72551 L
s
.40893 .76611 m .39728 .7685 L .40064 .76771 L 0 0 0 r
F
0 g
.39738 .76855 m
.39876 .76819 L
s
.68837 .57338 m
.69082 .57983 L
s
.687 .56977 m
.68837 .57338 L
s
.69082 .57983 m
.69343 .58668 L
s
.51991 .59993 m .52424 .59578 L .52797 .59522 L 0 0 .054 r
F
0 g
.52424 .59578 m
.52698 .5904 L
s
.48701 .89595 m .48624 .89463 L .48782 .89455 L 0 0 0 r
F
.49382 .89071 m .48782 .89455 L .48624 .89463 L F
0 g
.48624 .89463 m
.48746 .89297 L
s
.48274 .8962 m
.48624 .89463 L
s
.44033 .67424 m .43188 .67722 L .43568 .67678 L 0 1 .455 r
F
.44033 .67424 m .43105 .67532 L .43188 .67722 L F
0 g
.43568 .67678 m
.43697 .67868 L
s
.44033 .67424 m .43375 .67233 L .43105 .67532 L 0 1 .455 r
F
.44033 .67424 m .43841 .66978 L .43375 .67233 L F
.44033 .67424 m .44191 .66937 L .43841 .66978 L F
.44033 .67424 m .44273 .67128 L .44191 .66937 L F
0 g
.44033 .67424 m
.44137 .67608 L
s
.43568 .67678 m
.44033 .67424 L
s
.44273 .67128 m
.44716 .66871 L
s
.24711 .94209 m .23142 .93951 L .23185 .94135 L 0 .912 .306 r
F
.24711 .94209 m .23573 .93918 L .23142 .93951 L F
.24711 .94209 m .24246 .94029 L .23573 .93918 L F
.25753 .94073 m .24246 .94029 L .24711 .94209 L 0 .821 .274 r
F
0 g
.24711 .94209 m
.24751 .94392 L
s
.24711 .94209 m
.25366 .94295 L
s
.43153 .94804 m .42985 .95199 L .43253 .95085 L 0 1 .53 r
F
.44214 .95406 m .43253 .95085 L .42985 .95199 L 0 1 .529 r
F
0 g
.42985 .95199 m
.43138 .95466 L
s
.42457 .95078 m
.42985 .95199 L
s
.45877 .95631 m .45842 .9599 L .46042 .95869 L 0 1 .519 r
F
.46963 .96068 m .46042 .95869 L .45842 .9599 L 0 1 .508 r
F
0 g
.45842 .9599 m
.46056 .96207 L
s
.45347 .95931 m
.45842 .9599 L
s
.6619 .66459 m
.66377 .65107 L
s
.38758 .94027 m .37779 .93442 L .37433 .93526 L 0 1 .532 r
F
.38758 .94027 m .38347 .93657 L .37779 .93442 L F
.39575 .93801 m .38347 .93657 L .38758 .94027 L 0 1 .531 r
F
0 g
.38758 .94027 m
.38827 .9438 L
s
.38758 .94027 m
.39305 .94232 L
s
.30181 .72153 m .28787 .7211 L .29112 .72567 L 0 1 .531 r
F
0 g
.2867 .73026 m
.29112 .72567 L
s
.79975 .65206 m .81338 .66037 L .8111 .65395 L 0 1 .503 r
F
0 g
.81163 .66438 m
.81338 .66037 L
s
.81338 .66037 m
.81852 .66585 L
s
.42174 .68739 m
.42624 .68472 L
s
.54731 .79837 m
.5476 .80023 L
s
.54705 .79663 m
.54731 .79837 L
s
.36901 .92734 m .35574 .92665 L .35608 .92816 L 0 1 .376 r
F
.36901 .92734 m .35943 .92596 L .35574 .92665 L F
.36901 .92734 m .36513 .92626 L .35943 .92596 L F
.37782 .9253 m .36513 .92626 L .36901 .92734 L 0 1 .332 r
F
0 g
.36901 .92734 m
.3745 .92748 L
s
.36901 .92734 m
.36933 .92885 L
s
.23767 .65378 m .22644 .6534 L .22766 .66139 L 0 1 .487 r
F
0 g
.22305 .66929 m
.22766 .66139 L
s
.49316 .69271 m .49546 .68693 L .49624 .6716 L 0 1 .292 r
F
.31318 .9062 m .29695 .89961 L .30031 .90825 L 0 1 .47 r
F
0 g
.30031 .90825 m
.30664 .91405 L
s
.77522 .81194 m .78101 .83003 L .78523 .82057 L 0 1 .452 r
F
.77522 .81194 m .77657 .83111 L .78101 .83003 L F
0 g
.78101 .83003 m
.78253 .83711 L
s
.6941 .91595 m
.69548 .91438 L
s
.78643 .80901 m .79638 .81828 L .79766 .80658 L 0 1 .459 r
F
0 g
.79209 .82768 m
.79638 .81828 L
s
.79638 .81828 m
.79875 .82649 L
s
.66763 .49794 m
.6757 .51218 L
s
.66538 .49452 m
.66763 .49794 L
s
.52834 .8181 m
.52858 .82241 L
s
.52834 .8181 m
.5284 .81849 L
s
.5284 .81849 m
.52883 .82105 L
s
.46853 1.04164 m .47147 1.04718 L .47249 1.0461 L 0 .733 .453 r
F
.4846 1.05298 m .47249 1.0461 L .47147 1.04718 L 0 .649 .426 r
F
0 g
.47147 1.04718 m
.47588 1.05117 L
s
.46567 1.04441 m
.47147 1.04718 L
s
.34101 .92956 m
.34101 .92951 L
s
.4825 .67739 m .48515 .67017 L .48585 .65712 L 0 1 .304 r
F
0 g
.48585 .65712 m
.48922 .65913 L
s
.82952 .7944 m
.83138 .8016 L
s
.8295 .79433 m
.82952 .7944 L
s
.67032 .62782 m
.67034 .62765 L
s
.67034 .62765 m
.67036 .62749 L
s
.67031 .62786 m
.67032 .62782 L
s
.67231 .6342 m
.67355 .63814 L
s
.67032 .62787 m
.67135 .63117 L
s
.67135 .63117 m
.67231 .6342 L
s
.6705 .63373 m
.6708 .64313 L
s
.67045 .63227 m
.6705 .63373 L
s
.67033 .62838 m
.67045 .63227 L
s
.67031 .62787 m
.67033 .62838 L
s
.4686 .4777 m .47601 .47102 L .48096 .46778 L 0 0 0 r
F
0 g
.47601 .47102 m
.48065 .46574 L
s
.61196 .60743 m .6148 .61796 L .61155 .61333 L 0 .507 .099 r
F
.61196 .60743 m .62039 .62213 L .6148 .61796 L F
0 g
.60666 .60448 m
.61196 .60743 L
s
.53013 .93219 m .52895 .93035 L .52862 .93278 L 0 .223 .277 r
F
.43797 1.0158 m .4322 1.01017 L .42621 1.00681 L 0 .847 .466 r
F
.27842 .93813 m .27424 .9398 L .27836 .93919 L 0 .734 .245 r
F
.27842 .93813 m .26797 .93941 L .27424 .9398 L F
0 g
.27424 .9398 m
.27507 .94092 L
s
.27836 .93919 m
.2852 .93915 L
s
.4444 .75628 m .43596 .75891 L .4406 .75705 L 0 0 0 r
F
0 g
.4406 .75705 m
.44397 .75508 L
s
.39834 .97038 m .39671 .97709 L .39959 .97608 L 0 .966 .458 r
F
.41054 .98632 m .39959 .97608 L .39671 .97709 L 0 .93 .462 r
F
0 g
.39671 .97709 m
.39856 .98263 L
s
.3909 .97283 m
.39671 .97709 L
s
.73526 .62852 m
.73579 .62876 L
s
.45293 1.02921 m .44686 1.02396 L .44094 1.0209 L 0 .796 .463 r
F
0 g
.30568 .93082 m
.30568 .93081 L
s
.52764 .71963 m
.52909 .72461 L
s
.78668 .64814 m
.7874 .64885 L
s
.23758 .90798 m .23254 .91429 L .23684 .91376 L 0 1 .533 r
F
.23758 .90798 m .22673 .90913 L .23254 .91429 L F
0 g
.23254 .91429 m
.2328 .92007 L
s
.23684 .91376 m
.23793 .91457 L
s
.64999 .47287 m
.65819 .48455 L
s
.64983 .47284 m
.64999 .47287 L
s
.64698 .47236 m
.64983 .47284 L
s
.52169 .84995 m
.52216 .85377 L
s
.39834 .97038 m .38478 .96044 L .38604 .96614 L 0 .966 .458 r
F
0 g
.38001 .96184 m
.38604 .96614 L
s
.75193 .75266 m .76059 .76172 L .75586 .75811 L 0 .194 0 r
F
.75193 .75266 m .76372 .76211 L .76059 .76172 L F
0 g
.75193 .75266 m
.75586 .75811 L
s
.74943 .75222 m
.75193 .75266 L
s
.50284 .88715 m .49673 .88963 L .498 .8873 L 0 0 0 r
F
0 g
.49503 .88906 m
.498 .8873 L
s
.46719 .62069 m .47111 .59587 L .46647 .59945 L 0 1 .322 r
F
0 g
.47111 .59587 m
.47326 .58469 L
s
.22726 .92833 m
.23233 .9307 L
s
.40637 .69628 m
.41086 .69352 L
s
.42229 .52883 m .42843 .52117 L .43145 .51658 L 0 1 .186 r
F
0 g
.42843 .52117 m
.43288 .51615 L
s
.54548 .45181 m .5407 .45874 L .54008 .45743 L 0 0 .039 r
F
.54548 .45181 m .5474 .45588 L .5407 .45874 L F
0 g
.54077 .45672 m
.54548 .45181 L
s
.52492 .46636 m .53914 .4553 L .53363 .4616 L 0 0 .003 r
F
0 g
.53914 .4553 m
.54548 .45181 L
s
.54444 .58992 m .54903 .58622 L .55372 .58836 L 0 .246 .098 r
F
0 g
.54903 .58622 m
.55122 .57835 L
s
.3682 .71044 m .35777 .71062 L .3597 .71353 L 0 1 .53 r
F
0 g
.35583 .71681 m
.3597 .71353 L
s
.39728 .7685 m .38899 .76989 L .39365 .76908 L 0 0 0 r
F
0 g
.39464 .76894 m
.39738 .76855 L
s
.48812 .74136 m
.48872 .74001 L
s
.48872 .74001 m
.49001 .73712 L
s
.3943 .56471 m .38482 .57197 L .38801 .57069 L 0 1 .266 r
F
.3943 .56471 m .38656 .56815 L .38482 .57197 L F
0 g
.38801 .5707 m
.38928 .57119 L
s
.3943 .56471 m .39208 .56177 L .38656 .56815 L 0 1 .266 r
F
.3943 .56471 m .39838 .55577 L .39208 .56177 L F
.3943 .56471 m .40126 .55418 L .39838 .55577 L F
.3943 .56471 m .39951 .55801 L .40126 .55418 L F
0 g
.39951 .55801 m
.40555 .55191 L
s
.39279 .56889 m
.3943 .56471 L
s
.38801 .57069 m
.3943 .56471 L
s
.47232 .63529 m .47118 .61128 L .46719 .62069 L 0 1 .315 r
F
0 g
.47118 .61128 m
.47176 .60761 L
s
.47118 .61128 m
.47548 .60883 L
s
.33171 .9271 m .31822 .91927 L .31834 .92367 L 0 1 .531 r
F
.33171 .9271 m .3221 .91868 L .31822 .91927 L F
.33171 .9271 m .32789 .92204 L .3221 .91868 L F
.34106 .92535 m .32789 .92204 L .33171 .9271 L 0 1 .53 r
F
0 g
.33171 .9271 m
.33177 .92928 L
s
.33171 .9271 m
.33461 .92876 L
s
.34101 .92951 m
.34101 .92948 L
s
.53546 1.07907 m .53678 1.07777 L .54188 1.07945 L 0 .394 .202 r
F
0 g
.53678 1.07777 m
.54286 1.07811 L
s
.28787 .7211 m .27894 .72552 L .2835 .72559 L 0 1 .53 r
F
0 g
.2835 .72559 m
.28669 .73026 L
s
.21589 .91029 m .20128 .90357 L .20506 .91147 L 0 1 .534 r
F
0 g
.20506 .91147 m
.2111 .91697 L
s
.74498 .90537 m .74662 .91106 L .7524 .90959 L 0 1 .448 r
F
.74498 .90537 m .74238 .91021 L .74662 .91106 L F
0 g
.74646 .91381 m
.74662 .91106 L
s
.28922 .63246 m .27834 .63129 L .27898 .63859 L 0 1 .48 r
F
0 g
.27378 .64543 m
.27898 .63859 L
s
.48093 .96433 m .47636 .96296 L .47176 .96285 L 0 1 .49 r
F
.59426 .60665 m .59647 .62518 L .59347 .6113 L 0 .771 .083 r
F
.50284 .88715 m .50342 .88385 L .5041 .88482 L 0 0 0 r
F
.50877 .8815 m .5041 .88482 L .50342 .88385 L F
0 g
.50342 .88385 m
.50506 .88116 L
s
.50081 .88491 m
.50342 .88385 L
s
.48701 .89595 m .47883 .89961 L .47965 .89821 L 0 0 0 r
F
0 g
.47581 .90017 m
.47965 .89821 L
s
.52492 .46636 m .51953 .47322 L .51938 .47269 L 0 0 .003 r
F
.52492 .46636 m .52565 .46847 L .51953 .47322 L F
.52492 .46636 m .53363 .4616 L .52565 .46847 L F
0 g
.51959 .47244 m
.52492 .46636 L
s
.35053 .60091 m .34078 .60428 L .34454 .60482 L 0 1 .507 r
F
0 g
.34454 .60482 m
.34471 .61044 L
s
.73302 .87421 m .74276 .86505 L .73845 .86672 L 0 1 .466 r
F
0 g
.74276 .86505 m
.74369 .87027 L
s
.74276 .86505 m
.74738 .85669 L
s
.74884 .61639 m .75857 .60142 L .76297 .60301 L 0 .18 .062 r
F
.74884 .61639 m .75253 .60713 L .75857 .60142 L F
0 g
.75724 .59454 m
.75857 .60142 L
s
.51784 1.0726 m .52356 1.07514 L .52332 1.07493 L 0 .54 .31 r
F
.53546 1.07907 m .52332 1.07493 L .52356 1.07514 L 0 .394 .202 r
F
0 g
.51812 1.07358 m
.52356 1.07514 L
s
.52454 1.07534 m
.52932 1.07635 L
s
.4692 .57524 m .47588 .55295 L .47081 .55816 L 0 1 .313 r
F
0 g
.47588 .55295 m
.4792 .54319 L
s
.51784 1.0726 m .51078 1.06971 L .50535 1.06816 L 0 .54 .31 r
F
0 g
.52824 .97238 m
.53235 .97289 L
s
.53438 .97289 m .53291 .97278 L .53235 .97289 L 0 .593 .22 r
F
.41312 .91986 m .40975 .92137 L .41309 .92044 L 0 .762 .233 r
F
.41312 .91986 m .40455 .92201 L .40975 .92137 L F
0 g
.40975 .92137 m
.41027 .9219 L
s
.42379 1.00148 m .41837 .99551 L .41238 .99185 L 0 .89 .465 r
F
.50175 .72489 m .49896 .67829 L .49812 .69601 L 0 .914 .284 r
F
0 g
.49624 .6716 m
.49896 .67829 L
s
.41394 .94367 m .40113 .93995 L .40186 .94306 L 0 1 .531 r
F
0 g
.39623 .94136 m
.40186 .94306 L
s
.75298 1.06506 m .74576 1.06708 L .74296 1.06826 L 0 .778 .23 r
F
0 g
.73427 1.06964 m
.74296 1.06826 L
s
.69052 1.0728 m .70198 1.0728 L .69881 1.07302 L 0 .556 .207 r
F
.70895 1.07357 m .70198 1.0728 L .70994 1.07236 L 0 0 0 r
F
.70895 1.07357 m .69881 1.07302 L .70198 1.0728 L F
0 g
.69819 1.07263 m
.70198 1.0728 L
s
.2683 .93077 m .2535 .92478 L .25353 .92817 L 0 1 .513 r
F
.2683 .93077 m .25781 .92438 L .2535 .92478 L F
.2683 .93077 m .26416 .92695 L .25781 .92438 L F
.27875 .92932 m .26416 .92695 L .2683 .93077 L 0 1 .507 r
F
0 g
.2683 .93077 m
.26831 .93414 L
s
.2683 .93077 m
.27449 .93313 L
s
.68282 1.07311 m .69052 1.0728 L .69405 1.07341 L 0 0 0 r
F
0 g
.52097 .87209 m
.52107 .87247 L
s
.52107 .87247 m
.5228 .87972 L
s
.52117 .86911 m
.5219 .8663 L
s
.52116 .86914 m
.52117 .86911 L
s
.81014 .91297 m .82095 .91411 L .82108 .91008 L 0 1 .522 r
F
.77522 .81194 m .77409 .82337 L .77657 .83111 L 0 1 .452 r
F
0 g
.77153 .83965 m
.77657 .83111 L
s
.52485 .91306 m
.52504 .9136 L
s
.52541 .91464 m
.52567 .91537 L
s
.52623 .91695 m
.52652 .91777 L
s
.5222 .89223 m .52371 .90986 L .52565 .90858 L 0 .28 .298 r
F
0 g
.52371 .90986 m
.52565 .90858 L
s
.52371 .90986 m
.52485 .91306 L
s
.39728 .7685 m .38564 .77032 L .38899 .76989 L 0 0 0 r
F
0 g
.38576 .77077 m
.38899 .76989 L
s
.501 1.06312 m .49321 1.06127 L .50023 1.06486 L 0 .519 .362 r
F
.501 1.06312 m .48841 1.05789 L .49321 1.06127 L F
0 g
.4875 1.0594 m
.49321 1.06127 L
s
.28787 .7211 m .27651 .72067 L .27894 .72552 L 0 1 .53 r
F
0 g
.2753 .73033 m
.27894 .72552 L
s
.31243 .72174 m .30302 .71589 L .30182 .72153 L 0 1 .531 r
F
.31243 .72174 m .30709 .71188 L .30302 .71589 L F
0 g
.30182 .72153 m
.30411 .72574 L
s
.31243 .72174 m .31131 .71219 L .30709 .71188 L 0 1 .531 r
F
.31243 .72174 m .31359 .71642 L .31131 .71219 L F
0 g
.30837 .72573 m
.31243 .72174 L
s
.31243 .72174 m
.31476 .72569 L
s
.3217 .61489 m .30969 .61912 L .31488 .61992 L 0 1 .488 r
F
0 g
.31488 .61992 m
.31647 .62663 L
s
.56106 .44517 m
.56108 .44517 L
s
.5606 .44565 m
.56106 .44517 L
s
.55987 .44641 m
.5606 .44565 L
s
.55832 .44803 m
.55987 .44641 L
s
.55627 .45017 m
.55832 .44803 L
s
.50525 .96761 m .49964 .96869 L .5044 .96951 L 0 .822 .365 r
F
.50525 .96761 m .49658 .96741 L .49964 .96869 L F
0 g
.49558 .96885 m
.49964 .96869 L
s
.51794 .87238 m
.51832 .87159 L
s
.51784 .87259 m
.51794 .87238 L
s
.73773 .86771 m
.73845 .86672 L
s
.73302 .87421 m
.73773 .86771 L
s
.71992 .8803 m .73302 .87421 L .73124 .86992 L 0 1 .453 r
F
.43153 .94804 m .41919 .94521 L .4202 .94802 L 0 1 .53 r
F
0 g
.41466 .94678 m
.4202 .94802 L
s
.50525 .96761 m .5044 .96951 L .50812 .9696 L 0 .822 .365 r
F
0 g
.5044 .96951 m
.50782 .97076 L
s
.46853 1.04164 m .46222 1.03679 L .45642 1.03403 L 0 .733 .453 r
F
.77947 .60386 m .785 .60934 L .78059 .60827 L 0 .123 .007 r
F
.77947 .60386 m .7906 .60739 L .785 .60934 L F
0 g
.67043 .627 m
.67364 .62574 L
s
.67181 .64763 m
.67518 .62925 L
s
.67518 .62925 m
.67521 .62912 L
s
.67521 .62912 m
.67523 .62902 L
s
.67523 .62902 m
.67536 .62827 L
s
.22644 .6534 m .21635 .66121 L .22088 .66128 L 0 1 .489 r
F
0 g
.22088 .66128 m
.22305 .66929 L
s
.42229 .52883 m .4133 .53728 L .4158 .53573 L 0 1 .186 r
F
0 g
.41846 .53462 m
.41955 .53343 L
s
.42229 .52883 m .41632 .53269 L .4133 .53728 L 0 1 .186 r
F
.42229 .52883 m .42285 .52502 L .41632 .53269 L F
.42229 .52883 m .42934 .51812 L .42285 .52502 L F
.42229 .52883 m .43145 .51658 L .42934 .51812 L F
0 g
.42843 .52117 m
.43145 .51658 L
s
.41955 .53343 m
.42229 .52883 L
s
.43145 .51658 m
.4379 .50967 L
s
.51006 .48243 m .51938 .47269 L .51953 .47322 L 0 0 0 r
F
.50642 .4864 m .51885 .47217 L .51358 .47832 L F
.50642 .4864 m .51358 .47832 L .50598 .48639 L F
.50598 .48639 m .51151 .48073 L .51006 .48243 L F
.51151 .48073 m .51938 .47269 L .51006 .48243 L F
.51885 .47217 m .51915 .47183 L .51358 .47832 L F
0 g
.51915 .47183 m
.52492 .46636 L
s
.4444 .75628 m .43284 .76086 L .43596 .75891 L 0 0 0 r
F
.4444 .75628 m .43334 .76159 L .43284 .76086 L F
.4444 .75628 m .43715 .76083 L .43334 .76159 L F
0 g
.43236 .75983 m
.4352 .7591 L
s
.4352 .7591 m
.43596 .75891 L
s
.4444 .75628 m .44172 .75907 L .43715 .76083 L 0 0 0 r
F
.4444 .75628 m .44483 .75712 L .44172 .75907 L F
0 g
.4444 .75628 m
.44756 .75385 L
s
.4406 .75705 m
.4444 .75628 L
s
.76676 .9081 m .77381 .91297 L .77763 .90938 L 0 1 .488 r
F
0 g
.76779 .91507 m
.77381 .91297 L
s
.77381 .91297 m
.77412 .91621 L
s
.56106 .44542 m
.56248 .44662 L
s
.55568 .44989 m
.55987 .44641 L
s
.55987 .44641 m
.56106 .44542 L
s
.58365 .59735 m .58798 .59941 L .59347 .6113 L 0 .699 .106 r
F
.59194 .44451 m .60006 .44382 L .60812 .44642 L 0 .156 .035 r
F
.49457 .96495 m .49256 .96726 L .49658 .96741 L 0 .963 .429 r
F
.49457 .96495 m .48788 .96617 L .49256 .96726 L F
0 g
.49256 .96726 m
.49558 .96885 L
s
.28922 .63246 m .2819 .6219 L .27834 .63129 L 0 1 .48 r
F
.28922 .63246 m .28776 .6154 L .2819 .6219 L F
.28922 .63246 m .29201 .61614 L .28776 .6154 L F
.28922 .63246 m .29263 .62346 L .29201 .61614 L F
0 g
.28922 .63246 m
.28996 .63944 L
s
.28337 .63894 m
.28922 .63246 L
s
.80889 .80458 m .82013 .80294 L .81783 .79447 L 0 1 .471 r
F
.50651 .7168 m .50368 .6834 L .50447 .70369 L 0 .904 .278 r
F
.50175 .72489 m .50447 .70369 L .50368 .6834 L 0 .914 .284 r
F
0 g
.50368 .6834 m
.50489 .664 L
s
.50132 .67254 m
.50368 .6834 L
s
.39368 .70044 m .38481 .70336 L .38909 .70312 L 0 1 .519 r
F
0 g
.38909 .70312 m
.3913 .70557 L
s
.3682 .71044 m .35941 .70661 L .35777 .71062 L 0 1 .53 r
F
.3682 .71044 m .36371 .70365 L .35941 .70661 L F
.3682 .71044 m .36782 .7037 L .36371 .70365 L F
.3682 .71044 m .36974 .70662 L .36782 .7037 L F
0 g
.3639 .7134 m
.3682 .71044 L
s
.49042 .62442 m .4942 .62082 L .4964 .61901 L 0 0 0 r
F
0 g
.4942 .62082 m
.49557 .61949 L
s
.36876 .93818 m .36553 .94509 L .36898 .94426 L 0 1 .456 r
F
.36876 .93818 m .35996 .94015 L .36553 .94509 L F
.37915 .95588 m .36898 .94426 L .36553 .94509 L 0 1 .46 r
F
0 g
.36553 .94509 m
.3664 .95105 L
s
.51602 .96983 m .51155 .97058 L .51633 .97117 L 0 .651 .279 r
F
.51602 .96983 m .50812 .9696 L .51155 .97058 L F
0 g
.50782 .97076 m
.51155 .97058 L
s
.46973 .74694 m .46144 .75183 L .46589 .74864 L 0 0 .038 r
F
.46973 .74694 m .45874 .75499 L .46144 .75183 L F
0 g
.46781 .74667 m
.46885 .7456 L
s
.46973 .74694 m .45958 .75601 L .45874 .75499 L 0 0 .038 r
F
.46973 .74694 m .46343 .7543 L .45958 .75601 L F
.46973 .74694 m .46771 .751 L .46343 .7543 L F
.46973 .74694 m .47041 .74784 L .46771 .751 L F
0 g
.46973 .74694 m
.47255 .74307 L
s
.46589 .74864 m
.46781 .74667 L
s
.46589 .74864 m
.46973 .74694 L
s
.48915 .74036 m
.49069 .73748 L
s
.49069 .73748 m
.49069 .73748 L
s
.49029 .73881 m
.49069 .73748 L
s
.49015 .73928 m
.49029 .73881 L
s
.35996 .94015 m .35021 .92771 L .34653 .92844 L 0 1 .462 r
F
.35996 .94015 m .35597 .93273 L .35021 .92771 L F
.36876 .93818 m .35597 .93273 L .35996 .94015 L 0 1 .456 r
F
0 g
.35996 .94015 m
.36553 .94509 L
s
.35996 .94015 m
.36036 .94636 L
s
.74498 .90537 m .74167 .90778 L .74238 .91021 L 0 1 .448 r
F
0 g
.73602 .9114 m
.74238 .91021 L
s
.40455 .92201 m .39191 .92326 L .39212 .92409 L 0 .812 .252 r
F
0 g
.66101 .63949 m
.6619 .66459 L
s
.661 .63924 m
.66101 .63949 L
s
.6751 1.07354 m .67531 1.07202 L .68282 1.07311 L 0 0 0 r
F
0 g
.66755 1.07101 m
.67531 1.07202 L
s
.67188 1.07142 m
.67531 1.07202 L
s
.49457 .96495 m .4852 .9646 L .48788 .96617 L 0 .963 .429 r
F
0 g
.48352 .96623 m
.48788 .96617 L
s
.31432 .9217 m
.31834 .92367 L
s
.37771 .93081 m .37433 .93526 L .37779 .93442 L 0 1 .53 r
F
.37771 .93081 m .36889 .93276 L .37433 .93526 L F
0 g
.37433 .93526 m
.37504 .9388 L
s
.44214 .95406 m .4378 .95174 L .43253 .95085 L 0 1 .529 r
F
0 g
.44214 .95406 m
.44366 .95673 L
s
.40893 .76611 m .39746 .76852 L .39728 .7685 L 0 0 0 r
F
.40893 .76611 m .40109 .76795 L .39746 .76852 L F
.40893 .76611 m .40574 .76716 L .40109 .76795 L F
.40893 .76611 m .4091 .76637 L .40574 .76716 L F
0 g
.40893 .76611 m
.41043 .76559 L
s
.4053 .76668 m
.40893 .76611 L
s
.44846 .95123 m .44214 .95406 L .4472 .95493 L 0 1 .524 r
F
.44846 .95123 m .4378 .95174 L .44214 .95406 L F
.51475 .87544 m .51236 .87792 L .51041 .87881 L 0 0 0 r
F
.6751 1.07354 m .66792 1.07183 L .6647 1.07075 L F
0 g
.6647 1.07075 m
.66792 1.07183 L
s
.66468 1.07074 m
.6647 1.07075 L
s
.60153 .62469 m
.60349 .63105 L
s
.60356 .6313 m
.60392 .63246 L
s
.60145 .62445 m
.60153 .62469 L
s
.60145 .62445 m
.60145 .62445 L
s
.60145 .62445 m
.60145 .62445 L
s
.60145 .62445 m
.60145 .62445 L
s
.60141 .6243 m
.60145 .62445 L
s
.6846 .92286 m
.68482 .92267 L
s
.6846 .92286 m
.6846 .92284 L
s
.35053 .60091 m .34129 .59961 L .34078 .60428 L 0 1 .507 r
F
0 g
.33516 .60924 m
.34078 .60428 L
s
.35053 .60091 m .34575 .59393 L .34129 .59961 L 0 1 .507 r
F
.35053 .60091 m .35176 .59001 L .34575 .59393 L F
.35053 .60091 m .3553 .59047 L .35176 .59001 L F
.35053 .60091 m .35477 .59515 L .3553 .59047 L F
0 g
.35019 .6054 m
.35053 .60091 L
s
.34454 .60482 m
.35053 .60091 L
s
.43021 .91653 m .41821 .91911 L .41838 .91942 L 0 .73 .208 r
F
0 g
.41838 .91942 m
.41838 .91942 L
s
.38665 .92341 m .38314 .92531 L .3866 .92448 L 0 .886 .282 r
F
.38665 .92341 m .37782 .9253 L .38314 .92531 L F
0 g
.38314 .92531 m
.38368 .92634 L
s
.3866 .92448 m
.39212 .92409 L
s
.38563 .77032 m .37766 .77156 L .38214 .77095 L 0 .683 .218 r
F
0 g
.38214 .77095 m
.38575 .77077 L
s
.69514 .62199 m
.69519 .62211 L
s
.69499 .6216 m
.69514 .62199 L
s
.6947 .62085 m
.69499 .6216 L
s
.69068 .622 m
.69074 .62198 L
s
.69074 .62198 m
.69208 .6216 L
s
.69208 .6216 m
.6947 .62085 L
s
.68941 .62236 m
.68948 .62234 L
s
.68948 .62234 m
.69068 .622 L
s
.33165 .92931 m .31799 .92652 L .31819 .92871 L 0 1 .456 r
F
.33165 .92931 m .32188 .92599 L .31799 .92652 L F
.33165 .92931 m .32774 .92718 L .32188 .92599 L F
.341 .92759 m .32774 .92718 L .33165 .92931 L 0 1 .435 r
F
0 g
.33165 .92931 m
.33733 .93032 L
s
.33165 .92931 m
.33182 .93144 L
s
.56791 .44413 m .56381 .45038 L .56271 .44842 L 0 .096 .049 r
F
0 g
.56248 .44662 m
.56367 .44762 L
s
.56791 .44413 m .57101 .4498 L .56381 .45038 L 0 .096 .049 r
F
.56791 .44413 m .57949 .44706 L .57101 .4498 L F
.56791 .44413 m .58466 .44277 L .57949 .44706 L F
0 g
.56108 .44517 m
.56791 .44413 L
s
.56271 .44842 m
.56791 .44413 L
s
.51602 .96983 m .51633 .97117 L .51972 .97127 L 0 .651 .279 r
F
0 g
.51633 .97117 m
.52011 .97205 L
s
.27651 .72067 m .26754 .72532 L .2721 .7254 L 0 1 .529 r
F
0 g
.2721 .7254 m
.2753 .73033 L
s
.52298 .87483 m
.52304 .87524 L
s
.52287 .87389 m
.52298 .87483 L
s
.52258 .87159 m
.52287 .87389 L
s
.81568 .78868 m .81293 .78729 L .81758 .78932 L 0 0 0 r
F
.81 .77345 m .81568 .78868 L .82129 .78438 L 0 1 .458 r
F
.81568 .78868 m .81783 .79447 L .8193 .7902 L F
.81568 .78868 m .8193 .7902 L .81935 .79003 L F
.81568 .78868 m .81331 .79517 L .81783 .79447 L F
.8121 .78718 m .81211 .78719 L .81568 .78868 L 0 0 0 r
F
.81211 .78719 m .81293 .78729 L .81568 .78868 L F
.8121 .78718 m .81001 .78631 L .81331 .79517 L 0 1 .458 r
F
.81066 .78699 m .80996 .7863 L .81001 .78631 L 0 0 0 r
F
.8121 .78718 m .81001 .78631 L .81293 .78729 L F
.81066 .78699 m .81001 .78631 L .8121 .78718 L F
.81 .77345 m .80996 .78617 L .81001 .78631 L 0 1 .458 r
F
.81 .77345 m .81001 .78631 L .8121 .78718 L F
.81 .77345 m .8121 .78718 L .81568 .78868 L F
.8121 .78718 m .81331 .79517 L .81568 .78868 L F
.81066 .78699 m .8121 .78718 L .81568 .78868 L 0 0 0 r
F
.81066 .78699 m .81568 .78868 L .82161 .79093 L F
.81568 .78868 m .81758 .78932 L .81935 .79003 L F
.81568 .78868 m .81935 .79003 L .82161 .79093 L F
.81568 .78868 m .81935 .79003 L .82129 .78438 L 0 1 .458 r
F
0 g
.819 .79107 m
.81958 .79179 L
s
.80977 .78671 m
.81019 .78679 L
s
.52802 .91702 m .52751 .92447 L .52895 .93035 L 0 .23 .278 r
F
.47639 .53799 m .48653 .52003 L .48577 .51874 L 0 1 .245 r
F
.47639 .53799 m .48252 .52826 L .48653 .52003 L F
0 g
.48653 .52003 m
.49178 .5133 L
s
.48252 .52827 m
.48771 .52229 L
s
.48252 .52826 m
.48653 .52003 L
s
.32301 .9047 m .31844 .91203 L .32232 .91138 L 0 1 .465 r
F
.32301 .9047 m .31318 .9062 L .31844 .91203 L F
0 g
.31844 .91203 m
.3185 .91863 L
s
.35777 .71062 m .34919 .71366 L .3534 .71364 L 0 1 .533 r
F
0 g
.3534 .71364 m
.35583 .71681 L
s
.44515 .66836 m .43841 .66978 L .44191 .66936 L 0 1 .447 r
F
.44515 .66836 m .43646 .6694 L .43841 .66978 L F
.44515 .66836 m .43738 .66847 L .43646 .6694 L F
0 g
.44191 .66937 m
.44273 .67128 L
s
.44191 .66937 m
.44191 .66937 L
s
.44515 .66836 m .44062 .66746 L .43738 .66847 L 0 1 .447 r
F
.44515 .66836 m .44402 .66705 L .44062 .66746 L F
.44515 .66836 m .44596 .66743 L .44402 .66705 L F
0 g
.44515 .66836 m
.44716 .66871 L
s
.44191 .66936 m
.44515 .66836 L
s
.44596 .66743 m
.44911 .6664 L
s
.40769 .54746 m .4134 .5401 L .4158 .53573 L 0 1 .216 r
F
0 g
.4134 .5401 m
.41846 .53462 L
s
.23767 .65378 m .22933 .64278 L .22644 .6534 L 0 1 .487 r
F
.23767 .65378 m .23483 .63505 L .22933 .64278 L F
.23767 .65378 m .23926 .6354 L .23483 .63505 L F
.23767 .65378 m .24047 .64343 L .23926 .6354 L F
0 g
.23218 .66146 m
.23767 .65378 L
s
.23767 .65378 m
.23896 .66157 L
s
.28953 .91893 m .27558 .90919 L .27523 .91426 L 0 1 .532 r
F
.28953 .91893 m .27989 .90871 L .27558 .90919 L F
.28953 .91893 m .28588 .91289 L .27989 .90871 L F
.3 .91738 m .28588 .91289 L .28953 .91893 L 0 1 .531 r
F
0 g
.28917 .92398 m
.28953 .91893 L
s
.28953 .91893 m
.29536 .92293 L
s
.34112 .92311 m .32814 .91044 L .32804 .91691 L 0 1 .463 r
F
0 g
.32232 .91138 m
.32804 .91691 L
s
.72289 .62468 m
.72705 .62569 L
s
.40769 .54746 m .39838 .55577 L .40126 .55418 L 0 1 .216 r
F
.40769 .54746 m .40078 .55141 L .39838 .55577 L F
0 g
.39951 .55801 m
.40126 .55418 L
s
.40769 .54746 m .40685 .544 L .40078 .55141 L 0 1 .216 r
F
.40769 .54746 m .4133 .53728 L .40685 .544 L F
.40769 .54746 m .4158 .53573 L .4133 .53728 L F
0 g
.40126 .55418 m
.40769 .54746 L
s
.40555 .55191 m
.40769 .54746 L
s
.4158 .53573 m
.42229 .52883 L
s
.4134 .5401 m
.4158 .53573 L
s
.4739 .74534 m
.47412 .74519 L
s
.47041 .74784 m
.4739 .74534 L
s
.5222 .89223 m
.52292 .89464 L
s
.52292 .89464 m
.52404 .89845 L
s
.52415 .89882 m
.52491 .90139 L
s
.5222 .89223 m
.52365 .8897 L
s
.52365 .8897 m
.52379 .88946 L
s
.52802 .91702 m .52895 .93035 L .53013 .93219 L 0 .23 .278 r
F
0 g
.52862 .93278 m
.52895 .93035 L
s
.52751 .92447 m
.52895 .93035 L
s
.71267 .90548 m .72465 .90643 L .71942 .90523 L 0 .989 .43 r
F
.76055 .84278 m .76992 .83291 L .76549 .83423 L 0 1 .463 r
F
0 g
.75949 .83882 m
.76055 .84278 L
s
.75298 1.06506 m .75459 1.06558 L .76209 1.06306 L 0 .778 .23 r
F
0 g
.75218 1.06688 m
.75459 1.06558 L
s
.74641 1.0678 m
.75459 1.06558 L
s
.36889 .93276 m .35574 .92665 L .35603 .93045 L 0 1 .531 r
F
.44282 1.01306 m .4322 1.01017 L .43797 1.0158 L 0 .79 .456 r
F
.44282 1.01306 m .42951 1.00514 L .4322 1.01017 L F
0 g
.42621 1.00681 m
.4322 1.01017 L
s
.37915 .95588 m .37482 .94889 L .36898 .94426 L 0 1 .46 r
F
.38731 .95371 m .37915 .95588 L .38478 .96044 L 0 1 .454 r
F
.38731 .95371 m .37482 .94889 L .37915 .95588 L F
0 g
.37915 .95588 m
.38001 .96184 L
s
.50642 .4864 m .50051 .49265 L .50082 .49292 L 0 0 0 r
F
.50642 .4864 m .50598 .48639 L .50051 .49265 L F
.35049 .92139 m .34653 .92844 L .35021 .92771 L 0 1 .458 r
F
.35049 .92139 m .34112 .92311 L .34653 .92844 L F
0 g
.35044 .92782 m
.35047 .92783 L
s
.35043 .92368 m .34653 .92844 L .35021 .92771 L 0 1 .529 r
F
.35037 .92596 m .34653 .92844 L .35021 .92771 L 0 1 .407 r
F
.35043 .92368 m .34106 .92535 L .34653 .92844 L 0 1 .529 r
F
.35037 .92596 m .341 .92759 L .34653 .92844 L 0 1 .407 r
F
0 g
.34653 .92844 m
.34694 .93466 L
s
.35035 .92777 m
.35044 .92782 L
s
.35021 .92771 m
.35035 .92777 L
s
.35021 .92771 m
.35026 .92771 L
s
.35026 .92771 m
.35033 .92772 L
s
.35033 .92772 m
.3504 .92772 L
s
.34101 .92948 m
.34101 .92942 L
s
.34101 .92942 m
.34104 .9276 L
s
.34104 .92758 m
.34108 .92536 L
s
.34101 .92956 m
.34101 .92938 L
s
.34101 .92938 m
.34103 .9276 L
s
.22644 .6534 m .21519 .65302 L .21635 .66121 L 0 1 .489 r
F
0 g
.2117 .6693 m
.21635 .66121 L
s
.38563 .77032 m .37445 .77164 L .37766 .77156 L 0 .683 .218 r
F
0 g
.3746 .7725 m
.37766 .77156 L
s
.54457 1.08229 m .54411 1.07918 L .54642 1.07964 L 0 0 0 r
F
.54457 1.08229 m .54189 1.07945 L .54411 1.07918 L F
0 g
.54286 1.07811 m
.54411 1.07918 L
s
.3217 .61489 m .3089 .61236 L .30969 .61912 L 0 1 .488 r
F
0 g
.30334 .62498 m
.30969 .61912 L
s
.3217 .61489 m .31306 .60414 L .3089 .61236 L 0 1 .488 r
F
.3217 .61489 m .3199 .59909 L .31306 .60414 L F
.3217 .61489 m .32484 .60058 L .3199 .59909 L F
.3217 .61489 m .32561 .60736 L .32484 .60058 L F
0 g
.31488 .61992 m
.3217 .61489 L
s
.48408 .96176 m .48093 .96433 L .4852 .9646 L 0 1 .47 r
F
.48408 .96176 m .47636 .96296 L .48093 .96433 L F
0 g
.48093 .96433 m
.48352 .96623 L
s
.45373 .91011 m .45102 .91059 L .45383 .9098 L 0 0 0 r
F
.45373 .91011 m .44644 .91199 L .45102 .91059 L F
.4615 .90664 m .45383 .9098 L .45102 .91059 L F
0 g
.45102 .91059 m
.4516 .91016 L
s
.77522 .81194 m .78523 .82057 L .78643 .80901 L 0 1 .452 r
F
0 g
.78101 .83003 m
.78523 .82057 L
s
.78523 .82057 m
.78766 .82856 L
s
.44282 1.01306 m .43797 1.0158 L .44367 1.01919 L 0 .79 .456 r
F
0 g
.43797 1.0158 m
.44094 1.0209 L
s
.42957 .9988 m .42379 1.00148 L .42951 1.00514 L 0 .842 .456 r
F
.42957 .9988 m .41837 .99551 L .42379 1.00148 L F
0 g
.42379 1.00148 m
.42621 1.00681 L
s
.4686 .4777 m .46085 .48594 L .46211 .48409 L 0 0 0 r
F
0 g
.46243 .48284 m
.46398 .48114 L
s
.4686 .4777 m .46581 .48269 L .46085 .48594 L 0 0 0 r
F
.4686 .4777 m .47368 .47652 L .46581 .48269 L F
.4686 .4777 m .48017 .47013 L .47368 .47652 L F
.4686 .4777 m .48096 .46778 L .48017 .47013 L F
0 g
.47601 .47102 m
.48096 .46778 L
s
.46398 .48114 m
.4686 .4777 L
s
.48096 .46778 m
.48721 .46145 L
s
.31289 .91556 m .30641 .92113 L .31149 .92032 L 0 1 .53 r
F
.31289 .91556 m .3 .91738 L .30641 .92113 L F
0 g
.30584 .92589 m
.30641 .92113 L
s
.31149 .92032 m
.31432 .9217 L
s
.27651 .72067 m .26514 .7202 L .26754 .72532 L 0 1 .529 r
F
0 g
.2639 .73036 m
.26754 .72532 L
s
.21523 .92442 m .21053 .92907 L .21481 .92863 L 0 1 .528 r
F
.21523 .92442 m .20439 .92533 L .21053 .92907 L F
0 g
.21053 .92907 m
.21118 .93332 L
s
.21481 .92863 m
.22175 .932 L
s
.40455 .92201 m .39553 .92247 L .39191 .92326 L 0 .812 .252 r
F
.40455 .92201 m .40095 .92193 L .39553 .92247 L F
.41312 .91986 m .40095 .92193 L .40455 .92201 L 0 .762 .233 r
F
0 g
.40455 .92201 m
.40975 .92137 L
s
.40455 .92201 m
.40474 .92284 L
s
.41309 .92044 m
.41838 .91942 L
s
.43253 .95085 m
.4378 .95174 L
s
.39368 .70044 m .3831 .70095 L .38481 .70336 L 0 1 .519 r
F
0 g
.38053 .70627 m
.38481 .70336 L
s
.39368 .70044 m .3851 .69751 L .3831 .70095 L 0 1 .519 r
F
.39368 .70044 m .3897 .69482 L .3851 .69751 L F
.39368 .70044 m .39383 .69468 L .3897 .69482 L F
.39368 .70044 m .39553 .6971 L .39383 .69468 L F
0 g
.38909 .70312 m
.39368 .70044 L
s
.501 1.06312 m .50023 1.06486 L .50563 1.0671 L 0 .519 .362 r
F
0 g
.50023 1.06486 m
.50535 1.06816 L
s
.41054 .98632 m .40552 .98004 L .39959 .97608 L 0 .93 .462 r
F
.51991 .59993 m .51695 .60732 L .51679 .60488 L 0 0 .054 r
F
.51991 .59993 m .5207 .60676 L .51695 .60732 L F
.51991 .59993 m .52552 .60358 L .5207 .60676 L F
.51991 .59993 m .52864 .59863 L .52552 .60358 L F
.51991 .59993 m .52797 .59522 L .52864 .59863 L F
0 g
.51654 .6014 m
.51991 .59993 L
s
.52797 .59522 m
.53066 .58909 L
s
.52424 .59578 m
.52797 .59522 L
s
.44644 .91199 m .43826 .91454 L .43509 .91541 L 0 0 0 r
F
.44644 .91199 m .44312 .91307 L .43826 .91454 L F
.45373 .91011 m .44312 .91307 L .44644 .91199 L F
0 g
.44644 .91199 m
.45102 .91059 L
s
.47232 .63529 m .46583 .63205 L .46802 .63777 L 0 1 .315 r
F
.47232 .63529 m .46719 .62069 L .46583 .63205 L F
0 g
.47171 .64249 m
.47173 .64227 L
s
.47173 .64227 m
.47232 .63529 L
s
.4615 .90664 m .45832 .90811 L .45383 .9098 L 0 0 0 r
F
.46785 .90527 m .4615 .90664 L .46569 .90512 L F
.46785 .90527 m .45832 .90811 L .4615 .90664 L F
0 g
.4615 .90664 m
.46207 .90622 L
s
.50558 .45509 m .5136 .45066 L .51973 .44992 L 0 .018 .048 r
F
0 g
.5136 .45066 m
.5195 .44435 L
s
.42957 .9988 m .41622 .99026 L .41837 .99551 L 0 .842 .456 r
F
0 g
.41238 .99185 m
.41837 .99551 L
s
.27834 .63129 m .26797 .63769 L .27237 .63805 L 0 1 .481 r
F
0 g
.27237 .63805 m
.27378 .64543 L
s
.30181 .72153 m .28913 .71504 L .28787 .7211 L 0 1 .531 r
F
.30181 .72153 m .29424 .71083 L .28913 .71504 L F
0 g
.28787 .7211 m
.29112 .72567 L
s
.30181 .72153 m .29978 .7113 L .29424 .71083 L 0 1 .531 r
F
.30181 .72153 m .30302 .71589 L .29978 .7113 L F
0 g
.29672 .72571 m
.30181 .72153 L
s
.24844 .90685 m .24328 .91297 L .24758 .91245 L 0 1 .532 r
F
.24844 .90685 m .23758 .90798 L .24328 .91297 L F
0 g
.24328 .91297 m
.24339 .91858 L
s
.24758 .91245 m
.25399 .91711 L
s
.67997 .62953 m
.68013 .63528 L
s
.68014 .63562 m
.68038 .64452 L
s
.4846 1.05298 m .48841 1.05789 L .48901 1.05697 L 0 .649 .426 r
F
.501 1.06312 m .48901 1.05697 L .48841 1.05789 L 0 .519 .362 r
F
0 g
.48841 1.05789 m
.49321 1.06127 L
s
.48278 1.0554 m
.48841 1.05789 L
s
.39575 .93801 m .38298 .93321 L .38347 .93657 L 0 1 .531 r
F
0 g
.37779 .93442 m
.38347 .93657 L
s
.52312 .97188 m
.52348 .97194 L
s
.49042 .62442 m .48528 .62867 L .4866 .62778 L 0 0 0 r
F
0 g
.48632 .62845 m
.48857 .62661 L
s
.49042 .62442 m .48749 .62686 L .48528 .62867 L 0 0 0 r
F
.49042 .62442 m .49175 .62356 L .48749 .62686 L F
0 g
.48857 .62661 m
.49 .62492 L
s
.49042 .62442 m .49557 .6202 L .49175 .62356 L 0 0 0 r
F
.49042 .62442 m .4964 .61901 L .49557 .6202 L F
0 g
.4942 .62082 m
.4964 .61901 L
s
.4964 .61901 m
.49991 .6152 L
s
.73752 .86369 m
.73845 .86672 L
s
.45681 1.02653 m .44686 1.02396 L .45293 1.02921 L 0 .727 .451 r
F
.45681 1.02653 m .44367 1.01919 L .44686 1.02396 L F
0 g
.44094 1.0209 m
.44686 1.02396 L
s
.38731 .95371 m .38478 .96044 L .38796 .95954 L 0 1 .454 r
F
.39834 .97038 m .38796 .95954 L .38478 .96044 L 0 .966 .458 r
F
0 g
.38478 .96044 m
.38604 .96614 L
s
.37915 .95588 m
.38478 .96044 L
s
.25753 .94073 m .24218 .9387 L .24246 .94029 L 0 .821 .274 r
F
.25753 .94073 m .24649 .93839 L .24218 .9387 L F
.25753 .94073 m .25308 .93926 L .24649 .93839 L F
.26797 .93941 m .25308 .93926 L .25753 .94073 L 0 .761 .255 r
F
0 g
.25753 .94073 m
.25777 .94231 L
s
.25753 .94073 m
.26394 .94136 L
s
.21589 .91029 m .20176 .89739 L .20128 .90357 L 0 1 .534 r
F
.21589 .91029 m .2062 .89708 L .20176 .89739 L F
.21589 .91029 m .21226 .90262 L .2062 .89708 L F
.22673 .90913 m .21226 .90262 L .21589 .91029 L F
0 g
.21539 .91643 m
.21589 .91029 L
s
.21589 .91029 m
.22182 .91562 L
s
.29969 .92654 m .29512 .92987 L .29926 .92924 L 0 1 .489 r
F
.29969 .92654 m .28921 .9279 L .29512 .92987 L F
0 g
.29512 .92987 m
.29551 .93259 L
s
.29926 .92924 m
.30568 .93082 L
s
.37445 .77164 m .36648 .77283 L .37095 .77236 L 0 .726 .239 r
F
0 g
.37095 .77236 m
.3746 .7725 L
s
.44846 .95123 m .4472 .95493 L .44961 .95377 L 0 1 .524 r
F
.45877 .95631 m .44961 .95377 L .4472 .95493 L 0 1 .519 r
F
0 g
.4472 .95493 m
.44886 .95731 L
s
.44214 .95406 m
.4472 .95493 L
s
.45704 .75256 m .44859 .75598 L .45316 .75362 L 0 0 .008 r
F
0 g
.45316 .75362 m
.45631 .75119 L
s
.36889 .93276 m .35943 .92596 L .35574 .92665 L 0 1 .531 r
F
0 g
.35047 .92783 m
.35266 .92886 L
s
.35266 .92886 m
.35603 .93045 L
s
.36889 .93276 m .36507 .92858 L .35943 .92596 L 0 1 .531 r
F
.37771 .93081 m .36507 .92858 L .36889 .93276 L 0 1 .53 r
F
0 g
.36889 .93276 m
.37433 .93526 L
s
.36889 .93276 m
.36916 .93655 L
s
.48408 .96176 m .47411 .96113 L .47636 .96296 L 0 1 .47 r
F
0 g
.47176 .96285 m
.47636 .96296 L
s
.34112 .92311 m .33202 .90982 L .32814 .91044 L 0 1 .463 r
F
.34112 .92311 m .33759 .91526 L .33202 .90982 L F
.35049 .92139 m .33759 .91526 L .34112 .92311 L 0 1 .458 r
F
0 g
.34108 .92534 m
.34112 .92311 L
s
.34112 .92311 m
.34304 .92499 L
s
.54457 1.08229 m .54642 1.07964 L .54757 1.08086 L 0 0 0 r
F
0 g
.54642 1.07964 m
.54873 1.07888 L
s
.3703 .58664 m .36061 .59077 L .36416 .59071 L 0 1 .362 r
F
0 g
.3638 .59521 m
.36416 .59071 L
s
.46785 .90527 m .46569 .90512 L .46812 .90455 L 0 0 0 r
F
.47511 .90104 m .46812 .90455 L .46569 .90512 L F
0 g
.46569 .90512 m
.46641 .90424 L
s
.4615 .90664 m
.46569 .90512 L
s
.52698 .9154 m
.52699 .91528 L
s
.52691 .91648 m
.52698 .9154 L
s
.35777 .71062 m .34733 .71051 L .34919 .71366 L 0 1 .533 r
F
0 g
.34528 .71704 m
.34919 .71366 L
s
.80889 .80458 m .81783 .79447 L .81331 .79517 L 0 1 .471 r
F
0 g
.81783 .79447 m
.82013 .80294 L
s
.79766 .80658 m .80889 .80458 L .80653 .79632 L 0 1 .465 r
F
0 g
.80889 .80458 m
.81331 .79517 L
s
.3703 .58664 m .36162 .58763 L .36061 .59077 L 0 1 .362 r
F
.3703 .58664 m .36652 .58339 L .36162 .58763 L F
.3703 .58664 m .37268 .5793 L .36652 .58339 L F
.3703 .58664 m .37598 .57812 L .37268 .5793 L F
.3703 .58664 m .37496 .58126 L .37598 .57812 L F
0 g
.36947 .5904 m
.3703 .58664 L
s
.36416 .59071 m
.3703 .58664 L
s
.76401 .8155 m .76992 .83291 L .77409 .82337 L 0 1 .445 r
F
.76401 .8155 m .76549 .83423 L .76992 .83291 L F
0 g
.76992 .83291 m
.77153 .83965 L
s
.47132 .64333 m
.47171 .64249 L
s
.46963 .96068 m .46523 .95902 L .46042 .95869 L 0 1 .508 r
F
0 g
.3089 .61236 m
.30969 .61912 L
s
.46204 .60901 m .46847 .58943 L .46671 .58561 L 0 1 .332 r
F
.46204 .60901 m .46647 .59945 L .46847 .58943 L F
0 g
.46847 .58943 m
.47326 .58469 L
s
.46742 .59471 m
.46847 .58943 L
s
.73406 .90387 m .73601 .9089 L .74167 .90778 L 0 1 .416 r
F
.73406 .90387 m .73176 .908 L .73601 .9089 L F
0 g
.73601 .9089 m
.73602 .9114 L
s
.47742 .65382 m .47129 .64745 L .47346 .65465 L 0 1 .309 r
F
.4825 .67739 m .47742 .65382 L .47671 .66688 L 0 1 .304 r
F
0 g
.23811 .92726 m
.24292 .92942 L
s
.4902 .51063 m .5013 .49339 L .49573 .49971 L 0 .927 .158 r
F
0 g
.5013 .49339 m
.50642 .4864 L
s
.26514 .7202 m .25614 .72508 L .2607 .72518 L 0 1 .529 r
F
0 g
.2607 .72518 m
.2639 .73036 L
s
.53125 .82246 m
.53141 .82456 L
s
.53133 .82191 m
.53198 .82556 L
s
.53198 .82556 m
.53201 .82571 L
s
.53201 .82571 m
.53224 .82701 L
s
.53224 .82701 m
.53238 .82782 L
s
.42494 .68283 m .41607 .68574 L .42014 .68537 L 0 1 .483 r
F
.42494 .68283 m .41496 .68374 L .41607 .68574 L F
0 g
.42014 .68537 m
.42174 .68739 L
s
.42494 .68283 m .41754 .6807 L .41496 .68374 L 0 1 .483 r
F
.42494 .68283 m .42235 .67816 L .41754 .6807 L F
.42494 .68283 m .42617 .67781 L .42235 .67816 L F
.42494 .68283 m .42727 .67981 L .42617 .67781 L F
0 g
.42494 .68283 m
.42624 .68472 L
s
.42014 .68537 m
.42494 .68283 L
s
.58365 .59735 m .58486 .61412 L .5823 .60363 L 0 .699 .106 r
F
.58365 .59735 m .59037 .62611 L .58486 .61412 L F
.59442 .61786 m .59654 .62963 L .59371 .62929 L 0 .297 .144 r
F
.58365 .59735 m .59515 .63156 L .59037 .62611 L 0 .699 .106 r
F
.58365 .59735 m .59647 .62518 L .59515 .63156 L F
0 g
.58653 .63426 m
.5867 .62618 L
s
.58448 .63271 m
.58472 .63131 L
s
.58365 .59735 m .59347 .6113 L .59647 .62518 L 0 .699 .106 r
F
0 g
.5867 .62618 m
.58685 .61879 L
s
.58472 .63131 m
.58644 .62119 L
s
.58798 .59941 m
.59204 .6082 L
s
.59387 .60896 m
.59426 .60665 L
s
.59347 .6113 m
.59387 .60896 L
s
.59204 .6082 m
.59347 .6113 L
s
.45704 .75256 m .4457 .75845 L .44859 .75598 L 0 0 .008 r
F
.45704 .75256 m .44642 .75939 L .4457 .75845 L F
.45704 .75256 m .45031 .75833 L .44642 .75939 L F
.45704 .75256 m .45476 .75598 L .45031 .75833 L F
.45704 .75256 m .45765 .75351 L .45476 .75598 L F
0 g
.45704 .75256 m
.46001 .74952 L
s
.45316 .75362 m
.45704 .75256 L
s
.51444 .88207 m .51236 .87792 L .51475 .87544 L 0 0 .016 r
F
0 g
.51475 .87544 m
.51572 .87558 L
s
.51475 .87544 m
.51575 .87387 L
s
.44869 .66447 m .44062 .66746 L .44402 .66704 L 0 1 .409 r
F
.44869 .66447 m .44045 .66552 L .44062 .66746 L F
0 g
.44402 .66705 m
.44417 .66708 L
s
.44417 .66708 m
.44596 .66743 L
s
.44869 .66447 m .44362 .66252 L .44045 .66552 L 0 1 .409 r
F
.44869 .66447 m .4483 .65994 L .44362 .66252 L F
.44869 .66447 m .45135 .65951 L .4483 .65994 L F
.44869 .66447 m .45151 .66145 L .45135 .65951 L F
0 g
.44869 .66447 m
.44912 .6664 L
s
.44402 .66704 m
.44869 .66447 L
s
.45151 .66145 m
.45591 .65887 L
s
.37445 .77164 m .36327 .77259 L .36648 .77283 L 0 .726 .239 r
F
0 g
.36345 .77389 m
.36648 .77283 L
s
.53169 .93744 m
.53169 .93744 L
s
.41718 .98379 m .41054 .98632 L .41622 .99026 L 0 .887 .454 r
F
.41718 .98379 m .40552 .98004 L .41054 .98632 L F
0 g
.41054 .98632 m
.41238 .99185 L
s
.45681 1.02653 m .45293 1.02921 L .45856 1.03236 L 0 .727 .451 r
F
0 g
.45293 1.02921 m
.45642 1.03403 L
s
.4846 1.05298 m .47812 1.04858 L .47249 1.0461 L 0 .649 .426 r
F
.81014 .91297 m .82108 .91008 L .8167 .90973 L 0 1 .522 r
F
.79932 .9118 m .81014 .91297 L .81013 .90919 L 0 1 .517 r
F
.44846 .95123 m .43665 .9492 L .4378 .95174 L 0 1 .524 r
F
.49382 .89071 m .49107 .89287 L .48782 .89455 L 0 0 0 r
F
.49699 .89237 m .49382 .89071 L .49673 .88963 L F
.49699 .89237 m .49107 .89287 L .49382 .89071 L F
0 g
.49382 .89071 m
.49503 .88906 L
s
.48582 .74124 m .47851 .74956 L .48231 .74453 L 0 .108 .073 r
F
.48582 .74124 m .47656 .75411 L .47851 .74956 L F
.48582 .74124 m .47776 .75514 L .47656 .75411 L F
.48582 .74124 m .48129 .75182 L .47776 .75514 L F
.48582 .74124 m .48478 .74639 L .48129 .75182 L F
0 g
.48364 .74201 m
.48456 .74028 L
s
.48582 .74124 m .48672 .74186 L .48478 .74639 L 0 .108 .073 r
F
0 g
.48582 .74124 m
.48722 .73776 L
s
.48672 .74186 m
.49001 .73712 L
s
.52802 .91702 m .53013 .93219 L .53035 .929 L 0 .23 .278 r
F
0 g
.53013 .93219 m
.53169 .93743 L
s
.70994 .88604 m .71225 .89544 L .7172 .88811 L 0 1 .436 r
F
0 g
.71225 .89544 m
.71236 .89733 L
s
.8111 .65395 m .82481 .66236 L .82247 .65555 L 0 1 .512 r
F
0 g
.82311 .66676 m
.82481 .66236 L
s
.2889 .9369 m .28455 .93829 L .28868 .9377 L 0 .698 .232 r
F
.2889 .9369 m .27842 .93813 L .28455 .93829 L F
0 g
.28455 .93829 m
.2852 .93915 L
s
.28868 .9377 m
.29535 .93742 L
s
.52824 .97238 m
.53126 .97256 L
s
.31318 .9062 m .2984 .89262 L .29695 .89961 L 0 1 .47 r
F
.31318 .9062 m .30371 .89194 L .2984 .89262 L F
.31318 .9062 m .31005 .89777 L .30371 .89194 L F
0 g
.31172 .91317 m
.31318 .9062 L
s
.32301 .9047 m .31005 .89777 L .31318 .9062 L 0 1 .465 r
F
0 g
.31318 .9062 m
.31844 .91203 L
s
.35028 .92777 m
.35034 .92782 L
s
.35021 .92771 m
.35028 .92777 L
s
.36876 .93818 m .35574 .92665 L .35597 .93273 L 0 1 .456 r
F
0 g
.35034 .92782 m
.35597 .93273 L
s
.3504 .92772 m
.35052 .92773 L
s
.35052 .92773 m
.3558 .92814 L
s
.74884 .61639 m .76297 .60301 L .76338 .60989 L 0 .18 .062 r
F
0 g
.76297 .60301 m
.76835 .59962 L
s
.4692 .57524 m .46241 .57747 L .46411 .58049 L 0 1 .313 r
F
0 g
.4692 .57524 m
.4692 .57524 L
s
.4692 .57524 m .46528 .56789 L .46241 .57747 L 0 1 .313 r
F
.4692 .57524 m .47081 .55816 L .46528 .56789 L F
0 g
.62495 .61713 m
.62689 .6226 L
s
.62689 .6226 m
.62753 .6244 L
s
.62764 .6247 m
.6306 .63305 L
s
.62457 .62305 m
.62492 .61755 L
s
.62492 .61755 m
.62495 .61713 L
s
.52304 .87524 m
.52304 .87719 L
s
.43836 .9145 m .43509 .91541 L .43826 .91454 L 0 0 0 r
F
.43836 .9145 m .43021 .91653 L .43509 .91541 L F
0 g
.43509 .91541 m
.43549 .91537 L
s
.48756 .70715 m .48515 .67017 L .4825 .67739 L 0 1 .299 r
F
.48756 .70715 m .48843 .67443 L .48515 .67017 L F
0 g
.48515 .67017 m
.48585 .65712 L
s
.7276 .61288 m .74169 .6037 L .73821 .61486 L 0 .266 .093 r
F
0 g
.74097 .59363 m
.74169 .6037 L
s
.74169 .6037 m
.74757 .59684 L
s
.77118 1.06139 m .78354 1.05797 L .77983 1.05864 L 0 .926 .262 r
F
.76209 1.06306 m .77118 1.06139 L .77425 1.05975 L 0 .825 .246 r
F
.26514 .7202 m .25376 .71969 L .25614 .72508 L 0 1 .529 r
F
0 g
.2525 .73035 m
.25614 .72508 L
s
.77549 .77001 m .78661 .77475 L .78723 .77664 L 0 .03 0 r
F
0 g
.7832 .77156 m
.78661 .77475 L
s
.78661 .77475 m
.78964 .77533 L
s
.38731 .95371 m .37416 .94305 L .37482 .94889 L 0 1 .454 r
F
0 g
.36898 .94426 m
.37482 .94889 L
s
.39728 .7685 m .38583 .7701 L .38564 .77032 L 0 0 0 r
F
.39728 .7685 m .38946 .76951 L .38583 .7701 L F
0 g
.38564 .77032 m
.38899 .76989 L
s
.39728 .7685 m .39411 .76896 L .38946 .76951 L 0 0 0 r
F
.39728 .7685 m .39746 .76852 L .39411 .76896 L F
0 g
.39728 .7685 m
.40064 .76771 L
s
.75587 .90677 m .76311 .91132 L .76676 .9081 L 0 1 .471 r
F
0 g
.75721 .91311 m
.76311 .91132 L
s
.76311 .91132 m
.76356 .9143 L
s
.36327 .77259 m .35563 .77377 L .35991 .77343 L 0 .757 .254 r
F
0 g
.35991 .77343 m
.36345 .77389 L
s
.68378 .53281 m
.69163 .54839 L
s
.68228 .52579 m
.68378 .53281 L
s
.21519 .65302 m .20503 .66102 L .20956 .6611 L 0 1 .491 r
F
0 g
.20956 .6611 m
.2117 .6693 L
s
.69463 .62063 m
.69486 .62124 L
s
.68876 .60515 m
.69225 .61436 L
s
.69324 .61697 m
.69463 .62063 L
s
.69486 .62124 m
.69493 .62143 L
s
.69493 .62143 m
.69505 .62173 L
s
.69505 .62173 m
.69519 .62211 L
s
.68876 .60515 m
.68908 .61378 L
s
.68921 .61722 m
.6894 .62212 L
s
.6894 .62212 m
.68941 .62224 L
s
.68941 .62224 m
.68941 .62235 L
s
.52167 .87422 m .52119 .87284 L .52192 .86947 L 0 0 .015 r
F
0 g
.52116 .86914 m
.52192 .86947 L
s
.52192 .86947 m
.52217 .86876 L
s
.51921 .87694 m .52192 .86947 L .52119 .87284 L 0 0 .015 r
F
0 g
.52192 .86947 m
.52192 .86947 L
s
.49316 .69271 m .48843 .67443 L .49014 .68734 L 0 1 .292 r
F
.48756 .70715 m .49014 .68734 L .48843 .67443 L 0 1 .299 r
F
0 g
.48515 .67017 m
.48843 .67443 L
s
.48843 .67443 m
.48922 .65913 L
s
.41718 .98379 m .40392 .9746 L .40552 .98004 L 0 .887 .454 r
F
0 g
.39959 .97608 m
.40552 .98004 L
s
.40925 .69151 m .40014 .69436 L .40443 .69407 L 0 1 .505 r
F
0 g
.40443 .69407 m
.40637 .69628 L
s
.27834 .63129 m .26744 .63012 L .26797 .63769 L 0 1 .481 r
F
0 g
.2627 .64477 m
.26797 .63769 L
s
.58466 .44277 m
.59194 .4445 L
s
.57949 .44706 m
.58466 .44277 L
s
.52632 .91194 m
.52644 .91255 L
s
.52694 .91503 m
.52699 .91528 L
s
.5259 .89878 m .52491 .9014 L .52565 .90858 L 0 .246 .282 r
F
0 g
.52565 .90858 m
.52598 .91024 L
s
.36327 .77259 m .35257 .77322 L .35563 .77377 L 0 .757 .254 r
F
0 g
.35278 .77496 m
.35563 .77377 L
s
.50651 .7168 m .50844 .71393 L .50964 .69441 L 0 .904 .278 r
F
.47389 .95801 m .46963 .96068 L .47411 .96113 L 0 1 .494 r
F
.47389 .95801 m .46523 .95902 L .46963 .96068 L F
0 g
.46963 .96068 m
.47176 .96285 L
s
.43284 .76086 m .42434 .7628 L .42899 .76137 L 0 0 0 r
F
0 g
.42899 .76137 m
.43236 .75983 L
s
.73406 .90387 m .73092 .90585 L .73176 .908 L 0 1 .416 r
F
0 g
.73092 .90585 m
.73176 .908 L
s
.72555 .90886 m
.73176 .908 L
s
.58798 .45914 m .59579 .46463 L .60319 .47387 L 0 .436 .071 r
F
0 g
.59579 .46463 m
.60009 .4625 L
s
.60009 .4625 m
.60156 .46533 L
s
.42727 .67981 m
.43188 .67722 L
s
.54444 .58992 m .55372 .58836 L .55539 .59494 L 0 .246 .098 r
F
0 g
.55372 .58836 m
.55576 .58038 L
s
.54903 .58622 m
.55372 .58836 L
s
.52595 .8803 m
.5261 .88098 L
s
.58798 .45914 m .58493 .46518 L .58333 .45936 L 0 .436 .071 r
F
.58798 .45914 m .59234 .47446 L .58493 .46518 L F
.58798 .45914 m .60061 .48099 L .59234 .47446 L F
.58798 .45914 m .60526 .48073 L .60061 .48099 L F
0 g
.60156 .46533 m
.60271 .46754 L
s
.58798 .45914 m .60319 .47387 L .60526 .48073 L 0 .436 .071 r
F
0 g
.58092 .4498 m
.58798 .45914 L
s
.59579 .46463 m
.60135 .47158 L
s
.70895 1.07357 m .70179 1.07335 L .69881 1.07302 L 0 0 0 r
F
0 g
.69052 1.0728 m
.69881 1.07302 L
s
.40925 .69151 m .39869 .6922 L .40014 .69436 L 0 1 .505 r
F
.40925 .69151 m .40104 .68902 L .39869 .6922 L F
.40925 .69151 m .40588 .68644 L .40104 .68902 L F
.40925 .69151 m .40996 .6862 L .40588 .68644 L F
.40925 .69151 m .4114 .68837 L .40996 .6862 L F
0 g
.40925 .69151 m
.41086 .69352 L
s
.40443 .69407 m
.40925 .69151 L
s
.27875 .92932 m .26427 .92379 L .26416 .92695 L 0 1 .507 r
F
.27875 .92932 m .26859 .9234 L .26427 .92379 L F
.27875 .92932 m .2748 .92577 L .26859 .9234 L F
.28921 .9279 m .2748 .92577 L .27875 .92932 L 0 1 .499 r
F
0 g
.27861 .93246 m
.27875 .92932 L
s
.27875 .92932 m
.2848 .93148 L
s
.49457 .96495 m .49658 .96741 L .49724 .96652 L 0 .963 .429 r
F
.50525 .96761 m .49724 .96652 L .49658 .96741 L 0 .822 .365 r
F
0 g
.49658 .96741 m
.49964 .96869 L
s
.49256 .96726 m
.49658 .96741 L
s
.52379 .88946 m
.52454 .8942 L
s
.52491 .89652 m
.52494 .89669 L
s
.56721 .58954 m
.57231 .59634 L
s
.56519 .59757 m
.56721 .58954 L
s
.54444 .58992 m .54304 .60087 L .54187 .59619 L 0 .246 .098 r
F
.54444 .58992 m .54775 .60303 L .54304 .60087 L F
.54444 .58992 m .55284 .60124 L .54775 .60303 L F
.54444 .58992 m .55539 .59494 L .55284 .60124 L F
0 g
.54011 .58911 m
.54444 .58992 L
s
.37782 .9253 m .36498 .92496 L .36513 .92626 L 0 1 .332 r
F
.37782 .9253 m .36867 .92432 L .36498 .92496 L F
.37782 .9253 m .37418 .92447 L .36867 .92432 L F
.38665 .92341 m .37418 .92447 L .37782 .9253 L 0 .886 .282 r
F
0 g
.37782 .9253 m
.38314 .92531 L
s
.37782 .9253 m
.37795 .9266 L
s
.74101 .74954 m
.74228 .74876 L
s
.34106 .92535 m .32792 .91781 L .32789 .92204 L 0 1 .53 r
F
.34106 .92535 m .33181 .91726 L .32792 .91781 L F
.34106 .92535 m .33744 .92049 L .33181 .91726 L F
.35043 .92368 m .33744 .92049 L .34106 .92535 L 0 1 .529 r
F
0 g
.34103 .92759 m
.34106 .92535 L
s
.34106 .92535 m
.34408 .92706 L
s
.59194 .44451 m .60812 .44642 L .61077 .45058 L 0 .156 .035 r
F
0 g
.60812 .44642 m
.61193 .44491 L
s
.60006 .44382 m
.60812 .44642 L
s
.47139 1.03915 m .46222 1.03679 L .46853 1.04164 L 0 .645 .435 r
F
.47139 1.03915 m .45856 1.03236 L .46222 1.03679 L F
0 g
.45642 1.03403 m
.46222 1.03679 L
s
.46719 .62069 m .46647 .59945 L .46204 .60901 L 0 1 .322 r
F
0 g
.46647 .59945 m
.46742 .59471 L
s
.46647 .59945 m
.47111 .59587 L
s
.70369 .90265 m
.70372 .90265 L
s
.70283 .90267 m
.70369 .90265 L
s
.70251 .90099 m
.70258 .90136 L
s
.70258 .90136 m
.70283 .90267 L
s
.53232 .97261 m .53291 .97278 L .53438 .97289 L 0 .502 .203 r
F
.53232 .97261 m .53126 .97256 L .53291 .97278 L F
0 g
.53235 .97289 m
.53291 .97278 L
s
.50525 .96761 m .50812 .9696 L .50832 .96889 L 0 .822 .365 r
F
.51602 .96983 m .50832 .96889 L .50812 .9696 L 0 .651 .279 r
F
0 g
.50812 .9696 m
.51155 .97058 L
s
.5044 .96951 m
.50812 .9696 L
s
.35777 .71062 m .34906 .70629 L .34733 .71051 L 0 1 .533 r
F
.35777 .71062 m .35345 .70326 L .34906 .70629 L F
.35777 .71062 m .35755 .70345 L .35345 .70326 L F
.35777 .71062 m .35941 .70661 L .35755 .70345 L F
0 g
.35777 .71062 m
.3597 .71353 L
s
.3534 .71364 m
.35777 .71062 L
s
.5259 .89878 m .52502 .89719 L .52491 .9014 L 0 .246 .282 r
F
0 g
.52491 .9014 m
.52501 .89726 L
s
.52501 .89726 m
.52502 .89719 L
s
.52494 .89669 m
.52502 .89719 L
s
.48118 .63304 m .48484 .62965 L .4866 .62778 L 0 .886 .17 r
F
0 g
.48484 .62965 m
.48632 .62845 L
s
.42957 .9988 m .42951 1.00514 L .43172 1.00405 L 0 .842 .456 r
F
.44282 1.01306 m .43172 1.00405 L .42951 1.00514 L 0 .79 .456 r
F
0 g
.42951 1.00514 m
.4322 1.01017 L
s
.42379 1.00148 m
.42951 1.00514 L
s
.43021 .91653 m .4217 .91827 L .41821 .91911 L 0 .73 .208 r
F
.43021 .91653 m .42684 .91717 L .4217 .91827 L F
.43836 .9145 m .42684 .91717 L .43021 .91653 L 0 0 0 r
F
0 g
.43021 .91653 m
.43036 .91684 L
s
.43021 .91653 m
.43509 .91541 L
s
.76401 .8155 m .76296 .82678 L .76549 .83423 L 0 1 .445 r
F
0 g
.76055 .84278 m
.76549 .83423 L
s
.4923 .74183 m
.49307 .73853 L
s
.35257 .77322 m .34493 .77446 L .34921 .77421 L 0 .84 .287 r
F
0 g
.34921 .77421 m
.35278 .77496 L
s
.46719 .62069 m .46035 .61967 L .46255 .62429 L 0 1 .322 r
F
.46719 .62069 m .46204 .60901 L .46035 .61967 L F
.34733 .71051 m .33868 .71352 L .34288 .71361 L 0 1 .535 r
F
0 g
.34288 .71361 m
.34312 .71345 L
s
.34288 .71361 m
.34528 .71704 L
s
.25376 .71969 m .24472 .72482 L .24929 .72493 L 0 1 .528 r
F
0 g
.24929 .72493 m
.2525 .73035 L
s
.63055 .6779 m .63447 .64989 L .63057 .64335 L 0 .44 .248 r
F
0 g
.6303 .64259 m
.63057 .64335 L
s
.70994 .88604 m .7172 .88811 L .71992 .8803 L 0 1 .436 r
F
0 g
.71225 .89544 m
.7172 .88811 L
s
.41394 .94367 m .40447 .93902 L .40113 .93995 L 0 1 .531 r
F
.41394 .94367 m .40996 .94061 L .40447 .93902 L F
.42175 .94128 m .41394 .94367 L .41919 .94521 L 0 1 .529 r
F
.42175 .94128 m .40996 .94061 L .41394 .94367 L F
0 g
.41394 .94367 m
.41466 .94678 L
s
.70895 1.07357 m .70994 1.07236 L .71742 1.07199 L 0 0 0 r
F
0 g
.70198 1.0728 m
.70994 1.07236 L
s
.70673 1.07253 m
.70994 1.07236 L
s
.4902 .51063 m .48383 .51592 L .48461 .51698 L 0 .927 .158 r
F
.4902 .51063 m .48861 .50851 L .48383 .51592 L F
.4902 .51063 m .49573 .49971 L .48861 .50851 L F
.79975 .65206 m .80599 .64864 L .80147 .64801 L 0 1 .503 r
F
.79975 .65206 m .8111 .65395 L .80599 .64864 L F
0 g
.79975 .65206 m
.80108 .64893 L
s
.80108 .64893 m
.80147 .64801 L
s
.79771 .65001 m
.79975 .65206 L
s
.6524 .65116 m
.6524 .65116 L
s
.65589 .6485 m
.65701 .64766 L
s
.65701 .64766 m
.65712 .64757 L
s
.65712 .64757 m
.65736 .64738 L
s
.40432 .93583 m .40113 .93995 L .40447 .93902 L 0 1 .529 r
F
.40432 .93583 m .39576 .93801 L .40113 .93995 L F
0 g
.40113 .93995 m
.40186 .94306 L
s
.65737 .64739 m
.65737 .64739 L
s
.82138 .77158 m .82441 .7921 L .82914 .79294 L 0 1 .465 r
F
.82441 .7921 m .82455 .79218 L .82718 .79319 L 0 .349 .191 r
F
.82441 .7921 m .82462 .79351 L .82718 .79319 L 0 1 .465 r
F
.82441 .7921 m .82718 .79319 L .82914 .79294 L F
.82138 .77158 m .82129 .78438 L .82405 .79197 L F
.82441 .7921 m .82405 .79197 L .82455 .79218 L 0 .349 .191 r
F
.82441 .7921 m .82405 .79197 L .82462 .79351 L 0 1 .465 r
F
.82138 .77158 m .82405 .79197 L .82441 .7921 L F
.82235 .79104 m .82161 .79093 L .82405 .79197 L 0 .349 .191 r
F
.82235 .79104 m .82405 .79197 L .82441 .7921 L F
.82235 .79104 m .82441 .7921 L .82919 .79396 L F
.82441 .7921 m .82718 .79319 L .82919 .79396 L F
0 g
.82013 .80294 m
.82462 .79351 L
s
.82943 .79407 m
.8295 .79433 L
s
.81958 .79179 m
.82412 .79214 L
s
.65339 .68696 m
.654 .68083 L
s
.65506 .67033 m
.65506 .67033 L
s
.65669 .65408 m
.65726 .64846 L
s
.65726 .64846 m
.6573 .648 L
s
.6573 .648 m
.65736 .6474 L
s
.28787 .7211 m .27782 .71426 L .27651 .72067 L 0 1 .53 r
F
.28787 .7211 m .28219 .70975 L .27782 .71426 L F
.28787 .7211 m .2867 .71017 L .28219 .70975 L F
.28787 .7211 m .28913 .71504 L .2867 .71017 L F
0 g
.2835 .72559 m
.28787 .7211 L
s
.47511 .90104 m .47215 .9028 L .46812 .90455 L 0 0 0 r
F
.48046 .90066 m .47511 .90104 L .47883 .89961 L F
.48046 .90066 m .47215 .9028 L .47511 .90104 L F
0 g
.47511 .90104 m
.47581 .90017 L
s
.35257 .77322 m .34187 .7736 L .34493 .77446 L 0 .84 .287 r
F
0 g
.34211 .77581 m
.34493 .77446 L
s
.31819 .92871 m
.31819 .92871 L
s
.53232 .97261 m .53438 .97289 L .53484 .97291 L 0 .502 .203 r
F
0 g
.53438 .97289 m
.53614 .97309 L
s
.44795 .75617 m
.44859 .75598 L
s
.44483 .75712 m
.44795 .75617 L
s
.51444 .88207 m .51072 .88151 L .51236 .87792 L 0 0 .016 r
F
0 g
.51041 .87881 m
.51236 .87792 L
s
.42175 .94128 m .41919 .94521 L .42222 .9442 L 0 1 .529 r
F
.43153 .94804 m .42222 .9442 L .41919 .94521 L 0 1 .53 r
F
0 g
.41919 .94521 m
.4202 .94802 L
s
.41394 .94367 m
.41919 .94521 L
s
.631 .45751 m
.63923 .46607 L
s
.63094 .45754 m
.631 .45751 L
s
.62723 .45906 m
.63094 .45754 L
s
.72586 1.07068 m .73778 1.06902 L .73432 1.06958 L 0 .685 .221 r
F
.71742 1.07199 m .72586 1.07068 L .72912 1.07051 L 0 .607 .198 r
F
0 g
.53912 .74038 m
.53914 .73878 L
s
.53912 .74044 m
.53912 .74038 L
s
.53912 .74053 m
.53912 .74044 L
s
.53471 .72977 m .53644 .73856 L .53945 .708 L 0 .78 .249 r
F
0 g
.53921 .71037 m
.53945 .708 L
s
.53644 .73856 m
.53921 .71037 L
s
.53914 .73878 m
.53914 .73849 L
s
.53914 .73849 m
.53945 .708 L
s
.53471 .72977 m
.53484 .68931 L
s
.53207 .71935 m
.53484 .68931 L
s
.44282 1.01306 m .44367 1.01919 L .4455 1.01809 L 0 .79 .456 r
F
.45681 1.02653 m .4455 1.01809 L .44367 1.01919 L 0 .727 .451 r
F
0 g
.44367 1.01919 m
.44686 1.02396 L
s
.43797 1.0158 m
.44367 1.01919 L
s
.48408 .96176 m .4852 .9646 L .48633 .96359 L 0 1 .47 r
F
.49457 .96495 m .48633 .96359 L .4852 .9646 L 0 .963 .429 r
F
0 g
.4852 .9646 m
.48788 .96617 L
s
.48093 .96433 m
.4852 .9646 L
s
.22644 .6534 m .21817 .64214 L .21519 .65302 L 0 1 .489 r
F
.22644 .6534 m .22374 .63421 L .21817 .64214 L F
.22644 .6534 m .22818 .63455 L .22374 .63421 L F
.22644 .6534 m .22933 .64278 L .22818 .63455 L F
0 g
.22088 .66128 m
.22644 .6534 L
s
.22644 .6534 m
.22766 .66139 L
s
.21519 .65302 m .20392 .65264 L .20503 .66102 L 0 1 .491 r
F
0 g
.20035 .6693 m
.20503 .66102 L
s
.53546 1.07907 m .52842 1.07661 L .52332 1.07493 L 0 .394 .202 r
F
.27834 .63129 m .27115 .62036 L .26744 .63012 L 0 1 .481 r
F
.27834 .63129 m .27713 .61357 L .27115 .62036 L F
.27834 .63129 m .28139 .6143 L .27713 .61357 L F
.27834 .63129 m .2819 .6219 L .28139 .6143 L F
0 g
.27834 .63129 m
.27898 .63859 L
s
.27237 .63805 m
.27834 .63129 L
s
.60788 .64373 m
.60813 .64595 L
s
.60813 .64595 m
.60824 .64699 L
s
.60824 .64699 m
.60832 .64768 L
s
.60832 .64768 m
.60856 .64985 L
s
.61104 .67243 m
.61104 .67243 L
s
.61111 .67309 m
.61112 .67321 L
s
.60856 .64985 m
.60901 .65402 L
s
.60901 .65402 m
.60941 .65763 L
s
.60941 .65763 m
.60944 .65785 L
s
.61001 .66311 m
.61014 .66425 L
s
.61383 .69781 m
.61383 .69781 L
s
.61291 .68946 m
.61383 .69781 L
s
.61159 .67747 m
.61291 .68946 L
s
.61112 .67321 m
.61144 .67608 L
s
.60796 .64734 m
.60796 .64765 L
s
.60796 .64765 m
.60802 .65025 L
s
.60802 .65025 m
.60805 .65167 L
s
.60805 .65167 m
.60805 .65167 L
s
.60788 .64373 m
.60793 .64601 L
s
.60793 .64601 m
.60795 .64701 L
s
.60795 .64701 m
.60796 .64734 L
s
.51756 1.0721 m .51078 1.06971 L .51784 1.0726 L 0 .427 .237 r
F
.51756 1.0721 m .50563 1.0671 L .51078 1.06971 L F
0 g
.50535 1.06816 m
.51078 1.06971 L
s
.79766 .80658 m .80653 .79632 L .80201 .79716 L 0 1 .465 r
F
0 g
.80653 .79632 m
.80889 .80458 L
s
.78643 .80901 m .79766 .80658 L .79524 .79855 L 0 1 .459 r
F
0 g
.79766 .80658 m
.80201 .79716 L
s
.52419 .87921 m
.525 .88434 L
s
.41718 .98379 m .41622 .99026 L .41878 .98922 L 0 .887 .454 r
F
.42957 .9988 m .41878 .98922 L .41622 .99026 L 0 .842 .456 r
F
0 g
.41622 .99026 m
.41837 .99551 L
s
.41054 .98632 m
.41622 .99026 L
s
.70286 .90362 m
.70372 .90265 L
s
.70372 .90265 m
.7042 .90212 L
s
.7042 .90212 m
.70514 .90105 L
s
.7026 .90149 m
.70286 .90362 L
s
.70258 .90136 m
.7026 .90149 L
s
.70256 .9012 m
.70258 .90136 L
s
.70256 .90114 m
.70256 .9012 L
s
.70254 .90099 m
.70256 .90114 L
s
.82138 .77158 m .82914 .79294 L .83263 .78287 L 0 1 .465 r
F
0 g
.82914 .79294 m
.82943 .79407 L
s
.39575 .93801 m .38644 .93243 L .38298 .93321 L 0 1 .531 r
F
.39575 .93801 m .39192 .93449 L .38644 .93243 L F
0 g
.39575 .93801 m
.39623 .94136 L
s
.40432 .93583 m .39192 .93449 L .39576 .93801 L 0 1 .529 r
F
0 g
.39576 .93801 m
.40113 .93995 L
s
.25376 .71969 m .24238 .71918 L .24472 .72482 L 0 1 .528 r
F
0 g
.24109 .73032 m
.24472 .72482 L
s
.34187 .7736 m .33423 .77495 L .33851 .77477 L 0 .961 .337 r
F
0 g
.33851 .77477 m
.34211 .77581 L
s
.47389 .95801 m .46342 .95697 L .46523 .95902 L 0 1 .494 r
F
0 g
.46042 .95869 m
.46523 .95902 L
s
.39834 .97038 m .39378 .9638 L .38796 .95954 L 0 .966 .458 r
F
.22608 .92353 m .22125 .92796 L .22554 .92752 L 0 1 .525 r
F
.22608 .92353 m .21523 .92442 L .22125 .92796 L F
0 g
.22125 .92796 m
.22175 .932 L
s
.22554 .92752 m
.22726 .92833 L
s
.40579 .96807 m .39834 .97038 L .40392 .9746 L 0 .928 .45 r
F
.40579 .96807 m .39378 .9638 L .39834 .97038 L F
0 g
.39834 .97038 m
.39959 .97608 L
s
.37496 .58126 m
.38092 .57643 L
s
.22673 .90913 m .21287 .89662 L .21226 .90262 L 0 1 .534 r
F
.22673 .90913 m .21731 .89632 L .21287 .89662 L F
.22673 .90913 m .22326 .90169 L .21731 .89632 L F
.23758 .90798 m .22326 .90169 L .22673 .90913 L 0 1 .533 r
F
0 g
.22611 .91509 m
.22673 .90913 L
s
.22673 .90913 m
.23254 .91429 L
s
.4971 .73404 m .49546 .68693 L .49316 .69271 L 0 .921 .289 r
F
.4971 .73404 m .49812 .69601 L .49546 .68693 L F
0 g
.49546 .68693 m
.49624 .6716 L
s
.56797 .45125 m .57606 .45341 L .58333 .45936 L 0 .323 .076 r
F
0 g
.57606 .45341 m
.58092 .4498 L
s
.52802 .91702 m .53035 .929 L .52947 .9229 L 0 .23 .278 r
F
0 g
.53013 .93219 m
.53035 .929 L
s
.53459 .92841 m .53036 .929 L .53386 .93814 L 0 .193 .256 r
F
0 g
.53169 .93744 m
.53386 .93814 L
s
.53459 .92841 m .52947 .92291 L .53036 .929 L 0 .193 .256 r
F
0 g
.53036 .929 m
.53386 .93814 L
s
.76401 .8155 m .77409 .82337 L .77522 .81194 L 0 1 .445 r
F
0 g
.76992 .83291 m
.77409 .82337 L
s
.77409 .82337 m
.77657 .83111 L
s
.33284 .90328 m .32814 .91044 L .33202 .90982 L 0 1 .459 r
F
.33284 .90328 m .32301 .9047 L .32814 .91044 L F
0 g
.32804 .91691 m
.32814 .91044 L
s
.48118 .63304 m .4753 .63678 L .47709 .6361 L 0 .886 .17 r
F
0 g
.47736 .63689 m
.47976 .63517 L
s
.48118 .63304 m .47706 .63491 L .4753 .63678 L 0 .886 .17 r
F
.48118 .63304 m .48119 .63173 L .47706 .63491 L F
.48118 .63304 m .48528 .62867 L .48119 .63173 L F
.48118 .63304 m .4866 .62778 L .48528 .62867 L F
0 g
.48484 .62965 m
.4866 .62778 L
s
.47976 .63517 m
.48118 .63304 L
s
.4866 .62778 m
.48879 .62585 L
s
.34187 .7736 m .33117 .77379 L .33423 .77495 L 0 .961 .337 r
F
0 g
.33144 .77648 m
.33423 .77495 L
s
.3 .91738 m .28637 .908 L .28588 .91289 L 0 1 .531 r
F
.3 .91738 m .29069 .90754 L .28637 .908 L F
.3 .91738 m .29654 .91156 L .29069 .90754 L F
0 g
.29949 .92225 m
.3 .91738 L
s
.31289 .91556 m .29654 .91156 L .3 .91738 L 0 1 .53 r
F
0 g
.3 .91738 m
.30641 .92113 L
s
.35477 .59515 m
.36061 .59077 L
s
.45594 .65689 m .4483 .65994 L .45135 .65951 L 0 1 .352 r
F
.45594 .65689 m .44861 .658 L .4483 .65994 L F
0 g
.45135 .65951 m
.45151 .66145 L
s
.45594 .65689 m .45209 .65498 L .44861 .658 L 0 1 .352 r
F
.45594 .65689 m .4567 .65236 L .45209 .65498 L F
.45594 .65689 m .45936 .65188 L .4567 .65236 L F
.45594 .65689 m .45903 .65382 L .45936 .65188 L F
0 g
.45903 .65382 m
.46333 .65121 L
s
.45591 .65887 m
.45594 .65689 L
s
.45135 .65951 m
.45594 .65689 L
s
.47139 1.03915 m .46853 1.04164 L .47403 1.04456 L 0 .645 .435 r
F
0 g
.46853 1.04164 m
.47249 1.0461 L
s
.25932 .90575 m .25403 .91168 L .25834 .91117 L 0 1 .532 r
F
.25932 .90575 m .24844 .90685 L .25403 .91168 L F
0 g
.25399 .91711 m
.25403 .91168 L
s
.25834 .91117 m
.2646 .91567 L
s
.53546 1.07907 m .54188 1.07945 L .54123 1.08028 L 0 .394 .202 r
F
0 g
.53678 1.07777 m
.54188 1.07945 L
s
.54457 1.08229 m .54123 1.08028 L .54189 1.07945 L 0 0 0 r
F
0 g
.54189 1.07945 m
.54411 1.07918 L
s
.46528 .56789 m .474 .54921 L .47273 .54698 L 0 1 .322 r
F
.46528 .56789 m .47081 .55816 L .474 .54921 L F
0 g
.474 .54921 m
.4792 .54319 L
s
.47081 .55816 m
.47588 .55295 L
s
.47081 .55816 m
.474 .54921 L
s
.68038 .64452 m
.68261 .63511 L
s
.68421 .62838 m
.68477 .62602 L
s
.68477 .62602 m
.68535 .62359 L
s
.68535 .62359 m
.68539 .6234 L
s
.46204 .60901 m .46671 .58561 L .46173 .5899 L 0 1 .332 r
F
0 g
.46671 .58561 m
.4692 .57524 L
s
.80174 .61033 m .81619 .61111 L .81289 .61276 L 0 0 0 r
F
0 g
.81523 .60865 m
.81619 .61111 L
s
.50558 .45509 m .49898 .46305 L .49931 .4604 L 0 .018 .048 r
F
0 g
.4984 .45754 m
.49979 .45612 L
s
.50558 .45509 m .50512 .46232 L .49898 .46305 L 0 .018 .048 r
F
.50558 .45509 m .51363 .45869 L .50512 .46232 L F
.50558 .45509 m .51988 .45337 L .51363 .45869 L F
.50558 .45509 m .51973 .44992 L .51988 .45337 L F
0 g
.49979 .45612 m
.50558 .45509 L
s
.51973 .44992 m
.5256 .44495 L
s
.5136 .45066 m
.51973 .44992 L
s
.34733 .71051 m .33689 .71012 L .33868 .71352 L 0 1 .535 r
F
0 g
.33472 .71703 m
.33868 .71352 L
s
.33117 .77379 m .32353 .77527 L .32781 .77516 L 0 1 .382 r
F
0 g
.32781 .77516 m
.33144 .77648 L
s
.51602 .96983 m .51972 .97127 L .51946 .97081 L 0 .651 .279 r
F
0 g
.51972 .97127 m
.52307 .97187 L
s
.51633 .97117 m
.51972 .97127 L
s
.54554 .80587 m
.54595 .80866 L
s
.38563 .77032 m .37465 .77114 L .37445 .77164 L 0 .683 .218 r
F
.38563 .77032 m .37815 .77052 L .37465 .77114 L F
.38563 .77032 m .38262 .77018 L .37815 .77052 L F
.38563 .77032 m .38582 .7701 L .38262 .77018 L F
0 g
.38214 .77095 m
.38563 .77032 L
s
.74385 1.06741 m .73778 1.06902 L .74576 1.06708 L 0 .71 .208 r
F
.74385 1.06741 m .73432 1.06958 L .73778 1.06902 L F
0 g
.74296 1.06826 m
.74348 1.06803 L
s
.73427 1.06964 m
.73778 1.06902 L
s
.78881 1.05248 m .78354 1.05797 L .79154 1.05428 L 0 1 .276 r
F
.78881 1.05248 m .77983 1.05864 L .78354 1.05797 L F
0 g
.78025 1.06003 m
.78354 1.05797 L
s
.34129 .59961 m .33137 .60236 L .33513 .60322 L 0 1 .517 r
F
0 g
.33513 .60322 m
.33516 .60924 L
s
.3831 .70095 m .37411 .70368 L .37839 .7036 L 0 1 .525 r
F
0 g
.37839 .7036 m
.38053 .70627 L
s
.35049 .92139 m .33785 .90893 L .33759 .91526 L 0 1 .458 r
F
0 g
.33202 .90982 m
.33759 .91526 L
s
.52286 .70425 m
.52348 .72874 L
s
.49699 .89237 m .49673 .88963 L .49786 .89035 L 0 0 0 r
F
.50284 .88715 m .49786 .89035 L .49673 .88963 L F
0 g
.49673 .88963 m
.498 .8873 L
s
.49382 .89071 m
.49673 .88963 L
s
.39553 .6971 m
.40014 .69436 L
s
.59194 .44451 m .58944 .45037 L .58737 .44731 L 0 .156 .035 r
F
.59194 .44451 m .59753 .45299 L .58944 .45037 L F
.59194 .44451 m .60624 .4534 L .59753 .45299 L F
.59194 .44451 m .61077 .45058 L .60624 .4534 L F
.43284 .76086 m .42127 .76432 L .42434 .7628 L 0 0 0 r
F
0 g
.42073 .76352 m
.42434 .7628 L
s
.49699 .89237 m .49019 .89489 L .49107 .89287 L 0 0 0 r
F
0 g
.48782 .89455 m
.49107 .89287 L
s
.82235 .79104 m .82919 .79396 L .83325 .79496 L 0 .349 .191 r
F
0 g
.82417 .7923 m
.82462 .79351 L
s
.82405 .79197 m
.82417 .7923 L
s
.82919 .79396 m
.82952 .7944 L
s
.33117 .77379 m .32047 .77382 L .32353 .77527 L 0 1 .382 r
F
0 g
.32078 .77701 m
.32353 .77527 L
s
.60725 .47622 m .60526 .48073 L .60319 .47387 L 0 .474 .045 r
F
0 g
.60319 .47387 m
.60356 .47409 L
s
.60135 .47158 m
.60319 .47387 L
s
.60725 .47622 m .61275 .49401 L .60526 .48073 L 0 .474 .045 r
F
.60725 .47622 m .62068 .50484 L .61275 .49401 L F
0 g
.61844 .4865 m
.62055 .49203 L
s
.60725 .47622 m .62474 .50716 L .62068 .50484 L 0 .474 .045 r
F
.60725 .47622 m .62222 .49944 L .62474 .50716 L F
.60725 .47622 m .61473 .4862 L .62222 .49944 L F
0 g
.61473 .4862 m
.61844 .4865 L
s
.60271 .46754 m
.60725 .47622 L
s
.60356 .47409 m
.60725 .47622 L
s
.46995 .67392 m .47129 .64745 L .46714 .64848 L 0 1 .318 r
F
.46995 .67392 m .47346 .65465 L .47129 .64745 L F
0 g
.47129 .64745 m
.47171 .64249 L
s
.45044 .4952 m .45765 .48806 L .46211 .48409 L 0 0 0 r
F
0 g
.45765 .48806 m
.46243 .48284 L
s
.341 .92759 m .32771 .92521 L .32774 .92718 L 0 1 .435 r
F
.341 .92759 m .3316 .9247 L .32771 .92521 L F
.341 .92759 m .3373 .92573 L .3316 .9247 L F
.35037 .92596 m .3373 .92573 L .341 .92759 L 0 1 .407 r
F
0 g
.341 .92759 m
.34653 .92844 L
s
.341 .92759 m
.34101 .92956 L
s
.79932 .9118 m .81013 .90919 L .80575 .90882 L 0 1 .517 r
F
.78848 .91061 m .79932 .9118 L .79917 .90827 L 0 1 .51 r
F
.46785 .90527 m .45805 .90883 L .45832 .90811 L 0 0 0 r
F
0 g
.45383 .9098 m
.45832 .90811 L
s
.47639 .53799 m .48577 .51874 L .48026 .52467 L 0 1 .245 r
F
0 g
.48577 .51874 m
.4902 .51063 L
s
.5206 .70824 m
.52096 .70391 L
s
.72063 .90185 m .72465 .90643 L .73092 .90585 L 0 .872 .36 r
F
.72063 .90185 m .71942 .90523 L .72465 .90643 L F
0 g
.72465 .90643 m
.72555 .90886 L
s
.48046 .90066 m .47883 .89961 L .48084 .89946 L 0 0 0 r
F
.48701 .89595 m .48084 .89946 L .47883 .89961 L F
0 g
.47883 .89961 m
.47965 .89821 L
s
.47511 .90104 m
.47883 .89961 L
s
.24238 .71918 m .2333 .72455 L .23787 .72466 L 0 1 .528 r
F
0 g
.23787 .72466 m
.23813 .72435 L
s
.23787 .72466 m
.24109 .73032 L
s
.3089 .61236 m .29837 .61724 L .30261 .61797 L 0 1 .483 r
F
0 g
.30261 .61797 m
.30334 .62498 L
s
.46995 .67392 m .47289 .66599 L .47346 .65465 L 0 1 .318 r
F
0 g
.47346 .65465 m
.47742 .65382 L
s
.32047 .77382 m .31284 .77547 L .31711 .77541 L 0 1 .42 r
F
0 g
.31711 .77541 m
.32078 .77701 L
s
.46105 .752 m
.46144 .75183 L
s
.45765 .75351 m
.46105 .752 L
s
.32047 .77382 m .30978 .77371 L .31284 .77547 L 0 1 .42 r
F
0 g
.31012 .77742 m
.31284 .77547 L
s
.43284 .76086 m .42183 .76492 L .42127 .76432 L 0 0 0 r
F
.43284 .76086 m .42569 .7644 L .42183 .76492 L F
.43284 .76086 m .43027 .76311 L .42569 .7644 L F
.43284 .76086 m .43334 .76159 L .43027 .76311 L F
0 g
.43284 .76086 m
.43596 .75891 L
s
.42899 .76137 m
.43284 .76086 L
s
.52802 .91702 m
.52843 .91868 L
s
.52843 .91868 m
.52947 .9229 L
s
.52802 .91702 m
.52806 .91573 L
s
.50877 .8815 m .50639 .88381 L .5041 .88482 L 0 0 0 r
F
.26744 .63012 m .25694 .6368 L .26135 .63716 L 0 1 .482 r
F
0 g
.26135 .63716 m
.2627 .64477 L
s
.54075 .97389 m .53484 .97291 L .53902 .97321 L 0 0 0 r
F
.47228 .64125 m .47579 .63801 L .47709 .6361 L 0 1 .208 r
F
0 g
.47579 .63801 m
.47736 .63689 L
s
.40579 .96807 m .39275 .95822 L .39378 .9638 L 0 .928 .45 r
F
0 g
.38796 .95954 m
.39378 .9638 L
s
.69343 .58668 m .69829 .57559 L .69342 .57326 L 0 .628 .339 r
F
0 g
.69342 .57326 m
.69343 .58668 L
s
.69196 .57036 m
.69342 .57326 L
s
.69343 .58668 m .70577 .59091 L .69829 .57559 L 0 .628 .339 r
F
.69343 .58668 m .71088 .60902 L .70577 .59091 L F
0 g
.69343 .58668 m
.69343 .58668 L
s
.43153 .94804 m .42751 .94542 L .42222 .9442 L 0 1 .53 r
F
0 g
.43153 .94804 m
.43253 .95085 L
s
.43881 .94547 m .43154 .94804 L .43665 .9492 L 0 1 .526 r
F
.43881 .94547 m .42751 .94542 L .43154 .94804 L F
.45373 .91011 m .44301 .91339 L .44312 .91307 L 0 0 0 r
F
0 g
.43826 .91454 m
.44312 .91307 L
s
.249 .92623 m
.25353 .92817 L
s
.52348 .72874 m
.52568 .70627 L
s
.30978 .77371 m .30214 .77557 L .30642 .77554 L 0 1 .45 r
F
0 g
.30642 .77554 m
.31012 .77742 L
s
.46457 .64744 m .46802 .63777 L .46583 .63205 L 0 1 .326 r
F
.46384 .64917 m .46613 .64636 L .46457 .64744 L 0 1 .272 r
F
.46609 .64653 m .46613 .64636 L .46457 .64744 L 0 1 .326 r
F
.46613 .64636 m .46802 .63777 L .46457 .64744 L F
.46377 .65705 m .46714 .64848 L .46738 .6455 L F
.46613 .64636 m .46738 .6455 L .46802 .63777 L F
.46384 .64917 m .46716 .64604 L .46738 .6455 L 0 1 .272 r
F
.46384 .64917 m .46738 .6455 L .46613 .64636 L F
.46377 .65705 m .46738 .6455 L .46613 .64636 L 0 1 .326 r
F
.46613 .64636 m .46738 .6455 L .46797 .6441 L 0 1 .272 r
F
.46457 .64744 m .46797 .6441 L .46574 .64465 L F
.46613 .64636 m .46797 .6441 L .46457 .64744 L F
.46286 .64849 m .46583 .63205 L .46136 .63448 L 0 1 .326 r
F
.46384 .64917 m .46457 .64744 L .46286 .64849 L 0 1 .272 r
F
.46384 .64917 m .4567 .65236 L .45936 .65188 L F
.46384 .64917 m .46048 .64983 L .4567 .65236 L F
.46377 .65705 m .46048 .64983 L .45668 .65419 L 0 1 .326 r
F
.46048 .64983 m .45757 .64345 L .45688 .65186 L F
.46048 .64983 m .46136 .63448 L .45757 .64345 L F
.46285 .64843 m .46136 .63448 L .46048 .64983 L F
.46048 .64983 m .46125 .64736 L .45751 .65042 L 0 1 .272 r
F
.46384 .64917 m .46287 .64849 L .46048 .64983 L F
.46287 .64849 m .46125 .64736 L .46048 .64983 L F
.46048 .64983 m .45688 .65186 L .45687 .65195 L 0 1 .326 r
F
.46048 .64983 m .45687 .65195 L .45686 .65198 L 0 1 .272 r
F
.46048 .64983 m .45686 .65198 L .4567 .65236 L F
.46048 .64983 m .45687 .65195 L .45668 .65419 L 0 1 .326 r
F
.46048 .64983 m .45751 .65042 L .45687 .65195 L 0 1 .272 r
F
.46377 .65705 m .46285 .64843 L .46048 .64983 L 0 1 .326 r
F
.46377 .65705 m .46457 .64744 L .46286 .64849 L F
.46457 .64744 m .46583 .63205 L .46286 .64849 L F
.46286 .64849 m .46457 .64744 L .46283 .64847 L 0 1 .272 r
F
.46283 .64847 m .46574 .64465 L .46125 .64736 L F
.46457 .64744 m .46574 .64465 L .46283 .64847 L F
.46377 .65705 m .46609 .64653 L .46457 .64744 L 0 1 .326 r
F
0 g
.46802 .63777 m
.47232 .63529 L
s
.46583 .63205 m
.46719 .62069 L
s
.46735 .64591 m
.47132 .64333 L
s
.70736 .89341 m
.7078 .89521 L
s
.70808 .89635 m
.70818 .89676 L
s
.70825 .89701 m
.70825 .89702 L
s
.70823 .89696 m
.70825 .89701 L
s
.70825 .89704 m
.70833 .89735 L
s
.26797 .93941 m .25296 .93794 L .25308 .93926 L 0 .761 .255 r
F
.26797 .93941 m .25727 .93764 L .25296 .93794 L F
.26797 .93941 m .26371 .93828 L .25727 .93764 L F
.27842 .93813 m .26371 .93828 L .26797 .93941 L 0 .734 .245 r
F
0 g
.26797 .93941 m
.26806 .94073 L
s
.26797 .93941 m
.27424 .9398 L
s
.53459 .92841 m .53128 .92264 L .52947 .92291 L 0 .193 .256 r
F
.27651 .72067 m .2665 .71344 L .26514 .7202 L 0 1 .529 r
F
.27651 .72067 m .2709 .70868 L .2665 .71344 L F
.27651 .72067 m .27542 .70911 L .2709 .70868 L F
.27651 .72067 m .27782 .71426 L .27542 .70911 L F
0 g
.2721 .7254 m
.27651 .72067 L
s
.27651 .72067 m
.27894 .72552 L
s
.525 .88434 m
.5261 .88098 L
s
.36876 .93818 m .35943 .92596 L .35574 .92665 L 0 1 .456 r
F
.36876 .93818 m .36502 .9309 L .35943 .92596 L F
.37759 .93633 m .36876 .93818 L .37416 .94305 L 0 1 .449 r
F
.37759 .93633 m .36502 .9309 L .36876 .93818 L F
0 g
.36876 .93818 m
.36898 .94426 L
s
.39869 .6922 m
.40014 .69436 L
s
.30978 .77371 m .29908 .77351 L .30214 .77557 L 0 1 .45 r
F
0 g
.29946 .77774 m
.30214 .77557 L
s
.81783 .79447 m
.81933 .79011 L
s
.45877 .95631 m .45457 .95436 L .44961 .95377 L 0 1 .519 r
F
.74498 .90537 m .7524 .90959 L .75587 .90677 L 0 1 .448 r
F
0 g
.74662 .91106 m
.7524 .90959 L
s
.7524 .90959 m
.75298 .91231 L
s
.45681 1.02653 m .45856 1.03236 L .45999 1.0313 L 0 .727 .451 r
F
.47139 1.03915 m .45999 1.0313 L .45856 1.03236 L 0 .645 .435 r
F
0 g
.45856 1.03236 m
.46222 1.03679 L
s
.45293 1.02921 m
.45856 1.03236 L
s
.47389 .95801 m .47411 .96113 L .47569 .96006 L 0 1 .494 r
F
.48408 .96176 m .47569 .96006 L .47411 .96113 L 0 1 .47 r
F
0 g
.47411 .96113 m
.47636 .96296 L
s
.46963 .96068 m
.47411 .96113 L
s
.24238 .71918 m .23098 .71867 L .2333 .72455 L 0 1 .528 r
F
0 g
.22968 .73028 m
.2333 .72455 L
s
.40579 .96807 m .40392 .9746 L .40681 .97365 L 0 .928 .45 r
F
.41718 .98379 m .40681 .97365 L .40392 .9746 L 0 .887 .454 r
F
0 g
.40392 .9746 m
.40552 .98004 L
s
.39834 .97038 m
.40392 .9746 L
s
.47228 .64125 m .46574 .64465 L .46797 .6441 L 0 1 .208 r
F
.47228 .64125 m .46703 .64274 L .46574 .64465 L F
.47228 .64125 m .47099 .63963 L .46703 .64274 L F
0 g
.46765 .64225 m
.46802 .63777 L
s
.47228 .64125 m .4753 .63678 L .47099 .63963 L 0 1 .208 r
F
.47228 .64125 m .47709 .6361 L .4753 .63678 L F
0 g
.46797 .6441 m
.47228 .64125 L
s
.47171 .64249 m
.47228 .64125 L
s
.47709 .6361 m
.48118 .63304 L
s
.47579 .63801 m
.47709 .6361 L
s
.32272 .91424 m .31822 .91927 L .3221 .91868 L 0 1 .529 r
F
.32272 .91424 m .31289 .91556 L .31822 .91927 L F
0 g
.31822 .91927 m
.31834 .92367 L
s
.3221 .91868 m
.32484 .92027 L
s
.32484 .92027 m
.32789 .92204 L
s
.29908 .77351 m .28911 .77557 L .29472 .77558 L 0 1 .473 r
F
0 g
.29472 .77558 m
.29946 .77774 L
s
.37759 .93633 m .37416 .94305 L .37762 .94227 L 0 1 .449 r
F
.38731 .95371 m .37762 .94227 L .37416 .94305 L 0 1 .454 r
F
0 g
.37416 .94305 m
.37482 .94889 L
s
.36876 .93818 m
.37416 .94305 L
s
.35986 .91979 m .35574 .92665 L .35943 .92596 L 0 1 .451 r
F
.35986 .91979 m .35049 .92139 L .35574 .92665 L F
.35981 .92211 m .35574 .92665 L .35943 .92596 L 0 1 .528 r
F
.35975 .92444 m .35574 .92665 L .35943 .92596 L 0 1 .373 r
F
.35981 .92211 m .35043 .92368 L .35574 .92665 L 0 1 .528 r
F
.35975 .92444 m .35037 .92596 L .35574 .92665 L 0 1 .373 r
F
0 g
.35574 .92665 m
.35597 .93273 L
s
.35943 .92596 m
.35948 .92596 L
s
.35948 .92596 m
.35955 .92596 L
s
.501 1.06312 m .49441 1.05921 L .48901 1.05697 L 0 .519 .362 r
F
0 g
.46738 .6455 m
.46797 .6441 L
s
.29908 .77351 m .28504 .77314 L .28911 .77557 L 0 1 .473 r
F
0 g
.28808 .77496 m
.28911 .77557 L
s
.28548 .77806 m
.28911 .77557 L
s
.56797 .45125 m .56387 .45796 L .56275 .4532 L 0 .323 .076 r
F
.56797 .45125 m .57115 .46395 L .56387 .45796 L F
.56797 .45125 m .57971 .46715 L .57115 .46395 L F
.56797 .45125 m .58493 .46518 L .57971 .46715 L F
.56797 .45125 m .58333 .45936 L .58493 .46518 L F
0 g
.58412 .45932 m
.58798 .45914 L
s
.58333 .45936 m
.58412 .45932 L
s
.56275 .4532 m
.56797 .45125 L
s
.56666 .45015 m
.56797 .45125 L
s
.57606 .45341 m
.58333 .45936 L
s
.501 1.06312 m .50563 1.0671 L .50581 1.0665 L 0 .519 .362 r
F
.51756 1.0721 m .50581 1.0665 L .50563 1.0671 L 0 .427 .237 r
F
0 g
.50563 1.0671 m
.51078 1.06971 L
s
.50023 1.06486 m
.50563 1.0671 L
s
.51542 .74147 m .51687 .73991 L .51845 .74929 L 0 .314 .147 r
F
.51543 .77682 m .51633 .75243 L .51568 .75263 L 0 .731 .267 r
F
.51542 .74147 m .51633 .75243 L .51568 .75263 L 0 .314 .147 r
F
.51543 .77682 m .51721 .75212 L .51633 .75243 L 0 .731 .267 r
F
.51542 .74147 m .51568 .75263 L .51504 .75284 L 0 .314 .147 r
F
.51542 .74147 m .51845 .74929 L .51853 .75109 L F
.51542 .74147 m .51853 .75109 L .51844 .75116 L F
.51542 .74147 m .51856 .75155 L .5172 .75204 L F
.51542 .74147 m .51721 .75212 L .51633 .75243 L F
.51568 .75332 m .51569 .75232 L .51505 .75381 L 0 .731 .267 r
F
.51542 .74147 m .51504 .75283 L .51445 .75227 L 0 .314 .147 r
F
.51504 .75283 m .51504 .75284 L .51502 .75283 L F
.51504 .75283 m .51502 .75283 L .51445 .75227 L F
.51178 .77526 m .51446 .75487 L .51446 .75408 L 0 .745 .272 r
F
.51178 .77526 m .51446 .75408 L .51435 .75406 L F
.51178 .77526 m .51441 .75354 L .51304 .75376 L F
.51441 .75354 m .51446 .75309 L .5133 .75364 L F
.51441 .75354 m .5133 .75364 L .51304 .75376 L F
.51179 .74439 m .51305 .75366 L .51224 .75374 L 0 .298 .137 r
F
.51164 .75423 m .51164 .75408 L .51163 .75408 L 0 .745 .272 r
F
.51178 .77526 m .51225 .75392 L .51164 .75423 L F
.51164 .75364 m .51167 .75407 L .51163 .75408 L 0 .298 .137 r
F
.51178 .77526 m .51304 .75386 L .51225 .75392 L 0 .745 .272 r
F
.51304 .75386 m .51305 .75366 L .51225 .75392 L F
.51224 .75374 m .51225 .75392 L .51164 .75364 L 0 .298 .137 r
F
.51178 .77526 m .51324 .77557 L .51446 .75487 L 0 .745 .272 r
F
.51225 .75392 m .51327 .77475 L .51167 .75397 L 0 .298 .137 r
F
.51225 .75392 m .51167 .75397 L .51164 .75364 L F
.51305 .75366 m .51462 .7652 L .51228 .75391 L F
.51305 .75366 m .51228 .75391 L .51224 .75374 L F
.51179 .74439 m .51324 .74339 L .51445 .75227 L F
.51435 .75406 m .51446 .75408 L .51446 .75309 L 0 .745 .272 r
F
.51179 .74439 m .51445 .75227 L .51446 .75309 L 0 .298 .137 r
F
.51304 .75376 m .51446 .75309 L .51305 .75366 L 0 .745 .272 r
F
.51305 .75366 m .51446 .75309 L .51462 .7652 L 0 .298 .137 r
F
.51179 .74439 m .51446 .75309 L .51305 .75366 L F
.51305 .75366 m .51446 .75309 L .51461 .72712 L 0 .745 .272 r
F
.51225 .75392 m .51461 .72712 L .51327 .70803 L F
.51224 .75374 m .51228 .75391 L .51225 .75392 L 0 .298 .137 r
F
.51305 .75366 m .51461 .72712 L .51225 .75392 L 0 .745 .272 r
F
.51179 .74439 m .51224 .75374 L .51164 .75364 L 0 .298 .137 r
F
.51225 .75392 m .51327 .70803 L .51164 .75423 L 0 .745 .272 r
F
.51179 .74439 m .511 .75427 L .51044 .75384 L 0 .298 .137 r
F
.511 .75427 m .51133 .71017 L .51012 .73066 L 0 .745 .272 r
F
.51178 .77526 m .511 .75427 L .51044 .75596 L F
.50816 .74611 m .50961 .74556 L .51044 .75384 L 0 .283 .127 r
F
.50816 .74611 m .51044 .75384 L .51044 .75388 L F
.50816 .74611 m .51044 .75388 L .50904 .75491 L F
.50824 .75551 m .50826 .75527 L .50824 .75527 L 0 .758 .276 r
F
.50814 .77601 m .50905 .75521 L .50824 .75551 L F
.50905 .75521 m .50906 .75503 L .50871 .75523 L F
.50905 .75521 m .50871 .75523 L .50824 .75551 L F
.50816 .74611 m .50687 .75562 L .50646 .75433 L 0 .283 .127 r
F
.50687 .75562 m .50651 .7168 L .50566 .73612 L 0 .758 .276 r
F
.50814 .77601 m .50687 .75562 L .50645 .75911 L F
.50687 .75562 m .50685 .75563 L .50646 .75433 L 0 .283 .127 r
F
.50687 .75562 m .50633 .75562 L .50645 .75911 L 0 .758 .276 r
F
.50686 .75568 m .50632 .75606 L .50634 .75582 L 0 .283 .127 r
F
.50685 .75563 m .50634 .75582 L .50646 .75433 L F
.50686 .75568 m .50634 .75582 L .50685 .75563 L F
.50455 .77861 m .50645 .75911 L .50634 .75582 L 0 .77 .281 r
F
.5046 .74691 m .50646 .75433 L .50635 .75561 L 0 .266 .116 r
F
.5046 .74691 m .50635 .75561 L .5063 .75564 L F
.5046 .74691 m .50634 .75582 L .50513 .75627 L F
.5046 .74691 m .50258 .75677 L .50255 .75405 L F
.50258 .75677 m .50213 .757 L .50255 .75405 L F
.50113 .747 m .49797 .75807 L .49876 .7532 L 0 .246 .106 r
F
.49797 .75807 m .49769 .75819 L .49876 .7532 L F
.49779 .74654 m .49292 .75939 L .49513 .75196 L 0 .225 .101 r
F
.49292 .75939 m .4929 .75944 L .49291 .7594 L F
.49292 .75939 m .49291 .7594 L .49513 .75196 L F
.49462 .7457 m .49587 .74608 L .49513 .75196 L 0 .201 .095 r
F
.49779 .74654 m .49437 .75917 L .4929 .75944 L 0 .225 .101 r
F
.49769 .78799 m .49438 .75932 L .4929 .75977 L 0 .788 .29 r
F
.49448 .79425 m .4929 .75975 L .49284 .75955 L 0 .793 .294 r
F
.49448 .79425 m .49284 .75955 L .49283 .75955 L F
.49462 .7457 m .49284 .75954 L .49102 .76004 L 0 .201 .095 r
F
.49282 .75955 m .49283 .75955 L .49282 .75955 L 0 .793 .294 r
F
.49448 .79425 m .49283 .75955 L .49282 .75955 L F
.49462 .7457 m .4929 .75944 L .49284 .75954 L 0 .201 .095 r
F
.49462 .7457 m .49102 .76004 L .4893 .76036 L F
.49102 .76004 m .49281 .75946 L .49098 .75967 L 0 .793 .294 r
F
.49448 .79425 m .49282 .75971 L .49102 .76004 L F
.49282 .75971 m .49281 .75946 L .49102 .76004 L F
.49098 .75967 m .49281 .75946 L .49268 .75901 L F
.49167 .74456 m .48906 .75718 L .48615 .76109 L 0 .176 .089 r
F
.49167 .74456 m .49171 .75044 L .48906 .75718 L F
.49462 .7457 m .48906 .75718 L .49171 .75044 L 0 .201 .095 r
F
.49462 .7457 m .48927 .76044 L .48906 .75718 L F
.49448 .79425 m .48927 .76044 L .48901 .76915 L 0 .793 .294 r
F
.48927 .76044 m .48862 .76061 L .48906 .75718 L 0 .201 .095 r
F
.49167 .74456 m .48615 .76109 L .48602 .76113 L 0 .176 .089 r
F
.48927 .76044 m .48834 .75441 L .48862 .76061 L 0 .793 .294 r
F
.48927 .76044 m .48862 .76061 L .48901 .76915 L F
.48927 .76044 m .48862 .76062 L .48862 .76061 L 0 .201 .095 r
F
.48927 .76044 m .48831 .7631 L .48862 .76062 L F
.49102 .76004 m .49101 .75996 L .48927 .76044 L 0 .793 .294 r
F
.4893 .76036 m .48932 .76043 L .48927 .76044 L 0 .201 .095 r
F
.49101 .75996 m .49002 .75016 L .48927 .76044 L 0 .793 .294 r
F
.49097 .75955 m .49268 .75901 L .49002 .75016 L F
.49098 .75967 m .49268 .75901 L .49097 .75955 L F
.48602 .76113 m .48615 .76109 L .48594 .76137 L 0 .176 .089 r
F
.49147 .80129 m .48596 .76128 L .48433 .76529 L 0 .795 .298 r
F
.48596 .76128 m .48595 .76129 L .48433 .76529 L F
.48595 .76129 m .48575 .76133 L .48433 .76529 L F
.48596 .76126 m .48583 .7613 L .48595 .76129 L F
.48583 .7613 m .48575 .76133 L .48595 .76129 L F
.48436 .7603 m .48576 .76131 L .4845 .76148 L 0 .213 .084 r
F
.48895 .74321 m .48223 .75254 L .48562 .74696 L 0 .148 .082 r
F
.48895 .74321 m .48073 .75755 L .48223 .75254 L F
.48895 .74321 m .48214 .75864 L .48073 .75755 L F
.48895 .74321 m .48549 .75486 L .48214 .75864 L F
.48895 .74321 m .48853 .74876 L .48549 .75486 L F
.49167 .74456 m .48549 .75486 L .48853 .74876 L 0 .176 .089 r
F
.49167 .74456 m .48436 .7603 L .48549 .75486 L F
.48413 .76184 m .48415 .76164 L .48412 .76165 L 0 .916 .304 r
F
.48433 .76529 m .4845 .76172 L .48413 .76184 L F
.48433 .76529 m .48576 .76131 L .48451 .76157 L F
.48763 .74246 m .48129 .75182 L .48478 .74639 L 0 .128 .077 r
F
.48763 .74246 m .47896 .75616 L .48129 .75182 L F
.48763 .74246 m .47937 .75649 L .47896 .75616 L F
.48763 .74246 m .48223 .75254 L .47937 .75649 L F
.48763 .74246 m .48562 .74696 L .48223 .75254 L F
.48073 .75755 m .47442 .76341 L .47712 .75987 L 0 .18 .076 r
F
.47896 .75616 m .47251 .76303 L .47603 .75896 L 0 .156 .07 r
F
.47896 .75616 m .47246 .76382 L .47251 .76303 L F
.47385 .75162 m .46899 .75987 L .46516 .76175 L 0 .091 .057 r
F
.47385 .75162 m .47281 .75614 L .46899 .75987 L F
.47656 .75411 m .46899 .75987 L .47281 .75614 L 0 .132 .066 r
F
.47656 .75411 m .46725 .7637 L .46899 .75987 L F
.47156 .74923 m .46343 .7543 L .46771 .751 L 0 .048 .048 r
F
.47156 .74923 m .46102 .75762 L .46343 .7543 L F
.47156 .74923 m .46209 .75875 L .46102 .75762 L F
.47156 .74923 m .46596 .75697 L .46209 .75875 L F
.47156 .74923 m .47003 .75349 L .46596 .75697 L F
.47385 .75162 m .46596 .75697 L .47003 .75349 L 0 .091 .057 r
F
.47385 .75162 m .46386 .76052 L .46596 .75697 L F
.47385 .75162 m .46516 .76175 L .46386 .76052 L F
.46725 .7637 m .46392 .76525 L .46326 .76468 L 0 .134 .053 r
F
.46721 .76872 m .46391 .76526 L .46324 .76766 L 0 .982 .322 r
F
.46391 .76526 m .4639 .76526 L .46324 .76766 L F
.4639 .76526 m .46208 .76549 L .46208 .7655 L F
.4639 .76526 m .46208 .7655 L .46324 .76766 L F
.46386 .76052 m .454 .76678 L .45575 .76396 L 0 .086 .043 r
F
.454 .76678 m .4539 .7668 L .45575 .76396 L F
.46369 .7827 m .45767 .76621 L .454 .76678 L 0 .96 .326 r
F
.454 .76678 m .45539 .76829 L .45384 .76688 L 0 .086 .043 r
F
.46386 .76052 m .45767 .76619 L .454 .76678 L F
.45767 .76621 m .45767 .76619 L .454 .76678 L 0 .96 .326 r
F
.45767 .76619 m .45539 .76829 L .454 .76678 L 0 .086 .043 r
F
.45767 .76619 m .45759 .76597 L .454 .76678 L 0 .96 .326 r
F
.454 .76678 m .45759 .76597 L .45385 .76652 L F
.46369 .7827 m .454 .76678 L .45564 .77598 L F
.454 .76678 m .4539 .7668 L .4539 .7668 L 0 .086 .043 r
F
.454 .76678 m .45385 .76652 L .4539 .7668 L 0 .96 .326 r
F
.454 .76678 m .4539 .7668 L .45564 .77598 L F
.454 .76678 m .45384 .76688 L .4539 .7668 L 0 .086 .043 r
F
.45874 .75499 m .45031 .75833 L .45476 .75598 L 0 0 .021 r
F
.45874 .75499 m .44771 .7609 L .45031 .75833 L F
.45874 .75499 m .44872 .76197 L .44771 .7609 L F
.45874 .75499 m .4527 .76098 L .44872 .76197 L F
.45874 .75499 m .457 .75858 L .4527 .76098 L F
.45874 .75499 m .45958 .75601 L .457 .75858 L F
.46102 .75762 m .4527 .76098 L .457 .75858 L 0 .035 .033 r
F
.46102 .75762 m .45044 .76369 L .4527 .76098 L F
.46102 .75762 m .45172 .76492 L .45044 .76369 L F
.46102 .75762 m .45575 .76396 L .45172 .76492 L F
.46102 .75762 m .45984 .76146 L .45575 .76396 L F
.46102 .75762 m .46209 .75875 L .45984 .76146 L F
.46386 .76052 m .45575 .76396 L .45984 .76146 L 0 .086 .043 r
F
.45767 .76619 m .45949 .76064 L .45546 .76015 L 0 .96 .326 r
F
.46369 .7827 m .46046 .76575 L .45767 .76619 L F
.46386 .76052 m .46046 .76575 L .45767 .76619 L 0 .086 .043 r
F
.46046 .76575 m .45949 .76064 L .45767 .76619 L 0 .96 .326 r
F
.45767 .76619 m .46045 .76577 L .45754 .76631 L 0 .086 .043 r
F
.46046 .76575 m .46045 .76577 L .45767 .76619 L F
.45754 .76631 m .45943 .76734 L .45539 .76829 L F
.46045 .76577 m .45943 .76734 L .45754 .76631 L F
.46386 .76052 m .46326 .76468 L .46212 .76547 L F
.46386 .76052 m .46212 .76547 L .4621 .76547 L F
.46386 .76052 m .4621 .76548 L .46146 .76559 L F
.46721 .76872 m .46611 .76499 L .46538 .76507 L 0 .982 .322 r
F
.46612 .76496 m .46603 .76506 L .46539 .76506 L 0 .134 .053 r
F
.46369 .7827 m .46208 .76551 L .46046 .76575 L 0 .96 .326 r
F
.46369 .7827 m .46324 .76766 L .46208 .76549 L F
.46721 .76872 m .46538 .76507 L .46391 .76526 L 0 .982 .322 r
F
.46369 .7827 m .46504 .77711 L .46324 .76766 L 0 .96 .326 r
F
.46603 .76506 m .45969 .77214 L .46533 .76514 L 0 .134 .053 r
F
.46603 .76506 m .46533 .76514 L .46539 .76506 L F
.46208 .76551 m .46208 .7655 L .46194 .76552 L 0 .96 .326 r
F
.46208 .76551 m .46194 .76552 L .46046 .76575 L F
.46208 .7655 m .46208 .76549 L .46195 .76551 L F
.46208 .7655 m .46195 .76551 L .46046 .76575 L F
.46539 .76506 m .46527 .76515 L .4639 .76526 L 0 .134 .053 r
F
.46527 .76515 m .45789 .77054 L .46385 .7653 L F
.46391 .76526 m .4639 .76526 L .4639 .76526 L 0 .982 .322 r
F
.46527 .76515 m .46385 .7653 L .4639 .76526 L 0 .134 .053 r
F
.46046 .76575 m .46146 .76559 L .46045 .76577 L 0 .086 .043 r
F
.46386 .76052 m .46146 .76559 L .46046 .76575 L F
.46046 .76575 m .46208 .76549 L .45949 .76064 L 0 .96 .326 r
F
.46725 .7637 m .46539 .76506 L .46443 .76519 L 0 .134 .053 r
F
.46392 .76525 m .46443 .76519 L .4639 .76526 L F
.46725 .7637 m .46443 .76519 L .46392 .76525 L F
.46538 .76507 m .46534 .76492 L .46531 .76492 L 0 .982 .322 r
F
.46538 .76507 m .46538 .76507 L .46538 .76507 L F
.46538 .76507 m .46534 .76492 L .46538 .76507 L F
.46386 .76052 m .46516 .76175 L .46326 .76468 L 0 .086 .043 r
F
.46531 .76492 m .45993 .74405 L .45807 .75052 L 0 .982 .322 r
F
.46534 .76492 m .45993 .74405 L .46531 .76492 L F
.4621 .76547 m .46212 .76547 L .4621 .76548 L 0 .086 .043 r
F
.46045 .76577 m .4621 .76548 L .45943 .76734 L F
.46538 .76507 m .46531 .76492 L .46391 .76526 L 0 .982 .322 r
F
.46531 .76492 m .45807 .75052 L .46387 .76517 L F
.46531 .76492 m .46387 .76517 L .46391 .76526 L F
.46379 .76514 m .45807 .75052 L .45949 .76064 L F
.46391 .76526 m .46386 .76513 L .46379 .76514 L F
.46386 .76513 m .45807 .75052 L .46379 .76514 L F
.46538 .76507 m .46521 .76529 L .46506 .7653 L 0 .134 .053 r
F
.46539 .76506 m .46539 .76507 L .46538 .76507 L F
.46539 .76507 m .46521 .76529 L .46538 .76507 L F
.46506 .7653 m .45969 .77214 L .45789 .77054 L F
.46521 .76529 m .45969 .77214 L .46506 .7653 L F
.45759 .76597 m .45758 .76596 L .45735 .76599 L 0 .96 .326 r
F
.45759 .76597 m .45735 .76599 L .45385 .76652 L F
.45758 .76596 m .45546 .76015 L .45391 .76628 L F
.45758 .76596 m .45391 .76628 L .45385 .76652 L F
.46352 .76544 m .45789 .77054 L .45943 .76734 L 0 .134 .053 r
F
.4639 .76526 m .46372 .76542 L .46352 .76544 L F
.46372 .76542 m .45789 .77054 L .46352 .76544 L F
.46725 .7637 m .46612 .76496 L .46539 .76506 L F
.46392 .76525 m .4639 .76526 L .46386 .76526 L F
.4639 .76526 m .46386 .76526 L .46386 .76526 L F
.46392 .76525 m .46386 .76526 L .46326 .76468 L F
.46387 .76527 m .46375 .76529 L .46326 .76468 L F
.46377 .76532 m .46197 .76557 L .46326 .76468 L F
.4639 .76526 m .45949 .76064 L .46208 .76549 L 0 .982 .322 r
F
.4639 .76526 m .46387 .76527 L .46386 .76526 L 0 .134 .053 r
F
.46611 .76498 m .46369 .77117 L .45969 .77214 L F
.46668 .76491 m .46668 .7649 L .46611 .76499 L 0 .982 .322 r
F
.46725 .7637 m .46668 .7649 L .46611 .76498 L 0 .134 .053 r
F
.46668 .7649 m .4639 .74511 L .46611 .76498 L 0 .982 .322 r
F
.46668 .7649 m .46611 .76498 L .46611 .76499 L F
.46668 .7649 m .46667 .76491 L .46611 .76498 L 0 .134 .053 r
F
.46721 .76872 m .46668 .76491 L .46611 .76499 L 0 .982 .322 r
F
.46667 .76491 m .46369 .77117 L .46611 .76498 L 0 .134 .053 r
F
.46611 .76499 m .46611 .76498 L .46538 .76507 L 0 .982 .322 r
F
.46611 .76498 m .45993 .74405 L .46538 .76507 L F
.46611 .76498 m .46538 .76507 L .46538 .76507 L F
.46611 .76499 m .4639 .74511 L .45993 .74405 L F
.46387 .76527 m .46377 .76532 L .46375 .76529 L 0 .134 .053 r
F
.46377 .76532 m .45943 .76734 L .46197 .76557 L F
.46668 .76491 m .46734 .75298 L .4639 .74511 L 0 .982 .322 r
F
.46671 .76514 m .46672 .76491 L .46668 .76491 L F
.47656 .75411 m .46919 .76444 L .46725 .7637 L 0 .132 .066 r
F
.46919 .76444 m .46892 .76451 L .46725 .7637 L F
.46724 .76499 m .46876 .7631 L .46734 .75298 L 0 .982 .322 r
F
.46721 .76872 m .46832 .76468 L .46724 .76499 L F
.46892 .76451 m .46832 .76468 L .46725 .7637 L 0 .132 .066 r
F
.46832 .76468 m .46876 .7631 L .46724 .76499 L 0 .982 .322 r
F
.47634 .79139 m .46914 .76452 L .46721 .76872 L 0 .891 .314 r
F
.46899 .76455 m .46832 .76468 L .46892 .76451 L 0 .132 .066 r
F
.46919 .76444 m .46908 .76459 L .46892 .76451 L F
.46914 .76452 m .46876 .7631 L .46832 .76468 L 0 .891 .314 r
F
.46908 .76463 m .46832 .76468 L .46721 .76872 L F
.46724 .76475 m .46874 .76507 L .46722 .76826 L 0 .134 .053 r
F
.46725 .7637 m .46832 .76468 L .46724 .76475 L F
.46832 .76468 m .46874 .76507 L .46724 .76475 L F
.46914 .76452 m .46832 .76468 L .46908 .76463 L 0 .891 .314 r
F
.46908 .76459 m .46832 .76468 L .46899 .76455 L 0 .132 .066 r
F
.46908 .76459 m .4684 .76475 L .46832 .76468 L F
.46668 .7649 m .46722 .76826 L .46369 .77117 L 0 .134 .053 r
F
.46725 .7637 m .46724 .76483 L .46668 .7649 L F
.46672 .76491 m .46672 .7649 L .46668 .76491 L 0 .982 .322 r
F
.46672 .7649 m .46668 .7649 L .46668 .76491 L F
.46721 .76872 m .46724 .76499 L .46671 .76514 L F
.46724 .76483 m .46722 .76826 L .46668 .7649 L 0 .134 .053 r
F
.46672 .7649 m .46734 .75298 L .46668 .7649 L 0 .982 .322 r
F
.46724 .76499 m .46734 .75298 L .46671 .76514 L F
.46908 .76459 m .46874 .76507 L .4684 .76475 L 0 .132 .066 r
F
.47656 .75411 m .47251 .76303 L .47018 .76429 L F
.47634 .79139 m .47018 .76429 L .46914 .76452 L 0 .891 .314 r
F
.47008 .76431 m .47018 .76429 L .47005 .76436 L 0 .132 .066 r
F
.47656 .75411 m .47018 .76429 L .47008 .76431 L F
.47634 .79139 m .47249 .76624 L .47018 .76429 L 0 .891 .314 r
F
.46908 .76459 m .47005 .76436 L .46908 .76459 L 0 .132 .066 r
F
.47656 .75411 m .47005 .76436 L .46908 .76459 L F
.47005 .76436 m .47005 .76436 L .46908 .76459 L F
.47246 .76383 m .47076 .76689 L .47025 .76643 L 0 .156 .07 r
F
.47882 .78234 m .47705 .77225 L .47419 .76354 L 0 .9 .311 r
F
.47882 .78234 m .47419 .76354 L .47419 .76354 L F
.47882 .78234 m .47418 .76351 L .47408 .76352 L F
.47882 .78234 m .47246 .76384 L .47249 .76623 L F
.47246 .76384 m .47246 .76383 L .47246 .76384 L F
.47246 .76384 m .47246 .76384 L .47249 .76623 L F
.47246 .76383 m .47245 .76383 L .47249 .76623 L F
.47246 .76382 m .47191 .76394 L .47251 .76303 L 0 .156 .07 r
F
.47245 .76379 m .47191 .76392 L .47191 .76393 L 0 .9 .311 r
F
.47245 .76383 m .47191 .76393 L .47249 .76623 L F
.47246 .76382 m .47246 .76383 L .47217 .76388 L 0 .156 .07 r
F
.47245 .76379 m .47191 .76393 L .47245 .76383 L 0 .9 .311 r
F
.47322 .76366 m .47408 .76351 L .4732 .76369 L 0 .156 .07 r
F
.47896 .75616 m .4741 .76347 L .47322 .76366 L F
.4741 .76347 m .47408 .76351 L .47322 .76366 L F
.47797 .76287 m .47929 .76258 L .47796 .76283 L 0 .907 .309 r
F
.48063 .77648 m .47929 .76258 L .47797 .76287 L F
.48073 .75755 m .48089 .76223 L .47929 .76258 L 0 .18 .076 r
F
.47929 .76258 m .48089 .76214 L .47928 .76246 L 0 .907 .309 r
F
.48063 .77648 m .48089 .76224 L .47929 .76258 L F
.48089 .76223 m .48089 .76224 L .47929 .76258 L 0 .18 .076 r
F
.48089 .76224 m .48089 .76214 L .47929 .76258 L 0 .907 .309 r
F
.48063 .77648 m .48207 .77197 L .48113 .76216 L F
.48073 .75755 m .48214 .75864 L .48113 .7622 L 0 .18 .076 r
F
.48063 .77648 m .48113 .76216 L .48089 .7622 L 0 .907 .309 r
F
.48089 .76226 m .48113 .7622 L .48091 .76295 L 0 .18 .076 r
F
.48073 .75755 m .48113 .7622 L .48089 .76226 L F
.48223 .76194 m .48294 .76184 L .48218 .76198 L 0 .213 .084 r
F
.48436 .7603 m .48303 .7618 L .48223 .76194 L F
.48303 .7618 m .483 .76183 L .48223 .76194 L F
.48224 .76207 m .483 .76183 L .48218 .76198 L 0 .916 .304 r
F
.48433 .76529 m .48303 .7619 L .48224 .76207 L F
.48303 .7619 m .483 .76183 L .48224 .76207 L F
.48433 .76529 m .48348 .76176 L .48301 .76184 L F
.47321 .7637 m .47408 .76351 L .4732 .76369 L 0 .9 .311 r
F
.47882 .78234 m .47408 .76351 L .47321 .7637 L F
.47896 .75616 m .47712 .75987 L .47421 .76345 L 0 .156 .07 r
F
.47896 .75616 m .47421 .76345 L .4742 .76345 L F
.47408 .76351 m .47418 .76349 L .47408 .76351 L F
.47896 .75616 m .47418 .76348 L .47408 .76351 L F
.47418 .76348 m .47418 .76349 L .47408 .76351 L F
.48073 .75755 m .47796 .76283 L .47652 .76307 L 0 .18 .076 r
F
.48063 .77648 m .47652 .76307 L .47437 .76345 L 0 .907 .309 r
F
.47437 .76345 m .47652 .76307 L .47437 .76346 L 0 .18 .076 r
F
.48073 .75755 m .47652 .76307 L .47437 .76345 L F
.48063 .77648 m .47437 .76345 L .47705 .77224 L 0 .907 .309 r
F
.4742 .76345 m .47421 .76345 L .47418 .76349 L 0 .156 .07 r
F
.47896 .75616 m .4732 .76369 L .47246 .76383 L F
.47437 .76345 m .47372 .76209 L .47418 .76349 L 0 .907 .309 r
F
.47437 .76345 m .47418 .76349 L .47705 .77224 L F
.47427 .76347 m .47418 .76349 L .47712 .75987 L 0 .18 .076 r
F
.47427 .76347 m .47418 .76349 L .47427 .76347 L F
.47427 .76348 m .47421 .76349 L .47427 .76347 L F
.47421 .76349 m .47418 .76349 L .47427 .76347 L F
.47652 .76307 m .47651 .76302 L .47437 .76345 L 0 .907 .309 r
F
.47442 .76341 m .47438 .76344 L .47441 .76341 L 0 .18 .076 r
F
.47442 .76341 m .47441 .76341 L .47712 .75987 L F
.47438 .76344 m .47437 .76346 L .47438 .76344 L F
.47438 .76344 m .47438 .76344 L .47712 .75987 L F
.47437 .76346 m .47427 .76348 L .47712 .75987 L F
.47385 .75162 m .47488 .7526 L .47281 .75614 L 0 .091 .057 r
F
.47656 .75411 m .47603 .75896 L .47251 .76303 L 0 .132 .066 r
F
.47651 .76302 m .47258 .75021 L .47437 .76345 L 0 .907 .309 r
F
.47437 .76345 m .47258 .75021 L .47372 .76209 L F
.47656 .75411 m .47776 .75514 L .47603 .75896 L 0 .132 .066 r
F
.47896 .75616 m .47937 .75649 L .47712 .75987 L 0 .156 .07 r
F
.47792 .76258 m .47796 .74872 L .47438 .7445 L 0 .907 .309 r
F
.47794 .76273 m .47794 .76258 L .47792 .76258 L F
.47794 .76258 m .47796 .74872 L .47792 .76258 L F
.48073 .75755 m .47929 .76258 L .47796 .76283 L 0 .18 .076 r
F
.47926 .76226 m .48093 .76006 L .47796 .74872 L 0 .907 .309 r
F
.47927 .76235 m .47935 .76224 L .47926 .76226 L F
.47935 .76224 m .48093 .76006 L .47926 .76226 L F
.47408 .76352 m .47418 .76351 L .47418 .76349 L 0 .9 .311 r
F
.47408 .76352 m .47418 .76349 L .47408 .76351 L F
.47408 .76351 m .47418 .76349 L .47371 .76407 L 0 .156 .07 r
F
.47882 .78234 m .4732 .76369 L .47246 .76383 L 0 .9 .311 r
F
.47246 .76383 m .47311 .7637 L .47246 .76383 L 0 .156 .07 r
F
.4732 .76369 m .4732 .76369 L .47246 .76383 L F
.4732 .76369 m .4732 .76368 L .47246 .76383 L 0 .9 .311 r
F
.47311 .7637 m .4732 .76369 L .47246 .76383 L 0 .156 .07 r
F
.47882 .78234 m .47249 .76623 L .47593 .77604 L 0 .9 .311 r
F
.47634 .79139 m .47593 .77604 L .47249 .76624 L 0 .891 .314 r
F
.47652 .76307 m .47422 .76997 L .47246 .7684 L 0 .18 .076 r
F
.48063 .77648 m .47796 .76283 L .47652 .76307 L 0 .907 .309 r
F
.47796 .76283 m .47422 .76997 L .47652 .76307 L 0 .18 .076 r
F
.47796 .76283 m .47796 .76281 L .47652 .76307 L 0 .907 .309 r
F
.47652 .76307 m .47794 .76273 L .47651 .76302 L F
.47796 .76281 m .47794 .76273 L .47652 .76307 L F
.47437 .76346 m .47246 .7684 L .47371 .76407 L 0 .18 .076 r
F
.47652 .76307 m .47246 .7684 L .47437 .76346 L F
.48349 .76173 m .48381 .7617 L .48348 .76175 L 0 .213 .084 r
F
.48436 .7603 m .48381 .7617 L .48349 .76173 L F
.48381 .7617 m .48381 .7617 L .48349 .76173 L F
.4845 .76172 m .48451 .76162 L .48413 .76184 L 0 .916 .304 r
F
.48303 .7618 m .48348 .76175 L .483 .76183 L 0 .213 .084 r
F
.48436 .7603 m .48349 .76173 L .48303 .7618 L F
.48349 .76173 m .48348 .76175 L .48303 .7618 L F
.48451 .76162 m .48451 .7616 L .48414 .76166 L 0 .916 .304 r
F
.49167 .74456 m .48596 .76124 L .48436 .7603 L 0 .176 .089 r
F
.48596 .76124 m .48594 .76125 L .48436 .7603 L F
.48596 .76126 m .48576 .76131 L .48436 .7603 L F
.48436 .7603 m .4845 .76148 L .48414 .76153 L 0 .213 .084 r
F
.48451 .7616 m .48515 .74806 L .48415 .76165 L 0 .916 .304 r
F
.48451 .7616 m .48415 .76165 L .48414 .76166 L F
.48451 .76162 m .48414 .76166 L .48413 .76184 L F
.48348 .76175 m .4838 .76166 L .48347 .76173 L F
.48433 .76529 m .48381 .7617 L .48348 .76175 L F
.48381 .7617 m .4838 .76166 L .48348 .76175 L F
.47882 .78234 m .47924 .78093 L .47705 .77225 L 0 .9 .311 r
F
.48348 .76175 m .47893 .77415 L .477 .77243 L 0 .213 .084 r
F
.48381 .7617 m .47893 .77415 L .48348 .76175 L F
.48381 .7617 m .48239 .77147 L .47893 .77415 L F
.48381 .7617 m .48257 .73538 L .47917 .73018 L 0 .916 .304 r
F
.48433 .76529 m .48412 .76165 L .48381 .7617 L F
.48412 .76165 m .48257 .73538 L .48381 .7617 L F
.48381 .7617 m .48412 .76165 L .48381 .7617 L 0 .213 .084 r
F
.48436 .7603 m .48412 .76165 L .48381 .7617 L F
.48412 .76165 m .48239 .77147 L .48381 .7617 L F
.48301 .76184 m .48348 .76175 L .483 .76183 L 0 .916 .304 r
F
.48348 .76176 m .48348 .76175 L .48301 .76184 L F
.48348 .76175 m .48347 .76173 L .483 .76183 L F
.483 .76183 m .477 .77243 L .47785 .76763 L 0 .213 .084 r
F
.48348 .76175 m .477 .77243 L .483 .76183 L F
.49147 .80129 m .48433 .76529 L .48538 .77903 L 0 .795 .298 r
F
.48412 .76167 m .48506 .7662 L .48239 .77147 L 0 .213 .084 r
F
.48412 .76165 m .48412 .76166 L .48412 .76167 L F
.48412 .76166 m .48506 .7662 L .48412 .76167 L F
.483 .76183 m .483 .76183 L .48296 .76183 L F
.483 .76183 m .48296 .76183 L .48223 .76194 L F
.483 .76183 m .47721 .73591 L .47796 .74872 L 0 .916 .304 r
F
.48347 .76173 m .47721 .73591 L .483 .76183 L F
.483 .76183 m .48297 .76173 L .48218 .76198 L F
.48297 .76173 m .47796 .74872 L .48216 .76194 L F
.48297 .76173 m .48216 .76194 L .48218 .76198 L F
.48089 .7622 m .48113 .76216 L .48093 .76006 L 0 .907 .309 r
F
.48213 .76201 m .47785 .76763 L .48091 .76295 L 0 .213 .084 r
F
.48214 .762 m .48214 .76201 L .48213 .76201 L F
.48214 .76201 m .47785 .76763 L .48213 .76201 L F
.48089 .76224 m .48091 .76295 L .47929 .76258 L 0 .18 .076 r
F
.47929 .76258 m .48091 .76295 L .47785 .76763 L F
.47796 .76283 m .47925 .76272 L .47791 .76294 L F
.47929 .76258 m .47925 .76272 L .47796 .76283 L F
.47796 .76283 m .47928 .76246 L .47794 .76273 L 0 .907 .309 r
F
.47929 .76258 m .47928 .76246 L .47796 .76283 L F
.47927 .76238 m .4793 .76234 L .47927 .76235 L F
.4793 .76234 m .48093 .76006 L .47927 .76235 L F
.4732 .76369 m .47407 .76351 L .4732 .76366 L 0 .9 .311 r
F
.4732 .76369 m .47408 .76351 L .4732 .76369 L 0 .156 .07 r
F
.47408 .76351 m .47407 .76351 L .4732 .76369 L 0 .9 .311 r
F
.4732 .76369 m .47408 .76351 L .4732 .76369 L 0 .156 .07 r
F
.47408 .76351 m .47418 .76349 L .47372 .7621 L 0 .9 .311 r
F
.4732 .76366 m .47405 .7634 L .47318 .76361 L F
.47407 .76351 m .47405 .7634 L .4732 .76366 L F
.47405 .76375 m .47395 .76378 L .47418 .76349 L 0 .18 .076 r
F
.47419 .76354 m .47419 .76354 L .47418 .76351 L 0 .9 .311 r
F
.47405 .76375 m .47418 .76349 L .47427 .76348 L 0 .18 .076 r
F
.4732 .76369 m .47371 .76407 L .47076 .76689 L 0 .156 .07 r
F
.47408 .76351 m .47371 .76407 L .4732 .76369 L F
.47791 .76294 m .47785 .76763 L .47422 .76997 L 0 .18 .076 r
F
.47925 .76272 m .47785 .76763 L .47791 .76294 L F
.4732 .76369 m .47076 .76689 L .47246 .76383 L 0 .156 .07 r
F
.47246 .76383 m .47245 .76379 L .47245 .76383 L 0 .9 .311 r
F
.47245 .76379 m .47031 .75757 L .47191 .76392 L F
.46914 .76452 m .47018 .76429 L .46876 .7631 L 0 .891 .314 r
F
.47318 .76361 m .47372 .7621 L .47083 .75581 L 0 .9 .311 r
F
.47405 .7634 m .47372 .7621 L .47318 .76361 L F
.46908 .76459 m .47005 .76436 L .46874 .76507 L 0 .132 .066 r
F
.47245 .76379 m .47083 .75581 L .47031 .75757 L 0 .9 .311 r
F
.47245 .76381 m .47245 .76379 L .47245 .76379 L F
.47245 .76379 m .47083 .75581 L .47245 .76379 L F
.47246 .76383 m .47246 .76381 L .47245 .76381 L F
.47246 .76381 m .47083 .75581 L .47245 .76381 L F
.4732 .76368 m .47083 .75581 L .47246 .76383 L F
.47217 .76388 m .47025 .76643 L .47191 .76394 L 0 .156 .07 r
F
.47246 .76383 m .47025 .76643 L .47217 .76388 L F
.47928 .76246 m .47935 .76236 L .47927 .76238 L 0 .907 .309 r
F
.47935 .76236 m .48093 .76006 L .47927 .76238 L F
.48089 .76214 m .48093 .76006 L .47928 .76246 L F
.47928 .76246 m .47796 .74872 L .47794 .76273 L F
.47651 .76302 m .47438 .7445 L .47258 .75021 L F
.47794 .76273 m .47438 .7445 L .47651 .76302 L F
.47437 .76346 m .47405 .76375 L .47427 .76348 L 0 .18 .076 r
F
.47405 .76375 m .47371 .76407 L .47395 .76378 L F
.48211 .76188 m .47796 .74872 L .48093 .76006 L 0 .916 .304 r
F
.48218 .76198 m .48214 .76187 L .48211 .76188 L F
.48214 .76187 m .47796 .74872 L .48211 .76188 L F
.48218 .76198 m .483 .76183 L .48214 .762 L 0 .213 .084 r
F
.48294 .76184 m .483 .76183 L .48218 .76198 L F
.48412 .7616 m .48515 .74806 L .48257 .73538 L 0 .916 .304 r
F
.48412 .76165 m .48412 .7616 L .48412 .7616 L F
.48412 .7616 m .48515 .74806 L .48412 .7616 L F
.48347 .76173 m .47917 .73018 L .47721 .73591 L F
.4838 .76166 m .47917 .73018 L .48347 .76173 L F
.483 .76183 m .47785 .76763 L .48214 .762 L 0 .213 .084 r
F
.48414 .76153 m .48416 .76164 L .48412 .76165 L F
.48416 .76164 m .48506 .7662 L .48412 .76165 L F
.48415 .76164 m .48515 .74806 L .48412 .76165 L 0 .916 .304 r
F
.48596 .76124 m .48596 .76126 L .48594 .76125 L 0 .176 .089 r
F
.48596 .76126 m .48576 .76131 L .48575 .76133 L 0 .795 .298 r
F
.48596 .76126 m .4859 .76142 L .48576 .76131 L 0 .176 .089 r
F
.48596 .76126 m .48591 .76089 L .48576 .76131 L 0 .795 .298 r
F
.48451 .76157 m .48591 .76089 L .48515 .74806 L 0 .916 .304 r
F
.4845 .76148 m .48507 .76145 L .48451 .76157 L 0 .213 .084 r
F
.48576 .76131 m .48591 .76089 L .48451 .76157 L 0 .916 .304 r
F
.48451 .76157 m .4859 .76142 L .48506 .7662 L 0 .213 .084 r
F
.48507 .76145 m .4859 .76142 L .48451 .76157 L F
.48576 .76131 m .4859 .76142 L .4845 .76148 L F
.4845 .76148 m .48506 .7662 L .48414 .76153 L F
.48596 .76128 m .48596 .76126 L .48595 .76129 L 0 .795 .298 r
F
.48596 .76126 m .48594 .76137 L .48592 .76138 L 0 .176 .089 r
F
.49167 .74456 m .48598 .76126 L .48596 .76126 L F
.48598 .76126 m .48594 .76137 L .48596 .76126 L F
.48592 .76138 m .48594 .76137 L .4859 .76142 L F
.48923 .76018 m .49002 .75016 L .48834 .75441 L 0 .793 .294 r
F
.48927 .76044 m .48929 .76016 L .48923 .76018 L F
.48929 .76016 m .49002 .75016 L .48923 .76018 L F
.49448 .79425 m .49102 .76004 L .48927 .76044 L F
.48927 .76044 m .48997 .76423 L .48831 .7631 L 0 .201 .095 r
F
.48932 .76043 m .48997 .76423 L .48927 .76044 L F
.49102 .76004 m .48997 .76423 L .4893 .76036 L F
.49102 .76004 m .49284 .75954 L .48997 .76423 L F
.49769 .78799 m .4929 .75975 L .49506 .77683 L 0 .788 .29 r
F
.49448 .79425 m .49506 .77683 L .4929 .75975 L 0 .793 .294 r
F
.49335 .75945 m .49254 .76591 L .49289 .75958 L 0 .225 .101 r
F
.49437 .75917 m .4929 .75953 L .4929 .75975 L 0 .788 .29 r
F
.49437 .75917 m .49434 .75928 L .49335 .75945 L 0 .225 .101 r
F
.4929 .75977 m .49437 .75917 L .4929 .75975 L 0 .788 .29 r
F
.49438 .75932 m .49437 .75917 L .4929 .75977 L F
.49434 .75928 m .49254 .76591 L .49335 .75945 L 0 .225 .101 r
F
.49282 .75955 m .49284 .75955 L .49281 .75946 L 0 .793 .294 r
F
.49434 .75928 m .4943 .76701 L .49254 .76591 L 0 .225 .101 r
F
.49437 .75917 m .49437 .75927 L .49434 .75928 L F
.49437 .75927 m .4943 .76701 L .49434 .75928 L F
.49444 .75891 m .49569 .75888 L .49439 .75908 L F
.49769 .78799 m .49872 .76985 L .4977 .75863 L 0 .788 .29 r
F
.49779 .74654 m .49571 .75874 L .49447 .7588 L 0 .225 .101 r
F
.49779 .74654 m .49714 .75839 L .49655 .75859 L F
.49571 .75874 m .49655 .75859 L .49569 .75888 L F
.49779 .74654 m .49655 .75859 L .49571 .75874 L F
.49714 .75866 m .4977 .75863 L .49768 .75839 L 0 .788 .29 r
F
.49779 .74654 m .49876 .7532 L .49767 .7583 L 0 .225 .101 r
F
.49714 .75849 m .49768 .75839 L .49767 .7583 L 0 .788 .29 r
F
.49714 .75866 m .49768 .75839 L .49714 .75849 L F
.49769 .78799 m .4977 .75863 L .49714 .75866 L F
.49769 .78799 m .49714 .75866 L .49569 .75888 L F
.49714 .75849 m .49767 .7583 L .49697 .76155 L 0 .225 .101 r
F
.49779 .74654 m .49767 .7583 L .49714 .75849 L F
.49714 .75849 m .49767 .7583 L .497 .75098 L 0 .788 .29 r
F
.49447 .7588 m .4957 .7588 L .49444 .75891 L 0 .225 .101 r
F
.49571 .75874 m .4957 .7588 L .49447 .7588 L F
.4957 .7588 m .49569 .75888 L .49444 .75891 L F
.50106 .7827 m .49798 .7586 L .49872 .76985 L 0 .78 .285 r
F
.49797 .75807 m .49793 .75821 L .49769 .75819 L 0 .246 .106 r
F
.49793 .75821 m .49767 .7583 L .4977 .75863 L 0 .78 .285 r
F
.49793 .75821 m .49766 .75834 L .49767 .7583 L 0 .246 .106 r
F
.49793 .75821 m .49767 .7583 L .49769 .75819 L F
.49798 .7586 m .49793 .75821 L .4977 .75863 L 0 .78 .285 r
F
.49793 .75821 m .497 .75098 L .49767 .7583 L F
.49798 .7586 m .4977 .75863 L .49872 .76985 L F
.49569 .75888 m .49712 .7577 L .49565 .75829 L 0 .788 .29 r
F
.49714 .75839 m .49714 .75849 L .49569 .75888 L 0 .225 .101 r
F
.49714 .75866 m .49712 .7577 L .49569 .75888 L 0 .788 .29 r
F
.49439 .75908 m .49569 .75888 L .49437 .75917 L 0 .225 .101 r
F
.49438 .75932 m .49523 .75898 L .49437 .75917 L 0 .788 .29 r
F
.49769 .78799 m .49569 .75888 L .49438 .75932 L F
.49569 .75888 m .49568 .7588 L .49438 .75932 L F
.49569 .75888 m .4943 .76701 L .49437 .75917 L 0 .225 .101 r
F
.49523 .75898 m .49568 .7588 L .49437 .75917 L 0 .788 .29 r
F
.49569 .75888 m .49714 .75849 L .49568 .75893 L 0 .225 .101 r
F
.49568 .75893 m .49697 .76155 L .4943 .76701 L F
.49714 .75849 m .49697 .76155 L .49568 .75893 L F
.49437 .75917 m .4929 .75953 L .4929 .75944 L F
.49167 .74456 m .49282 .74504 L .49171 .75044 L 0 .176 .089 r
F
.49462 .7457 m .49513 .75196 L .4929 .75944 L 0 .201 .095 r
F
.49437 .75917 m .49261 .74394 L .4929 .75953 L 0 .788 .29 r
F
.49437 .75917 m .49289 .75958 L .4929 .75953 L 0 .225 .101 r
F
.49437 .75917 m .49439 .7399 L .49261 .74394 L 0 .788 .29 r
F
.49568 .7588 m .49439 .7399 L .49437 .75917 L F
.49565 .75829 m .497 .75098 L .49439 .7399 L F
.49712 .7577 m .497 .75098 L .49565 .75829 L F
.49793 .75821 m .4971 .73404 L .497 .75098 L 0 .78 .285 r
F
.49793 .75821 m .49701 .76862 L .49697 .76155 L 0 .246 .106 r
F
.50113 .747 m .49906 .75784 L .49797 .75807 L F
.50113 .747 m .50255 .75405 L .50214 .75695 L F
.50113 .747 m .50214 .75695 L .50209 .75697 L F
.50106 .7827 m .50211 .75727 L .50119 .75741 L 0 .78 .285 r
F
.50211 .75727 m .50212 .75708 L .50119 .75741 L F
.49795 .75843 m .49904 .75794 L .49793 .75821 L F
.50106 .7827 m .49905 .75808 L .49795 .75843 L F
.49905 .75808 m .49904 .75794 L .49795 .75843 L F
.50106 .7827 m .50119 .75741 L .50006 .75796 L F
.49906 .75784 m .49904 .75794 L .49797 .75807 L 0 .246 .106 r
F
.49779 .74654 m .49911 .74678 L .49876 .7532 L 0 .225 .101 r
F
.49904 .75794 m .49894 .73027 L .4971 .73404 L 0 .78 .285 r
F
.50106 .7827 m .50005 .75772 L .49904 .75794 L F
.49906 .75784 m .50005 .75772 L .49904 .75794 L 0 .246 .106 r
F
.50113 .747 m .50005 .75772 L .49906 .75784 L F
.50005 .75772 m .50013 .7571 L .50003 .75715 L 0 .78 .285 r
F
.50006 .75796 m .50008 .75772 L .50005 .75772 L F
.50005 .75772 m .5001 .75775 L .50004 .75777 L 0 .246 .106 r
F
.50006 .75757 m .50009 .75771 L .50005 .75772 L F
.50008 .75772 m .50008 .75771 L .50005 .75772 L 0 .78 .285 r
F
.50119 .75741 m .50009 .75771 L .50006 .75757 L 0 .246 .106 r
F
.50119 .75741 m .50008 .75763 L .50008 .75771 L 0 .78 .285 r
F
.50119 .75741 m .50008 .75771 L .50006 .75796 L F
.50119 .75741 m .50123 .76339 L .50009 .75771 L 0 .246 .106 r
F
.50009 .75771 m .5001 .75775 L .50005 .75772 L F
.50113 .747 m .50119 .75741 L .50006 .75757 L F
.50008 .75771 m .50013 .7571 L .50005 .75772 L 0 .78 .285 r
F
.50005 .75772 m .49894 .73027 L .49904 .75794 L F
.49904 .75794 m .49885 .76965 L .49701 .76862 L 0 .246 .106 r
F
.50005 .75772 m .49885 .76965 L .49904 .75794 L F
.50004 .75777 m .50123 .76339 L .49885 .76965 L F
.5001 .75775 m .50123 .76339 L .50004 .75777 L F
.50119 .75741 m .50211 .75716 L .50119 .75769 L F
.50113 .747 m .5021 .75708 L .50119 .75741 L F
.5021 .75708 m .50211 .75716 L .50119 .75741 L F
.50106 .7827 m .50253 .76385 L .50212 .75708 L 0 .78 .285 r
F
.50209 .75697 m .50214 .75695 L .50211 .75716 L 0 .246 .106 r
F
.50113 .747 m .5025 .74704 L .50255 .75405 L F
.50119 .75741 m .50212 .75708 L .50127 .74301 L 0 .78 .285 r
F
.50119 .75741 m .50127 .74301 L .50008 .75763 L F
.49797 .75807 m .49904 .75794 L .49793 .75821 L 0 .246 .106 r
F
.49904 .75794 m .49701 .76862 L .49793 .75821 L F
.49904 .75794 m .49902 .75768 L .49793 .75821 L 0 .78 .285 r
F
.49902 .75768 m .4971 .73404 L .49793 .75821 L F
.49793 .75821 m .49697 .76155 L .49766 .75834 L 0 .246 .106 r
F
.50003 .75715 m .50127 .74301 L .49894 .73027 L 0 .78 .285 r
F
.50013 .7571 m .50127 .74301 L .50003 .75715 L F
.50119 .75769 m .50211 .75716 L .50123 .76339 L 0 .246 .106 r
F
.50255 .75691 m .50175 .72489 L .50127 .74301 L 0 .77 .281 r
F
.50258 .75677 m .50255 .75692 L .50213 .757 L 0 .266 .116 r
F
.50255 .75692 m .50255 .75691 L .50255 .75691 L 0 .77 .281 r
F
.50255 .75691 m .50175 .72489 L .50255 .75691 L F
.50455 .77861 m .50257 .75713 L .50253 .76385 L F
.50455 .77861 m .50341 .7567 L .50255 .75692 L F
.50455 .77861 m .50513 .75627 L .5042 .75676 L F
.50455 .77861 m .50631 .75613 L .50513 .75627 L F
.50631 .75613 m .50634 .75582 L .50515 .75626 L F
.50631 .75613 m .50515 .75626 L .50513 .75627 L F
.50421 .75638 m .50442 .75647 L .5042 .75653 L 0 .266 .116 r
F
.5046 .74691 m .50513 .75627 L .50421 .75638 L F
.5046 .74691 m .50602 .7467 L .50646 .75433 L F
.50513 .75627 m .50566 .73612 L .50422 .75652 L 0 .77 .281 r
F
.50513 .75627 m .50422 .75652 L .5042 .75676 L F
.5046 .74691 m .50341 .7567 L .50255 .75692 L 0 .266 .116 r
F
.50341 .7567 m .50364 .7215 L .50175 .72489 L 0 .77 .281 r
F
.50455 .77861 m .5042 .75653 L .50341 .7567 L F
.5046 .74691 m .5042 .75653 L .50341 .7567 L 0 .266 .116 r
F
.5042 .75653 m .50364 .7215 L .50341 .7567 L 0 .77 .281 r
F
.50106 .7827 m .50244 .7809 L .50253 .76385 L 0 .78 .285 r
F
.50341 .7567 m .50356 .77199 L .50166 .7711 L 0 .266 .116 r
F
.5042 .75653 m .50356 .77199 L .50341 .7567 L F
.5042 .75653 m .50516 .75677 L .50419 .75691 L F
.50442 .75647 m .50516 .75677 L .5042 .75653 L F
.50513 .75627 m .50516 .75677 L .50421 .75638 L F
.50419 .75691 m .50562 .76478 L .50356 .77199 L F
.50516 .75677 m .50562 .76478 L .50419 .75691 L F
.50257 .75713 m .50255 .75692 L .50255 .75713 L 0 .77 .281 r
F
.50257 .75713 m .50255 .75713 L .50253 .76385 L F
.50255 .75692 m .50127 .74301 L .50211 .75694 L F
.50255 .75692 m .50212 .75708 L .50253 .76385 L F
.50255 .75692 m .50211 .75716 L .50212 .75708 L 0 .266 .116 r
F
.50255 .75692 m .50212 .75708 L .50213 .757 L F
.50255 .75692 m .50211 .75694 L .50212 .75708 L 0 .77 .281 r
F
.50341 .7567 m .50339 .75687 L .50255 .75692 L 0 .266 .116 r
F
.50339 .75687 m .50166 .7711 L .50255 .75692 L F
.50255 .75692 m .50166 .7711 L .50123 .76339 L F
.50341 .7567 m .5034 .75645 L .50255 .75692 L 0 .77 .281 r
F
.5034 .75645 m .50175 .72489 L .50255 .75692 L F
.50255 .75692 m .50123 .76339 L .50211 .75716 L 0 .266 .116 r
F
.50419 .75596 m .50566 .73612 L .50364 .7215 L 0 .77 .281 r
F
.5042 .75676 m .50426 .75593 L .50419 .75596 L F
.50426 .75593 m .50566 .73612 L .50419 .75596 L F
.5063 .75564 m .50635 .75561 L .50634 .75582 L 0 .266 .116 r
F
.50513 .75627 m .50634 .75582 L .50513 .75627 L 0 .77 .281 r
F
.50513 .75627 m .50634 .75582 L .50562 .76478 L 0 .266 .116 r
F
.50513 .75627 m .50634 .75582 L .50566 .73612 L 0 .77 .281 r
F
.50687 .75562 m .50566 .73612 L .50633 .75562 L 0 .758 .276 r
F
.50814 .77601 m .50757 .75543 L .50687 .75562 L F
.50757 .75543 m .50756 .75561 L .50687 .75562 L 0 .283 .127 r
F
.50756 .75561 m .50645 .77315 L .50687 .75562 L F
.50455 .77861 m .50598 .77736 L .50645 .75911 L 0 .77 .281 r
F
.50687 .75562 m .50645 .77315 L .50562 .76478 L 0 .283 .127 r
F
.50816 .74611 m .50757 .75543 L .50687 .75562 L F
.50757 .75543 m .50757 .75518 L .50687 .75562 L 0 .758 .276 r
F
.50757 .75518 m .50651 .7168 L .50687 .75562 L F
.50687 .75562 m .50686 .75568 L .50685 .75563 L 0 .283 .127 r
F
.50686 .75568 m .50562 .76478 L .50632 .75606 L F
.50757 .75518 m .50844 .71393 L .50651 .7168 L 0 .758 .276 r
F
.50757 .75543 m .50758 .75517 L .50757 .75518 L F
.50758 .75517 m .50844 .71393 L .50757 .75518 L F
.50759 .75599 m .5076 .75542 L .50757 .75543 L F
.50758 .75533 m .50758 .75542 L .50757 .75543 L 0 .283 .127 r
F
.5076 .75542 m .50844 .71393 L .50757 .75543 L 0 .758 .276 r
F
.50814 .77601 m .50824 .75551 L .50759 .75599 L F
.50816 .74611 m .50824 .75527 L .50758 .75533 L 0 .283 .127 r
F
.50824 .75551 m .50824 .75527 L .50759 .75599 L 0 .758 .276 r
F
.50824 .75527 m .50758 .75542 L .50758 .75533 L 0 .283 .127 r
F
.50816 .74611 m .50906 .75503 L .50824 .75527 L F
.50824 .75527 m .50844 .71393 L .5076 .75542 L 0 .758 .276 r
F
.50824 .75527 m .5076 .75542 L .50759 .75599 L F
.50904 .75491 m .51044 .75388 L .51043 .75422 L 0 .283 .127 r
F
.50814 .77601 m .51044 .75596 L .51042 .7545 L 0 .758 .276 r
F
.50906 .75503 m .51043 .75422 L .51042 .7545 L 0 .283 .127 r
F
.50904 .75491 m .51043 .75422 L .50906 .75503 L F
.50906 .75503 m .51042 .7545 L .51012 .73066 L 0 .758 .276 r
F
.50814 .77601 m .51042 .7545 L .50906 .75503 L F
.50814 .77601 m .50959 .77545 L .51044 .75596 L F
.50906 .75503 m .51042 .7545 L .5101 .7655 L 0 .283 .127 r
F
.50824 .75527 m .50839 .7738 L .50758 .75542 L F
.50757 .75543 m .50839 .7738 L .50645 .77315 L F
.50758 .75542 m .50839 .7738 L .50757 .75543 L F
.50906 .75503 m .51012 .73066 L .50824 .75551 L 0 .758 .276 r
F
.50824 .75527 m .5101 .7655 L .50839 .7738 L 0 .283 .127 r
F
.50906 .75503 m .5101 .7655 L .50824 .75527 L F
.50824 .75527 m .51012 .73066 L .50844 .71393 L 0 .758 .276 r
F
.50826 .75527 m .51012 .73066 L .50824 .75527 L F
.511 .75427 m .51012 .73066 L .51042 .75426 L 0 .745 .272 r
F
.511 .75427 m .51042 .7545 L .51044 .75596 L F
.511 .75427 m .51042 .75469 L .51042 .7545 L 0 .298 .137 r
F
.511 .75427 m .51042 .7545 L .51044 .75384 L F
.511 .75427 m .51042 .75426 L .51042 .7545 L 0 .745 .272 r
F
.51178 .77526 m .51163 .75408 L .511 .75427 L F
.51163 .75408 m .51163 .75428 L .511 .75427 L 0 .298 .137 r
F
.51163 .75428 m .51131 .77449 L .511 .75427 L F
.511 .75427 m .51131 .77449 L .5101 .7655 L F
.51179 .74439 m .51163 .75408 L .511 .75427 L F
.51163 .75408 m .51163 .75381 L .511 .75427 L 0 .745 .272 r
F
.51163 .75381 m .51133 .71017 L .511 .75427 L F
.511 .75427 m .5101 .7655 L .51042 .75469 L 0 .298 .137 r
F
.51163 .75408 m .51327 .77475 L .51131 .77449 L F
.51167 .75407 m .51327 .77475 L .51163 .75408 L F
.51163 .75408 m .51327 .70803 L .51133 .71017 L 0 .745 .272 r
F
.51164 .75408 m .51327 .70803 L .51163 .75408 L F
.51225 .75392 m .51462 .7652 L .51327 .77475 L 0 .298 .137 r
F
.51228 .75391 m .51462 .7652 L .51225 .75392 L F
.51569 .75232 m .51617 .70559 L .51507 .75281 L 0 .731 .267 r
F
.51569 .75232 m .51507 .75281 L .51505 .75381 L F
.51543 .77682 m .51504 .75284 L .51446 .75487 L F
.51504 .75284 m .51446 .75309 L .51445 .75227 L 0 .314 .147 r
F
.51504 .75284 m .51461 .72712 L .51446 .75309 L 0 .731 .267 r
F
.51504 .75284 m .51446 .75309 L .51446 .75487 L F
.51504 .75284 m .51447 .7533 L .51446 .75309 L 0 .314 .147 r
F
.51504 .75284 m .51462 .7652 L .51447 .7533 L F
.51504 .75284 m .51568 .75263 L .51503 .75292 L F
.51504 .75284 m .51617 .70559 L .51461 .72712 L 0 .731 .267 r
F
.51505 .75381 m .51507 .75283 L .51504 .75284 L F
.51507 .75283 m .51617 .70559 L .51504 .75284 L F
.51543 .77682 m .51568 .75332 L .51505 .75381 L F
.51844 .75116 m .51853 .75109 L .51856 .75155 L 0 .314 .147 r
F
.51907 .7812 m .51907 .75136 L .51846 .7564 L 0 .718 .263 r
F
.51907 .75136 m .51907 .75136 L .51846 .7564 L F
.51907 .75131 m .51856 .75155 L .51846 .7564 L F
.51543 .77682 m .51846 .7564 L .51856 .75155 L 0 .731 .267 r
F
.5172 .75204 m .51856 .75155 L .51721 .75212 L 0 .314 .147 r
F
.51903 .73706 m .51907 .75131 L .51845 .74929 L 0 .333 .155 r
F
.51907 .75131 m .51856 .75155 L .51845 .74929 L F
.51721 .75212 m .51856 .75155 L .51908 .72617 L 0 .731 .267 r
F
.51543 .77682 m .51856 .75155 L .51721 .75212 L F
.51543 .77682 m .51689 .77818 L .51846 .7564 L F
.51721 .75212 m .51856 .75155 L .51911 .76344 L 0 .314 .147 r
F
.51907 .75136 m .51907 .75131 L .51907 .75136 L 0 .718 .263 r
F
.51907 .75131 m .51908 .72617 L .51856 .75155 L F
.51907 .75131 m .51911 .76344 L .51856 .75155 L 0 .333 .155 r
F
.51633 .75243 m .51911 .76344 L .51815 .77437 L 0 .314 .147 r
F
.51721 .75212 m .51911 .76344 L .51633 .75243 L F
.51633 .75243 m .51908 .72617 L .51809 .70448 L 0 .731 .267 r
F
.51721 .75212 m .51908 .72617 L .51633 .75243 L F
.51633 .75243 m .51633 .75234 L .51568 .75263 L F
.51568 .75263 m .51815 .77437 L .5162 .7747 L 0 .314 .147 r
F
.51633 .75243 m .51815 .77437 L .51568 .75263 L F
.51503 .75292 m .5162 .7747 L .51462 .7652 L F
.51568 .75263 m .5162 .7747 L .51503 .75292 L F
.51568 .75263 m .51809 .70448 L .51617 .70559 L 0 .731 .267 r
F
.51633 .75234 m .51809 .70448 L .51568 .75263 L F
0 g
.51809 .70448 m
.51908 .72617 L
s
.51483 .68657 m
.51617 .70559 L
s
.51809 .70448 m
.52 .68086 L
s
.51908 .72617 m
.5206 .70824 L
s
.48409 .74286 m
.48582 .74124 L
s
.48763 .74246 m .48793 .74265 L .48562 .74696 L 0 .128 .077 r
F
0 g
.48763 .74246 m
.48812 .74136 L
s
.48582 .74396 m
.48672 .74186 L
s
.48572 .7442 m
.48582 .74396 L
s
.4848 .74635 m
.48572 .7442 L
s
.48714 .74313 m
.48763 .74246 L
s
.4848 .74636 m
.48714 .74313 L
s
.48793 .74265 m
.48915 .74036 L
s
.50905 .6096 m .5134 .60585 L .51679 .60488 L 0 0 .013 r
F
0 g
.5134 .60585 m
.51654 .6014 L
s
.32301 .9047 m .31073 .89107 L .31005 .89777 L 0 1 .465 r
F
.32301 .9047 m .31478 .89058 L .31073 .89107 L F
.32301 .9047 m .32004 .89643 L .31478 .89058 L F
.33284 .90328 m .32004 .89643 L .32301 .9047 L 0 1 .459 r
F
0 g
.32301 .9047 m
.32814 .91044 L
s
.32232 .91138 m
.32301 .9047 L
s
.35968 .92607 m
.36149 .92692 L
s
.35958 .92602 m
.35966 .92606 L
s
.35943 .92596 m
.35958 .92602 L
s
.35966 .92606 m
.35968 .92607 L
s
.37771 .93081 m .36498 .92496 L .36507 .92858 L 0 1 .53 r
F
0 g
.36149 .92692 m
.36507 .92858 L
s
.35955 .92596 m
.35963 .92597 L
s
.4114 .68837 m
.41607 .68574 L
s
.71992 .8803 m .73124 .86992 L .72594 .87249 L 0 1 .453 r
F
0 g
.73124 .86992 m
.73302 .87421 L
s
.73124 .86992 m
.73609 .86179 L
s
.38654 .92901 m .38298 .93321 L .38644 .93243 L 0 1 .528 r
F
.38654 .92901 m .37771 .93081 L .38298 .93321 L F
0 g
.38298 .93321 m
.38347 .93657 L
s
.28504 .77314 m .2769 .77552 L .28147 .77555 L 0 1 .496 r
F
0 g
.28147 .77555 m
.28548 .77806 L
s
.4641 .95367 m .45877 .95631 L .46342 .95697 L 0 1 .509 r
F
.4641 .95367 m .45457 .95436 L .45877 .95631 L F
0 g
.45877 .95631 m
.46042 .95869 L
s
.5259 .89878 m
.52608 .89969 L
s
.52608 .89969 m
.52724 .90548 L
s
.5259 .89351 m
.5259 .89878 L
s
.51756 1.0721 m .51784 1.0726 L .52297 1.07475 L 0 .427 .237 r
F
0 g
.51784 1.0726 m
.52332 1.07493 L
s
.31259 .92495 m .30617 .92822 L .31126 .92748 L 0 1 .473 r
F
.31259 .92495 m .2997 .92654 L .30617 .92822 L F
0 g
.30568 .93081 m
.30617 .92822 L
s
.31126 .92748 m
.31819 .92871 L
s
.28504 .77314 m .27361 .77278 L .2769 .77552 L 0 1 .496 r
F
0 g
.27631 .77502 m
.2769 .77552 L
s
.27409 .77826 m
.2769 .77552 L
s
.76372 .76211 m .77239 .76965 L .76767 .76667 L 0 .116 0 r
F
.76372 .76211 m .77549 .77001 L .77239 .76965 L F
0 g
.76059 .76172 m
.76372 .76211 L
s
.22586 .94018 m
.23185 .94135 L
s
.81001 .78631 m
.81001 .78631 L
s
.81003 .78636 m
.81014 .78666 L
s
.81014 .78666 m
.81331 .79517 L
s
.27361 .77278 m .26548 .77542 L .27005 .77546 L 0 1 .509 r
F
0 g
.27005 .77546 m
.27409 .77826 L
s
.27361 .77278 m .26218 .77238 L .26548 .77542 L 0 1 .509 r
F
0 g
.26492 .7749 m
.26548 .77542 L
s
.26271 .77842 m
.26548 .77542 L
s
.3959 .92162 m .39191 .92326 L .39553 .92247 L 0 .776 .251 r
F
.3959 .92162 m .38666 .92341 L .39191 .92326 L F
0 g
.39191 .92326 m
.39212 .92409 L
s
.64751 .61918 m .65005 .60788 L .64632 .59158 L 0 .195 .208 r
F
0 g
.64632 .59158 m
.64643 .59413 L
s
.64643 .59413 m
.64711 .60992 L
s
.64711 .60992 m
.64751 .61918 L
s
.64361 .58668 m
.64634 .60947 L
s
.64634 .60947 m
.64751 .61918 L
s
.64591 .58923 m
.64632 .59158 L
s
.33689 .71012 m .32815 .71316 L .33236 .71333 L 0 1 .536 r
F
0 g
.33236 .71333 m
.33472 .71703 L
s
.35049 .92139 m .34174 .90835 L .33785 .90893 L 0 1 .458 r
F
.35049 .92139 m .34716 .9137 L .34174 .90835 L F
.35986 .91979 m .34716 .9137 L .35049 .92139 L 0 1 .451 r
F
0 g
.35039 .92367 m
.35049 .92139 L
s
.35049 .92139 m
.35244 .92334 L
s
.42207 .91793 m .41821 .91911 L .4217 .91827 L 0 .683 .205 r
F
.42207 .91793 m .41312 .91986 L .41821 .91911 L F
0 g
.41821 .91911 m
.41838 .91942 L
s
.37445 .77164 m .36347 .77181 L .36327 .77259 L 0 .726 .239 r
F
0 g
.36327 .77259 m
.36648 .77283 L
s
.37445 .77164 m .36697 .77108 L .36347 .77181 L 0 .726 .239 r
F
.37445 .77164 m .37144 .7709 L .36697 .77108 L F
.37445 .77164 m .37465 .77114 L .37144 .7709 L F
0 g
.37095 .77236 m
.37445 .77164 L
s
.37445 .77164 m
.37766 .77156 L
s
.4825 .67739 m .47671 .66688 L .47888 .67598 L 0 1 .304 r
F
.48756 .70715 m .4825 .67739 L .48212 .69141 L 0 1 .299 r
F
.26218 .77238 m .25405 .77529 L .25862 .77534 L 0 1 .519 r
F
0 g
.25862 .77534 m
.26271 .77842 L
s
.48643 1.0509 m .47812 1.04858 L .4846 1.05298 L 0 .531 .397 r
F
.48643 1.0509 m .47403 1.04456 L .47812 1.04858 L F
0 g
.47249 1.0461 m
.47812 1.04858 L
s
.72063 .90185 m .71769 .90327 L .71942 .90523 L 0 .872 .36 r
F
0 g
.71769 .90327 m
.71942 .90523 L
s
.71267 .90548 m
.71942 .90523 L
s
.5278 .90049 m
.52825 .90219 L
s
.52593 .8934 m
.52619 .89438 L
s
.5267 .89633 m
.5278 .90049 L
s
.57232 .59635 m .57694 .59604 L .5823 .60363 L 0 .534 .107 r
F
.43881 .94547 m .43665 .9492 L .43945 .94814 L 0 1 .526 r
F
.44846 .95123 m .43945 .94814 L .43665 .9492 L 0 1 .524 r
F
0 g
.43665 .9492 m
.4378 .95174 L
s
.43154 .94804 m
.43665 .9492 L
s
.3831 .70095 m .37251 .70109 L .37411 .70368 L 0 1 .525 r
F
0 g
.36974 .70662 m
.37411 .70368 L
s
.3831 .70095 m .37466 .69753 L .37251 .70109 L 0 1 .525 r
F
.3831 .70095 m .37937 .69488 L .37466 .69753 L F
.3831 .70095 m .38351 .6949 L .37937 .69488 L F
.3831 .70095 m .3851 .69751 L .38351 .6949 L F
0 g
.3831 .70095 m
.38481 .70336 L
s
.37839 .7036 m
.3831 .70095 L
s
.47609 .69506 m .47671 .66688 L .47289 .66599 L 0 1 .311 r
F
.47609 .69506 m .47888 .67598 L .47671 .66688 L F
0 g
.47671 .66688 m
.47742 .65382 L
s
.26218 .77238 m .25075 .77196 L .25405 .77529 L 0 1 .519 r
F
0 g
.25352 .77476 m
.25405 .77529 L
s
.25133 .77856 m
.25405 .77529 L
s
.52753 .70862 m
.52779 .736 L
s
.42175 .94128 m .40948 .93769 L .40996 .94061 L 0 1 .529 r
F
0 g
.40447 .93902 m
.40996 .94061 L
s
.48562 .74696 m
.48562 .74696 L
s
.48775 .74298 m
.48793 .74265 L
s
.54802 .79068 m
.54805 .79099 L
s
.4956 .73979 m
.49567 .73935 L
s
.49509 .74288 m
.4956 .73979 L
s
.49527 .74015 m
.49567 .73935 L
s
.49471 .74127 m
.49527 .74015 L
s
.41312 .91986 m .40097 .92135 L .40095 .92193 L 0 .762 .233 r
F
0 g
.39553 .92247 m
.40095 .92193 L
s
.25075 .77196 m .24263 .77516 L .2472 .77521 L 0 1 .525 r
F
0 g
.2472 .77521 m
.25133 .77856 L
s
.78643 .80901 m .79524 .79855 L .79073 .79956 L 0 1 .459 r
F
.77522 .81194 m .78643 .80901 L .78396 .80123 L 0 1 .452 r
F
.29938 .93573 m .29488 .93682 L .29902 .93625 L 0 .653 .215 r
F
.29938 .93573 m .2889 .9369 L .29488 .93682 L F
0 g
.29488 .93682 m
.29535 .93742 L
s
.29902 .93625 m
.30552 .93574 L
s
.23098 .71867 m .22187 .72428 L .22645 .72439 L 0 1 .528 r
F
0 g
.22645 .72439 m
.22968 .73028 L
s
.37251 .70109 m
.37411 .70368 L
s
.71116 .62196 m
.71701 .61043 L
s
.25075 .77196 m .23932 .77155 L .24263 .77516 L 0 1 .525 r
F
0 g
.24166 .7741 m
.24263 .77516 L
s
.23995 .77868 m
.24263 .77516 L
s
.71701 .61043 m .72201 .6229 L .71784 .62274 L 0 .297 .105 r
F
.71701 .61043 m .7276 .61288 L .72201 .6229 L F
0 g
.71781 .6222 m
.71784 .62274 L
s
.71701 .61043 m
.71781 .6222 L
s
.50964 .88699 m .50877 .8815 L .51072 .88151 L 0 0 .018 r
F
.50964 .88699 m .50639 .88381 L .50877 .8815 L F
0 g
.50877 .8815 m
.51041 .87881 L
s
.34129 .59961 m .33206 .59714 L .33137 .60236 L 0 1 .517 r
F
0 g
.32561 .60736 m
.33137 .60236 L
s
.34129 .59961 m .33675 .59104 L .33206 .59714 L 0 1 .517 r
F
.34129 .59961 m .34292 .58742 L .33675 .59104 L F
.34129 .59961 m .34645 .5887 L .34292 .58742 L F
.34129 .59961 m .34575 .59393 L .34645 .5887 L F
0 g
.34078 .60428 m
.34129 .59961 L
s
.33513 .60322 m
.34129 .59961 L
s
.54457 1.08229 m .54757 1.08086 L .54679 1.08202 L 0 0 0 r
F
0 g
.54642 1.07964 m
.54757 1.08086 L
s
.23932 .77155 m .2312 .77502 L .23577 .77507 L 0 1 .53 r
F
0 g
.23577 .77507 m
.23995 .77868 L
s
.34733 .71051 m .33871 .70565 L .33689 .71012 L 0 1 .535 r
F
.34733 .71051 m .34317 .70254 L .33871 .70565 L F
.34733 .71051 m .34728 .70286 L .34317 .70254 L F
.34733 .71051 m .34906 .70629 L .34728 .70286 L F
0 g
.34733 .71051 m
.34919 .71366 L
s
.34312 .71345 m
.34733 .71051 L
s
.66409 1.0711 m
.66764 1.07178 L
s
.23932 .77155 m .22788 .77113 L .2312 .77502 L 0 1 .53 r
F
0 g
.2308 .77454 m
.2312 .77502 L
s
.22858 .77881 m
.2312 .77502 L
s
.68989 .62368 m
.69043 .62516 L
s
.68964 .62299 m
.68989 .62368 L
s
.69043 .62516 m
.69255 .63099 L
s
.68941 .62236 m
.68955 .62275 L
s
.68962 .62294 m
.68964 .62299 L
s
.68941 .62236 m
.68941 .62236 L
s
.52724 .90548 m
.52736 .90535 L
s
.68944 .62368 m
.68978 .64022 L
s
.68942 .62301 m
.68944 .62368 L
s
.68941 .62237 m
.68942 .62277 L
s
.68942 .62296 m
.68942 .62301 L
s
.22788 .77113 m .21978 .77488 L .22435 .77494 L 0 1 .534 r
F
0 g
.22435 .77494 m
.22858 .77881 L
s
.26744 .63012 m .25652 .62898 L .25694 .6368 L 0 1 .482 r
F
0 g
.25159 .64409 m
.25694 .6368 L
s
.30598 .88493 m .2984 .89262 L .30371 .89194 L 0 1 .466 r
F
.30598 .88493 m .29258 .88647 L .2984 .89262 L F
0 g
.29695 .89961 m
.2984 .89262 L
s
.30371 .89194 m
.31005 .89777 L
s
.22788 .77113 m .21645 .77073 L .21978 .77488 L 0 1 .534 r
F
0 g
.21938 .77439 m
.21978 .77488 L
s
.2172 .77893 m
.21978 .77488 L
s
.3089 .61236 m .29846 .61008 L .29837 .61724 L 0 1 .483 r
F
0 g
.29263 .62346 m
.29837 .61724 L
s
.51461 .72712 m
.516 .70794 L
s
.516 .70794 m
.51617 .70559 L
s
.51327 .70803 m
.51483 .68657 L
s
.48756 .70715 m .48977 .70137 L .49014 .68734 L 0 1 .299 r
F
.48046 .90066 m .47176 .904 L .47215 .9028 L 0 0 0 r
F
0 g
.46812 .90455 m
.47215 .9028 L
s
.3089 .61236 m .30283 .60125 L .29846 .61008 L 0 1 .483 r
F
.3089 .61236 m .30914 .59561 L .30283 .60125 L F
.3089 .61236 m .31317 .59696 L .30914 .59561 L F
.3089 .61236 m .31306 .60414 L .31317 .59696 L F
0 g
.30261 .61797 m
.3089 .61236 L
s
.47639 .53799 m .46966 .54214 L .47087 .54395 L 0 1 .245 r
F
0 g
.47639 .53799 m
.47639 .53799 L
s
.47639 .53799 m .47369 .53387 L .46966 .54214 L 0 1 .245 r
F
.47639 .53799 m .48026 .52467 L .47369 .53387 L F
0 g
.47639 .53799 m
.47639 .53799 L
s
.44282 1.01306 m .43742 1.00744 L .43172 1.00405 L 0 .79 .456 r
F
0 g
.43172 1.00405 m
.43742 1.00744 L
s
.42222 .9442 m
.42751 .94542 L
s
.23758 .90798 m .22398 .89587 L .22326 .90169 L 0 1 .533 r
F
.23758 .90798 m .22843 .89557 L .22398 .89587 L F
.23758 .90798 m .23426 .90077 L .22843 .89557 L F
.24844 .90685 m .23426 .90077 L .23758 .90798 L 0 1 .532 r
F
0 g
.23684 .91376 m
.23758 .90798 L
s
.23758 .90798 m
.24328 .91297 L
s
.21645 .77073 m .20835 .77475 L .21292 .7748 L 0 1 .536 r
F
0 g
.21292 .7748 m
.2172 .77893 L
s
.28921 .9279 m .27507 .92283 L .2748 .92577 L 0 1 .499 r
F
.28921 .9279 m .27939 .92246 L .27507 .92283 L F
.28921 .9279 m .28546 .92464 L .27939 .92246 L F
.29969 .92654 m .28546 .92464 L .28921 .9279 L 0 1 .489 r
F
0 g
.28893 .93083 m
.28921 .9279 L
s
.28921 .9279 m
.29512 .92987 L
s
.46771 .751 m
.46822 .75041 L
s
.46822 .75041 m
.46864 .74992 L
s
.46864 .74992 m
.47041 .74784 L
s
.47156 .74923 m .47242 .75017 L .47003 .75349 L 0 .048 .048 r
F
0 g
.47156 .74923 m
.47412 .74519 L
s
.46771 .751 m
.47156 .74923 L
s
.21645 .77073 m .20501 .77034 L .20835 .77475 L 0 1 .536 r
F
0 g
.20798 .77426 m
.20835 .77475 L
s
.20582 .77906 m
.20835 .77475 L
s
.53232 .97261 m .53054 .97238 L .53126 .97256 L 0 .502 .203 r
F
0 g
.53126 .97256 m
.53291 .97278 L
s
.45044 .4952 m .44207 .50323 L .44377 .5017 L 0 0 0 r
F
0 g
.44471 .50097 m
.44631 .49926 L
s
.45044 .4952 m .44653 .49926 L .44207 .50323 L 0 0 0 r
F
.45044 .4952 m .45418 .49244 L .44653 .49926 L F
.45044 .4952 m .46085 .48594 L .45418 .49244 L F
.45044 .4952 m .46211 .48409 L .46085 .48594 L F
0 g
.45765 .48806 m
.46211 .48409 L
s
.46211 .48409 m
.4686 .4777 L
s
.47242 .75017 m
.47264 .75001 L
s
.20501 .77034 m .19692 .77464 L .2015 .77468 L 0 1 .538 r
F
0 g
.2015 .77468 m
.20582 .77906 L
s
.23098 .71867 m .21958 .71815 L .22187 .72428 L 0 1 .528 r
F
0 g
.21826 .73024 m
.22187 .72428 L
s
.64509 .64233 m
.64696 .65801 L
s
.64696 .65801 m
.64804 .66705 L
s
.64506 .64205 m
.64509 .64233 L
s
.64288 .62377 m
.64317 .63358 L
s
.6434 .64148 m
.64359 .64771 L
s
.70106 .62205 m
.70452 .62188 L
s
.70452 .62188 m
.70493 .62202 L
s
.62082 .49697 m
.62099 .49726 L
s
.62076 .49687 m
.62082 .49697 L
s
.61473 .4862 m
.62076 .49687 L
s
.37771 .93081 m .36867 .92432 L .36498 .92496 L 0 1 .53 r
F
0 g
.35963 .92597 m
.36501 .92625 L
s
.37771 .93081 m .37413 .92683 L .36867 .92432 L 0 1 .53 r
F
.38654 .92901 m .37413 .92683 L .37771 .93081 L 0 1 .528 r
F
0 g
.37771 .93081 m
.37779 .93442 L
s
.37771 .93081 m
.38298 .93321 L
s
.80653 .79632 m
.80992 .78628 L
s
.42127 .76432 m .41272 .76576 L .41737 .76468 L 0 0 0 r
F
0 g
.41737 .76468 m
.42073 .76352 L
s
.7873 .77825 m .79863 .78831 L .79864 .78163 L 0 1 .444 r
F
.78723 .77664 m .79829 .78095 L .79864 .78163 L 0 0 0 r
F
.78723 .77664 m .79864 .78163 L .78953 .77774 L F
.78953 .77774 m .79864 .78163 L .79865 .77564 L 0 1 .444 r
F
.7873 .77825 m .79864 .78163 L .78953 .77774 L F
.78953 .77774 m .79864 .78163 L .79895 .78224 L 0 0 0 r
F
.20501 .77034 m .19356 .76996 L .19692 .77464 L 0 1 .538 r
F
0 g
.19444 .7792 m
.19692 .77464 L
s
.21519 .65302 m .20699 .64152 L .20392 .65264 L 0 1 .491 r
F
0 g
.20392 .65264 m
.20503 .66102 L
s
.21519 .65302 m .21263 .63339 L .20699 .64152 L 0 1 .491 r
F
.21519 .65302 m .21708 .63372 L .21263 .63339 L F
.21519 .65302 m .21817 .64214 L .21708 .63372 L F
0 g
.20956 .6611 m
.21519 .65302 L
s
.21519 .65302 m
.21635 .66121 L
s
.38731 .95371 m .38326 .94684 L .37762 .94227 L 0 1 .454 r
F
.3955 .95167 m .38731 .95371 L .39275 .95822 L 0 .965 .446 r
F
.3955 .95167 m .38326 .94684 L .38731 .95371 L F
0 g
.38731 .95371 m
.38796 .95954 L
s
.26514 .7202 m .25516 .71259 L .25376 .71969 L 0 1 .529 r
F
.26514 .7202 m .25961 .70758 L .25516 .71259 L F
.26514 .7202 m .26413 .70802 L .25961 .70758 L F
.26514 .7202 m .2665 .71344 L .26413 .70802 L F
0 g
.2607 .72518 m
.26514 .7202 L
s
.26514 .7202 m
.26754 .72532 L
s
.42957 .9988 m .4245 .99288 L .41878 .98922 L 0 .842 .456 r
F
0 g
.41878 .98922 m
.4245 .99288 L
s
.42957 .9988 m
.43172 1.00405 L
s
.33689 .71012 m .32643 .70948 L .32815 .71316 L 0 1 .536 r
F
0 g
.32416 .71681 m
.32815 .71316 L
s
.23694 .92267 m .23198 .92687 L .23628 .92645 L 0 1 .522 r
F
.23694 .92267 m .22608 .92353 L .23198 .92687 L F
0 g
.23198 .92687 m
.23233 .9307 L
s
.23628 .92645 m
.23811 .92726 L
s
.58942 .63127 m
.59055 .62823 L
s
.7906 .60739 m .79603 .61164 L .79162 .61078 L 0 .041 0 r
F
.7906 .60739 m .80174 .61033 L .79603 .61164 L F
.4641 .95367 m .45323 .95213 L .45457 .95436 L 0 1 .509 r
F
0 g
.44961 .95377 m
.45457 .95436 L
s
.75949 .61753 m .76957 .60519 L .77398 .60649 L 0 .124 .042 r
F
.75949 .61753 m .76338 .60989 L .76957 .60519 L F
0 g
.76835 .59962 m
.76957 .60519 L
s
.43105 .67532 m .42235 .67816 L .42617 .67781 L 0 1 .459 r
F
.43105 .67532 m .42173 .67619 L .42235 .67816 L F
0 g
.42617 .67781 m
.42727 .67981 L
s
.43105 .67532 m .42473 .67322 L .42173 .67619 L 0 1 .459 r
F
.43105 .67532 m .42962 .67072 L .42473 .67322 L F
.43105 .67532 m .43314 .67036 L .42962 .67072 L F
.43105 .67532 m .43375 .67233 L .43314 .67036 L F
0 g
.43105 .67532 m
.43188 .67722 L
s
.42617 .67781 m
.43105 .67532 L
s
.57656 .67618 m
.57688 .67331 L
s
.57688 .67331 m
.57737 .66889 L
s
.57737 .66889 m
.57742 .66845 L
s
.57742 .66845 m
.57746 .66806 L
s
.57746 .66806 m
.57749 .66776 L
s
.57749 .66776 m
.57757 .66702 L
s
.57757 .66702 m
.5777 .66589 L
s
.5777 .66589 m
.5778 .66498 L
s
.57854 .65826 m
.57889 .65508 L
s
.2702 .90468 m .2648 .91042 L .26911 .90992 L 0 1 .531 r
F
.2702 .90468 m .25932 .90575 L .2648 .91042 L F
0 g
.2646 .91567 m
.2648 .91042 L
s
.26911 .90992 m
.27523 .91426 L
s
.38644 .93243 m
.38837 .93316 L
s
.40432 .93583 m .39176 .93129 L .39192 .93449 L 0 1 .529 r
F
0 g
.38837 .93316 m
.39192 .93449 L
s
.50175 .72489 m .49812 .69601 L .49938 .71395 L 0 .914 .284 r
F
.4971 .73404 m .49938 .71395 L .49812 .69601 L 0 .921 .289 r
F
0 g
.49546 .68693 m
.49812 .69601 L
s
.49812 .69601 m
.49896 .67829 L
s
.4971 .73404 m .49316 .69271 L .49271 .70896 L 0 .921 .289 r
F
0 g
.49014 .68734 m
.49316 .69271 L
s
.3595 .92602 m
.35956 .92607 L
s
.35943 .92596 m
.3595 .92602 L
s
.37759 .93633 m .36498 .92496 L .36502 .9309 L 0 1 .449 r
F
0 g
.35956 .92607 m
.36502 .9309 L
s
.43881 .94547 m .42687 .94275 L .42751 .94542 L 0 1 .526 r
F
.78848 .91061 m .79917 .90827 L .79478 .9079 L 0 1 .51 r
F
.77763 .90938 m .78848 .91061 L .78819 .90734 L 0 1 .5 r
F
.46995 .67392 m .46714 .64848 L .46377 .65705 L 0 1 .318 r
F
0 g
.46714 .64848 m
.47129 .64745 L
s
.46714 .64848 m
.46738 .6455 L
s
.43375 .67233 m
.43841 .66978 L
s
.36327 .77259 m .35277 .77213 L .35257 .77322 L 0 .757 .254 r
F
.36327 .77259 m .35613 .77129 L .35277 .77213 L F
.36327 .77259 m .36041 .77125 L .35613 .77129 L F
.36327 .77259 m .36347 .77181 L .36041 .77125 L F
0 g
.35991 .77343 m
.36327 .77259 L
s
.45681 1.02653 m .45113 1.02124 L .4455 1.01809 L 0 .727 .451 r
F
0 g
.4455 1.01809 m
.45113 1.02124 L
s
.44282 1.01306 m
.4455 1.01809 L
s
.48643 1.0509 m .4846 1.05298 L .48992 1.0557 L 0 .531 .397 r
F
0 g
.4846 1.05298 m
.48901 1.05697 L
s
.35043 .92368 m .33764 .91644 L .33744 .92049 L 0 1 .529 r
F
.35043 .92368 m .34154 .91592 L .33764 .91644 L F
.35043 .92368 m .34702 .91902 L .34154 .91592 L F
.35981 .92211 m .34702 .91902 L .35043 .92368 L 0 1 .528 r
F
0 g
.35031 .92596 m
.35043 .92368 L
s
.35043 .92368 m
.35358 .92544 L
s
.41312 .91986 m .4046 .92065 L .40097 .92135 L 0 .762 .233 r
F
.41312 .91986 m .40981 .92001 L .4046 .92065 L F
0 g
.41309 .92044 m
.41312 .91986 L
s
.42207 .91793 m .40981 .92001 L .41312 .91986 L 0 .683 .205 r
F
0 g
.41312 .91986 m
.41821 .91911 L
s
.73443 .62695 m
.73643 .62758 L
s
.46204 .60901 m .45484 .60949 L .45705 .61333 L 0 1 .332 r
F
.46204 .60901 m .45685 .59944 L .45484 .60949 L F
.46204 .60901 m .46173 .5899 L .45685 .59944 L F
.78881 1.05248 m .78207 1.0563 L .77983 1.05864 L 0 1 .276 r
F
0 g
.77118 1.06139 m
.77983 1.05864 L
s
.47609 .69506 m .47289 .66599 L .46995 .67392 L 0 1 .311 r
F
0 g
.47289 .66599 m
.47671 .66688 L
s
.47289 .66599 m
.47346 .65465 L
s
.75183 .83093 m
.75264 .83314 L
s
.47609 .69506 m .47861 .68806 L .47888 .67598 L 0 1 .311 r
F
0 g
.47888 .67598 m
.4825 .67739 L
s
.50525 .96761 m .50096 .9666 L .49724 .96652 L 0 .822 .365 r
F
.21958 .71815 m .21044 .72401 L .21501 .72412 L 0 1 .528 r
F
0 g
.21501 .72412 m
.21826 .73024 L
s
.48895 .74321 m .49001 .74377 L .48853 .74876 L 0 .148 .082 r
F
0 g
.48895 .74321 m
.49015 .73928 L
s
.49001 .74377 m
.49307 .73853 L
s
.43836 .9145 m .42694 .91713 L .42684 .91717 L 0 0 0 r
F
0 g
.4217 .91827 m
.42684 .91717 L
s
.53232 .97261 m .53484 .97291 L .53397 .97283 L 0 .502 .203 r
F
0 g
.53438 .97289 m
.53484 .97291 L
s
.54075 .97389 m .53397 .97283 L .53484 .97291 L 0 0 0 r
F
0 g
.53484 .97291 m
.53902 .97321 L
s
.4641 .95367 m .46342 .95697 L .46543 .9559 L 0 1 .509 r
F
.47389 .95801 m .46543 .9559 L .46342 .95697 L 0 1 .494 r
F
0 g
.46342 .95697 m
.46523 .95902 L
s
.45877 .95631 m
.46342 .95697 L
s
.71038 .90015 m .7125 .90358 L .71769 .90327 L 0 .706 .305 r
F
.71038 .90015 m .70851 .90257 L .7125 .90358 L F
0 g
.7125 .90358 m
.71267 .90548 L
s
.26744 .63012 m .26037 .61888 L .25652 .62898 L 0 1 .482 r
F
.26744 .63012 m .26647 .61181 L .26037 .61888 L F
.26744 .63012 m .27074 .61251 L .26647 .61181 L F
.26744 .63012 m .27115 .62036 L .27074 .61251 L F
0 g
.26744 .63012 m
.26797 .63769 L
s
.26135 .63716 m
.26744 .63012 L
s
.75281 .81982 m .76296 .82678 L .76401 .8155 L 0 1 .436 r
F
0 g
.76134 .83058 m
.76296 .82678 L
s
.76296 .82678 m
.76549 .83423 L
s
.34269 .90195 m .33785 .90893 L .34174 .90835 L 0 1 .454 r
F
.34269 .90195 m .33284 .90328 L .33785 .90893 L F
0 g
.33759 .91526 m
.33785 .90893 L
s
.3955 .95167 m .39275 .95822 L .39594 .95736 L 0 .965 .446 r
F
.40579 .96807 m .39594 .95736 L .39275 .95822 L 0 .928 .45 r
F
0 g
.39275 .95822 m
.39378 .9638 L
s
.38731 .95371 m
.39275 .95822 L
s
.37964 .57594 m .37268 .5793 L .37598 .57811 L 0 1 .279 r
F
.37964 .57594 m .37145 .5792 L .37268 .5793 L F
.37964 .57594 m .37311 .57788 L .37145 .5792 L F
0 g
.37496 .58126 m
.37597 .57814 L
s
.37597 .57814 m
.37598 .57812 L
s
.37964 .57594 m .37678 .5757 L .37311 .57788 L 0 1 .279 r
F
.37964 .57594 m .38 .57412 L .37678 .5757 L F
.37964 .57594 m .38123 .57422 L .38 .57412 L F
0 g
.37964 .57594 m
.38093 .57643 L
s
.37598 .57811 m
.37964 .57594 L
s
.38123 .57422 m
.38481 .57197 L
s
.46528 .56789 m .47273 .54698 L .46731 .55232 L 0 1 .322 r
F
0 g
.47273 .54698 m
.47639 .53799 L
s
.52565 .46847 m .53363 .4616 L .54008 .45743 L 0 0 0 r
F
0 g
.53363 .4616 m
.53914 .4553 L
s
.45757 .64345 m .46255 .62429 L .46035 .61967 L 0 1 .335 r
F
.45757 .64345 m .46136 .63448 L .46255 .62429 L F
0 g
.46255 .62429 m
.46719 .62069 L
s
.46136 .63448 m
.46583 .63205 L
s
.46136 .63448 m
.46255 .62429 L
s
.72458 .87426 m
.72594 .87249 L
s
.71992 .8803 m
.72458 .87426 L
s
.74385 1.06741 m .73691 1.06889 L .73432 1.06958 L 0 .71 .208 r
F
0 g
.72586 1.07068 m
.73432 1.06958 L
s
.71903 .8766 m
.71992 .8803 L
s
.47139 1.03915 m .47403 1.04456 L .47505 1.04359 L 0 .645 .435 r
F
.48643 1.0509 m .47505 1.04359 L .47403 1.04456 L 0 .531 .397 r
F
0 g
.47403 1.04456 m
.47812 1.04858 L
s
.46853 1.04164 m
.47403 1.04456 L
s
.73406 .90387 m .74167 .90778 L .74498 .90537 L 0 1 .416 r
F
0 g
.73601 .9089 m
.74167 .90778 L
s
.74167 .90778 m
.74238 .91021 L
s
.51602 .96983 m .51171 .96899 L .50832 .96889 L 0 .651 .279 r
F
.50964 .88699 m .5051 .88698 L .50639 .88381 L 0 0 .018 r
F
0 g
.5041 .88482 m
.50639 .88381 L
s
.52565 .46847 m .54008 .45743 L .5407 .45874 L 0 0 0 r
F
0 g
.54008 .45743 m
.54077 .45672 L
s
.53363 .4616 m
.54008 .45743 L
s
.49457 .96495 m .49034 .96374 L .48633 .96359 L 0 .963 .429 r
F
.50905 .6096 m .50518 .61547 L .50552 .61372 L 0 0 .013 r
F
.50905 .6096 m .50857 .6145 L .50518 .61547 L F
0 g
.50412 .61328 m
.50603 .61119 L
s
.50905 .6096 m .51343 .61144 L .50857 .6145 L 0 0 .013 r
F
.50905 .6096 m .51695 .60732 L .51343 .61144 L F
.50905 .6096 m .51679 .60488 L .51695 .60732 L F
0 g
.50603 .61119 m
.50905 .6096 L
s
.51679 .60488 m
.51991 .59993 L
s
.5134 .60585 m
.51679 .60488 L
s
.50598 .48639 m .51358 .47832 L .51938 .47269 L 0 0 0 r
F
0 g
.51938 .47269 m
.51959 .47244 L
s
.51358 .47832 m
.51938 .47269 L
s
.51358 .47832 m
.51915 .47183 L
s
.41718 .98379 m .4125 .97758 L .40681 .97365 L 0 .887 .454 r
F
0 g
.40681 .97365 m
.4125 .97758 L
s
.41718 .98379 m
.41878 .98922 L
s
.21958 .71815 m .20817 .71765 L .21044 .72401 L 0 1 .528 r
F
0 g
.20683 .7302 m
.21044 .72401 L
s
.8111 .65395 m .81731 .65003 L .81278 .64951 L 0 1 .512 r
F
.8111 .65395 m .82247 .65555 L .81731 .65003 L F
0 g
.80599 .64864 m
.8111 .65395 L
s
.42127 .76432 m .40969 .76688 L .41272 .76576 L 0 0 0 r
F
0 g
.4091 .76637 m
.41272 .76576 L
s
.45685 .59944 m .46411 .58049 L .46241 .57747 L 0 1 .343 r
F
.45685 .59944 m .46173 .5899 L .46411 .58049 L F
0 g
.46411 .58049 m
.4692 .57524 L
s
.46173 .5899 m
.46671 .58561 L
s
.46173 .5899 m
.46411 .58049 L
s
.3955 .95167 m .38281 .94114 L .38326 .94684 L 0 .965 .446 r
F
0 g
.37762 .94227 m
.38326 .94684 L
s
.21523 .92442 m .20047 .91986 L .20439 .92533 L 0 1 .528 r
F
0 g
.20439 .92533 m
.21053 .92907 L
s
.55568 .44989 m
.55666 .45035 L
s
.55666 .45035 m
.55678 .45041 L
s
.5612 .45248 m
.56275 .4532 L
s
.35257 .77322 m .34207 .77221 L .34187 .7736 L 0 .84 .287 r
F
.35257 .77322 m .34543 .77121 L .34207 .77221 L F
.35257 .77322 m .34971 .77127 L .34543 .77121 L F
.35257 .77322 m .35277 .77213 L .34971 .77127 L F
0 g
.34921 .77421 m
.35257 .77322 L
s
.35257 .77322 m
.35563 .77377 L
s
.48701 .89595 m .48435 .89789 L .48084 .89946 L 0 0 0 r
F
.4913 .8972 m .48701 .89595 L .49019 .89489 L F
.4913 .8972 m .48435 .89789 L .48701 .89595 L F
0 g
.48701 .89595 m
.48782 .89455 L
s
.4457 .75845 m .43715 .76083 L .44172 .75907 L 0 0 0 r
F
0 g
.44172 .75907 m
.44483 .75712 L
s
.51327 .70803 m
.51461 .72712 L
s
.50964 .69441 m
.51133 .71017 L
s
.38665 .92341 m .37422 .9234 L .37418 .92447 L 0 .886 .282 r
F
.38665 .92341 m .37793 .92282 L .37422 .9234 L F
.38665 .92341 m .38326 .92282 L .37793 .92282 L F
0 g
.3866 .92448 m
.38665 .92341 L
s
.3959 .92162 m .38326 .92282 L .38666 .92341 L 0 .776 .251 r
F
0 g
.38666 .92341 m
.39191 .92326 L
s
.32643 .70948 m .31763 .7126 L .32184 .71285 L 0 1 .536 r
F
0 g
.32184 .71285 m
.32416 .71681 L
s
.25993 .92524 m
.26416 .92695 L
s
.68282 1.07311 m .69405 1.07341 L .69087 1.07371 L 0 0 0 r
F
.70046 1.07542 m .69405 1.07341 L .70179 1.07335 L F
.70046 1.07542 m .69087 1.07371 L .69405 1.07341 L F
0 g
.69052 1.0728 m
.69405 1.07341 L
s
.82138 .77158 m .83263 .78287 L .83276 .76999 L 0 1 .465 r
F
0 g
.82914 .79294 m
.83263 .78287 L
s
.35986 .91979 m .34758 .90751 L .34716 .9137 L 0 1 .451 r
F
0 g
.34174 .90835 m
.34716 .9137 L
s
.49587 .74608 m
.49705 .74327 L
s
.54518 .82161 m
.54578 .82598 L
s
.54444 .81625 m
.54518 .82161 L
s
.5446 .81196 m
.5461 .8183 L
s
.81885 .9011 m .82108 .91008 L .82679 .90651 L 0 1 .516 r
F
.81885 .9011 m .8167 .90973 L .82108 .91008 L F
0 g
.82095 .91411 m
.82108 .91008 L
s
.6751 1.07354 m .68282 1.07311 L .68609 1.0742 L 0 0 0 r
F
.48557 .46785 m .49356 .46246 L .49931 .4604 L 0 0 .012 r
F
0 g
.49356 .46246 m
.4984 .45754 L
s
.25376 .71969 m .24382 .71174 L .24238 .71918 L 0 1 .528 r
F
.25376 .71969 m .2483 .70647 L .24382 .71174 L F
.25376 .71969 m .25282 .70692 L .2483 .70647 L F
.25376 .71969 m .25516 .71259 L .25282 .70692 L F
0 g
.24929 .72493 m
.25376 .71969 L
s
.25376 .71969 m
.25614 .72508 L
s
.31289 .91556 m .29792 .90679 L .29654 .91156 L 0 1 .53 r
F
.31289 .91556 m .30323 .90625 L .29792 .90679 L F
.31289 .91556 m .30965 .91002 L .30323 .90625 L F
0 g
.31149 .92032 m
.31289 .91556 L
s
.32272 .91424 m .30965 .91002 L .31289 .91556 L 0 1 .529 r
F
0 g
.31289 .91556 m
.31822 .91927 L
s
.50175 .72489 m .50364 .7215 L .50447 .70369 L 0 .914 .284 r
F
0 g
.50364 .7215 m
.50447 .70369 L
s
.50447 .70369 m
.50651 .7168 L
s
.71038 .90015 m .70759 .9011 L .70851 .90257 L 0 .706 .305 r
F
0 g
.70759 .9011 m
.70851 .90257 L
s
.70372 .90265 m
.70851 .90257 L
s
.7873 .77825 m .79524 .79855 L .79863 .78831 L 0 1 .444 r
F
0 g
.79863 .78831 m
.80201 .79716 L
s
.7873 .77825 m .79073 .79956 L .79524 .79855 L 0 1 .444 r
F
0 g
.79524 .79855 m
.79766 .80658 L
s
.79524 .79855 m
.79863 .78831 L
s
.3725 .70109 m .36371 .70365 L .36782 .7037 L 0 1 .531 r
F
0 g
.36782 .7037 m
.36927 .70289 L
s
.36782 .7037 m
.36974 .70662 L
s
.25652 .62898 m .2459 .63592 L .25032 .63627 L 0 1 .484 r
F
0 g
.25032 .63627 m
.25159 .64409 L
s
.39869 .6922 m .3897 .69482 L .39383 .69468 L 0 1 .512 r
F
0 g
.39383 .69468 m
.39553 .6971 L
s
.30598 .88493 m .29012 .87758 L .29258 .88647 L 0 1 .466 r
F
0 g
.29258 .88647 m
.2984 .89262 L
s
.52779 .736 m
.53027 .71423 L
s
.72331 .86761 m
.72594 .87249 L
s
.77522 .81194 m .78396 .80123 L .77945 .80245 L 0 1 .452 r
F
.76401 .8155 m .77522 .81194 L .77269 .80446 L 0 1 .445 r
F
.27842 .93813 m .26375 .93721 L .26371 .93828 L 0 .734 .245 r
F
.27842 .93813 m .26807 .93693 L .26375 .93721 L F
.27842 .93813 m .27437 .93733 L .26807 .93693 L F
.2889 .9369 m .27437 .93733 L .27842 .93813 L 0 .698 .232 r
F
0 g
.27836 .93919 m
.27842 .93813 L
s
.27842 .93813 m
.28455 .93829 L
s
.5327 .59864 m .53744 .59525 L .54187 .59619 L 0 .145 .077 r
F
0 g
.53744 .59525 m
.54011 .58911 L
s
.55678 .45041 m
.56271 .44842 L
s
.33284 .90328 m .32085 .88987 L .32004 .89643 L 0 1 .459 r
F
.33284 .90328 m .3249 .88941 L .32085 .88987 L F
.33284 .90328 m .33004 .89517 L .3249 .88941 L F
.34269 .90195 m .33004 .89517 L .33284 .90328 L 0 1 .454 r
F
0 g
.33284 .90328 m
.33785 .90893 L
s
.33202 .90982 m
.33284 .90328 L
s
.35037 .92596 m .33743 .92397 L .3373 .92573 L 0 1 .407 r
F
.35037 .92596 m .34133 .92351 L .33743 .92397 L F
.35037 .92596 m .34688 .92436 L .34133 .92351 L F
.35975 .92444 m .34688 .92436 L .35037 .92596 L 0 1 .373 r
F
0 g
.35037 .92596 m
.35574 .92665 L
s
.35021 .92771 m
.35037 .92596 L
s
.53413 1.08038 m .52842 1.07661 L .53546 1.07907 L 0 0 0 r
F
.53413 1.08038 m .52297 1.07475 L .52842 1.07661 L F
.47139 1.03915 m .46549 1.03421 L .45999 1.0313 L 0 .645 .435 r
F
0 g
.45999 1.0313 m
.46549 1.03421 L
s
.45681 1.02653 m
.45999 1.0313 L
s
.20817 .71765 m .19899 .72374 L .20357 .72385 L 0 1 .528 r
F
0 g
.20357 .72385 m
.20683 .7302 L
s
.74385 1.06741 m .74576 1.06708 L .75298 1.06506 L 0 .71 .208 r
F
0 g
.74348 1.06803 m
.74576 1.06708 L
s
.73778 1.06902 m
.74576 1.06708 L
s
.60181 .62385 m .61155 .61333 L .6148 .61796 L 0 .26 .102 r
F
.60181 .62385 m .60599 .61584 L .61155 .61333 L F
0 g
.60599 .61584 m
.60666 .60448 L
s
.61155 .61333 m
.61196 .60743 L
s
.60599 .61584 m
.61155 .61333 L
s
.33256 .913 m .32792 .91781 L .33181 .91726 L 0 1 .528 r
F
.33256 .913 m .32272 .91424 L .32792 .91781 L F
0 g
.32789 .92204 m
.32792 .91781 L
s
.33181 .91726 m
.33437 .91872 L
s
.33437 .91872 m
.33744 .92049 L
s
.36162 .58763 m .35176 .59001 L .3553 .59047 L 0 1 .25 r
F
0 g
.35477 .59515 m
.3553 .59047 L
s
.43562 .99617 m .42957 .9988 L .4351 1.00244 L 0 .788 .445 r
F
.43562 .99617 m .4245 .99288 L .42957 .9988 L F
0 g
.23664 .93933 m
.24246 .94029 L
s
.29846 .61008 m .28776 .6154 L .29201 .61614 L 0 1 .48 r
F
0 g
.29201 .61614 m
.29263 .62346 L
s
.21456 .9386 m .20995 .94122 L .21424 .94087 L 0 .98 .353 r
F
.21456 .9386 m .20371 .93924 L .20995 .94122 L F
0 g
.20995 .94122 m
.21069 .94357 L
s
.21424 .94087 m
.22126 .94245 L
s
.48853 .74876 m
.48862 .74844 L
s
.48862 .74844 m
.48967 .74492 L
s
.48967 .74492 m
.49001 .74377 L
s
.24844 .90685 m .23511 .89513 L .23426 .90077 L 0 1 .532 r
F
.24844 .90685 m .23956 .89484 L .23511 .89513 L F
.24844 .90685 m .24528 .89987 L .23956 .89484 L F
.25932 .90575 m .24528 .89987 L .24844 .90685 L F
0 g
.24758 .91245 m
.24844 .90685 L
s
.24844 .90685 m
.25403 .91168 L
s
.34187 .7736 m .33137 .77207 L .33117 .77379 L 0 .961 .337 r
F
.34187 .7736 m .33474 .77089 L .33137 .77207 L F
.34187 .7736 m .33902 .77104 L .33474 .77089 L F
.34187 .7736 m .34207 .77221 L .33902 .77104 L F
0 g
.33851 .77477 m
.34187 .7736 L
s
.34187 .7736 m
.34493 .77446 L
s
.43562 .99617 m .42271 .98768 L .4245 .99288 L 0 .788 .445 r
F
.33689 .71012 m .32835 .70472 L .32643 .70948 L 0 1 .536 r
F
.33689 .71012 m .33288 .70149 L .32835 .70472 L F
.33689 .71012 m .337 .70195 L .33288 .70149 L F
.33689 .71012 m .33871 .70565 L .337 .70195 L F
0 g
.33236 .71333 m
.33689 .71012 L
s
.33689 .71012 m
.33868 .71352 L
s
.44846 .95123 m .44451 .949 L .43945 .94814 L 0 1 .524 r
F
.45481 .94875 m .44846 .95123 L .45323 .95213 L 0 1 .516 r
F
.45481 .94875 m .44451 .949 L .44846 .95123 L F
0 g
.44846 .95123 m
.44961 .95377 L
s
.52294 .87126 m
.52323 .87167 L
s
.52289 .87119 m
.52294 .87126 L
s
.47003 .75349 m
.47005 .75346 L
s
.47005 .75346 m
.47006 .75344 L
s
.47006 .75344 m
.47242 .75017 L
s
.32643 .70948 m .31597 .70863 L .31763 .7126 L 0 1 .536 r
F
0 g
.31359 .71642 m
.31763 .7126 L
s
.57232 .59635 m .5725 .61001 L .57041 .60232 L 0 .534 .107 r
F
.57232 .59635 m .57789 .61767 L .5725 .61001 L F
.57232 .59635 m .58297 .62016 L .57789 .61767 L F
.57232 .59635 m .58486 .61412 L .58297 .62016 L F
.57232 .59635 m .5823 .60363 L .58486 .61412 L F
0 g
.57694 .59604 m
.5823 .60363 L
s
.5823 .60363 m
.58365 .59735 L
s
.48861 .50851 m .50082 .49292 L .50051 .49265 L 0 .928 .165 r
F
.48861 .50851 m .49573 .49971 L .50082 .49292 L F
0 g
.50082 .49292 m
.50642 .4864 L
s
.49573 .49971 m
.5013 .49339 L
s
.49573 .49971 m
.50082 .49292 L
s
.66556 1.07421 m .66792 1.07183 L .67509 1.07354 L 0 0 0 r
F
0 g
.66764 1.07178 m
.66792 1.07183 L
s
.67545 .9281 m
.67655 .92714 L
s
.67545 .9281 m
.67546 .92768 L
s
.44791 1.01039 m .43742 1.00744 L .44282 1.01306 L 0 .727 .443 r
F
.44791 1.01039 m .4351 1.00244 L .43742 1.00744 L F
.81 .77345 m .82129 .78438 L .82138 .77158 L 0 1 .458 r
F
0 g
.81935 .79003 m
.82129 .78438 L
s
.82129 .78438 m
.82392 .79161 L
s
.42127 .76432 m .41031 .7673 L .40969 .76688 L 0 0 0 r
F
.42127 .76432 m .41422 .76694 L .41031 .7673 L F
.42127 .76432 m .41881 .76604 L .41422 .76694 L F
.42127 .76432 m .42183 .76492 L .41881 .76604 L F
0 g
.42127 .76432 m
.42434 .7628 L
s
.41737 .76468 m
.42127 .76432 L
s
.64711 .56977 m
.64924 .5803 L
s
.64655 .56702 m
.64711 .56977 L
s
.64588 .56372 m
.64655 .56702 L
s
.64523 .5605 m
.64588 .56372 L
s
.64455 .55718 m
.64523 .5605 L
s
.64451 .55694 m
.64455 .55718 L
s
.64451 .55693 m
.64451 .55694 L
s
.4457 .75845 m .43433 .76281 L .43715 .76083 L 0 0 0 r
F
.4457 .75845 m .43517 .76369 L .43433 .76281 L F
.4457 .75845 m .43915 .76307 L .43517 .76369 L F
0 g
.43334 .76159 m
.43646 .76097 L
s
.43646 .76097 m
.43715 .76083 L
s
.4457 .75845 m .44361 .76137 L .43915 .76307 L 0 0 0 r
F
.4457 .75845 m .44642 .75939 L .44361 .76137 L F
0 g
.4457 .75845 m
.44859 .75598 L
s
.44172 .75907 m
.4457 .75845 L
s
.54457 1.08229 m .54238 1.0815 L .54123 1.08028 L 0 0 0 r
F
.7873 .77825 m .78732 .79087 L .79073 .79956 L 0 1 .444 r
F
0 g
.78643 .80901 m
.79073 .79956 L
s
.43294 .51366 m .43985 .50617 L .44377 .5017 L 0 .879 .156 r
F
0 g
.43985 .50617 m
.44471 .50097 L
s
.81885 .9011 m .81574 .90589 L .8167 .90973 L 0 1 .516 r
F
0 g
.81014 .91297 m
.8167 .90973 L
s
.48408 .96176 m .47996 .96033 L .47569 .96006 L 0 1 .47 r
F
.45757 .64345 m .46035 .61967 L .45555 .62308 L 0 1 .335 r
F
0 g
.46035 .61967 m
.46204 .60901 L
s
.42415 .9813 m .41718 .98379 L .42271 .98768 L 0 .839 .444 r
F
.42415 .9813 m .4125 .97758 L .41718 .98379 L F
.39869 .6922 m .38852 .69251 L .3897 .69482 L 0 1 .512 r
F
.39869 .6922 m .39107 .68929 L .38852 .69251 L F
.39869 .6922 m .39593 .6868 L .39107 .68929 L F
.39869 .6922 m .39986 .6867 L .39593 .6868 L F
.39869 .6922 m .40104 .68902 L .39986 .6867 L F
0 g
.39383 .69468 m
.39869 .6922 L
s
.53153 .90911 m .53128 .92264 L .53459 .92841 L 0 .215 .264 r
F
0 g
.5286 .91427 m
.53128 .92264 L
s
.52947 .92291 m
.53128 .92264 L
s
.20817 .71765 m .19675 .71716 L .19899 .72374 L 0 1 .528 r
F
0 g
.1954 .73015 m
.19899 .72374 L
s
.44791 1.01039 m .44282 1.01306 L .44831 1.01647 L 0 .727 .443 r
F
.46528 .56789 m .45814 .57068 L .45985 .57327 L 0 1 .322 r
F
.46528 .56789 m .46134 .5617 L .45814 .57068 L F
.46528 .56789 m .46731 .55232 L .46134 .5617 L F
.33205 .59714 m .3199 .59909 L .32484 .60058 L 0 1 .496 r
F
0 g
.33137 .60236 m
.33206 .59714 L
s
.32484 .60058 m
.32561 .60736 L
s
.3162 .88383 m .31073 .89107 L .31478 .89058 L 0 1 .461 r
F
.3162 .88383 m .30598 .88493 L .31073 .89107 L F
0 g
.31005 .89777 m
.31073 .89107 L
s
.31478 .89058 m
.32004 .89643 L
s
.77763 .90938 m .78819 .90734 L .7838 .90696 L 0 1 .5 r
F
.76676 .9081 m .77763 .90938 L .7772 .90638 L 0 1 .488 r
F
0 g
.7041 .89833 m
.7043 .89801 L
s
.7059 .89561 m
.70736 .89341 L
s
.51012 .73066 m
.51133 .71017 L
s
.78881 1.05248 m .79154 1.05428 L .79852 1.05001 L 0 1 .276 r
F
0 g
.78354 1.05797 m
.79154 1.05428 L
s
.41496 .68374 m .40588 .68644 L .40996 .6862 L 0 1 .489 r
F
.41496 .68374 m .40494 .68435 L .40588 .68644 L F
0 g
.40996 .6862 m
.4114 .68837 L
s
.41496 .68374 m .40777 .68132 L .40494 .68435 L 0 1 .489 r
F
.41496 .68374 m .41278 .67885 L .40777 .68132 L F
.41496 .68374 m .41661 .67861 L .41278 .67885 L F
.41496 .68374 m .41754 .6807 L .41661 .67861 L F
0 g
.41496 .68374 m
.41607 .68574 L
s
.40996 .6862 m
.41496 .68374 L
s
.3851 .69751 m
.3897 .69482 L
s
.51756 1.0721 m .51093 1.06864 L .50581 1.0665 L 0 .427 .237 r
F
.50178 1.06177 m .49441 1.05921 L .501 1.06312 L 0 .419 .312 r
F
.50178 1.06177 m .48992 1.0557 L .49441 1.05921 L F
0 g
.48901 1.05697 m
.49441 1.05921 L
s
.33117 .77379 m .32068 .77175 L .32047 .77382 L 0 1 .382 r
F
.33117 .77379 m .32404 .77037 L .32068 .77175 L F
.33117 .77379 m .32832 .7706 L .32404 .77037 L F
.33117 .77379 m .33137 .77207 L .32832 .7706 L F
0 g
.32781 .77516 m
.33117 .77379 L
s
.33117 .77379 m
.33423 .77495 L
s
.68521 .62331 m .68927 .62263 L .6952 .62214 L 0 0 0 r
F
0 g
.68927 .62263 m
.69269 .62235 L
s
.68927 .62263 m
.68941 .62236 L
s
.69494 .62301 m
.69509 .62251 L
s
.69509 .62251 m
.6951 .62248 L
s
.2811 .90364 m .27558 .90919 L .27989 .90871 L 0 1 .53 r
F
.2811 .90364 m .2702 .90468 L .27558 .90919 L F
0 g
.27523 .91426 m
.27558 .90919 L
s
.27989 .90871 m
.28588 .91289 L
s
.24781 .92184 m .24273 .92581 L .24704 .9254 L 0 1 .518 r
F
.24781 .92184 m .23694 .92267 L .24273 .92581 L F
0 g
.24273 .92581 m
.24292 .92942 L
s
.24704 .9254 m
.249 .92623 L
s
.70251 .90099 m
.70759 .9011 L
s
.42415 .9813 m .41125 .97223 L .4125 .97758 L 0 .839 .444 r
F
.50964 .88699 m .51072 .88151 L .51092 .88382 L 0 0 .018 r
F
.51444 .88207 m .51092 .88382 L .51072 .88151 L 0 0 .016 r
F
0 g
.51072 .88151 m
.51236 .87792 L
s
.50877 .8815 m
.51072 .88151 L
s
.75949 .61753 m .77398 .60649 L .77424 .6121 L 0 .124 .042 r
F
0 g
.77398 .60649 m
.77947 .60386 L
s
.45373 .91011 m .44618 .91273 L .44301 .91339 L 0 0 0 r
F
.45373 .91011 m .45078 .91133 L .44618 .91273 L F
.46104 .90894 m .45373 .91011 L .45805 .90883 L F
.46104 .90894 m .45078 .91133 L .45373 .91011 L F
0 g
.45373 .91011 m
.45383 .9098 L
s
.36926 .9183 m .36498 .92496 L .36867 .92432 L 0 1 .445 r
F
.36926 .9183 m .35986 .91979 L .36498 .92496 L F
.37759 .93633 m .36867 .92432 L .36498 .92496 L 0 1 .449 r
F
.36921 .92067 m .36498 .92496 L .36867 .92432 L 0 1 .527 r
F
.36915 .92303 m .36498 .92496 L .36867 .92432 L 0 .971 .329 r
F
.36921 .92067 m .35981 .92211 L .36498 .92496 L 0 1 .527 r
F
.36915 .92303 m .35975 .92444 L .36498 .92496 L 0 .971 .329 r
F
0 g
.36498 .92496 m
.36502 .9309 L
s
.4129 .93386 m .40948 .93769 L .41283 .93685 L 0 1 .527 r
F
.4129 .93386 m .40432 .93583 L .40948 .93769 L F
.42175 .94128 m .41283 .93685 L .40948 .93769 L 0 1 .529 r
F
0 g
.40948 .93769 m
.40996 .94061 L
s
.50284 .88715 m .50048 .88929 L .49786 .89035 L 0 0 0 r
F
.52167 .87422 m .52109 .87488 L .52119 .87284 L 0 0 .015 r
F
.46104 .90894 m .45805 .90883 L .46086 .90833 L 0 0 0 r
F
.46785 .90527 m .46086 .90833 L .45805 .90883 L F
0 g
.45805 .90883 m
.45832 .90811 L
s
.45373 .91011 m
.45805 .90883 L
s
.40969 .76688 m .40109 .76795 L .40574 .76716 L 0 0 0 r
F
0 g
.40574 .76716 m
.4091 .76637 L
s
.50097 .74137 m
.50134 .74028 L
s
.25652 .62898 m .24557 .62787 L .2459 .63592 L 0 1 .484 r
F
0 g
.24047 .64343 m
.2459 .63592 L
s
.24238 .71918 m .23246 .7109 L .23098 .71867 L 0 1 .528 r
F
.24238 .71918 m .23698 .70538 L .23246 .7109 L F
.24238 .71918 m .24151 .70582 L .23698 .70538 L F
.24238 .71918 m .24382 .71174 L .24151 .70582 L F
0 g
.23813 .72435 m
.24238 .71918 L
s
.24238 .71918 m
.24472 .72482 L
s
.32243 .92382 m .31799 .92652 L .32188 .92599 L 0 1 .456 r
F
.32243 .92382 m .31259 .92495 L .31799 .92652 L F
0 g
.31799 .92652 m
.31819 .92871 L
s
.32188 .92599 m
.32774 .92718 L
s
.45476 .75598 m
.4587 .755 L
s
.45476 .75598 m
.45765 .75351 L
s
.3725 .70109 m .36235 .70085 L .36371 .70365 L 0 1 .531 r
F
0 g
.35941 .70661 m
.36371 .70365 L
s
.69831 .607 m
.69906 .62207 L
s
.6983 .60694 m
.69831 .607 L
s
.70559 .6219 m
.70565 .62201 L
s
.70544 .62159 m
.70559 .6219 L
s
.69831 .60694 m
.70533 .62135 L
s
.70533 .62135 m
.70544 .62159 L
s
.35986 .91979 m .35147 .90698 L .34758 .90751 L 0 1 .451 r
F
.35986 .91979 m .35674 .91224 L .35147 .90698 L F
.36926 .9183 m .35674 .91224 L .35986 .91979 L 0 1 .445 r
F
0 g
.3597 .92209 m
.35986 .91979 L
s
.35986 .91979 m
.36185 .9218 L
s
.40432 .93583 m .39538 .93055 L .39176 .93129 L 0 1 .529 r
F
.40432 .93583 m .40077 .9325 L .39538 .93055 L F
.4129 .93386 m .40077 .9325 L .40432 .93583 L 0 1 .527 r
F
0 g
.40432 .93583 m
.40948 .93769 L
s
.40432 .93583 m
.40447 .93902 L
s
.29969 .92654 m .28587 .92192 L .28546 .92464 L 0 1 .489 r
F
.29969 .92654 m .2902 .92158 L .28587 .92192 L F
.29969 .92654 m .29613 .92356 L .2902 .92158 L F
0 g
.29926 .92924 m
.29969 .92654 L
s
.31259 .92495 m .29613 .92356 L .2997 .92654 L 0 1 .473 r
F
0 g
.2997 .92654 m
.30617 .92822 L
s
.40579 .96807 m .40153 .96159 L .39594 .95736 L 0 .928 .45 r
F
0 g
.39594 .95736 m
.40153 .96159 L
s
.40579 .96807 m
.40681 .97365 L
s
.36162 .58763 m .35292 .58786 L .35176 .59001 L 0 1 .25 r
F
.36162 .58763 m .35804 .58545 L .35292 .58786 L F
.36162 .58763 m .36438 .5826 L .35804 .58545 L F
.36439 .5826 m .36319 .58338 L .36439 .5826 L 0 .85 .171 r
F
.37145 .5792 m .36439 .5826 L .36771 .58122 L F
.37145 .5792 m .36648 .58171 L .36439 .5826 L F
.36162 .58763 m .36771 .58123 L .36438 .5826 L 0 1 .25 r
F
.36648 .58171 m .36319 .58338 L .36439 .5826 L 0 .85 .171 r
F
.36162 .58763 m .36652 .58339 L .36771 .58123 L 0 1 .25 r
F
0 g
.3553 .59047 m
.36162 .58763 L
s
.36061 .59077 m
.36162 .58763 L
s
.55476 .72647 m
.55481 .72809 L
s
.55476 .72645 m
.55476 .72647 L
s
.55476 .72644 m
.55476 .72645 L
s
.55476 .72644 m
.55476 .72644 L
s
.55459 .72062 m
.55476 .72644 L
s
.55136 .72318 m
.55459 .72062 L
s
.75038 .83445 m
.75183 .83093 L
s
.4913 .8972 m .49019 .89489 L .49177 .89543 L 0 0 0 r
F
.49699 .89237 m .49177 .89543 L .49019 .89489 L F
0 g
.49019 .89489 m
.49107 .89287 L
s
.48701 .89595 m
.49019 .89489 L
s
.73821 .61486 m .75253 .60713 L .74884 .61639 L 0 .227 .079 r
F
0 g
.75197 .59878 m
.75253 .60713 L
s
.75253 .60713 m
.75857 .60142 L
s
.76209 1.06306 m .77425 1.05975 L .77053 1.06056 L 0 .825 .246 r
F
.75298 1.06506 m .76209 1.06306 L .76495 1.06187 L 0 .778 .23 r
F
.54737 .45022 m .54225 .4571 L .54161 .45331 L 0 .238 .071 r
F
.5474 .45588 m .54228 .46153 L .54165 .46049 L 0 0 .019 r
F
.5474 .45588 m .54898 .45857 L .54228 .46153 L F
.54898 .45857 m .54934 .46043 L .54776 .45969 L 0 .238 .071 r
F
.54898 .45857 m .54933 .45917 L .54776 .45969 L 0 0 .019 r
F
.54898 .45857 m .54776 .45969 L .54228 .46153 L F
.54737 .45022 m .54898 .45857 L .54225 .4571 L 0 .238 .071 r
F
.54898 .45857 m .54776 .45969 L .54225 .4571 L F
0 g
.54065 .44713 m
.54737 .45022 L
s
.37759 .93633 m .37408 .9292 L .36867 .92432 L 0 1 .449 r
F
0 g
.36872 .92432 m
.36879 .92432 L
s
.36867 .92432 m
.36872 .92432 L
s
.38643 .93462 m .37759 .93633 L .38281 .94114 L 0 1 .442 r
F
.38643 .93462 m .37408 .9292 L .37759 .93633 L F
0 g
.37759 .93633 m
.37762 .94227 L
s
.79865 .77564 m .80996 .78617 L .81 .77345 L 0 1 .452 r
F
0 g
.80992 .78627 m
.80996 .78617 L
s
.80996 .78617 m
.81001 .78631 L
s
.46088 1.02394 m .45113 1.02123 L .45681 1.02653 L 0 .651 .435 r
F
.46088 1.02394 m .44831 1.01647 L .45113 1.02123 L F
.38656 .56815 m .37679 .5757 L .38001 .57412 L 0 1 .211 r
F
.38656 .56815 m .37875 .57231 L .37679 .5757 L F
0 g
.38 .57412 m
.38123 .57422 L
s
.38656 .56815 m .38459 .56619 L .37875 .57231 L 0 1 .211 r
F
.38656 .56815 m .39116 .56021 L .38459 .56619 L F
.38656 .56815 m .39406 .55836 L .39116 .56021 L F
.38656 .56815 m .39208 .56177 L .39406 .55836 L F
0 g
.39208 .56177 m
.39838 .55577 L
s
.38482 .57197 m
.38656 .56815 L
s
.38001 .57412 m
.38656 .56815 L
s
.72063 .90185 m .73092 .90585 L .73406 .90387 L 0 .872 .36 r
F
0 g
.72465 .90643 m
.73092 .90585 L
s
.36882 .92439 m
.3689 .92443 L
s
.36867 .92432 m
.36882 .92439 L
s
.3689 .92443 m
.37072 .92526 L
s
.38654 .92901 m .37422 .9234 L .37413 .92683 L 0 1 .528 r
F
0 g
.37072 .92526 m
.37413 .92683 L
s
.36879 .92432 m
.36888 .92433 L
s
.36888 .92433 m
.37418 .92447 L
s
.32047 .77382 m .30998 .7713 L .30978 .77371 L 0 1 .42 r
F
.32047 .77382 m .31334 .7697 L .30998 .7713 L F
.32047 .77382 m .31762 .76999 L .31334 .7697 L F
.32047 .77382 m .32068 .77175 L .31762 .76999 L F
0 g
.31711 .77541 m
.32047 .77382 L
s
.32047 .77382 m
.32353 .77527 L
s
.44655 .91298 m .44301 .91339 L .44618 .91273 L 0 0 0 r
F
.44655 .91298 m .43836 .9145 L .44301 .91339 L F
0 g
.44301 .91339 m
.44312 .91307 L
s
.34575 .59393 m
.35176 .59001 L
s
.79895 .78224 m .80996 .7863 L .81066 .78699 L 0 0 0 r
F
0 g
.80992 .78627 m
.80996 .7863 L
s
.80996 .7863 m
.81001 .78631 L
s
.42175 .94128 m .41809 .93839 L .41283 .93685 L 0 1 .529 r
F
0 g
.42175 .94128 m
.42222 .9442 L
s
.42991 .93908 m .42175 .94128 L .42687 .94275 L 0 1 .525 r
F
.42991 .93908 m .41809 .93839 L .42175 .94128 L F
.43646 .6694 m .42962 .67072 L .43314 .67036 L 0 1 .449 r
F
.43646 .6694 m .42774 .6703 L .42962 .67072 L F
0 g
.43314 .67036 m
.43314 .67037 L
s
.43314 .67037 m
.43375 .67233 L
s
.43646 .6694 m .42876 .66938 L .42774 .6703 L 0 1 .449 r
F
.43646 .6694 m .43209 .66841 L .42876 .66938 L F
.43646 .6694 m .4355 .66805 L .43209 .66841 L F
.43646 .6694 m .43738 .66847 L .4355 .66805 L F
0 g
.43646 .6694 m
.43841 .66978 L
s
.43314 .67036 m
.43646 .6694 L
s
.43738 .66847 m
.44062 .66746 L
s
.31597 .70863 m .30709 .71188 L .31131 .71219 L 0 1 .535 r
F
0 g
.31131 .71219 m
.31359 .71642 L
s
.69829 .57559 m
.70577 .59091 L
s
.69752 .56492 m
.69829 .57559 L
s
.51756 1.0721 m .52297 1.07475 L .52273 1.07472 L 0 .427 .237 r
F
0 g
.51784 1.0726 m
.52191 1.07431 L
s
.53413 1.08038 m .52273 1.07472 L .52297 1.07475 L 0 0 0 r
F
0 g
.52297 1.07475 m
.52842 1.07661 L
s
.3725 .70109 m .36464 .69717 L .36235 .70085 L 0 1 .531 r
F
.3725 .70109 m .36934 .69454 L .36464 .69717 L F
.3725 .70109 m .3733 .69472 L .36934 .69454 L F
.3725 .70109 m .37465 .69753 L .3733 .69472 L F
0 g
.36927 .70289 m
.3725 .70109 L
s
.77597 .78136 m .78396 .80123 L .78732 .79087 L 0 1 .436 r
F
.77597 .78136 m .77945 .80245 L .78396 .80123 L F
0 g
.78396 .80123 m
.78643 .80901 L
s
.45481 .94875 m .45323 .95213 L .45565 .95111 L 0 1 .516 r
F
.4641 .95367 m .45565 .95111 L .45323 .95213 L 0 1 .509 r
F
0 g
.45323 .95213 m
.45457 .95436 L
s
.44846 .95123 m
.45323 .95213 L
s
.45481 .94875 m .44366 .94664 L .44451 .949 L 0 1 .516 r
F
0 g
.43945 .94814 m
.44451 .949 L
s
.53725 .73038 m
.53888 .73272 L
s
.46377 .65705 m .45668 .65419 L .45929 .65951 L 0 1 .326 r
F
.46995 .67392 m .46377 .65705 L .46319 .66841 L 0 1 .318 r
F
.4136 .96581 m .40579 .96807 L .41125 .97223 L 0 .884 .441 r
F
.4136 .96581 m .40153 .96159 L .40579 .96807 L F
.50487 .89169 m .50284 .88715 L .5051 .88698 L 0 0 .02 r
F
.50487 .89169 m .50048 .88929 L .50284 .88715 L F
0 g
.50284 .88715 m
.5041 .88482 L
s
.29846 .61008 m .288 .6078 L .28776 .6154 L 0 1 .48 r
F
0 g
.2819 .6219 m
.28776 .6154 L
s
.80766 .90084 m .81013 .90919 L .81574 .90589 L 0 1 .508 r
F
.80766 .90084 m .80575 .90882 L .81013 .90919 L F
0 g
.81013 .90919 m
.81014 .91297 L
s
.4913 .8972 m .48387 .89966 L .48435 .89789 L 0 0 0 r
F
0 g
.48084 .89946 m
.48435 .89789 L
s
.63055 .6779 m .64041 .68827 L .63447 .64989 L 0 .44 .248 r
F
0 g
.63893 .67874 m
.64024 .68718 L
s
.6359 .65918 m
.63893 .67874 L
s
.64024 .68718 m
.64037 .68807 L
s
.64037 .68807 m
.64038 .68809 L
s
.64038 .68809 m
.64041 .68827 L
s
.6269 .63985 m
.63055 .6779 L
s
.63055 .6779 m
.63057 .64335 L
s
.55125 .73042 m
.55125 .73042 L
s
.38643 .93462 m .38281 .94114 L .38628 .94041 L 0 1 .442 r
F
.3955 .95167 m .38628 .94041 L .38281 .94114 L 0 .965 .446 r
F
0 g
.38281 .94114 m
.38326 .94684 L
s
.37759 .93633 m
.38281 .94114 L
s
.43294 .51366 m .42404 .52174 L .42617 .52033 L 0 .879 .156 r
F
0 g
.42769 .51988 m
.42934 .51812 L
s
.43294 .51366 m .42795 .51727 L .42404 .52174 L 0 .879 .156 r
F
.43294 .51366 m .43529 .5099 L .42795 .51727 L F
.43294 .51366 m .44207 .50323 L .43529 .5099 L F
.43294 .51366 m .44377 .5017 L .44207 .50323 L F
0 g
.43985 .50617 m
.4437 .50177 L
s
.42934 .51812 m
.43294 .51366 L
s
.21523 .92442 m .20086 .91561 L .20047 .91986 L 0 1 .528 r
F
.21523 .92442 m .20531 .91545 L .20086 .91561 L F
.21523 .92442 m .21147 .91923 L .20531 .91545 L F
.22608 .92353 m .21147 .91923 L .21523 .92442 L 0 1 .525 r
F
0 g
.21481 .92863 m
.21523 .92442 L
s
.21523 .92442 m
.22125 .92796 L
s
.29846 .61008 m .29258 .59841 L .288 .6078 L 0 1 .48 r
F
.29846 .61008 m .29905 .59232 L .29258 .59841 L F
.29846 .61008 m .30309 .59363 L .29905 .59232 L F
.29846 .61008 m .30283 .60125 L .30309 .59363 L F
0 g
.29837 .61724 m
.29846 .61008 L
s
.29201 .61614 m
.29846 .61008 L
s
.46995 .67392 m .46319 .66841 L .46579 .67496 L 0 1 .318 r
F
.47609 .69506 m .46995 .67392 L .46967 .68601 L 0 1 .311 r
F
.48222 .72156 m .47861 .68806 L .47609 .69506 L 0 1 .305 r
F
0 g
.48214 .69047 m
.4825 .67739 L
s
.48222 .72156 m .48212 .69141 L .47861 .68806 L 0 1 .305 r
F
0 g
.47861 .68806 m
.47888 .67598 L
s
.529 .88749 m
.52908 .88778 L
s
.52908 .88778 m
.52966 .89 L
s
.48756 .70715 m .48212 .69141 L .48427 .70287 L 0 1 .299 r
F
.48222 .72156 m .48427 .70287 L .48212 .69141 L 0 1 .305 r
F
0 g
.48212 .69141 m
.48214 .69047 L
s
.47861 .68806 m
.48212 .69141 L
s
.45685 .59944 m .46241 .57747 L .45715 .58225 L 0 1 .343 r
F
0 g
.46241 .57747 m
.46528 .56789 L
s
.30978 .77371 m .29928 .77074 L .29908 .77351 L 0 1 .45 r
F
.30978 .77371 m .30264 .7689 L .29928 .77074 L F
0 g
.29908 .77351 m
.30214 .77557 L
s
.30978 .77371 m .30692 .76923 L .30264 .7689 L 0 1 .45 r
F
.30978 .77371 m .30998 .7713 L .30692 .76923 L F
0 g
.30642 .77554 m
.30978 .77371 L
s
.30978 .77371 m
.31284 .77547 L
s
.47369 .53387 m .48461 .51698 L .48383 .51592 L 0 1 .25 r
F
.47369 .53387 m .48026 .52467 L .48461 .51698 L F
0 g
.48461 .51698 m
.4902 .51063 L
s
.48026 .52467 m
.48577 .51874 L
s
.48026 .52467 m
.48461 .51698 L
s
.43836 .9145 m .43044 .91645 L .42694 .91713 L 0 0 0 r
F
.43836 .9145 m .43534 .91532 L .43044 .91645 L F
.44655 .91298 m .43534 .91532 L .43836 .9145 L F
0 g
.43836 .9145 m
.44301 .91339 L
s
.49659 .96299 m .49457 .96495 L .49825 .96529 L 0 .812 .396 r
F
.49659 .96299 m .49034 .96374 L .49457 .96495 L F
0 g
.49457 .96495 m
.49724 .96652 L
s
.50611 .96602 m .50096 .9666 L .50525 .96761 L 0 .659 .324 r
F
.50611 .96602 m .49825 .96529 L .50096 .9666 L F
0 g
.49724 .96652 m
.50096 .9666 L
s
.42991 .93908 m .42687 .94275 L .43003 .94182 L 0 1 .525 r
F
.43881 .94547 m .43003 .94182 L .42687 .94275 L 0 1 .526 r
F
0 g
.42687 .94275 m
.42751 .94542 L
s
.42175 .94128 m
.42687 .94275 L
s
.5476 .80023 m
.54782 .80141 L
s
.46785 .90527 m .46507 .9068 L .46086 .90833 L 0 0 0 r
F
.47423 .90488 m .46785 .90527 L .47176 .904 L F
.47423 .90488 m .46507 .9068 L .46785 .90527 L F
0 g
.46785 .90527 m
.46812 .90455 L
s
.48557 .46785 m .47817 .47545 L .47897 .47342 L 0 0 .012 r
F
0 g
.47872 .47156 m
.48017 .47013 L
s
.48557 .46785 m .48393 .4734 L .47817 .47545 L 0 0 .012 r
F
.48557 .46785 m .49239 .46863 L .48393 .4734 L F
.48557 .46785 m .49898 .46305 L .49239 .46863 L F
.48557 .46785 m .49931 .4604 L .49898 .46305 L F
0 g
.48017 .47013 m
.48557 .46785 L
s
.49931 .4604 m
.50558 .45509 L
s
.49356 .46246 m
.49931 .4604 L
s
.46088 1.02394 m .45681 1.02653 L .4622 1.02973 L 0 .651 .435 r
F
.3958 .92731 m .39176 .93129 L .39538 .93055 L 0 1 .526 r
F
.3958 .92731 m .38654 .92901 L .39176 .93129 L F
0 g
.39176 .93129 m
.39192 .93449 L
s
.49659 .96299 m .48802 .96219 L .49034 .96374 L 0 .812 .396 r
F
0 g
.48633 .96359 m
.49034 .96374 L
s
.33205 .59714 m .31995 .5923 L .3199 .59909 L 0 1 .496 r
F
0 g
.31306 .60414 m
.3199 .59909 L
s
.33205 .59714 m .32497 .58475 L .31995 .5923 L 0 1 .496 r
F
.33205 .59714 m .33221 .58129 L .32497 .58475 L F
.33205 .59714 m .33681 .58424 L .33221 .58129 L F
.33205 .59714 m .33674 .59104 L .33681 .58424 L F
0 g
.32484 .60058 m
.33205 .59714 L
s
.48853 .74876 m
.48897 .74817 L
s
.48897 .74817 m
.49167 .74456 L
s
.49167 .74456 m
.4923 .74183 L
s
.40969 .76688 m .39811 .76871 L .40109 .76795 L 0 0 0 r
F
0 g
.39746 .76852 m
.40109 .76795 L
s
.7549 .75867 m
.75586 .75811 L
s
.50611 .96602 m .50525 .96761 L .50863 .96792 L 0 .659 .324 r
F
0 g
.50525 .96761 m
.50832 .96889 L
s
.49819 .61848 m .50253 .61501 L .50552 .61372 L 0 0 0 r
F
0 g
.50253 .61501 m
.50412 .61328 L
s
.35255 .90073 m .34758 .90751 L .35147 .90698 L 0 1 .447 r
F
.35255 .90073 m .34269 .90195 L .34758 .90751 L F
0 g
.34716 .9137 m
.34758 .90751 L
s
.53198 .7448 m
.53207 .71935 L
s
.53198 .74513 m
.53198 .7448 L
s
.53413 1.08038 m .53546 1.07907 L .54025 1.08148 L 0 0 0 r
F
0 g
.53546 1.07907 m
.54123 1.08028 L
s
.64198 .54826 m
.64362 .55389 L
s
.6454 .56003 m
.64633 .56321 L
s
.64414 .55568 m
.6454 .56003 L
s
.64364 .55395 m
.64414 .55568 L
s
.64362 .55389 m
.64364 .55395 L
s
.64633 .56321 m
.64813 .5694 L
s
.6487 .57136 m
.64879 .57168 L
s
.64813 .5694 m
.6487 .57136 L
s
.29908 .77351 m .28523 .76989 L .28504 .77314 L 0 1 .473 r
F
.29908 .77351 m .28959 .76781 L .28523 .76989 L F
0 g
.28504 .77314 m
.28808 .77496 L
s
.29908 .77351 m .29521 .76829 L .28959 .76781 L 0 1 .473 r
F
.29908 .77351 m .29928 .77074 L .29521 .76829 L F
0 g
.29472 .77558 m
.29908 .77351 L
s
.53003 .88354 m
.53049 .8856 L
s
.49261 .74394 m .48977 .70137 L .48756 .70715 L 0 .923 .295 r
F
0 g
.48562 .74696 m
.48895 .74321 L
s
.48562 .74696 m
.48775 .74298 L
s
.49261 .74394 m .49271 .70896 L .48977 .70137 L 0 .923 .295 r
F
0 g
.48977 .70137 m
.49014 .68734 L
s
.31597 .70863 m .30551 .7076 L .30709 .71188 L 0 1 .535 r
F
0 g
.30302 .71589 m
.30709 .71188 L
s
.25652 .62898 m .24957 .61748 L .24557 .62787 L 0 1 .484 r
F
.25652 .62898 m .25579 .61015 L .24957 .61748 L F
.25652 .62898 m .26007 .6108 L .25579 .61015 L F
.25652 .62898 m .26037 .61888 L .26007 .6108 L F
0 g
.25652 .62898 m
.25694 .6368 L
s
.25032 .63627 m
.25652 .62898 L
s
.4136 .96581 m .40084 .9561 L .40153 .96159 L 0 .884 .441 r
F
.48643 1.0509 m .48992 1.0557 L .49053 1.05493 L 0 .531 .397 r
F
.50178 1.06177 m .49053 1.05493 L .48992 1.0557 L 0 .419 .312 r
F
0 g
.48992 1.0557 m
.49441 1.05921 L
s
.4846 1.05298 m
.48992 1.0557 L
s
.47389 .95801 m .46992 .95635 L .46543 .9559 L 0 1 .494 r
F
.42415 .9813 m .42271 .98768 L .42539 .98666 L 0 .839 .444 r
F
.43562 .99617 m .42539 .98666 L .42271 .98768 L 0 .788 .445 r
F
0 g
.42271 .98768 m
.4245 .99288 L
s
.41718 .98379 m
.42271 .98768 L
s
.53225 .87495 m
.5323 .87516 L
s
.63061 .63305 m .63365 .62813 L .63025 .62562 L 0 .84 .347 r
F
.63061 .63305 m .63923 .63491 L .63365 .62813 L F
.63061 .63305 m .64326 .64143 L .63923 .63491 L F
0 g
.64288 .62377 m
.64401 .6333 L
s
.63061 .63305 m .63449 .64548 L .64006 .65226 L 0 .84 .347 r
F
0 g
.6303 .62673 m
.63061 .63305 L
s
.63447 .64989 m
.63448 .64548 L
s
.63447 .64989 m
.6359 .65918 L
s
.43562 .99617 m .4351 1.00244 L .43741 1.00137 L 0 .788 .445 r
F
.44791 1.01039 m .43741 1.00137 L .4351 1.00244 L 0 .727 .443 r
F
0 g
.4351 1.00244 m
.43742 1.00744 L
s
.42957 .9988 m
.4351 1.00244 L
s
.52802 .97193 m
.53054 .97238 L
s
.52731 .97181 m
.52802 .97193 L
s
.53232 .97261 m .53099 .9724 L .53054 .97238 L 0 .502 .203 r
F
0 g
.41754 .6807 m
.42235 .67816 L
s
.77597 .78136 m .77602 .79394 L .77945 .80245 L 0 1 .436 r
F
0 g
.77522 .81194 m
.77945 .80245 L
s
.25932 .90575 m .24624 .89442 L .24528 .89987 L 0 1 .532 r
F
.25932 .90575 m .2507 .89414 L .24624 .89442 L F
.25932 .90575 m .25631 .899 L .2507 .89414 L F
.2702 .90468 m .25631 .899 L .25932 .90575 L 0 1 .531 r
F
0 g
.25834 .91117 m
.25932 .90575 L
s
.25932 .90575 m
.2648 .91042 L
s
.40517 .92006 m .40097 .92135 L .4046 .92065 L 0 .722 .232 r
F
.40517 .92006 m .3959 .92162 L .40097 .92135 L F
0 g
.40095 .92193 m
.40097 .92135 L
s
.50178 1.06177 m .501 1.06312 L .50609 1.06573 L 0 .419 .312 r
F
0 g
.501 1.06312 m
.50581 1.0665 L
s
.48725 .95958 m .48408 .96176 L .48802 .96219 L 0 .927 .446 r
F
.48725 .95958 m .47996 .96033 L .48408 .96176 L F
0 g
.48408 .96176 m
.48633 .96359 L
s
.77549 .77001 m .78723 .77664 L .78662 .77655 L 0 .03 0 r
F
.77549 .77001 m .78662 .77655 L .781 .77395 L F
.77597 .78136 m .78644 .77612 L .781 .77395 L 0 1 .436 r
F
.781 .77395 m .78662 .77655 L .78416 .77621 L 0 .03 0 r
F
.77597 .78136 m .7873 .77825 L .78662 .77655 L 0 1 .436 r
F
.78608 .7763 m .78662 .77655 L .78644 .77612 L F
.77597 .78136 m .78662 .77655 L .78608 .7763 L F
.781 .77395 m .78644 .77612 L .78388 .76971 L F
.77549 .77001 m .781 .77395 L .77868 .77301 L 0 .03 0 r
F
.77868 .77301 m .78388 .76971 L .77934 .77097 L 0 1 .436 r
F
.77597 .78136 m .781 .77395 L .77868 .77301 L F
.781 .77395 m .78388 .76971 L .77868 .77301 L F
.77868 .77301 m .781 .77395 L .77871 .77304 L 0 .03 0 r
F
.77871 .77304 m .78416 .77621 L .77946 .77374 L F
.781 .77395 m .78416 .77621 L .77871 .77304 L F
.35981 .92211 m .34738 .91516 L .34702 .91902 L 0 1 .528 r
F
.35981 .92211 m .35128 .91468 L .34738 .91516 L F
.35981 .92211 m .35661 .91766 L .35128 .91468 L F
.36921 .92067 m .35661 .91766 L .35981 .92211 L 0 1 .527 r
F
0 g
.35958 .92444 m
.35981 .92211 L
s
.35981 .92211 m
.36311 .92393 L
s
.80766 .90084 m .80468 .90526 L .80575 .90882 L 0 1 .508 r
F
0 g
.79932 .9118 m
.80575 .90882 L
s
.30598 .88493 m .29239 .87055 L .29012 .87758 L 0 1 .466 r
F
.30598 .88493 m .29787 .87008 L .29239 .87055 L F
.30598 .88493 m .30369 .87625 L .29787 .87008 L F
0 g
.30371 .89194 m
.30598 .88493 L
s
.3162 .88383 m .3037 .87625 L .30598 .88493 L 0 1 .461 r
F
0 g
.30598 .88493 m
.31073 .89107 L
s
.48643 1.0509 m .48037 1.04631 L .47505 1.04359 L 0 .531 .397 r
F
0 g
.47505 1.04359 m
.48037 1.04631 L
s
.47139 1.03915 m
.47505 1.04359 L
s
.32643 .70948 m .31799 .70356 L .31597 .70863 L 0 1 .536 r
F
.32643 .70948 m .32259 .70017 L .31799 .70356 L F
.32643 .70948 m .32671 .70073 L .32259 .70017 L F
.32643 .70948 m .32835 .70472 L .32671 .70073 L F
0 g
.32184 .71285 m
.32643 .70948 L
s
.32643 .70948 m
.32815 .71316 L
s
.23098 .71867 m .2211 .71007 L .21958 .71815 L 0 1 .528 r
F
.23098 .71867 m .22564 .7043 L .2211 .71007 L F
.23098 .71867 m .23018 .70473 L .22564 .7043 L F
.23098 .71867 m .23246 .7109 L .23018 .70473 L F
0 g
.22645 .72439 m
.23098 .71867 L
s
.23098 .71867 m
.2333 .72455 L
s
.36867 .92432 m
.36874 .92438 L
s
.57101 .4498 m .57949 .44706 L .58737 .44731 L 0 .032 .023 r
F
0 g
.69325 .90921 m
.69334 .9091 L
s
.69276 .90704 m
.69325 .90921 L
s
.51571 .96873 m .51171 .96899 L .51602 .96983 L 0 .576 .25 r
F
.51571 .96873 m .50863 .96792 L .51171 .96899 L F
0 g
.50832 .96889 m
.51171 .96899 L
s
.32272 .91424 m .31026 .90557 L .30965 .91002 L 0 1 .529 r
F
.32272 .91424 m .31432 .90519 L .31026 .90557 L F
.32272 .91424 m .31966 .90891 L .31432 .90519 L F
.33256 .913 m .31966 .90891 L .32272 .91424 L 0 1 .528 r
F
0 g
.32272 .91424 m
.32792 .91781 L
s
.3221 .91868 m
.32272 .91424 L
s
.34269 .90195 m .33099 .88876 L .33004 .89517 L 0 1 .454 r
F
0 g
.65772 .63554 m
.65772 .6355 L
s
.65439 .63806 m
.65697 .6361 L
s
.65697 .6361 m
.65772 .63554 L
s
.76401 .8155 m .77269 .80446 L .76818 .80593 L 0 1 .445 r
F
.75281 .81982 m .76401 .8155 L .76143 .80836 L 0 1 .436 r
F
.70046 1.07542 m .6936 1.07457 L .69087 1.07371 L 0 0 0 r
F
0 g
.68282 1.07311 m
.69087 1.07371 L
s
.28504 .77314 m .2738 .76914 L .27361 .77278 L 0 1 .496 r
F
.28504 .77314 m .27737 .76671 L .2738 .76914 L F
.28504 .77314 m .28195 .76713 L .27737 .76671 L F
.28504 .77314 m .28523 .76989 L .28195 .76713 L F
0 g
.28147 .77555 m
.28504 .77314 L
s
.38654 .92901 m .37793 .92282 L .37422 .9234 L 0 1 .528 r
F
.38654 .92901 m .38321 .92523 L .37793 .92282 L F
0 g
.38644 .93243 m
.38654 .92901 L
s
.3958 .92731 m .38321 .92523 L .38654 .92901 L 0 1 .526 r
F
0 g
.38654 .92901 m
.39176 .93129 L
s
.47423 .90488 m .47176 .904 L .47419 .90384 L 0 0 0 r
F
.48046 .90066 m .47419 .90384 L .47176 .904 L F
0 g
.47176 .904 m
.47215 .9028 L
s
.46785 .90527 m
.47176 .904 L
s
.38643 .93462 m .37422 .9234 L .37408 .9292 L 0 1 .442 r
F
0 g
.36874 .92438 m
.37408 .9292 L
s
.37418 .92447 m
.37422 .92342 L
s
.37413 .92683 m
.37422 .92347 L
s
.50844 .71393 m
.51012 .73066 L
s
.50844 .71393 m
.50964 .69441 L
s
.77908 1.05533 m .77425 1.05975 L .78207 1.0563 L 0 .903 .246 r
F
.77908 1.05533 m .77053 1.06056 L .77425 1.05975 L F
0 g
.77118 1.06139 m
.77425 1.05975 L
s
.22542 .938 m .22068 .94035 L .22497 .94001 L 0 .902 .324 r
F
.22542 .938 m .21456 .9386 L .22068 .94035 L F
0 g
.22068 .94035 m
.22126 .94245 L
s
.22497 .94001 m
.22586 .94018 L
s
.48725 .95958 m .47805 .95858 L .47996 .96033 L 0 .927 .446 r
F
0 g
.47569 .96006 m
.47996 .96033 L
s
.76676 .9081 m .7772 .90638 L .7728 .90598 L 0 1 .488 r
F
.75587 .90677 m .76676 .9081 L .7662 .90537 L 0 1 .471 r
F
.42207 .91793 m .41017 .91967 L .40981 .92001 L 0 .683 .205 r
F
0 g
.40981 .92001 m
.40981 .92001 L
s
.69942 .62304 m
.70052 .62581 L
s
.69909 .62222 m
.69942 .62304 L
s
.70052 .62581 m
.70231 .63034 L
s
.7048 .6366 m
.705 .63711 L
s
.34269 .90195 m .33504 .88834 L .33099 .88876 L 0 1 .454 r
F
.34269 .90195 m .34006 .894 L .33504 .88834 L F
.35255 .90073 m .34006 .894 L .34269 .90195 L 0 1 .447 r
F
0 g
.34269 .90195 m
.34758 .90751 L
s
.34174 .90835 m
.34269 .90195 L
s
.69907 .62222 m
.69908 .623 L
s
.61077 .45058 m
.61897 .456 L
s
.60624 .4534 m
.61077 .45058 L
s
.5327 .59864 m .53032 .607 L .52964 .60368 L 0 .145 .077 r
F
.5327 .59864 m .53476 .60796 L .53032 .607 L F
.5327 .59864 m .54 .60592 L .53476 .60796 L F
.5327 .59864 m .54304 .60087 L .54 .60592 L F
.5327 .59864 m .54187 .59619 L .54304 .60087 L F
0 g
.52864 .59863 m
.5327 .59864 L
s
.54187 .59619 m
.54444 .58992 L
s
.53744 .59525 m
.54187 .59619 L
s
.45134 .63228 m .45705 .61333 L .45484 .60949 L 0 1 .346 r
F
.45134 .63228 m .45555 .62308 L .45705 .61333 L F
0 g
.45705 .61333 m
.46204 .60901 L
s
.32643 .88281 m .32085 .88987 L .3249 .88941 L 0 1 .456 r
F
.32643 .88281 m .3162 .88383 L .32085 .88987 L F
0 g
.32004 .89643 m
.32085 .88987 L
s
.3249 .88941 m
.33004 .89517 L
s
.70046 1.07542 m .70179 1.07335 L .70895 1.07357 L 0 0 0 r
F
0 g
.69405 1.07341 m
.70179 1.07335 L
s
.69881 1.07302 m
.70179 1.07335 L
s
.79665 .64442 m
.80147 .64801 L
s
.71742 1.07199 m .72912 1.07051 L .72565 1.0712 L 0 .607 .198 r
F
.70895 1.07357 m .71742 1.07199 L .72044 1.07231 L 0 0 0 r
F
.36926 .9183 m .35732 .90621 L .35674 .91224 L 0 1 .445 r
F
0 g
.35147 .90698 m
.35674 .91224 L
s
.24557 .62787 m .23483 .63505 L .23926 .6354 L 0 1 .486 r
F
0 g
.23926 .6354 m
.24047 .64343 L
s
.27361 .77278 m .26236 .76836 L .26218 .77238 L 0 1 .509 r
F
.27361 .77278 m .26593 .76565 L .26236 .76836 L F
.27361 .77278 m .2705 .76608 L .26593 .76565 L F
.27361 .77278 m .2738 .76914 L .2705 .76608 L F
0 g
.27005 .77546 m
.27361 .77278 L
s
.27361 .77278 m
.27631 .77502 L
s
.24744 .93852 m
.25308 .93926 L
s
.4136 .96581 m .41125 .97223 L .41428 .97129 L 0 .884 .441 r
F
.42415 .9813 m .41428 .97129 L .41125 .97223 L 0 .839 .444 r
F
0 g
.41125 .97223 m
.4125 .97758 L
s
.40579 .96807 m
.41125 .97223 L
s
.36235 .70085 m .35345 .70326 L .35755 .70345 L 0 1 .535 r
F
0 g
.35755 .70345 m
.35821 .7031 L
s
.35755 .70345 m
.35941 .70661 L
s
.62568 .50552 m .62474 .50716 L .62222 .49944 L 0 .416 0 r
F
0 g
.6223 .49959 m
.62541 .50505 L
s
.62222 .49944 m
.6223 .49959 L
s
.62099 .49726 m
.62222 .49944 L
s
.62568 .50552 m .63228 .5251 L .62474 .50716 L 0 .416 0 r
F
0 g
.62055 .49203 m
.62568 .50552 L
s
.62541 .50505 m
.62568 .50552 L
s
.51571 .96873 m .51602 .96983 L .51906 .97018 L 0 .576 .25 r
F
0 g
.51602 .96983 m
.51946 .97081 L
s
.44045 .66552 m .43209 .66841 L .43551 .66805 L 0 1 .404 r
F
.44045 .66552 m .43217 .66646 L .43209 .66841 L F
0 g
.4355 .66805 m
.43552 .66805 L
s
.43552 .66805 m
.43738 .66847 L
s
.44045 .66552 m .4357 .6635 L .43217 .66646 L 0 1 .404 r
F
.44045 .66552 m .44065 .66097 L .4357 .6635 L F
.44045 .66552 m .44371 .66057 L .44065 .66097 L F
.44045 .66552 m .44362 .66252 L .44371 .66057 L F
0 g
.44362 .66252 m
.4483 .65994 L
s
.44045 .66552 m
.44062 .66746 L
s
.43551 .66805 m
.44045 .66552 L
s
.41632 .53269 m .42285 .52502 L .42617 .52033 L 0 1 .192 r
F
0 g
.42285 .52502 m
.42769 .51988 L
s
.2889 .9369 m .27455 .93653 L .27437 .93733 L 0 .698 .232 r
F
.2889 .9369 m .27888 .93628 L .27455 .93653 L F
.2889 .9369 m .28503 .93644 L .27888 .93628 L F
.29938 .93573 m .28503 .93644 L .2889 .9369 L 0 .653 .215 r
F
0 g
.28868 .9377 m
.2889 .9369 L
s
.2889 .9369 m
.29488 .93682 L
s
.49171 .75044 m
.49265 .74589 L
s
.54075 .97389 m .5365 .97324 L .53397 .97283 L 0 0 0 r
F
.4744 1.03682 m .46549 1.0342 L .47139 1.03915 L 0 .55 .414 r
F
.4744 1.03682 m .4622 1.02973 L .46549 1.0342 L F
.44791 1.01039 m .44831 1.01647 L .45022 1.0154 L 0 .727 .443 r
F
.46088 1.02394 m .45022 1.0154 L .44831 1.01647 L 0 .651 .435 r
F
0 g
.44831 1.01647 m
.45113 1.02123 L
s
.44282 1.01306 m
.44831 1.01647 L
s
.34242 .91185 m .33764 .91644 L .34154 .91592 L 0 1 .526 r
F
.34242 .91185 m .33256 .913 L .33764 .91644 L F
0 g
.33744 .92049 m
.33764 .91644 L
s
.34154 .91592 m
.34394 .91728 L
s
.34394 .91728 m
.34702 .91902 L
s
.41283 .93685 m
.41556 .93765 L
s
.41556 .93765 m
.41809 .93839 L
s
.40104 .68902 m
.40588 .68644 L
s
.55539 .59494 m
.56031 .59889 L
s
.55284 .60124 m
.55539 .59494 L
s
.50487 .89169 m .49957 .89208 L .50048 .88929 L 0 0 .02 r
F
0 g
.49786 .89035 m
.50048 .88929 L
s
.29201 .90266 m .28637 .908 L .29069 .90754 L 0 1 .529 r
F
.29201 .90266 m .2811 .90364 L .28637 .908 L F
0 g
.28588 .91289 m
.28637 .908 L
s
.29069 .90754 m
.29642 .91149 L
s
.29642 .91149 m
.29654 .91156 L
s
.26218 .77238 m .25092 .76756 L .25075 .77196 L 0 1 .519 r
F
.26218 .77238 m .25448 .76457 L .25092 .76756 L F
.26218 .77238 m .25906 .765 L .25448 .76457 L F
.26218 .77238 m .26236 .76836 L .25906 .765 L F
0 g
.25862 .77534 m
.26218 .77238 L
s
.26218 .77238 m
.26492 .7749 L
s
.2587 .92105 m .2535 .92478 L .25781 .92438 L 0 1 .513 r
F
.2587 .92105 m .24781 .92184 L .2535 .92478 L F
0 g
.2535 .92478 m
.25353 .92817 L
s
.25781 .92438 m
.25993 .92524 L
s
.45757 .64345 m .45014 .64249 L .45276 .6469 L 0 1 .335 r
F
.45757 .64345 m .45134 .63228 L .45014 .64249 L F
.45757 .64345 m .45555 .62308 L .45134 .63228 L F
0 g
.45555 .62308 m
.45705 .61333 L
s
.45555 .62308 m
.46035 .61967 L
s
.45687 .65195 m
.45687 .65187 L
s
.45687 .65187 m
.45688 .65186 L
s
.45688 .65186 m
.45757 .64345 L
s
.3955 .95167 m .39172 .94493 L .38628 .94041 L 0 .965 .446 r
F
0 g
.3955 .95167 m
.39594 .95736 L
s
.40408 .9497 m .3955 .95167 L .40084 .9561 L 0 .925 .437 r
F
.40408 .9497 m .39172 .94493 L .3955 .95167 L F
.39811 .76871 m .38946 .76951 L .39411 .76896 L 0 0 0 r
F
0 g
.39411 .76896 m
.39746 .76852 L
s
.42991 .93908 m .41796 .93565 L .41809 .93839 L 0 1 .525 r
F
0 g
.40494 .68435 m
.40588 .68644 L
s
.73469 1.07015 m .72912 1.07051 L .73691 1.06889 L 0 0 0 r
F
.73469 1.07015 m .72565 1.0712 L .72912 1.07051 L F
0 g
.72586 1.07068 m
.72912 1.07051 L
s
.3055 .7076 m .29424 .71083 L .29978 .7113 L 0 1 .534 r
F
0 g
.29978 .7113 m
.30302 .71589 L
s
.43104 .91639 m .42694 .91713 L .43044 .91645 L 0 0 0 r
F
.43104 .91639 m .42207 .91793 L .42694 .91713 L F
0 g
.42684 .91717 m
.42694 .91713 L
s
.47003 .75349 m
.47277 .75215 L
s
.62457 .62306 m
.62863 .62489 L
s
.62863 .62489 m
.63013 .62557 L
s
.40969 .76688 m .39878 .76892 L .39811 .76871 L 0 0 0 r
F
.40969 .76688 m .40273 .76864 L .39878 .76892 L F
.40969 .76688 m .40733 .76806 L .40273 .76864 L F
.40969 .76688 m .41031 .7673 L .40733 .76806 L F
0 g
.40969 .76688 m
.41272 .76576 L
s
.40574 .76716 m
.40969 .76688 L
s
.38628 .94041 m
.39172 .94493 L
s
.49819 .61848 m .49347 .6233 L .49431 .62204 L 0 0 0 r
F
0 g
.49348 .62203 m
.49557 .6202 L
s
.49819 .61848 m .49647 .62201 L .49347 .6233 L 0 0 0 r
F
.49819 .61848 m .5013 .61903 L .49647 .62201 L F
.49819 .61848 m .50518 .61547 L .5013 .61903 L F
.49819 .61848 m .50552 .61372 L .50518 .61547 L F
0 g
.49557 .6202 m
.49819 .61848 L
s
.50552 .61372 m
.50905 .6096 L
s
.50253 .61501 m
.50552 .61372 L
s
.45685 .59944 m .44945 .60109 L .45158 .60425 L 0 1 .343 r
F
0 g
.45685 .59944 m
.45685 .59944 L
s
.45685 .59944 m .45184 .59165 L .44945 .60109 L 0 1 .343 r
F
.45685 .59944 m .45715 .58225 L .45184 .59165 L F
0 g
.45674 .59954 m
.45685 .59944 L
s
.39538 .93055 m
.39774 .9314 L
s
.4129 .93386 m .40082 .9295 L .40077 .9325 L 0 1 .527 r
F
0 g
.39774 .9314 m
.40077 .9325 L
s
.25075 .77196 m .23948 .76677 L .23932 .77155 L 0 1 .525 r
F
.25075 .77196 m .24303 .76349 L .23948 .76677 L F
.25075 .77196 m .24761 .76392 L .24303 .76349 L F
.25075 .77196 m .25092 .76756 L .24761 .76392 L F
0 g
.2472 .77521 m
.25075 .77196 L
s
.25075 .77196 m
.25352 .77476 L
s
.47817 .95573 m .47389 .95801 L .47805 .95858 L 0 1 .477 r
F
.47817 .95573 m .46992 .95635 L .47389 .95801 L F
0 g
.47389 .95801 m
.47569 .96006 L
s
.46134 .5617 m .47087 .54395 L .46966 .54214 L 0 1 .334 r
F
.46134 .5617 m .46731 .55232 L .47087 .54395 L F
0 g
.47087 .54395 m
.47639 .53799 L
s
.46731 .55232 m
.47273 .54698 L
s
.46731 .55232 m
.47087 .54395 L
s
.44978 .75848 m
.45031 .75833 L
s
.44642 .75939 m
.44978 .75848 L
s
.79646 .90057 m .79917 .90827 L .80468 .90526 L 0 1 .499 r
F
.79646 .90057 m .79478 .9079 L .79917 .90827 L F
0 g
.79917 .90827 m
.79932 .9118 L
s
.51454 .88185 m
.51564 .87941 L
s
.76466 .7851 m .77269 .80446 L .77602 .79394 L 0 1 .427 r
F
.76466 .7851 m .76818 .80593 L .77269 .80446 L F
0 g
.77269 .80446 m
.77522 .81194 L
s
.72047 .87322 m
.72331 .86761 L
s
.62039 .62213 m .63025 .62562 L .63365 .62813 L 0 .03 0 r
F
0 g
.63013 .62557 m
.63025 .62562 L
s
.63029 .62661 m
.6303 .62673 L
s
.35975 .92444 m .34718 .92283 L .34688 .92436 L 0 1 .373 r
F
.35975 .92444 m .35108 .92241 L .34718 .92283 L F
.35975 .92444 m .35647 .92309 L .35108 .92241 L F
.36915 .92303 m .35647 .92309 L .35975 .92444 L 0 .971 .329 r
F
0 g
.35975 .92444 m
.36498 .92496 L
s
.35943 .92596 m
.35975 .92444 L
s
.41632 .53269 m .407 .5411 L .40952 .53958 L 0 1 .192 r
F
0 g
.41022 .54049 m
.4133 .53728 L
s
.41632 .53269 m .41031 .53641 L .407 .5411 L 0 1 .192 r
F
.41632 .53269 m .41725 .52863 L .41031 .53641 L F
.41632 .53269 m .42404 .52174 L .41725 .52863 L F
.41632 .53269 m .42617 .52033 L .42404 .52174 L F
0 g
.42285 .52502 m
.42617 .52033 L
s
.4133 .53728 m
.41632 .53269 L
s
.42617 .52033 m
.43294 .51366 L
s
.43881 .94547 m .43515 .94299 L .43003 .94182 L 0 1 .526 r
F
.44611 .94325 m .43881 .94547 L .44366 .94664 L 0 1 .52 r
F
.44611 .94325 m .43515 .94299 L .43881 .94547 L F
0 g
.43881 .94547 m
.43945 .94814 L
s
.77597 .78136 m .78732 .79087 L .7873 .77825 L 0 1 .436 r
F
0 g
.78396 .80123 m
.78732 .79087 L
s
.78732 .79087 m
.79073 .79956 L
s
.288 .6078 m .27713 .61357 L .28139 .6143 L 0 1 .479 r
F
0 g
.28139 .6143 m
.2819 .6219 L
s
.63595 .52548 m
.63614 .52614 L
s
.63614 .52614 m
.63639 .52701 L
s
.63639 .52701 m
.63686 .52861 L
s
.63686 .52861 m
.63746 .53068 L
s
.63746 .53068 m
.6387 .53495 L
s
.6387 .53495 m
.63909 .53629 L
s
.64132 .54394 m
.64166 .54511 L
s
.6344 .52345 m
.63595 .52548 L
s
.63346 .52221 m
.6344 .52345 L
s
.63281 .52135 m
.63309 .52171 L
s
.63309 .52171 m
.63346 .52221 L
s
.457 .75858 m
.45819 .7574 L
s
.45819 .7574 m
.45893 .75666 L
s
.71038 .90015 m .71769 .90327 L .72063 .90185 L 0 .706 .305 r
F
0 g
.7125 .90358 m
.71769 .90327 L
s
.21958 .71815 m .20972 .70925 L .20817 .71765 L 0 1 .528 r
F
.21958 .71815 m .2143 .70324 L .20972 .70925 L F
.21958 .71815 m .21884 .70366 L .2143 .70324 L F
.21958 .71815 m .2211 .71007 L .21884 .70366 L F
0 g
.21501 .72412 m
.21958 .71815 L
s
.21958 .71815 m
.22187 .72428 L
s
.40078 .55141 m .39116 .56021 L .39406 .55836 L 0 1 .211 r
F
.40078 .55141 m .39382 .55579 L .39116 .56021 L F
0 g
.39387 .55868 m
.39406 .55836 L
s
.39208 .56177 m
.39387 .55868 L
s
.40078 .55141 m .40027 .54805 L .39382 .55579 L 0 1 .211 r
F
.40078 .55141 m .407 .5411 L .40027 .54805 L F
.40078 .55141 m .40952 .53958 L .407 .5411 L F
.40078 .55141 m .40685 .544 L .40952 .53958 L F
0 g
.40952 .53958 m
.41632 .53269 L
s
.39838 .55577 m
.40078 .55141 L
s
.39406 .55836 m
.40078 .55141 L
s
.40685 .544 m
.41022 .54049 L
s
.46292 .69327 m .46319 .66841 L .45889 .66968 L 0 1 .326 r
F
.46292 .69327 m .46579 .67496 L .46319 .66841 L F
0 g
.46319 .66841 m
.46377 .65705 L
s
.23932 .77155 m .22803 .76599 L .22788 .77113 L 0 1 .53 r
F
.23932 .77155 m .23157 .76243 L .22803 .76599 L F
.23932 .77155 m .23616 .76285 L .23157 .76243 L F
.23932 .77155 m .23948 .76677 L .23616 .76285 L F
0 g
.23577 .77507 m
.23932 .77155 L
s
.23932 .77155 m
.24166 .7741 L
s
.46292 .69327 m .46567 .68561 L .46579 .67496 L 0 1 .326 r
F
0 g
.46579 .67496 m
.46995 .67392 L
s
.52565 .46847 m .51991 .47436 L .51976 .47394 L 0 0 0 r
F
.52565 .46847 m .52638 .47017 L .51991 .47436 L F
.52565 .46847 m .53484 .46419 L .52638 .47017 L F
.52565 .46847 m .5407 .45874 L .53484 .46419 L F
0 g
.52021 .47352 m
.52565 .46847 L
s
.46104 .90894 m .45094 .91195 L .45078 .91133 L 0 0 0 r
F
0 g
.44618 .91273 m
.45078 .91133 L
s
.22608 .92353 m .21198 .91521 L .21147 .91923 L 0 1 .525 r
F
.22608 .92353 m .21643 .91505 L .21198 .91521 L F
.22608 .92353 m .22248 .91863 L .21643 .91505 L F
.23694 .92267 m .22248 .91863 L .22608 .92353 L 0 1 .522 r
F
0 g
.22554 .92752 m
.22608 .92353 L
s
.22608 .92353 m
.23198 .92687 L
s
.52529 .97122 m .51906 .97018 L .52248 .97099 L 0 .503 .224 r
F
0 g
.51946 .97081 m
.52248 .97099 L
s
.51159 .48107 m .5136 .47907 L .51976 .47394 L 0 0 0 r
F
.50598 .48639 m .51887 .47387 L .5136 .47907 L F
.50598 .48639 m .5136 .47907 L .50554 .48635 L F
.50554 .48635 m .5136 .47907 L .51159 .48107 L F
.51887 .47387 m .51953 .47322 L .5136 .47907 L F
0 g
.5136 .47907 m
.51953 .47322 L
s
.51953 .47322 m
.52565 .46847 L
s
.40685 .544 m
.40952 .53958 L
s
.4567 .65236 m
.45687 .65195 L
s
.50598 .48639 m .49971 .49201 L .50003 .49226 L 0 0 0 r
F
.50598 .48639 m .50554 .48635 L .49971 .49201 L F
.81066 .78699 m .82161 .79093 L .82235 .79104 L F
0 g
.82161 .79093 m
.82405 .79197 L
s
.50566 .73612 m
.50651 .7168 L
s
.80174 .61033 m .80708 .61349 L .80266 .61281 L 0 0 0 r
F
.80174 .61033 m .81289 .61276 L .80708 .61349 L F
0 g
.58297 .64339 m
.58389 .64102 L
s
.58567 .63647 m
.58653 .63426 L
s
.3959 .92162 m .38362 .92198 L .38326 .92282 L 0 .776 .251 r
F
0 g
.38326 .92282 m
.38326 .92282 L
s
.4971 .73404 m .49271 .70896 L .49443 .72489 L 0 .921 .289 r
F
.49261 .74394 m .49443 .72489 L .49271 .70896 L 0 .923 .295 r
F
0 g
.48977 .70137 m
.49271 .70896 L
s
.49271 .70896 m
.49316 .69271 L
s
.4744 1.03682 m .47139 1.03915 L .47663 1.0422 L 0 .55 .414 r
F
.3959 .92162 m .38749 .92144 L .38362 .92198 L 0 .776 .251 r
F
.3959 .92162 m .39276 .92129 L .38749 .92144 L F
.40517 .92006 m .39276 .92129 L .3959 .92162 L 0 .722 .232 r
F
0 g
.3959 .92162 m
.40097 .92135 L
s
.39553 .92247 m
.3959 .92162 L
s
.4046 .92065 m
.40981 .92001 L
s
.52635 .45432 m .5348 .45212 L .54161 .45331 L 0 .131 .058 r
F
0 g
.5348 .45212 m
.54065 .44713 L
s
.24557 .62787 m .2346 .62681 L .23483 .63505 L 0 1 .486 r
F
0 g
.22933 .64278 m
.23483 .63505 L
s
.22788 .77113 m .21658 .76522 L .21645 .77073 L 0 1 .534 r
F
.22788 .77113 m .22011 .76138 L .21658 .76522 L F
.22788 .77113 m .2247 .7618 L .22011 .76138 L F
.22788 .77113 m .22803 .76599 L .2247 .7618 L F
0 g
.22435 .77494 m
.22788 .77113 L
s
.22788 .77113 m
.2308 .77454 L
s
.33229 .92276 m .32771 .92521 L .3316 .9247 L 0 1 .435 r
F
.33229 .92276 m .32243 .92382 L .32771 .92521 L F
0 g
.32771 .92521 m
.32774 .92718 L
s
.3316 .9247 m
.3373 .92573 L
s
.36235 .70085 m .35218 .70024 L .35345 .70326 L 0 1 .535 r
F
0 g
.34906 .70629 m
.35345 .70326 L
s
.5427 1.08464 m .54238 1.0815 L .54457 1.08229 L 0 .012 0 r
F
.5427 1.08464 m .54025 1.08148 L .54238 1.0815 L F
0 g
.54123 1.08028 m
.54238 1.0815 L
s
.7276 .61288 m .73245 .62321 L .72827 .6231 L 0 .266 .093 r
F
.7276 .61288 m .73821 .61486 L .73245 .62321 L F
0 g
.72825 .62275 m
.72827 .6231 L
s
.7276 .61288 m
.72825 .62275 L
s
.72201 .6229 m
.7276 .61288 L
s
.47817 .95573 m .46844 .95441 L .46992 .95635 L 0 1 .477 r
F
0 g
.46543 .9559 m
.46992 .95635 L
s
.39811 .76871 m .38651 .76991 L .38946 .76951 L 0 0 0 r
F
0 g
.38583 .7701 m
.38783 .76977 L
s
.40408 .9497 m .3916 .93935 L .39172 .94493 L 0 .925 .437 r
F
.43433 .76281 m .42569 .7644 L .43027 .76311 L 0 0 0 r
F
0 g
.43027 .76311 m
.43334 .76159 L
s
.47609 .69506 m .46967 .68601 L .47226 .69419 L 0 1 .311 r
F
.48222 .72156 m .47609 .69506 L .47613 .70798 L 0 1 .305 r
F
.48222 .72156 m .48432 .7158 L .48427 .70287 L F
.53153 .90911 m .53606 .92682 L .53469 .91894 L 0 .215 .264 r
F
.53153 .90911 m .53459 .92841 L .53606 .92682 L F
0 g
.53153 .90911 m
.53251 .91215 L
s
.53251 .91215 m
.53264 .91257 L
s
.53264 .91257 m
.53469 .91894 L
s
.53153 .90911 m
.53263 .90575 L
s
.5407 .45874 m
.54334 .45761 L
s
.79646 .90057 m .79361 .90461 L .79478 .9079 L 0 1 .499 r
F
0 g
.78848 .91061 m
.79478 .9079 L
s
.45574 .67794 m .45929 .65951 L .45668 .65419 L 0 1 .334 r
F
.45574 .67794 m .45889 .66968 L .45929 .65951 L F
0 g
.45929 .65951 m
.46377 .65705 L
s
.40408 .9497 m .40084 .9561 L .40419 .95528 L 0 .925 .437 r
F
.4136 .96581 m .40419 .95528 L .40084 .9561 L 0 .884 .441 r
F
0 g
.40084 .9561 m
.40153 .96159 L
s
.3955 .95167 m
.40084 .9561 L
s
.3162 .88383 m .30511 .86948 L .3037 .87625 L 0 1 .461 r
F
.3162 .88383 m .30929 .86915 L .30511 .86948 L F
.3162 .88383 m .31404 .87531 L .30929 .86915 L F
.32643 .88281 m .31404 .87531 L .3162 .88383 L 0 1 .456 r
F
0 g
.3162 .88383 m
.32085 .88987 L
s
.31478 .89058 m
.3162 .88383 L
s
.3055 .7076 m .29175 .70607 L .29424 .71083 L 0 1 .534 r
F
0 g
.28913 .71504 m
.29424 .71083 L
s
.64361 .64886 m
.64368 .64885 L
s
.64368 .64885 m
.64505 .64875 L
s
.64505 .64875 m
.64585 .6487 L
s
.76059 .76172 m
.7615 .76368 L
s
.52239 .88392 m .52146 .8775 L .52353 .87208 L 0 0 .057 r
F
0 g
.52303 .87339 m
.52317 .87302 L
s
.52317 .87302 m
.52334 .87258 L
s
.52334 .87258 m
.52343 .87233 L
s
.52343 .87233 m
.52346 .87225 L
s
.52346 .87225 m
.52353 .87208 L
s
.52171 .87411 m
.52268 .8713 L
s
.52323 .87167 m
.52353 .87208 L
s
.48861 .50851 m .50051 .49265 L .49459 .49854 L 0 .928 .165 r
F
0 g
.50051 .49265 m
.50598 .48639 L
s
.50487 .89169 m .5051 .88698 L .50578 .88889 L 0 0 .02 r
F
.50964 .88699 m .50578 .88889 L .5051 .88698 L 0 0 .018 r
F
0 g
.5051 .88698 m
.50639 .88381 L
s
.50284 .88715 m
.5051 .88698 L
s
.56031 .5989 m .56519 .59757 L .57041 .60232 L 0 .36 .099 r
F
.4971 .73404 m .49894 .73027 L .49938 .71395 L 0 .921 .289 r
F
0 g
.49894 .73027 m
.49938 .71395 L
s
.49938 .71395 m
.50175 .72489 L
s
.21645 .77073 m .20512 .76447 L .20501 .77034 L 0 1 .536 r
F
.21645 .77073 m .20864 .76036 L .20512 .76447 L F
.21645 .77073 m .21323 .76077 L .20864 .76036 L F
.21645 .77073 m .21658 .76522 L .21323 .76077 L F
0 g
.21292 .7748 m
.21645 .77073 L
s
.21645 .77073 m
.21938 .77439 L
s
.42207 .91793 m .41396 .91906 L .41017 .91967 L 0 .683 .205 r
F
.42207 .91793 m .41906 .91831 L .41396 .91906 L F
.43104 .91639 m .41906 .91831 L .42207 .91793 L 0 0 0 r
F
0 g
.4217 .91827 m
.42207 .91793 L
s
.42207 .91793 m
.42694 .91713 L
s
.2702 .90468 m .25738 .89373 L .25631 .899 L 0 1 .531 r
F
.2702 .90468 m .26184 .89346 L .25738 .89373 L F
.2702 .90468 m .26734 .89816 L .26184 .89346 L F
.2811 .90364 m .26734 .89816 L .2702 .90468 L 0 1 .53 r
F
0 g
.26911 .90992 m
.2702 .90468 L
s
.2702 .90468 m
.27558 .90919 L
s
.77016 .61831 m .78059 .60827 L .785 .60934 L 0 .057 .018 r
F
.77016 .61831 m .77424 .6121 L .78059 .60827 L F
0 g
.77947 .60386 m
.78059 .60827 L
s
.53459 .92841 m
.53629 .93283 L
s
.53629 .93283 m
.5372 .93522 L
s
.53743 .93581 m
.5381 .93757 L
s
.53459 .92841 m
.53606 .92682 L
s
.49261 .74394 m .48756 .70715 L .48751 .72211 L 0 .923 .295 r
F
0 g
.48427 .70287 m
.48756 .70715 L
s
.38852 .69251 m .37937 .69488 L .38351 .6949 L 0 1 .518 r
F
0 g
.38351 .6949 m
.3851 .69751 L
s
.76466 .7851 m .76474 .79764 L .76818 .80593 L 0 1 .427 r
F
0 g
.76401 .8155 m
.76818 .80593 L
s
.47423 .90488 m .46509 .90785 L .46507 .9068 L 0 0 0 r
F
0 g
.46086 .90833 m
.46507 .9068 L
s
.47008 .71226 m .46967 .68601 L .46567 .68561 L 0 1 .318 r
F
.47008 .71226 m .47226 .69419 L .46967 .68601 L F
0 g
.46967 .68601 m
.46995 .67392 L
s
.31597 .70863 m .30761 .70219 L .30551 .7076 L 0 1 .535 r
F
0 g
.30551 .7076 m
.30709 .71188 L
s
.31597 .70863 m .31229 .69861 L .30761 .70219 L 0 1 .535 r
F
.31597 .70863 m .31641 .69926 L .31229 .69861 L F
.31597 .70863 m .31799 .70356 L .31641 .69926 L F
0 g
.31131 .71219 m
.31597 .70863 L
s
.31597 .70863 m
.31763 .7126 L
s
.63449 .64548 m
.6397 .65181 L
s
.6397 .65181 m
.64006 .65226 L
s
.49659 .96299 m .49825 .96529 L .49892 .96454 L 0 .812 .396 r
F
.50611 .96602 m .49892 .96454 L .49825 .96529 L 0 .659 .324 r
F
0 g
.49825 .96529 m
.50096 .9666 L
s
.49457 .96495 m
.49825 .96529 L
s
.49171 .75044 m
.4927 .74883 L
s
.4641 .95367 m .46031 .95177 L .45565 .95111 L 0 1 .509 r
F
.57101 .4498 m .58737 .44731 L .58944 .45037 L 0 .032 .023 r
F
0 g
.58737 .44731 m
.59194 .44451 L
s
.57949 .44706 m
.58737 .44731 L
s
.45134 .63228 m .45484 .60949 L .44971 .61356 L 0 1 .346 r
F
0 g
.45484 .60949 m
.45685 .59944 L
s
.36652 .58339 m
.37268 .5793 L
s
.44611 .94325 m .44366 .94664 L .44647 .94571 L 0 1 .52 r
F
.45481 .94875 m .44647 .94571 L .44366 .94664 L 0 1 .516 r
F
0 g
.44366 .94664 m
.44451 .949 L
s
.43881 .94547 m
.44366 .94664 L
s
.36926 .9183 m .36122 .90573 L .35732 .90621 L 0 1 .445 r
F
.36926 .9183 m .36634 .91091 L .36122 .90573 L F
.37867 .91696 m .36926 .9183 L .37422 .9234 L 0 1 .437 r
F
.37867 .91696 m .36634 .91091 L .36926 .9183 L F
0 g
.36903 .92062 m
.36926 .9183 L
s
.20501 .77034 m .19366 .76375 L .19356 .76996 L 0 1 .538 r
F
.20501 .77034 m .19717 .75937 L .19366 .76375 L F
0 g
.19356 .76996 m
.19692 .77464 L
s
.20501 .77034 m .20176 .75976 L .19717 .75937 L 0 1 .538 r
F
.20501 .77034 m .20512 .76447 L .20176 .75976 L F
0 g
.2015 .77468 m
.20501 .77034 L
s
.20501 .77034 m
.20798 .77426 L
s
.48861 .50851 m .48189 .51349 L .48267 .51443 L 0 .928 .165 r
F
.48861 .50851 m .48701 .50668 L .48189 .51349 L F
.48861 .50851 m .49459 .49854 L .48701 .50668 L F
.75587 .90677 m .7662 .90537 L .7618 .90496 L 0 1 .471 r
F
.74498 .90537 m .75587 .90677 L .75519 .90432 L 0 1 .448 r
F
0 g
.5278 .97188 m
.52864 .97202 L
s
.52726 .97179 m
.5278 .97188 L
s
.37867 .91696 m .37422 .9234 L .37793 .92282 L 0 1 .437 r
F
.38643 .93462 m .37793 .92282 L .37422 .9234 L 0 1 .442 r
F
.37862 .91936 m .37422 .9234 L .37793 .92282 L 0 1 .525 r
F
.37857 .92177 m .37422 .9234 L .37793 .92282 L 0 .829 .28 r
F
.37862 .91936 m .36921 .92067 L .37422 .9234 L 0 1 .525 r
F
.37857 .92177 m .36915 .92303 L .37422 .9234 L 0 .829 .28 r
F
0 g
.37422 .92342 m
.37422 .9234 L
s
.37422 .92347 m
.37422 .9234 L
s
.37408 .9292 m
.37422 .9234 L
s
.36926 .9183 m
.37128 .92038 L
s
.48725 .95958 m .48802 .96219 L .48915 .96134 L 0 .927 .446 r
F
.49659 .96299 m .48915 .96134 L .48802 .96219 L 0 .812 .396 r
F
0 g
.48802 .96219 m
.49034 .96374 L
s
.48408 .96176 m
.48802 .96219 L
s
.46088 1.02394 m .4622 1.02973 L .4637 1.02871 L 0 .651 .435 r
F
.4744 1.03682 m .4637 1.02871 L .4622 1.02973 L 0 .55 .414 r
F
0 g
.4622 1.02973 m
.46549 1.0342 L
s
.45681 1.02653 m
.4622 1.02973 L
s
.31259 .92495 m .29743 .92102 L .29613 .92356 L 0 1 .473 r
F
.31259 .92495 m .30275 .92063 L .29743 .92102 L F
.31259 .92495 m .30926 .92232 L .30275 .92063 L F
0 g
.31126 .92748 m
.31259 .92495 L
s
.32243 .92382 m .30926 .92232 L .31259 .92495 L 0 1 .456 r
F
0 g
.31259 .92495 m
.31799 .92652 L
s
.51728 1.07191 m .50627 1.06529 L .50609 1.06573 L 0 .318 .216 r
F
.51728 1.07191 m .51107 1.06794 L .50627 1.06529 L F
.51574 1.07107 m .50656 1.06471 L .51107 1.06794 L 0 .217 .197 r
F
.51728 1.07191 m .51481 1.07064 L .51756 1.0721 L 0 .318 .216 r
F
.51728 1.07191 m .50746 1.06649 L .51093 1.06864 L F
.50746 1.06649 m .50609 1.06573 L .50693 1.06623 L F
.50746 1.06649 m .50693 1.06623 L .51093 1.06864 L F
.51276 1.06899 m .50675 1.06437 L .50656 1.06471 L 0 .217 .197 r
F
.51699 1.07191 m .51444 1.0702 L .51388 1.06976 L F
.51585 1.07112 m .51424 1.07001 L .51574 1.07107 L F
.51424 1.07001 m .50656 1.06471 L .51432 1.07009 L F
.51424 1.07001 m .51432 1.07009 L .51574 1.07107 L F
.51372 1.06952 m .50704 1.06392 L .51122 1.06745 L 0 .131 .18 r
F
.51699 1.07191 m .5135 1.06934 L .51276 1.06899 L 0 .217 .197 r
F
.51699 1.07191 m .51585 1.07112 L .51574 1.07107 L F
.51669 1.07198 m .51122 1.06745 L .51699 1.07191 L 0 .131 .18 r
F
.51621 1.07158 m .51349 1.06931 L .51372 1.06952 L F
.51349 1.06931 m .50704 1.06392 L .51372 1.06952 L F
.51669 1.07197 m .51629 1.07164 L .51621 1.07158 L F
.51481 1.07064 m .51434 1.07043 L .51756 1.0721 L 0 .318 .216 r
F
.51638 1.07197 m .51407 1.06972 L .51669 1.07198 L 0 .058 .167 r
F
.51699 1.07191 m .51122 1.06745 L .50675 1.06437 L 0 .217 .197 r
F
.51669 1.07198 m .51137 1.0671 L .50724 1.06365 L 0 .131 .18 r
F
.51407 1.06972 m .51137 1.0671 L .51669 1.07197 L 0 .058 .167 r
F
.51669 1.07198 m .50724 1.06365 L .50704 1.06392 L 0 .131 .18 r
F
.51407 1.06972 m .51669 1.07197 L .51669 1.07198 L 0 .058 .167 r
F
.51407 1.06972 m .50754 1.06324 L .51137 1.0671 L F
.51391 1.06965 m .5139 1.06965 L .51621 1.07158 L 0 .131 .18 r
F
.51638 1.07197 m .51413 1.06975 L .51407 1.06972 L 0 .058 .167 r
F
.51413 1.06975 m .50754 1.06324 L .51407 1.06972 L F
.51629 1.07164 m .51391 1.06965 L .51621 1.07158 L 0 .131 .18 r
F
.51391 1.06965 m .50704 1.06392 L .5139 1.06965 L F
.51388 1.06976 m .51107 1.06794 L .51338 1.06941 L 0 .217 .197 r
F
.51444 1.0702 m .51107 1.06794 L .51388 1.06976 L F
.51699 1.07191 m .5151 1.07051 L .51728 1.07191 L F
.5135 1.06934 m .50675 1.06437 L .51276 1.06899 L F
.51481 1.07064 m .51093 1.06864 L .51434 1.07043 L 0 .318 .216 r
F
0 g
.50693 1.06623 m
.50739 1.06651 L
s
.50739 1.06651 m
.51093 1.06864 L
s
.50581 1.0665 m
.5067 1.06687 L
s
.5067 1.06687 m
.50756 1.06723 L
s
.50756 1.06723 m
.50785 1.06736 L
s
.50785 1.06736 m
.51093 1.06864 L
s
.71384 .88026 m
.714 .88002 L
s
.70994 .88604 m
.71384 .88026 L
s
.70886 .88268 m
.70994 .88604 L
s
.48046 .90066 m .47792 .9024 L .47419 .90384 L 0 0 0 r
F
.48583 .90164 m .48046 .90066 L .48387 .89966 L F
.48583 .90164 m .47792 .9024 L .48046 .90066 L F
0 g
.48046 .90066 m
.48084 .89946 L
s
.46581 .48269 m .47368 .47652 L .47897 .47342 L 0 0 0 r
F
0 g
.47368 .47652 m
.47872 .47156 L
s
.43562 .99617 m .43093 .9903 L .42539 .98666 L 0 .788 .445 r
F
.36235 .70085 m .35461 .69641 L .35218 .70024 L 0 1 .535 r
F
.36235 .70085 m .35942 .69379 L .35461 .69641 L F
.36235 .70085 m .36339 .69414 L .35942 .69379 L F
.36235 .70085 m .36464 .69717 L .36339 .69414 L F
0 g
.36235 .70085 m
.36371 .70365 L
s
.35821 .7031 m
.36235 .70085 L
s
.5427 1.08464 m .54457 1.08229 L .54562 1.08365 L 0 .012 0 r
F
0 g
.54457 1.08229 m
.54679 1.08202 L
s
.82138 .77158 m .83276 .76999 L .82943 .76081 L 0 1 .465 r
F
.35255 .90073 m .34113 .88774 L .34006 .894 L 0 1 .447 r
F
.45574 .67794 m .45668 .65419 L .45207 .6567 L 0 1 .334 r
F
0 g
.45668 .65419 m
.45687 .65195 L
s
.33666 .88188 m .33099 .88876 L .33504 .88834 L 0 1 .45 r
F
.33666 .88188 m .32643 .88281 L .33099 .88876 L F
0 g
.33004 .89517 m
.33099 .88876 L
s
.33504 .88834 m
.34006 .894 L
s
.50611 .96602 m .50863 .96792 L .50883 .96734 L 0 .659 .324 r
F
.51571 .96873 m .50883 .96734 L .50863 .96792 L 0 .576 .25 r
F
0 g
.50863 .96792 m
.51171 .96899 L
s
.50525 .96761 m
.50863 .96792 L
s
.31995 .5923 m .30914 .59561 L .31317 .59696 L 0 1 .474 r
F
0 g
.31317 .59696 m
.31995 .5923 L
s
.31995 .59231 m
.31995 .5923 L
s
.3199 .59909 m
.31995 .59231 L
s
.31306 .60414 m
.31317 .59696 L
s
.51958 .8867 m .52167 .87422 L .52146 .8775 L 0 0 .057 r
F
.51958 .8867 m .52109 .87488 L .52167 .87422 L F
0 g
.5193 .87675 m
.51943 .87649 L
s
.52164 .87702 m
.52303 .87339 L
s
.52167 .87422 m
.52171 .87411 L
s
.52167 .87429 m
.52167 .87422 L
s
.52166 .87445 m
.52167 .87429 L
s
.52146 .8775 m
.52166 .87445 L
s
.44655 .91298 m .43569 .91558 L .43534 .91532 L 0 0 0 r
F
0 g
.43044 .91645 m
.43534 .91532 L
s
.36243 .89964 m .35732 .90621 L .36122 .90573 L 0 1 .44 r
F
.36243 .89964 m .35255 .90073 L .35732 .90621 L F
0 g
.35674 .91224 m
.35732 .90621 L
s
.44791 1.01039 m .4429 1.00478 L .43741 1.00137 L 0 .727 .443 r
F
.20817 .71765 m .19833 .70845 L .19675 .71716 L 0 1 .528 r
F
.20817 .71765 m .20294 .70221 L .19833 .70845 L F
0 g
.19675 .71716 m
.19899 .72374 L
s
.20817 .71765 m .20748 .70262 L .20294 .70221 L 0 1 .528 r
F
.20817 .71765 m .20972 .70925 L .20748 .70262 L F
0 g
.20357 .72385 m
.20817 .71765 L
s
.20817 .71765 m
.21044 .72401 L
s
.288 .6078 m .27752 .60564 L .27713 .61357 L 0 1 .479 r
F
0 g
.27115 .62036 m
.27713 .61357 L
s
.71089 .62249 m
.71293 .62275 L
s
.71293 .62275 m
.71745 .62332 L
s
.71781 .6228 m
.71784 .62275 L
s
.71779 .62283 m
.71781 .6228 L
s
.71745 .62332 m
.71779 .62283 L
s
.44611 .94325 m .43478 .94053 L .43515 .94299 L 0 1 .52 r
F
0 g
.43003 .94182 m
.43515 .94299 L
s
.77908 1.05533 m .77259 1.05867 L .77053 1.06056 L 0 .903 .246 r
F
0 g
.76209 1.06306 m
.77053 1.06056 L
s
.23629 .93744 m .23142 .93951 L .23573 .93918 L 0 .818 .293 r
F
.23629 .93744 m .22542 .938 L .23142 .93951 L F
0 g
.23142 .93951 m
.23185 .94135 L
s
.23573 .93918 m
.23664 .93933 L
s
.48749 .62686 m .49175 .62356 L .49431 .62204 L 0 0 0 r
F
0 g
.49175 .62356 m
.49348 .62203 L
s
.53413 1.08038 m .52751 1.07713 L .52273 1.07472 L 0 0 0 r
F
.47369 .53387 m .48383 .51592 L .47799 .52162 L 0 1 .25 r
F
0 g
.48383 .51592 m
.48861 .50851 L
s
.35292 .58786 m .34292 .58742 L .34645 .5887 L 0 .877 .241 r
F
0 g
.34575 .59393 m
.34645 .5887 L
s
.288 .6078 m .2823 .59577 L .27752 .60564 L 0 1 .479 r
F
.288 .6078 m .28893 .58925 L .2823 .59577 L F
.288 .6078 m .29298 .59045 L .28893 .58925 L F
.288 .6078 m .29258 .59841 L .29298 .59045 L F
0 g
.28776 .6154 m
.288 .6078 L
s
.28139 .6143 m
.288 .6078 L
s
.33256 .913 m .3204 .90465 L .31966 .90891 L 0 1 .528 r
F
.33256 .913 m .32446 .9043 L .3204 .90465 L F
.33256 .913 m .32968 .90789 L .32446 .9043 L F
.34242 .91185 m .32968 .90789 L .33256 .913 L 0 1 .526 r
F
0 g
.33256 .913 m
.33764 .91644 L
s
.33181 .91726 m
.33256 .913 L
s
.38651 .76991 m .37815 .77052 L .38262 .77018 L 0 .591 .198 r
F
0 g
.38292 .77017 m
.38582 .7701 L
s
.82138 .77158 m .82943 .76081 L .82486 .76147 L 0 1 .465 r
F
.81 .77345 m .82138 .77158 L .81802 .76254 L 0 1 .458 r
F
.46945 .95143 m .4641 .95367 L .46844 .95441 L 0 1 .496 r
F
.46945 .95143 m .46031 .95177 L .4641 .95367 L F
0 g
.4641 .95367 m
.46543 .9559 L
s
.76466 .7851 m .77602 .79394 L .77597 .78136 L 0 1 .427 r
F
0 g
.77269 .80446 m
.77602 .79394 L
s
.77602 .79394 m
.77945 .80245 L
s
.45184 .59165 m .45985 .57327 L .45814 .57068 L 0 1 .356 r
F
.45184 .59165 m .45715 .58225 L .45985 .57327 L F
0 g
.45985 .57327 m
.46528 .56789 L
s
.45715 .58225 m
.46241 .57747 L
s
.45715 .58225 m
.45985 .57327 L
s
.51958 .8867 m .52009 .87899 L .52109 .87488 L 0 0 .057 r
F
0 g
.52106 .875 m
.52109 .87488 L
s
.51943 .87649 m
.52119 .87284 L
s
.52109 .87488 m
.52119 .87284 L
s
.42415 .9813 m .41981 .97518 L .41428 .97129 L 0 .839 .444 r
F
.3958 .92731 m .38362 .92198 L .38321 .92523 L 0 1 .526 r
F
.57287 .72612 m .5757 .71755 L .57994 .67892 L 0 1 .186 r
F
0 g
.57597 .68159 m
.57656 .67618 L
s
.38852 .69251 m .37833 .69244 L .37937 .69488 L 0 1 .518 r
F
0 g
.37466 .69753 m
.37937 .69488 L
s
.38852 .69251 m .38107 .6892 L .37833 .69244 L 0 1 .518 r
F
.38852 .69251 m .38609 .6868 L .38107 .6892 L F
.38852 .69251 m .39003 .68685 L .38609 .6868 L F
.38852 .69251 m .39107 .68929 L .39003 .68685 L F
0 g
.38852 .69251 m
.3897 .69482 L
s
.38351 .6949 m
.38852 .69251 L
s
.47008 .71226 m .47243 .70543 L .47226 .69419 L 0 1 .318 r
F
0 g
.47226 .69419 m
.47609 .69506 L
s
.24557 .62787 m .23875 .61614 L .2346 .62681 L 0 1 .486 r
F
.24557 .62787 m .24508 .60858 L .23875 .61614 L F
.24557 .62787 m .24937 .6092 L .24508 .60858 L F
.24557 .62787 m .24957 .61748 L .24937 .6092 L F
0 g
.24557 .62787 m
.2459 .63592 L
s
.23926 .6354 m
.24557 .62787 L
s
.78525 .9003 m .78819 .90734 L .79361 .90461 L 0 1 .486 r
F
.78525 .9003 m .7838 .90696 L .78819 .90734 L F
0 g
.78819 .90734 m
.78848 .91061 L
s
.49586 .74614 m
.49587 .74608 L
s
.20775 .89096 m .20176 .89739 L .2062 .89708 L 0 1 .534 r
F
.20775 .89096 m .19656 .89155 L .20176 .89739 L F
0 g
.20128 .90357 m
.20176 .89739 L
s
.2062 .89708 m
.21226 .90262 L
s
.47281 .75614 m
.4731 .75564 L
s
.49699 .89237 m .49469 .89435 L .49177 .89543 L 0 0 0 r
F
.75281 .81982 m .76143 .80836 L .75693 .81014 L 0 1 .436 r
F
0 g
.75018 .81309 m
.75281 .81982 L
s
.44861 .658 m .44065 .66097 L .44371 .66057 L 0 1 .339 r
F
.44714 .65715 m .45014 .64249 L .44523 .64589 L 0 1 .344 r
F
.44861 .658 m .44393 .65867 L .44065 .66097 L 0 1 .339 r
F
.44393 .65867 m .4413 .65485 L .44093 .66002 L 0 1 .344 r
F
.44393 .65867 m .44093 .66002 L .44093 .66008 L F
.44861 .658 m .44716 .65721 L .44393 .65867 L 0 1 .339 r
F
.44393 .65867 m .44523 .64589 L .4413 .65485 L 0 1 .344 r
F
.44716 .65721 m .44715 .6572 L .44393 .65867 L 0 1 .339 r
F
.44854 .66537 m .44715 .6572 L .44393 .65867 L 0 1 .344 r
F
.44715 .6572 m .44523 .64589 L .44393 .65867 L F
.44715 .6572 m .44511 .65609 L .44393 .65867 L 0 1 .339 r
F
.44393 .65867 m .44511 .65609 L .44125 .65906 L F
.44393 .65867 m .44379 .65869 L .44362 .65882 L F
.44393 .65867 m .44362 .65882 L .44065 .66097 L F
.44854 .66537 m .44393 .65867 L .4406 .66466 L 0 1 .344 r
F
.44379 .65869 m .44095 .66 L .44065 .66097 L 0 1 .339 r
F
.44393 .65867 m .44093 .66008 L .4406 .66466 L 0 1 .344 r
F
.44918 .65621 m .45276 .6469 L .45014 .64249 L F
.44861 .658 m .45084 .65531 L .44918 .65621 L 0 1 .339 r
F
.44861 .658 m .45209 .65498 L .45222 .65456 L F
.45084 .65531 m .45222 .65456 L .45276 .6469 L 0 1 .344 r
F
.45084 .65531 m .45222 .65456 L .4527 .65306 L 0 1 .339 r
F
.44861 .658 m .45222 .65456 L .45084 .65531 L F
.44854 .66537 m .45207 .6567 L .45222 .65456 L 0 1 .344 r
F
.44854 .66537 m .45222 .65456 L .45084 .65531 L F
.44854 .66537 m .45084 .65531 L .44918 .65621 L F
.45084 .65531 m .45276 .6469 L .44918 .65621 L F
.45084 .65531 m .45089 .65525 L .44918 .65621 L 0 1 .339 r
F
.44918 .65621 m .4527 .65306 L .45003 .65352 L F
.45089 .65525 m .4527 .65306 L .44918 .65621 L F
.44918 .65621 m .45014 .64249 L .44714 .65715 L 0 1 .344 r
F
.44715 .6572 m .45003 .65352 L .44511 .65609 L 0 1 .339 r
F
.44861 .658 m .44918 .65621 L .44715 .6572 L F
.44715 .6572 m .44918 .65621 L .44714 .65715 L 0 1 .344 r
F
.44918 .65621 m .45003 .65352 L .44715 .6572 L 0 1 .339 r
F
.44717 .65734 m .44918 .65621 L .44715 .6572 L 0 1 .344 r
F
.44854 .66537 m .44918 .65621 L .44717 .65734 L F
.44379 .65869 m .44125 .65906 L .44095 .66 L 0 1 .339 r
F
0 g
.4522 .65492 m
.4567 .65236 L
s
.29175 .70607 m .28219 .70975 L .2867 .71017 L 0 1 .532 r
F
0 g
.2867 .71017 m
.28913 .71504 L
s
.47008 .71226 m .46567 .68561 L .46292 .69327 L 0 1 .318 r
F
0 g
.46567 .68561 m
.46967 .68601 L
s
.46567 .68561 m
.46579 .67496 L
s
.43433 .76281 m .42295 .76594 L .42569 .7644 L 0 0 0 r
F
.43433 .76281 m .4239 .76671 L .42295 .76594 L F
.43433 .76281 m .42797 .76641 L .4239 .76671 L F
0 g
.42183 .76492 m
.42497 .7645 L
s
.42497 .7645 m
.42569 .7644 L
s
.43433 .76281 m .43244 .76523 L .42797 .76641 L 0 0 0 r
F
.43433 .76281 m .43517 .76369 L .43244 .76523 L F
0 g
.43433 .76281 m
.43715 .76083 L
s
.43027 .76311 m
.43433 .76281 L
s
.53024 .97247 m .53099 .9724 L .53232 .97261 L 0 0 0 r
F
.53024 .97247 m .52945 .97216 L .53099 .9724 L F
.35255 .90073 m .34519 .88736 L .34113 .88774 L 0 1 .447 r
F
.35255 .90073 m .35009 .89294 L .34519 .88736 L F
.36243 .89964 m .35009 .89294 L .35255 .90073 L 0 1 .44 r
F
0 g
.35147 .90698 m
.35255 .90073 L
s
.35255 .90073 m
.35732 .90621 L
s
.38643 .93462 m .38316 .92763 L .37793 .92282 L 0 1 .442 r
F
0 g
.37816 .92282 m
.38326 .92282 L
s
.37804 .92282 m
.37816 .92282 L
s
.37999 .92376 m
.38321 .92523 L
s
.37816 .92293 m
.37999 .92376 L
s
.37793 .92282 m
.37807 .92289 L
s
.37807 .92289 m
.37816 .92293 L
s
.37797 .92282 m
.37804 .92282 L
s
.37793 .92282 m
.37797 .92282 L
s
.38628 .94041 m
.38643 .93462 L
s
.50178 1.06177 m .49561 1.05753 L .49053 1.05493 L 0 .419 .312 r
F
0 g
.49053 1.05493 m
.49561 1.05753 L
s
.48643 1.0509 m
.49053 1.05493 L
s
.39569 .93301 m .38643 .93462 L .3916 .93935 L 0 .963 .433 r
F
.39569 .93301 m .38316 .92763 L .38643 .93462 L F
.46292 .69327 m .45889 .66968 L .45574 .67794 L 0 1 .326 r
F
0 g
.45889 .66968 m
.45929 .65951 L
s
.45889 .66968 m
.46319 .66841 L
s
.47817 .95573 m .47805 .95858 L .47963 .95767 L 0 1 .477 r
F
.48725 .95958 m .47963 .95767 L .47805 .95858 L 0 .927 .446 r
F
0 g
.47805 .95858 m
.47996 .96033 L
s
.47389 .95801 m
.47805 .95858 L
s
.50018 .89616 m .49699 .89237 L .49957 .89208 L 0 0 .023 r
F
.50018 .89616 m .49469 .89435 L .49699 .89237 L F
0 g
.49699 .89237 m
.49786 .89035 L
s
.73973 .83814 m
.7399 .83777 L
s
.2696 .92029 m .26427 .92379 L .26859 .9234 L 0 1 .507 r
F
.2696 .92029 m .2587 .92105 L .26427 .92379 L F
0 g
.26416 .92695 m
.26427 .92379 L
s
.26859 .9234 m
.2748 .92577 L
s
.30543 .90153 m .29792 .90679 L .30323 .90625 L 0 1 .528 r
F
.30543 .90153 m .29202 .90266 L .29792 .90679 L F
0 g
.29654 .91156 m
.29792 .90679 L
s
.30323 .90625 m
.30965 .91002 L
s
.56381 .45038 m
.57101 .4498 L
s
.55808 .45498 m
.56381 .45038 L
s
.56424 .74097 m
.56776 .72428 L
s
.56391 .7425 m
.56424 .74097 L
s
.36921 .92067 m .35713 .914 L .35661 .91766 L 0 1 .527 r
F
.42173 .67619 m .41278 .67885 L .41661 .67861 L 0 1 .46 r
F
.42173 .67619 m .41237 .67684 L .41278 .67885 L F
0 g
.41661 .67861 m
.41754 .6807 L
s
.42173 .67619 m .41567 .67391 L .41237 .67684 L 0 1 .46 r
F
.42173 .67619 m .4208 .67149 L .41567 .67391 L F
.42173 .67619 m .42433 .6712 L .4208 .67149 L F
.42173 .67619 m .42473 .67322 L .42433 .6712 L F
0 g
.42173 .67619 m
.42235 .67816 L
s
.41661 .67861 m
.42173 .67619 L
s
.48836 1.04904 m .48037 1.04631 L .48643 1.0509 L 0 .419 .365 r
F
.48836 1.04904 m .47663 1.0422 L .48037 1.04631 L F
.81 .77345 m .81802 .76254 L .81346 .7633 L 0 1 .458 r
F
.79865 .77564 m .81 .77345 L .80663 .76455 L 0 1 .452 r
F
.47369 .53387 m .46661 .538 L .46783 .53959 L 0 1 .25 r
F
.47369 .53387 m .47097 .53029 L .46661 .538 L F
.47369 .53387 m .47799 .52162 L .47097 .53029 L F
0 g
.61621 .61901 m
.62039 .62213 L
s
.60181 .62385 m .6148 .61796 L .61382 .62448 L 0 .26 .102 r
F
0 g
.6148 .61796 m
.61621 .61901 L
s
.35218 .70024 m .34317 .70254 L .34728 .70286 L 0 1 .538 r
F
0 g
.34728 .70286 m
.34746 .70277 L
s
.34728 .70286 m
.34906 .70629 L
s
.58845 .63743 m
.58942 .63127 L
s
.53024 .97247 m .53232 .97261 L .53266 .97274 L 0 0 0 r
F
0 g
.53232 .97261 m
.53397 .97283 L
s
.2346 .62681 m .22374 .63421 L .22818 .63455 L 0 1 .488 r
F
0 g
.22818 .63455 m
.22933 .64278 L
s
.75336 .78961 m .76143 .80836 L .76474 .79764 L 0 1 .418 r
F
.75336 .78961 m .75693 .81014 L .76143 .80836 L F
0 g
.76143 .80836 m
.76401 .8155 L
s
.36921 .92067 m .36103 .91356 L .35713 .914 L 0 1 .527 r
F
.36921 .92067 m .36621 .91643 L .36103 .91356 L F
.37862 .91936 m .36621 .91643 L .36921 .92067 L 0 1 .525 r
F
0 g
.36886 .92303 m
.36921 .92067 L
s
.36921 .92067 m
.37268 .92256 L
s
.53491 .91407 m
.53573 .91707 L
s
.53442 .91229 m
.53491 .91407 L
s
.53263 .90575 m
.53442 .91229 L
s
.38651 .76991 m .37538 .77057 L .37815 .77052 L 0 .591 .198 r
F
0 g
.37465 .77114 m
.37815 .77052 L
s
.53913 .74074 m
.53917 .74204 L
s
.53913 .74066 m
.53913 .74074 L
s
.53912 .74053 m
.53913 .74066 L
s
.53911 .74018 m
.53912 .74053 L
s
.53911 .74009 m
.53911 .74018 L
s
.53888 .73272 m
.53911 .74009 L
s
.81885 .9011 m .82679 .90651 L .83003 .90137 L 0 1 .516 r
F
0 g
.82108 .91008 m
.82679 .90651 L
s
.29938 .93573 m .28537 .93591 L .28503 .93644 L 0 .653 .215 r
F
.29938 .93573 m .2897 .93568 L .28537 .93591 L F
.29938 .93573 m .29571 .9356 L .2897 .93568 L F
0 g
.29902 .93625 m
.29938 .93573 L
s
.52635 .45432 m .52027 .46113 L .52012 .45818 L 0 .131 .058 r
F
.52635 .45432 m .5271 .46233 L .52027 .46113 L F
.52635 .45432 m .53604 .46098 L .5271 .46233 L F
.52635 .45432 m .54225 .4571 L .53604 .46098 L F
.52635 .45432 m .54161 .45331 L .54225 .4571 L F
0 g
.51988 .45337 m
.52635 .45432 L
s
.54161 .45331 m
.54737 .45022 L
s
.5348 .45212 m
.54161 .45331 L
s
.23694 .92267 m .22311 .91483 L .22248 .91863 L 0 1 .522 r
F
.23694 .92267 m .22757 .91468 L .22311 .91483 L F
.23694 .92267 m .2335 .91805 L .22757 .91468 L F
.24781 .92184 m .2335 .91805 L .23694 .92267 L 0 1 .518 r
F
0 g
.23628 .92645 m
.23694 .92267 L
s
.23694 .92267 m
.24273 .92581 L
s
.39811 .76871 m .38724 .76989 L .38651 .76991 L 0 0 0 r
F
.39811 .76871 m .39124 .76964 L .38724 .76989 L F
0 g
.38651 .76991 m
.38946 .76951 L
s
.39811 .76871 m .39584 .76932 L .39124 .76964 L 0 0 0 r
F
.39811 .76871 m .39878 .76892 L .39584 .76932 L F
0 g
.39811 .76871 m
.40109 .76795 L
s
.39411 .76896 m
.39811 .76871 L
s
.50178 1.06177 m .50609 1.06573 L .50627 1.06529 L 0 .419 .312 r
F
0 g
.501 1.06312 m
.50609 1.06573 L
s
.50609 1.06573 m
.50693 1.06623 L
s
.50364 .7215 m
.50566 .73612 L
s
.65332 .68524 m
.65363 .68452 L
s
.46088 1.02394 m .45561 1.0186 L .45022 1.0154 L 0 .651 .435 r
F
.48749 .62686 m .48197 .63096 L .4833 .63003 L 0 0 0 r
F
0 g
.48305 .63034 m
.48528 .62867 L
s
.48749 .62686 m .48453 .62944 L .48197 .63096 L 0 0 0 r
F
.48749 .62686 m .48928 .62647 L .48453 .62944 L F
.48749 .62686 m .49347 .6233 L .48928 .62647 L F
.48749 .62686 m .49431 .62204 L .49347 .6233 L F
0 g
.49175 .62356 m
.49431 .62204 L
s
.49431 .62204 m
.49819 .61848 L
s
.37867 .91696 m .36708 .90504 L .36634 .91091 L 0 1 .437 r
F
0 g
.36122 .90573 m
.36634 .91091 L
s
.73469 1.07015 m .72803 1.07104 L .72565 1.0712 L 0 0 0 r
F
0 g
.71742 1.07199 m
.72565 1.0712 L
s
.78525 .9003 m .78253 .90395 L .7838 .90696 L 0 1 .486 r
F
0 g
.77763 .90938 m
.7838 .90696 L
s
.46945 .95143 m .45929 .9497 L .46031 .95177 L 0 1 .496 r
F
0 g
.45565 .95111 m
.46031 .95177 L
s
.35229 .91081 m .34738 .91516 L .35128 .91468 L 0 1 .525 r
F
.35229 .91081 m .34242 .91185 L .34738 .91516 L F
0 g
.34702 .91902 m
.34738 .91516 L
s
.35128 .91468 m
.35355 .91595 L
s
.35355 .91595 m
.35661 .91766 L
s
.57284 .87073 m .5822 .69298 L .5797 .70334 L 0 .924 .229 r
F
.57284 .87073 m .58215 .75533 L .5822 .69298 L F
0 g
.5822 .72823 m
.58252 .7507 L
s
.58217 .72654 m
.5822 .72823 L
s
.5822 .69298 m
.58347 .66757 L
s
.57806 .72812 m
.57855 .70826 L
s
.58216 .73596 m
.58218 .7115 L
s
.58218 .7115 m
.5822 .69298 L
s
.37833 .69244 m
.37937 .69488 L
s
.48583 .90164 m .48387 .89966 L .48589 .90008 L 0 0 0 r
F
.4913 .8972 m .48589 .90008 L .48387 .89966 L F
0 g
.48387 .89966 m
.48435 .89789 L
s
.48046 .90066 m
.48387 .89966 L
s
.39569 .93301 m .3916 .93935 L .39523 .93866 L 0 .963 .433 r
F
.40408 .9497 m .39523 .93866 L .3916 .93935 L 0 .925 .437 r
F
0 g
.3916 .93935 m
.39172 .94493 L
s
.38643 .93462 m
.3916 .93935 L
s
.51772 .88853 m .51921 .87694 L .52009 .87899 L 0 0 .054 r
F
0 g
.51921 .87694 m
.5193 .87675 L
s
.705 .63711 m
.70506 .63599 L
s
.64546 .66978 m
.64887 .71007 L
s
.64438 .65708 m
.64546 .66978 L
s
.64369 .64897 m
.64438 .65708 L
s
.64368 .64885 m
.64369 .64897 L
s
.64359 .64771 m
.64368 .64885 L
s
.64907 .71242 m
.64916 .71342 L
s
.64887 .71007 m
.64907 .71242 L
s
.70543 .62314 m
.70559 .62278 L
s
.70559 .62278 m
.70561 .62272 L
s
.70561 .62272 m
.70576 .62237 L
s
.32643 .88281 m .31556 .86868 L .31404 .87531 L 0 1 .456 r
F
.32643 .88281 m .31974 .86839 L .31556 .86868 L F
.32643 .88281 m .3244 .87444 L .31974 .86839 L F
.33666 .88188 m .3244 .87444 L .32643 .88281 L 0 1 .45 r
F
0 g
.32643 .88281 m
.33099 .88876 L
s
.3249 .88941 m
.32643 .88281 L
s
.82235 .79104 m .83325 .79496 L .83403 .7945 L 0 .349 .191 r
F
0 g
.82919 .79396 m
.83325 .79496 L
s
.29175 .70607 m .28055 .70473 L .28219 .70975 L 0 1 .532 r
F
0 g
.27782 .71426 m
.28219 .70975 L
s
.378 .92288 m
.38316 .92763 L
s
.37793 .92282 m
.378 .92288 L
s
.51571 .96873 m .51906 .97018 L .5188 .9698 L 0 .576 .25 r
F
.52529 .97122 m .5188 .9698 L .51906 .97018 L 0 .503 .224 r
F
0 g
.51906 .97018 m
.52248 .97099 L
s
.51602 .96983 m
.51906 .97018 L
s
.69165 .67117 m
.69339 .67597 L
s
.68251 .68106 m
.68441 .68675 L
s
.4129 .93386 m .40446 .92885 L .40082 .9295 L 0 1 .527 r
F
.4129 .93386 m .40964 .93072 L .40446 .92885 L F
0 g
.41283 .93685 m
.4129 .93386 L
s
.42186 .93209 m .4129 .93386 L .41796 .93565 L 0 1 .524 r
F
.42186 .93209 m .40964 .93072 L .4129 .93386 L F
0 g
.6477 1.06878 m
.64787 1.06884 L
s
.31995 .5923 m .31009 .58794 L .30914 .59561 L 0 1 .474 r
F
0 g
.30283 .60125 m
.30914 .59561 L
s
.31995 .5923 m .31539 .57904 L .31009 .58794 L 0 1 .474 r
F
.31995 .5923 m .32218 .57437 L .31539 .57904 L F
.31995 .5923 m .32593 .57705 L .32218 .57437 L F
.31995 .5923 m .32497 .58475 L .32593 .57705 L F
0 g
.31995 .5923 m
.31995 .5923 L
s
.45233 .65312 m
.45276 .6469 L
s
.45276 .6469 m
.45757 .64345 L
s
.45134 .63228 m .44357 .63262 L .4462 .63637 L 0 1 .346 r
F
.45134 .63228 m .44507 .62284 L .44357 .63262 L F
.45134 .63228 m .44971 .61356 L .44507 .62284 L F
0 g
.45014 .64249 m
.45134 .63228 L
s
.51444 .88207 m .51252 .88407 L .51092 .88382 L 0 0 .016 r
F
.46134 .5617 m .46966 .54214 L .46395 .54751 L 0 1 .334 r
F
0 g
.46966 .54214 m
.47369 .53387 L
s
.3055 .7076 m .29398 .70018 L .29175 .70607 L 0 1 .534 r
F
.3055 .7076 m .29972 .69646 L .29398 .70018 L F
0 g
.29175 .70607 m
.29424 .71083 L
s
.3055 .7076 m .30514 .69741 L .29972 .69646 L 0 1 .534 r
F
.3055 .7076 m .30761 .70219 L .30514 .69741 L F
0 g
.29978 .7113 m
.3055 .7076 L
s
.4136 .96581 m .40966 .95944 L .40419 .95528 L 0 .884 .441 r
F
.79865 .77564 m .80663 .76455 L .80207 .76545 L 0 1 .452 r
F
.7873 .77825 m .78953 .77774 L .78808 .77713 L 0 1 .444 r
F
.78953 .77774 m .78968 .7777 L .78808 .77713 L F
.78808 .77713 m .79895 .78224 L .79592 .78167 L 0 0 0 r
F
.78723 .77664 m .78953 .77774 L .78808 .77713 L F
.78953 .77774 m .79895 .78224 L .78808 .77713 L F
.78771 .777 m .79524 .76692 L .7907 .76798 L 0 1 .444 r
F
.7873 .77825 m .78808 .77713 L .78771 .777 L F
.78808 .77713 m .79524 .76692 L .78771 .777 L F
.78771 .777 m .78808 .77713 L .78772 .77701 L 0 0 0 r
F
.78723 .77664 m .78808 .77713 L .78771 .777 L F
.78772 .77701 m .79592 .78167 L .79122 .77961 L F
.78808 .77713 m .79592 .78167 L .78772 .77701 L F
.78808 .77713 m .79865 .77564 L .79524 .76692 L 0 1 .444 r
F
.78968 .7777 m .79865 .77564 L .78808 .77713 L F
0 g
.64006 .65226 m
.6404 .68805 L
s
.78772 .77701 m
.78772 .77701 L
s
.78771 .777 m
.78772 .77701 L
s
.7877 .77699 m
.78771 .777 L
s
.78723 .77664 m
.7877 .77699 L
s
.78662 .77655 m
.78723 .77664 L
s
.42186 .93209 m .41796 .93565 L .42146 .93488 L 0 1 .524 r
F
.42991 .93908 m .42146 .93488 L .41796 .93565 L 0 1 .525 r
F
0 g
.41796 .93565 m
.41809 .93839 L
s
.4129 .93386 m
.41796 .93565 L
s
.2811 .90364 m .26854 .89307 L .26734 .89816 L 0 1 .53 r
F
.2811 .90364 m .273 .89282 L .26854 .89307 L F
.2811 .90364 m .27839 .89736 L .273 .89282 L F
.29201 .90266 m .27839 .89736 L .2811 .90364 L 0 1 .529 r
F
0 g
.27989 .90871 m
.2811 .90364 L
s
.2811 .90364 m
.28637 .908 L
s
.5207 .60676 m .52552 .60358 L .52964 .60368 L 0 .012 .048 r
F
0 g
.52552 .60358 m
.52864 .59863 L
s
.57101 .4498 m .56717 .45529 L .56572 .45332 L 0 .032 .023 r
F
.57101 .4498 m .5751 .45554 L .56717 .45529 L F
.57101 .4498 m .58418 .4539 L .5751 .45554 L F
.57101 .4498 m .58944 .45037 L .58418 .4539 L F
0 g
.42473 .67322 m
.42962 .67072 L
s
.39569 .93301 m .38362 .92198 L .38316 .92763 L 0 .963 .433 r
F
0 g
.38316 .92763 m
.38361 .92207 L
s
.38321 .92523 m
.38361 .92205 L
s
.38326 .92282 m
.38361 .922 L
s
.46581 .48269 m .4577 .49009 L .45896 .48851 L 0 0 0 r
F
0 g
.45935 .48739 m
.46085 .48594 L
s
.46581 .48269 m .463 .48699 L .4577 .49009 L 0 0 0 r
F
.46581 .48269 m .47133 .48127 L .463 .48699 L F
.46581 .48269 m .47817 .47545 L .47133 .48127 L F
.46581 .48269 m .47897 .47342 L .47817 .47545 L F
0 g
.47368 .47652 m
.47897 .47342 L
s
.46085 .48594 m
.46581 .48269 L
s
.47897 .47342 m
.48557 .46785 L
s
.49655 .74907 m
.49702 .74812 L
s
.53263 .74467 m
.53471 .72977 L
s
.53263 .74472 m
.53263 .74467 L
s
.5326 .7449 m
.53263 .74472 L
s
.53256 .7452 m
.5326 .7449 L
s
.53204 .74891 m
.53256 .7452 L
s
.74498 .90537 m .75519 .90432 L .75077 .90388 L 0 1 .448 r
F
.73406 .90387 m .74498 .90537 L .74415 .9032 L 0 1 .416 r
F
.53413 1.08038 m .54025 1.08148 L .5396 1.08225 L 0 0 0 r
F
0 g
.53546 1.07907 m
.54025 1.08148 L
s
.5427 1.08464 m .5396 1.08225 L .54025 1.08148 L 0 .012 0 r
F
0 g
.54025 1.08148 m
.54238 1.0815 L
s
.51728 1.07191 m .51756 1.0721 L .52237 1.07476 L 0 .318 .216 r
F
0 g
.51822 1.07244 m
.52273 1.07472 L
s
.30093 .86306 m .29239 .87055 L .29787 .87008 L 0 1 .463 r
F
.30093 .86306 m .28714 .86408 L .29239 .87055 L F
0 g
.29012 .87758 m
.29239 .87055 L
s
.29787 .87008 m
.30369 .87625 L
s
.77016 .61831 m .785 .60934 L .78513 .61382 L 0 .057 .018 r
F
0 g
.785 .60934 m
.7906 .60739 L
s
.40507 .92583 m .40082 .9295 L .40446 .92885 L 0 1 .524 r
F
.40507 .92583 m .3958 .92731 L .40082 .9295 L F
0 g
.40077 .9325 m
.40082 .9295 L
s
.80312 .63906 m .81278 .64951 L .81731 .65003 L 0 1 .503 r
F
.80312 .63906 m .80671 .64482 L .81278 .64951 L F
0 g
.8111 .65395 m
.81278 .64951 L
s
.40494 .68435 m .39593 .6868 L .39986 .6867 L 0 1 .493 r
F
0 g
.39986 .6867 m
.40104 .68902 L
s
.77908 1.05533 m .78207 1.0563 L .78881 1.05248 L 0 .903 .246 r
F
0 g
.77425 1.05975 m
.78207 1.0563 L
s
.77983 1.05864 m
.78207 1.0563 L
s
.60811 .6545 m
.61044 .66502 L
s
.61324 .67768 m
.61324 .67768 L
s
.61349 .67884 m
.61369 .6797 L
s
.61369 .6797 m
.6137 .67975 L
s
.53834 .93752 m
.53864 .93745 L
s
.5381 .93757 m
.53834 .93752 L
s
.64326 .64143 m
.64352 .647 L
s
.64352 .647 m
.64361 .64886 L
s
.43114 .979 m .42415 .9813 L .42942 .98519 L 0 .787 .433 r
F
.43114 .979 m .41981 .97518 L .42415 .9813 L F
0 g
.42415 .9813 m
.42539 .98666 L
s
.37538 .77057 m .36697 .77108 L .37144 .7709 L 0 .644 .223 r
F
0 g
.37144 .7709 m
.37465 .77114 L
s
.21456 .9386 m .19967 .93623 L .20371 .93924 L 0 .98 .353 r
F
0 g
.20371 .93924 m
.20995 .94122 L
s
.4417 .99373 m .43093 .9903 L .43562 .99617 L 0 .729 .433 r
F
.4417 .99373 m .42942 .98519 L .43093 .9903 L F
0 g
.42539 .98666 m
.43093 .9903 L
s
.35292 .58786 m .34425 .58612 L .34292 .58742 L 0 .877 .241 r
F
0 g
.33675 .59104 m
.34292 .58742 L
s
.35218 .70024 m .34201 .69927 L .34317 .70254 L 0 1 .538 r
F
0 g
.33871 .70565 m
.34317 .70254 L
s
.73469 1.07015 m .73691 1.06889 L .74385 1.06741 L 0 0 0 r
F
0 g
.72912 1.07051 m
.73691 1.06889 L
s
.53573 .91708 m
.53573 .91707 L
s
.53569 .91715 m
.53573 .91708 L
s
.53469 .91894 m
.53569 .91715 L
s
.6751 1.07354 m .68609 1.0742 L .68289 1.07456 L 0 0 0 r
F
.69194 1.07756 m .68609 1.0742 L .6936 1.07457 L F
.69194 1.07756 m .68289 1.07456 L .68609 1.0742 L F
0 g
.69087 1.07371 m
.69108 1.07377 L
s
.68282 1.07311 m
.68609 1.0742 L
s
.21895 .89038 m .21287 .89662 L .21731 .89632 L 0 1 .533 r
F
.21895 .89038 m .20775 .89096 L .21287 .89662 L F
0 g
.21226 .90262 m
.21287 .89662 L
s
.21731 .89632 m
.22326 .90169 L
s
.40494 .68435 m .39529 .68463 L .39593 .6868 L 0 1 .493 r
F
.40494 .68435 m .39837 .68163 L .39529 .68463 L F
.40494 .68435 m .40345 .67928 L .39837 .68163 L F
.40494 .68435 m .40714 .67914 L .40345 .67928 L F
.40494 .68435 m .40777 .68132 L .40714 .67914 L F
0 g
.39986 .6867 m
.40494 .68435 L
s
.75336 .78961 m .75347 .80211 L .75693 .81014 L 0 1 .418 r
F
0 g
.75347 .80211 m
.75693 .81014 L
s
.75281 .81982 m
.75693 .81014 L
s
.43114 .979 m .41883 .96994 L .41981 .97518 L 0 .787 .433 r
F
0 g
.41428 .97129 m
.41981 .97518 L
s
.48583 .90164 m .47784 .90397 L .47792 .9024 L 0 0 0 r
F
0 g
.47419 .90384 m
.47792 .9024 L
s
.56031 .5989 m .55948 .60963 L .55786 .60406 L 0 .36 .099 r
F
.56031 .5989 m .56471 .61442 L .55948 .60963 L F
.56031 .5989 m .57006 .61521 L .56471 .61442 L F
.56031 .5989 m .5725 .61001 L .57006 .61521 L F
.56031 .5989 m .57041 .60232 L .5725 .61001 L F
0 g
.57041 .60232 m
.57232 .59635 L
s
.56519 .59757 m
.57041 .60232 L
s
.66556 1.07421 m .67509 1.07354 L .67755 1.07522 L 0 0 0 r
F
0 g
.67509 1.07354 m
.6751 1.07354 L
s
.6751 1.07354 m
.6751 1.07354 L
s
.46945 .95143 m .46844 .95441 L .47046 .9535 L 0 1 .496 r
F
.47817 .95573 m .47046 .9535 L .46844 .95441 L 0 1 .477 r
F
0 g
.46844 .95441 m
.46992 .95635 L
s
.4641 .95367 m
.46844 .95441 L
s
.2346 .62681 m .22361 .62579 L .22374 .63421 L 0 1 .488 r
F
0 g
.21817 .64214 m
.22374 .63421 L
s
.53776 .97435 m .5365 .97324 L .54075 .97389 L 0 0 0 r
F
0 g
.54075 .97389 m
.54115 .97391 L
s
.53776 .97435 m .53266 .97274 L .5365 .97324 L 0 0 0 r
F
0 g
.53397 .97283 m
.5365 .97324 L
s
.48836 1.04904 m .48643 1.0509 L .49146 1.05384 L 0 .419 .365 r
F
.4417 .99373 m .43562 .99617 L .44088 .99983 L 0 .729 .433 r
F
0 g
.43562 .99617 m
.43741 1.00137 L
s
.3958 .92731 m .38749 .92144 L .38362 .92198 L 0 1 .526 r
F
.3958 .92731 m .39272 .92373 L .38749 .92144 L F
.40507 .92583 m .39272 .92373 L .3958 .92731 L 0 1 .524 r
F
0 g
.39538 .93055 m
.3958 .92731 L
s
.3958 .92731 m
.40082 .9295 L
s
.53606 .92682 m
.53792 .93248 L
s
.53868 .93475 m
.53917 .93624 L
s
.47706 .63491 m .48119 .63173 L .4833 .63003 L 0 .833 .165 r
F
0 g
.48119 .63173 m
.48305 .63034 L
s
.34215 .92179 m .33743 .92397 L .34133 .92351 L 0 1 .409 r
F
.34215 .92179 m .33229 .92276 L .33743 .92397 L F
0 g
.3373 .92573 m
.33743 .92397 L
s
.34133 .92351 m
.34688 .92436 L
s
.46134 .5617 m .45397 .5649 L .45561 .5671 L 0 1 .334 r
F
0 g
.46134 .5617 m
.46134 .5617 L
s
.46134 .5617 m .45754 .5565 L .45397 .5649 L 0 1 .334 r
F
.46134 .5617 m .46395 .54751 L .45754 .5565 L F
0 g
.46134 .5617 m
.46134 .5617 L
s
.41484 .91873 m .41017 .91967 L .41396 .91906 L 0 .639 .203 r
F
.41484 .91873 m .40517 .92006 L .41017 .91967 L F
0 g
.40981 .92001 m
.41017 .91967 L
s
.45751 .65042 m .45003 .65352 L .4527 .65306 L 0 1 .253 r
F
.45751 .65042 m .45114 .65165 L .45003 .65352 L F
0 g
.45222 .65456 m
.4527 .65306 L
s
.45751 .65042 m .4553 .64869 L .45114 .65165 L 0 1 .253 r
F
.45751 .65042 m .46012 .64604 L .4553 .64869 L F
.45751 .65042 m .46237 .64549 L .46012 .64604 L F
.45751 .65042 m .46125 .64736 L .46237 .64549 L F
0 g
.46125 .64736 m
.46574 .64465 L
s
.45687 .65195 m
.45751 .65042 L
s
.4527 .65306 m
.45751 .65042 L
s
.36915 .92303 m .35694 .9218 L .35647 .92309 L 0 .971 .329 r
F
.36915 .92303 m .36084 .92142 L .35694 .9218 L F
.36915 .92303 m .36608 .92195 L .36084 .92142 L F
.37857 .92177 m .36608 .92195 L .36915 .92303 L 0 .829 .28 r
F
0 g
.36915 .92303 m
.37422 .9234 L
s
.36867 .92432 m
.36915 .92303 L
s
.62039 .62213 m .62267 .62499 L .61957 .62296 L 0 .03 0 r
F
.62039 .62213 m .62837 .62757 L .62267 .62499 L F
.62039 .62213 m .63285 .62897 L .62837 .62757 L F
.62039 .62213 m .63365 .62813 L .63285 .62897 L F
.27752 .60564 m .26647 .61181 L .27074 .61251 L 0 1 .479 r
F
0 g
.27074 .61251 m
.27115 .62036 L
s
.34691 .88107 m .34113 .88774 L .34519 .88736 L 0 1 .443 r
F
.34691 .88107 m .33666 .88188 L .34113 .88774 L F
0 g
.34006 .894 m
.34113 .88774 L
s
.64326 .64143 m
.64506 .64205 L
s
.75336 .78961 m .76474 .79764 L .76466 .7851 L 0 1 .418 r
F
0 g
.76143 .80836 m
.76474 .79764 L
s
.76474 .79764 m
.76818 .80593 L
s
.45574 .67794 m .45207 .6567 L .44854 .66537 L 0 1 .334 r
F
0 g
.45207 .6567 m
.45222 .65456 L
s
.45207 .6567 m
.45668 .65419 L
s
.74884 .61639 m .76338 .60989 L .75949 .61753 L 0 .18 .062 r
F
0 g
.76297 .60301 m
.76338 .60989 L
s
.76338 .60989 m
.76957 .60519 L
s
.77403 .90001 m .7772 .90638 L .78253 .90395 L 0 1 .468 r
F
.77403 .90001 m .7728 .90598 L .7772 .90638 L F
0 g
.7772 .90638 m
.77763 .90938 L
s
.63281 .52135 m
.63291 .5216 L
s
.63291 .5216 m
.63421 .52468 L
s
.63421 .52468 m
.63898 .53602 L
s
.63898 .53602 m
.6391 .53631 L
s
.6391 .53631 m
.63949 .53723 L
s
.63949 .53723 m
.64017 .53885 L
s
.64017 .53885 m
.64036 .5393 L
s
.69276 .90704 m
.69334 .90616 L
s
.4744 1.03682 m .47663 1.0422 L .4777 1.0413 L 0 .55 .414 r
F
.48836 1.04904 m .4777 1.0413 L .47663 1.0422 L 0 .419 .365 r
F
0 g
.47663 1.0422 m
.48037 1.04631 L
s
.47139 1.03915 m
.47663 1.0422 L
s
.28055 .70473 m .2709 .70868 L .27542 .70911 L 0 1 .53 r
F
0 g
.27542 .70911 m
.27782 .71426 L
s
.50018 .89616 m .49416 .89683 L .49469 .89435 L 0 0 .023 r
F
0 g
.49177 .89543 m
.49469 .89435 L
s
.78772 .77698 m
.78773 .77697 L
s
.78771 .777 m
.78772 .77698 L
s
.7873 .77825 m
.78771 .777 L
s
.78644 .77612 m
.78662 .77655 L
s
.78662 .77655 m
.78665 .77662 L
s
.78665 .77662 m
.7873 .77825 L
s
.44507 .62284 m .45158 .60425 L .44945 .60109 L 0 1 .358 r
F
.44507 .62284 m .44971 .61356 L .45158 .60425 L F
0 g
.45158 .60425 m
.45674 .59954 L
s
.44971 .61356 m
.45484 .60949 L
s
.44971 .61356 m
.45158 .60425 L
s
.65369 .61934 m
.65463 .62399 L
s
.64981 .60016 m
.65163 .60916 L
s
.65463 .62399 m
.65469 .62426 L
s
.65488 .62521 m
.65498 .6257 L
s
.6485 .59369 m
.64981 .60016 L
s
.6485 .59369 m
.65005 .60788 L
s
.42143 .96373 m .4136 .96581 L .41883 .96994 L 0 .837 .43 r
F
.42143 .96373 m .40966 .95944 L .4136 .96581 L F
0 g
.4136 .96581 m
.41428 .97129 L
s
.36243 .89964 m .35129 .88684 L .35009 .89294 L 0 1 .44 r
F
0 g
.34519 .88736 m
.35009 .89294 L
s
.45481 .94875 m .45125 .94661 L .44647 .94571 L 0 1 .516 r
F
.37538 .77057 m .36424 .77081 L .36697 .77108 L 0 .644 .223 r
F
0 g
.36347 .77181 m
.36697 .77108 L
s
.77123 .77026 m .76767 .76667 L .77239 .76965 L 0 .216 .019 r
F
.76245 .75153 m .77123 .77026 L .775 .76166 L 0 1 .413 r
F
.77123 .77026 m .77253 .77305 L .77299 .77091 L F
.76466 .7851 m .77597 .78136 L .77253 .77305 L 0 1 .427 r
F
.76466 .7851 m .77253 .77305 L .768 .77455 L F
.77123 .77026 m .768 .77455 L .77253 .77305 L 0 1 .413 r
F
.76657 .76865 m .76661 .76858 L .77123 .77026 L 0 .216 .019 r
F
.76661 .76858 m .76767 .76667 L .77123 .77026 L F
.76337 .7744 m .76381 .76869 L .76496 .76809 L F
.76657 .76865 m .76496 .76809 L .76767 .76667 L F
.76657 .76865 m .76496 .76809 L .768 .77455 L 0 1 .413 r
F
.76337 .7744 m .76496 .76809 L .76657 .76865 L 0 .216 .019 r
F
.76245 .75153 m .76368 .76534 L .76496 .76809 L 0 1 .413 r
F
.76245 .75153 m .76496 .76809 L .76657 .76865 L F
.76245 .75153 m .76657 .76865 L .77123 .77026 L F
.76657 .76865 m .768 .77455 L .77123 .77026 L F
.76337 .7744 m .76657 .76865 L .77123 .77026 L 0 .216 .019 r
F
.76337 .7744 m .77123 .77026 L .77558 .77547 L F
.77123 .77026 m .77239 .76965 L .77302 .7708 L F
.77123 .77026 m .77299 .77091 L .77302 .7708 L 0 1 .413 r
F
.77123 .77026 m .77302 .7708 L .77558 .77547 L 0 .216 .019 r
F
.77123 .77026 m .77302 .7708 L .775 .76166 L 0 1 .413 r
F
0 g
.77325 .76975 m
.77549 .77001 L
s
.50127 .74301 m
.50175 .72489 L
s
.42991 .93908 m .42658 .93635 L .42146 .93488 L 0 1 .525 r
F
.4381 .93721 m .42991 .93908 L .43478 .94053 L 0 1 .521 r
F
.4381 .93721 m .42658 .93635 L .42991 .93908 L F
0 g
.42991 .93908 m
.43003 .94182 L
s
.29613 .92356 m
.29613 .92356 L
s
.45301 1.00792 m .4429 1.00478 L .44791 1.01039 L 0 .659 .429 r
F
.45301 1.00792 m .44088 .99983 L .4429 1.00478 L F
0 g
.43741 1.00137 m
.4429 1.00478 L
s
.44771 .7609 m .43915 .76307 L .44361 .76137 L 0 0 0 r
F
0 g
.44361 .76137 m
.44642 .75939 L
s
.48222 .72156 m .47613 .70798 L .47871 .7182 L 0 1 .305 r
F
.47721 .73591 m .47613 .70798 L .47243 .70543 L 0 1 .311 r
F
.47721 .73591 m .47871 .7182 L .47613 .70798 L F
0 g
.47609 .69506 m
.47613 .70798 L
s
.35292 .58786 m .34957 .58566 L .34425 .58612 L 0 .877 .241 r
F
0 g
.34292 .58742 m
.34425 .58612 L
s
.35292 .58786 m .35607 .58482 L .34957 .58566 L 0 .877 .241 r
F
.35292 .58786 m .3594 .58414 L .35607 .58482 L F
.35292 .58786 m .35804 .58545 L .3594 .58414 L F
0 g
.35176 .59001 m
.35292 .58786 L
s
.34645 .5887 m
.35292 .58786 L
s
.47706 .63491 m .47081 .63853 L .47261 .63782 L 0 .833 .165 r
F
0 g
.47289 .63837 m
.4753 .63678 L
s
.47706 .63491 m .47291 .63684 L .47081 .63853 L 0 .833 .165 r
F
.47706 .63491 m .47752 .63388 L .47291 .63684 L F
.47706 .63491 m .48197 .63096 L .47752 .63388 L F
.47706 .63491 m .4833 .63003 L .48197 .63096 L F
0 g
.48119 .63173 m
.48264 .63056 L
s
.4753 .63678 m
.47706 .63491 L
s
.48834 .75441 m .48432 .7158 L .48222 .72156 L 0 .921 .3 r
F
.48834 .75441 m .48751 .72211 L .48432 .7158 L F
0 g
.48427 .70287 m
.48432 .7158 L
s
.48752 .71829 m
.48756 .70715 L
s
.32243 .92382 m .30979 .92014 L .30926 .92232 L 0 1 .456 r
F
.32243 .92382 m .31385 .91987 L .30979 .92014 L F
.32243 .92382 m .31927 .92145 L .31385 .91987 L F
.33229 .92276 m .31927 .92145 L .32243 .92382 L 0 1 .435 r
F
0 g
.32188 .92599 m
.32243 .92382 L
s
.32243 .92382 m
.32771 .92521 L
s
.46117 .94665 m .45481 .94875 L .45929 .9497 L 0 1 .507 r
F
.46117 .94665 m .45125 .94661 L .45481 .94875 L F
0 g
.45481 .94875 m
.45565 .95111 L
s
.457 .75858 m
.45913 .75807 L
s
.47721 .73591 m .47243 .70543 L .47008 .71226 L 0 1 .311 r
F
0 g
.47243 .70543 m
.47613 .70798 L
s
.47226 .69419 m
.47243 .70543 L
s
.67037 .62748 m
.6717 .62696 L
s
.6717 .62696 m
.67186 .62689 L
s
.67186 .62689 m
.67199 .62684 L
s
.67199 .62684 m
.67436 .62591 L
s
.80766 .90084 m .81574 .90589 L .81885 .9011 L 0 1 .508 r
F
0 g
.81013 .90919 m
.81574 .90589 L
s
.81574 .90589 m
.8167 .90973 L
s
.24718 .93691 m .24218 .9387 L .24649 .93839 L 0 .739 .262 r
F
.24718 .93691 m .23629 .93744 L .24218 .9387 L F
0 g
.24218 .9387 m
.24246 .94029 L
s
.24649 .93839 m
.24744 .93852 L
s
.42143 .96373 m .40921 .9541 L .40966 .95944 L 0 .837 .43 r
F
0 g
.40419 .95528 m
.40966 .95944 L
s
.75298 1.06506 m .76495 1.06187 L .76122 1.06282 L 0 .778 .23 r
F
.74385 1.06741 m .75298 1.06506 L .75562 1.06436 L 0 .71 .208 r
F
.45184 .59165 m .45814 .57068 L .45255 .57561 L 0 1 .356 r
F
0 g
.45814 .57068 m
.46134 .5617 L
s
.46292 .69327 m .45562 .6886 L .45861 .69456 L 0 1 .326 r
F
.46292 .69327 m .45574 .67794 L .45562 .6886 L F
.47008 .71226 m .46292 .69327 L .46309 .70453 L 0 1 .318 r
F
0 g
.70172 .66657 m
.70211 .66756 L
s
.69915 .66007 m
.70172 .66657 L
s
.69914 .66372 m
.69915 .66007 L
s
.46703 .64274 m .46012 .64604 L .46237 .64549 L 0 .946 .208 r
F
.46703 .64274 m .46174 .64424 L .46012 .64604 L F
0 g
.46125 .64736 m
.46237 .64549 L
s
.46703 .64274 m .46615 .64128 L .46174 .64424 L 0 .946 .208 r
F
.46703 .64274 m .47081 .63853 L .46615 .64128 L F
.46703 .64274 m .47261 .63782 L .47081 .63853 L F
.46703 .64274 m .47099 .63963 L .47261 .63782 L F
0 g
.47099 .63963 m
.47289 .63837 L
s
.47261 .63782 m
.47706 .63491 L
s
.46574 .64465 m
.46703 .64274 L
s
.46237 .64549 m
.46703 .64274 L
s
.47099 .63963 m
.47261 .63782 L
s
.37145 .5792 m .36492 .58303 L .36319 .58338 L 0 .85 .171 r
F
.37145 .5792 m .36867 .581 L .36492 .58303 L F
0 g
.36652 .58339 m
.36747 .58165 L
s
.37145 .5792 m .37193 .57865 L .36867 .581 L 0 .85 .171 r
F
.37145 .5792 m .37311 .57788 L .37193 .57865 L F
0 g
.37145 .5792 m
.37268 .5793 L
s
.37311 .57788 m
.37678 .5757 L
s
.45574 .67794 m .44813 .67556 L .45113 .68046 L 0 1 .334 r
F
.45574 .67794 m .44854 .66537 L .44813 .67556 L F
.4744 1.03682 m .46893 1.03175 L .4637 1.02871 L 0 .55 .414 r
F
.77403 .90001 m .77144 .90326 L .7728 .90598 L 0 1 .468 r
F
0 g
.76676 .9081 m
.7728 .90598 L
s
.28055 .70473 m .26933 .70335 L .2709 .70868 L 0 1 .53 r
F
0 g
.2665 .71344 m
.2709 .70868 L
s
.45301 1.00792 m .44791 1.01039 L .4531 1.01386 L 0 .659 .429 r
F
0 g
.44791 1.01039 m
.45022 1.0154 L
s
.35218 .70024 m .34458 .69523 L .34201 .69927 L 0 1 .538 r
F
.35218 .70024 m .34949 .6926 L .34458 .69523 L F
.35218 .70024 m .35346 .69313 L .34949 .6926 L F
.35218 .70024 m .35461 .69641 L .35346 .69313 L F
0 g
.35218 .70024 m
.35345 .70326 L
s
.34746 .70277 m
.35218 .70024 L
s
.43104 .91639 m .41965 .91826 L .41906 .91831 L 0 0 0 r
F
0 g
.58493 .46518 m
.59234 .47446 L
s
.57971 .46715 m
.58493 .46518 L
s
.34242 .91185 m .33055 .90381 L .32968 .90789 L 0 1 .526 r
F
.34242 .91185 m .33461 .9035 L .33055 .90381 L F
.34242 .91185 m .3397 .90695 L .33461 .9035 L F
.35229 .91081 m .3397 .90695 L .34242 .91185 L 0 1 .525 r
F
0 g
.34242 .91185 m
.34738 .91516 L
s
.34154 .91592 m
.34242 .91185 L
s
.50018 .89616 m .49957 .89208 L .5007 .89368 L 0 0 .023 r
F
.50487 .89169 m .5007 .89368 L .49957 .89208 L 0 0 .02 r
F
0 g
.49957 .89208 m
.50048 .88929 L
s
.49699 .89237 m
.49957 .89208 L
s
.6539 .63465 m
.6573 .63468 L
s
.6573 .63468 m
.65746 .63468 L
s
.40408 .9497 m .40058 .94309 L .39523 .93866 L 0 .925 .437 r
F
.44771 .7609 m .43667 .76513 L .43915 .76307 L 0 0 0 r
F
.44771 .7609 m .43784 .76618 L .43667 .76513 L F
.44771 .7609 m .44195 .76571 L .43784 .76618 L F
.44771 .7609 m .44625 .76403 L .44195 .76571 L F
.44771 .7609 m .44872 .76197 L .44625 .76403 L F
0 g
.44771 .7609 m
.45031 .75833 L
s
.44361 .76137 m
.44771 .7609 L
s
.63503 .75778 m
.63518 .75437 L
s
.63533 .75076 m
.63569 .74238 L
s
.63569 .74238 m
.6358 .7399 L
s
.28052 .91959 m .27507 .92283 L .27939 .92246 L 0 1 .499 r
F
.28052 .91959 m .2696 .92029 L .27507 .92283 L F
0 g
.2748 .92577 m
.27507 .92283 L
s
.27939 .92246 m
.28546 .92464 L
s
.45475 .91211 m .45094 .91195 L .45413 .91155 L 0 0 0 r
F
.45475 .91211 m .44655 .91298 L .45094 .91195 L F
.46104 .90894 m .45413 .91155 L .45094 .91195 L F
0 g
.45078 .91133 m
.45094 .91195 L
s
.37231 .89871 m .36708 .90504 L .37098 .90462 L 0 1 .433 r
F
.37231 .89871 m .36243 .89964 L .36708 .90504 L F
.37867 .91696 m .37098 .90462 L .36708 .90504 L 0 1 .437 r
F
0 g
.36634 .91091 m
.36708 .90504 L
s
.42295 .76594 m .41422 .76694 L .41881 .76604 L 0 0 0 r
F
0 g
.41881 .76604 m
.42183 .76492 L
s
.4381 .93721 m .43478 .94053 L .43796 .93973 L 0 1 .521 r
F
.44611 .94325 m .43796 .93973 L .43478 .94053 L 0 1 .52 r
F
0 g
.43478 .94053 m
.43515 .94299 L
s
.42991 .93908 m
.43478 .94053 L
s
.33666 .88188 m .32602 .86797 L .3244 .87444 L 0 1 .45 r
F
.33666 .88188 m .3302 .86771 L .32602 .86797 L F
.33666 .88188 m .33476 .87368 L .3302 .86771 L F
.34691 .88107 m .33476 .87368 L .33666 .88188 L 0 1 .443 r
F
0 g
.33666 .88188 m
.34113 .88774 L
s
.33504 .88834 m
.33666 .88188 L
s
.24781 .92184 m .23425 .91448 L .2335 .91805 L 0 1 .518 r
F
.24781 .92184 m .23871 .91434 L .23425 .91448 L F
.24781 .92184 m .24453 .91751 L .23871 .91434 L F
.2587 .92105 m .24453 .91751 L .24781 .92184 L 0 1 .513 r
F
0 g
.24704 .9254 m
.24781 .92184 L
s
.24781 .92184 m
.2535 .92478 L
s
.50611 .96602 m .50229 .96485 L .49892 .96454 L 0 .659 .324 r
F
.80312 .63906 m .81731 .65003 L .81794 .64581 L 0 1 .503 r
F
0 g
.80671 .64482 m
.81278 .64951 L
s
.80599 .64864 m
.80671 .64482 L
s
.81731 .65003 m
.82247 .65555 L
s
.37867 .91696 m .37595 .90973 L .37098 .90462 L 0 1 .437 r
F
0 g
.37837 .91931 m
.37867 .91696 L
s
.38852 .91575 m .37867 .91696 L .38362 .92198 L 0 .999 .429 r
F
.38852 .91575 m .37596 .90973 L .37867 .91696 L F
.31144 .86235 m .30511 .86948 L .30929 .86915 L 0 1 .458 r
F
.31144 .86235 m .30093 .86306 L .30511 .86948 L F
0 g
.3037 .87625 m
.30511 .86948 L
s
.30929 .86915 m
.31404 .87531 L
s
.40517 .92006 m .39332 .92071 L .39276 .92129 L 0 .722 .232 r
F
.49659 .96299 m .49283 .96168 L .48915 .96134 L 0 .812 .396 r
F
.44655 .91298 m .4392 .91509 L .43569 .91558 L 0 0 0 r
F
.44655 .91298 m .44385 .91398 L .4392 .91509 L F
.45475 .91211 m .44385 .91398 L .44655 .91298 L F
0 g
.44655 .91298 m
.45094 .91195 L
s
.44618 .91273 m
.44655 .91298 L
s
.36424 .77081 m .35613 .77129 L .36041 .77125 L 0 .685 .242 r
F
0 g
.36041 .77125 m
.36347 .77181 L
s
.53024 .97247 m .52872 .97204 L .52945 .97216 L 0 0 0 r
F
0 g
.52945 .97216 m
.53099 .9724 L
s
.39107 .68929 m
.39593 .6868 L
s
.38651 .76991 m .37616 .7703 L .37538 .77057 L 0 .591 .198 r
F
.38651 .76991 m .38006 .77003 L .37616 .7703 L F
.38651 .76991 m .38448 .76994 L .38006 .77003 L F
.38651 .76991 m .38724 .76989 L .38448 .76994 L F
0 g
.54075 .97389 m
.54127 .97405 L
s
.46104 .90894 m .45846 .91027 L .45413 .91155 L 0 0 0 r
F
.46838 .90866 m .46104 .90894 L .46509 .90785 L F
.46838 .90866 m .45846 .91027 L .46104 .90894 L F
0 g
.46086 .90833 m
.46104 .90894 L
s
.47281 .75614 m
.47289 .75609 L
s
.47289 .75609 m
.47313 .75596 L
s
.36243 .89964 m .35535 .88652 L .35129 .88684 L 0 1 .44 r
F
.36243 .89964 m .36013 .89201 L .35535 .88652 L F
.37231 .89871 m .36013 .89201 L .36243 .89964 L 0 1 .433 r
F
0 g
.36243 .89964 m
.36708 .90504 L
s
.36122 .90573 m
.36243 .89964 L
s
.31567 .90075 m .31026 .90557 L .31432 .90519 L 0 1 .526 r
F
.31567 .90075 m .30543 .90153 L .31026 .90557 L F
0 g
.30965 .91002 m
.31026 .90557 L
s
.31432 .90519 m
.31764 .90751 L
s
.31764 .90751 m
.31966 .90891 L
s
.40446 .92885 m
.40716 .92982 L
s
.40716 .92982 m
.40964 .93072 L
s
.42186 .93209 m .41003 .92793 L .40964 .93072 L 0 1 .524 r
F
.23015 .88981 m .22398 .89587 L .22843 .89557 L 0 1 .532 r
F
.23015 .88981 m .21895 .89038 L .22398 .89587 L F
0 g
.22326 .90169 m
.22398 .89587 L
s
.22843 .89557 m
.23426 .90077 L
s
.41268 .94793 m .40408 .9497 L .40921 .9541 L 0 .881 .427 r
F
.41268 .94793 m .40058 .94309 L .40408 .9497 L F
0 g
.40408 .9497 m
.40419 .95528 L
s
.57696 .66828 m
.57755 .66588 L
s
.57755 .66588 m
.57772 .66516 L
s
.57586 .67279 m
.57683 .66881 L
s
.57683 .66881 m
.57696 .66828 L
s
.73406 .90387 m .74415 .9032 L .73974 .90273 L 0 1 .416 r
F
.72063 .90185 m .73406 .90387 L .73235 .9019 L 0 .872 .36 r
F
.34201 .69927 m .33288 .70149 L .337 .70195 L 0 1 .54 r
F
0 g
.337 .70195 m
.33871 .70565 L
s
.77868 .77301 m
.77872 .77288 L
s
.77597 .78136 m
.77868 .77301 L
s
.77346 .77528 m
.77597 .78136 L
s
.2346 .62681 m .2279 .61486 L .22361 .62579 L 0 1 .488 r
F
.2346 .62681 m .23434 .60708 L .2279 .61486 L F
.2346 .62681 m .23864 .60767 L .23434 .60708 L F
.2346 .62681 m .23875 .61614 L .23864 .60767 L F
0 g
.2346 .62681 m
.23483 .63505 L
s
.22818 .63455 m
.2346 .62681 L
s
.5427 1.08464 m .54562 1.08365 L .54483 1.08466 L 0 .012 0 r
F
0 g
.54457 1.08229 m
.54562 1.08365 L
s
.38852 .91575 m .38362 .92198 L .38749 .92144 L 0 .999 .429 r
F
.38848 .91819 m .38362 .92198 L .38749 .92144 L 0 1 .523 r
F
.38843 .92063 m .38362 .92198 L .38749 .92144 L 0 .742 .251 r
F
.38848 .91819 m .37862 .91936 L .38362 .92198 L 0 1 .523 r
F
.38843 .92063 m .37857 .92177 L .38362 .92198 L 0 .742 .251 r
F
0 g
.37867 .91696 m
.38079 .91911 L
s
.38754 .92144 m
.38762 .92144 L
s
.39569 .93301 m .38749 .92144 L .38362 .92198 L 0 .963 .433 r
F
0 g
.38361 .92205 m
.38362 .92198 L
s
.38361 .922 m
.38362 .92198 L
s
.38361 .92207 m
.38362 .92198 L
s
.29201 .90266 m .2797 .89245 L .27839 .89736 L 0 1 .529 r
F
.29201 .90266 m .28417 .89222 L .2797 .89245 L F
.29201 .90266 m .28945 .8966 L .28417 .89222 L F
0 g
.29069 .90754 m
.29201 .90266 L
s
.30543 .90153 m .28945 .8966 L .29202 .90266 L 0 1 .528 r
F
0 g
.29202 .90266 m
.29792 .90679 L
s
.45184 .59165 m .4441 .5938 L .44624 .59661 L 0 1 .356 r
F
.45184 .59165 m .4468 .58479 L .4441 .5938 L F
.45184 .59165 m .45255 .57561 L .4468 .58479 L F
.51412 .8921 m .51252 .88407 L .51444 .88207 L 0 0 .053 r
F
0 g
.51444 .88207 m
.51557 .88355 L
s
.51444 .88207 m
.51454 .88185 L
s
.37832 .69244 m .36934 .69454 L .3733 .69472 L 0 1 .524 r
F
0 g
.3733 .69472 m
.37465 .69753 L
s
.27752 .60564 m .267 .60362 L .26647 .61181 L 0 1 .479 r
F
0 g
.26037 .61888 m
.26647 .61181 L
s
.40517 .92006 m .3972 .92026 L .39332 .92071 L 0 .722 .232 r
F
.40517 .92006 m .40228 .91998 L .3972 .92026 L F
0 g
.4046 .92065 m
.40517 .92006 L
s
.41484 .91873 m .40229 .91998 L .40517 .92006 L 0 .639 .203 r
F
0 g
.41396 .91906 m
.41906 .91831 L
s
.40517 .92006 m
.41017 .91967 L
s
.31009 .58794 m .29905 .59232 L .30309 .59363 L 0 1 .467 r
F
0 g
.30283 .60125 m
.30309 .59363 L
s
.5207 .60676 m .51736 .61327 L .51719 .61092 L 0 .012 .048 r
F
.5207 .60676 m .52149 .61338 L .51736 .61327 L F
.5207 .60676 m .52682 .61116 L .52149 .61338 L F
.5207 .60676 m .53032 .607 L .52682 .61116 L F
.5207 .60676 m .52964 .60368 L .53032 .607 L F
0 g
.51695 .60732 m
.5207 .60676 L
s
.52964 .60368 m
.5327 .59864 L
s
.52552 .60358 m
.52964 .60368 L
s
.46117 .94665 m .45069 .94443 L .45125 .94661 L 0 1 .507 r
F
0 g
.44647 .94571 m
.45125 .94661 L
s
.75018 .81309 m
.75347 .80211 L
s
.42146 .93488 m
.42572 .93611 L
s
.49261 .74394 m .49439 .7399 L .49443 .72489 L 0 .923 .295 r
F
0 g
.49439 .7399 m
.49443 .72489 L
s
.49443 .72489 m
.4971 .73404 L
s
.43114 .979 m .42942 .98519 L .43211 .98424 L 0 .787 .433 r
F
.4417 .99373 m .43211 .98424 L .42942 .98519 L 0 .729 .433 r
F
0 g
.42942 .98519 m
.43093 .9903 L
s
.42415 .9813 m
.42942 .98519 L
s
.46838 .90866 m .46509 .90785 L .46792 .90771 L 0 0 0 r
F
.47423 .90488 m .46792 .90771 L .46509 .90785 L F
0 g
.46507 .9068 m
.46509 .90785 L
s
.46104 .90894 m
.46509 .90785 L
s
.30093 .86306 m .28562 .85496 L .28714 .86408 L 0 1 .463 r
F
0 g
.28714 .86408 m
.29239 .87055 L
s
.36424 .77081 m .35358 .7707 L .35613 .77129 L 0 .685 .242 r
F
0 g
.35277 .77213 m
.35613 .77129 L
s
.71088 .60902 m
.71089 .62196 L
s
.71234 .62535 m
.71575 .63206 L
s
.27752 .60564 m .27198 .59338 L .267 .60362 L 0 1 .479 r
F
.27752 .60564 m .27878 .58648 L .27198 .59338 L F
.27752 .60564 m .28284 .58755 L .27878 .58648 L F
.27752 .60564 m .2823 .59577 L .28284 .58755 L F
0 g
.27713 .61357 m
.27752 .60564 L
s
.27074 .61251 m
.27752 .60564 L
s
.69557 .65797 m .71089 .6225 L .71173 .63495 L 0 .216 .109 r
F
0 g
.71089 .6225 m
.71089 .6225 L
s
.71089 .6225 m
.71234 .62535 L
s
.69924 .63743 m
.70543 .62314 L
s
.69908 .623 m
.69924 .63743 L
s
.74367 .82013 m
.74392 .81953 L
s
.74403 .81926 m
.74569 .81525 L
s
.51571 .96873 m .51187 .96768 L .50883 .96734 L 0 .576 .25 r
F
.22361 .62579 m .21263 .63339 L .21708 .63372 L 0 1 .491 r
F
0 g
.21708 .63372 m
.21817 .64214 L
s
.81918 .73834 m .82943 .76081 L .83188 .75019 L 0 1 .455 r
F
.81918 .73834 m .82486 .76147 L .82943 .76081 L F
0 g
.82943 .76081 m
.83276 .76999 L
s
.29175 .70607 m .28288 .69844 L .28055 .70473 L 0 1 .532 r
F
.29175 .70607 m .28794 .69432 L .28288 .69844 L F
.29175 .70607 m .29235 .69514 L .28794 .69432 L F
.29175 .70607 m .29398 .70018 L .29235 .69514 L F
0 g
.2867 .71017 m
.29175 .70607 L
s
.81918 .73834 m .82047 .75185 L .82486 .76147 L 0 1 .455 r
F
0 g
.82138 .77158 m
.82486 .76147 L
s
.78881 1.05248 m .79852 1.05001 L .80082 1.04764 L 0 1 .276 r
F
.42143 .96373 m .41883 .96994 L .42186 .96907 L 0 .837 .43 r
F
.43114 .979 m .42186 .96907 L .41883 .96994 L 0 .787 .433 r
F
0 g
.41883 .96994 m
.41981 .97518 L
s
.4136 .96581 m
.41883 .96994 L
s
.50512 .46232 m .51363 .45869 L .52012 .45818 L 0 0 .034 r
F
0 g
.51363 .45869 m
.51988 .45337 L
s
.46496 1.02157 m .45561 1.0186 L .46088 1.02394 L 0 .571 .418 r
F
.46496 1.02157 m .4531 1.01386 L .45561 1.0186 L F
0 g
.45022 1.0154 m
.45561 1.0186 L
s
.44653 .49926 m .45418 .49244 L .45896 .48851 L 0 0 0 r
F
0 g
.45418 .49244 m
.45935 .48739 L
s
.76934 1.05862 m .76495 1.06187 L .77259 1.05867 L 0 .841 .229 r
F
.76934 1.05862 m .76122 1.06282 L .76495 1.06187 L F
0 g
.76209 1.06306 m
.76495 1.06187 L
s
.8078 .74024 m .81802 .76254 L .82047 .75185 L 0 1 .448 r
F
.8078 .74024 m .81346 .7633 L .81802 .76254 L F
0 g
.81802 .76254 m
.82138 .77158 L
s
.43853 .76317 m
.43915 .76307 L
s
.43517 .76369 m
.43853 .76317 L
s
.48725 .95958 m .48357 .9581 L .47963 .95767 L 0 .927 .446 r
F
.49261 .74394 m .48751 .72211 L .48966 .73631 L 0 .923 .295 r
F
.48834 .75441 m .48966 .73631 L .48751 .72211 L 0 .921 .3 r
F
0 g
.48751 .72211 m
.48752 .71829 L
s
.48432 .7158 m
.48751 .72211 L
s
.8078 .74024 m .80908 .75376 L .81346 .7633 L 0 1 .448 r
F
0 g
.81 .77345 m
.81346 .7633 L
s
.37862 .91936 m .36689 .91296 L .36621 .91643 L 0 1 .525 r
F
.26933 .70335 m .25961 .70758 L .26413 .70802 L 0 1 .529 r
F
0 g
.26413 .70802 m
.2665 .71344 L
s
.41268 .94793 m .40068 .93768 L .40058 .94309 L 0 .881 .427 r
F
0 g
.39523 .93866 m
.40058 .94309 L
s
.7628 .89971 m .7662 .90537 L .77144 .90326 L 0 1 .445 r
F
.7628 .89971 m .7618 .90496 L .7662 .90537 L F
0 g
.7662 .90537 m
.76676 .9081 L
s
.46117 .94665 m .45929 .9497 L .46172 .94883 L 0 1 .507 r
F
.46945 .95143 m .46172 .94883 L .45929 .9497 L 0 1 .496 r
F
0 g
.45929 .9497 m
.46031 .95177 L
s
.45481 .94875 m
.45929 .9497 L
s
.55618 .79839 m
.55643 .80052 L
s
.55618 .79839 m
.5562 .79843 L
s
.5562 .79843 m
.55822 .80271 L
s
.55822 .80271 m
.55854 .80338 L
s
.53024 .97247 m .53266 .97274 L .53179 .97271 L 0 0 0 r
F
0 g
.53232 .97261 m
.53266 .97274 L
s
.53776 .97435 m .53179 .97271 L .53266 .97274 L 0 0 0 r
F
0 g
.53266 .97274 m
.5365 .97324 L
s
.41237 .67684 m
.41278 .67885 L
s
.40777 .68132 m
.41278 .67885 L
s
.21456 .9386 m .19995 .93394 L .19967 .93623 L 0 .98 .353 r
F
.21456 .9386 m .20441 .93392 L .19995 .93394 L F
.21456 .9386 m .21068 .93593 L .20441 .93392 L F
.22542 .938 m .21068 .93593 L .21456 .9386 L 0 .902 .324 r
F
0 g
.21424 .94087 m
.21456 .9386 L
s
.21456 .9386 m
.22068 .94035 L
s
.70886 .88268 m
.71262 .87506 L
s
.36218 .90989 m .35713 .914 L .36103 .91356 L 0 1 .523 r
F
.36218 .90989 m .35229 .91081 L .35713 .914 L F
0 g
.35661 .91766 m
.35713 .914 L
s
.36103 .91356 m
.3632 .91476 L
s
.3632 .91476 m
.36621 .91643 L
s
.79643 .74243 m .80663 .76455 L .80908 .75376 L 0 1 .44 r
F
.79643 .74243 m .80207 .76545 L .80663 .76455 L F
0 g
.80663 .76455 m
.81 .77345 L
s
.4381 .93721 m .42671 .93383 L .42658 .93635 L 0 1 .521 r
F
0 g
.42572 .93611 m
.42658 .93635 L
s
.5026 1.06067 m .49561 1.05753 L .50178 1.06177 L 0 .345 .268 r
F
.5026 1.06067 m .49146 1.05384 L .49561 1.05753 L F
.34425 .58612 m .33221 .58129 L .33681 .58424 L 0 .418 .366 r
F
0 g
.33674 .59104 m
.33681 .58424 L
s
.4417 .99373 m .44088 .99983 L .4432 .99884 L 0 .729 .433 r
F
.45301 1.00792 m .4432 .99884 L .44088 .99983 L 0 .659 .429 r
F
0 g
.44088 .99983 m
.4429 1.00478 L
s
.43562 .99617 m
.44088 .99983 L
s
.42774 .6703 m .4208 .67149 L .42433 .6712 L 0 1 .447 r
F
.42774 .6703 m .41898 .67103 L .4208 .67149 L F
0 g
.42433 .6712 m
.42433 .67121 L
s
.42433 .67121 m
.42473 .67322 L
s
.42774 .6703 m .4201 .67013 L .41898 .67103 L 0 1 .447 r
F
.42774 .6703 m .42351 .66922 L .4201 .67013 L F
.42774 .6703 m .42695 .66892 L .42351 .66922 L F
.42774 .6703 m .42876 .66938 L .42695 .66892 L F
0 g
.42774 .6703 m
.42962 .67072 L
s
.42433 .6712 m
.42774 .6703 L
s
.42876 .66938 m
.43209 .66841 L
s
.44507 .62284 m .44945 .60109 L .44407 .60565 L 0 1 .358 r
F
0 g
.44945 .60109 m
.45184 .59165 L
s
.44003 .91532 m .43569 .91558 L .4392 .91509 L 0 0 0 r
F
.44003 .91532 m .43104 .91639 L .43569 .91558 L F
0 g
.43534 .91532 m
.43569 .91558 L
s
.79643 .74243 m .7977 .75598 L .80207 .76545 L 0 1 .44 r
F
0 g
.79865 .77564 m
.80207 .76545 L
s
.54578 .82598 m
.54627 .82865 L
s
.37098 .90462 m
.37595 .90973 L
s
.53483 .89875 m
.53492 .89908 L
s
.53492 .89908 m
.53495 .89919 L
s
.53565 .90175 m
.53627 .90401 L
s
.53675 .90576 m
.53735 .90795 L
s
.65304 .62866 m
.65307 .62889 L
s
.65256 .6253 m
.65266 .62602 L
s
.65287 .62746 m
.65304 .62866 L
s
.65188 .62059 m
.65251 .62495 L
s
.65179 .61994 m
.65188 .62059 L
s
.65253 .62508 m
.65256 .6253 L
s
.65047 .61077 m
.65179 .61994 L
s
.65005 .60788 m
.65047 .61077 L
s
.79646 .90057 m .80468 .90526 L .80766 .90084 L 0 1 .499 r
F
0 g
.79917 .90827 m
.80468 .90526 L
s
.80468 .90526 m
.80575 .90882 L
s
.53572 .89511 m
.53583 .89558 L
s
.53665 .89915 m
.53695 .90044 L
s
.38852 .91575 m .37698 .90403 L .37596 .90973 L 0 .999 .429 r
F
0 g
.77549 .77001 m
.77868 .77301 L
s
.68301 .91455 m
.68336 .91531 L
s
.50964 .88699 m .50772 .8889 L .50578 .88889 L 0 0 .018 r
F
.35716 .8804 m .35129 .88684 L .35535 .88652 L 0 1 .436 r
F
.35716 .8804 m .34691 .88107 L .35129 .88684 L F
0 g
.35009 .89294 m
.35129 .88684 L
s
.35358 .7707 m .34543 .77121 L .34971 .77127 L 0 .714 .256 r
F
0 g
.34971 .77127 m
.35277 .77213 L
s
.37862 .91936 m .3708 .91259 L .36689 .91296 L 0 1 .525 r
F
.37862 .91936 m .37583 .91534 L .3708 .91259 L F
0 g
.37814 .92178 m
.37862 .91936 L
s
.38848 .91819 m .37583 .91534 L .37862 .91936 L 0 1 .523 r
F
0 g
.37862 .91936 m
.38238 .92133 L
s
.34201 .69927 m .33182 .69793 L .33288 .70149 L 0 1 .54 r
F
0 g
.32835 .70472 m
.33288 .70149 L
s
.47721 .73591 m .47917 .73018 L .47871 .7182 L 0 1 .311 r
F
0 g
.47871 .7182 m
.47917 .73018 L
s
.48834 .75441 m .48222 .72156 L .48257 .73538 L 0 .921 .3 r
F
0 g
.48222 .72156 m
.48251 .733 L
s
.47871 .7182 m
.48222 .72156 L
s
.44854 .66537 m .4406 .66466 L .44362 .66879 L 0 1 .344 r
F
.63923 .63491 m .64211 .63004 L .63874 .63003 L 0 1 .414 r
F
.63923 .63491 m .64779 .63202 L .64211 .63004 L F
0 g
.63365 .62813 m
.63923 .63491 L
s
.40507 .92583 m .39332 .92071 L .39272 .92373 L 0 1 .524 r
F
0 g
.38989 .92249 m
.39272 .92373 L
s
.38762 .92144 m
.38775 .92144 L
s
.38775 .92144 m
.39276 .92129 L
s
.50178 1.06177 m
.50627 1.06529 L
s
.50627 1.06529 m
.50686 1.06561 L
s
.50686 1.06561 m
.50732 1.06587 L
s
.50732 1.06587 m
.51107 1.06794 L
s
.42295 .76594 m .41156 .76809 L .41422 .76694 L 0 0 0 r
F
0 g
.41031 .7673 m
.41422 .76694 L
s
.4413 .65485 m .4462 .63637 L .44357 .63262 L 0 1 .354 r
F
.4413 .65485 m .44523 .64589 L .4462 .63637 L F
0 g
.4462 .63637 m
.45134 .63228 L
s
.44523 .64589 m
.45014 .64249 L
s
.44523 .64589 m
.4462 .63637 L
s
.45644 .71204 m .45861 .69456 L .45562 .6886 L 0 1 .332 r
F
.45644 .71204 m .45896 .7046 L .45861 .69456 L F
0 g
.45861 .69456 m
.46292 .69327 L
s
.51412 .8921 m .51123 .88827 L .51252 .88407 L 0 0 .053 r
F
0 g
.51092 .88382 m
.51252 .88407 L
s
.32196 .86173 m .31556 .86868 L .31974 .86839 L 0 1 .452 r
F
.32196 .86173 m .31144 .86235 L .31556 .86868 L F
0 g
.31404 .87531 m
.31556 .86868 L
s
.31974 .86839 m
.3244 .87444 L
s
.78508 .74497 m .79524 .76692 L .7977 .75598 L 0 1 .432 r
F
.78508 .74497 m .7907 .76798 L .79524 .76692 L F
0 g
.79524 .76692 m
.79865 .77564 L
s
.41268 .94793 m .40921 .9541 L .41257 .95334 L 0 .881 .427 r
F
.42143 .96373 m .41257 .95334 L .40921 .9541 L 0 .837 .43 r
F
0 g
.40921 .9541 m
.40966 .95944 L
s
.40408 .9497 m
.40921 .9541 L
s
.45644 .71204 m .45562 .6886 L .45122 .69014 L 0 1 .332 r
F
0 g
.45562 .6886 m
.45574 .67794 L
s
.31009 .58794 m .30019 .58396 L .29905 .59232 L 0 1 .467 r
F
0 g
.29258 .59841 m
.29905 .59232 L
s
.31009 .58794 m .30576 .57411 L .30019 .58396 L 0 1 .467 r
F
.31009 .58794 m .31277 .5684 L .30576 .57411 L F
.31009 .58794 m .31654 .57066 L .31277 .5684 L F
.31009 .58794 m .31539 .57904 L .31654 .57066 L F
0 g
.30914 .59561 m
.31009 .58794 L
s
.30309 .59363 m
.31009 .58794 L
s
.49894 .73027 m
.50127 .74301 L
s
.46496 1.02157 m .46088 1.02394 L .46596 1.02725 L 0 .571 .418 r
F
0 g
.46088 1.02394 m
.4637 1.02871 L
s
.5328 1.08171 m .52751 1.07713 L .53413 1.08038 L 0 0 0 r
F
.5328 1.08171 m .52237 1.07476 L .52751 1.07713 L F
0 g
.52273 1.07472 m
.52751 1.07713 L
s
.47008 .71226 m .46309 .70453 L .46607 .71187 L 0 1 .318 r
F
.47721 .73591 m .47008 .71226 L .47053 .72423 L 0 1 .311 r
F
.26933 .70335 m .2581 .70196 L .25961 .70758 L 0 1 .529 r
F
0 g
.25516 .71259 m
.25961 .70758 L
s
.7628 .89971 m .76033 .90254 L .7618 .90496 L 0 1 .445 r
F
0 g
.75587 .90677 m
.7618 .90496 L
s
.58948 .63584 m
.591 .63348 L
s
.58845 .63743 m
.58948 .63584 L
s
.69194 1.07756 m .68539 1.076 L .68289 1.07456 L 0 0 0 r
F
0 g
.6751 1.07354 m
.68289 1.07456 L
s
.58344 .73936 m
.58604 .70724 L
s
.78508 .74497 m .78634 .75858 L .7907 .76798 L 0 1 .432 r
F
0 g
.78773 .77697 m
.7907 .76798 L
s
.78085 .61878 m .79162 .61078 L .79603 .61164 L 0 0 0 r
F
.78085 .61878 m .78513 .61382 L .79162 .61078 L F
0 g
.7906 .60739 m
.79162 .61078 L
s
.42295 .76594 m .41261 .76871 L .41156 .76809 L 0 0 0 r
F
.42295 .76594 m .41677 .76862 L .41261 .76871 L F
.42295 .76594 m .42125 .76786 L .41677 .76862 L F
.42295 .76594 m .4239 .76671 L .42125 .76786 L F
0 g
.42295 .76594 m
.42569 .7644 L
s
.41881 .76604 m
.42295 .76594 L
s
.37832 .69244 m .36855 .69197 L .36934 .69454 L 0 1 .524 r
F
0 g
.36464 .69717 m
.36934 .69454 L
s
.37832 .69244 m .37148 .68872 L .36855 .69197 L 0 1 .524 r
F
.37832 .69244 m .37652 .68642 L .37148 .68872 L F
.37832 .69244 m .3803 .68662 L .37652 .68642 L F
.37832 .69244 m .38107 .6892 L .3803 .68662 L F
0 g
.3733 .69472 m
.37832 .69244 L
s
.35358 .7707 m .34292 .77031 L .34543 .77121 L 0 .714 .256 r
F
0 g
.34207 .77221 m
.34543 .77121 L
s
.37231 .89871 m .36145 .8861 L .36013 .89201 L 0 1 .433 r
F
0 g
.35535 .88652 m
.36013 .89201 L
s
.70895 1.07357 m .72044 1.07231 L .71696 1.07312 L 0 0 0 r
F
.70046 1.07542 m .70895 1.07357 L .71173 1.07443 L F
0 g
.74484 .81336 m
.74569 .81525 L
s
.4913 .8972 m .48908 .89902 L .48589 .90008 L 0 0 0 r
F
.49561 .9004 m .4913 .8972 L .49416 .89683 L 0 0 .026 r
F
.49561 .9004 m .48908 .89902 L .4913 .8972 L F
0 g
.4913 .8972 m
.49177 .89543 L
s
.52239 .88392 m .52058 .88256 L .52146 .8775 L 0 0 .057 r
F
0 g
.52146 .8775 m
.52164 .87702 L
s
.51958 .8867 m .52146 .8775 L .52058 .88256 L 0 0 .057 r
F
0 g
.52146 .8775 m
.52146 .8775 L
s
.51921 .87694 m
.52009 .87899 L
s
.24137 .88927 m .23511 .89513 L .23956 .89484 L 0 1 .532 r
F
.24137 .88927 m .23015 .88981 L .23511 .89513 L F
0 g
.23426 .90077 m
.23511 .89513 L
s
.23956 .89484 m
.24528 .89987 L
s
.60181 .62385 m .60364 .63109 L .60079 .6304 L 0 .26 .102 r
F
.60181 .62385 m .60923 .62855 L .60364 .63109 L F
.60181 .62385 m .61382 .62448 L .60923 .62855 L F
0 g
.60079 .6304 m
.60181 .62385 L
s
.60066 .62511 m
.60172 .62395 L
s
.60066 .62511 m
.60066 .62511 L
s
.59759 .62848 m
.60066 .62511 L
s
.59751 .62856 m
.59759 .62848 L
s
.59703 .62909 m
.59751 .62856 L
s
.59654 .62963 m
.59703 .62909 L
s
.60172 .62395 m
.60181 .62385 L
s
.79895 .78224 m .80766 .78623 L .80296 .78451 L 0 0 0 r
F
.79895 .78224 m .81066 .78699 L .80766 .78623 L F
.75336 .78961 m .76466 .7851 L .7612 .77704 L 0 1 .418 r
F
0 g
.76466 .7851 m
.76792 .7748 L
s
.54304 .60087 m
.54775 .60303 L
s
.54 .60592 m
.54304 .60087 L
s
.22361 .62579 m .2126 .62479 L .21263 .63339 L 0 1 .491 r
F
0 g
.20699 .64152 m
.21263 .63339 L
s
.73821 .61486 m .74291 .62336 L .73872 .62332 L 0 .227 .079 r
F
.73821 .61486 m .74884 .61639 L .74291 .62336 L F
0 g
.73871 .62305 m
.73872 .62332 L
s
.73821 .61486 m
.73871 .62305 L
s
.73245 .62321 m
.73821 .61486 L
s
.43104 .91639 m .42345 .91779 L .41965 .91826 L 0 0 0 r
F
.43104 .91639 m .42833 .91699 L .42345 .91779 L F
.44003 .91532 m .42833 .91699 L .43104 .91639 L F
0 g
.43044 .91645 m
.43104 .91639 L
s
.43104 .91639 m
.43569 .91558 L
s
.69194 1.07756 m .6936 1.07457 L .70046 1.07542 L 0 0 0 r
F
0 g
.69108 1.07377 m
.6936 1.07457 L
s
.68609 1.0742 m
.6936 1.07457 L
s
.48701 .50668 m .49459 .49854 L .50003 .49226 L 0 .932 .175 r
F
0 g
.49459 .49854 m
.50051 .49265 L
s
.39569 .93301 m .39267 .92617 L .38749 .92144 L 0 .963 .433 r
F
0 g
.38775 .92155 m
.38989 .92249 L
s
.38749 .92144 m
.38765 .92151 L
s
.38765 .92151 m
.38775 .92155 L
s
.38749 .92144 m
.38754 .92144 L
s
.40497 .9316 m .39569 .93301 L .40068 .93768 L 0 .922 .424 r
F
.40497 .9316 m .39267 .92617 L .39569 .93301 L F
0 g
.39523 .93866 m
.39569 .93301 L
s
.5518 .74232 m
.5547 .73688 L
s
.46452 .72908 m .46309 .70453 L .45896 .7046 L 0 1 .324 r
F
.46452 .72908 m .46607 .71187 L .46309 .70453 L F
0 g
.46292 .69327 m
.46309 .70453 L
s
.52529 .97122 m .52147 .97025 L .5188 .9698 L 0 .503 .224 r
F
.44833 .69816 m .45113 .68046 L .44813 .67556 L 0 1 .341 r
F
.44833 .69816 m .45122 .69014 L .45113 .68046 L F
0 g
.45113 .68046 m
.45574 .67794 L
s
.35204 .92092 m .34718 .92283 L .35108 .92241 L 0 1 .374 r
F
.35204 .92092 m .34215 .92179 L .34718 .92283 L F
0 g
.34688 .92436 m
.34718 .92283 L
s
.35108 .92241 m
.35647 .92309 L
s
.38749 .92144 m
.38757 .92151 L
s
.25808 .93643 m .25296 .93794 L .25727 .93764 L 0 .715 .252 r
F
.25808 .93643 m .24718 .93691 L .25296 .93794 L F
0 g
.25296 .93794 m
.25308 .93926 L
s
.25727 .93764 m
.26371 .93828 L
s
.37538 .77057 m .36508 .77027 L .36424 .77081 L 0 .644 .223 r
F
0 g
.36424 .77081 m
.36697 .77108 L
s
.37538 .77057 m .36902 .76993 L .36508 .77027 L 0 .644 .223 r
F
.37538 .77057 m .37344 .77003 L .36902 .76993 L F
.37538 .77057 m .37616 .7703 L .37344 .77003 L F
0 g
.37144 .7709 m
.37538 .77057 L
s
.37538 .77057 m
.37815 .77052 L
s
.30093 .86306 m .28867 .84792 L .28562 .85496 L 0 1 .463 r
F
.30093 .86306 m .29427 .84766 L .28867 .84792 L F
.30093 .86306 m .29952 .85415 L .29427 .84766 L F
0 g
.29787 .87008 m
.30093 .86306 L
s
.31144 .86235 m .29953 .85415 L .30093 .86306 L 0 1 .458 r
F
0 g
.30093 .86306 m
.30511 .86948 L
s
.34691 .88107 m .33648 .86737 L .33476 .87368 L 0 1 .443 r
F
.34691 .88107 m .34066 .86716 L .33648 .86737 L F
.34691 .88107 m .34513 .87303 L .34066 .86716 L F
.35716 .8804 m .34513 .87303 L .34691 .88107 L 0 1 .436 r
F
0 g
.34691 .88107 m
.35129 .88684 L
s
.34519 .88736 m
.34691 .88107 L
s
.48701 .50668 m .50003 .49226 L .49971 .49201 L 0 .932 .175 r
F
0 g
.50003 .49226 m
.50598 .48639 L
s
.49459 .49854 m
.50003 .49226 L
s
.44653 .49926 m .43781 .50666 L .43951 .50535 L 0 0 0 r
F
0 g
.44054 .50473 m
.44207 .50323 L
s
.44259 .50273 m .45454 .49358 L .44718 .49929 L 0 0 0 r
F
.44259 .50273 m .44718 .49929 L .44535 .50064 L F
.44653 .49926 m .44259 .50273 L .44106 .5039 L F
.43865 .50558 m .44718 .49929 L .45233 .49555 L F
.43864 .50558 m .44354 .50197 L .43865 .50558 L F
.44653 .49926 m .45069 .49619 L .44259 .50273 L F
.44354 .50197 m .44718 .49929 L .43865 .50558 L F
.44718 .49929 m .44718 .49929 L .44685 .49954 L F
.44718 .49929 m .44685 .49954 L .44535 .50064 L F
.44259 .50273 m .44535 .50064 L .43864 .50558 L F
.44106 .5039 m .44259 .50273 L .43781 .50666 L F
0 g
.44207 .50323 m
.44224 .50307 L
s
.44224 .50307 m
.44278 .50259 L
s
.44653 .49926 m .4577 .49009 L .45069 .49619 L 0 0 0 r
F
.44653 .49926 m .45896 .48851 L .4577 .49009 L F
0 g
.45418 .49244 m
.45896 .48851 L
s
.45896 .48851 m
.46581 .48269 L
s
.47817 .95573 m .47463 .95407 L .47046 .9535 L 0 1 .477 r
F
.47097 .53029 m .47799 .52162 L .48267 .51443 L 0 1 .26 r
F
0 g
.47799 .52162 m
.48383 .51592 L
s
.70905 .65708 m
.70906 .66131 L
s
.70905 .65707 m
.70905 .65708 L
s
.70905 .65707 m
.71068 .66029 L
s
.77375 .74796 m .78388 .76971 L .78634 .75858 L 0 1 .423 r
F
.77375 .74796 m .77934 .77097 L .78388 .76971 L F
0 g
.78388 .76971 m
.78644 .77612 L
s
.72551 1.07331 m .72044 1.07231 L .72803 1.07104 L 0 0 0 r
F
.72551 1.07331 m .71696 1.07312 L .72044 1.07231 L F
0 g
.71742 1.07199 m
.72044 1.07231 L
s
.44507 .62284 m .43715 .62423 L .43969 .62742 L 0 1 .358 r
F
0 g
.44507 .62284 m
.44507 .62284 L
s
.44507 .62284 m .43903 .6149 L .43715 .62423 L 0 1 .358 r
F
.44507 .62284 m .44407 .60565 L .43903 .6149 L F
0 g
.44505 .62286 m
.44507 .62284 L
s
.47423 .90488 m .47184 .90644 L .46792 .90771 L 0 0 0 r
F
.48063 .90573 m .47423 .90488 L .47784 .90397 L F
.48063 .90573 m .47184 .90644 L .47423 .90488 L F
0 g
.47419 .90384 m
.47423 .90488 L
s
.33229 .92276 m .31995 .91949 L .31927 .92145 L 0 1 .435 r
F
.33229 .92276 m .32401 .91926 L .31995 .91949 L F
.33229 .92276 m .3293 .92066 L .32401 .91926 L F
.34215 .92179 m .3293 .92066 L .33229 .92276 L 0 1 .409 r
F
0 g
.3316 .9247 m
.33229 .92276 L
s
.33229 .92276 m
.33743 .92397 L
s
.47097 .53029 m .48267 .51443 L .48189 .51349 L 0 1 .26 r
F
0 g
.48267 .51443 m
.48861 .50851 L
s
.47799 .52162 m
.48267 .51443 L
s
.2587 .92105 m .2454 .91416 L .24453 .91751 L 0 1 .513 r
F
.2587 .92105 m .24987 .91404 L .2454 .91416 L F
.2587 .92105 m .25557 .917 L .24987 .91404 L F
.2696 .92029 m .25557 .917 L .2587 .92105 L 0 1 .507 r
F
0 g
.25781 .92438 m
.2587 .92105 L
s
.2587 .92105 m
.26427 .92379 L
s
.44611 .94325 m .44281 .94089 L .43796 .93973 L 0 1 .52 r
F
.45343 .94141 m .44611 .94325 L .45069 .94443 L 0 1 .512 r
F
.45343 .94141 m .44281 .94089 L .44611 .94325 L F
0 g
.44611 .94325 m
.44647 .94571 L
s
.72827 .62311 m
.72827 .6231 L
s
.72201 .62291 m
.72202 .62291 L
s
.72202 .62291 m
.72367 .62331 L
s
.72367 .62331 m
.72775 .62429 L
s
.50554 .48635 m .51976 .47394 L .51991 .47436 L 0 0 0 r
F
0 g
.51976 .47394 m
.52021 .47352 L
s
.5136 .47907 m
.51976 .47394 L
s
.51958 .8867 m .51936 .88383 L .52009 .87899 L 0 0 .057 r
F
0 g
.52009 .87899 m
.52106 .875 L
s
.51772 .88853 m .52009 .87899 L .51936 .88383 L 0 0 .054 r
F
0 g
.52009 .87899 m
.52009 .87899 L
s
.53639 .74221 m
.53644 .73856 L
s
.20775 .89096 m .19406 .88343 L .19656 .89155 L 0 1 .534 r
F
0 g
.19656 .89155 m
.20176 .89739 L
s
.29144 .91893 m .28587 .92192 L .2902 .92158 L 0 1 .49 r
F
.29144 .91893 m .28052 .91959 L .28587 .92192 L F
0 g
.28546 .92464 m
.28587 .92192 L
s
.2902 .92158 m
.29613 .92356 L
s
.34292 .77031 m .33474 .77089 L .33902 .77104 L 0 .791 .298 r
F
0 g
.33902 .77104 m
.34207 .77221 L
s
.45301 1.00792 m .4531 1.01386 L .45503 1.01287 L 0 .659 .429 r
F
.46496 1.02157 m .45503 1.01287 L .4531 1.01386 L 0 .571 .418 r
F
0 g
.4531 1.01386 m
.45561 1.0186 L
s
.44791 1.01039 m
.4531 1.01386 L
s
.48836 1.04904 m .48273 1.04423 L .4777 1.0413 L 0 .419 .365 r
F
.77375 .74796 m .775 .76166 L .77934 .77097 L 0 1 .423 r
F
0 g
.77872 .77288 m
.77934 .77097 L
s
.32592 .90004 m .3204 .90465 L .32446 .9043 L 0 1 .525 r
F
.32592 .90004 m .31567 .90075 L .3204 .90465 L F
0 g
.31966 .90891 m
.3204 .90465 L
s
.32446 .9043 m
.32741 .90633 L
s
.32741 .90633 m
.32968 .90789 L
s
.48836 1.04904 m .49146 1.05384 L .4921 1.05316 L 0 .419 .365 r
F
.5026 1.06067 m .4921 1.05316 L .49146 1.05384 L 0 .345 .268 r
F
0 g
.49146 1.05384 m
.49561 1.05753 L
s
.48643 1.0509 m
.49146 1.05384 L
s
.5427 1.08464 m .54065 1.0836 L .5396 1.08225 L 0 .012 0 r
F
.72063 .90185 m .73235 .9019 L .72692 .90127 L 0 .872 .36 r
F
.71038 .90015 m .72063 .90185 L .71973 .90038 L 0 .706 .305 r
F
.267 .60362 m .25579 .61015 L .26007 .6108 L 0 1 .48 r
F
0 g
.26007 .6108 m
.26037 .61888 L
s
.37857 .92177 m .36671 .9209 L .36608 .92195 L 0 .829 .28 r
F
.37857 .92177 m .37062 .92058 L .36671 .9209 L F
.37857 .92177 m .37571 .92095 L .37062 .92058 L F
0 g
.37793 .92282 m
.37857 .92177 L
s
.38843 .92063 m .37571 .92095 L .37857 .92177 L 0 .742 .251 r
F
0 g
.38757 .92151 m
.38762 .92156 L
s
.37857 .92177 m
.38362 .92198 L
s
.46452 .72908 m .46668 .72239 L .46607 .71187 L 0 1 .324 r
F
0 g
.46607 .71187 m
.47008 .71226 L
s
.28055 .70473 m .27176 .69667 L .26933 .70335 L 0 1 .53 r
F
.28055 .70473 m .2769 .69226 L .27176 .69667 L F
.28055 .70473 m .28131 .69309 L .2769 .69226 L F
.28055 .70473 m .28288 .69844 L .28131 .69309 L F
0 g
.27542 .70911 m
.28055 .70473 L
s
.28055 .70473 m
.28219 .70975 L
s
.2581 .70196 m .2483 .70647 L .25282 .70692 L 0 1 .528 r
F
0 g
.25282 .70692 m
.25516 .71259 L
s
.45754 .5565 m .46395 .54751 L .46783 .53959 L 0 1 .348 r
F
0 g
.46395 .54751 m
.46966 .54214 L
s
.34425 .58612 m .3331 .57459 L .33221 .58129 L 0 .418 .366 r
F
0 g
.32497 .58475 m
.33221 .58129 L
s
.51728 1.07191 m .52237 1.07476 L .52213 1.07484 L 0 .318 .216 r
F
0 g
.51756 1.0721 m
.518 1.07235 L
s
.5328 1.08171 m .52213 1.07484 L .52237 1.07476 L 0 0 0 r
F
0 g
.52237 1.07476 m
.52751 1.07713 L
s
.44833 .69816 m .44813 .67556 L .44344 .67822 L 0 1 .341 r
F
0 g
.44813 .67556 m
.44854 .66537 L
s
.30926 .92232 m
.30926 .92232 L
s
.50512 .46232 m .49816 .469 L .49849 .46674 L 0 0 .034 r
F
0 g
.49763 .4642 m
.49898 .46305 L
s
.50512 .46232 m .50467 .4685 L .49816 .469 L 0 0 .034 r
F
.50512 .46232 m .51366 .46556 L .50467 .4685 L F
.50512 .46232 m .52027 .46113 L .51366 .46556 L F
.50512 .46232 m .52012 .45818 L .52027 .46113 L F
0 g
.49898 .46305 m
.50512 .46232 L
s
.52012 .45818 m
.52635 .45432 L
s
.51363 .45869 m
.52012 .45818 L
s
.40497 .9316 m .39332 .92071 L .39267 .92617 L 0 .922 .424 r
F
0 g
.39267 .92617 m
.39331 .92079 L
s
.38762 .92156 m
.39267 .92617 L
s
.39272 .92373 m
.3933 .92079 L
s
.54304 .79278 m
.54314 .7863 L
s
.45754 .5565 m .46783 .53959 L .46661 .538 L 0 1 .348 r
F
0 g
.46783 .53959 m
.47369 .53387 L
s
.46395 .54751 m
.46783 .53959 L
s
.75156 .89937 m .75519 .90432 L .76033 .90254 L 0 1 .412 r
F
.75156 .89937 m .75077 .90388 L .75519 .90432 L F
0 g
.75519 .90432 m
.75587 .90677 L
s
.60153 .64164 m
.60192 .64292 L
s
.60153 .64164 m
.60153 .64164 L
s
.59647 .62518 m
.5973 .62787 L
s
.5973 .62787 m
.59751 .62856 L
s
.59751 .62856 m
.59838 .6314 L
s
.59838 .6314 m
.59861 .63215 L
s
.59861 .63215 m
.5987 .63244 L
s
.60027 .63753 m
.60081 .63931 L
s
.60081 .63931 m
.60086 .63947 L
s
.60086 .63947 m
.60086 .63947 L
s
.60107 .64016 m
.60111 .6403 L
s
.60111 .6403 m
.60153 .64164 L
s
.59515 .63156 m
.59647 .62518 L
s
.54775 .60304 m .55284 .60124 L .55786 .60406 L 0 .255 .085 r
F
.35229 .91081 m .34071 .90306 L .3397 .90695 L 0 1 .525 r
F
.35229 .91081 m .34478 .9028 L .34071 .90306 L F
.35229 .91081 m .34975 .90612 L .34478 .9028 L F
.36218 .90989 m .34975 .90612 L .35229 .91081 L 0 1 .523 r
F
0 g
.35229 .91081 m
.35713 .914 L
s
.35128 .91468 m
.35229 .91081 L
s
.34201 .69927 m .33453 .69363 L .33182 .69793 L 0 1 .54 r
F
.34201 .69927 m .33956 .69094 L .33453 .69363 L F
.34201 .69927 m .34353 .69166 L .33956 .69094 L F
.34201 .69927 m .34458 .69523 L .34353 .69166 L F
0 g
.34201 .69927 m
.34317 .70254 L
s
.337 .70195 m
.34201 .69927 L
s
.40497 .9316 m .40068 .93768 L .40432 .93707 L 0 .922 .424 r
F
.41268 .94793 m .40432 .93707 L .40068 .93768 L 0 .881 .427 r
F
0 g
.40058 .94309 m
.40068 .93768 L
s
.39569 .93301 m
.40068 .93768 L
s
.52638 .47017 m .53484 .46419 L .54165 .46049 L 0 0 0 r
F
0 g
.53484 .46419 m
.5407 .45874 L
s
.37875 .57231 m .36867 .581 L .37193 .57865 L 0 .949 .192 r
F
.37875 .57231 m .37086 .57804 L .36867 .581 L F
0 g
.37193 .57865 m
.37211 .57854 L
s
.37193 .57865 m
.37193 .57865 L
s
.37875 .57231 m .37704 .57172 L .37086 .57804 L 0 .949 .192 r
F
0 g
.37211 .57854 m
.37225 .57844 L
s
.37225 .57844 m
.37311 .57788 L
s
.37875 .57231 m .38388 .56536 L .37704 .57172 L 0 .949 .192 r
F
.37875 .57231 m .3868 .56321 L .38388 .56536 L F
.37875 .57231 m .38459 .56619 L .3868 .56321 L F
0 g
.38459 .56619 m
.39116 .56021 L
s
.37679 .5757 m
.37875 .57231 L
s
.37193 .57865 m
.37875 .57231 L
s
.34292 .77031 m .33226 .76967 L .33474 .77089 L 0 .791 .298 r
F
0 g
.33137 .77207 m
.33474 .77089 L
s
.5026 1.06067 m .50178 1.06177 L .50656 1.06471 L 0 .345 .268 r
F
.49862 .96138 m .49283 .96168 L .49659 .96299 L 0 .661 .362 r
F
.49862 .96138 m .49085 .96016 L .49283 .96168 L F
0 g
.48915 .96134 m
.49283 .96168 L
s
.70105 .89127 m
.70187 .89003 L
s
.70282 .88861 m
.70306 .88824 L
s
.70306 .88824 m
.7039 .88698 L
s
.69877 .89037 m
.6988 .89042 L
s
.69902 .8909 m
.69912 .89111 L
s
.69902 .8909 m
.69902 .8909 L
s
.49862 .96138 m .49659 .96299 L .49992 .96351 L 0 .661 .362 r
F
0 g
.49659 .96299 m
.49892 .96454 L
s
.46452 .72908 m .45896 .7046 L .45644 .71204 L 0 1 .324 r
F
0 g
.45896 .7046 m
.46309 .70453 L
s
.45861 .69456 m
.45896 .7046 L
s
.33182 .69793 m .32259 .70017 L .32671 .70073 L 0 1 .54 r
F
0 g
.32671 .70073 m
.32835 .70472 L
s
.46838 .90866 m .45891 .91121 L .45846 .91027 L 0 0 0 r
F
0 g
.45413 .91155 m
.45846 .91027 L
s
.33248 .86121 m .32602 .86797 L .3302 .86771 L 0 1 .446 r
F
.33248 .86121 m .32196 .86173 L .32602 .86797 L F
0 g
.3244 .87444 m
.32602 .86797 L
s
.3302 .86771 m
.33476 .87368 L
s
.4523 .76108 m
.4527 .76098 L
s
.44872 .76197 m
.4523 .76108 L
s
.78525 .9003 m .79361 .90461 L .79646 .90057 L 0 1 .486 r
F
0 g
.78819 .90734 m
.79361 .90461 L
s
.79361 .90461 m
.79478 .9079 L
s
.49042 .95778 m .48725 .95958 L .49085 .96016 L 0 .788 .418 r
F
.49042 .95778 m .48357 .9581 L .48725 .95958 L F
0 g
.48725 .95958 m
.48915 .96134 L
s
.4413 .65485 m .44357 .63262 L .43835 .63664 L 0 1 .354 r
F
0 g
.44357 .63262 m
.44507 .62284 L
s
.44065 .66097 m
.44093 .66008 L
s
.47743 1.03471 m .46893 1.03175 L .4744 1.03682 L 0 .456 .391 r
F
.47743 1.03471 m .46596 1.02725 L .46893 1.03175 L F
0 g
.4637 1.02871 m
.46893 1.03175 L
s
.45644 .71204 m .45122 .69014 L .44833 .69816 L 0 1 .332 r
F
0 g
.45122 .69014 m
.45562 .6886 L
s
.45113 .68046 m
.45122 .69014 L
s
.497 .75098 m
.4971 .73404 L
s
.50698 .96471 m .50229 .96485 L .50611 .96602 L 0 .549 .286 r
F
.50698 .96471 m .49992 .96351 L .50229 .96485 L F
0 g
.49892 .96454 m
.50229 .96485 L
s
.30543 .90153 m .29164 .89186 L .28945 .8966 L 0 1 .528 r
F
.30543 .90153 m .29713 .8916 L .29164 .89186 L F
.30543 .90153 m .30304 .89575 L .29713 .8916 L F
0 g
.30323 .90625 m
.30543 .90153 L
s
.31567 .90075 m .30305 .89575 L .30543 .90153 L 0 1 .526 r
F
0 g
.30543 .90153 m
.31026 .90557 L
s
.43217 .66646 m .42352 .66922 L .42695 .66891 L 0 1 .396 r
F
.43217 .66646 m .42385 .66727 L .42352 .66922 L F
0 g
.42695 .66892 m
.42696 .66892 L
s
.42696 .66892 m
.42876 .66938 L
s
.42916 .66504 m .43305 .65531 L .4278 .65942 L 0 1 .36 r
F
.43217 .66646 m .42936 .66513 L .42385 .66727 L 0 1 .396 r
F
.42936 .66513 m .42916 .66504 L .42737 .66579 L F
.42936 .66513 m .42737 .66579 L .42385 .66727 L F
.42396 .66691 m .42859 .65032 L .42567 .64724 L 0 1 .37 r
F
.42383 .66847 m .42426 .66681 L .42396 .66691 L F
.42426 .66681 m .42859 .65032 L .42396 .66691 L F
.43265 .66367 m .43607 .65889 L .43305 .65531 L 0 1 .36 r
F
.43217 .66646 m .43525 .66254 L .43265 .66367 L 0 1 .396 r
F
.43217 .66646 m .4357 .6635 L .43591 .66226 L F
.43525 .66254 m .43591 .66226 L .43607 .65889 L 0 1 .36 r
F
.43525 .66254 m .43591 .66226 L .43604 .66155 L 0 1 .396 r
F
.43217 .66646 m .43591 .66226 L .43525 .66254 L F
.43203 .67694 m .43564 .66815 L .43591 .66226 L 0 1 .36 r
F
.43203 .67694 m .43591 .66226 L .43525 .66254 L F
.43203 .67694 m .43525 .66254 L .43265 .66367 L F
.43525 .66254 m .43607 .65889 L .43265 .66367 L F
.43525 .66254 m .43532 .66245 L .43265 .66367 L 0 1 .396 r
F
.43265 .66367 m .43604 .66155 L .43296 .66191 L F
.43532 .66245 m .43604 .66155 L .43265 .66367 L F
.43265 .66367 m .43305 .65531 L .42916 .66504 L 0 1 .36 r
F
.43203 .67694 m .42916 .66504 L .42383 .66848 L F
.42911 .66487 m .4278 .65942 L .42461 .6667 L F
.42426 .66683 m .4278 .65942 L .42859 .65032 L 0 1 .37 r
F
.42383 .66847 m .4246 .6667 L .42426 .66683 L F
.4246 .6667 m .4278 .65942 L .42426 .66683 L F
.42396 .66694 m .42842 .66241 L .42545 .66273 L 0 1 .381 r
F
.42395 .66697 m .42398 .66694 L .42396 .66694 L F
.42398 .66694 m .42842 .66241 L .42396 .66694 L F
.42384 .66727 m .42424 .66685 L .42395 .66697 L F
.42353 .66709 m .42567 .64724 L .42025 .65188 L 0 1 .37 r
F
.42354 .66709 m .42567 .64724 L .42353 .66709 L F
.42396 .66694 m .42567 .64724 L .42353 .66711 L F
.41898 .67103 m .41514 .66987 L .41345 .67029 L 0 1 .439 r
F
.41206 .67073 m .41345 .67029 L .41175 .6703 L 0 1 .371 r
F
.41295 .67045 m .41345 .67029 L .41286 .67044 L 0 1 .439 r
F
.41898 .67103 m .41345 .67029 L .41295 .67045 L F
.41206 .67073 m .41286 .67044 L .4119 .67072 L F
.41898 .67103 m .41293 .67044 L .41206 .67073 L F
.41293 .67044 m .41286 .67044 L .41206 .67073 L F
.41237 .67684 m .41218 .67209 L .40693 .67439 L 0 1 .456 r
F
.41237 .67684 m .41559 .67187 L .41218 .67209 L F
.41237 .67684 m .41567 .67391 L .41559 .67187 L F
.41898 .67103 m .41218 .67208 L .41559 .67187 L 0 1 .439 r
F
.41898 .67103 m .41053 .67159 L .41218 .67208 L F
.41898 .67103 m .41206 .67073 L .41053 .67159 L F
.41206 .67073 m .41175 .6703 L .41149 .67091 L 0 1 .371 r
F
.41206 .67073 m .41174 .67071 L .4115 .67089 L 0 1 .439 r
F
.41043 .67119 m .41175 .6703 L .41023 .66615 L 0 1 .379 r
F
.41203 .67074 m .41149 .67089 L .41053 .67159 L 0 1 .439 r
F
.4105 .67318 m .41149 .67089 L .41043 .67119 L 0 1 .379 r
F
.41149 .67089 m .41175 .6703 L .41043 .67119 L F
.41206 .67073 m .4115 .67089 L .41149 .67089 L 0 1 .439 r
F
.41206 .67073 m .41149 .67089 L .41203 .67074 L F
.41884 .68016 m .41513 .67028 L .41356 .67029 L 0 1 .371 r
F
.41346 .67032 m .41356 .67029 L .41345 .67029 L F
.41884 .68016 m .41356 .67029 L .41346 .67032 L F
.41884 .68016 m .41206 .67073 L .4105 .67318 L F
.41206 .67073 m .41149 .67091 L .4105 .67318 L F
.41884 .68016 m .41345 .67029 L .41206 .67073 L F
.41898 .67103 m .41845 .66963 L .41514 .66987 L 0 1 .439 r
F
.42384 .66727 m .41514 .66987 L .41845 .66963 L 0 1 .381 r
F
.42384 .66727 m .42263 .66737 L .41514 .66987 L F
.42263 .66737 m .41593 .66117 L .41571 .66952 L 0 1 .37 r
F
.42263 .66737 m .41571 .66952 L .41571 .66959 L F
.42263 .66737 m .42004 .66509 L .41582 .66793 L 0 1 .381 r
F
.42384 .66727 m .42353 .66709 L .42263 .66737 L F
.42263 .66737 m .42025 .65188 L .41593 .66117 L 0 1 .37 r
F
.42353 .66709 m .42353 .66709 L .42263 .66737 L 0 1 .381 r
F
.42383 .66847 m .42353 .66709 L .42263 .66737 L 0 1 .37 r
F
.42353 .66709 m .42025 .65188 L .42263 .66737 L F
.42353 .66709 m .42004 .66509 L .42263 .66737 L 0 1 .381 r
F
.42263 .66737 m .41582 .66793 L .41518 .66976 L F
.42263 .66737 m .41518 .66976 L .41514 .66987 L F
.41571 .66959 m .41593 .66117 L .41518 .66975 L 0 1 .37 r
F
.42277 .6675 m .42263 .66737 L .41571 .66959 L F
.42383 .66847 m .42277 .6675 L .41514 .67028 L F
.42277 .6675 m .41518 .66975 L .41514 .67028 L F
.4119 .67072 m .41286 .67044 L .41174 .67071 L 0 1 .439 r
F
.42353 .66709 m .42545 .66273 L .42004 .66509 L 0 1 .381 r
F
.42384 .66727 m .42396 .66694 L .42353 .66709 L F
.42396 .66694 m .42545 .66273 L .42353 .66709 L F
.42353 .66711 m .42354 .66709 L .42353 .66709 L 0 1 .37 r
F
.42383 .66847 m .42396 .66694 L .42353 .66711 L F
.42424 .66685 m .42427 .66682 L .42395 .66697 L 0 1 .381 r
F
.42427 .66682 m .42842 .66241 L .42398 .66693 L F
.42427 .66682 m .42398 .66693 L .42395 .66697 L F
.42916 .66504 m .42911 .66487 L .42461 .6667 L 0 1 .36 r
F
.42911 .66487 m .42461 .6667 L .42461 .6667 L F
.42916 .66504 m .42461 .6667 L .42385 .66727 L 0 1 .396 r
F
.42916 .66504 m .42461 .6667 L .42383 .66848 L 0 1 .36 r
F
.42916 .66504 m .42475 .6666 L .42461 .6667 L 0 1 .396 r
F
.42916 .66504 m .43296 .66191 L .42773 .66436 L F
.43217 .66646 m .43265 .66367 L .42916 .66504 L F
.43265 .66367 m .43296 .66191 L .42916 .66504 L F
.43265 .6638 m .43265 .66367 L .42916 .66504 L 0 1 .36 r
F
.43203 .67694 m .43265 .6638 L .43138 .66425 L F
.4292 .66524 m .43138 .66425 L .42916 .66504 L F
.43203 .67694 m .43138 .66425 L .4292 .66524 L F
.42916 .66504 m .42773 .66436 L .42475 .6666 L 0 1 .396 r
F
0 g
.43586 .66342 m
.44065 .66097 L
s
.37231 .89871 m .36552 .88584 L .36145 .8861 L 0 1 .433 r
F
.37231 .89871 m .37018 .89125 L .36552 .88584 L F
0 g
.37098 .90462 m
.37231 .89871 L
s
.38266 .89794 m .37232 .89871 L .37698 .90403 L 0 1 .425 r
F
.38266 .89794 m .37018 .89125 L .37232 .89871 L F
.51051 .89567 m .50964 .88699 L .51123 .88827 L 0 0 .053 r
F
.51051 .89567 m .50772 .8889 L .50964 .88699 L F
0 g
.50964 .88699 m
.51092 .88382 L
s
.43114 .979 m .42714 .97296 L .42186 .96907 L 0 .787 .433 r
F
0 g
.42186 .96907 m
.42714 .97296 L
s
.45475 .91211 m .44447 .91454 L .44385 .91398 L 0 0 0 r
F
0 g
.4392 .91509 m
.44385 .91398 L
s
.38266 .89794 m .37698 .90403 L .38107 .90367 L 0 1 .425 r
F
.38852 .91575 m .38107 .90367 L .37698 .90403 L 0 .999 .429 r
F
0 g
.37596 .90973 m
.37698 .90403 L
s
.37232 .89871 m
.37698 .90403 L
s
.31144 .86235 m .30167 .84734 L .29953 .85415 L 0 1 .458 r
F
.31144 .86235 m .30594 .84717 L .30167 .84734 L F
.31144 .86235 m .31013 .85361 L .30594 .84717 L F
.32196 .86173 m .31013 .85361 L .31144 .86235 L 0 1 .452 r
F
0 g
.30929 .86915 m
.31144 .86235 L
s
.31144 .86235 m
.31556 .86868 L
s
.49042 .95778 m .48201 .95642 L .48357 .9581 L 0 .788 .418 r
F
0 g
.47963 .95767 m
.48357 .9581 L
s
.52638 .47017 m .54165 .46049 L .54228 .46153 L 0 0 0 r
F
0 g
.54165 .46049 m
.54454 .45818 L
s
.53484 .46419 m
.54165 .46049 L
s
.4417 .99373 m .43737 .9879 L .43211 .98424 L 0 .729 .433 r
F
0 g
.43211 .98424 m
.43737 .9879 L
s
.43114 .979 m
.43211 .98424 L
s
.58944 .45037 m
.59753 .45299 L
s
.58418 .4539 m
.58944 .45037 L
s
.48063 .90573 m .47784 .90397 L .48028 .90432 L 0 0 0 r
F
.48583 .90164 m .48028 .90432 L .47784 .90397 L F
0 g
.47784 .90397 m
.47792 .9024 L
s
.47423 .90488 m
.47784 .90397 L
s
.22542 .938 m .21109 .9339 L .21068 .93593 L 0 .902 .324 r
F
.22542 .938 m .21555 .9339 L .21109 .9339 L F
.22542 .938 m .2217 .93566 L .21555 .9339 L F
.23629 .93744 m .2217 .93566 L .22542 .938 L 0 .818 .293 r
F
0 g
.22497 .94001 m
.22542 .938 L
s
.22542 .938 m
.23142 .93951 L
s
.50698 .96471 m .50611 .96602 L .50914 .96654 L 0 .549 .286 r
F
0 g
.50611 .96602 m
.50883 .96734 L
s
.50857 .6145 m .51343 .61144 L .51719 .61092 L 0 0 .008 r
F
0 g
.51343 .61144 m
.51695 .60732 L
s
.2581 .70196 m .24686 .70059 L .2483 .70647 L 0 1 .528 r
F
0 g
.24382 .71174 m
.2483 .70647 L
s
.25259 .88874 m .24624 .89442 L .2507 .89414 L 0 1 .531 r
F
.25259 .88874 m .24137 .88927 L .24624 .89442 L F
0 g
.24528 .89987 m
.24624 .89442 L
s
.2507 .89414 m
.25631 .899 L
s
.76934 1.05862 m .76309 1.06143 L .76122 1.06282 L 0 .841 .229 r
F
0 g
.75415 1.06474 m
.76122 1.06282 L
s
.41475 .92456 m .41003 .92793 L .41383 .92735 L 0 1 .521 r
F
.41475 .92456 m .40507 .92583 L .41003 .92793 L F
.42186 .93209 m .41383 .92735 L .41003 .92793 L 0 1 .524 r
F
0 g
.40964 .93072 m
.41003 .92793 L
s
.33226 .76967 m .32404 .77037 L .32832 .7706 L 0 .911 .349 r
F
0 g
.32832 .7706 m
.33137 .77207 L
s
.68941 .68602 m
.68961 .6865 L
s
.53263 .74472 m
.53265 .74478 L
s
.53255 .74452 m
.53263 .74472 L
s
.5325 .7444 m
.53255 .74452 L
s
.53199 .74309 m
.5325 .7444 L
s
.53198 .74513 m
.53198 .74513 L
s
.4468 .58479 m .45561 .5671 L .45397 .5649 L 0 1 .371 r
F
.4468 .58479 m .45255 .57561 L .45561 .5671 L F
0 g
.45561 .5671 m
.46134 .5617 L
s
.45255 .57561 m
.45814 .57068 L
s
.45255 .57561 m
.45561 .5671 L
s
.75156 .89937 m .74921 .90177 L .75077 .90388 L 0 1 .412 r
F
0 g
.74498 .90537 m
.75077 .90388 L
s
.41156 .76809 m .40273 .76864 L .40733 .76806 L 0 0 0 r
F
0 g
.40733 .76806 m
.41031 .7673 L
s
.45343 .94141 m .45069 .94443 L .45351 .94366 L 0 1 .512 r
F
.46117 .94665 m .45351 .94366 L .45069 .94443 L 0 1 .507 r
F
0 g
.45069 .94443 m
.45125 .94661 L
s
.44611 .94325 m
.45069 .94443 L
s
.40507 .92583 m .3972 .92026 L .39332 .92071 L 0 1 .524 r
F
.40507 .92583 m .40224 .92245 L .3972 .92026 L F
0 g
.40446 .92885 m
.40507 .92583 L
s
.41475 .92456 m .40224 .92245 L .40507 .92583 L 0 1 .521 r
F
0 g
.40507 .92583 m
.41003 .92793 L
s
.22361 .62579 m .21702 .61362 L .2126 .62479 L 0 1 .491 r
F
0 g
.2126 .62479 m
.21263 .63339 L
s
.22361 .62579 m .22358 .60565 L .21702 .61362 L 0 1 .491 r
F
.22361 .62579 m .22789 .60621 L .22358 .60565 L F
.22361 .62579 m .2279 .61486 L .22789 .60621 L F
0 g
.22361 .62579 m
.22374 .63421 L
s
.21708 .63372 m
.22361 .62579 L
s
.45343 .94141 m .44273 .93865 L .44281 .94089 L 0 1 .512 r
F
0 g
.43796 .93973 m
.44281 .94089 L
s
.76491 .76798 m
.76496 .76809 L
s
.49561 .9004 m .48894 .90124 L .48908 .89902 L 0 0 .026 r
F
0 g
.48589 .90008 m
.48908 .89902 L
s
.42143 .96373 m .4178 .95747 L .41257 .95334 L 0 .837 .43 r
F
0 g
.41257 .95334 m
.4178 .95747 L
s
.42143 .96373 m
.42186 .96907 L
s
.20775 .89096 m .19559 .87727 L .19406 .88343 L 0 1 .534 r
F
.20775 .89096 m .20015 .8772 L .19559 .87727 L F
.20775 .89096 m .20536 .88308 L .20015 .8772 L F
.21895 .89038 m .20536 .88308 L .20775 .89096 L 0 1 .533 r
F
0 g
.2062 .89708 m
.20775 .89096 L
s
.20775 .89096 m
.21287 .89662 L
s
.42186 .93209 m .4189 .92914 L .41383 .92735 L 0 1 .524 r
F
.43085 .93065 m .42186 .93209 L .42671 .93383 L 0 1 .519 r
F
.43085 .93065 m .4189 .92914 L .42186 .93209 L F
0 g
.42146 .93488 m
.42186 .93209 L
s
.36743 .8799 m .36145 .8861 L .36552 .88584 L 0 1 .429 r
F
.36743 .8799 m .35716 .8804 L .36145 .8861 L F
0 g
.36013 .89201 m
.36145 .8861 L
s
.33226 .76967 m .32159 .76883 L .32404 .77037 L 0 .911 .349 r
F
0 g
.32068 .77175 m
.32404 .77037 L
s
.48246 .95386 m .47817 .95573 L .48201 .95642 L 0 .883 .456 r
F
.48246 .95386 m .47463 .95407 L .47817 .95573 L F
0 g
.47817 .95573 m
.47963 .95767 L
s
.36424 .77081 m .35446 .76987 L .35358 .7707 L 0 .685 .242 r
F
.36424 .77081 m .3583 .76943 L .35446 .76987 L F
.36424 .77081 m .36253 .76968 L .3583 .76943 L F
.36424 .77081 m .36508 .77027 L .36253 .76968 L F
0 g
.36041 .77125 m
.36424 .77081 L
s
.62743 .75625 m
.62748 .75102 L
s
.62748 .75102 m
.62754 .7432 L
s
.62688 .82182 m
.62694 .81435 L
s
.62694 .81435 m
.62711 .79435 L
s
.62714 .79024 m
.62724 .77882 L
s
.62711 .79435 m
.62714 .79024 L
s
.62724 .77882 m
.62728 .77356 L
s
.62735 .76563 m
.62743 .75625 L
s
.75336 .78961 m .7612 .77704 L .75668 .77886 L 0 1 .418 r
F
0 g
.75336 .78961 m
.75668 .77886 L
s
.7612 .77704 m
.76466 .7851 L
s
.7499 .78188 m
.75336 .78961 L
s
.68521 .62331 m .68853 .62261 L .68489 .6233 L 0 0 0 r
F
.68521 .62331 m .69449 .62212 L .68853 .62261 L F
0 g
.68489 .6233 m
.68521 .62331 L
s
.68978 .64022 m
.69494 .62301 L
s
.68239 .62392 m
.68521 .62331 L
s
.42795 .51727 m .43529 .5099 L .43951 .50535 L 0 .899 .169 r
F
0 g
.43529 .5099 m
.44054 .50473 L
s
.33182 .69793 m .32163 .69628 L .32259 .70017 L 0 1 .54 r
F
0 g
.31799 .70356 m
.32259 .70017 L
s
.66991 .62663 m
.67037 .62748 L
s
.78085 .61878 m .79603 .61164 L .79602 .61514 L 0 0 0 r
F
0 g
.79603 .61164 m
.80174 .61033 L
s
.5328 1.08171 m .53413 1.08038 L .53861 1.08336 L 0 0 0 r
F
0 g
.53413 1.08038 m
.5396 1.08225 L
s
.79643 .74243 m .80908 .75376 L .8078 .74024 L 0 1 .44 r
F
0 g
.80663 .76455 m
.80908 .75376 L
s
.80908 .75376 m
.81346 .7633 L
s
.49561 .9004 m .49416 .89683 L .49575 .89817 L 0 0 .026 r
F
.50018 .89616 m .49575 .89817 L .49416 .89683 L 0 0 .023 r
F
0 g
.49416 .89683 m
.49469 .89435 L
s
.4913 .8972 m
.49416 .89683 L
s
.78508 .74497 m .7977 .75598 L .79643 .74243 L 0 1 .432 r
F
0 g
.79524 .76692 m
.7977 .75598 L
s
.7977 .75598 m
.80207 .76545 L
s
.39529 .68463 m .38609 .6868 L .39003 .68685 L 0 1 .494 r
F
0 g
.39003 .68685 m
.39107 .68929 L
s
.38852 .91575 m .38602 .90869 L .38107 .90367 L 0 .999 .429 r
F
.39839 .91476 m .38852 .91575 L .39332 .92071 L 0 .96 .42 r
F
.39839 .91476 m .38602 .90869 L .38852 .91575 L F
0 g
.3881 .9181 m
.38852 .91575 L
s
.44019 .68667 m .44362 .66879 L .4406 .66466 L 0 1 .35 r
F
.44019 .68667 m .44344 .67822 L .44362 .66879 L F
0 g
.44362 .66879 m
.44854 .66537 L
s
.68442 .70815 m
.68452 .70593 L
s
.5154 .96785 m .51187 .96768 L .51571 .96873 L 0 .492 .237 r
F
.5154 .96785 m .50914 .96654 L .51187 .96768 L F
0 g
.50883 .96734 m
.51187 .96768 L
s
.45301 1.00792 m .4484 1.00231 L .4432 .99884 L 0 .659 .429 r
F
0 g
.4432 .99884 m
.4484 1.00231 L
s
.4417 .99373 m
.4432 .99884 L
s
.46945 .95143 m .46608 .94957 L .46172 .94883 L 0 1 .496 r
F
.77512 .78028 m .77946 .77374 L .78416 .77621 L 0 .145 0 r
F
.77512 .78028 m .77558 .77547 L .77946 .77374 L F
0 g
.77868 .77301 m
.77946 .77374 L
s
.35716 .8804 m .34694 .8669 L .34513 .87303 L 0 1 .436 r
F
.267 .60362 m .25646 .60176 L .25579 .61015 L 0 1 .48 r
F
0 g
.24957 .61748 m
.25579 .61015 L
s
.8078 .74024 m .82047 .75185 L .81918 .73834 L 0 1 .448 r
F
0 g
.81802 .76254 m
.82047 .75185 L
s
.82047 .75185 m
.82486 .76147 L
s
.43085 .93065 m .42671 .93383 L .43022 .9332 L 0 1 .519 r
F
.4381 .93721 m .43022 .9332 L .42671 .93383 L 0 1 .521 r
F
0 g
.42658 .93635 m
.42671 .93383 L
s
.42186 .93209 m
.42671 .93383 L
s
.47743 1.03471 m .4744 1.03682 L .47932 1.04002 L 0 .456 .391 r
F
0 g
.4744 1.03682 m
.4777 1.0413 L
s
.71784 .62275 m
.71784 .62276 L
s
.42454 .91776 m .41965 .91826 L .42345 .91779 L 0 0 0 r
F
.42454 .91776 m .41484 .91873 L .41965 .91826 L F
0 g
.41906 .91831 m
.41965 .91826 L
s
.71038 .90015 m .71973 .90038 L .71559 .89984 L 0 .706 .305 r
F
0 g
.70936 .89897 m
.71038 .90015 L
s
.4413 .65485 m .43305 .65531 L .43607 .65889 L 0 1 .354 r
F
.4413 .65485 m .43402 .64577 L .43305 .65531 L F
.4413 .65485 m .43835 .63664 L .43402 .64577 L F
0 g
.44093 .66008 m
.44094 .6599 L
s
.44094 .6599 m
.4413 .65485 L
s
.37208 .90913 m .36689 .91296 L .3708 .91259 L 0 1 .522 r
F
.37208 .90913 m .36218 .90989 L .36689 .91296 L F
0 g
.36621 .91643 m
.36689 .91296 L
s
.52567 .97131 m
.526 .97139 L
s
.52649 .97151 m
.5267 .97156 L
s
.52671 .97156 m
.52871 .97204 L
s
.52601 .97139 m
.52634 .97147 L
s
.52635 .97148 m
.52649 .97151 L
s
.53024 .97247 m .52906 .97217 L .52872 .97204 L 0 0 0 r
F
.77375 .74796 m .78634 .75858 L .78508 .74497 L 0 1 .423 r
F
0 g
.78388 .76971 m
.78634 .75858 L
s
.78634 .75858 m
.7907 .76798 L
s
.36438 .58261 m
.36438 .5826 L
s
.35804 .58545 m
.36438 .58261 L
s
.35716 .8804 m .35113 .86675 L .34694 .8669 L 0 1 .436 r
F
.35716 .8804 m .35551 .87254 L .35113 .86675 L F
.36743 .8799 m .35551 .87254 L .35716 .8804 L 0 1 .429 r
F
0 g
.35716 .8804 m
.36145 .8861 L
s
.35535 .88652 m
.35716 .8804 L
s
.30019 .58396 m .28893 .58925 L .29298 .59045 L 0 1 .466 r
F
0 g
.29258 .59841 m
.29298 .59045 L
s
.32159 .76883 m .31334 .7697 L .31762 .76999 L 0 1 .395 r
F
0 g
.31762 .76999 m
.32068 .77175 L
s
.48246 .95386 m .47349 .95226 L .47463 .95407 L 0 .883 .456 r
F
0 g
.47046 .9535 m
.47463 .95407 L
s
.70674 .62106 m .71784 .62275 L .72201 .6229 L 0 .629 .231 r
F
.70674 .62106 m .71131 .62196 L .71784 .62275 L F
0 g
.71646 .62258 m
.71717 .62267 L
s
.71717 .62267 m
.71784 .62275 L
s
.70772 .65152 m .71784 .62275 L .72201 .62291 L 0 .183 .096 r
F
.70772 .65152 m .71174 .63495 L .71784 .62275 L F
0 g
.7178 .62284 m
.71784 .62275 L
s
.71763 .62319 m
.7178 .62284 L
s
.3708 .91259 m
.3729 .91373 L
s
.3729 .91373 m
.37583 .91534 L
s
.38848 .91819 m .37681 .91207 L .37583 .91534 L 0 1 .523 r
F
.43903 .6149 m .44624 .59661 L .4441 .5938 L 0 1 .371 r
F
.43903 .6149 m .44407 .60565 L .44624 .59661 L F
0 g
.44624 .59661 m
.45184 .59165 L
s
.44407 .60565 m
.44945 .60109 L
s
.44407 .60565 m
.44624 .59661 L
s
.36855 .69197 m .35942 .69379 L .36339 .69414 L 0 1 .529 r
F
0 g
.36339 .69414 m
.36464 .69717 L
s
.81918 .73834 m .83188 .75019 L .83058 .73666 L 0 1 .455 r
F
0 g
.82943 .76081 m
.83188 .75019 L
s
.51051 .89567 m .50679 .89267 L .50772 .8889 L 0 0 .053 r
F
0 g
.50578 .88889 m
.50772 .8889 L
s
.267 .60362 m .26163 .5912 L .25646 .60176 L 0 1 .48 r
F
.267 .60362 m .26858 .58399 L .26163 .5912 L F
.267 .60362 m .27267 .58495 L .26858 .58399 L F
.267 .60362 m .27198 .59338 L .27267 .58495 L F
0 g
.26647 .61181 m
.267 .60362 L
s
.26007 .6108 m
.267 .60362 L
s
.32196 .86173 m .31234 .84694 L .31013 .85361 L 0 1 .452 r
F
.32196 .86173 m .31661 .8468 L .31234 .84694 L F
.32196 .86173 m .32073 .85315 L .31661 .8468 L F
.33248 .86121 m .32073 .85315 L .32196 .86173 L 0 1 .446 r
F
0 g
.31974 .86839 m
.32196 .86173 L
s
.32196 .86173 m
.32602 .86797 L
s
.34301 .86082 m .33648 .86737 L .34066 .86716 L 0 1 .439 r
F
.34301 .86082 m .33248 .86121 L .33648 .86737 L F
0 g
.33476 .87368 m
.33648 .86737 L
s
.34066 .86716 m
.34513 .87303 L
s
.24686 .70059 m .23698 .70538 L .24151 .70582 L 0 1 .527 r
F
0 g
.24151 .70582 m
.24382 .71174 L
s
.62837 .62757 m .63874 .63003 L .64211 .63004 L 0 .683 .274 r
F
0 g
.63334 .62846 m
.63365 .62813 L
s
.62837 .62757 m .63285 .62897 L .63874 .63003 L 0 .683 .274 r
F
0 g
.63874 .63003 m
.63923 .63491 L
s
.63285 .62897 m
.63874 .63003 L
s
.47721 .73591 m .47053 .72423 L .4735 .73336 L 0 1 .311 r
F
.47258 .75021 m .47053 .72423 L .46668 .72239 L 0 1 .316 r
F
.47258 .75021 m .4735 .73336 L .47053 .72423 L F
0 g
.47008 .71226 m
.47053 .72423 L
s
.47049 .72421 m
.47053 .72423 L
s
.54933 .45917 m .55808 .45498 L .56572 .45332 L 0 0 0 r
F
0 g
.36552 .88584 m
.37018 .89125 L
s
.38266 .89794 m .37176 .88552 L .37018 .89125 L 0 1 .425 r
F
0 g
.7612 .77704 m
.76299 .76858 L
s
.41484 .91873 m .40316 .91965 L .40229 .91998 L 0 .639 .203 r
F
.39529 .68463 m .38562 .68458 L .38609 .6868 L 0 1 .494 r
F
.39529 .68463 m .38893 .68166 L .38562 .68458 L F
.39529 .68463 m .3942 .67944 L .38893 .68166 L F
.39529 .68463 m .3979 .67941 L .3942 .67944 L F
.39529 .68463 m .39837 .68163 L .3979 .67941 L F
0 g
.39529 .68463 m
.39593 .6868 L
s
.39003 .68685 m
.39529 .68463 L
s
.55995 .78431 m
.55995 .78431 L
s
.55803 .76229 m
.55803 .76229 L
s
.7403 .899 m .74415 .9032 L .74921 .90177 L 0 .999 .368 r
F
.7403 .899 m .73974 .90273 L .74415 .9032 L F
0 g
.74415 .9032 m
.74498 .90537 L
s
.2696 .92029 m .25657 .91387 L .25557 .917 L 0 1 .507 r
F
.2696 .92029 m .26103 .91377 L .25657 .91387 L F
.2696 .92029 m .26663 .91653 L .26103 .91377 L F
.28052 .91959 m .26663 .91653 L .2696 .92029 L 0 1 .499 r
F
0 g
.26859 .9234 m
.2696 .92029 L
s
.2696 .92029 m
.27507 .92283 L
s
.39839 .91476 m .39332 .92071 L .3972 .92026 L 0 .96 .42 r
F
.39835 .91724 m .39332 .92071 L .3972 .92026 L 0 1 .521 r
F
.39835 .91724 m .38848 .91819 L .39332 .92071 L F
0 g
.38852 .91575 m
.39068 .91798 L
s
.3983 .91971 m .39332 .92071 L .3972 .92026 L 0 .685 .232 r
F
.3983 .91971 m .38843 .92063 L .39332 .92071 L F
0 g
.39725 .92025 m
.39733 .92025 L
s
.40497 .9316 m .3972 .92026 L .39332 .92071 L 0 .922 .424 r
F
0 g
.3933 .92079 m
.39332 .92071 L
s
.39276 .92129 m
.39332 .92071 L
s
.39331 .92079 m
.39332 .92071 L
s
.47258 .75021 m .46668 .72239 L .46452 .72908 L 0 1 .316 r
F
0 g
.46607 .71187 m
.46668 .72239 L
s
.46668 .72239 m
.47049 .72421 L
s
.48063 .90573 m .47217 .90786 L .47184 .90644 L 0 0 0 r
F
0 g
.46792 .90771 m
.47184 .90644 L
s
.32159 .76883 m .31092 .76784 L .31334 .7697 L 0 1 .395 r
F
0 g
.30998 .7713 m
.31334 .7697 L
s
.46496 1.02157 m .46596 1.02725 L .46747 1.02632 L 0 .571 .418 r
F
.47743 1.03471 m .46747 1.02632 L .46596 1.02725 L 0 .456 .391 r
F
0 g
.46596 1.02725 m
.46893 1.03175 L
s
.46088 1.02394 m
.46596 1.02725 L
s
.5154 .96785 m .51571 .96873 L .5184 .9693 L 0 .492 .237 r
F
0 g
.51571 .96873 m
.5188 .9698 L
s
.26933 .70335 m .26062 .6949 L .2581 .70196 L 0 1 .529 r
F
.26933 .70335 m .26584 .6902 L .26062 .6949 L F
.26933 .70335 m .27026 .69102 L .26584 .6902 L F
.26933 .70335 m .27176 .69667 L .27026 .69102 L F
0 g
.26413 .70802 m
.26933 .70335 L
s
.26933 .70335 m
.2709 .70868 L
s
.44833 .69816 m .44344 .67822 L .44019 .68667 L 0 1 .341 r
F
0 g
.44344 .67822 m
.44362 .66879 L
s
.44344 .67822 m
.44813 .67556 L
s
.3331 .57453 m .32218 .57437 L .32593 .57705 L 0 .617 .354 r
F
0 g
.32593 .57705 m
.3329 .5746 L
s
.33221 .58129 m
.33294 .57578 L
s
.32497 .58475 m
.32593 .57705 L
s
.269 .93599 m .26375 .93721 L .26807 .93693 L 0 .684 .241 r
F
.269 .93599 m .25808 .93643 L .26375 .93721 L F
0 g
.26371 .93828 m
.26375 .93721 L
s
.26807 .93693 m
.27437 .93733 L
s
.77403 .90001 m .78253 .90395 L .78525 .9003 L 0 1 .468 r
F
0 g
.7772 .90638 m
.78253 .90395 L
s
.78253 .90395 m
.7838 .90696 L
s
.41237 .67684 m .40345 .67928 L .40714 .67914 L 0 1 .456 r
F
.41237 .67684 m .40336 .67724 L .40345 .67928 L F
0 g
.40714 .67914 m
.40777 .68132 L
s
.41237 .67684 m .40693 .67439 L .40336 .67724 L 0 1 .456 r
F
0 g
.40714 .67914 m
.41237 .67684 L
s
.34425 .58612 m .33891 .56861 L .3331 .57459 L 0 .418 .366 r
F
0 g
.33294 .57578 m
.3331 .57459 L
s
.34425 .58612 m .34636 .57047 L .33891 .56861 L 0 .418 .366 r
F
.34425 .58612 m .35048 .57895 L .34636 .57047 L F
.34425 .58612 m .34957 .58566 L .35048 .57895 L F
0 g
.33681 .58424 m
.34425 .58612 L
s
.76245 .75153 m .775 .76166 L .77375 .74796 L 0 1 .413 r
F
0 g
.77302 .7708 m
.775 .76166 L
s
.775 .76166 m
.77934 .77097 L
s
.75949 .61753 m .77424 .6121 L .77016 .61831 L 0 .124 .042 r
F
0 g
.77398 .60649 m
.77424 .6121 L
s
.77424 .6121 m
.78059 .60827 L
s
.41268 .94793 m .40946 .94146 L .40432 .93707 L 0 .881 .427 r
F
0 g
.40432 .93707 m
.40946 .94146 L
s
.41257 .95334 m
.41268 .94793 L
s
.41156 .76809 m .40016 .76942 L .40273 .76864 L 0 0 0 r
F
0 g
.39878 .76892 m
.40273 .76864 L
s
.76934 1.05862 m .77259 1.05867 L .77908 1.05533 L 0 .841 .229 r
F
0 g
.76495 1.06187 m
.77259 1.05867 L
s
.77053 1.06056 m
.77259 1.05867 L
s
.42795 .51727 m .41872 .52494 L .42085 .52372 L 0 .899 .169 r
F
0 g
.42248 .52333 m
.42404 .52174 L
s
.42795 .51727 m .42294 .5204 L .41872 .52494 L 0 .899 .169 r
F
.42795 .51727 m .4307 .51311 L .42294 .5204 L F
.42795 .51727 m .43781 .50666 L .4307 .51311 L F
.42795 .51727 m .43951 .50535 L .43781 .50666 L F
0 g
.43529 .5099 m
.43951 .50535 L
s
.42404 .52174 m
.42795 .51727 L
s
.43951 .50535 m
.44143 .50368 L
s
.45644 .71204 m .44867 .70822 L .45203 .7136 L 0 1 .332 r
F
.45644 .71204 m .44833 .69816 L .44867 .70822 L F
.46452 .72908 m .45644 .71204 L .45704 .72257 L 0 1 .324 r
F
0 g
.45203 .7136 m
.45644 .71204 L
s
.48834 .75441 m .49002 .75016 L .48966 .73631 L 0 .921 .3 r
F
0 g
.48966 .73631 m
.49002 .75016 L
s
.48966 .73631 m
.49261 .74394 L
s
.50487 .89169 m .50298 .89351 L .5007 .89368 L 0 0 .02 r
F
.33617 .89943 m .33055 .90381 L .33461 .9035 L 0 1 .524 r
F
.33617 .89943 m .32592 .90004 L .33055 .90381 L F
0 g
.32968 .90789 m
.33055 .90381 L
s
.33461 .9035 m
.33726 .90529 L
s
.33726 .90529 m
.3397 .90695 L
s
.64771 1.06989 m
.64795 1.06999 L
s
.39839 .91476 m .3872 .9032 L .38602 .90869 L 0 .96 .42 r
F
0 g
.38107 .90367 m
.38602 .90869 L
s
.60923 .62855 m .61957 .62296 L .62267 .62499 L 0 .112 .051 r
F
.60923 .62855 m .61382 .62448 L .61957 .62296 L F
0 g
.61957 .62296 m
.62039 .62213 L
s
.61382 .62448 m
.6148 .61796 L
s
.61606 .62389 m
.61957 .62296 L
s
.61382 .62448 m
.61382 .62448 L
s
.61382 .62448 m
.61606 .62389 L
s
.43667 .76513 m .42797 .76641 L .43244 .76523 L 0 0 0 r
F
0 g
.43244 .76523 m
.43517 .76369 L
s
.26382 .88824 m .25738 .89373 L .26184 .89346 L 0 1 .53 r
F
.26382 .88824 m .25259 .88874 L .25738 .89373 L F
0 g
.25631 .899 m
.25738 .89373 L
s
.26184 .89346 m
.26734 .89816 L
s
.53736 .90794 m
.53762 .90361 L
s
.81066 .78699 m .81938 .79004 L .81469 .7886 L 0 0 0 r
F
.81066 .78699 m .82235 .79104 L .81938 .79004 L F
.50857 .6145 m .50432 .6197 L .50466 .61803 L 0 0 .008 r
F
0 g
.5033 .61719 m
.50518 .61547 L
s
.50857 .6145 m .50809 .61918 L .50432 .6197 L 0 0 .008 r
F
.50857 .6145 m .51346 .61682 L .50809 .61918 L F
.50857 .6145 m .51736 .61327 L .51346 .61682 L F
.50857 .6145 m .51719 .61092 L .51736 .61327 L F
0 g
.50518 .61547 m
.50857 .6145 L
s
.51719 .61092 m
.5207 .60676 L
s
.51343 .61144 m
.51719 .61092 L
s
.44833 .69816 m .44028 .69637 L .44364 .70083 L 0 1 .341 r
F
.44833 .69816 m .44019 .68667 L .44028 .69637 L F
0 g
.44364 .70083 m
.44833 .69816 L
s
.44833 .69816 m
.44867 .70822 L
s
.21895 .89038 m .20698 .8771 L .20536 .88308 L 0 1 .533 r
F
.21895 .89038 m .21154 .87704 L .20698 .8771 L F
.21895 .89038 m .21667 .88274 L .21154 .87704 L F
.23015 .88981 m .21667 .88274 L .21895 .89038 L 0 1 .532 r
F
0 g
.21731 .89632 m
.21895 .89038 L
s
.21895 .89038 m
.22398 .89587 L
s
.31092 .76784 m .30264 .7689 L .30692 .76923 L 0 1 .433 r
F
0 g
.30692 .76923 m
.30998 .7713 L
s
.72551 1.07331 m .71912 1.07355 L .71696 1.07312 L 0 0 0 r
F
0 g
.70895 1.07357 m
.71696 1.07312 L
s
.53776 .97435 m .53397 .9734 L .53179 .97271 L 0 0 0 r
F
.44019 .68667 m .4406 .66466 L .43564 .66815 L 0 1 .35 r
F
0 g
.4406 .66466 m
.44093 .66008 L
s
.43844 .9768 m .42714 .97296 L .43114 .979 L 0 .73 .419 r
F
.43844 .9768 m .42653 .96781 L .42714 .97296 L F
.30488 .91822 m .29743 .92102 L .30275 .92063 L 0 1 .475 r
F
.30488 .91822 m .29145 .91893 L .29743 .92102 L F
0 g
.29613 .92356 m
.29743 .92102 L
s
.30275 .92063 m
.30926 .92232 L
s
.42961 .96179 m .42143 .96373 L .42653 .96781 L 0 .784 .418 r
F
.42961 .96179 m .41781 .95747 L .42143 .96373 L F
.30019 .58396 m .29025 .58055 L .28893 .58925 L 0 1 .466 r
F
0 g
.2823 .59577 m
.28893 .58925 L
s
.30019 .58396 m .29608 .57012 L .29025 .58055 L 0 1 .466 r
F
.30019 .58396 m .3033 .56361 L .29608 .57012 L F
.30019 .58396 m .3071 .56538 L .3033 .56361 L F
.30019 .58396 m .30576 .57411 L .3071 .56538 L F
0 g
.29905 .59232 m
.30019 .58396 L
s
.29298 .59045 m
.30019 .58396 L
s
.47482 .94961 m .46945 .95143 L .47349 .95226 L 0 .95 .48 r
F
.47482 .94961 m .46608 .94957 L .46945 .95143 L F
0 g
.46945 .95143 m
.47046 .9535 L
s
.75238 .76978 m
.75668 .77886 L
s
.38107 .6892 m
.38609 .6868 L
s
.24686 .70059 m .2356 .69923 L .23698 .70538 L 0 1 .527 r
F
0 g
.23246 .7109 m
.23698 .70538 L
s
.24151 .70582 m
.24367 .7037 L
s
.31567 .90075 m .30439 .89129 L .30305 .89575 L 0 1 .526 r
F
.31567 .90075 m .30858 .89113 L .30439 .89129 L F
.31567 .90075 m .31341 .89519 L .30858 .89113 L F
.32592 .90004 m .31341 .89519 L .31567 .90075 L 0 1 .525 r
F
0 g
.31432 .90519 m
.31567 .90075 L
s
.31567 .90075 m
.3204 .90465 L
s
.34215 .92179 m .33011 .91893 L .3293 .92066 L 0 1 .409 r
F
.34215 .92179 m .33418 .91873 L .33011 .91893 L F
.34215 .92179 m .33935 .91996 L .33418 .91873 L F
.35204 .92092 m .33935 .91996 L .34215 .92179 L 0 1 .374 r
F
0 g
.34133 .92351 m
.34215 .92179 L
s
.34215 .92179 m
.34718 .92283 L
s
.43844 .9768 m .43114 .979 L .43624 .98286 L 0 .73 .419 r
F
.36194 .92018 m .35694 .9218 L .36084 .92142 L 0 .926 .332 r
F
.36194 .92018 m .35204 .92092 L .35694 .9218 L F
0 g
.35647 .92309 m
.35694 .9218 L
s
.36084 .92142 m
.36608 .92195 L
s
.5392 .92459 m
.53939 .92516 L
s
.53939 .92516 m
.5394 .92519 L
s
.5394 .92519 m
.53951 .92551 L
s
.53951 .92551 m
.53964 .92593 L
s
.54775 .60304 m .54592 .61138 L .54478 .60738 L 0 .255 .085 r
F
.54775 .60304 m .55095 .61422 L .54592 .61138 L F
.54775 .60304 m .55652 .61399 L .55095 .61422 L F
.54775 .60304 m .55948 .60963 L .55652 .61399 L F
.54775 .60304 m .55786 .60406 L .55948 .60963 L F
0 g
.55786 .60406 m
.56031 .5989 L
s
.55284 .60124 m
.55786 .60406 L
s
.35358 .7707 m .34385 .76917 L .34292 .77031 L 0 .714 .256 r
F
.35358 .7707 m .34772 .76859 L .34385 .76917 L F
.35358 .7707 m .35195 .76897 L .34772 .76859 L F
.35358 .7707 m .35446 .76987 L .35195 .76897 L F
0 g
.34971 .77127 m
.35358 .7707 L
s
.35358 .7707 m
.35613 .77129 L
s
.7403 .899 m .73808 .90094 L .73974 .90273 L 0 .999 .368 r
F
0 g
.73808 .90094 m
.73974 .90273 L
s
.73406 .90387 m
.73974 .90273 L
s
.59645 .63003 m
.59654 .62963 L
s
.59625 .63098 m
.59645 .63003 L
s
.59607 .63181 m
.59625 .63098 L
s
.59583 .63292 m
.59607 .63181 L
s
.49439 .7399 m
.497 .75098 L
s
.42961 .96179 m .41771 .95226 L .41781 .95747 L 0 .784 .418 r
F
.38848 .91819 m .3809 .91176 L .37681 .91207 L 0 1 .523 r
F
.38848 .91819 m .3859 .91438 L .3809 .91176 L F
.39835 .91724 m .3859 .91438 L .38848 .91819 L 0 1 .521 r
F
0 g
.38773 .92065 m
.38848 .91819 L
s
.38848 .91819 m
.39245 .92026 L
s
.32163 .69628 m .31229 .69861 L .31641 .69926 L 0 1 .539 r
F
0 g
.31641 .69926 m
.31799 .70356 L
s
.44003 .91532 m .42915 .91723 L .42833 .91699 L 0 0 0 r
F
.31092 .76784 m .30026 .76672 L .30264 .7689 L 0 1 .433 r
F
0 g
.29928 .77074 m
.30264 .7689 L
s
.53479 .75021 m .53646 .74398 L .53966 .75807 L 0 .526 .187 r
F
0 g
.53639 .74221 m
.53646 .74398 L
s
.53912 .74106 m
.53912 .74053 L
s
.41484 .91873 m .40721 .9193 L .40316 .91965 L 0 .639 .203 r
F
.41484 .91873 m .41222 .9189 L .40721 .9193 L F
.42454 .91776 m .41222 .9189 L .41484 .91873 L 0 0 0 r
F
0 g
.41484 .91873 m
.41965 .91826 L
s
.41396 .91906 m
.41484 .91873 L
s
.42345 .91779 m
.42833 .91699 L
s
.48834 .75441 m .48257 .73538 L .48515 .74806 L 0 .921 .3 r
F
0 g
.47917 .73018 m
.48257 .73538 L
s
.48251 .733 m
.48257 .73538 L
s
.54225 .4571 m
.547 .45934 L
s
.547 .45934 m
.54769 .45966 L
s
.54769 .45966 m
.54776 .45969 L
s
.53604 .46098 m
.54225 .4571 L
s
.48393 .4734 m .49239 .46863 L .49849 .46674 L 0 0 0 r
F
0 g
.49239 .46863 m
.49763 .4642 L
s
.41383 .92735 m
.41762 .92869 L
s
.43402 .64577 m .43969 .62742 L .43715 .62423 L 0 1 .365 r
F
.43402 .64577 m .43835 .63664 L .43969 .62742 L F
0 g
.43969 .62742 m
.44505 .62286 L
s
.43835 .63664 m
.44357 .63262 L
s
.43835 .63664 m
.43969 .62742 L
s
.46496 1.02157 m .46011 1.01617 L .45503 1.01287 L 0 .571 .418 r
F
0 g
.45503 1.01287 m
.46011 1.01617 L
s
.45301 1.00792 m
.45503 1.01287 L
s
.44805 .99138 m .43738 .9879 L .4417 .99373 L 0 .665 .418 r
F
.44805 .99138 m .43624 .98286 L .43738 .9879 L F
.47097 .53029 m .46354 .53425 L .46477 .53571 L 0 1 .26 r
F
.47097 .53029 m .46823 .52704 L .46354 .53425 L F
.47097 .53029 m .47571 .51889 L .46823 .52704 L F
.47097 .53029 m .48189 .51349 L .47571 .51889 L F
.75117 .75585 m .76368 .76534 L .76245 .75153 L 0 1 .402 r
F
0 g
.76323 .76744 m
.76368 .76534 L
s
.76368 .76534 m
.76491 .76798 L
s
.33182 .69793 m .32449 .69165 L .32163 .69628 L 0 1 .54 r
F
.33182 .69793 m .32961 .68883 L .32449 .69165 L F
.33182 .69793 m .33359 .68973 L .32961 .68883 L F
.33182 .69793 m .33453 .69363 L .33359 .68973 L F
0 g
.33182 .69793 m
.33288 .70149 L
s
.32671 .70073 m
.33182 .69793 L
s
.49042 .95778 m .49085 .96016 L .49199 .95945 L 0 .788 .418 r
F
.49862 .96138 m .49199 .95945 L .49085 .96016 L 0 .661 .362 r
F
0 g
.49085 .96016 m
.49283 .96168 L
s
.48725 .95958 m
.49085 .96016 L
s
.59234 .47446 m .58983 .48035 L .58771 .47417 L 0 .359 .043 r
F
.59234 .47446 m .59807 .49065 L .58983 .48035 L F
.59234 .47446 m .60695 .49818 L .59807 .49065 L F
0 g
.60526 .48073 m
.60848 .48644 L
s
.59234 .47446 m .61157 .49843 L .60695 .49818 L 0 .359 .043 r
F
.59234 .47446 m .60885 .49125 L .61157 .49843 L F
.59234 .47446 m .60061 .48099 L .60885 .49125 L F
0 g
.60848 .48644 m
.61275 .49401 L
s
.60061 .48099 m
.60526 .48073 L
s
.43085 .93065 m .41952 .9266 L .4189 .92914 L 0 1 .519 r
F
0 g
.41762 .92869 m
.4189 .92914 L
s
.42166 .94632 m .41268 .94793 L .41771 .95226 L 0 .833 .416 r
F
.42166 .94632 m .40946 .94146 L .41268 .94793 L F
.33248 .86121 m .32301 .84663 L .32073 .85315 L 0 1 .446 r
F
.33248 .86121 m .32728 .84653 L .32301 .84663 L F
.33248 .86121 m .33134 .85279 L .32728 .84653 L F
.34301 .86082 m .33134 .85279 L .33248 .86121 L 0 1 .439 r
F
0 g
.33248 .86121 m
.33648 .86737 L
s
.3302 .86771 m
.33248 .86121 L
s
.45754 .5565 m .44983 .55974 L .45149 .56175 L 0 1 .348 r
F
.45754 .5565 m .45372 .55179 L .44983 .55974 L F
.45754 .5565 m .46056 .54322 L .45372 .55179 L F
.45754 .5565 m .46661 .538 L .46056 .54322 L F
0 g
.46661 .538 m
.47097 .53029 L
s
.48701 .50668 m .47994 .51126 L .48072 .51213 L 0 .932 .175 r
F
.48701 .50668 m .4854 .50495 L .47994 .51126 L F
.48701 .50668 m .49345 .49744 L .4854 .50495 L F
.48701 .50668 m .49971 .49201 L .49345 .49744 L F
0 g
.48189 .51349 m
.48701 .50668 L
s
.41156 .76809 m .40132 .76987 L .40016 .76942 L 0 0 0 r
F
.41156 .76809 m .40556 .7699 L .40132 .76987 L F
.41156 .76809 m .41004 .76949 L .40556 .7699 L F
.41156 .76809 m .41261 .76871 L .41004 .76949 L F
0 g
.41156 .76809 m
.41422 .76694 L
s
.40733 .76806 m
.41156 .76809 L
s
.507 1.06503 m
.51107 1.06794 L
s
.70281 .8983 m
.70521 .89835 L
s
.70269 .89829 m
.70281 .8983 L
s
.4381 .93721 m .4351 .93464 L .43022 .9332 L 0 1 .521 r
F
.44631 .93572 m .4381 .93721 L .44273 .93865 L 0 1 .514 r
F
.44631 .93572 m .4351 .93464 L .4381 .93721 L F
0 g
.43796 .93973 m
.4381 .93721 L
s
.72551 1.07331 m .72803 1.07104 L .73469 1.07015 L 0 0 0 r
F
0 g
.72044 1.07231 m
.72803 1.07104 L
s
.72565 1.0712 m
.72803 1.07104 L
s
.52381 .97086 m .52147 .97025 L .52529 .97122 L 0 .407 .208 r
F
0 g
.52529 .97122 m
.52565 .97131 L
s
.52381 .97086 m .5184 .9693 L .52147 .97025 L 0 .407 .208 r
F
0 g
.5188 .9698 m
.52147 .97025 L
s
.36218 .90989 m .35088 .90244 L .34975 .90612 L 0 1 .523 r
F
.36218 .90989 m .35496 .90223 L .35088 .90244 L F
.36218 .90989 m .3598 .90542 L .35496 .90223 L F
.37208 .90913 m .3598 .90542 L .36218 .90989 L 0 1 .522 r
F
0 g
.36218 .90989 m
.36689 .91296 L
s
.36103 .91356 m
.36218 .90989 L
s
.23629 .93744 m .22224 .9339 L .2217 .93566 L 0 .818 .293 r
F
.23629 .93744 m .2267 .93391 L .22224 .9339 L F
.23629 .93744 m .23273 .93543 L .2267 .93391 L F
.24718 .93691 m .23273 .93543 L .23629 .93744 L 0 .739 .262 r
F
0 g
.23573 .93918 m
.23629 .93744 L
s
.23629 .93744 m
.24218 .9387 L
s
.49862 .96138 m .49992 .96351 L .5006 .9629 L 0 .661 .362 r
F
.50698 .96471 m .5006 .9629 L .49992 .96351 L 0 .549 .286 r
F
0 g
.49992 .96351 m
.50229 .96485 L
s
.49659 .96299 m
.49992 .96351 L
s
.3331 .57453 m .32407 .56339 L .32218 .57437 L 0 .617 .354 r
F
0 g
.31539 .57904 m
.32218 .57437 L
s
.77512 .78028 m .78416 .77621 L .78733 .781 L 0 .145 0 r
F
0 g
.78416 .77621 m
.78662 .77655 L
s
.68407 .70735 m
.68442 .70815 L
s
.36855 .69197 m .35877 .69107 L .35942 .69379 L 0 1 .529 r
F
0 g
.35461 .69641 m
.35942 .69379 L
s
.39736 .92033 m
.39746 .92037 L
s
.39746 .92037 m
.39977 .92138 L
s
.39977 .92138 m
.40224 .92245 L
s
.41475 .92456 m .40316 .91965 L .40224 .92245 L 0 1 .521 r
F
0 g
.39733 .92025 m
.39748 .92024 L
s
.39748 .92024 m
.40228 .91998 L
s
.41031 .53641 m .41725 .52863 L .42085 .52372 L 0 1 .201 r
F
0 g
.41725 .52863 m
.42248 .52333 L
s
.57115 .46395 m .57972 .46715 L .58771 .47417 L 0 .291 .055 r
F
.47482 .94961 m .46537 .94766 L .46608 .94957 L 0 .95 .48 r
F
0 g
.46172 .94883 m
.46608 .94957 L
s
.30025 .76672 m .28959 .76781 L .29521 .76829 L 0 1 .463 r
F
0 g
.29521 .76829 m
.29928 .77074 L
s
.36743 .8799 m .35741 .86659 L .35551 .87254 L 0 1 .429 r
F
.44805 .99138 m .4417 .99373 L .44676 .99738 L 0 .665 .418 r
F
.42166 .94632 m .4099 .93621 L .40946 .94146 L 0 .833 .416 r
F
0 g
.60061 .48099 m
.60661 .48846 L
s
.4468 .58479 m .45397 .5649 L .44812 .56992 L 0 1 .371 r
F
0 g
.45397 .5649 m
.45754 .5565 L
s
.35354 .86059 m .34694 .8669 L .35113 .86675 L 0 1 .432 r
F
.35354 .86059 m .34301 .86082 L .34694 .8669 L F
0 g
.34513 .87303 m
.34694 .8669 L
s
.35113 .86675 m
.35551 .87254 L
s
.36855 .69197 m .36188 .68778 L .35877 .69107 L 0 1 .529 r
F
.36855 .69197 m .36706 .6856 L .36188 .68778 L F
.36855 .69197 m .37084 .68598 L .36706 .6856 L F
.36855 .69197 m .37148 .68872 L .37084 .68598 L F
0 g
.36855 .69197 m
.36934 .69454 L
s
.36339 .69414 m
.36855 .69197 L
s
.43667 .76513 m .4256 .76803 L .42797 .76641 L 0 0 0 r
F
.43667 .76513 m .42693 .76901 L .4256 .76803 L F
.43667 .76513 m .43117 .76891 L .42693 .76901 L F
0 g
.4239 .76671 m
.4273 .76646 L
s
.4273 .76646 m
.42797 .76641 L
s
.43667 .76513 m .43548 .7678 L .43117 .76891 L 0 0 0 r
F
.43667 .76513 m .43784 .76618 L .43548 .7678 L F
0 g
.43667 .76513 m
.43915 .76307 L
s
.43244 .76523 m
.43667 .76513 L
s
.4779 .74775 m
.47796 .74872 L
s
.47721 .73591 m
.4779 .74775 L
s
.48246 .95386 m .48201 .95642 L .4836 .95567 L 0 .883 .456 r
F
.49042 .95778 m .4836 .95567 L .48201 .95642 L 0 .788 .418 r
F
0 g
.48201 .95642 m
.48357 .9581 L
s
.47817 .95573 m
.48201 .95642 L
s
.38562 .68458 m
.38609 .6868 L
s
.50554 .48635 m .49891 .4913 L .49923 .49159 L 0 0 0 r
F
.50554 .48635 m .50509 .48615 L .49891 .4913 L F
.50554 .48635 m .51363 .47958 L .50509 .48615 L F
.50554 .48635 m .51889 .47521 L .51363 .47958 L F
.51166 .48123 m .51363 .47958 L .52014 .47487 L F
.50509 .48615 m .51363 .47958 L .51166 .48123 L F
.51889 .47521 m .51991 .47436 L .51363 .47958 L F
0 g
.49942 .49144 m
.50554 .48635 L
s
.49971 .49201 m
.50554 .48635 L
s
.64779 .63202 m .65053 .62864 L .64716 .62945 L 0 1 .516 r
F
.5026 1.06067 m .49687 1.05609 L .4921 1.05316 L 0 .345 .268 r
F
.39382 .55579 m .38388 .56536 L .3868 .56321 L 0 1 .222 r
F
.39382 .55579 m .3868 .56063 L .38388 .56536 L F
0 g
.38459 .56619 m
.3868 .56321 L
s
.39382 .55579 m .39364 .55217 L .3868 .56063 L 0 1 .222 r
F
.39382 .55579 m .40067 .54475 L .39364 .55217 L F
.39382 .55579 m .40321 .54332 L .40067 .54475 L F
.39382 .55579 m .40027 .54805 L .40321 .54332 L F
0 g
.39116 .56021 m
.39382 .55579 L
s
.3868 .56321 m
.39382 .55579 L
s
.4468 .58479 m .43888 .58735 L .44094 .58983 L 0 1 .371 r
F
0 g
.4468 .5848 m
.4468 .58479 L
s
.4468 .58479 m .44196 .57881 L .43888 .58735 L 0 1 .371 r
F
.4468 .58479 m .44812 .56992 L .44196 .57881 L F
0 g
.4468 .58479 m
.4468 .58479 L
s
.47258 .75021 m .47438 .7445 L .4735 .73336 L 0 1 .316 r
F
0 g
.4735 .73336 m
.47438 .7445 L
s
.4735 .73336 m
.47721 .73591 L
s
.49029 1.0474 m .48273 1.04423 L .48836 1.04904 L 0 .36 .334 r
F
.49029 1.0474 m .47932 1.04002 L .48273 1.04423 L F
0 g
.4777 1.0413 m
.48273 1.04423 L
s
.30025 .76672 m .28625 .76513 L .28959 .76781 L 0 1 .463 r
F
0 g
.28523 .76989 m
.28959 .76781 L
s
.2356 .69923 m .22564 .7043 L .23018 .70473 L 0 1 .527 r
F
0 g
.23018 .70473 m
.23047 .70444 L
s
.23018 .70473 m
.23246 .7109 L
s
.41637 .67358 m
.41828 .67268 L
s
.41828 .67268 m
.4208 .67149 L
s
.41898 .67103 m
.4208 .67149 L
s
.32163 .69628 m .31144 .69436 L .31229 .69861 L 0 1 .539 r
F
0 g
.30761 .70219 m
.31229 .69861 L
s
.50692 .89921 m .50487 .89169 L .50679 .89267 L 0 0 .053 r
F
.50692 .89921 m .50298 .89351 L .50487 .89169 L F
0 g
.50487 .89169 m
.50578 .88889 L
s
.40497 .9316 m .4022 .92493 L .3972 .92026 L 0 .922 .424 r
F
0 g
.3972 .92026 m
.39728 .92033 L
s
.3972 .92026 m
.39736 .92033 L
s
.40432 .93707 m
.40497 .9316 L
s
.3972 .92026 m
.39725 .92025 L
s
.41031 .53641 m .40067 .54475 L .40321 .54332 L 0 1 .201 r
F
0 g
.405 .54316 m
.407 .5411 L
s
.41031 .53641 m .40427 .53984 L .40067 .54475 L 0 1 .201 r
F
0 g
.40027 .54805 m
.405 .54316 L
s
.41031 .53641 m .41161 .53185 L .40427 .53984 L 0 1 .201 r
F
.41031 .53641 m .41872 .52494 L .41161 .53185 L F
.41031 .53641 m .42085 .52372 L .41872 .52494 L F
0 g
.41725 .52863 m
.42085 .52372 L
s
.40321 .54332 m
.41031 .53641 L
s
.407 .5411 m
.41031 .53641 L
s
.42085 .52372 m
.42795 .51727 L
s
.25646 .60176 m .24508 .60858 L .24937 .6092 L 0 1 .483 r
F
0 g
.24937 .6092 m
.24957 .61748 L
s
.37816 .87961 m .37176 .88552 L .37602 .88535 L 0 1 .421 r
F
.37816 .87961 m .36743 .8799 L .37176 .88552 L F
.38266 .89794 m .37602 .88535 L .37176 .88552 L 0 1 .425 r
F
0 g
.37018 .89125 m
.37176 .88552 L
s
.67007 .62604 m
.67426 .62569 L
s
.54933 .45917 m .56572 .45332 L .56717 .45529 L 0 0 0 r
F
0 g
.56572 .45332 m
.57101 .4498 L
s
.56387 .45796 m
.57115 .46395 L
s
.55813 .46107 m
.56387 .45796 L
s
.55808 .45498 m
.56572 .45332 L
s
.7499 .78188 m
.75238 .76978 L
s
.74235 .79423 m
.74538 .78409 L
s
.73785 .78831 m
.74127 .79377 L
s
.54083 1.08681 m .54065 1.0836 L .5427 1.08464 L 0 .075 0 r
F
.54083 1.08681 m .53861 1.08337 L .54065 1.0836 L F
0 g
.5396 1.08225 m
.54065 1.0836 L
s
.74385 1.06741 m .75562 1.06436 L .75188 1.06546 L 0 .71 .208 r
F
.73469 1.07015 m .74385 1.06741 L .74627 1.06724 L 0 0 0 r
F
0 g
.68301 .91455 m
.68336 .91401 L
s
.57284 .87073 m .5797 .70334 L .57576 .75156 L 0 .924 .229 r
F
0 g
.57832 .7202 m
.5797 .70334 L
s
.5797 .70334 m
.57994 .67892 L
s
.57679 .70763 m
.57994 .67892 L
s
.57643 .7109 m
.57679 .70763 L
s
.23015 .88981 m .21838 .87694 L .21667 .88274 L 0 1 .532 r
F
.23015 .88981 m .22294 .87688 L .21838 .87694 L F
.23015 .88981 m .22799 .88241 L .22294 .87688 L F
.24137 .88927 m .22799 .88241 L .23015 .88981 L F
0 g
.22843 .89557 m
.23015 .88981 L
s
.23015 .88981 m
.23511 .89513 L
s
.45326 .72159 m .45202 .7136 L .44867 .70822 L 0 1 .335 r
F
.45326 .72159 m .45399 .71933 L .45202 .7136 L F
.38266 .89794 m .38069 .89067 L .37602 .88535 L 0 1 .425 r
F
.39302 .89743 m .38266 .89794 L .3872 .9032 L 0 .997 .416 r
F
.39302 .89743 m .38069 .89067 L .38266 .89794 L F
0 g
.38107 .90367 m
.38266 .89794 L
s
.72646 .89848 m .73235 .9019 L .73808 .90094 L 0 .781 .294 r
F
.72646 .89848 m .72692 .90127 L .73235 .9019 L F
0 g
.73235 .9019 m
.73406 .90387 L
s
.40027 .54805 m
.40321 .54332 L
s
.7628 .89971 m .77144 .90326 L .77403 .90001 L 0 1 .445 r
F
0 g
.7662 .90537 m
.77144 .90326 L
s
.77144 .90326 m
.7728 .90598 L
s
.46452 .72908 m .45704 .72257 L .46039 .72915 L 0 1 .324 r
F
.47258 .75021 m .46452 .72908 L .46539 .74021 L 0 1 .316 r
F
0 g
.72201 .62291 m
.72202 .62292 L
s
.72202 .62292 m
.72298 .62487 L
s
.72298 .62487 m
.72318 .62528 L
s
.72318 .62528 m
.72538 .62972 L
s
.70674 .62106 m .72201 .6229 L .72155 .62187 L 0 .629 .231 r
F
0 g
.71089 .6225 m
.71094 .62321 L
s
.71131 .62196 m
.71646 .62258 L
s
.45326 .72159 m .44867 .70822 L .44553 .70602 L 0 1 .335 r
F
.70772 .65152 m .72201 .62291 L .72195 .63342 L 0 .183 .096 r
F
.46117 .94665 m .45801 .94461 L .45351 .94366 L 0 1 .507 r
F
0 g
.72201 .62291 m
.72201 .62317 L
s
.36743 .8799 m .3616 .86652 L .35741 .86659 L 0 1 .429 r
F
.36743 .8799 m .3659 .87222 L .3616 .86652 L F
0 g
.36552 .88584 m
.36743 .8799 L
s
.37816 .87961 m .3659 .87222 L .36743 .8799 L 0 1 .421 r
F
0 g
.36743 .8799 m
.37176 .88552 L
s
.43903 .6149 m .4441 .5938 L .43841 .59854 L 0 1 .371 r
F
0 g
.4441 .5938 m
.4468 .5848 L
s
.48583 .90164 m .48371 .90332 L .48028 .90432 L 0 0 0 r
F
.49122 .9044 m .48583 .90164 L .48894 .90124 L 0 0 .028 r
F
.49122 .9044 m .48371 .90332 L .48583 .90164 L F
0 g
.48583 .90164 m
.48589 .90008 L
s
.3331 .57453 m .33034 .55145 L .32407 .56339 L 0 .617 .354 r
F
.3331 .57453 m .33751 .54891 L .33034 .55145 L F
.3331 .57453 m .34081 .55749 L .33751 .54891 L F
.3331 .57453 m .33891 .56848 L .34081 .55749 L F
0 g
.3329 .5746 m
.3331 .57453 L
s
.44019 .68667 m .43185 .68638 L .43522 .69018 L 0 1 .35 r
F
.44019 .68667 m .43203 .67694 L .43185 .68638 L F
.44019 .68667 m .43564 .66815 L .43203 .67694 L F
0 g
.43522 .69018 m
.44019 .68667 L
s
.43564 .66815 m
.4406 .66466 L
s
.52607 .88 m
.52666 .8785 L
s
.52666 .8785 m
.5272 .87711 L
s
.57115 .46395 m .56731 .47047 L .56583 .46536 L 0 .291 .055 r
F
.57115 .46395 m .57533 .47752 L .56731 .47047 L F
.57115 .46395 m .58452 .48179 L .57533 .47752 L F
.57115 .46395 m .58983 .48035 L .58452 .48179 L F
.57115 .46395 m .58771 .47417 L .58983 .48035 L F
0 g
.58843 .47421 m
.59234 .47446 L
s
.58771 .47417 m
.58843 .47421 L
s
.57972 .46715 m
.58771 .47417 L
s
.5328 1.08171 m .5266 1.07781 L .52213 1.07484 L 0 0 0 r
F
0 g
.52213 1.07484 m
.5266 1.07781 L
s
.51728 1.07191 m
.52213 1.07484 L
s
.34292 .77031 m .33323 .7682 L .33226 .76967 L 0 .791 .298 r
F
.34292 .77031 m .33714 .76746 L .33323 .7682 L F
.34292 .77031 m .34137 .76795 L .33714 .76746 L F
.34292 .77031 m .34385 .76917 L .34137 .76795 L F
0 g
.33902 .77104 m
.34292 .77031 L
s
.34292 .77031 m
.34543 .77121 L
s
.50698 .96471 m .50914 .96654 L .50934 .96605 L 0 .549 .286 r
F
.5154 .96785 m .50934 .96605 L .50914 .96654 L 0 .492 .237 r
F
0 g
.50914 .96654 m
.51187 .96768 L
s
.50611 .96602 m
.50914 .96654 L
s
.27505 .88778 m .26854 .89307 L .273 .89282 L 0 1 .529 r
F
.27505 .88778 m .26382 .88824 L .26854 .89307 L F
0 g
.26734 .89816 m
.26854 .89307 L
s
.273 .89282 m
.27839 .89736 L
s
.2581 .70196 m .24947 .69315 L .24686 .70059 L 0 1 .528 r
F
.2581 .70196 m .25476 .68816 L .24947 .69315 L F
.2581 .70196 m .2592 .68897 L .25476 .68816 L F
.2581 .70196 m .26062 .6949 L .2592 .68897 L F
0 g
.25282 .70692 m
.2581 .70196 L
s
.2581 .70196 m
.25961 .70758 L
s
.44125 .65906 m .43296 .66191 L .43604 .66155 L 0 1 .325 r
F
.44125 .65906 m .43384 .66001 L .43296 .66191 L F
0 g
.43591 .66226 m
.43604 .66155 L
s
.44125 .65906 m .4381 .65711 L .43384 .66001 L 0 1 .325 r
F
0 g
.43825 .6572 m
.4413 .65485 L
s
.44125 .65906 m .44332 .65461 L .4381 .65711 L 0 1 .325 r
F
.44125 .65906 m .44601 .65419 L .44332 .65461 L F
.44125 .65906 m .44511 .65609 L .44601 .65419 L F
0 g
.44511 .65609 m
.45003 .65352 L
s
.44093 .66008 m
.44125 .65906 L
s
.43604 .66155 m
.44125 .65906 L
s
.40016 .76942 m .39124 .76964 L .39584 .76932 L 0 0 0 r
F
0 g
.39584 .76932 m
.39878 .76892 L
s
.38843 .92063 m .37663 .92014 L .37571 .92095 L 0 .742 .251 r
F
.38843 .92063 m .38073 .91987 L .37663 .92014 L F
.38843 .92063 m .38579 .92008 L .38073 .91987 L F
.3983 .91971 m .38579 .92008 L .38843 .92063 L 0 .685 .232 r
F
0 g
.38749 .92144 m
.38843 .92063 L
s
.38843 .92063 m
.39332 .92071 L
s
.39733 .92038 m
.4022 .92493 L
s
.39728 .92033 m
.39733 .92038 L
s
.52529 .97122 m
.52566 .97133 L
s
.52568 .97134 m
.52602 .97143 L
s
.52603 .97144 m
.52638 .97153 L
s
.52638 .97154 m
.52674 .97164 L
s
.52675 .97164 m
.52762 .97189 L
s
.65135 .59069 m .65261 .58345 L .64928 .57337 L 0 .1 .186 r
F
0 g
.64928 .57337 m
.65024 .58138 L
s
.64879 .57168 m
.64928 .57337 L
s
.44631 .93572 m .44273 .93865 L .44591 .938 L 0 1 .514 r
F
.45343 .94141 m .44591 .938 L .44273 .93865 L 0 1 .512 r
F
0 g
.44273 .93865 m
.44281 .94089 L
s
.4381 .93721 m
.44273 .93865 L
s
.78881 1.05248 m .80082 1.04764 L .79686 1.04876 L 0 1 .276 r
F
.77908 1.05533 m .78881 1.05248 L .79092 1.05056 L 0 .903 .246 r
F
.41466 .9304 m .40497 .9316 L .4099 .93621 L 0 .876 .413 r
F
.41466 .9304 m .4022 .92493 L .40497 .9316 L F
.39302 .89743 m .3872 .9032 L .39129 .90293 L 0 .997 .416 r
F
.39839 .91476 m .39129 .90293 L .3872 .9032 L 0 .96 .42 r
F
0 g
.38602 .90869 m
.3872 .9032 L
s
.38266 .89794 m
.3872 .9032 L
s
.66556 1.07421 m .67755 1.07522 L .67361 1.07574 L 0 0 0 r
F
.68142 1.08056 m .67755 1.07522 L .68539 1.076 L F
0 g
.68289 1.07456 m
.68539 1.076 L
s
.68142 1.08056 m .67361 1.07574 L .67755 1.07522 L 0 0 0 r
F
0 g
.6751 1.07354 m
.67755 1.07522 L
s
.45835 1.00552 m .4484 1.00231 L .45301 1.00791 L 0 .587 .412 r
F
.45835 1.00552 m .44676 .99738 L .4484 1.00231 L F
.46179 .73767 m .45399 .71933 L .45326 .72159 L 0 1 .327 r
F
.46179 .73767 m .45704 .72257 L .45399 .71933 L F
0 g
.45644 .71204 m
.45704 .72257 L
s
.45202 .7136 m
.45399 .71933 L
s
.28625 .76513 m .27737 .76671 L .28195 .76713 L 0 1 .491 r
F
0 g
.28195 .76713 m
.28523 .76989 L
s
.49261 .74394 m
.49288 .75872 L
s
.49288 .75872 m
.49289 .75944 L
s
.49289 .75944 m
.4929 .75952 L
s
.4929 .75952 m
.4929 .75953 L
s
.4929 .75953 m
.4929 .75953 L
s
.54039 .92286 m
.54042 .92298 L
s
.46179 .73767 m .46038 .72916 L .45704 .72257 L 0 1 .327 r
F
0 g
.45399 .71933 m
.45704 .72257 L
s
.51363 .47958 m
.51991 .47436 L
s
.43903 .6149 m .43079 .61674 L .43334 .61966 L 0 1 .371 r
F
.43903 .6149 m .43296 .60768 L .43079 .61674 L F
.43903 .6149 m .43841 .59854 L .43296 .60768 L F
0 g
.43841 .59854 m
.4441 .5938 L
s
.28052 .91959 m .26774 .91363 L .26663 .91653 L 0 1 .499 r
F
.28052 .91959 m .27221 .91355 L .26774 .91363 L F
.28052 .91959 m .27769 .91611 L .27221 .91355 L F
.29144 .91893 m .27769 .91611 L .28052 .91959 L 0 1 .49 r
F
0 g
.27939 .92246 m
.28052 .91959 L
s
.28052 .91959 m
.28587 .92192 L
s
.46847 .76103 m
.46899 .75987 L
s
.46835 .76019 m
.46899 .75987 L
s
.4447 .70845 m .44553 .70602 L .44364 .70084 L 0 1 .344 r
F
.45326 .72159 m .44553 .70602 L .4447 .70845 L 0 1 .335 r
F
0 g
.44553 .70602 m
.44867 .70822 L
s
.51051 .89567 m .51123 .88827 L .51143 .89188 L 0 0 .053 r
F
.51412 .8921 m .51143 .89188 L .51123 .88827 L F
0 g
.51123 .88827 m
.51252 .88407 L
s
.50964 .88699 m
.51123 .88827 L
s
.4447 .70845 m .44364 .70084 L .44028 .69637 L 0 1 .344 r
F
0 g
.44364 .70084 m
.44553 .70602 L
s
.43564 .66815 m
.43591 .66226 L
s
.5026 1.06067 m .50656 1.06471 L .50675 1.06437 L 0 .345 .268 r
F
0 g
.50656 1.06471 m
.507 1.06503 L
s
.50178 1.06177 m
.50656 1.06471 L
s
.81885 .9011 m .83003 .90137 L .8291 .8975 L 0 1 .516 r
F
.2356 .69923 m .22433 .69791 L .22564 .7043 L 0 1 .527 r
F
0 g
.2211 .71007 m
.22564 .7043 L
s
.42961 .96179 m .42653 .96781 L .4297 .967 L 0 .784 .418 r
F
.43844 .9768 m .4297 .967 L .42653 .96781 L 0 .73 .419 r
F
0 g
.42653 .96781 m
.42714 .97296 L
s
.42143 .96373 m
.42653 .96781 L
s
.52638 .47017 m .52029 .47514 L .52014 .47487 L 0 0 0 r
F
.52638 .47017 m .52712 .47142 L .52029 .47514 L F
.52638 .47017 m .53606 .46621 L .52712 .47142 L F
.52638 .47017 m .54228 .46153 L .53606 .46621 L F
0 g
.51991 .47436 m
.52638 .47017 L
s
.20676 .91131 m .20086 .91561 L .20531 .91545 L 0 1 .527 r
F
.20676 .91131 m .19556 .91151 L .20086 .91561 L F
0 g
.20047 .91986 m
.20086 .91561 L
s
.20531 .91545 m
.21147 .91923 L
s
.32407 .56339 m .31277 .5684 L .31654 .57066 L 0 1 .422 r
F
0 g
.31539 .57904 m
.31654 .57066 L
s
.32407 .56339 m .31486 .55754 L .31277 .5684 L 0 1 .422 r
F
.32407 .56339 m .32142 .54532 L .31486 .55754 L F
.32407 .56339 m .32895 .53806 L .32142 .54532 L F
.32407 .56339 m .33243 .54059 L .32895 .53806 L F
.32407 .56339 m .33034 .55145 L .33243 .54059 L F
0 g
.32218 .57437 m
.32407 .56339 L
s
.31654 .57066 m
.32407 .56339 L
s
.34301 .86082 m .33368 .84644 L .33134 .85279 L 0 1 .439 r
F
.34301 .86082 m .33795 .8464 L .33368 .84644 L F
.34301 .86082 m .34194 .85257 L .33795 .8464 L F
.35354 .86059 m .34194 .85257 L .34301 .86082 L 0 1 .432 r
F
0 g
.34301 .86082 m
.34694 .8669 L
s
.34066 .86716 m
.34301 .86082 L
s
.28625 .76513 m .27484 .76376 L .27737 .76671 L 0 1 .491 r
F
0 g
.2738 .76914 m
.27737 .76671 L
s
.46757 .94499 m .46117 .94665 L .46537 .94766 L 0 .997 .494 r
F
.46757 .94499 m .45801 .94461 L .46117 .94665 L F
0 g
.46117 .94665 m
.46172 .94883 L
s
.45475 .91211 m .44799 .91429 L .44447 .91454 L 0 0 0 r
F
.45475 .91211 m .4524 .91325 L .44799 .91429 L F
.46299 .91204 m .45475 .91211 L .45891 .91121 L F
.46299 .91204 m .4524 .91325 L .45475 .91211 L F
0 g
.45413 .91155 m
.45475 .91211 L
s
.49647 .62201 m .5013 .61903 L .50466 .61803 L 0 0 0 r
F
0 g
.5013 .61903 m
.5033 .61719 L
s
.79155 .61896 m .80266 .61281 L .80708 .61349 L 0 0 0 r
F
0 g
.78917 .61193 m
.79162 .61078 L
s
.79155 .61896 m .79602 .61514 L .80266 .61281 L 0 0 0 r
F
0 g
.80174 .61033 m
.80266 .61281 L
s
.62837 .62757 m .64211 .63004 L .64107 .62936 L 0 .683 .274 r
F
0 g
.64211 .63004 m
.64779 .63202 L
s
.42166 .94632 m .41771 .95226 L .42122 .95157 L 0 .833 .416 r
F
.42961 .96179 m .42122 .95157 L .41771 .95226 L 0 .784 .418 r
F
0 g
.41771 .95226 m
.41781 .95747 L
s
.41268 .94793 m
.41771 .95226 L
s
.41466 .9304 m .40316 .91965 L .4022 .92493 L 0 .876 .413 r
F
0 g
.4022 .92493 m
.40314 .91975 L
s
.40224 .92245 m
.40313 .91975 L
s
.47482 .94961 m .47349 .95226 L .47551 .95152 L 0 .95 .48 r
F
.48246 .95386 m .47551 .95152 L .47349 .95226 L 0 .883 .456 r
F
0 g
.47349 .95226 m
.47463 .95407 L
s
.46945 .95143 m
.47349 .95226 L
s
.74398 .78116 m
.74538 .78409 L
s
.44631 .93572 m .43549 .93236 L .4351 .93464 L 0 1 .514 r
F
0 g
.43022 .9332 m
.4351 .93464 L
s
.54083 1.08681 m .5427 1.08464 L .54365 1.08612 L 0 .075 0 r
F
0 g
.5427 1.08464 m
.54483 1.08466 L
s
.46299 .91204 m .45891 .91121 L .4621 .91115 L 0 0 0 r
F
.46838 .90866 m .4621 .91115 L .45891 .91121 L F
0 g
.45846 .91027 m
.45891 .91121 L
s
.45475 .91211 m
.45891 .91121 L
s
.2981 .84065 m .28867 .84792 L .29427 .84766 L 0 1 .461 r
F
.2981 .84065 m .28406 .84116 L .28867 .84792 L F
0 g
.28562 .85496 m
.28867 .84792 L
s
.29427 .84766 m
.29952 .85415 L
s
.48393 .4734 m .47617 .47998 L .47697 .47827 L 0 0 0 r
F
0 g
.47677 .47665 m
.47817 .47545 L
s
.48393 .4734 m .48227 .4781 L .47617 .47998 L 0 0 0 r
F
.48393 .4734 m .49122 .47387 L .48227 .4781 L F
.48393 .4734 m .49816 .469 L .49122 .47387 L F
.48393 .4734 m .49849 .46674 L .49816 .469 L F
0 g
.47817 .47545 m
.48393 .4734 L
s
.49849 .46674 m
.50512 .46232 L
s
.49239 .46863 m
.49849 .46674 L
s
.72646 .89848 m .72439 .8998 L .72692 .90127 L 0 .781 .294 r
F
0 g
.72063 .90185 m
.72692 .90127 L
s
.45326 .72159 m .44666 .71419 L .45012 .71939 L 0 1 .335 r
F
.45326 .72159 m .4447 .70845 L .44666 .71419 L F
.46179 .73767 m .45326 .72159 L .45529 .72806 L 0 1 .327 r
F
0 g
.45012 .71939 m
.45326 .72159 L
s
.46039 .72915 m
.46452 .72908 L
s
.46039 .72915 m
.46039 .72915 L
s
.43402 .64577 m .43715 .62423 L .43172 .62876 L 0 1 .365 r
F
0 g
.43715 .62423 m
.43903 .6149 L
s
.34644 .89893 m .34071 .90306 L .34478 .9028 L 0 1 .522 r
F
.34644 .89893 m .33617 .89943 L .34071 .90306 L F
0 g
.3397 .90695 m
.34071 .90306 L
s
.34478 .9028 m
.34717 .9044 L
s
.34717 .9044 m
.34975 .90612 L
s
.27993 .93561 m .27455 .93653 L .27888 .93628 L 0 .644 .227 r
F
.27993 .93561 m .269 .93599 L .27455 .93653 L F
0 g
.27437 .93733 m
.27455 .93653 L
s
.27888 .93628 m
.28503 .93644 L
s
.32592 .90004 m .31486 .89091 L .31341 .89519 L 0 1 .525 r
F
.32592 .90004 m .31905 .89078 L .31486 .89091 L F
.32592 .90004 m .32379 .8947 L .31905 .89078 L F
.33617 .89943 m .32379 .8947 L .32592 .90004 L 0 1 .524 r
F
0 g
.32446 .9043 m
.32592 .90004 L
s
.32592 .90004 m
.33055 .90381 L
s
.37571 .92095 m
.37571 .92095 L
s
.78508 .74497 m .79207 .73299 L .78754 .73399 L 0 1 .432 r
F
.78508 .74497 m .79643 .74243 L .79207 .73299 L F
.77375 .74796 m .78508 .74497 L .78074 .73563 L 0 1 .423 r
F
.77375 .74796 m .78074 .73563 L .77621 .7368 L F
.76245 .75153 m .77375 .74796 L .76943 .73873 L 0 1 .413 r
F
.75957 1.06239 m .75562 1.06436 L .76309 1.06143 L 0 .776 .205 r
F
.75957 1.06239 m .75188 1.06546 L .75562 1.06436 L F
.46179 .73767 m .46242 .73563 L .46038 .72916 L 0 1 .327 r
F
.45044 .76369 m .44195 .76571 L .44625 .76403 L 0 .005 .013 r
F
0 g
.44625 .76403 m
.44872 .76197 L
s
.45835 1.00552 m .45301 1.00791 L .45798 1.01141 L 0 .587 .412 r
F
0 g
.39837 .68163 m
.40345 .67928 L
s
.39302 .89743 m .38241 .88517 L .38069 .89067 L 0 .997 .416 r
F
0 g
.37602 .88535 m
.38069 .89067 L
s
.43844 .9768 m .43624 .98286 L .43905 .98195 L 0 .73 .419 r
F
.44805 .99138 m .43905 .98195 L .43624 .98286 L 0 .665 .418 r
F
0 g
.43624 .98286 m
.43738 .9879 L
s
.43114 .979 m
.43624 .98286 L
s
.7516 .76699 m .76381 .76869 L .76337 .7744 L 0 .278 .038 r
F
0 g
.76323 .76744 m
.76381 .76869 L
s
.76381 .76869 m
.76496 .76809 L
s
.52317 .88188 m
.52429 .87893 L
s
.52586 .88055 m .52449 .88188 L .52447 .87847 L 0 0 .06 r
F
0 g
.52447 .87853 m
.52448 .88119 L
s
.4447 .70845 m .438 .70271 L .44147 .70704 L 0 1 .344 r
F
.4447 .70845 m .43611 .69753 L .438 .70271 L F
.4447 .70845 m .43705 .69495 L .43611 .69753 L F
.4447 .70845 m .44028 .69637 L .43705 .69495 L F
0 g
.44028 .69637 m
.44028 .69637 L
s
.44019 .68667 m
.44028 .69637 L
s
.44147 .70704 m
.4447 .70845 L
s
.4447 .70845 m
.44666 .71419 L
s
.27484 .76376 m .26593 .76565 L .2705 .76608 L 0 1 .507 r
F
0 g
.2705 .76608 m
.2738 .76914 L
s
.69877 .89037 m
.69879 .89034 L
s
.6988 .89032 m
.70177 .88416 L
s
.44905 .91484 m .44447 .91454 L .44799 .91429 L 0 0 0 r
F
.44905 .91484 m .44003 .91532 L .44447 .91454 L F
0 g
.44385 .91398 m
.44447 .91454 L
s
.38244 .90852 m .37681 .91207 L .3809 .91176 L 0 1 .519 r
F
.38244 .90852 m .37208 .90913 L .37681 .91207 L F
0 g
.37583 .91534 m
.37681 .91207 L
s
.79643 .74243 m .80342 .73073 L .79888 .73159 L 0 1 .44 r
F
.79643 .74243 m .8078 .74024 L .80342 .73073 L F
.52815 .9724 m .52906 .97217 L .53024 .97247 L 0 0 0 r
F
.52815 .9724 m .52762 .97189 L .52906 .97217 L F
0 g
.52872 .97204 m
.52906 .97217 L
s
.62412 .70698 m
.62466 .71269 L
s
.62526 .71908 m
.62579 .72467 L
s
.62715 .73906 m
.6288 .75653 L
s
.6288 .75653 m
.62921 .76083 L
s
.80312 .63906 m .81794 .64581 L .81423 .63962 L 0 1 .503 r
F
0 g
.81731 .65003 m
.81794 .64581 L
s
.33034 .55145 m
.33243 .54059 L
s
.33034 .55145 m
.33751 .54891 L
s
.50692 .89921 m .50242 .89691 L .50298 .89351 L 0 0 .053 r
F
0 g
.5007 .89368 m
.50298 .89351 L
s
.45044 .76369 m .43983 .76791 L .44195 .76571 L 0 .005 .013 r
F
.45044 .76369 m .44363 .76778 L .43983 .76791 L F
.44363 .76778 m .44228 .76801 L .43983 .76791 L F
.44334 .76795 m .44559 .76248 L .44138 .76387 L 0 1 .338 r
F
.45025 .78231 m .44677 .76752 L .44334 .76795 L F
.44363 .76778 m .44334 .76795 L .44228 .76801 L 0 .005 .013 r
F
.45025 .78231 m .44334 .76795 L .4398 .77077 L 0 1 .338 r
F
.44334 .76795 m .44272 .76803 L .44228 .76801 L 0 .005 .013 r
F
.44317 .76805 m .44051 .76848 L .43983 .76791 L F
.44334 .76795 m .44138 .76387 L .44035 .76835 L 0 1 .338 r
F
.4429 .7683 m .44035 .76835 L .4398 .77077 L F
.4398 .77077 m .44035 .76835 L .43976 .76845 L 0 1 .348 r
F
.43983 .76791 m .43117 .76891 L .43548 .7678 L 0 0 0 r
F
.43983 .76791 m .43734 .76855 L .43117 .76891 L F
.43734 .76855 m .43113 .75393 L .42932 .76134 L 0 1 .348 r
F
.4398 .77077 m .43861 .76846 L .43734 .76855 L F
.4398 .77077 m .43734 .76855 L .43116 .7696 L F
.43734 .76855 m .43578 .76867 L .43562 .76868 L 0 0 0 r
F
.43734 .76855 m .43562 .76868 L .43117 .76891 L F
.43734 .76855 m .42932 .76134 L .43103 .76903 L 0 1 .348 r
F
.43734 .76855 m .43103 .76903 L .43116 .7696 L F
.43734 .76855 m .43716 .7686 L .43578 .76867 L 0 0 0 r
F
.4398 .77077 m .43116 .7696 L .43541 .77322 L 0 1 .348 r
F
.43639 .7878 m .43116 .7696 L .42688 .77234 L 0 1 .352 r
F
.43639 .7878 m .43541 .77322 L .43116 .7696 L F
.43734 .76855 m .4309 .77189 L .4292 .77066 L 0 0 0 r
F
.43983 .76791 m .43861 .76846 L .43734 .76855 L F
.43861 .76846 m .43861 .76846 L .43734 .76855 L 0 1 .348 r
F
.43861 .76846 m .4309 .77189 L .43734 .76855 L 0 0 0 r
F
.43861 .76846 m .43113 .75393 L .43734 .76855 L 0 1 .348 r
F
.43716 .7686 m .4292 .77066 L .43087 .76918 L 0 0 0 r
F
.43716 .7686 m .43087 .76918 L .43117 .76891 L F
.43861 .76846 m .43526 .77199 L .4309 .77189 L F
.43983 .76791 m .43927 .76841 L .43861 .76846 L F
.4398 .77077 m .43927 .76841 L .43861 .76846 L 0 1 .348 r
F
.43927 .76841 m .43526 .77199 L .43861 .76846 L 0 0 0 r
F
.43861 .76846 m .43927 .76841 L .4386 .76844 L 0 1 .348 r
F
.43927 .76841 m .43936 .77091 L .43526 .77199 L 0 0 0 r
F
.43983 .76791 m .43976 .76838 L .43927 .76841 L F
.4398 .77077 m .43976 .76838 L .43927 .76841 L 0 1 .348 r
F
.43976 .76838 m .43936 .77091 L .43927 .76841 L 0 0 0 r
F
.43927 .76841 m .43955 .75561 L .43552 .75148 L 0 1 .348 r
F
.43976 .76838 m .43955 .75561 L .43927 .76841 L F
.43976 .76836 m .44138 .76387 L .43955 .75561 L F
.43976 .76845 m .43978 .76838 L .43976 .76838 L F
.43976 .76838 m .43981 .76839 L .43976 .76839 L 0 0 0 r
F
.43976 .76836 m .4398 .76838 L .43976 .76838 L F
.43983 .76791 m .44035 .76835 L .43976 .76836 L F
.44035 .76835 m .44138 .76387 L .43976 .76845 L 0 1 .348 r
F
.4398 .76838 m .43981 .76839 L .43976 .76838 L 0 0 0 r
F
.43976 .76838 m .43979 .76836 L .43976 .76836 L 0 1 .348 r
F
.43978 .76838 m .43979 .76836 L .43976 .76838 L F
.43979 .76836 m .44138 .76387 L .43976 .76836 L F
.4386 .76844 m .43552 .75148 L .43113 .75393 L F
.43927 .76841 m .43552 .75148 L .4386 .76844 L F
.43976 .76839 m .44132 .76916 L .43936 .77091 L 0 0 0 r
F
.43981 .76839 m .44132 .76916 L .43976 .76839 L F
.44035 .76835 m .44132 .76916 L .43976 .76836 L F
.44334 .76795 m .44035 .76835 L .4429 .7683 L 0 1 .338 r
F
.44334 .76795 m .44275 .76803 L .44272 .76803 L 0 .005 .013 r
F
.44334 .76795 m .44552 .76882 L .44132 .76916 L F
.45044 .76369 m .44677 .76752 L .44334 .76795 L F
.44677 .76752 m .44552 .76882 L .44334 .76795 L F
.44677 .76752 m .44676 .76747 L .44334 .76795 L 0 1 .338 r
F
.44676 .76747 m .44559 .76248 L .44334 .76795 L F
.44334 .76795 m .44317 .76805 L .44275 .76803 L 0 .005 .013 r
F
.45044 .76369 m .44962 .76711 L .44937 .76722 L F
.45025 .78231 m .44961 .76752 L .44937 .76722 L 0 1 .338 r
F
.45044 .76369 m .44937 .76722 L .44677 .76752 L 0 .005 .013 r
F
.44677 .76752 m .44937 .76722 L .44559 .76248 L 0 1 .338 r
F
.45025 .78231 m .44937 .76722 L .44677 .76752 L F
.44677 .76752 m .44937 .76722 L .44674 .76755 L 0 .005 .013 r
F
.44674 .76755 m .44937 .76722 L .44552 .76882 L F
.45044 .76369 m .45172 .76492 L .44962 .76711 L F
.45385 .76652 m .44559 .76248 L .44937 .76722 L 0 1 .334 r
F
.45186 .76699 m .44937 .76722 L .44961 .76752 L F
.45025 .78231 m .45161 .77602 L .44961 .76752 L 0 1 .338 r
F
.45384 .76688 m .44552 .76882 L .44937 .76722 L 0 .064 .025 r
F
.45186 .76699 m .44937 .76722 L .44962 .76711 L F
.45384 .76688 m .44937 .76722 L .45186 .76699 L F
.4527 .76679 m .44937 .76722 L .45186 .76699 L 0 1 .334 r
F
.45385 .76652 m .44937 .76722 L .4527 .76679 L F
.45354 .76637 m .44399 .75344 L .44559 .76248 L F
.45385 .76652 m .45371 .76634 L .45354 .76637 L F
.45371 .76634 m .44399 .75344 L .45354 .76637 L F
.44317 .76805 m .44132 .76916 L .44051 .76848 L 0 .005 .013 r
F
0 g
.45111 .76289 m
.4527 .76098 L
s
.47743 1.03471 m .47932 1.04002 L .4804 1.03922 L 0 .456 .391 r
F
.49029 1.0474 m .4804 1.03922 L .47932 1.04002 L 0 .36 .334 r
F
0 g
.47932 1.04002 m
.48273 1.04423 L
s
.4744 1.03682 m
.47932 1.04002 L
s
.74884 .61639 m .7534 .62332 L .7492 .62336 L 0 .18 .062 r
F
.74884 .61639 m .75949 .61753 L .7534 .62332 L F
0 g
.74919 .62323 m
.7492 .62336 L
s
.7491 .62149 m
.74919 .62323 L
s
.74884 .61639 m
.7491 .62149 L
s
.74291 .62336 m
.74294 .62332 L
s
.74294 .62332 m
.74317 .62306 L
s
.74317 .62306 m
.74884 .61639 L
s
.53032 .607 m
.53476 .60796 L
s
.52682 .61116 m
.53032 .607 L
s
.76245 .75153 m .76943 .73873 L .76491 .74012 L 0 1 .413 r
F
.75117 .75585 m .76245 .75153 L .75815 .74243 L 0 1 .402 r
F
.36407 .86055 m .35741 .86659 L .3616 .86652 L 0 1 .425 r
F
.36407 .86055 m .35354 .86059 L .35741 .86659 L F
0 g
.35551 .87254 m
.35741 .86659 L
s
.49029 1.0474 m .48836 1.04904 L .49306 1.05221 L 0 .36 .334 r
F
0 g
.48836 1.04904 m
.4921 1.05316 L
s
.24137 .88927 m .22978 .87679 L .22799 .88241 L 0 1 .532 r
F
.24137 .88927 m .23435 .87674 L .22978 .87679 L F
.24137 .88927 m .23931 .88209 L .23435 .87674 L F
.25259 .88874 m .23931 .88209 L .24137 .88927 L 0 1 .531 r
F
0 g
.23956 .89484 m
.24137 .88927 L
s
.24137 .88927 m
.24624 .89442 L
s
.33226 .76967 m .32261 .76701 L .32159 .76883 L 0 .911 .349 r
F
.33226 .76967 m .32656 .76607 L .32261 .76701 L F
.33226 .76967 m .33079 .76665 L .32656 .76607 L F
.33226 .76967 m .33323 .7682 L .33079 .76665 L F
0 g
.32832 .7706 m
.33226 .76967 L
s
.33226 .76967 m
.33474 .77089 L
s
.73872 .62333 m
.73872 .62332 L
s
.73245 .62321 m
.73246 .62322 L
s
.73246 .62322 m
.73403 .62372 L
s
.73403 .62372 m
.73785 .62493 L
s
.44892 .7358 m .45012 .71939 L .44666 .71419 L 0 1 .339 r
F
.44892 .7358 m .45109 .72865 L .45012 .71939 L F
.27484 .76376 m .26343 .76238 L .26593 .76565 L 0 1 .507 r
F
0 g
.26236 .76836 m
.26593 .76565 L
s
.82235 .79104 m .83109 .79325 L .82641 .79203 L 0 .349 .191 r
F
.82235 .79104 m .83403 .7945 L .83109 .79325 L F
.40016 .76942 m .38874 .77006 L .39124 .76964 L 0 0 0 r
F
0 g
.38724 .76989 m
.39124 .76964 L
s
.4201 .67013 m
.42068 .66997 L
s
.25646 .60176 m .24588 .60002 L .24508 .60858 L 0 1 .483 r
F
0 g
.23875 .61614 m
.24508 .60858 L
s
.44892 .7358 m .44666 .71419 L .44221 .71605 L 0 1 .339 r
F
.61276 .49401 m .61157 .49843 L .60885 .49125 L 0 .388 .002 r
F
0 g
.60885 .49125 m
.60911 .49144 L
s
.60661 .48846 m
.60885 .49125 L
s
.61276 .49401 m .61999 .51249 L .61157 .49843 L 0 .388 .002 r
F
.61276 .49401 m .62849 .52404 L .61999 .51249 L F
0 g
.62474 .50716 m
.62615 .51052 L
s
.61276 .49401 m .63239 .52676 L .62849 .52404 L 0 .388 .002 r
F
0 g
.62615 .51052 m
.62623 .51071 L
s
.61276 .49401 m .62909 .51886 L .63239 .52676 L 0 .388 .002 r
F
0 g
.63146 .52316 m
.63227 .52509 L
s
.63227 .52509 m
.63228 .5251 L
s
.62623 .51071 m
.62633 .51096 L
s
.61276 .49401 m .62068 .50484 L .62909 .51886 L 0 .388 .002 r
F
0 g
.62633 .51096 m
.63146 .52316 L
s
.62079 .5049 m
.6209 .50496 L
s
.62068 .50484 m
.62079 .5049 L
s
.6209 .50496 m
.62474 .50716 L
s
.60911 .49144 m
.61276 .49401 L
s
.51699 1.07191 m .51728 1.07191 L .52176 1.075 L 0 .217 .197 r
F
.41466 .9304 m .4099 .93621 L .4137 .93567 L 0 .876 .413 r
F
.42166 .94632 m .4137 .93567 L .4099 .93621 L 0 .833 .416 r
F
0 g
.40946 .94146 m
.4099 .93621 L
s
.40497 .9316 m
.4099 .93621 L
s
.43402 .64577 m .42567 .64724 L .42859 .65032 L 0 1 .365 r
F
0 g
.43402 .64578 m
.43402 .64577 L
s
.43402 .64577 m .42701 .63799 L .42567 .64724 L 0 1 .365 r
F
0 g
.43305 .65531 m
.43402 .64578 L
s
.42859 .65032 m
.43401 .64579 L
s
.43402 .64577 m .43172 .62876 L .42701 .63799 L 0 1 .365 r
F
0 g
.43401 .64579 m
.43402 .64577 L
s
.31144 .69436 m .29972 .69646 L .30514 .69741 L 0 1 .536 r
F
0 g
.30514 .69741 m
.30761 .70219 L
s
.30576 .57411 m
.31277 .5684 L
s
.3616 .86652 m
.3659 .87222 L
s
.37816 .87961 m .36803 .86648 L .3659 .87222 L 0 1 .421 r
F
.47743 1.03471 m .47238 1.02951 L .46747 1.02632 L 0 .456 .391 r
F
0 g
.46747 1.02632 m
.47238 1.02951 L
s
.46496 1.02157 m
.46747 1.02632 L
s
.52815 .9724 m .53024 .97247 L .53047 .97269 L 0 0 0 r
F
0 g
.53024 .97247 m
.53179 .97271 L
s
.3088 .84034 m .30167 .84734 L .30594 .84717 L 0 1 .455 r
F
.3088 .84034 m .2981 .84065 L .30167 .84734 L F
0 g
.29953 .85415 m
.30167 .84734 L
s
.30594 .84717 m
.31013 .85361 L
s
.44003 .91532 m .43296 .91695 L .42915 .91723 L 0 0 0 r
F
.44003 .91532 m .43763 .91613 L .43296 .91695 L F
.44905 .91484 m .43763 .91613 L .44003 .91532 L F
0 g
.4392 .91509 m
.44003 .91532 L
s
.44003 .91532 m
.44447 .91454 L
s
.46757 .94499 m .45775 .94263 L .45801 .94461 L 0 .997 .494 r
F
0 g
.45351 .94366 m
.45801 .94461 L
s
.8078 .74024 m .8148 .72875 L .81024 .72951 L 0 1 .448 r
F
.8078 .74024 m .81918 .73834 L .8148 .72875 L F
0 g
.3809 .91176 m
.38321 .91297 L
s
.39835 .91724 m .38704 .91136 L .3859 .91438 L 0 1 .521 r
F
0 g
.38321 .91297 m
.3859 .91438 L
s
.35877 .69107 m .34949 .6926 L .35346 .69313 L 0 1 .535 r
F
0 g
.35346 .69313 m
.35461 .69641 L
s
.66556 1.07421 m
.66556 1.07421 L
s
.66556 1.07421 m
.66557 1.07422 L
s
.54934 .46044 m .55813 .46107 L .56583 .46536 L 0 .203 .052 r
F
.39839 .91476 m .39609 .90789 L .39129 .90293 L 0 .96 .42 r
F
0 g
.39791 .91701 m
.39839 .91476 L
s
.40869 .91403 m .39839 .91476 L .40316 .91965 L 0 .916 .41 r
F
.40869 .91403 m .39609 .90789 L .39839 .91476 L F
0 g
.54782 .45967 m
.54933 .45917 L
s
.54776 .45969 m
.54782 .45967 L
s
.54228 .46153 m
.54776 .45969 L
s
.22433 .69791 m .2143 .70324 L .21884 .70366 L 0 1 .527 r
F
0 g
.21884 .70366 m
.2211 .71007 L
s
.31514 .91775 m .30979 .92014 L .31385 .91987 L 0 1 .459 r
F
.31514 .91775 m .30489 .91822 L .30979 .92014 L F
0 g
.30926 .92232 m
.30979 .92014 L
s
.31385 .91987 m
.31927 .92145 L
s
.5154 .96785 m .5184 .9693 L .51813 .969 L 0 .492 .237 r
F
.52381 .97086 m .51813 .969 L .5184 .9693 L 0 .407 .208 r
F
0 g
.5184 .9693 m
.52147 .97025 L
s
.51571 .96873 m
.5184 .9693 L
s
.46179 .73767 m .45529 .72806 L .45874 .73443 L 0 1 .327 r
F
0 g
.45326 .72159 m
.45529 .72806 L
s
.45807 .75052 m .45529 .72807 L .45109 .72865 L 0 1 .33 r
F
.45807 .75052 m .45874 .73443 L .45529 .72807 L F
0 g
.45501 .72811 m
.45529 .72807 L
s
.6945 .62212 m .71131 .62196 L .70674 .62106 L 0 0 0 r
F
0 g
.71089 .62249 m
.71131 .62196 L
s
.39129 .90293 m
.39609 .90789 L
s
.75156 .89937 m .76033 .90254 L .7628 .89971 L 0 1 .412 r
F
0 g
.75519 .90432 m
.76033 .90254 L
s
.76033 .90254 m
.7618 .90496 L
s
.24718 .93691 m .23339 .93394 L .23273 .93543 L 0 .739 .262 r
F
.24718 .93691 m .23786 .93396 L .23339 .93394 L F
.24718 .93691 m .24378 .93524 L .23786 .93396 L F
.25808 .93643 m .24378 .93524 L .24718 .93691 L 0 .715 .252 r
F
0 g
.24649 .93839 m
.24718 .93691 L
s
.24718 .93691 m
.25296 .93794 L
s
.78685 .78495 m .79122 .77961 L .79592 .78167 L 0 .063 0 r
F
.78685 .78495 m .78733 .781 L .79122 .77961 L F
0 g
.78772 .77701 m
.79122 .77961 L
s
.26343 .76238 m .25448 .76457 L .25906 .765 L 0 1 .518 r
F
0 g
.25906 .765 m
.26236 .76836 L
s
.2863 .88737 m .2797 .89245 L .28417 .89222 L 0 1 .527 r
F
.2863 .88737 m .27505 .88778 L .2797 .89245 L F
0 g
.27839 .89736 m
.2797 .89245 L
s
.28417 .89222 m
.28945 .8966 L
s
.49647 .62201 m .49136 .62632 L .49221 .62514 L 0 0 0 r
F
0 g
.49143 .62485 m
.49347 .6233 L
s
.49647 .62201 m .49473 .62533 L .49136 .62632 L 0 0 0 r
F
.49647 .62201 m .50006 .62283 L .49473 .62533 L F
.49647 .62201 m .50432 .6197 L .50006 .62283 L F
.49647 .62201 m .50466 .61803 L .50432 .6197 L F
0 g
.49347 .6233 m
.49647 .62201 L
s
.50466 .61803 m
.50857 .6145 L
s
.5013 .61903 m
.50466 .61803 L
s
.35204 .92092 m .34029 .91846 L .33935 .91996 L 0 1 .374 r
F
.35204 .92092 m .34437 .91831 L .34029 .91846 L F
.35204 .92092 m .3494 .91936 L .34437 .91831 L F
.36194 .92018 m .3494 .91936 L .35204 .92092 L 0 .926 .332 r
F
0 g
.35204 .92092 m
.35694 .9218 L
s
.35108 .92241 m
.35204 .92092 L
s
.46838 .90866 m .46617 .91005 L .4621 .91115 L 0 0 0 r
F
.47575 .9095 m .46838 .90866 L .47217 .90786 L F
.47575 .9095 m .46617 .91005 L .46838 .90866 L F
0 g
.46792 .90771 m
.46838 .90866 L
s
.47031 .75757 m .46242 .73563 L .46179 .73767 L 0 .992 .319 r
F
.47031 .75757 m .46539 .74021 L .46242 .73563 L F
0 g
.46038 .72916 m
.46242 .73563 L
s
.25646 .60176 m .25125 .58921 L .24588 .60002 L 0 1 .483 r
F
.25646 .60176 m .25836 .58174 L .25125 .58921 L F
.25646 .60176 m .26245 .58261 L .25836 .58174 L F
.25646 .60176 m .26163 .5912 L .26245 .58261 L F
0 g
.25579 .61015 m
.25646 .60176 L
s
.24937 .6092 m
.25646 .60176 L
s
.29025 .58055 m .27878 .58648 L .28284 .58755 L 0 1 .468 r
F
0 g
.2823 .59577 m
.28284 .58755 L
s
.64173 .54467 m
.64201 .54576 L
s
.64323 .55052 m .65798 .59311 L .65084 .57044 L 0 0 .132 r
F
.64323 .55052 m .66088 .60442 L .65798 .59311 L F
.64323 .55052 m .65758 .59677 L .66088 .60442 L F
0 g
.64924 .5803 m
.64972 .58263 L
s
.64323 .55052 m .65001 .57364 L .65758 .59677 L 0 0 .132 r
F
0 g
.64261 .54837 m
.64323 .55052 L
s
.65024 .58138 m
.65048 .58339 L
s
.65048 .58339 m
.65114 .58895 L
s
.64972 .58263 m
.65099 .58889 L
s
.64276 .54869 m
.64323 .55052 L
s
.32163 .69628 m .31443 .68933 L .31144 .69436 L 0 1 .539 r
F
0 g
.31144 .69436 m
.31229 .69861 L
s
.32163 .69628 m .31967 .68633 L .31443 .68933 L 0 1 .539 r
F
.32163 .69628 m .32365 .68738 L .31967 .68633 L F
.32163 .69628 m .32449 .69165 L .32365 .68738 L F
0 g
.31641 .69926 m
.32163 .69628 L
s
.32163 .69628 m
.32259 .70017 L
s
.43974 .72375 m .44147 .70704 L .438 .70271 L 0 1 .348 r
F
.43974 .72375 m .44221 .71605 L .44147 .70704 L F
0 g
.44147 .70704 m
.44147 .70704 L
s
.48091 .76295 m
.48112 .76224 L
s
.48112 .76224 m
.48113 .76218 L
s
.48113 .76218 m
.48149 .76093 L
s
.7159 .89801 m .71973 .90038 L .72439 .8998 L 0 .674 .252 r
F
.7159 .89801 m .71559 .89984 L .71973 .90038 L F
0 g
.71973 .90038 m
.72063 .90185 L
s
.43611 .69753 m .43705 .69495 L .43522 .69018 L 0 1 .353 r
F
0 g
.43705 .69495 m
.44028 .69637 L
s
.4278 .65942 m
.43305 .65531 L
s
.49122 .9044 m .48894 .90124 L .49097 .90239 L 0 0 .028 r
F
.49561 .9004 m .49097 .90239 L .48894 .90124 L 0 0 .026 r
F
0 g
.48894 .90124 m
.48908 .89902 L
s
.48583 .90164 m
.48894 .90124 L
s
.35354 .86059 m .34435 .8464 L .34194 .85257 L 0 1 .432 r
F
.35354 .86059 m .34862 .84643 L .34435 .8464 L F
.35354 .86059 m .35255 .85251 L .34862 .84643 L F
.36407 .86055 m .35255 .85251 L .35354 .86059 L 0 1 .425 r
F
0 g
.35354 .86059 m
.35741 .86659 L
s
.35113 .86675 m
.35354 .86059 L
s
.26343 .76238 m .25201 .76099 L .25448 .76457 L 0 1 .518 r
F
0 g
.25092 .76756 m
.25448 .76457 L
s
.54151 .97484 m
.5416 .97485 L
s
.53776 .97435 m
.54151 .97484 L
s
.5416 .97485 m
.5424 .97528 L
s
.48862 .76065 m
.48862 .76061 L
s
.75117 .75585 m .75815 .74243 L .75364 .74412 L 0 1 .402 r
F
0 g
.74689 .74693 m
.75117 .75585 L
s
.49122 .9044 m .48396 .90533 L .48371 .90332 L 0 0 .028 r
F
0 g
.48028 .90432 m
.48371 .90332 L
s
.81885 .9011 m .8291 .8975 L .82459 .8975 L 0 1 .516 r
F
.80766 .90084 m .81885 .9011 L .81781 .8975 L 0 1 .508 r
F
.37185 .91958 m .36671 .9209 L .37062 .92058 L 0 .789 .283 r
F
.37185 .91958 m .36194 .92018 L .36671 .9209 L F
0 g
.36608 .92195 m
.36671 .9209 L
s
.37062 .92058 m
.37571 .92095 L
s
.44805 .99138 m .44676 .99738 L .44919 .99643 L 0 .665 .418 r
F
.45835 1.00552 m .44919 .99643 L .44676 .99738 L 0 .587 .412 r
F
0 g
.44676 .99738 m
.4484 1.00231 L
s
.4417 .99373 m
.44676 .99738 L
s
.24686 .70059 m .23831 .69145 L .2356 .69923 L 0 1 .527 r
F
.24686 .70059 m .24367 .68618 L .23831 .69145 L F
.24686 .70059 m .24811 .68697 L .24367 .68618 L F
.24686 .70059 m .24947 .69315 L .24811 .68697 L F
0 g
.24367 .7037 m
.24686 .70059 L
s
.24686 .70059 m
.2483 .70647 L
s
.3195 .84011 m .31234 .84694 L .31661 .8468 L 0 1 .449 r
F
.3195 .84011 m .3088 .84034 L .31234 .84694 L F
0 g
.31013 .85361 m
.31234 .84694 L
s
.31661 .8468 m
.32073 .85315 L
s
.54934 .46044 m .54422 .46709 L .54351 .46369 L 0 .203 .052 r
F
.53538 .46873 m .54422 .46709 L .53767 .4705 L 0 .091 .039 r
F
.52712 .47142 m .53937 .4661 L .53538 .46873 L 0 0 0 r
F
.53937 .4661 m .53987 .46588 L .53538 .46873 L F
.52712 .47142 m .53606 .46621 L .54337 .46304 L F
.52712 .47142 m .54337 .46304 L .54338 .46304 L F
.53987 .46588 m .54338 .46304 L .54422 .46709 L 0 .091 .039 r
F
.53987 .46588 m .54338 .46304 L .5442 .464 L 0 0 0 r
F
.52712 .47142 m .54338 .46304 L .53987 .46588 L F
.5271 .46234 m .54337 .46301 L .54338 .46304 L 0 .091 .039 r
F
.5271 .46234 m .54338 .46304 L .53987 .46588 L F
.5271 .46234 m .53538 .46873 L .5281 .47094 L F
.53538 .46873 m .53767 .4705 L .5323 .47075 L F
.53083 .47113 m .53767 .4705 L .54537 .47214 L 0 .039 .013 r
F
.52833 .47253 m .53901 .47665 L .52891 .47648 L F
.52712 .47142 m .53448 .46902 L .5281 .47232 L 0 0 0 r
F
.53448 .46902 m .53407 .46925 L .5281 .47232 L F
.53461 .46898 m .533 .46989 L .5281 .47232 L F
.53527 .46876 m .53484 .46899 L .53326 .46977 L F
.53347 .46965 m .53326 .46977 L .5281 .47232 L F
.53527 .46876 m .53326 .46977 L .53347 .46965 L F
.52967 .47177 m .54607 .47479 L .53901 .47665 L 0 .039 .013 r
F
.53484 .46899 m .53148 .47079 L .5281 .47232 L 0 0 0 r
F
.53538 .46873 m .53148 .47078 L .53484 .46899 L F
.53148 .47078 m .53148 .47079 L .53484 .46899 L F
.5303 .47142 m .54537 .47214 L .54607 .47479 L 0 .039 .013 r
F
.5281 .47094 m .53083 .47113 L .5303 .47142 L F
.53083 .47113 m .54537 .47214 L .5303 .47142 L F
.5281 .47094 m .5303 .47142 L .52967 .47177 L F
.5303 .47142 m .54607 .47479 L .52967 .47177 L F
.5281 .47094 m .52967 .47177 L .52833 .47253 L F
.52967 .47177 m .53901 .47665 L .52833 .47253 L F
.53448 .46902 m .53461 .46898 L .53407 .46925 L 0 0 0 r
F
.53461 .46898 m .53527 .46876 L .533 .46989 L F
.52712 .47142 m .52076 .47551 L .52056 .47541 L F
.52712 .47142 m .5281 .47232 L .52076 .47551 L F
.5281 .47094 m .52833 .47253 L .5212 .47483 L 0 .039 .013 r
F
.52833 .47253 m .52891 .47648 L .52343 .47531 L F
.52833 .47253 m .52343 .47531 L .5212 .47483 L F
.5281 .47094 m .53148 .47079 L .53083 .47113 L F
.53148 .47079 m .53767 .4705 L .53083 .47113 L F
.53527 .46876 m .53538 .46873 L .53484 .46899 L 0 0 0 r
F
.53987 .46588 m .54422 .46709 L .53538 .46873 L 0 .091 .039 r
F
.53538 .46873 m .53766 .46798 L .53148 .47079 L 0 0 0 r
F
.53538 .46873 m .5323 .47075 L .53148 .47079 L 0 .091 .039 r
F
.53538 .46873 m .53148 .47079 L .5281 .47094 L F
.5271 .46234 m .53987 .46588 L .53538 .46873 L F
.53538 .46873 m .54107 .46536 L .53686 .46824 L 0 0 0 r
F
.53987 .46588 m .54107 .46536 L .53538 .46873 L F
.53686 .46824 m .5442 .464 L .53766 .46798 L F
.54107 .46536 m .5442 .464 L .53686 .46824 L F
.54638 .46173 m .54351 .46369 L .54338 .46304 L 0 .203 .052 r
F
.54934 .46044 m .54351 .46369 L .54638 .46173 L F
.5435 .46295 m .54338 .46304 L .54337 .46304 L 0 0 0 r
F
.5435 .46295 m .54338 .46304 L .54337 .46301 L 0 .203 .052 r
F
.54934 .46044 m .54338 .46304 L .5435 .46295 L F
.54933 .45917 m .5442 .464 L .54338 .46304 L 0 0 0 r
F
.54933 .45917 m .54338 .46304 L .5435 .46295 L F
0 g
.54776 .45969 m
.54782 .45972 L
s
.54934 .46044 m .55193 .47141 L .54422 .46709 L 0 .203 .052 r
F
.54934 .46044 m .56136 .47307 L .55193 .47141 L F
.54934 .46044 m .56731 .47047 L .56136 .47307 L F
.54934 .46044 m .56583 .46536 L .56731 .47047 L F
.54933 .45917 m .55187 .46233 L .5442 .464 L 0 0 0 r
F
0 g
.54782 .45972 m
.5482 .4599 L
s
.5435 .46295 m
.54454 .46228 L
s
.54933 .45917 m .56125 .45915 L .55187 .46233 L 0 0 0 r
F
0 g
.55813 .46107 m
.56583 .46536 L
s
.54933 .45917 m .56717 .45529 L .56125 .45915 L 0 0 0 r
F
0 g
.54454 .46228 m
.54933 .45917 L
s
.81918 .73834 m .82619 .727 L .82163 .72767 L 0 1 .455 r
F
.81918 .73834 m .83058 .73666 L .82619 .727 L F
0 g
.72789 .67833 m
.72801 .67627 L
s
.72801 .67627 m
.72846 .66857 L
s
.41475 .92456 m .40721 .9193 L .40316 .91965 L 0 1 .521 r
F
.41475 .92456 m .41218 .9214 L .40721 .9193 L F
.42446 .92362 m .41475 .92456 L .41952 .9266 L 0 1 .517 r
F
.42446 .92362 m .41218 .9214 L .41475 .92456 L F
0 g
.41383 .92735 m
.41475 .92456 L
s
.46923 1.01927 m .46011 1.01617 L .46496 1.02157 L 0 .489 .398 r
F
.46923 1.01927 m .45798 1.01141 L .46011 1.01617 L F
0 g
.73785 .78831 m
.73928 .78253 L
s
.80367 1.0412 m .80082 1.04764 L .80812 1.04287 L 0 1 .322 r
F
.80367 1.0412 m .79686 1.04876 L .80082 1.04764 L F
0 g
.79852 1.05001 m
.80082 1.04764 L
s
.47438 .7445 m
.47796 .74872 L
s
.42446 .92362 m .41952 .9266 L .42333 .92616 L 0 1 .517 r
F
.43085 .93065 m .42333 .92616 L .41952 .9266 L 0 1 .519 r
F
0 g
.4189 .92914 m
.41952 .9266 L
s
.41475 .92456 m
.41952 .9266 L
s
.45807 .75052 m .45993 .74405 L .45874 .73443 L 0 1 .33 r
F
0 g
.45941 .73986 m
.45993 .74405 L
s
.45874 .73443 m
.45941 .73986 L
s
.50018 .89616 m .49833 .89788 L .49575 .89817 L 0 0 .023 r
F
.43611 .69753 m .43522 .69018 L .43185 .68639 L 0 1 .353 r
F
0 g
.43522 .69018 m
.43705 .69495 L
s
.40869 .91403 m .39757 .90262 L .39609 .90789 L 0 .916 .41 r
F
.53476 .60797 m .54 .60592 L .54478 .60738 L 0 .149 .065 r
F
.47031 .75757 m .46179 .73767 L .4639 .74511 L 0 .992 .319 r
F
0 g
.46179 .73767 m
.46389 .74506 L
s
.45874 .73443 m
.46179 .73767 L
s
.46242 .73563 m
.46477 .73926 L
s
.68853 .62261 m
.69449 .62212 L
s
.6945 .62212 m .69969 .6209 L .69488 .62158 L 0 0 0 r
F
.6945 .62212 m .70674 .62106 L .69969 .6209 L F
.21798 .91114 m .21198 .91521 L .21643 .91505 L 0 1 .525 r
F
.21798 .91114 m .20676 .91131 L .21198 .91521 L F
0 g
.21147 .91923 m
.21198 .91521 L
s
.21643 .91505 m
.22248 .91863 L
s
.52239 .88392 m .52098 .88532 L .52058 .88256 L 0 0 .057 r
F
.32159 .76883 m .31199 .76564 L .31092 .76784 L 0 1 .395 r
F
.32159 .76883 m .31597 .76448 L .31199 .76564 L F
.32159 .76883 m .3202 .76514 L .31597 .76448 L F
.32159 .76883 m .32261 .76701 L .3202 .76514 L F
0 g
.31762 .76999 m
.32159 .76883 L
s
.32159 .76883 m
.32404 .77037 L
s
.37208 .90913 m .36107 .90195 L .3598 .90542 L 0 1 .522 r
F
.37208 .90913 m .36515 .9018 L .36107 .90195 L F
.37208 .90913 m .36987 .90488 L .36515 .9018 L F
0 g
.3708 .91259 m
.37208 .90913 L
s
.38244 .90852 m .36987 .90488 L .37208 .90913 L 0 1 .519 r
F
0 g
.37208 .90913 m
.37681 .91207 L
s
.22433 .69791 m .21304 .69662 L .2143 .70324 L 0 1 .527 r
F
0 g
.20972 .70925 m
.2143 .70324 L
s
.5328 1.08171 m .53861 1.08336 L .53795 1.08409 L 0 0 0 r
F
0 g
.53413 1.08038 m
.53861 1.08336 L
s
.54083 1.08681 m .53795 1.08409 L .53861 1.08337 L 0 .075 0 r
F
0 g
.53861 1.08337 m
.54065 1.0836 L
s
.46757 .94499 m .46537 .94766 L .46781 .94697 L 0 .997 .494 r
F
.47482 .94961 m .46781 .94697 L .46537 .94766 L 0 .95 .48 r
F
0 g
.46537 .94766 m
.46608 .94957 L
s
.46117 .94665 m
.46537 .94766 L
s
.45807 .75052 m .45109 .72865 L .44892 .7358 L 0 1 .33 r
F
0 g
.45012 .71939 m
.45109 .72865 L
s
.45109 .72865 m
.45501 .72811 L
s
.43974 .72375 m .438 .70271 L .43332 .70557 L 0 1 .348 r
F
0 g
.4375 .70302 m
.438 .70271 L
s
.48515 .74806 m
.48834 .75441 L
s
.25201 .76099 m .24303 .76349 L .24761 .76392 L 0 1 .525 r
F
0 g
.24761 .76392 m
.25092 .76756 L
s
.43611 .69753 m .42932 .69302 L .4328 .6967 L 0 1 .353 r
F
.43611 .69753 m .42749 .68825 L .42932 .69302 L F
.43611 .69753 m .42853 .68556 L .42749 .68825 L F
.43611 .69753 m .43185 .68639 L .42853 .68556 L F
0 g
.43611 .69753 m
.438 .70271 L
s
.4328 .6967 m
.43611 .69753 L
s
.47258 .75021 m .46539 .74021 L .46872 .74837 L 0 1 .316 r
F
0 g
.46452 .72908 m
.46539 .74021 L
s
.47031 .75757 m .46872 .74837 L .46539 .74021 L 0 .992 .319 r
F
0 g
.46477 .73926 m
.46539 .74021 L
s
.49002 .75016 m
.49268 .75901 L
s
.49268 .75901 m
.49281 .75946 L
s
.49281 .75946 m
.49284 .75954 L
s
.49284 .75954 m
.49284 .75954 L
s
.49284 .75954 m
.49284 .75955 L
s
.49284 .75955 m
.49289 .7597 L
s
.49289 .7597 m
.49289 .75971 L
s
.40869 .91403 m .40316 .91965 L .40721 .9193 L 0 .916 .41 r
F
.41466 .9304 m .40721 .9193 L .40316 .91965 L 0 .876 .413 r
F
.40865 .91653 m .40316 .91965 L .40721 .9193 L 0 1 .517 r
F
.40865 .91653 m .39835 .91724 L .40316 .91965 L F
0 g
.39839 .91476 m
.40065 .91708 L
s
.40861 .91903 m .40316 .91965 L .40721 .9193 L 0 .599 .203 r
F
.40861 .91903 m .3983 .91971 L .40316 .91965 L F
0 g
.40314 .91975 m
.40316 .91965 L
s
.40229 .91998 m
.40316 .91965 L
s
.40313 .91975 m
.40316 .91965 L
s
.44892 .7358 m .44221 .71605 L .43974 .72375 L 0 1 .339 r
F
0 g
.44221 .71605 m
.44666 .71419 L
s
.44147 .70704 m
.44221 .71605 L
s
.7159 .89801 m .71394 .89882 L .71559 .89984 L 0 .674 .252 r
F
0 g
.71394 .89882 m
.71559 .89984 L
s
.71038 .90015 m
.71559 .89984 L
s
.70738 .71019 m
.70763 .71079 L
s
.70728 .71231 m
.70738 .71019 L
s
.37816 .87961 m .37241 .8665 L .36803 .86648 L 0 1 .421 r
F
.37816 .87961 m .37675 .87213 L .37241 .8665 L F
.3889 .8796 m .37816 .87961 L .38241 .88517 L 0 1 .412 r
F
.3889 .8796 m .37675 .87213 L .37816 .87961 L F
0 g
.37602 .88535 m
.37816 .87961 L
s
.47575 .9095 m .47217 .90786 L .475 .90818 L 0 0 0 r
F
.48063 .90573 m .475 .90818 L .47217 .90786 L F
0 g
.47184 .90644 m
.47217 .90786 L
s
.46838 .90866 m
.47217 .90786 L
s
.43203 .67694 m .42339 .67776 L .42678 .68106 L 0 1 .36 r
F
.43203 .67694 m .42383 .66848 L .42339 .67776 L F
0 g
.42352 .66922 m
.42364 .66851 L
s
.42068 .66997 m
.42351 .66922 L
s
.43185 .68638 m
.43185 .68638 L
s
.43185 .68638 m
.43203 .67694 L
s
.3889 .8796 m .38241 .88517 L .38667 .8851 L 0 1 .412 r
F
.39302 .89743 m .38667 .8851 L .38241 .88517 L 0 .997 .416 r
F
0 g
.38069 .89067 m
.38241 .88517 L
s
.37816 .87961 m
.38241 .88517 L
s
.31144 .69436 m .29804 .69155 L .29972 .69646 L 0 1 .536 r
F
0 g
.29398 .70018 m
.29972 .69646 L
s
.45114 .65165 m .44332 .65461 L .44601 .65419 L 0 1 .243 r
F
.45114 .65165 m .44474 .65277 L .44332 .65461 L F
0 g
.44511 .65609 m
.44601 .65419 L
s
.45114 .65165 m .44932 .64989 L .44474 .65277 L 0 1 .243 r
F
.45114 .65165 m .45447 .64735 L .44932 .64989 L F
.45114 .65165 m .45673 .64684 L .45447 .64735 L F
.45114 .65165 m .4553 .64869 L .45673 .64684 L F
0 g
.4553 .64869 m
.46012 .64604 L
s
.45003 .65352 m
.45114 .65165 L
s
.44601 .65419 m
.45114 .65165 L
s
.67325 .92344 m
.6733 .92347 L
s
.25259 .88874 m .24119 .87666 L .23931 .88209 L 0 1 .531 r
F
.25259 .88874 m .24576 .87661 L .24119 .87666 L F
.25259 .88874 m .25064 .8818 L .24576 .87661 L F
.26382 .88824 m .25064 .8818 L .25259 .88874 L 0 1 .53 r
F
0 g
.2507 .89414 m
.25259 .88874 L
s
.25259 .88874 m
.25738 .89373 L
s
.60923 .62855 m .62267 .62499 L .62129 .62815 L 0 .112 .051 r
F
.29025 .58055 m .28027 .57761 L .27878 .58648 L 0 1 .468 r
F
0 g
.27198 .59338 m
.27878 .58648 L
s
.29025 .58055 m .28634 .56685 L .28027 .57761 L 0 1 .468 r
F
.29025 .58055 m .29377 .55982 L .28634 .56685 L F
.29025 .58055 m .29759 .56123 L .29377 .55982 L F
.29025 .58055 m .29608 .57012 L .29759 .56123 L F
0 g
.28893 .58925 m
.29025 .58055 L
s
.28284 .58755 m
.29025 .58055 L
s
.41898 .67103 m .42009 .67013 L .41845 .66963 L 0 1 .439 r
F
0 g
.41572 .67184 m
.41898 .67103 L
s
.25201 .76099 m .24059 .75961 L .24303 .76349 L 0 1 .525 r
F
0 g
.23948 .76677 m
.24303 .76349 L
s
.36319 .58338 m .35608 .58482 L .3594 .58414 L 0 0 .065 r
F
.36319 .58338 m .3548 .59045 L .35608 .58482 L F
.36319 .58338 m .35644 .59729 L .3548 .59045 L F
.36319 .58338 m .36025 .59652 L .35644 .59729 L F
0 g
.35939 .58414 m
.35939 .58414 L
s
.35939 .58414 m
.3594 .58414 L
s
.36319 .58338 m .36367 .58865 L .36025 .59652 L 0 0 .065 r
F
.36319 .58338 m .36492 .58303 L .36367 .58865 L F
0 g
.36319 .58338 m
.36439 .5826 L
s
.3594 .58414 m
.36319 .58338 L
s
.36492 .58303 m
.36867 .581 L
s
.79155 .61896 m .80708 .61349 L .80693 .6161 L 0 0 0 r
F
0 g
.80708 .61349 m
.81289 .61276 L
s
.29144 .91893 m .27892 .91344 L .27769 .91611 L 0 1 .49 r
F
.29144 .91893 m .2834 .91338 L .27892 .91344 L F
.29144 .91893 m .28877 .91574 L .2834 .91338 L F
0 g
.2902 .92158 m
.29144 .91893 L
s
.30488 .91822 m .28877 .91574 L .29145 .91893 L 0 1 .475 r
F
0 g
.29145 .91893 m
.29743 .92102 L
s
.40016 .76942 m .39001 .77031 L .38874 .77006 L 0 0 0 r
F
.40016 .76942 m .39438 .77041 L .39001 .77031 L F
.39438 .77041 m .39419 .77041 L .38991 .77511 L 0 1 .383 r
F
.39438 .77041 m .39438 .77041 L .39438 .77041 L 0 0 0 r
F
.39438 .77041 m .39438 .77041 L .39001 .77031 L F
.39983 .78716 m .39438 .77041 L .38991 .77511 L 0 1 .383 r
F
.39438 .77041 m .39434 .77026 L .39419 .77041 L F
.40348 .76728 m .39434 .77026 L .39469 .7704 L 0 1 .379 r
F
.40034 .77045 m .39471 .7704 L .39879 .77202 L F
.39983 .78716 m .39879 .77202 L .39471 .7704 L 0 1 .383 r
F
.39438 .77041 m .39471 .7704 L .39434 .77026 L F
.39983 .78716 m .39471 .7704 L .39438 .77041 L F
.40016 .76942 m .39882 .7703 L .39471 .7704 L 0 0 0 r
F
.39438 .77041 m .39471 .7704 L .39433 .77041 L F
.40016 .76942 m .39471 .7704 L .39438 .77041 L F
.40342 .77076 m .39433 .77041 L .39471 .7704 L F
.40034 .77045 m .39471 .7704 L .39882 .7703 L F
.40342 .77076 m .39471 .7704 L .40034 .77045 L F
.40059 .7702 m .39469 .7704 L .39471 .7704 L 0 1 .379 r
F
.40059 .7702 m .39471 .7704 L .40034 .77045 L F
.40016 .76942 m .40132 .76987 L .39882 .7703 L 0 0 0 r
F
.40348 .76728 m .39469 .7704 L .40059 .7702 L 0 1 .379 r
F
.39438 .77041 m .39433 .77041 L .39421 .77041 L 0 0 0 r
F
.39438 .77041 m .39421 .77041 L .39001 .77031 L F
0 g
.38874 .77006 m
.39124 .76964 L
s
.40188 .7689 m
.40273 .76864 L
s
.39584 .76932 m
.39712 .76935 L
s
.70046 1.07542 m .71173 1.07443 L .70824 1.07537 L 0 0 0 r
F
.69194 1.07756 m .70046 1.07542 L .703 1.07687 L F
.38561 .68458 m .37652 .68642 L .3803 .68662 L 0 1 .493 r
F
0 g
.3803 .68662 m
.38107 .6892 L
s
.6641 .71758 m
.66535 .72133 L
s
.53475 .97481 m .53048 .97269 L .53397 .9734 L 0 0 0 r
F
0 g
.53179 .97271 m
.53397 .9734 L
s
.3302 .84 m .32301 .84663 L .32728 .84653 L 0 1 .442 r
F
.3302 .84 m .3195 .84011 L .32301 .84663 L F
0 g
.32073 .85315 m
.32301 .84663 L
s
.32728 .84653 m
.33134 .85279 L
s
.51958 .8867 m .51913 .88714 L .51936 .88383 L 0 0 .057 r
F
0 g
.51935 .88383 m
.51936 .88383 L
s
.62837 .62757 m .63039 .62737 L .6273 .62688 L 0 .683 .274 r
F
.62837 .62757 m .63629 .62843 L .63039 .62737 L F
.62837 .62757 m .64107 .62936 L .63629 .62843 L F
0 g
.62267 .62499 m
.62837 .62757 L
s
.42454 .91776 m .4133 .91887 L .41222 .9189 L 0 0 0 r
F
.75738 .71497 m .76491 .74012 L .76943 .73873 L 0 1 .402 r
F
.75738 .71497 m .75975 .72995 L .76491 .74012 L F
0 g
.76245 .75153 m
.76491 .74012 L
s
.75738 .71497 m .76943 .73873 L .771 .72668 L 0 1 .402 r
F
0 g
.76943 .73873 m
.77375 .74796 L
s
.56583 .46536 m
.56723 .46499 L
s
.56723 .46499 m
.57115 .46395 L
s
.49862 .96138 m .49532 .95997 L .49199 .95945 L 0 .661 .362 r
F
.38874 .77006 m .38006 .77003 L .38448 .76994 L 0 0 0 r
F
0 g
.38448 .76994 m
.38724 .76989 L
s
.45343 .94141 m .4505 .93919 L .44591 .938 L 0 1 .512 r
F
.39835 .91724 m .39114 .91113 L .38704 .91136 L 0 1 .521 r
F
.39835 .91724 m .39599 .91366 L .39114 .91113 L F
0 g
.3974 .91974 m
.39835 .91724 L
s
.40865 .91653 m .39599 .91366 L .39835 .91724 L 0 1 .517 r
F
0 g
.39835 .91724 m
.40269 .91942 L
s
.74623 .71857 m .75815 .74243 L .75975 .72995 L 0 1 .39 r
F
.74623 .71857 m .75364 .74412 L .75815 .74243 L F
0 g
.75815 .74243 m
.76245 .75153 L
s
.35877 .69107 m .34897 .68968 L .34949 .6926 L 0 1 .535 r
F
0 g
.34458 .69523 m
.34949 .6926 L
s
.68142 1.08056 m .68539 1.076 L .69193 1.07756 L 0 0 0 r
F
0 g
.67755 1.07522 m
.68539 1.076 L
s
.76857 .71199 m .77621 .7368 L .78074 .73563 L 0 1 .413 r
F
.76857 .71199 m .771 .72668 L .77621 .7368 L F
0 g
.77375 .74796 m
.77621 .7368 L
s
.7163 1.07691 m .71173 1.07443 L .71912 1.07355 L 0 0 0 r
F
.7163 1.07691 m .70824 1.07537 L .71173 1.07443 L F
0 g
.70895 1.07357 m
.71173 1.07443 L
s
.46079 .94002 m .45343 .94141 L .45775 .94263 L 0 1 .501 r
F
.46079 .94002 m .4505 .93919 L .45343 .94141 L F
0 g
.45343 .94141 m
.45351 .94366 L
s
.37508 .86077 m .36803 .86648 L .37241 .8665 L 0 1 .417 r
F
.37508 .86077 m .36407 .86055 L .36803 .86648 L F
0 g
.3659 .87222 m
.36803 .86648 L
s
.33617 .89943 m .32534 .89061 L .32379 .8947 L 0 1 .524 r
F
.33617 .89943 m .32953 .89052 L .32534 .89061 L F
.33617 .89943 m .33418 .89431 L .32953 .89052 L F
.34644 .89893 m .33418 .89431 L .33617 .89943 L 0 1 .522 r
F
0 g
.33461 .9035 m
.33617 .89943 L
s
.33617 .89943 m
.34071 .90306 L
s
.48453 .62944 m .48928 .62647 L .49221 .62514 L 0 0 0 r
F
0 g
.48928 .62647 m
.49143 .62485 L
s
.74623 .71857 m .74854 .7339 L .75364 .74412 L 0 1 .39 r
F
0 g
.74854 .7339 m
.75364 .74412 L
s
.75117 .75585 m
.75364 .74412 L
s
.42961 .96179 m .42632 .95565 L .42122 .95157 L 0 .784 .418 r
F
.76857 .71199 m .78074 .73563 L .78227 .72392 L 0 1 .413 r
F
0 g
.78074 .73563 m
.78508 .74497 L
s
.24059 .75961 m .23157 .76243 L .23616 .76285 L 0 1 .531 r
F
0 g
.23616 .76285 m
.23948 .76677 L
s
.43085 .93065 m .42819 .9279 L .42333 .92616 L 0 1 .519 r
F
.43987 .9296 m .43085 .93065 L .43549 .93236 L 0 1 .513 r
F
.43987 .9296 m .42819 .9279 L .43085 .93065 L F
0 g
.43022 .9332 m
.43085 .93065 L
s
.50698 .96471 m .50362 .96341 L .5006 .9629 L 0 .549 .286 r
F
.463 .48699 m .47133 .48127 L .47697 .47827 L 0 0 0 r
F
0 g
.47133 .48127 m
.47677 .47665 L
s
.46923 1.01927 m .46496 1.02157 L .46978 1.02494 L 0 .489 .398 r
F
.43844 .9768 m .43481 .97085 L .4297 .967 L 0 .73 .419 r
F
.78685 .78495 m .79592 .78167 L .79907 .78554 L 0 .063 0 r
F
0 g
.79592 .78167 m
.79633 .78218 L
s
.79592 .78167 m
.79895 .78224 L
s
.43426 .91721 m .42915 .91723 L .43296 .91695 L 0 0 0 r
F
.43426 .91721 m .42454 .91776 L .42915 .91723 L F
0 g
.42833 .91699 m
.42915 .91723 L
s
.52027 .46113 m
.5271 .46233 L
s
.51366 .46556 m
.52027 .46113 L
s
.49042 .95778 m .4872 .95625 L .4836 .95567 L 0 .788 .418 r
F
.50339 .90271 m .50018 .89616 L .50242 .89691 L 0 .003 .054 r
F
.50339 .90271 m .49833 .89788 L .50018 .89616 L F
0 g
.50018 .89616 m
.5007 .89368 L
s
.71675 .62032 m .72827 .6231 L .73244 .62321 L 0 .683 .253 r
F
0 g
.72201 .62294 m
.72201 .62291 L
s
.71675 .62032 m .72155 .62187 L .72827 .6231 L 0 .683 .253 r
F
0 g
.72717 .6229 m
.72763 .62299 L
s
.72763 .62299 m
.72827 .6231 L
s
.71766 .64738 m .72195 .63342 L .72827 .62311 L 0 .148 .084 r
F
0 g
.72649 .626 m
.72788 .62374 L
s
.72788 .62374 m
.72826 .62312 L
s
.72826 .62312 m
.72827 .62311 L
s
.72201 .62317 m
.7221 .62854 L
s
.7221 .62854 m
.72217 .63306 L
s
.44196 .57881 m .44812 .56992 L .45149 .56175 L 0 1 .387 r
F
0 g
.44812 .56992 m
.45397 .5649 L
s
.74177 .75211 m
.7424 .749 L
s
.50692 .89921 m .50679 .89267 L .50747 .8958 L 0 0 .053 r
F
.51051 .89567 m .50747 .8958 L .50679 .89267 L F
0 g
.50679 .89267 m
.50772 .8889 L
s
.50487 .89169 m
.50679 .89267 L
s
.52951 .81751 m .5336 .80549 L .53597 .77091 L 0 .661 .255 r
F
.53479 .75021 m .5373 .79603 L .53513 .77243 L 0 .526 .187 r
F
.53479 .75021 m .54053 .81042 L .5373 .79603 L F
0 g
.53909 .74388 m
.53912 .74106 L
s
.53479 .75021 m .54266 .80582 L .54053 .81042 L 0 .526 .187 r
F
0 g
.53908 .74498 m
.53909 .74388 L
s
.53479 .75021 m .54228 .78329 L .54266 .80582 L 0 .526 .187 r
F
.53479 .75021 m .53966 .75807 L .54228 .78329 L F
0 g
.53917 .74204 m
.53966 .75807 L
s
.53898 .75506 m
.53908 .74498 L
s
.53265 .74478 m
.53479 .75021 L
s
.53646 .74398 m
.53966 .75807 L
s
.2981 .84065 m .2835 .83187 L .28406 .84116 L 0 1 .461 r
F
0 g
.28406 .84116 m
.28867 .84792 L
s
.39302 .89743 m .39121 .89035 L .38667 .8851 L 0 .997 .416 r
F
0 g
.39129 .90293 m
.39302 .89743 L
s
.43296 .60768 m .43841 .59854 L .44094 .58983 L 0 1 .385 r
F
.31092 .76784 m .30137 .76413 L .30026 .76672 L 0 1 .433 r
F
.31092 .76784 m .30538 .76273 L .30137 .76413 L F
0 g
.30026 .76672 m
.30264 .7689 L
s
.31092 .76784 m .30961 .76344 L .30538 .76273 L 0 1 .433 r
F
.31092 .76784 m .31199 .76564 L .30961 .76344 L F
0 g
.30692 .76923 m
.31092 .76784 L
s
.31092 .76784 m
.31334 .7697 L
s
.40382 .89721 m .39302 .89743 L .39757 .90262 L 0 .954 .406 r
F
.40382 .89721 m .39122 .89035 L .39302 .89743 L F
0 g
.73558 .67208 m
.73843 .67785 L
s
.35671 .89857 m .35088 .90244 L .35496 .90223 L 0 1 .52 r
F
.35671 .89857 m .34644 .89893 L .35088 .90244 L F
0 g
.34975 .90612 m
.35088 .90244 L
s
.35496 .90223 m
.35713 .90366 L
s
.35713 .90366 m
.3598 .90542 L
s
.7403 .899 m .74921 .90177 L .75156 .89937 L 0 .999 .368 r
F
0 g
.74415 .9032 m
.74921 .90177 L
s
.74921 .90177 m
.75077 .90388 L
s
.69322 .89617 m
.69331 .89603 L
s
.69312 .89632 m
.69322 .89617 L
s
.69308 .89638 m
.69312 .89632 L
s
.77978 .70947 m .78754 .73399 L .79207 .73299 L 0 1 .423 r
F
.77978 .70947 m .78227 .72392 L .78754 .73399 L F
0 g
.78508 .74497 m
.78754 .73399 L
s
.70936 .89897 m
.71394 .89882 L
s
.24059 .75961 m .22916 .75826 L .23157 .76243 L 0 1 .531 r
F
0 g
.22803 .76599 m
.23157 .76243 L
s
.62712 .51557 m
.62786 .51681 L
s
.62068 .50484 m
.62712 .51557 L
s
.43296 .60768 m .44094 .58983 L .43888 .58735 L 0 1 .385 r
F
0 g
.44094 .58983 m
.4468 .58479 L
s
.43841 .59854 m
.44094 .58983 L
s
.73839 .66354 m
.73903 .66473 L
s
.73833 .66343 m
.73839 .66354 L
s
.21304 .69662 m .20294 .70221 L .20748 .70262 L 0 1 .527 r
F
0 g
.20748 .70262 m
.20972 .70925 L
s
.74689 .74693 m
.74854 .7339 L
s
.4256 .76803 m .41677 .76862 L .42125 .76786 L 0 0 0 r
F
0 g
.42125 .76786 m
.4239 .76671 L
s
.43053 .71371 m .43279 .69671 L .42931 .69303 L 0 1 .357 r
F
.43053 .71371 m .43332 .70557 L .43279 .69671 L F
.46299 .91204 m .45327 .91414 L .4524 .91325 L 0 0 0 r
F
0 g
.44799 .91429 m
.4524 .91325 L
s
.3409 .84003 m .33368 .84644 L .33795 .8464 L 0 1 .435 r
F
.3409 .84003 m .3302 .84 L .33368 .84644 L F
0 g
.33134 .85279 m
.33368 .84644 L
s
.33795 .8464 m
.34194 .85257 L
s
.29087 .93529 m .28537 .93591 L .2897 .93568 L 0 .595 .21 r
F
.29087 .93529 m .27993 .93561 L .28537 .93591 L F
0 g
.28503 .93644 m
.28537 .93591 L
s
.2897 .93568 m
.29571 .9356 L
s
.36407 .86055 m .35502 .84654 L .35255 .85251 L 0 1 .425 r
F
.36407 .86055 m .35929 .84665 L .35502 .84654 L F
.36407 .86055 m .36317 .85266 L .35929 .84665 L F
0 g
.3616 .86652 m
.36407 .86055 L
s
.42166 .94632 m .41874 .94 L .4137 .93567 L 0 .833 .416 r
F
.37508 .86077 m .36317 .85266 L .36407 .86055 L 0 1 .417 r
F
0 g
.36407 .86055 m
.36803 .86648 L
s
.30012 .88694 m .29164 .89186 L .29713 .8916 L 0 1 .526 r
F
.30012 .88694 m .2863 .88737 L .29164 .89186 L F
0 g
.28945 .8966 m
.29164 .89186 L
s
.29713 .8916 m
.30304 .89575 L
s
.44196 .57881 m .45149 .56175 L .44983 .55974 L 0 1 .387 r
F
0 g
.45149 .56175 m
.45754 .5565 L
s
.44812 .56992 m
.45149 .56175 L
s
.42701 .63799 m .43172 .62876 L .43334 .61966 L 0 1 .376 r
F
0 g
.43172 .62876 m
.43715 .62423 L
s
.24588 .60002 m .23434 .60708 L .23864 .60767 L 0 1 .485 r
F
0 g
.23864 .60767 m
.23875 .61614 L
s
.65135 .59069 m .65989 .61458 L .65261 .58345 L 0 .1 .186 r
F
0 g
.65099 .58889 m
.65135 .59069 L
s
.65114 .58895 m
.65135 .59069 L
s
.65163 .60916 m
.65363 .61905 L
s
.80766 .90084 m .81781 .8975 L .8133 .89751 L 0 1 .508 r
F
.79646 .90057 m .80766 .90084 L .80652 .89752 L 0 1 .499 r
F
.35877 .69107 m .35226 .68631 L .34897 .68968 L 0 1 .535 r
F
.35877 .69107 m .35758 .68424 L .35226 .68631 L F
.35877 .69107 m .36138 .68485 L .35758 .68424 L F
.35877 .69107 m .36188 .68778 L .36138 .68485 L F
0 g
.35877 .69107 m
.35942 .69379 L
s
.35346 .69313 m
.35877 .69107 L
s
.42701 .63799 m .43334 .61966 L .43079 .61674 L 0 1 .376 r
F
0 g
.43334 .61966 m
.43903 .6149 L
s
.43172 .62876 m
.43334 .61966 L
s
.3889 .8796 m .37898 .86663 L .37675 .87213 L 0 1 .412 r
F
0 g
.37241 .8665 m
.37675 .87213 L
s
.75957 1.06239 m .75356 1.06462 L .75188 1.06546 L 0 .776 .205 r
F
0 g
.74385 1.06741 m
.75188 1.06546 L
s
.77978 .70947 m .79207 .73299 L .79356 .72156 L 0 1 .423 r
F
0 g
.79207 .73299 m
.79643 .74243 L
s
.45372 .55179 m .46056 .54322 L .46477 .53571 L 0 1 .364 r
F
0 g
.46056 .54322 m
.46661 .538 L
s
.33891 .56848 m
.34081 .55749 L
s
.48453 .62944 m .47863 .63314 L .47997 .63229 L 0 0 0 r
F
0 g
.47979 .63239 m
.48197 .63096 L
s
.47872 .63309 m
.47979 .63239 L
s
.48453 .62944 m .48156 .63181 L .47863 .63314 L 0 0 0 r
F
.48453 .62944 m .4868 .62918 L .48156 .63181 L F
.48453 .62944 m .49136 .62632 L .4868 .62918 L F
.48453 .62944 m .49221 .62514 L .49136 .62632 L F
0 g
.48928 .62647 m
.49221 .62514 L
s
.48197 .63096 m
.48453 .62944 L
s
.49221 .62514 m
.49647 .62201 L
s
.56524 .74253 m .57484 .67699 L .57141 .69026 L 0 1 .226 r
F
.56524 .74253 m .57541 .68662 L .57484 .67699 L F
0 g
.57484 .67699 m
.57586 .67279 L
s
.57484 .67699 m
.57485 .6772 L
s
.57485 .6772 m
.57486 .67728 L
s
.57486 .67728 m
.57486 .67739 L
s
.57486 .67739 m
.57493 .67845 L
s
.57493 .67845 m
.57516 .68231 L
s
.2981 .84065 m .28732 .82484 L .2835 .83187 L 0 1 .461 r
F
.2981 .84065 m .29298 .82477 L .28732 .82484 L F
.2981 .84065 m .2976 .83155 L .29298 .82477 L F
0 g
.29427 .84766 m
.2981 .84065 L
s
.3088 .84034 m .2976 .83155 L .2981 .84065 L 0 1 .455 r
F
0 g
.2981 .84065 m
.30167 .84734 L
s
.51874 .76772 m
.51907 .7812 L
s
.47031 .75757 m .4639 .74511 L .46734 .75298 L 0 .992 .319 r
F
0 g
.46389 .74506 m
.4639 .74511 L
s
.46375 .74507 m
.4639 .74511 L
s
.45993 .74405 m
.46375 .74507 L
s
.38561 .68458 m .37633 .68417 L .37652 .68642 L 0 1 .493 r
F
0 g
.37148 .68872 m
.37652 .68642 L
s
.38561 .68458 m .37987 .68137 L .37633 .68417 L 0 1 .493 r
F
.38561 .68458 m .3852 .67933 L .37987 .68137 L F
.38561 .68458 m .38876 .6794 L .3852 .67933 L F
.38561 .68458 m .38893 .68166 L .38876 .6794 L F
0 g
.3803 .68662 m
.38561 .68458 L
s
.38667 .8851 m
.39121 .89035 L
s
.33891 .56861 m
.33954 .56876 L
s
.33954 .56876 m
.34636 .57047 L
s
.43987 .9296 m .43549 .93236 L .439 .93188 L 0 1 .513 r
F
.44631 .93572 m .439 .93188 L .43549 .93236 L 0 1 .514 r
F
0 g
.4351 .93464 m
.43549 .93236 L
s
.43085 .93065 m
.43549 .93236 L
s
.74623 .71857 m .75975 .72995 L .75738 .71497 L 0 1 .39 r
F
0 g
.75815 .74243 m
.75975 .72995 L
s
.75975 .72995 m
.76491 .74012 L
s
.44805 .99138 m .44412 .9856 L .43905 .98195 L 0 .665 .418 r
F
0 g
.73853 .74113 m
.7424 .749 L
s
.77016 .61831 m .78513 .61382 L .78085 .61878 L 0 .057 .018 r
F
0 g
.78513 .61382 m
.78917 .61193 L
s
.785 .60934 m
.78513 .61382 L
s
.46872 .74837 m
.46936 .74867 L
s
.46936 .74867 m
.47258 .75021 L
s
.47372 .76209 m
.47372 .76209 L
s
.47258 .75021 m
.47372 .76209 L
s
.43974 .72375 m .43332 .70557 L .43053 .71371 L 0 1 .348 r
F
0 g
.43332 .70557 m
.4375 .70302 L
s
.43279 .69671 m
.43332 .70557 L
s
.4525 .76473 m
.45442 .76428 L
s
.22916 .75826 m .22011 .76138 L .2247 .7618 L 0 1 .534 r
F
0 g
.2247 .7618 m
.22803 .76599 L
s
.50342 1.05976 m .49687 1.05609 L .5026 1.06067 L 0 .273 .233 r
F
.50342 1.05976 m .49306 1.05221 L .49687 1.05609 L F
0 g
.4921 1.05316 m
.49687 1.05609 L
s
.69921 .72301 m
.6996 .72394 L
s
.69726 .71832 m
.69921 .72301 L
s
.69703 .72346 m
.69703 .72345 L
s
.69707 .72264 m
.69726 .71832 L
s
.45835 1.00552 m .45798 1.01141 L .45999 1.01045 L 0 .587 .412 r
F
.46923 1.01927 m .45999 1.01045 L .45798 1.01141 L 0 .489 .398 r
F
0 g
.45798 1.01141 m
.46011 1.01617 L
s
.45301 1.00791 m
.45798 1.01141 L
s
.48834 .75441 m
.48862 .76039 L
s
.48862 .76039 m
.48862 .76057 L
s
.48862 .76057 m
.48862 .76058 L
s
.48862 .76058 m
.48862 .76061 L
s
.38874 .77006 m .37777 .77012 L .38006 .77003 L 0 0 0 r
F
0 g
.37616 .7703 m
.37881 .77012 L
s
.44892 .7358 m .4407 .73302 L .44447 .73767 L 0 1 .339 r
F
.44892 .7358 m .43974 .72375 L .4407 .73302 L F
.45807 .75052 m .44892 .7358 L .45011 .74543 L 0 1 .33 r
F
.40382 .89721 m .39757 .90262 L .40184 .90246 L 0 .954 .406 r
F
.40869 .91403 m .40184 .90246 L .39757 .90262 L 0 .916 .41 r
F
0 g
.39609 .90789 m
.39757 .90262 L
s
.39302 .89743 m
.39757 .90262 L
s
.47031 .75757 m .47083 .75581 L .46872 .74837 L 0 .992 .319 r
F
0 g
.46872 .74837 m
.47083 .75581 L
s
.68142 1.08056 m .67525 1.07803 L .67361 1.07574 L 0 0 0 r
F
0 g
.66556 1.07421 m
.67361 1.07574 L
s
.52815 .9724 m .52688 .97181 L .52762 .97189 L 0 0 0 r
F
0 g
.52762 .97189 m
.52906 .97217 L
s
.70414 .89795 m
.70521 .89835 L
s
.70404 .89791 m
.70414 .89795 L
s
.43974 .72375 m .43127 .72273 L .43505 .72661 L 0 1 .348 r
F
.43974 .72375 m .43053 .71371 L .43127 .72273 L F
.26382 .88824 m .2526 .87655 L .25064 .8818 L 0 1 .53 r
F
.26382 .88824 m .25717 .87651 L .2526 .87655 L F
.26382 .88824 m .26198 .88153 L .25717 .87651 L F
.27505 .88778 m .26198 .88153 L .26382 .88824 L 0 1 .529 r
F
0 g
.26184 .89346 m
.26382 .88824 L
s
.26382 .88824 m
.26854 .89307 L
s
.79101 .70729 m .79888 .73159 L .80342 .73073 L 0 1 .432 r
F
.79101 .70729 m .79356 .72156 L .79888 .73159 L F
0 g
.79643 .74243 m
.79888 .73159 L
s
.40382 .89721 m .39319 .8851 L .39122 .89035 L 0 .954 .406 r
F
.2292 .911 m .22311 .91483 L .22757 .91468 L 0 1 .522 r
F
.2292 .911 m .21798 .91114 L .22311 .91483 L F
0 g
.22248 .91863 m
.22311 .91483 L
s
.22757 .91468 m
.2335 .91805 L
s
.60746 .70495 m
.61344 .75993 L
s
.46174 .64424 m .45447 .64735 L .45673 .64684 L 0 .921 .21 r
F
.46174 .64424 m .45641 .6456 L .45447 .64735 L F
0 g
.4553 .64869 m
.45673 .64684 L
s
.46174 .64424 m .46128 .64277 L .45641 .6456 L 0 .921 .21 r
F
.46174 .64424 m .46629 .64017 L .46128 .64277 L F
.46174 .64424 m .4681 .63953 L .46629 .64017 L F
.46174 .64424 m .46615 .64128 L .4681 .63953 L F
0 g
.46012 .64604 m
.46174 .64424 L
s
.45673 .64684 m
.46174 .64424 L
s
.46615 .64128 m
.47081 .63853 L
s
.45372 .55179 m .46477 .53571 L .46354 .53425 L 0 1 .364 r
F
0 g
.46477 .53571 m
.47097 .53029 L
s
.46056 .54322 m
.46477 .53571 L
s
.73124 .71641 m
.7342 .72147 L
s
.2356 .69923 m .22712 .68979 L .22433 .69791 L 0 1 .527 r
F
.2356 .69923 m .23256 .68425 L .22712 .68979 L F
.2356 .69923 m .23701 .68502 L .23256 .68425 L F
.2356 .69923 m .23831 .69145 L .23701 .68502 L F
0 g
.23047 .70444 m
.2356 .69923 L
s
.2356 .69923 m
.23698 .70538 L
s
.3088 .84034 m .30046 .8247 L .2976 .83155 L 0 1 .455 r
F
.3088 .84034 m .30478 .82468 L .30046 .8247 L F
.3088 .84034 m .30835 .83139 L .30478 .82468 L F
.3195 .84011 m .30835 .83139 L .3088 .84034 L 0 1 .449 r
F
0 g
.30594 .84717 m
.3088 .84034 L
s
.3088 .84034 m
.31234 .84694 L
s
.31486 .55754 m .3033 .56361 L .3071 .56538 L 0 1 .433 r
F
0 g
.30576 .57411 m
.3071 .56538 L
s
.31486 .55754 m .30558 .55325 L .3033 .56361 L 0 1 .433 r
F
.31486 .55754 m .31242 .54119 L .30558 .55325 L F
.31486 .55754 m .32019 .53335 L .31242 .54119 L F
.31486 .55754 m .32371 .53496 L .32019 .53335 L F
.31486 .55754 m .32142 .54532 L .32371 .53496 L F
0 g
.31277 .5684 m
.31486 .55754 L
s
.3071 .56538 m
.31486 .55754 L
s
.5154 .96785 m .51203 .96661 L .50934 .96605 L 0 .492 .237 r
F
.3254 .91737 m .31995 .91949 L .32401 .91926 L 0 1 .439 r
F
.3254 .91737 m .31514 .91775 L .31995 .91949 L F
0 g
.31927 .92145 m
.31995 .91949 L
s
.32401 .91926 m
.3293 .92066 L
s
.25808 .93643 m .24456 .93402 L .24378 .93524 L 0 .715 .252 r
F
.25808 .93643 m .24903 .93406 L .24456 .93402 L F
.25808 .93643 m .25484 .9351 L .24903 .93406 L F
.269 .93599 m .25484 .9351 L .25808 .93643 L 0 .684 .241 r
F
0 g
.25727 .93764 m
.25808 .93643 L
s
.25808 .93643 m
.26375 .93721 L
s
.53776 .97435 m
.53959 .97526 L
s
.22916 .75826 m .21772 .75693 L .22011 .76138 L 0 1 .534 r
F
0 g
.21658 .76522 m
.22011 .76138 L
s
.4278 .65942 m
.42859 .65032 L
s
.46079 .94002 m .4507 .93717 L .4505 .93919 L 0 1 .501 r
F
0 g
.44591 .938 m
.4505 .93919 L
s
.48246 .95386 m .47936 .9522 L .47551 .95152 L 0 .883 .456 r
F
.42446 .92362 m .4133 .91887 L .41218 .9214 L 0 1 .517 r
F
0 g
.41051 .92069 m
.41218 .9214 L
s
.40754 .91927 m
.41222 .9189 L
s
.21304 .69662 m .20174 .69536 L .20294 .70221 L 0 1 .527 r
F
0 g
.19833 .70845 m
.20294 .70221 L
s
.29804 .69155 m .28794 .69432 L .29235 .69514 L 0 1 .532 r
F
0 g
.29235 .69514 m
.29398 .70018 L
s
.30025 .76672 m .28741 .76202 L .28625 .76513 L 0 1 .463 r
F
.30025 .76672 m .29247 .76043 L .28741 .76202 L F
0 g
.28625 .76513 m
.28959 .76781 L
s
.30025 .76672 m .29803 .76144 L .29247 .76043 L 0 1 .463 r
F
.30025 .76672 m .30136 .76413 L .29803 .76144 L F
0 g
.29521 .76829 m
.30025 .76672 L
s
.42454 .91776 m .41737 .91865 L .4133 .91887 L 0 0 0 r
F
.42454 .91776 m .42219 .91817 L .41737 .91865 L F
.43426 .91721 m .42219 .91817 L .42454 .91776 L F
0 g
.42345 .91779 m
.42454 .91776 L
s
.42454 .91776 m
.42915 .91723 L
s
.65304 .62866 m
.6535 .62867 L
s
.6535 .62867 m
.65558 .62868 L
s
.47575 .9095 m .4669 .91137 L .46617 .91005 L 0 0 0 r
F
0 g
.4621 .91115 m
.46617 .91005 L
s
.31144 .69436 m .30122 .68594 L .29804 .69155 L 0 1 .536 r
F
0 g
.29804 .69155 m
.29972 .69646 L
s
.31144 .69436 m .30753 .68287 L .30122 .68594 L 0 1 .536 r
F
.31144 .69436 m .31276 .6844 L .30753 .68287 L F
.31144 .69436 m .31443 .68933 L .31276 .6844 L F
0 g
.30514 .69741 m
.31144 .69436 L
s
.3983 .91971 m .38688 .91954 L .38579 .92008 L 0 .685 .232 r
F
.3983 .91971 m .39098 .91936 L .38688 .91954 L F
.3983 .91971 m .39588 .91943 L .39098 .91936 L F
0 g
.3972 .92026 m
.3983 .91971 L
s
.40861 .91903 m .39588 .91943 L .3983 .91971 L 0 .599 .203 r
F
0 g
.40735 .91929 m
.40754 .91927 L
s
.40752 .91943 m
.41051 .92069 L
s
.40749 .91942 m
.40752 .91943 L
s
.40739 .91937 m
.40749 .91942 L
s
.40726 .91929 m
.40735 .91929 L
s
.3983 .91971 m
.40316 .91965 L
s
.47291 .63684 m .47752 .63388 L .47997 .63229 L 0 .8 .167 r
F
0 g
.4779 .63363 m
.47864 .63314 L
s
.42749 .68825 m .42853 .68556 L .42678 .68106 L 0 1 .362 r
F
0 g
.42853 .68556 m
.43185 .68639 L
s
.75738 .71497 m .771 .72668 L .76857 .71199 L 0 1 .402 r
F
0 g
.76943 .73873 m
.771 .72668 L
s
.771 .72668 m
.77621 .7368 L
s
.32142 .54532 m
.32895 .53806 L
s
.35159 .84024 m .34435 .8464 L .34862 .84643 L 0 1 .428 r
F
0 g
.34862 .84643 m
.35255 .85251 L
s
.35159 .84024 m .3409 .84003 L .34435 .8464 L 0 1 .428 r
F
0 g
.34194 .85257 m
.34435 .8464 L
s
.63629 .62843 m .64716 .62945 L .65053 .62864 L 0 1 .367 r
F
.63629 .62843 m .64107 .62936 L .64716 .62945 L F
0 g
.64716 .62945 m
.64779 .63202 L
s
.64107 .62936 m
.64211 .63004 L
s
.64107 .62936 m
.64716 .62945 L
s
.59728 .63382 m
.60079 .6304 L
s
.59661 .63447 m
.59728 .63382 L
s
.41466 .9304 m .41214 .9239 L .40721 .9193 L 0 .876 .413 r
F
0 g
.40721 .9193 m
.40729 .91937 L
s
.40729 .91937 m
.40735 .91943 L
s
.40721 .9193 m
.40726 .91929 L
s
.40721 .9193 m
.40739 .91937 L
s
.79101 .70729 m .80342 .73073 L .80488 .7195 L 0 1 .432 r
F
0 g
.80342 .73073 m
.8078 .74024 L
s
.50675 1.06437 m
.5071 1.06461 L
s
.5071 1.06461 m
.51122 1.06745 L
s
.46823 .52704 m .47571 .51889 L .48072 .51213 L 0 1 .274 r
F
0 g
.47571 .51889 m
.48189 .51349 L
s
.74623 .71857 m
.74768 .70731 L
s
.74597 .71803 m
.74623 .71857 L
s
.68219 .62343 m
.68489 .6233 L
s
.73864 .67769 m
.73931 .66571 L
s
.53476 .60797 m .53196 .61447 L .53131 .61163 L 0 .149 .065 r
F
.53476 .60797 m .53675 .61594 L .53196 .61447 L F
.53476 .60797 m .54248 .61505 L .53675 .61594 L F
.53476 .60797 m .54592 .61138 L .54248 .61505 L F
.53476 .60797 m .54478 .60738 L .54592 .61138 L F
0 g
.54478 .60738 m
.54775 .60304 L
s
.54 .60592 m
.54478 .60738 L
s
.43053 .71371 m .42931 .69303 L .42439 .69666 L 0 1 .357 r
F
0 g
.4287 .69348 m
.42931 .69303 L
s
.47291 .63684 m .46629 .64017 L .4681 .63953 L 0 .8 .167 r
F
.47291 .63684 m .46874 .63859 L .46629 .64017 L F
0 g
.46615 .64128 m
.4681 .63953 L
s
.47291 .63684 m .47382 .63584 L .46874 .63859 L 0 .8 .167 r
F
.47291 .63684 m .47863 .63314 L .47382 .63584 L F
.47291 .63684 m .47997 .63229 L .47863 .63314 L F
0 g
.47752 .63388 m
.4787 .63311 L
s
.4681 .63953 m
.47291 .63684 L
s
.47081 .63853 m
.47291 .63684 L
s
.47997 .63229 m
.48453 .62944 L
s
.46079 .94002 m .45775 .94263 L .46058 .94203 L 0 1 .501 r
F
.46757 .94499 m .46058 .94203 L .45775 .94263 L 0 .997 .494 r
F
0 g
.45775 .94263 m
.45801 .94461 L
s
.45343 .94141 m
.45775 .94263 L
s
.3195 .84011 m .31124 .82468 L .30835 .83139 L 0 1 .449 r
F
.3195 .84011 m .31555 .8247 L .31124 .82468 L F
.3195 .84011 m .31909 .83132 L .31555 .8247 L F
.3302 .84 m .31909 .83132 L .3195 .84011 L 0 1 .442 r
F
0 g
.31661 .8468 m
.3195 .84011 L
s
.3195 .84011 m
.32301 .84663 L
s
.48091 .76295 m
.48213 .76201 L
s
.48213 .76201 m
.48214 .762 L
s
.48214 .762 m
.48218 .76198 L
s
.80367 1.0412 m .79807 1.04601 L .79686 1.04876 L 0 1 .322 r
F
0 g
.78881 1.05248 m
.79686 1.04876 L
s
.21772 .75693 m .20864 .76036 L .21323 .76077 L 0 1 .537 r
F
0 g
.21323 .76077 m
.21658 .76522 L
s
.463 .48699 m .45454 .49358 L .4558 .49227 L 0 0 0 r
F
0 g
.45626 .49135 m
.4577 .49009 L
s
.463 .48699 m .46018 .49058 L .45454 .49358 L 0 0 0 r
F
.463 .48699 m .46897 .48526 L .46018 .49058 L F
.463 .48699 m .47617 .47998 L .46897 .48526 L F
.463 .48699 m .47697 .47827 L .47617 .47998 L F
0 g
.47133 .48127 m
.47697 .47827 L
s
.4577 .49009 m
.463 .48699 L
s
.47697 .47827 m
.48393 .4734 L
s
.51541 .88788 m
.51548 .88805 L
s
.54083 1.08681 m .54365 1.08612 L .54286 1.08705 L 0 .075 0 r
F
0 g
.5427 1.08464 m
.54365 1.08612 L
s
.34957 .58566 m
.35607 .58482 L
s
.39281 .90814 m .38704 .91136 L .39114 .91113 L 0 1 .517 r
F
.39281 .90814 m .38244 .90852 L .38704 .91136 L F
0 g
.3859 .91438 m
.38704 .91136 L
s
.74372 .69809 m
.7439 .69843 L
s
.74605 .7026 m
.74669 .70385 L
s
.74669 .70385 m
.74681 .70409 L
s
.74769 .70579 m
.74779 .70599 L
s
.49029 1.0474 m .4851 1.04238 L .4804 1.03922 L 0 .36 .334 r
F
0 g
.4804 1.03922 m
.4851 1.04238 L
s
.47743 1.03471 m
.4804 1.03922 L
s
.57287 .72612 m .57541 .68662 L .57274 .71282 L 0 1 .186 r
F
.56524 .74253 m .57274 .71282 L .57541 .68662 L 0 1 .226 r
F
0 g
.57516 .68231 m
.57541 .68662 L
s
.57541 .68662 m
.57597 .68159 L
s
.50339 .90271 m .49815 .90095 L .49833 .89788 L 0 .003 .054 r
F
0 g
.49575 .89817 m
.49833 .89788 L
s
.44905 .91484 m .43869 .91668 L .43763 .91613 L 0 0 0 r
F
0 g
.43296 .91695 m
.43763 .91613 L
s
.42749 .68825 m .4206 .68465 L .42409 .68786 L 0 1 .362 r
F
.42749 .68825 m .41884 .68016 L .4206 .68465 L F
.42749 .68825 m .41999 .67737 L .41884 .68016 L F
.42749 .68825 m .42339 .67776 L .41999 .67737 L F
.42749 .68825 m .42678 .68106 L .42339 .67776 L F
0 g
.42678 .68106 m
.42678 .68106 L
s
.42678 .68106 m
.43203 .67694 L
s
.42409 .68786 m
.42749 .68825 L
s
.42749 .68825 m
.42932 .69302 L
s
.42678 .68106 m
.42853 .68556 L
s
.43987 .9296 m .42904 .92561 L .42819 .9279 L 0 1 .513 r
F
0 g
.42333 .92616 m
.42819 .9279 L
s
.46823 .52704 m .48072 .51213 L .47994 .51126 L 0 1 .274 r
F
0 g
.48072 .51213 m
.48701 .50668 L
s
.47571 .51889 m
.48072 .51213 L
s
.59888 .63902 m
.59941 .64006 L
s
.59515 .63156 m
.59637 .634 L
s
.59637 .634 m
.59661 .63447 L
s
.36194 .92018 m .35048 .91811 L .3494 .91936 L 0 .926 .332 r
F
.36194 .92018 m .35456 .91801 L .35048 .91811 L F
.36194 .92018 m .35947 .91889 L .35456 .91801 L F
.37185 .91958 m .35947 .91889 L .36194 .92018 L 0 .789 .283 r
F
0 g
.36194 .92018 m
.36671 .9209 L
s
.36084 .92142 m
.36194 .92018 L
s
.75957 1.06239 m .76309 1.06143 L .76934 1.05862 L 0 .776 .205 r
F
0 g
.75562 1.06436 m
.76309 1.06143 L
s
.76122 1.06282 m
.76309 1.06143 L
s
.52815 .9724 m .53047 .97269 L .52959 .97268 L 0 0 0 r
F
0 g
.53024 .97247 m
.53047 .97269 L
s
.53475 .97481 m .5296 .97268 L .53048 .97269 L 0 0 0 r
F
0 g
.53048 .97269 m
.53397 .9734 L
s
.80227 .70536 m .81024 .72951 L .8148 .72875 L 0 1 .441 r
F
.80227 .70536 m .80488 .7195 L .81024 .72951 L F
0 g
.8078 .74024 m
.81024 .72951 L
s
.21772 .75693 m .20628 .75564 L .20864 .76036 L 0 1 .537 r
F
0 g
.20512 .76447 m
.20864 .76036 L
s
.32142 .54532 m
.32371 .53496 L
s
.37508 .86077 m .36583 .84692 L .36317 .85266 L 0 1 .417 r
F
.59037 .62611 m .59125 .63629 L .58869 .62812 L 0 .592 .07 r
F
0 g
.58486 .61412 m
.59037 .62611 L
s
.48059 1.03268 m .47238 1.02951 L .47743 1.03471 L 0 .372 .367 r
F
.48059 1.03268 m .46978 1.02494 L .47238 1.02951 L F
.43067 .94498 m .42166 .94632 L .42648 .95062 L 0 .781 .404 r
F
.43067 .94498 m .41874 .94 L .42166 .94632 L F
0 g
.42122 .95157 m
.42166 .94632 L
s
.43782 .96008 m .42632 .95565 L .42961 .96179 L 0 .729 .405 r
F
.43782 .96008 m .42648 .95062 L .42632 .95565 L F
0 g
.42122 .95157 m
.42632 .95565 L
s
.3302 .84 m .32201 .82476 L .31909 .83132 L 0 1 .442 r
F
.3302 .84 m .32632 .82483 L .32201 .82476 L F
.3302 .84 m .32983 .83136 L .32632 .82483 L F
.3409 .84003 m .32983 .83136 L .3302 .84 L 0 1 .435 r
F
0 g
.32728 .84653 m
.3302 .84 L
s
.3302 .84 m
.33368 .84644 L
s
.34897 .68968 m .33956 .69094 L .34353 .69166 L 0 1 .539 r
F
0 g
.34353 .69166 m
.34458 .69523 L
s
.53139 1.08307 m .5266 1.07781 L .5328 1.08171 L 0 0 0 r
F
.53139 1.08307 m .52176 1.075 L .5266 1.07781 L F
.5271 .46234 m .53604 .46098 L .54337 .46301 L 0 .091 .039 r
F
0 g
.54261 .4628 m
.54337 .46301 L
s
.53604 .46098 m
.54261 .4628 L
s
.54337 .46301 m
.5435 .46295 L
s
.54114 .46239 m
.54228 .46153 L
s
.72646 .89848 m .73808 .90094 L .7403 .899 L 0 .781 .294 r
F
0 g
.72439 .8998 m
.72692 .90127 L
s
.73235 .9019 m
.73808 .90094 L
s
.40336 .67724 m .3942 .67944 L .3979 .67941 L 0 1 .446 r
F
0 g
.3979 .67941 m
.39837 .68163 L
s
.43067 .94498 m .4194 .93496 L .41874 .94 L 0 .781 .404 r
F
0 g
.4137 .93567 m
.41874 .94 L
s
.4256 .76803 m .41452 .76984 L .41677 .76862 L 0 0 0 r
F
.41452 .76984 m .40556 .7699 L .41004 .76949 L F
.41452 .76984 m .40935 .77027 L .40556 .7699 L F
.40935 .77027 m .40429 .77041 L .4043 .77043 L 0 1 .37 r
F
.40935 .77027 m .4043 .77043 L .40547 .77493 L F
.40935 .77027 m .40506 .7715 L .40342 .77076 L 0 0 0 r
F
.41452 .76984 m .41267 .77016 L .40935 .77027 L F
.41447 .77287 m .40935 .77027 L .40547 .77493 L 0 1 .37 r
F
.41265 .77017 m .40983 .75503 L .40527 .75921 L F
.40927 .77022 m .40527 .75921 L .40348 .76728 L F
.41267 .77016 m .41265 .77017 L .40935 .77027 L 0 0 0 r
F
.41447 .77287 m .41265 .77017 L .40927 .77022 L 0 1 .37 r
F
.41265 .77017 m .40527 .75921 L .40927 .77022 L F
.41452 .76984 m .41376 .77014 L .41265 .77017 L 0 0 0 r
F
.41376 .77014 m .40983 .75503 L .41266 .77018 L 0 1 .37 r
F
.41376 .77014 m .41375 .77015 L .41265 .77017 L 0 0 0 r
F
.41266 .77018 m .41266 .77016 L .41265 .77017 L 0 1 .37 r
F
.41447 .77287 m .41376 .77014 L .41266 .77018 L F
.41375 .77015 m .40954 .77185 L .41265 .77017 L 0 0 0 r
F
.41265 .77017 m .40954 .77185 L .40506 .7715 L F
.41266 .77016 m .40983 .75503 L .41265 .77017 L 0 1 .37 r
F
.41265 .77017 m .40506 .7715 L .40932 .77028 L 0 0 0 r
F
.41265 .77017 m .40932 .77028 L .40935 .77027 L F
.40935 .77027 m .40917 .77028 L .40909 .77027 L F
.40935 .77027 m .40909 .77027 L .40556 .7699 L F
.40917 .77028 m .40842 .7703 L .40556 .7699 L F
.4086 .77033 m .40408 .77049 L .40556 .7699 L F
.40935 .77027 m .40348 .76728 L .40429 .77041 L 0 1 .37 r
F
.40917 .77028 m .4086 .77033 L .40842 .7703 L 0 0 0 r
F
.4086 .77033 m .40342 .77076 L .40408 .77049 L F
.41376 .77014 m .41387 .77157 L .40954 .77185 L F
.41452 .76984 m .4144 .77014 L .41376 .77014 L F
.41447 .77287 m .4144 .77014 L .41376 .77014 L 0 1 .37 r
F
.4144 .77014 m .41387 .77157 L .41376 .77014 L 0 0 0 r
F
.41376 .77014 m .4141 .75753 L .40983 .75503 L 0 1 .37 r
F
.4144 .77014 m .4141 .75753 L .41376 .77014 L F
.4144 .77012 m .41609 .76518 L .4141 .75753 L F
.41441 .77021 m .41443 .77014 L .4144 .77014 L F
.41447 .77287 m .41504 .77015 L .41441 .77021 L F
.4256 .76803 m .41952 .76973 L .41452 .76984 L 0 0 0 r
F
.41952 .76973 m .41911 .76984 L .41831 .76984 L F
.41952 .76973 m .41831 .76984 L .41452 .76984 L F
.42544 .7796 m .41911 .76984 L .41447 .77287 L 0 1 .361 r
F
.41911 .76984 m .41863 .76988 L .41452 .76984 L 0 0 0 r
F
.41897 .76988 m .41515 .77021 L .41452 .76984 L F
.41911 .76984 m .41609 .76518 L .41504 .77015 L 0 1 .361 r
F
.41911 .76984 m .41504 .77015 L .41447 .77287 L F
.41911 .76984 m .41865 .76988 L .41863 .76988 L 0 0 0 r
F
.4144 .77014 m .416 .77071 L .41387 .77157 L F
.41452 .76984 m .41504 .77015 L .4144 .77014 L F
.41504 .77015 m .416 .77071 L .4144 .77014 L F
.4144 .77014 m .41443 .77012 L .4144 .77012 L 0 1 .37 r
F
.41443 .77014 m .41443 .77012 L .4144 .77014 L F
.41443 .77012 m .41609 .76518 L .4144 .77012 L F
.41504 .77015 m .41609 .76518 L .41441 .77021 L F
.41911 .76984 m .41897 .76988 L .41865 .76988 L 0 0 0 r
F
.41911 .76984 m .4205 .76165 L .41609 .76518 L 0 1 .361 r
F
.42544 .7796 m .42269 .76961 L .41911 .76984 L F
.41911 .76984 m .42036 .77088 L .416 .77071 L 0 0 0 r
F
.4256 .76803 m .42269 .76961 L .41911 .76984 L F
.42269 .76961 m .42036 .77088 L .41911 .76984 L F
.42269 .76961 m .42268 .76956 L .41911 .76984 L 0 1 .361 r
F
.42268 .76956 m .4205 .76165 L .41911 .76984 L F
.42268 .76956 m .42477 .76465 L .4205 .76165 L F
.42544 .7796 m .42499 .76951 L .42269 .76961 L F
.42269 .76961 m .42469 .77023 L .42036 .77088 L 0 0 0 r
F
.4256 .76803 m .42499 .76951 L .42269 .76961 L F
.42499 .76951 m .42469 .77023 L .42269 .76961 L F
.42269 .76961 m .42498 .76936 L .42268 .76956 L 0 1 .361 r
F
.42499 .76951 m .42498 .76936 L .42269 .76961 L F
.42498 .76936 m .42477 .76465 L .42268 .76956 L F
.41897 .76988 m .416 .77071 L .41515 .77021 L 0 0 0 r
F
.42544 .7796 m .42688 .77234 L .42609 .76946 L 0 1 .361 r
F
.4256 .76803 m .42609 .76946 L .42499 .76951 L 0 0 0 r
F
.42499 .76951 m .42609 .76946 L .42477 .76465 L 0 1 .361 r
F
.42544 .7796 m .42609 .76946 L .42499 .76951 L F
.4256 .76803 m .42693 .76901 L .42609 .76946 L 0 0 0 r
F
.42499 .76951 m .42609 .76946 L .42469 .77023 L F
0 g
.42568 .76797 m
.42797 .76641 L
s
.43782 .96008 m .42961 .96179 L .43447 .96584 L 0 .729 .405 r
F
0 g
.42961 .96179 m
.4297 .967 L
s
.44399 .75344 m .44447 .73767 L .4407 .73302 L 0 1 .344 r
F
.44399 .75344 m .44588 .74643 L .44447 .73767 L F
0 g
.44447 .73767 m
.44892 .7358 L
s
.76857 .71199 m .78227 .72392 L .77978 .70947 L 0 1 .413 r
F
0 g
.78074 .73563 m
.78227 .72392 L
s
.78227 .72392 m
.78754 .73399 L
s
.40336 .67724 m .39431 .67743 L .3942 .67944 L 0 1 .446 r
F
.40336 .67724 m .39816 .67471 L .39431 .67743 L F
.40336 .67724 m .40705 .67237 L .40573 .67244 L F
.4036 .67304 m .40572 .67244 L .4036 .67302 L 0 1 .382 r
F
.4036 .67304 m .40573 .67244 L .4036 .67302 L 0 1 .446 r
F
.40336 .67724 m .40573 .67244 L .4036 .67304 L F
.40573 .67244 m .40573 .67244 L .4036 .67304 L F
.4036 .67304 m .40573 .67244 L .40572 .67244 L 0 1 .382 r
F
.4036 .67304 m .40587 .67255 L .40573 .67244 L F
.40361 .67296 m .4057 .67242 L .40568 .6724 L F
.40361 .67291 m .40568 .6724 L .40366 .67087 L F
.40361 .67296 m .40568 .6724 L .40361 .67291 L F
.40715 .67205 m .40366 .67087 L .40573 .67244 L 0 1 .379 r
F
.40717 .67205 m .40214 .66672 L .40366 .67087 L F
.41053 .67159 m .4072 .67205 L .40706 .67237 L 0 1 .424 r
F
.40715 .67205 m .40573 .67244 L .40573 .67244 L 0 1 .379 r
F
.40717 .67205 m .40711 .67207 L .40711 .67207 L 0 1 .424 r
F
.4072 .67205 m .40711 .67207 L .40706 .67237 L F
.40715 .67205 m .40573 .67244 L .40715 .67206 L 0 1 .379 r
F
.40711 .67206 m .40573 .67244 L .40706 .67237 L 0 1 .424 r
F
.40336 .67724 m .40693 .67439 L .40705 .67237 L 0 1 .446 r
F
.40715 .67206 m .40573 .67244 L .40704 .67342 L 0 1 .379 r
F
.4072 .67205 m .40717 .67205 L .40711 .67207 L 0 1 .424 r
F
.40717 .67205 m .40711 .67206 L .40711 .67207 L F
.40856 .67167 m .40349 .66374 L .40214 .66672 L 0 1 .379 r
F
.4072 .67205 m .40858 .67169 L .40717 .67205 L 0 1 .424 r
F
.41053 .67159 m .40858 .67169 L .4072 .67205 L F
.40858 .67169 m .40924 .67148 L .40856 .67167 L 0 1 .379 r
F
.4105 .67318 m .40927 .67152 L .40858 .67169 L F
.40927 .67152 m .40924 .67148 L .40858 .67169 L F
.40924 .67148 m .40349 .66374 L .40856 .67167 L F
.4105 .67318 m .40858 .67169 L .40717 .67205 L F
.40858 .67169 m .40214 .66672 L .40717 .67205 L F
.40717 .67205 m .40854 .67169 L .40711 .67206 L 0 1 .424 r
F
.40858 .67169 m .40854 .67169 L .40717 .67205 L F
.40336 .67724 m .4036 .67304 L .39816 .67471 L 0 1 .446 r
F
.4031 .69147 m .40361 .67291 L .39814 .67614 L 0 1 .382 r
F
.40361 .67291 m .40366 .67087 L .40076 .67364 L F
.40361 .67291 m .40069 .67371 L .40325 .67312 L F
.4036 .67304 m .40094 .67361 L .40069 .67371 L 0 1 .446 r
F
.4036 .67304 m .40069 .67371 L .39816 .67471 L F
.40361 .67291 m .40076 .67364 L .40069 .67371 L 0 1 .382 r
F
.40325 .67312 m .40069 .67371 L .39814 .67614 L F
.40825 .67171 m .40336 .6712 L .40205 .67204 L 0 1 .424 r
F
.40854 .67169 m .40838 .67168 L .40825 .67171 L F
.40838 .67168 m .40336 .6712 L .40825 .67171 L F
.40927 .67152 m .40696 .66349 L .40349 .66374 L 0 1 .379 r
F
.41053 .67159 m .40927 .67152 L .40856 .67169 L 0 1 .424 r
F
.40927 .67152 m .40684 .67042 L .40336 .6712 L F
.41053 .67159 m .40984 .67137 L .40927 .67152 L F
.40984 .67137 m .40696 .66349 L .40927 .67152 L 0 1 .379 r
F
.40984 .67137 m .40684 .67042 L .40927 .67152 L 0 1 .424 r
F
.40984 .67138 m .40984 .67137 L .40927 .67152 L 0 1 .379 r
F
.4105 .67318 m .40984 .67138 L .40927 .67152 L F
.40856 .67169 m .40925 .67152 L .40854 .67169 L 0 1 .424 r
F
.40927 .67152 m .40925 .67152 L .40856 .67169 L F
.40925 .67152 m .40336 .6712 L .40854 .67169 L F
.40711 .67206 m .40205 .67204 L .40363 .67254 L F
.40854 .67169 m .40205 .67204 L .40711 .67206 L F
.4036 .67302 m .40573 .67244 L .4057 .67242 L 0 1 .382 r
F
.4036 .67302 m .4057 .67242 L .40361 .67296 L F
.40711 .67206 m .40363 .67254 L .40573 .67244 L 0 1 .424 r
F
.4036 .67302 m .40573 .67244 L .40363 .67254 L 0 1 .446 r
F
.4105 .67318 m .40715 .67205 L .40704 .67342 L 0 1 .379 r
F
.4031 .69147 m .40704 .67343 L .40587 .67255 L 0 1 .382 r
F
.4031 .69147 m .40587 .67255 L .4036 .67304 L F
.4036 .67304 m .40363 .67254 L .40094 .67361 L 0 1 .446 r
F
0 g
.3979 .67941 m
.39905 .67895 L
s
.24588 .60002 m .23528 .59838 L .23434 .60708 L 0 1 .485 r
F
0 g
.2279 .61486 m
.23434 .60708 L
s
.38609 .8613 m .37898 .86663 L .38337 .86678 L 0 1 .408 r
F
.38609 .8613 m .37508 .86077 L .37898 .86663 L F
.3889 .8796 m .38337 .86678 L .37898 .86663 L 0 1 .412 r
F
0 g
.37675 .87213 m
.37898 .86663 L
s
.44399 .75344 m .4407 .73302 L .43626 .73518 L 0 1 .344 r
F
0 g
.43974 .72375 m
.4407 .73302 L
s
.79646 .90057 m .80652 .89752 L .802 .89753 L 0 1 .499 r
F
.78525 .9003 m .79646 .90057 L .79522 .89754 L 0 1 .486 r
F
0 g
.75738 .71497 m
.75867 .70505 L
s
.75515 .71049 m
.75738 .71497 L
s
.48063 .90573 m .47863 .90727 L .475 .90818 L 0 0 0 r
F
.48705 .90819 m .48063 .90573 L .48396 .90533 L 0 0 .031 r
F
.48705 .90819 m .47863 .90727 L .48063 .90573 L F
0 g
.48028 .90432 m
.48063 .90573 L
s
.45835 1.00552 m .45415 .99992 L .44919 .99643 L 0 .587 .412 r
F
0 g
.46734 .75298 m
.47031 .75757 L
s
.46734 .75298 m
.46756 .75454 L
s
.46756 .75454 m
.46786 .75669 L
s
.46786 .75669 m
.46876 .7631 L
s
.29804 .69155 m .28712 .68915 L .28794 .69432 L 0 1 .532 r
F
0 g
.28288 .69844 m
.28794 .69432 L
s
.42384 .66727 m .42773 .66436 L .42842 .66241 L 0 1 .381 r
F
.49029 1.0474 m .49306 1.05221 L .4937 1.05162 L 0 .36 .334 r
F
.50342 1.05976 m .4937 1.05162 L .49306 1.05221 L 0 .273 .233 r
F
0 g
.49306 1.05221 m
.49687 1.05609 L
s
.48836 1.04904 m
.49306 1.05221 L
s
.3889 .8796 m .38762 .87234 L .38337 .86678 L 0 1 .412 r
F
0 g
.38667 .8851 m
.3889 .8796 L
s
.4001 .87996 m .3889 .8796 L .39319 .8851 L 0 .991 .403 r
F
.4001 .87996 m .38762 .87234 L .3889 .8796 L F
.43053 .71371 m .42181 .71405 L .4256 .71735 L 0 1 .357 r
F
.43053 .71371 m .42129 .70518 L .42181 .71405 L F
.43053 .71371 m .42439 .69666 L .42129 .70518 L F
.80227 .70536 m .8148 .72875 L .81621 .71767 L 0 1 .441 r
F
0 g
.8148 .72875 m
.81918 .73834 L
s
.36229 .84067 m .35502 .84654 L .35929 .84665 L 0 1 .421 r
F
0 g
.35929 .84665 m
.36317 .85266 L
s
.36229 .84067 m .35159 .84024 L .35502 .84654 L 0 1 .421 r
F
0 g
.35255 .85251 m
.35502 .84654 L
s
.37508 .86077 m .37029 .84715 L .36583 .84692 L 0 1 .417 r
F
.37508 .86077 m .37426 .85309 L .37029 .84715 L F
.38609 .8613 m .37426 .85309 L .37508 .86077 L 0 1 .408 r
F
0 g
.37508 .86077 m
.37898 .86663 L
s
.37241 .8665 m
.37508 .86077 L
s
.79856 .78865 m .80296 .78451 L .80766 .78623 L 0 0 0 r
F
.79856 .78865 m .79907 .78554 L .80296 .78451 L F
0 g
.79895 .78224 m
.80296 .78451 L
s
.4854 .50495 m .49345 .49744 L .49923 .49159 L 0 .94 .187 r
F
0 g
.49345 .49744 m
.49971 .49201 L
s
.45807 .75052 m .45011 .74543 L .45386 .75111 L 0 1 .33 r
F
0 g
.45807 .75052 m
.45949 .76064 L
s
.42437 .9295 m .41466 .9304 L .4194 .93496 L 0 .827 .402 r
F
.42437 .9295 m .41214 .9239 L .41466 .9304 L F
0 g
.4137 .93567 m
.41466 .9304 L
s
.37777 .77012 m .36902 .76993 L .37344 .77003 L 0 .551 .204 r
F
0 g
.37346 .77003 m
.37616 .7703 L
s
.69301 .89637 m
.69331 .89641 L
s
.20628 .75564 m .19717 .75937 L .20176 .75976 L 0 1 .539 r
F
0 g
.20176 .75976 m
.20512 .76447 L
s
.34644 .89893 m .33583 .89042 L .33418 .89431 L 0 1 .522 r
F
.34644 .89893 m .34002 .89038 L .33583 .89042 L F
.34644 .89893 m .34457 .89403 L .34002 .89038 L F
.35671 .89857 m .34457 .89403 L .34644 .89893 L 0 1 .52 r
F
0 g
.34644 .89893 m
.35088 .90244 L
s
.34478 .9028 m
.34644 .89893 L
s
.28625 .76513 m .27605 .76024 L .27484 .76376 L 0 1 .491 r
F
.28625 .76513 m .28036 .75821 L .27605 .76024 L F
.28625 .76513 m .28489 .75905 L .28036 .75821 L F
.28625 .76513 m .28741 .76202 L .28489 .75905 L F
0 g
.28195 .76713 m
.28625 .76513 L
s
.39114 .91113 m
.39347 .91235 L
s
.39347 .91235 m
.39599 .91366 L
s
.40865 .91653 m .39742 .91088 L .39599 .91366 L 0 1 .517 r
F
.44577 .97481 m .43481 .97085 L .43844 .9768 L 0 .67 .405 r
F
.44577 .97481 m .43447 .96584 L .43481 .97085 L F
0 g
.4297 .967 m
.43481 .97085 L
s
.47083 .75581 m
.47372 .7621 L
s
.66589 .74748 m
.66596 .74846 L
s
.43296 .60768 m .42459 .6099 L .42704 .61256 L 0 1 .385 r
F
0 g
.43296 .60769 m
.43296 .60768 L
s
.43296 .60768 m .42713 .60118 L .42459 .6099 L 0 1 .385 r
F
.43296 .60768 m .43296 .59221 L .42713 .60118 L F
.43296 .60768 m .43888 .58735 L .43296 .59221 L F
0 g
.43296 .60768 m
.43296 .60768 L
s
.27505 .88778 m .26402 .87647 L .26198 .88153 L 0 1 .529 r
F
.27505 .88778 m .26859 .87645 L .26402 .87647 L F
.27505 .88778 m .27332 .8813 L .26859 .87645 L F
.2863 .88737 m .27332 .8813 L .27505 .88778 L 0 1 .527 r
F
0 g
.273 .89282 m
.27505 .88778 L
s
.27505 .88778 m
.2797 .89245 L
s
.38244 .90852 m .3714 .90163 L .36987 .90488 L 0 1 .519 r
F
0 g
.49271 .76284 m
.4929 .75953 L
s
.4929 .75953 m
.4929 .75953 L
s
.49273 .75973 m
.49284 .75955 L
s
.49284 .75955 m
.49284 .75954 L
s
.49284 .75954 m
.49289 .75945 L
s
.73245 .62322 m
.73246 .62323 L
s
.73246 .62323 m
.73337 .62496 L
s
.73337 .62496 m
.73357 .62532 L
s
.73357 .62532 m
.73559 .62913 L
s
.71675 .62032 m .73244 .62321 L .73182 .62169 L 0 .683 .253 r
F
0 g
.72201 .62349 m
.72201 .62294 L
s
.71174 .63495 m
.7174 .62363 L
s
.7174 .62363 m
.71763 .62319 L
s
.73245 .62322 m
.73245 .62343 L
s
.42701 .63799 m .41836 .63989 L .42129 .64277 L 0 1 .376 r
F
.42701 .63799 m .41998 .63077 L .41836 .63989 L F
.42701 .63799 m .42506 .6215 L .41998 .63077 L F
.42701 .63799 m .43079 .61674 L .42506 .6215 L F
0 g
.43079 .61674 m
.43296 .60769 L
s
.42567 .64724 m
.42701 .63799 L
s
.45385 .76652 m .45011 .74543 L .44588 .74643 L 0 1 .334 r
F
.45385 .76652 m .45386 .75111 L .45011 .74543 L F
0 g
.44892 .7358 m
.45011 .74543 L
s
.43411 .74272 m .43505 .72661 L .43127 .72273 L 0 1 .353 r
F
.43411 .74272 m .43626 .73518 L .43505 .72661 L F
0 g
.43505 .72661 m
.43974 .72375 L
s
.38222 .91913 m .37663 .92014 L .38073 .91987 L 0 .711 .252 r
F
.38222 .91913 m .37185 .91958 L .37663 .92014 L F
0 g
.37571 .92095 m
.37663 .92014 L
s
.38073 .91987 m
.38579 .92008 L
s
.31066 .8867 m .30439 .89129 L .30858 .89113 L 0 1 .524 r
F
.31066 .8867 m .30012 .88694 L .30439 .89129 L F
0 g
.30305 .89575 m
.30439 .89129 L
s
.30858 .89113 m
.31265 .89454 L
s
.31265 .89454 m
.31341 .89519 L
s
.29608 .57012 m
.3033 .56361 L
s
.40869 .91403 m .40661 .90735 L .40184 .90246 L 0 .916 .41 r
F
.55045 .76675 m .55218 .75066 L .55616 .77301 L 0 .664 .204 r
F
0 g
.55125 .73042 m
.55218 .75066 L
s
.3409 .84003 m .33278 .82498 L .32983 .83136 L 0 1 .435 r
F
.3409 .84003 m .33709 .82511 L .33278 .82498 L F
.3409 .84003 m .34057 .83156 L .33709 .82511 L F
.35159 .84024 m .34057 .83156 L .3409 .84003 L 0 1 .428 r
F
0 g
.33795 .8464 m
.3409 .84003 L
s
.3409 .84003 m
.34435 .8464 L
s
.80312 .63906 m .80813 .63489 L .80372 .6348 L 0 1 .503 r
F
.80312 .63906 m .81423 .63962 L .80813 .63489 L F
0 g
.80312 .63906 m
.80351 .63626 L
s
.80351 .63626 m
.80372 .6348 L
s
.7978 .63509 m
.80312 .63906 L
s
.79711 .63458 m
.7978 .63509 L
s
.42506 .6215 m
.43079 .61674 L
s
.42437 .9295 m .4133 .91887 L .41214 .9239 L 0 .827 .402 r
F
0 g
.41214 .9239 m
.41328 .91896 L
s
.40735 .91943 m
.41214 .9239 L
s
.41218 .9214 m
.41326 .91897 L
s
.4001 .87996 m .39319 .8851 L .39763 .88517 L 0 .991 .403 r
F
.40382 .89721 m .39763 .88517 L .39319 .8851 L 0 .954 .406 r
F
0 g
.39122 .89035 m
.39319 .8851 L
s
.3889 .8796 m
.39319 .8851 L
s
.47482 .94961 m .47186 .9478 L .46781 .94697 L 0 .95 .48 r
F
.44196 .57881 m .43371 .58139 L .43578 .58373 L 0 1 .387 r
F
.44196 .57881 m .43709 .57321 L .43371 .58139 L F
.44196 .57881 m .44366 .56465 L .43709 .57321 L F
.44196 .57881 m .44983 .55974 L .44366 .56465 L F
0 g
.43888 .58735 m
.44196 .57881 L
s
.20628 .75564 m .19482 .75439 L .19717 .75937 L 0 1 .539 r
F
0 g
.19366 .76375 m
.19717 .75937 L
s
.43296 .66191 m
.43384 .66001 L
s
.42773 .66436 m
.42774 .66436 L
s
.42774 .66436 m
.43296 .66191 L
s
.30488 .91822 m .29088 .91331 L .28877 .91574 L 0 1 .475 r
F
.30488 .91822 m .29638 .91328 L .29088 .91331 L F
.30488 .91822 m .30239 .91538 L .29638 .91328 L F
0 g
.30275 .92063 m
.30488 .91822 L
s
.31514 .91775 m .30239 .91538 L .30489 .91822 L 0 1 .459 r
F
0 g
.30489 .91822 m
.30979 .92014 L
s
.38244 .90852 m .37567 .90156 L .3714 .90163 L 0 1 .519 r
F
.38244 .90852 m .3804 .90451 L .37567 .90156 L F
.39281 .90814 m .3804 .90451 L .38244 .90852 L 0 1 .517 r
F
0 g
.38244 .90852 m
.38704 .91136 L
s
.3809 .91176 m
.38244 .90852 L
s
.24588 .60002 m .24083 .58735 L .23528 .59838 L 0 1 .485 r
F
.24588 .60002 m .2481 .57966 L .24083 .58735 L F
.24588 .60002 m .25221 .58047 L .2481 .57966 L F
.24588 .60002 m .25125 .58921 L .25221 .58047 L F
0 g
.24508 .60858 m
.24588 .60002 L
s
.23864 .60767 m
.24588 .60002 L
s
.75263 .69842 m
.75266 .69799 L
s
.44577 .97481 m .43844 .9768 L .44328 .98065 L 0 .67 .405 r
F
0 g
.43844 .9768 m
.43905 .98195 L
s
.52051 .78386 m
.52142 .77299 L
s
.52381 .97086 m .52045 .96966 L .51813 .969 L 0 .407 .208 r
F
.4854 .50495 m .49923 .49159 L .49891 .4913 L 0 .94 .187 r
F
0 g
.49923 .49159 m
.49942 .49144 L
s
.49345 .49744 m
.49923 .49159 L
s
.49362 .95633 m .49042 .95778 L .49369 .95849 L 0 .646 .389 r
F
.49362 .95633 m .4872 .95625 L .49042 .95778 L F
0 g
.49042 .95778 m
.49199 .95945 L
s
.50342 1.05976 m .5026 1.06067 L .50704 1.06392 L 0 .273 .233 r
F
0 g
.5026 1.06067 m
.50675 1.06437 L
s
.50067 .96006 m .49532 .95997 L .49862 .96138 L 0 .524 .329 r
F
.50067 .96006 m .49369 .95849 L .49532 .95997 L F
0 g
.49199 .95945 m
.49532 .95997 L
s
.81354 .70362 m .82163 .72767 L .82619 .727 L 0 1 .449 r
F
.81354 .70362 m .81621 .71767 L .82163 .72767 L F
0 g
.81918 .73834 m
.82163 .72767 L
s
.42383 .66847 m .41514 .67028 L .4184 .67313 L 0 1 .37 r
F
0 g
.42378 .66851 m
.42383 .66847 L
s
.42339 .67776 m
.42383 .66848 L
s
.42383 .66848 m
.42383 .66848 L
s
.24043 .91088 m .23425 .91448 L .23871 .91434 L 0 1 .518 r
F
.24043 .91088 m .2292 .911 L .23425 .91448 L F
0 g
.2335 .91805 m
.23425 .91448 L
s
.23871 .91434 m
.24453 .91751 L
s
.52603 .89893 m .53234 .87462 L .5313 .88127 L 0 .138 .097 r
F
0 g
.53145 .88026 m
.53234 .87462 L
s
.53144 .88037 m
.53145 .88026 L
s
.52662 .88244 m
.52696 .8814 L
s
.53234 .87462 m
.53237 .87453 L
s
.47031 .75757 m
.47191 .76392 L
s
.47191 .76392 m
.47191 .76393 L
s
.47191 .76393 m
.47191 .76393 L
s
.47229 .76542 m
.47249 .76623 L
s
.49362 .95633 m .48598 .95466 L .4872 .95625 L 0 .646 .389 r
F
0 g
.4836 .95567 m
.4872 .95625 L
s
.38874 .77006 m .37914 .77016 L .37777 .77012 L 0 0 0 r
F
.38847 .78333 m .3846 .77023 L .3791 .7718 L 0 1 .392 r
F
.38874 .77006 m .3846 .77023 L .37914 .77016 L 0 0 0 r
F
.3846 .77023 m .38043 .77019 L .37914 .77016 L F
.3846 .77023 m .38349 .76647 L .38043 .77019 L 0 1 .392 r
F
.3846 .77023 m .38043 .77019 L .3791 .7718 L F
.3846 .77023 m .38341 .77028 L .38043 .77019 L 0 0 0 r
F
.3846 .77023 m .38778 .76788 L .38349 .76647 L 0 1 .392 r
F
.38847 .78333 m .38789 .77035 L .3846 .77023 L F
.38874 .77006 m .38789 .77035 L .3846 .77023 L 0 0 0 r
F
.38789 .77035 m .38778 .76788 L .3846 .77023 L 0 1 .392 r
F
.3846 .77023 m .38772 .77041 L .38341 .77028 L 0 0 0 r
F
.38789 .77035 m .38772 .77041 L .3846 .77023 L F
.38847 .78333 m .38991 .77511 L .38851 .77037 L 0 1 .392 r
F
.38874 .77006 m .38851 .77037 L .38789 .77035 L 0 0 0 r
F
.38789 .77035 m .38851 .77037 L .38778 .76788 L 0 1 .392 r
F
.38847 .78333 m .38851 .77037 L .38789 .77035 L F
.38874 .77006 m .39001 .77031 L .38851 .77037 L 0 0 0 r
F
.38789 .77035 m .38851 .77037 L .38772 .77041 L F
0 g
.38842 .77005 m
.38874 .77006 L
s
.51736 .61327 m
.52149 .61338 L
s
.51346 .61682 m
.51736 .61327 L
s
.367 .89837 m .36107 .90195 L .36515 .9018 L 0 1 .518 r
F
.367 .89837 m .35671 .89857 L .36107 .90195 L F
0 g
.3598 .90542 m
.36107 .90195 L
s
.36515 .9018 m
.36715 .90311 L
s
.36715 .90311 m
.36987 .90488 L
s
.43411 .74272 m .43127 .72273 L .42662 .72581 L 0 1 .353 r
F
0 g
.43053 .71371 m
.43127 .72273 L
s
.44631 .93572 m .44364 .93332 L .439 .93188 L 0 1 .514 r
F
.45455 .93469 m .44631 .93572 L .4507 .93717 L 0 1 .505 r
F
.45455 .93469 m .44364 .93332 L .44631 .93572 L F
0 g
.44591 .938 m
.44631 .93572 L
s
.61383 .69087 m
.61383 .69777 L
s
.61382 .68431 m
.61383 .69087 L
s
.61382 .68403 m
.61382 .68431 L
s
.61382 .68225 m
.61382 .68403 L
s
.61382 .68124 m
.61382 .68225 L
s
.38337 .86678 m
.38762 .87234 L
s
.76337 .7744 m .77558 .77547 L .77512 .78028 L 0 .216 .019 r
F
0 g
.77558 .77547 m
.77946 .77374 L
s
.77302 .7708 m
.77558 .77547 L
s
.28027 .57761 m .26858 .58399 L .27267 .58495 L 0 1 .471 r
F
0 g
.27198 .59338 m
.27267 .58495 L
s
.57789 .61767 m .58297 .62016 L .58869 .62812 L 0 .487 .082 r
F
0 g
.58297 .62016 m
.58486 .61412 L
s
.50067 .96006 m .49862 .96138 L .50161 .96205 L 0 .524 .329 r
F
0 g
.49862 .96138 m
.5006 .9629 L
s
.49147 .80129 m .48901 .76915 L .48591 .76089 L 0 .795 .298 r
F
0 g
.48603 .76123 m
.48604 .76124 L
s
.48591 .76089 m
.48603 .76123 L
s
.49257 .75998 m
.49273 .75973 L
s
.48875 .7634 m
.48877 .76382 L
s
.48515 .74806 m
.48591 .76089 L
s
.48604 .76124 m
.4885 .75793 L
s
.48601 .76128 m
.48604 .76124 L
s
.48604 .76124 m
.48604 .76124 L
s
.4859 .76142 m
.48601 .76128 L
s
.48861 .76074 m
.48862 .76065 L
s
.4001 .87996 m .39008 .86712 L .38762 .87234 L 0 .991 .403 r
F
.45385 .76652 m .44588 .74643 L .44399 .75344 L 0 1 .334 r
F
0 g
.44588 .74643 m
.45011 .74543 L
s
.44447 .73767 m
.44588 .74643 L
s
.44399 .75344 m .43626 .73518 L .43411 .74272 L 0 1 .344 r
F
0 g
.43626 .73518 m
.4407 .73302 L
s
.43505 .72661 m
.43626 .73518 L
s
.7163 1.07691 m .71019 1.07643 L .70824 1.07537 L 0 0 0 r
F
0 g
.70046 1.07542 m
.70824 1.07537 L
s
.45385 .76652 m .45546 .76015 L .45386 .75111 L 0 1 .334 r
F
0 g
.45386 .75111 m
.45546 .76015 L
s
.45386 .75111 m
.45807 .75052 L
s
.41901 .91365 m .40869 .91403 L .4133 .91887 L 0 .869 .399 r
F
.41901 .91365 m .40661 .90735 L .40869 .91403 L F
0 g
.40807 .91624 m
.40869 .91403 L
s
.42129 .70518 m .42409 .68786 L .4206 .68466 L 0 1 .366 r
F
.42129 .70518 m .42439 .69666 L .42409 .68786 L F
0 g
.42409 .68786 m
.42439 .69666 L
s
.42439 .69666 m
.4287 .69348 L
s
.52168 .9006 m .52586 .88055 L .52554 .88572 L 0 .114 .089 r
F
.52168 .9006 m .52449 .88188 L .52586 .88055 L F
0 g
.52259 .88342 m
.52317 .88188 L
s
.52649 .88283 m
.52662 .88244 L
s
.52586 .88055 m
.52607 .88 L
s
.52581 .88138 m
.52586 .88055 L
s
.69175 .89611 m
.69301 .89637 L
s
.51699 1.07191 m .52176 1.075 L .52151 1.07514 L 0 .217 .197 r
F
.53139 1.08307 m .52151 1.07514 L .52176 1.075 L 0 0 0 r
F
0 g
.52176 1.075 m
.5266 1.07781 L
s
.51728 1.07191 m
.52176 1.075 L
s
.77978 .70947 m .79356 .72156 L .79101 .70729 L 0 1 .423 r
F
0 g
.79207 .73299 m
.79356 .72156 L
s
.79356 .72156 m
.79888 .73159 L
s
.22433 .69791 m .21592 .68818 L .21304 .69662 L 0 1 .527 r
F
.22433 .69791 m .22143 .68238 L .21592 .68818 L F
.22433 .69791 m .22589 .68312 L .22143 .68238 L F
.22433 .69791 m .22712 .68979 L .22589 .68312 L F
0 g
.21884 .70366 m
.22433 .69791 L
s
.22433 .69791 m
.22564 .7043 L
s
.48093 .76006 m
.48214 .76192 L
s
.48214 .76192 m
.48215 .76194 L
s
.48215 .76194 m
.48215 .76195 L
s
.48215 .76195 m
.48218 .76198 L
s
.48093 .76006 m
.48112 .76204 L
s
.48112 .76204 m
.48112 .76208 L
s
.48112 .76208 m
.48113 .76214 L
s
.48113 .76214 m
.48113 .76216 L
s
.48113 .76216 m
.48113 .76218 L
s
.48113 .76218 m
.48118 .76274 L
s
.41999 .67737 m
.42339 .67776 L
s
.48678 .9524 m .48246 .95386 L .48598 .95466 L 0 .752 .432 r
F
.48678 .9524 m .47936 .9522 L .48246 .95386 L F
0 g
.48246 .95386 m
.4836 .95567 L
s
.35159 .84024 m .34354 .82536 L .34057 .83156 L 0 1 .428 r
F
.35159 .84024 m .34785 .82557 L .34354 .82536 L F
.35159 .84024 m .3513 .83195 L .34785 .82557 L F
.36229 .84067 m .3513 .83195 L .35159 .84024 L 0 1 .421 r
F
0 g
.34862 .84643 m
.35159 .84024 L
s
.35159 .84024 m
.35502 .84654 L
s
.37777 .77012 m .3668 .7697 L .36902 .76993 L 0 .551 .204 r
F
0 g
.36508 .77027 m
.36902 .76993 L
s
.76857 .71199 m .77456 .69932 L .77009 .70027 L 0 1 .413 r
F
.76857 .71199 m .77978 .70947 L .77456 .69932 L F
0 g
.76857 .71199 m
.77009 .70027 L
s
.76352 .70203 m
.76857 .71199 L
s
.27484 .76376 m .26468 .75843 L .26343 .76238 L 0 1 .507 r
F
.27484 .76376 m .26903 .75609 L .26468 .75843 L F
.27484 .76376 m .27356 .75694 L .26903 .75609 L F
.27484 .76376 m .27605 .76024 L .27356 .75694 L F
0 g
.2705 .76608 m
.27484 .76376 L
s
.27484 .76376 m
.27737 .76671 L
s
.53169 .88014 m
.53173 .88004 L
s
.81354 .70362 m .82619 .727 L .82757 .71602 L 0 1 .449 r
F
0 g
.82619 .727 m
.83058 .73666 L
s
.48059 1.03268 m .47743 1.03471 L .48206 1.03803 L 0 .372 .367 r
F
.34897 .68968 m .33917 .68775 L .33956 .69094 L 0 1 .539 r
F
0 g
.33453 .69363 m
.33956 .69094 L
s
.46874 .76507 m
.47017 .7643 L
s
.47017 .7643 m
.47018 .76429 L
s
.47018 .76429 m
.47072 .764 L
s
.47072 .764 m
.47178 .76342 L
s
.47172 .76422 m
.47191 .76393 L
s
.52168 .9006 m .52244 .88844 L .52449 .88188 L 0 .114 .089 r
F
0 g
.52369 .88444 m
.52433 .88237 L
s
.52433 .88237 m
.52449 .88188 L
s
.52448 .88119 m
.52449 .88188 L
s
.37346 .84142 m .36583 .84692 L .37029 .84715 L 0 1 .413 r
F
.37346 .84142 m .36229 .84067 L .36583 .84692 L F
0 g
.36317 .85266 m
.36583 .84692 L
s
.60923 .62855 m .61056 .63188 L .60783 .63172 L 0 .112 .051 r
F
0 g
.60364 .63109 m
.60923 .62855 L
s
.60923 .62855 m .61634 .63035 L .61056 .63188 L 0 .112 .051 r
F
.60923 .62855 m .62129 .62815 L .61634 .63035 L F
.45372 .55179 m .44568 .55495 L .44734 .55683 L 0 1 .364 r
F
.45372 .55179 m .44989 .54742 L .44568 .55495 L F
.45372 .55179 m .45716 .53927 L .44989 .54742 L F
.45372 .55179 m .46354 .53425 L .45716 .53927 L F
0 g
.44983 .55974 m
.45372 .55179 L
s
.68743 .62171 m
.68853 .62261 L
s
.38609 .8613 m .37698 .8476 L .37426 .85309 L 0 1 .408 r
F
0 g
.37029 .84715 m
.37426 .85309 L
s
.50785 .96362 m .50362 .96341 L .50698 .96471 L 0 .472 .254 r
F
.50785 .96362 m .50161 .96205 L .50362 .96341 L F
0 g
.5006 .9629 m
.50362 .96341 L
s
.41901 .91365 m .40825 .90235 L .40661 .90735 L 0 .869 .399 r
F
0 g
.40184 .90246 m
.40661 .90735 L
s
.77908 1.05533 m .79092 1.05056 L .78695 1.05185 L 0 .903 .246 r
F
.76934 1.05862 m .77908 1.05533 L .781 1.05392 L 0 .841 .229 r
F
.50339 .90271 m .50242 .89691 L .50356 .89963 L 0 .003 .054 r
F
.50692 .89921 m .50356 .89963 L .50242 .89691 L 0 0 .053 r
F
0 g
.50242 .89691 m
.50298 .89351 L
s
.50018 .89616 m
.50242 .89691 L
s
.74507 .66729 m
.7476 .6722 L
s
.49561 .9004 m .49383 .90202 L .49097 .90239 L 0 0 .026 r
F
.45443 .9892 m .44412 .9856 L .44805 .99138 L 0 .599 .402 r
F
.45443 .9892 m .44328 .98065 L .44412 .9856 L F
0 g
.43905 .98195 m
.44412 .9856 L
s
.56717 .45529 m
.5751 .45554 L
s
.56125 .45915 m
.56717 .45529 L
s
.53959 .97526 m
.5428 .97572 L
s
.6021 .6435 m .60397 .65333 L .60098 .64321 L 0 .493 .007 r
F
0 g
.6012 .64326 m
.60161 .64337 L
s
.60098 .64321 m
.6012 .64326 L
s
.59987 .64098 m
.60098 .64321 L
s
.6021 .6435 m .60989 .66969 L .60397 .65333 L 0 .493 .007 r
F
.6021 .6435 m .60658 .65399 L .61248 .67029 L F
0 g
.60735 .64922 m
.60963 .65952 L
s
.60963 .65952 m
.60977 .66015 L
s
.60982 .66039 m
.60989 .66067 L
s
.60977 .66015 m
.60982 .66039 L
s
.60989 .66067 m
.61129 .66701 L
s
.60658 .65399 m
.60735 .64922 L
s
.60161 .64337 m
.6021 .6435 L
s
.60192 .64292 m
.6021 .6435 L
s
.48678 .9524 m .47855 .95053 L .47936 .9522 L 0 .752 .432 r
F
0 g
.47551 .95152 m
.47936 .9522 L
s
.44259 .50273 m .45069 .49619 L .4558 .49227 L 0 0 0 r
F
0 g
.45069 .49619 m
.45626 .49135 L
s
.57741 .66332 m
.57769 .66159 L
s
.57769 .66159 m
.57774 .66123 L
s
.57492 .6728 m
.57499 .67251 L
s
.57499 .67251 m
.57532 .67117 L
s
.57532 .67117 m
.57559 .67004 L
s
.57708 .66394 m
.57774 .66123 L
s
.57416 .67594 m
.57492 .6728 L
s
.46923 1.01927 m .46978 1.02494 L .47136 1.02404 L 0 .489 .398 r
F
.48059 1.03268 m .47136 1.02404 L .46978 1.02494 L 0 .372 .367 r
F
0 g
.46978 1.02494 m
.47238 1.02951 L
s
.46496 1.02157 m
.46978 1.02494 L
s
.7163 1.07691 m .71912 1.07355 L .72551 1.07331 L 0 0 0 r
F
0 g
.71173 1.07443 m
.71912 1.07355 L
s
.71696 1.07312 m
.71912 1.07355 L
s
.5328 1.08171 m
.53795 1.08409 L
s
.54083 1.08681 m .5389 1.08557 L .53795 1.08409 L 0 .075 0 r
F
0 g
.53795 1.08409 m
.5389 1.08557 L
s
.7492 .62336 m
.7492 .62336 L
s
.74291 .62336 m
.74293 .62337 L
s
.74293 .62337 m
.74443 .62394 L
s
.74443 .62394 m
.74794 .62526 L
s
.5271 .46234 m .52075 .46889 L .52055 .46572 L 0 .091 .039 r
F
.5271 .46234 m .5281 .47094 L .52075 .46889 L F
0 g
.52369 .4722 m
.5261 .47039 L
s
.63629 .62843 m .65053 .62864 L .64927 .62767 L 0 1 .367 r
F
0 g
.65053 .62864 m
.65304 .62866 L
s
.79856 .78865 m .80766 .78623 L .81079 .78925 L 0 0 0 r
F
0 g
.80766 .78623 m
.80804 .7866 L
s
.80766 .78623 m
.81066 .78699 L
s
.28712 .68915 m .2769 .69226 L .28131 .69309 L 0 1 .529 r
F
0 g
.28131 .69309 m
.28288 .69844 L
s
.269 .93599 m .25574 .93415 L .25484 .9351 L 0 .684 .241 r
F
.269 .93599 m .26022 .93421 L .25574 .93415 L F
.269 .93599 m .26591 .935 L .26022 .93421 L F
.27993 .93561 m .26591 .935 L .269 .93599 L 0 .644 .227 r
F
0 g
.26807 .93693 m
.269 .93599 L
s
.269 .93599 m
.27455 .93653 L
s
.71626 .83056 m
.71626 .83055 L
s
.33568 .91708 m .33011 .91893 L .33418 .91873 L 0 1 .414 r
F
.33568 .91708 m .3254 .91737 L .33011 .91893 L F
0 g
.3293 .92066 m
.33011 .91893 L
s
.33418 .91873 m
.33935 .91996 L
s
.64499 .76118 m
.64538 .75515 L
s
.64538 .75515 m
.64539 .75502 L
s
.64553 .75279 m
.64592 .74671 L
s
.64592 .74671 m
.64618 .74268 L
s
.78525 .9003 m .79522 .89754 L .79069 .89754 L 0 1 .486 r
F
.77403 .90001 m .78525 .9003 L .78391 .89756 L 0 1 .468 r
F
.48705 .90819 m .48396 .90533 L .48641 .90634 L 0 0 .031 r
F
.49122 .9044 m .48641 .90634 L .48396 .90533 L 0 0 .028 r
F
0 g
.48371 .90332 m
.48396 .90533 L
s
.48063 .90573 m
.48396 .90533 L
s
.80367 1.0412 m .80812 1.04287 L .81393 1.03761 L 0 1 .322 r
F
0 g
.80082 1.04764 m
.80812 1.04287 L
s
.43067 .94498 m .42648 .95062 L .43 .95003 L 0 .781 .404 r
F
.43782 .96008 m .43 .95003 L .42648 .95062 L 0 .729 .405 r
F
0 g
.42632 .95565 m
.42648 .95062 L
s
.42166 .94632 m
.42648 .95062 L
s
.42437 .9295 m .4194 .93496 L .42321 .93454 L 0 .827 .402 r
F
.43067 .94498 m .42321 .93454 L .4194 .93496 L 0 .781 .404 r
F
0 g
.41874 .94 m
.4194 .93496 L
s
.41466 .9304 m
.4194 .93496 L
s
.51412 .8921 m .51267 .89353 L .51143 .89188 L 0 0 .053 r
F
.20676 .91131 m .19292 .90584 L .19556 .91151 L 0 1 .527 r
F
0 g
.19556 .91151 m
.20086 .91561 L
s
.50785 .96362 m .50698 .96471 L .50965 .96539 L 0 .472 .254 r
F
0 g
.50698 .96471 m
.50934 .96605 L
s
.51935 .902 m .52239 .88392 L .52244 .88844 L 0 .106 .085 r
F
.51935 .902 m .52098 .88532 L .52239 .88392 L F
0 g
.52239 .88392 m
.52259 .88342 L
s
.75949 .61753 m .76391 .62309 L .7597 .6232 L 0 .124 .042 r
F
0 g
.7597 .62309 m
.7597 .6232 L
s
.75949 .61753 m .77016 .61831 L .76391 .62309 L 0 .124 .042 r
F
0 g
.75965 .62181 m
.7597 .62309 L
s
.75949 .61753 m
.75965 .62181 L
s
.7534 .62332 m
.75344 .62329 L
s
.75344 .62329 m
.75615 .6207 L
s
.75615 .6207 m
.75949 .61753 L
s
.2863 .88737 m .27544 .87642 L .27332 .8813 L 0 1 .527 r
F
.2863 .88737 m .28001 .87642 L .27544 .87642 L F
.2863 .88737 m .28466 .88112 L .28001 .87642 L F
0 g
.28417 .89222 m
.2863 .88737 L
s
.30012 .88694 m .28467 .88112 L .2863 .88737 L 0 1 .526 r
F
0 g
.2863 .88737 m
.29164 .89186 L
s
.40382 .89721 m .40219 .89036 L .39763 .88517 L 0 .954 .406 r
F
.4242 .7338 m .4256 .71735 L .42181 .71405 L 0 1 .362 r
F
.4242 .7338 m .42662 .72581 L .4256 .71735 L F
0 g
.4256 .71735 m
.43053 .71371 L
s
.28027 .57761 m .27025 .57505 L .26858 .58399 L 0 1 .471 r
F
0 g
.26163 .5912 m
.26858 .58399 L
s
.28027 .57761 m .27656 .56408 L .27025 .57505 L 0 1 .471 r
F
.28027 .57761 m .28419 .55671 L .27656 .56408 L F
.28027 .57761 m .28803 .55788 L .28419 .55671 L F
.28027 .57761 m .28634 .56685 L .28803 .55788 L F
0 g
.27878 .58648 m
.28027 .57761 L
s
.27267 .58495 m
.28027 .57761 L
s
.68818 .7318 m
.68818 .7318 L
s
.73469 1.07015 m .74627 1.06724 L .74252 1.06852 L 0 0 0 r
F
.72551 1.07331 m .73469 1.07015 L .7369 1.07057 L F
.36229 .84067 m .3543 .82596 L .3513 .83195 L 0 1 .421 r
F
.36229 .84067 m .3586 .82627 L .3543 .82596 L F
.36229 .84067 m .36203 .83258 L .3586 .82627 L F
0 g
.35929 .84665 m
.36229 .84067 L
s
.37346 .84142 m .36203 .83258 L .36229 .84067 L 0 1 .413 r
F
0 g
.36229 .84067 m
.36583 .84692 L
s
.74983 .67018 m
.75017 .66356 L
s
.7159 .89801 m .72439 .8998 L .72646 .89848 L 0 .674 .252 r
F
0 g
.71973 .90038 m
.72439 .8998 L
s
.50509 .48615 m .52014 .47487 L .52029 .47514 L 0 0 0 r
F
0 g
.52014 .47487 m
.52369 .4722 L
s
.51363 .47958 m
.52014 .47487 L
s
.41464 .8974 m .40382 .89721 L .40825 .90235 L 0 .909 .396 r
F
.41464 .8974 m .40219 .89036 L .40382 .89721 L F
0 g
.40184 .90246 m
.40382 .89721 L
s
.45443 .9892 m .44805 .99138 L .45283 .99505 L 0 .599 .402 r
F
0 g
.44805 .99138 m
.44919 .99643 L
s
.49995 .90613 m .49561 .9004 L .49815 .90095 L 0 .023 .055 r
F
.49995 .90613 m .49383 .90202 L .49561 .9004 L F
0 g
.49561 .9004 m
.49575 .89817 L
s
.3548 .59045 m
.35608 .58482 L
s
.38893 .68166 m
.3942 .67944 L
s
.43411 .74272 m .42662 .72581 L .4242 .7338 L 0 1 .353 r
F
0 g
.42662 .72581 m
.43127 .72273 L
s
.4256 .71735 m
.42662 .72581 L
s
.26343 .76238 m .25331 .75663 L .25201 .76099 L 0 1 .518 r
F
.26343 .76238 m .25768 .75398 L .25331 .75663 L F
.26343 .76238 m .26222 .75482 L .25768 .75398 L F
.26343 .76238 m .26468 .75843 L .26222 .75482 L F
0 g
.25906 .765 m
.26343 .76238 L
s
.26343 .76238 m
.26593 .76565 L
s
.45455 .93469 m .4507 .93717 L .45389 .93671 L 0 1 .505 r
F
.46079 .94002 m .45389 .93671 L .4507 .93717 L 0 1 .501 r
F
0 g
.4505 .93919 m
.4507 .93717 L
s
.44631 .93572 m
.4507 .93717 L
s
.37086 .57804 m .36025 .59671 L .36367 .58873 L 0 .932 .186 r
F
.37086 .57804 m .36267 .59368 L .36025 .59671 L F
.37086 .57804 m .36933 .58164 L .36267 .59368 L F
0 g
.36367 .58873 m
.36386 .58845 L
s
.36367 .58865 m
.36492 .58303 L
s
.37086 .57804 m .37948 .56866 L .37654 .57091 L 0 .932 .186 r
F
.37086 .57804 m .37704 .57172 L .37948 .56866 L F
.37086 .57804 m .37654 .57091 L .36933 .58164 L F
0 g
.36867 .581 m
.37086 .57804 L
s
.36386 .58845 m
.37086 .57804 L
s
.3212 .88654 m .31486 .89091 L .31905 .89078 L 0 1 .522 r
F
.3212 .88654 m .31066 .8867 L .31486 .89091 L F
0 g
.31341 .89519 m
.31486 .89091 L
s
.31905 .89078 m
.32238 .89353 L
s
.32238 .89353 m
.32379 .8947 L
s
.48021 .94823 m .47482 .94961 L .47855 .95053 L 0 .832 .46 r
F
.48021 .94823 m .47186 .9478 L .47482 .94961 L F
0 g
.47482 .94961 m
.47551 .95152 L
s
.43782 .96008 m .43447 .96584 L .43766 .96512 L 0 .729 .405 r
F
.44577 .97481 m .43766 .96512 L .43447 .96584 L 0 .67 .405 r
F
0 g
.43447 .96584 m
.43481 .97085 L
s
.42961 .96179 m
.43447 .96584 L
s
.70674 .62106 m .72155 .62187 L .71675 .62032 L 0 .629 .231 r
F
0 g
.72155 .62187 m
.72201 .6229 L
s
.72155 .62187 m
.72717 .6229 L
s
.38609 .8613 m .38144 .84797 L .37698 .8476 L 0 1 .408 r
F
.38609 .8613 m .38535 .85384 L .38144 .84797 L F
0 g
.38337 .86678 m
.38609 .8613 L
s
.39757 .86227 m .3861 .8613 L .39008 .86712 L 0 1 .399 r
F
.39757 .86227 m .38535 .85384 L .3861 .8613 L F
.43411 .74272 m .42542 .74238 L .42946 .74581 L 0 1 .353 r
F
.43411 .74272 m .4242 .7338 L .42542 .74238 L F
.44399 .75344 m .43411 .74272 L .43552 .75148 L 0 1 .344 r
F
.46923 1.01927 m .46481 1.01382 L .45999 1.01045 L 0 .489 .398 r
F
0 g
.76341 .70165 m
.76406 .68943 L
s
.41901 .91365 m .4133 .91887 L .41737 .91865 L 0 .869 .399 r
F
.42446 .92362 m .41737 .91865 L .4133 .91887 L 0 1 .517 r
F
.42437 .9295 m .41737 .91865 L .4133 .91887 L 0 .827 .402 r
F
.41898 .91616 m .4133 .91887 L .41737 .91865 L 0 1 .513 r
F
.41898 .91616 m .40865 .91653 L .4133 .91887 L F
0 g
.40869 .91403 m
.41099 .91644 L
s
.42446 .92362 m .42215 .92069 L .41737 .91865 L 0 1 .517 r
F
.42437 .9295 m .42211 .92321 L .41737 .91865 L 0 .827 .402 r
F
.41894 .91868 m .4133 .91887 L .41737 .91865 L 0 0 0 r
F
.41894 .91868 m .40861 .91903 L .4133 .91887 L F
0 g
.41222 .9189 m
.4133 .91887 L
s
.41326 .91897 m
.4133 .91887 L
s
.41328 .91896 m
.4133 .91887 L
s
.40733 .91907 m
.40733 .91907 L
s
.45455 .93469 m .44429 .9313 L .44364 .93332 L 0 1 .505 r
F
0 g
.439 .93188 m
.44364 .93332 L
s
.41884 .68016 m
.4206 .68465 L
s
.42129 .70518 m .4206 .68466 L .41543 .68891 L 0 1 .366 r
F
0 g
.41987 .68526 m
.4206 .68466 L
s
.48705 .90819 m .47927 .90912 L .47863 .90727 L 0 0 .031 r
F
0 g
.475 .90818 m
.47863 .90727 L
s
.57789 .61767 m .57774 .62672 L .57564 .62047 L 0 .487 .082 r
F
.57789 .61767 m .58348 .63473 L .57774 .62672 L F
.57789 .61767 m .58902 .63914 L .58348 .63473 L F
.57789 .61767 m .59125 .63629 L .58902 .63914 L F
.57789 .61767 m .58869 .62812 L .59125 .63629 L F
0 g
.58297 .62016 m
.58869 .62812 L
s
.5725 .61001 m
.57789 .61767 L
s
.58948 .62718 m
.59037 .62611 L
s
.58869 .62812 m
.58948 .62718 L
s
.46876 .7631 m
.47011 .76424 L
s
.47011 .76424 m
.47018 .76429 L
s
.47018 .76429 m
.47114 .7651 L
s
.47193 .76577 m
.47249 .76624 L
s
.51935 .902 m .51925 .89137 L .52098 .88532 L 0 .106 .085 r
F
0 g
.52074 .88616 m
.52089 .88562 L
s
.52089 .88562 m
.52098 .88532 L
s
.51801 .8877 m
.51935 .88383 L
s
.5196 .88661 m
.52058 .88256 L
s
.51915 .88698 m
.51936 .88383 L
s
.52058 .88256 m
.52098 .88532 L
s
.44399 .75344 m .43552 .75148 L .43955 .75561 L 0 1 .344 r
F
0 g
.43955 .75561 m
.44399 .75344 L
s
.43411 .74272 m
.43552 .75148 L
s
.44399 .75344 m
.44559 .76248 L
s
.79101 .70729 m .80488 .7195 L .80227 .70536 L 0 1 .432 r
F
0 g
.80342 .73073 m
.80488 .7195 L
s
.80488 .7195 m
.81024 .72951 L
s
.74936 .66213 m
.75017 .66356 L
s
.74837 .66038 m
.74936 .66213 L
s
.74794 .65962 m
.74837 .66038 L
s
.37704 .57172 m
.38388 .56536 L
s
.52149 .61338 m .52682 .61116 L .53131 .61163 L 0 .012 .035 r
F
.42129 .70518 m .41233 .70658 L .41612 .70944 L 0 1 .366 r
F
.42129 .70518 m .41203 .69778 L .41233 .70658 L F
.42129 .70518 m .41543 .68891 L .41203 .69778 L F
0 g
.41543 .68891 m
.41987 .68526 L
s
.39757 .86227 m .39008 .86712 L .39465 .86743 L 0 1 .399 r
F
.4001 .87996 m .39465 .86743 L .39008 .86712 L 0 .991 .403 r
F
0 g
.38762 .87234 m
.39008 .86712 L
s
.3861 .8613 m
.39008 .86712 L
s
.40083 .76995 m
.40132 .76987 L
s
.40132 .76987 m
.40416 .76989 L
s
.34897 .68968 m .34265 .68422 L .33917 .68775 L 0 1 .539 r
F
.34897 .68968 m .3481 .68222 L .34265 .68422 L F
.34897 .68968 m .3519 .68312 L .3481 .68222 L F
.34897 .68968 m .35226 .68631 L .3519 .68312 L F
0 g
.34897 .68968 m
.34949 .6926 L
s
.34353 .69166 m
.34897 .68968 L
s
.23528 .59838 m .22358 .60565 L .22789 .60621 L 0 1 .488 r
F
0 g
.22789 .60621 m
.2279 .61486 L
s
.45907 .76058 m
.45949 .76064 L
s
.45546 .76015 m
.45907 .76058 L
s
.40865 .91653 m .40169 .91076 L .39742 .91088 L 0 1 .517 r
F
.40865 .91653 m .40651 .91318 L .40169 .91076 L F
.41898 .91616 m .40651 .91318 L .40865 .91653 L 0 1 .513 r
F
0 g
.40733 .91907 m
.40865 .91653 L
s
.40865 .91653 m
.4133 .91887 L
s
.41884 .68016 m .41998 .67737 L .4184 .67314 L 0 1 .371 r
F
.46823 .52704 m .46045 .53077 L .46169 .53214 L 0 1 .274 r
F
.46823 .52704 m .46548 .52399 L .46045 .53077 L F
.46823 .52704 m .47341 .51633 L .46548 .52399 L F
.46823 .52704 m .47994 .51126 L .47341 .51633 L F
0 g
.46354 .53425 m
.46823 .52704 L
s
.43419 .92309 m .42446 .92362 L .42904 .92561 L 0 1 .511 r
F
.43419 .92309 m .42215 .92069 L .42446 .92362 L F
0 g
.42333 .92616 m
.42446 .92362 L
s
.29804 .69155 m .29045 .68304 L .28712 .68915 L 0 1 .532 r
F
.29804 .69155 m .29615 .67943 L .29045 .68304 L F
.29804 .69155 m .30041 .68074 L .29615 .67943 L F
.29804 .69155 m .30122 .68594 L .30041 .68074 L F
0 g
.29235 .69514 m
.29804 .69155 L
s
.3668 .7697 m .3583 .76943 L .36253 .76968 L 0 .601 .227 r
F
0 g
.36253 .76968 m
.36508 .77027 L
s
.40693 .67439 m
.40953 .67325 L
s
.41039 .67287 m
.41049 .67283 L
s
.41464 .8974 m .4043 .88541 L .40219 .89036 L 0 .909 .396 r
F
0 g
.39763 .88517 m
.40219 .89036 L
s
.28712 .68915 m .27618 .68672 L .2769 .69226 L 0 1 .529 r
F
0 g
.27176 .69667 m
.2769 .69226 L
s
.3548 .59045 m .34636 .57074 L .35048 .57907 L 0 .581 .046 r
F
.3548 .59045 m .34457 .56974 L .34636 .57074 L F
0 g
.35047 .57903 m
.35048 .579 L
s
.35047 .57905 m
.35047 .57903 L
s
.34957 .58566 m
.35019 .58112 L
s
.35048 .579 m
.35048 .57895 L
s
.46757 .94499 m .46479 .94305 L .46058 .94203 L 0 .997 .494 r
F
.77978 .70947 m .78574 .69718 L .78126 .698 L 0 1 .423 r
F
.77978 .70947 m .79101 .70729 L .78574 .69718 L F
0 g
.77456 .69932 m
.77978 .70947 L
s
.44259 .50273 m .43352 .5095 L .43524 .50844 L 0 0 0 r
F
0 g
.43634 .50799 m
.43781 .50666 L
s
.44259 .50273 m .43864 .50558 L .43352 .5095 L 0 0 0 r
F
.44259 .50273 m .4558 .49227 L .45454 .49358 L F
0 g
.43781 .50666 m
.44259 .50273 L
s
.4558 .49227 m
.463 .48699 L
s
.45069 .49619 m
.4558 .49227 L
s
.38463 .84252 m .37698 .8476 L .38144 .84797 L 0 1 .404 r
F
.38463 .84252 m .37346 .84142 L .37698 .8476 L F
0 g
.37426 .85309 m
.37698 .8476 L
s
.37633 .68417 m .36706 .6856 L .37084 .68598 L 0 1 .49 r
F
0 g
.37084 .68598 m
.37148 .68872 L
s
.51509 .96708 m .51203 .96661 L .5154 .96785 L 0 .403 .224 r
F
.51509 .96708 m .50965 .96539 L .51203 .96661 L F
0 g
.50934 .96605 m
.51203 .96661 L
s
.25167 .9108 m .2454 .91416 L .24987 .91404 L 0 1 .513 r
F
.25167 .9108 m .24043 .91088 L .2454 .91416 L F
0 g
.24453 .91751 m
.2454 .91416 L
s
.24987 .91404 m
.25557 .917 L
s
.71974 .80416 m
.71974 .80415 L
s
.71683 .79168 m
.71944 .79711 L
s
.7203 .79891 m
.72031 .79892 L
s
.48021 .94823 m .47148 .94608 L .47186 .9478 L 0 .832 .46 r
F
0 g
.46781 .94697 m
.47186 .9478 L
s
.4242 .7338 m .42181 .71405 L .41696 .71787 L 0 1 .362 r
F
0 g
.42129 .70518 m
.42181 .71405 L
s
.53139 1.08307 m .5328 1.08171 L .53694 1.08517 L 0 0 0 r
F
.35671 .89857 m .34632 .89036 L .34457 .89403 L 0 1 .52 r
F
.35671 .89857 m .35052 .89037 L .34632 .89036 L F
.35671 .89857 m .35498 .8939 L .35052 .89037 L F
.367 .89837 m .35498 .8939 L .35671 .89857 L 0 1 .518 r
F
0 g
.35671 .89857 m
.36107 .90195 L
s
.35496 .90223 m
.35671 .89857 L
s
.51747 .90329 m .51958 .8867 L .51925 .89137 L 0 .107 .084 r
F
.51747 .90329 m .51913 .88714 L .51958 .8867 L F
0 g
.51953 .89038 m
.52074 .88616 L
s
.51958 .8867 m
.5196 .88661 L
s
.51957 .88687 m
.51958 .8867 L
s
.40693 .67439 m
.40697 .67372 L
s
.40699 .6734 m
.40699 .67339 L
s
.43419 .92309 m .42904 .92561 L .43286 .92533 L 0 1 .511 r
F
.43987 .9296 m .43286 .92533 L .42904 .92561 L 0 1 .513 r
F
0 g
.42819 .9279 m
.42904 .92561 L
s
.42446 .92362 m
.42904 .92561 L
s
.4581 .91507 m .45327 .91414 L .4568 .91419 L 0 0 0 r
F
.4581 .91507 m .44905 .91484 L .45327 .91414 L F
.46299 .91204 m .4568 .91419 L .45327 .91414 L F
0 g
.4524 .91325 m
.45327 .91414 L
s
.74978 1.06669 m .74627 1.06724 L .75356 1.06462 L 0 0 0 r
F
.74978 1.06669 m .74252 1.06852 L .74627 1.06724 L F
0 g
.74385 1.06741 m
.74627 1.06724 L
s
.41884 .68016 m .41209 .67741 L .41545 .68018 L 0 1 .371 r
F
.41884 .68016 m .4105 .67318 L .41209 .67741 L F
.41884 .68016 m .4184 .67314 L .41513 .67028 L F
0 g
.4184 .67314 m
.41998 .67737 L
s
.41545 .68018 m
.41884 .68016 L
s
.4184 .67313 m
.4184 .67313 L
s
.4184 .67313 m
.42378 .66851 L
s
.41737 .91865 m
.41742 .91864 L
s
.41742 .91864 m
.4175 .91863 L
s
.43426 .91721 m .42347 .91844 L .42219 .91817 L 0 0 0 r
F
0 g
.4175 .91863 m
.42219 .91817 L
s
.51747 .90329 m .51825 .89231 L .51913 .88714 L 0 .107 .084 r
F
0 g
.51912 .88722 m
.51913 .88714 L
s
.51783 .88821 m
.51801 .8877 L
s
.51913 .88714 m
.51915 .88698 L
s
.44905 .91484 m .4425 .91661 L .43869 .91668 L 0 0 0 r
F
.44905 .91484 m .44695 .91582 L .4425 .91661 L F
.4581 .91507 m .44695 .91582 L .44905 .91484 L F
0 g
.44905 .91484 m
.45327 .91414 L
s
.44799 .91429 m
.44905 .91484 L
s
.67325 .92344 m
.6733 .92337 L
s
.41464 .8974 m .40825 .90235 L .41253 .90235 L 0 .909 .396 r
F
.41901 .91365 m .41253 .90235 L .40825 .90235 L 0 .869 .399 r
F
0 g
.40661 .90735 m
.40825 .90235 L
s
.40382 .89721 m
.40825 .90235 L
s
.82439 .889 m .8291 .8975 L .83391 .89358 L 0 1 .511 r
F
.82439 .889 m .82459 .8975 L .8291 .8975 L F
0 g
.8291 .8975 m
.83003 .90137 L
s
.37346 .84142 m .3652 .82684 L .36203 .83258 L 0 1 .413 r
F
.37346 .84142 m .36969 .82729 L .3652 .82684 L F
.37346 .84142 m .37323 .83354 L .36969 .82729 L F
.38463 .84252 m .37323 .83354 L .37346 .84142 L 0 1 .404 r
F
0 g
.37346 .84142 m
.37698 .8476 L
s
.37029 .84715 m
.37346 .84142 L
s
.25201 .76099 m .24192 .75485 L .24059 .75961 L 0 1 .525 r
F
.25201 .76099 m .24633 .75188 L .24192 .75485 L F
.25201 .76099 m .25087 .75272 L .24633 .75188 L F
.25201 .76099 m .25331 .75663 L .25087 .75272 L F
0 g
.24761 .76392 m
.25201 .76099 L
s
.25201 .76099 m
.25448 .76457 L
s
.31514 .91775 m .30366 .91325 L .30239 .91538 L 0 1 .459 r
F
.31514 .91775 m .30786 .91326 L .30366 .91325 L F
.31514 .91775 m .31278 .91519 L .30786 .91326 L F
.3254 .91737 m .31278 .91519 L .31514 .91775 L 0 1 .439 r
F
0 g
.31385 .91987 m
.31514 .91775 L
s
.31514 .91775 m
.31995 .91949 L
s
.38144 .84797 m
.38535 .85384 L
s
.39757 .86227 m .38827 .84868 L .38535 .85384 L 0 1 .399 r
F
.41593 .66117 m .42025 .65188 L .42129 .64277 L 0 1 .378 r
F
0 g
.42025 .65188 m
.42567 .64724 L
s
.69255 .89138 m
.69283 .89078 L
s
.69227 .89197 m
.69255 .89138 L
s
.37185 .91958 m .36068 .91789 L .35947 .91889 L 0 .789 .283 r
F
.37185 .91958 m .36477 .91784 L .36068 .91789 L F
.37185 .91958 m .36956 .91857 L .36477 .91784 L F
0 g
.37062 .92058 m
.37185 .91958 L
s
.38222 .91913 m .36956 .91857 L .37185 .91958 L 0 .711 .252 r
F
0 g
.37185 .91958 m
.37663 .92014 L
s
.47361 .76442 m
.47371 .76407 L
s
.46299 .91204 m .46097 .91329 L .4568 .91419 L 0 0 0 r
F
.47125 .91297 m .46299 .91204 L .4669 .91137 L 0 0 .003 r
F
.47125 .91297 m .46097 .91329 L .46299 .91204 L F
0 g
.4621 .91115 m
.46299 .91204 L
s
.4242 .7338 m .41529 .73473 L .41935 .73763 L 0 1 .362 r
F
.4242 .7338 m .41427 .72626 L .41529 .73473 L F
.4242 .7338 m .41696 .71787 L .41427 .72626 L F
0 g
.73777 .76887 m
.73856 .77177 L
s
.73856 .77177 m
.73856 .77177 L
s
.46372 1.00328 m .45415 .99992 L .45835 1.00552 L 0 .514 .394 r
F
.46372 1.00328 m .45283 .99505 L .45415 .99992 L F
0 g
.44919 .99643 m
.45415 .99992 L
s
.21304 .69662 m .20471 .68661 L .20174 .69536 L 0 1 .527 r
F
0 g
.20174 .69536 m
.20294 .70221 L
s
.21304 .69662 m .21029 .68056 L .20471 .68661 L 0 1 .527 r
F
.21304 .69662 m .21475 .68128 L .21029 .68056 L F
.21304 .69662 m .21592 .68818 L .21475 .68128 L F
0 g
.20748 .70262 m
.21304 .69662 L
s
.21304 .69662 m
.2143 .70324 L
s
.52577 .97147 m
.52609 .97157 L
s
.52576 .97146 m
.52577 .97147 L
s
.52611 .97157 m
.52645 .97168 L
s
.52646 .97168 m
.52682 .97179 L
s
.52683 .9718 m
.52688 .97181 L
s
.52815 .9724 m .52711 .97203 L .52688 .97181 L 0 0 0 r
F
0 g
.52688 .97181 m
.52711 .97203 L
s
.41593 .66117 m .42129 .64277 L .41836 .63989 L 0 1 .378 r
F
0 g
.42129 .64277 m
.42701 .63799 L
s
.42025 .65188 m
.42129 .64277 L
s
.43955 .75561 m
.44138 .76387 L
s
.77403 .90001 m .78391 .89756 L .77938 .89756 L 0 1 .468 r
F
.7628 .89971 m .77403 .90001 L .77259 .89757 L 0 1 .445 r
F
.44577 .97481 m .44328 .98065 L .44611 .97982 L 0 .67 .405 r
F
.45443 .9892 m .44611 .97982 L .44328 .98065 L 0 .599 .402 r
F
0 g
.44328 .98065 m
.44412 .9856 L
s
.43844 .9768 m
.44328 .98065 L
s
.79339 1.04528 m .79092 1.05056 L .79807 1.04601 L 0 1 .27 r
F
.79339 1.04528 m .78695 1.05185 L .79092 1.05056 L F
0 g
.78881 1.05248 m
.79092 1.05056 L
s
.33917 .68775 m .32961 .68883 L .33359 .68973 L 0 1 .542 r
F
0 g
.33359 .68973 m
.33453 .69363 L
s
.4001 .87996 m .39894 .87293 L .39465 .86743 L 0 .991 .403 r
F
.41131 .88077 m .4001 .87996 L .4043 .88541 L 0 .946 .393 r
F
.41131 .88077 m .39894 .87293 L .4001 .87996 L F
0 g
.39763 .88517 m
.4001 .87996 L
s
.76406 .68943 m
.77009 .70027 L
s
.7516 .76699 m .75951 .77669 L .75481 .77401 L 0 .278 .038 r
F
.7516 .76699 m .76337 .7744 L .75951 .77669 L F
0 g
.74775 .7694 m
.7516 .76699 L
s
.61634 .63035 m .6273 .62688 L .63039 .62737 L 0 0 0 r
F
.61634 .63035 m .62129 .62815 L .6273 .62688 L F
0 g
.62129 .62815 m
.62267 .62499 L
s
.62129 .62815 m
.6273 .62688 L
s
.3668 .7697 m .35629 .7689 L .3583 .76943 L 0 .601 .227 r
F
0 g
.35446 .76987 m
.3583 .76943 L
s
.41998 .63077 m .42506 .62149 L .42704 .61256 L 0 1 .387 r
F
.63228 .5251 m .63239 .52676 L .62909 .51886 L 0 0 .089 r
F
0 g
.63227 .52509 m
.63228 .5251 L
s
.6316 .52377 m
.63227 .52509 L
s
.63159 .52375 m
.6316 .52377 L
s
.62909 .51886 m
.63159 .52375 L
s
.62786 .51681 m
.62909 .51886 L
s
.51509 .96708 m .5154 .96785 L .51773 .96857 L 0 .403 .224 r
F
0 g
.5154 .96785 m
.51813 .969 L
s
.42932 .76134 m .42946 .74581 L .42542 .74238 L 0 1 .357 r
F
.42932 .76134 m .43113 .75393 L .42946 .74581 L F
0 g
.42946 .74581 m
.43411 .74272 L
s
.42946 .74581 m
.43113 .75393 L
s
.43113 .75393 m
.43552 .75148 L
s
.20676 .91131 m .19436 .90167 L .19292 .90584 L 0 1 .527 r
F
.20676 .91131 m .19892 .9018 L .19436 .90167 L F
.20676 .91131 m .20424 .90594 L .19892 .9018 L F
.21798 .91114 m .20424 .90594 L .20676 .91131 L 0 1 .525 r
F
0 g
.20531 .91545 m
.20676 .91131 L
s
.20676 .91131 m
.21198 .91521 L
s
.81026 .79158 m .81469 .7886 L .81938 .79004 L 0 0 0 r
F
.81026 .79158 m .81079 .78925 L .81469 .7886 L F
0 g
.81066 .78699 m
.81469 .7886 L
s
.40363 .90805 m .39742 .91088 L .40169 .91076 L 0 1 .513 r
F
.40363 .90805 m .39281 .90814 L .39742 .91088 L F
0 g
.39599 .91366 m
.39742 .91088 L
s
.41998 .63077 m .42704 .61256 L .42459 .6099 L 0 1 .387 r
F
0 g
.42704 .61256 m
.43296 .60768 L
s
.42506 .62149 m
.42704 .61256 L
s
.82439 .889 m .82256 .89387 L .82459 .8975 L 0 1 .511 r
F
0 g
.81885 .9011 m
.82459 .8975 L
s
.51622 .90424 m .51772 .88853 L .51825 .89231 L 0 .099 .082 r
F
0 g
.51772 .88853 m
.51783 .88821 L
s
.39281 .90814 m .38207 .90151 L .3804 .90451 L 0 1 .517 r
F
.40861 .91903 m .39727 .91916 L .39588 .91943 L 0 .599 .203 r
F
0 g
.39588 .91943 m
.39588 .91943 L
s
.30558 .55325 m .29377 .55982 L .29759 .56123 L 0 1 .444 r
F
0 g
.29608 .57012 m
.29759 .56123 L
s
.30558 .55325 m .29624 .54988 L .29377 .55982 L 0 1 .444 r
F
.30558 .55325 m .30336 .53803 L .29624 .54988 L F
.30558 .55325 m .31136 .53004 L .30336 .53803 L F
.30558 .55325 m .3149 .53124 L .31136 .53004 L F
.30558 .55325 m .31242 .54119 L .3149 .53124 L F
0 g
.3033 .56361 m
.30558 .55325 L
s
.29759 .56123 m
.30558 .55325 L
s
.80227 .70536 m .81621 .71767 L .81354 .70362 L 0 1 .441 r
F
0 g
.8148 .72875 m
.81621 .71767 L
s
.81621 .71767 m
.82163 .72767 L
s
.37777 .77012 m .36869 .76952 L .3668 .7697 L 0 .551 .204 r
F
.36869 .76952 m .36864 .76952 L .36863 .76952 L F
.36869 .76952 m .36863 .76952 L .3668 .7697 L F
.36652 .76931 m .36828 .76907 L .36644 .76181 L 0 1 .408 r
F
.36693 .76936 m .36828 .76907 L .36652 .76931 L F
.36819 .7695 m .36828 .76907 L .36652 .76944 L F
.36437 .76899 m .36644 .76181 L .36231 .76088 L F
.35612 .76828 m .35789 .76693 L .35612 .75963 L 0 1 .415 r
F
.35758 .76851 m .35789 .76693 L .35612 .7684 L F
.35629 .7689 m .34772 .76859 L .35195 .76897 L 0 .638 .244 r
F
.35629 .7689 m .34578 .76774 L .34772 .76859 L F
.35418 .7679 m .35612 .75963 L .35199 .75888 L 0 1 .415 r
F
.34569 .76686 m .34748 .7652 L .34579 .75787 L 0 1 .423 r
F
.34579 .76688 m .34748 .7652 L .34569 .76686 L F
.34708 .76714 m .34748 .7652 L .34568 .76698 L F
.34578 .76774 m .33714 .76746 L .34137 .76795 L 0 .666 .259 r
F
.34578 .76774 m .33527 .76628 L .33714 .76746 L F
.34376 .76639 m .34579 .75787 L .34164 .75727 L 0 1 .423 r
F
.33524 .765 m .33705 .76382 L .33543 .75647 L 0 1 .43 r
F
.33538 .76503 m .33705 .76382 L .33524 .765 L F
.33672 .76537 m .33705 .76382 L .33524 .76513 L F
.33527 .76628 m .32656 .76607 L .33079 .76665 L 0 .741 .312 r
F
.33527 .76628 m .32475 .76455 L .32656 .76607 L F
.33313 .76438 m .33543 .75647 L .33127 .756 L 0 1 .43 r
F
.32475 .76455 m .32234 .76191 L .31616 .76074 L 0 .861 .367 r
F
.32475 .76455 m .31597 .76448 L .3202 .76514 L F
.32475 .76455 m .31423 .7626 L .31597 .76448 L F
.32475 .76455 m .31616 .76074 L .31423 .7626 L F
.32452 .77217 m .32234 .76191 L .31612 .76191 L 0 1 .438 r
F
.32234 .76191 m .32088 .75503 L .31715 .76043 L F
.32234 .76191 m .32504 .75539 L .32088 .75503 L F
.32256 .76197 m .32504 .75539 L .32234 .76191 L F
.32475 .76455 m .32481 .76265 L .32234 .76191 L 0 .861 .367 r
F
.32481 .76281 m .32481 .76265 L .32243 .76233 L 0 1 .438 r
F
.32481 .76265 m .32504 .75539 L .32256 .76198 L F
.32481 .76265 m .32256 .76198 L .32243 .76233 L F
.32481 .76265 m .32482 .76262 L .32234 .76191 L 0 .861 .367 r
F
.32234 .76191 m .32486 .7612 L .32072 .76014 L F
.32482 .76262 m .32486 .7612 L .32234 .76191 L F
.32234 .76191 m .31715 .76043 L .31701 .76063 L 0 1 .438 r
F
.32234 .76191 m .31701 .76063 L .31616 .76074 L 0 .861 .367 r
F
.32234 .76191 m .31701 .76063 L .31612 .76191 L 0 1 .438 r
F
.32234 .76191 m .31719 .76061 L .31701 .76063 L 0 .861 .367 r
F
.32234 .76191 m .32072 .76014 L .31719 .76061 L F
.32243 .76233 m .32256 .76197 L .32234 .76191 L 0 1 .438 r
F
.32452 .77217 m .32481 .76281 L .32243 .76233 L F
.33527 .76628 m .32708 .76327 L .32475 .76455 L 0 .741 .312 r
F
.32708 .76327 m .32701 .76325 L .327 .76325 L F
.32708 .76327 m .327 .76325 L .32475 .76455 L F
.32701 .76325 m .3266 .76274 L .32651 .76315 L 0 1 .43 r
F
.32701 .76325 m .32662 .7631 L .32654 .76316 L 0 .741 .312 r
F
.32481 .76281 m .3266 .76274 L .32504 .75539 L 0 1 .438 r
F
.327 .76325 m .32654 .76316 L .32475 .76455 L 0 .741 .312 r
F
.32662 .7631 m .32658 .76309 L .32475 .76455 L F
.32651 .76315 m .3266 .76274 L .32529 .76279 L 0 1 .438 r
F
.32481 .76265 m .32659 .76309 L .32486 .7612 L 0 .861 .367 r
F
.32475 .76455 m .32651 .76315 L .32481 .76265 L F
.32651 .76315 m .32659 .76309 L .32481 .76265 L F
.32651 .76315 m .32529 .76279 L .32481 .76281 L 0 1 .438 r
F
.32452 .77217 m .32651 .76315 L .32481 .76281 L F
.32701 .76325 m .32654 .76316 L .32654 .76316 L 0 .741 .312 r
F
.32701 .76325 m .32654 .76316 L .327 .76325 L F
.33507 .77313 m .32701 .76325 L .32452 .77217 L 0 1 .43 r
F
.32701 .76325 m .32651 .76315 L .32452 .77217 L F
.32701 .76325 m .33127 .756 L .3266 .76274 L F
.33527 .76628 m .33315 .76447 L .32701 .76325 L 0 .741 .312 r
F
.33507 .77313 m .33315 .76447 L .32701 .76325 L 0 1 .43 r
F
.33315 .76447 m .33127 .756 L .32714 .76302 L F
.33525 .76479 m .33543 .75647 L .33313 .76438 L F
.33315 .76447 m .33522 .76366 L .33108 .76271 L 0 .741 .312 r
F
.33527 .76628 m .33524 .765 L .33315 .76447 L F
.33507 .77313 m .33524 .765 L .33315 .76447 L 0 1 .43 r
F
.33524 .765 m .33525 .76491 L .33315 .76447 L F
.33524 .765 m .33524 .76498 L .33315 .76447 L 0 .741 .312 r
F
.33315 .76447 m .33525 .76479 L .33313 .76438 L 0 1 .43 r
F
.33525 .76491 m .33525 .76479 L .33315 .76447 L F
.33524 .76498 m .33522 .76366 L .33315 .76447 L 0 .741 .312 r
F
.33315 .76447 m .32714 .76302 L .32701 .76325 L 0 1 .43 r
F
.32701 .76325 m .33315 .76447 L .32662 .7631 L 0 .741 .312 r
F
.32662 .7631 m .33108 .76271 L .32659 .76309 L F
.33315 .76447 m .33108 .76271 L .32662 .7631 L F
.32662 .7631 m .32659 .76309 L .32658 .76309 L F
.33524 .765 m .33701 .76519 L .33522 .76366 L F
.33527 .76628 m .33672 .76537 L .33524 .765 L F
.33672 .76537 m .33701 .76519 L .33524 .765 L F
.33524 .76513 m .33538 .76503 L .33524 .765 L 0 1 .43 r
F
.34578 .76774 m .33874 .76569 L .33527 .76628 L 0 .666 .259 r
F
.33874 .76569 m .33844 .76564 L .33527 .76628 L F
.33852 .76563 m .3381 .76557 L .33527 .76628 L F
.33822 .76554 m .3368 .76532 L .33527 .76628 L F
.33507 .77313 m .33672 .76537 L .33524 .76513 L 0 1 .43 r
F
.33874 .76569 m .33852 .76563 L .33844 .76564 L 0 .666 .259 r
F
.33852 .76563 m .33705 .76382 L .33673 .76534 L 0 1 .423 r
F
.33852 .76563 m .33673 .76534 L .33672 .76537 L F
.33852 .76563 m .34164 .75727 L .33705 .76382 L F
.34578 .76774 m .34377 .76647 L .33852 .76563 L 0 .666 .259 r
F
.3456 .77436 m .34377 .76647 L .33852 .76563 L 0 1 .423 r
F
.34377 .76647 m .34164 .75727 L .33859 .76544 L F
.34569 .76669 m .34579 .75787 L .34376 .76639 L F
.34377 .76647 m .34557 .7658 L .34143 .76498 L 0 .666 .259 r
F
.34377 .76647 m .34569 .76669 L .34376 .76639 L 0 1 .423 r
F
.34578 .76774 m .34569 .76686 L .34377 .76647 L 0 .666 .259 r
F
.3456 .77436 m .34569 .76686 L .34377 .76647 L 0 1 .423 r
F
.34569 .76686 m .34569 .76669 L .34377 .76647 L F
.34569 .76686 m .34568 .76685 L .34377 .76647 L 0 .666 .259 r
F
.34568 .76685 m .34557 .7658 L .34377 .76647 L F
.34377 .76647 m .33859 .76544 L .33852 .76563 L 0 1 .423 r
F
.34377 .76647 m .34374 .76645 L .33852 .76563 L 0 .666 .259 r
F
.33852 .76563 m .34143 .76498 L .33701 .76519 L F
.34374 .76645 m .34143 .76498 L .33852 .76563 L F
.33852 .76563 m .33822 .76554 L .3381 .76557 L F
.3456 .77436 m .33852 .76563 L .33507 .77313 L 0 1 .423 r
F
.33852 .76563 m .33672 .76537 L .33507 .77313 L F
.33822 .76554 m .33701 .76519 L .3368 .76532 L 0 .666 .259 r
F
.34569 .76686 m .34743 .76698 L .34557 .7658 L F
.34578 .76774 m .34708 .76714 L .34569 .76686 L F
.34708 .76714 m .34743 .76698 L .34569 .76686 L F
.34568 .76698 m .34579 .76688 L .34569 .76686 L 0 1 .423 r
F
.35629 .7689 m .34948 .76742 L .34578 .76774 L 0 .638 .244 r
F
.34948 .76742 m .34912 .76738 L .34578 .76774 L F
.34923 .76737 m .34885 .76733 L .34578 .76774 L F
.34897 .76731 m .34716 .76711 L .34578 .76774 L F
.3456 .77436 m .34708 .76714 L .34568 .76698 L 0 1 .423 r
F
.34948 .76742 m .34923 .76737 L .34912 .76738 L 0 .638 .244 r
F
.34923 .76737 m .34748 .7652 L .34709 .76711 L 0 1 .415 r
F
.34923 .76737 m .34709 .76711 L .34708 .76714 L F
.34923 .76737 m .35199 .75888 L .34748 .7652 L F
.35629 .7689 m .35419 .76797 L .34923 .76737 L 0 .638 .244 r
F
.35611 .77592 m .35419 .76797 L .34923 .76737 L 0 1 .415 r
F
.35419 .76797 m .35199 .75888 L .34928 .76721 L F
.35612 .76812 m .35612 .75963 L .35418 .7679 L F
.35419 .76797 m .35592 .76758 L .35178 .76691 L 0 .638 .244 r
F
.35419 .76797 m .35612 .76812 L .35418 .7679 L 0 1 .415 r
F
.35629 .7689 m .35612 .76828 L .35419 .76797 L 0 .638 .244 r
F
.35611 .77592 m .35612 .76828 L .35419 .76797 L 0 1 .415 r
F
.35612 .76828 m .35612 .76812 L .35419 .76797 L F
.35612 .76828 m .35612 .76827 L .35419 .76797 L 0 .638 .244 r
F
.35612 .76827 m .35592 .76758 L .35419 .76797 L F
.35419 .76797 m .34928 .76721 L .34923 .76737 L 0 1 .415 r
F
.35419 .76797 m .35416 .76796 L .34923 .76737 L 0 .638 .244 r
F
.34923 .76737 m .35178 .76691 L .34743 .76698 L F
.35416 .76796 m .35178 .76691 L .34923 .76737 L F
.34923 .76737 m .34897 .76731 L .34885 .76733 L F
.35611 .77592 m .34923 .76737 L .3456 .77436 L 0 1 .415 r
F
.34923 .76737 m .34708 .76714 L .3456 .77436 L F
.34897 .76731 m .34743 .76698 L .34716 .76711 L 0 .638 .244 r
F
.35612 .76828 m .35785 .76843 L .35592 .76758 L F
.35629 .7689 m .35758 .76851 L .35612 .76828 L F
.35758 .76851 m .35785 .76843 L .35612 .76828 L F
.35612 .7684 m .35624 .7683 L .35612 .76828 L 0 1 .415 r
F
.35624 .7683 m .35789 .76693 L .35612 .76828 L F
.3668 .7697 m .35942 .76865 L .35629 .7689 L 0 .601 .227 r
F
.35942 .76865 m .35917 .76863 L .35629 .7689 L F
.35924 .76863 m .35889 .7686 L .35629 .7689 L F
.35899 .76859 m .35764 .76849 L .35629 .7689 L F
.35611 .77592 m .35758 .76851 L .35612 .7684 L 0 1 .415 r
F
.35942 .76865 m .35924 .76863 L .35917 .76863 L 0 .601 .227 r
F
.35924 .76863 m .35789 .76693 L .35758 .76851 L 0 1 .408 r
F
.35924 .76863 m .35899 .76859 L .35889 .7686 L 0 .601 .227 r
F
.36661 .77784 m .35924 .76863 L .35611 .77592 L 0 1 .408 r
F
.35924 .76863 m .35758 .76851 L .35611 .77592 L F
.35924 .76863 m .36231 .76088 L .35789 .76693 L F
.3668 .7697 m .36438 .76906 L .35924 .76863 L 0 .601 .227 r
F
.36661 .77784 m .36438 .76906 L .35924 .76863 L 0 1 .408 r
F
.36438 .76906 m .36231 .76088 L .35931 .76847 L F
.36651 .76915 m .36644 .76181 L .36437 .76899 L F
.36438 .76906 m .36627 .76896 L .36213 .76846 L 0 .601 .227 r
F
.3668 .7697 m .36652 .76931 L .36438 .76906 L F
.36661 .77784 m .36652 .76931 L .36438 .76906 L 0 1 .408 r
F
.36652 .76931 m .36652 .76924 L .36438 .76906 L F
.36652 .76931 m .36651 .7693 L .36438 .76906 L 0 .601 .227 r
F
.36438 .76906 m .36651 .76915 L .36437 .76899 L 0 1 .408 r
F
.36652 .76924 m .36651 .76915 L .36438 .76906 L F
.36651 .7693 m .36627 .76896 L .36438 .76906 L 0 .601 .227 r
F
.36438 .76906 m .35931 .76847 L .35924 .76863 L 0 1 .408 r
F
.35924 .76863 m .36438 .76906 L .35899 .76859 L 0 .601 .227 r
F
.35899 .76859 m .36213 .76846 L .35785 .76843 L F
.36438 .76906 m .36213 .76846 L .35899 .76859 L F
.35899 .76859 m .35785 .76843 L .35764 .76849 L F
.36652 .76931 m .36827 .76949 L .36627 .76896 L F
.3668 .7697 m .36819 .7695 L .36652 .76931 L F
.36819 .7695 m .36827 .76949 L .36652 .76931 L F
.36652 .76944 m .36693 .76936 L .36652 .76931 L 0 1 .408 r
F
.36864 .76952 m .3682 .7695 L .3668 .7697 L 0 .551 .204 r
F
.36661 .77784 m .36819 .7695 L .36652 .76944 L 0 1 .408 r
F
.37755 .78031 m .36864 .76952 L .36661 .77784 L 0 1 .4 r
F
.36864 .76952 m .36828 .76907 L .3682 .7695 L F
.36864 .76952 m .3682 .7695 L .36661 .77784 L F
.36864 .76952 m .36827 .76949 L .3682 .7695 L 0 .551 .204 r
F
0 g
.36813 .76984 m
.36813 .76984 L
s
.36898 .76993 m
.36902 .76993 L
s
.36864 .76952 m .37275 .76337 L .36828 .76907 L 0 1 .4 r
F
.37777 .77012 m .37457 .76979 L .36864 .76952 L 0 .551 .204 r
F
.37755 .78031 m .37457 .76979 L .36864 .76952 L 0 1 .4 r
F
.37457 .76979 m .37275 .76337 L .36864 .76952 L F
.36864 .76952 m .37261 .76959 L .36827 .76949 L 0 .551 .204 r
F
.37457 .76979 m .37261 .76959 L .36864 .76952 L F
.37457 .76979 m .37705 .76454 L .37275 .76337 L 0 1 .4 r
F
.37777 .77012 m .37722 .77 L .37457 .76979 L 0 .551 .204 r
F
.37755 .78031 m .37722 .77 L .37457 .76979 L 0 1 .4 r
F
.37722 .77 m .37705 .76454 L .37457 .76979 L F
.37457 .76979 m .37693 .76993 L .37261 .76959 L 0 .551 .204 r
F
.37722 .77 m .37693 .76993 L .37457 .76979 L F
.37755 .78031 m .3791 .7718 L .37862 .7701 L 0 1 .4 r
F
.37722 .77 m .37862 .7701 L .37705 .76454 L F
.37777 .77012 m .37914 .77016 L .37862 .7701 L 0 .551 .204 r
F
.37777 .77012 m .37862 .7701 L .37722 .77 L F
.37755 .78031 m .37862 .7701 L .37722 .77 L 0 1 .4 r
F
.37722 .77 m .37862 .7701 L .37693 .76993 L 0 .551 .204 r
F
0 g
.37862 .77009 m
.38006 .77003 L
s
.49362 .95633 m .49369 .95849 L .49484 .95792 L 0 .646 .389 r
F
.50067 .96006 m .49484 .95792 L .49369 .95849 L 0 .524 .329 r
F
0 g
.49369 .95849 m
.49532 .95997 L
s
.49042 .95778 m
.49369 .95849 L
s
.47399 .94381 m .46757 .94499 L .47148 .94608 L 0 .891 .477 r
F
.47399 .94381 m .46479 .94305 L .46757 .94499 L F
0 g
.46757 .94499 m
.46781 .94697 L
s
.49231 1.04583 m .4851 1.04238 L .49029 1.0474 L 0 .306 .305 r
F
.49231 1.04583 m .48206 1.03803 L .4851 1.04238 L F
.49995 .90613 m .49403 .90482 L .49383 .90202 L 0 .023 .055 r
F
0 g
.49097 .90239 m
.49383 .90202 L
s
.47125 .91297 m .4669 .91137 L .47011 .91172 L 0 0 .003 r
F
.47575 .9095 m .47011 .91172 L .4669 .91137 L 0 0 0 r
F
0 g
.46617 .91005 m
.4669 .91137 L
s
.46299 .91204 m
.4669 .91137 L
s
.37776 .89836 m .3714 .90163 L .37567 .90156 L 0 1 .515 r
F
.37776 .89836 m .367 .89837 L .3714 .90163 L F
0 g
.36987 .90488 m
.3714 .90163 L
s
.37567 .90156 m
.37778 .90288 L
s
.37778 .90288 m
.3804 .90451 L
s
.47634 .79139 m .46721 .76872 L .46885 .77949 L 0 .891 .314 r
F
0 g
.46681 .76861 m
.46721 .76872 L
s
.44485 .76273 m
.44559 .76248 L
s
.44138 .76387 m
.44485 .76273 L
s
.30012 .88694 m .28765 .87644 L .28467 .88112 L 0 1 .526 r
F
.30012 .88694 m .29326 .87646 L .28765 .87644 L F
.30012 .88694 m .29861 .88097 L .29326 .87646 L F
0 g
.29713 .8916 m
.30012 .88694 L
s
.42932 .76134 m .42542 .74238 L .42086 .74568 L 0 1 .357 r
F
0 g
.4242 .7338 m
.42542 .74238 L
s
.31066 .8867 m .29861 .88097 L .30012 .88694 L 0 1 .524 r
F
0 g
.30012 .88694 m
.30439 .89129 L
s
.4527 .76679 m
.45385 .76652 L
s
.45385 .76652 m
.4539 .7668 L
s
.49448 .79425 m .48901 .76915 L .49159 .7846 L 0 .793 .294 r
F
.49147 .80129 m .49159 .7846 L .48901 .76915 L 0 .795 .298 r
F
0 g
.48604 .76124 m
.48901 .76915 L
s
.48877 .76382 m
.48901 .76915 L
s
.41131 .88077 m .4015 .86805 L .39894 .87293 L 0 .946 .393 r
F
0 g
.39465 .86743 m
.39894 .87293 L
s
.72679 .61955 m .73872 .62332 L .74291 .62336 L 0 .771 .3 r
F
0 g
.73244 .62326 m
.73245 .62322 L
s
.72679 .61955 m .73182 .62169 L .73872 .62332 L 0 .771 .3 r
F
0 g
.73767 .62308 m
.73812 .62318 L
s
.73812 .62318 m
.73872 .62332 L
s
.72765 .64386 m .7322 .63207 L .73872 .62333 L 0 .105 .069 r
F
0 g
.737 .62563 m
.73819 .62404 L
s
.73819 .62404 m
.73872 .62333 L
s
.73872 .62333 m
.73872 .62333 L
s
.73248 .62789 m
.7325 .63166 L
s
.73245 .62343 m
.73248 .62789 L
s
.4854 .50495 m .47797 .50909 L .47876 .50996 L 0 .94 .187 r
F
.4854 .50495 m .48378 .50323 L .47797 .50909 L F
.4854 .50495 m .4923 .49628 L .48378 .50323 L F
.4854 .50495 m .49891 .4913 L .4923 .49628 L F
0 g
.47994 .51126 m
.4854 .50495 L
s
.48678 .9524 m .48598 .95466 L .48758 .95407 L 0 .752 .432 r
F
.49362 .95633 m .48758 .95407 L .48598 .95466 L 0 .646 .389 r
F
0 g
.48598 .95466 m
.4872 .95625 L
s
.48246 .95386 m
.48598 .95466 L
s
.42713 .60118 m .43296 .59221 L .43578 .58373 L 0 1 .399 r
F
0 g
.43296 .59221 m
.43888 .58735 L
s
.40861 .91903 m .40155 .91908 L .39727 .91916 L 0 .599 .203 r
F
.40861 .91903 m .40641 .91903 L .40155 .91908 L F
.41894 .91868 m .40641 .91903 L .40861 .91903 L 0 0 0 r
F
0 g
.40721 .9193 m
.40861 .91903 L
s
.48831 .7631 m .48239 .77147 L .48506 .7662 L 0 .244 .091 r
F
.48869 .80895 m .48207 .77197 L .48063 .77648 L 0 .794 .301 r
F
.48869 .80895 m .48538 .77903 L .48207 .77197 L F
.48831 .7631 m .48194 .77685 L .48239 .77147 L 0 .244 .091 r
F
.48831 .7631 m .48402 .77872 L .48194 .77685 L F
0 g
.48205 .77173 m
.48207 .77197 L
s
.48831 .7631 m .48728 .7756 L .48402 .77872 L 0 .244 .091 r
F
0 g
.48506 .7662 m
.4859 .76142 L
s
.48831 .7631 m .48954 .76958 L .48728 .7756 L 0 .244 .091 r
F
.48831 .7631 m .48997 .76423 L .48954 .76958 L F
0 g
.48831 .7631 m
.48861 .76074 L
s
.48506 .7662 m
.48831 .7631 L
s
.48997 .76423 m
.49257 .75998 L
s
.58147 .65582 m
.58293 .65207 L
s
.58024 .65898 m
.58147 .65582 L
s
.58289 .65496 m
.58316 .65372 L
s
.58324 .65336 m
.58364 .65152 L
s
.71523 .80129 m
.71683 .79168 L
s
.61113 .66657 m
.61248 .67029 L
s
.61051 .66486 m
.61113 .66657 L
s
.60658 .65399 m
.61051 .66486 L
s
.53041 .76202 m .53219 .75794 L .53513 .77243 L 0 .525 .181 r
F
0 g
.53198 .74513 m
.53219 .75794 L
s
.5887 .73677 m
.58898 .84587 L
s
.33175 .88648 m .32534 .89061 L .32953 .89052 L 0 1 .52 r
F
.33175 .88648 m .3212 .88654 L .32534 .89061 L F
0 g
.32379 .8947 m
.32534 .89061 L
s
.32953 .89052 m
.33232 .89279 L
s
.33232 .89279 m
.33418 .89431 L
s
.24059 .75961 m .23053 .7531 L .22916 .75826 L 0 1 .531 r
F
.24059 .75961 m .23497 .74983 L .23053 .7531 L F
.24059 .75961 m .23952 .75064 L .23497 .74983 L F
.24059 .75961 m .24192 .75485 L .23952 .75064 L F
0 g
.23616 .76285 m
.24059 .75961 L
s
.24059 .75961 m
.24303 .76349 L
s
.41131 .88077 m .4043 .88541 L .40875 .88566 L 0 .946 .393 r
F
.41464 .8974 m .40875 .88566 L .4043 .88541 L 0 .909 .396 r
F
0 g
.40219 .89036 m
.4043 .88541 L
s
.4001 .87996 m
.4043 .88541 L
s
.50342 1.05976 m .49814 1.05485 L .4937 1.05162 L 0 .273 .233 r
F
0 g
.4937 1.05162 m
.49814 1.05485 L
s
.49029 1.0474 m
.4937 1.05162 L
s
.45384 .76688 m .44379 .77122 L .44552 .76882 L 0 .064 .025 r
F
.45384 .76688 m .44559 .7727 L .44379 .77122 L F
.45384 .76688 m .44983 .77247 L .44559 .7727 L F
.45384 .76688 m .45367 .77068 L .44983 .77247 L F
0 g
.45212 .76693 m
.4527 .76679 L
s
.45186 .76699 m
.45212 .76693 L
s
.45384 .76688 m .45539 .76829 L .45367 .77068 L 0 .064 .025 r
F
0 g
.45186 .76699 m
.45384 .76688 L
s
.45384 .76688 m
.4539 .7668 L
s
.50467 .4685 m .51366 .46556 L .52055 .46572 L 0 0 .013 r
F
0 g
.49816 .469 m
.50467 .4685 L
s
.54083 1.08681 m
.54286 1.08705 L
s
.23528 .59838 m .22464 .59682 L .22358 .60565 L 0 1 .488 r
F
0 g
.21702 .61362 m
.22358 .60565 L
s
.42294 .5204 m .4307 .51311 L .43524 .50844 L 0 .924 .184 r
F
0 g
.4307 .51311 m
.43634 .50799 L
s
.41427 .72626 m .41696 .71787 L .41612 .70944 L 0 1 .37 r
F
0 g
.41696 .71787 m
.42181 .71405 L
s
.67338 1.08308 m .66839 1.07646 L .67525 1.07803 L 0 0 0 r
F
0 g
.67361 1.07574 m
.67525 1.07803 L
s
.67338 1.08308 m .66537 1.0769 L .66839 1.07646 L 0 0 0 r
F
0 g
.66557 1.07422 m
.66839 1.07646 L
s
.49769 .78799 m .49902 .78574 L .49872 .76985 L 0 .788 .29 r
F
.27618 .68672 m .26584 .6902 L .27026 .69102 L 0 1 .527 r
F
0 g
.27026 .69102 m
.27176 .69667 L
s
.41202 .69778 m .41542 .6889 L .41545 .68018 L 0 1 .374 r
F
.43067 .94498 m .42804 .93884 L .42321 .93454 L 0 .781 .404 r
F
.38463 .84252 m .37642 .82808 L .37323 .83354 L 0 1 .404 r
F
.34062 .8187 m .33278 .82498 L .33709 .82511 L 0 1 .432 r
F
0 g
.33709 .82511 m
.34057 .83156 L
s
.34062 .8187 m .32986 .81825 L .33278 .82498 L 0 1 .432 r
F
0 g
.33205 .8233 m
.33278 .82498 L
s
.32983 .83136 m
.33278 .82498 L
s
.42597 .76953 m
.42609 .76946 L
s
.42609 .76946 m
.42616 .76943 L
s
.42616 .76943 m
.42693 .76901 L
s
.43055 .76893 m
.43101 .76892 L
s
.42693 .76901 m
.43055 .76893 L
s
.44401 .9172 m .43869 .91668 L .4425 .91661 L 0 0 0 r
F
.44401 .9172 m .43426 .91721 L .43869 .91668 L F
0 g
.43763 .91613 m
.43869 .91668 L
s
.65499 .59364 m
.65814 .60707 L
s
.65317 .58586 m
.65399 .58937 L
s
.65413 .58995 m
.65499 .59364 L
s
.65399 .58937 m
.65413 .58995 L
s
.65261 .58345 m
.65317 .58586 L
s
.65001 .57364 m
.65149 .57923 L
s
.65149 .57923 m
.65261 .58345 L
s
.35137 .81936 m .34354 .82536 L .34785 .82557 L 0 1 .424 r
F
0 g
.34785 .82557 m
.3513 .83195 L
s
.35137 .81936 m .34062 .8187 L .34354 .82536 L 0 1 .424 r
F
0 g
.34057 .83156 m
.34354 .82536 L
s
.32986 .81825 m .32201 .82476 L .32632 .82483 L 0 1 .439 r
F
0 g
.32632 .82483 m
.32983 .83136 L
s
.37633 .68417 m .36703 .68335 L .36706 .6856 L 0 1 .49 r
F
0 g
.36188 .68778 m
.36706 .6856 L
s
.37633 .68417 m .37079 .68072 L .36703 .68335 L 0 1 .49 r
F
.37633 .68417 m .3763 .6789 L .37079 .68072 L F
.37633 .68417 m .37986 .67911 L .3763 .6789 L F
.37633 .68417 m .37987 .68137 L .37986 .67911 L F
0 g
.37633 .68417 m
.37652 .68642 L
s
.37084 .68598 m
.37633 .68417 L
s
.46372 1.00328 m .45835 1.00552 L .46302 1.00906 L 0 .514 .394 r
F
0 g
.45835 1.00552 m
.45999 1.01045 L
s
.44332 .65461 m
.44474 .65277 L
s
.52149 .61338 m .51776 .61854 L .5176 .61654 L 0 .012 .035 r
F
.52149 .61338 m .52225 .61901 L .51776 .61854 L F
.52149 .61338 m .52808 .61764 L .52225 .61901 L F
.52149 .61338 m .53196 .61447 L .52808 .61764 L F
.52149 .61338 m .53131 .61163 L .53196 .61447 L F
0 g
.53131 .61163 m
.53476 .60797 L
s
.52682 .61116 m
.53131 .61163 L
s
.70674 .62106 m .71018 .61952 L .70625 .62001 L 0 .629 .231 r
F
0 g
.70673 .62106 m
.70674 .62106 L
s
.70674 .62106 m .71675 .62032 L .71018 .61952 L 0 .629 .231 r
F
0 g
.70674 .62106 m
.70674 .62106 L
s
.32986 .81825 m .3191 .81798 L .32201 .82476 L 0 1 .439 r
F
0 g
.32135 .82322 m
.32201 .82476 L
s
.31909 .83132 m
.32201 .82476 L
s
.41427 .72626 m .41612 .70944 L .41233 .70658 L 0 1 .37 r
F
0 g
.41612 .70944 m
.42129 .70518 L
s
.41612 .70944 m
.41696 .71787 L
s
.50067 .96006 m .50161 .96205 L .50229 .96154 L 0 .524 .329 r
F
.50785 .96362 m .50229 .96154 L .50161 .96205 L 0 .472 .254 r
F
0 g
.50161 .96205 m
.50362 .96341 L
s
.49862 .96138 m
.50161 .96205 L
s
.52933 .97263 m
.52959 .97268 L
s
.52815 .9724 m
.52933 .97263 L
s
.53475 .97481 m .53143 .9736 L .5296 .97268 L 0 0 0 r
F
0 g
.5296 .97268 m
.5296 .97269 L
s
.69557 .65797 m .71173 .63495 L .70772 .65152 L 0 .216 .109 r
F
0 g
.71094 .62321 m
.71173 .63495 L
s
.39627 .84414 m .38827 .84868 L .39292 .84924 L 0 1 .395 r
F
.39627 .84414 m .38464 .84252 L .38827 .84868 L F
.39757 .86227 m .39292 .84924 L .38827 .84868 L 0 1 .399 r
F
0 g
.38535 .85384 m
.38827 .84868 L
s
.27993 .93561 m .26693 .93433 L .26591 .935 L 0 .644 .227 r
F
.27993 .93561 m .27141 .93442 L .26693 .93433 L F
.27993 .93561 m .27699 .93497 L .27141 .93442 L F
.29087 .93529 m .27699 .93497 L .27993 .93561 L 0 .595 .21 r
F
0 g
.27888 .93628 m
.27993 .93561 L
s
.27993 .93561 m
.28537 .93591 L
s
.38463 .84252 m .38091 .82869 L .37642 .82808 L 0 1 .404 r
F
.38463 .84252 m .38443 .83488 L .38091 .82869 L F
0 g
.38144 .84797 m
.38463 .84252 L
s
.39627 .84414 m .38443 .83488 L .38464 .84252 L 0 1 .395 r
F
0 g
.38464 .84252 m
.38827 .84868 L
s
.3191 .81798 m .31124 .82468 L .31555 .8247 L 0 1 .446 r
F
0 g
.31555 .8247 m
.31909 .83132 L
s
.39261 .9189 m .38688 .91954 L .39098 .91936 L 0 .651 .233 r
F
.39261 .9189 m .38222 .91913 L .38688 .91954 L F
0 g
.38579 .92008 m
.38688 .91954 L
s
.39098 .91936 m
.39588 .91943 L
s
.41745 .91873 m
.41751 .91878 L
s
.41755 .91873 m
.41765 .91877 L
s
.41768 .91878 m
.42142 .92038 L
s
.41765 .91877 m
.41768 .91878 L
s
.79101 .70729 m .79694 .69529 L .79246 .69602 L 0 1 .432 r
F
.79101 .70729 m .80227 .70536 L .79694 .69529 L F
.41202 .69778 m .41545 .68018 L .41209 .67742 L 0 1 .374 r
F
0 g
.41542 .6889 m
.41545 .68018 L
s
.36211 .82027 m .3543 .82596 L .3586 .82627 L 0 1 .417 r
F
0 g
.3586 .82627 m
.36203 .83258 L
s
.36211 .82027 m .35137 .81936 L .3543 .82596 L 0 1 .417 r
F
0 g
.3513 .83195 m
.3543 .82596 L
s
.78085 .61878 m .79602 .61514 L .79155 .61896 L 0 0 0 r
F
0 g
.79602 .61514 m
.79603 .61164 L
s
.79602 .61514 m
.80266 .61281 L
s
.39281 .90814 m .38633 .90153 L .38207 .90151 L 0 1 .517 r
F
.39281 .90814 m .39094 .90438 L .38633 .90153 L F
0 g
.39114 .91113 m
.39281 .90814 L
s
.40363 .90805 m .39094 .90438 L .39281 .90814 L 0 1 .513 r
F
0 g
.39281 .90814 m
.39742 .91088 L
s
.42713 .60118 m .43578 .58373 L .43371 .58139 L 0 1 .399 r
F
0 g
.43578 .58373 m
.44196 .57881 L
s
.43296 .59221 m
.43578 .58373 L
s
.3191 .81798 m .30833 .81783 L .31124 .82468 L 0 1 .446 r
F
0 g
.30835 .83139 m
.31124 .82468 L
s
.31242 .54119 m
.32019 .53335 L
s
.43782 .96008 m .43486 .95408 L .43 .95003 L 0 .729 .405 r
F
.34596 .9169 m .34029 .91846 L .34437 .91831 L 0 1 .382 r
F
.34596 .9169 m .33568 .91708 L .34029 .91846 L F
0 g
.33935 .91996 m
.34029 .91846 L
s
.34437 .91831 m
.3494 .91936 L
s
.43419 .92309 m .42347 .91844 L .42215 .92069 L 0 1 .511 r
F
0 g
.42142 .92038 m
.42215 .92069 L
s
.43987 .9296 m .4375 .92704 L .43286 .92533 L 0 1 .513 r
F
.44891 .92902 m .43987 .9296 L .44429 .9313 L 0 1 .505 r
F
.44891 .92902 m .4375 .92704 L .43987 .9296 L F
0 g
.439 .93188 m
.43987 .9296 L
s
.41331 .67033 m
.41345 .67029 L
s
.41345 .67029 m
.41514 .66987 L
s
.51051 .89567 m .50906 .89709 L .50747 .8958 L 0 0 .053 r
F
0 g
.41518 .66977 m
.41518 .66976 L
s
.41514 .66987 m
.41518 .66977 L
s
.81295 .88968 m .81781 .8975 L .82256 .89387 L 0 1 .502 r
F
.81295 .88968 m .8133 .89751 L .81781 .8975 L F
0 g
.81781 .8975 m
.81885 .9011 L
s
.30833 .81783 m .30046 .8247 L .30478 .82468 L 0 1 .452 r
F
0 g
.30478 .82468 m
.30835 .83139 L
s
.48207 .77197 m
.48231 .77247 L
s
.47399 .94381 m .46484 .94129 L .46479 .94305 L 0 .891 .477 r
F
0 g
.46058 .94203 m
.46479 .94305 L
s
.30833 .81783 m .29755 .81778 L .30046 .8247 L 0 1 .452 r
F
0 g
.2976 .83155 m
.30046 .8247 L
s
.41883 .75352 m .41935 .73763 L .41529 .73473 L 0 1 .366 r
F
.41883 .75352 m .42086 .74568 L .41935 .73763 L F
0 g
.41935 .73763 m
.4242 .7338 L
s
.33917 .68775 m .32937 .68528 L .32961 .68883 L 0 1 .542 r
F
0 g
.32449 .69165 m
.32961 .68883 L
s
.48021 .94823 m .47855 .95053 L .48059 .94996 L 0 .832 .46 r
F
.48678 .9524 m .48059 .94996 L .47855 .95053 L 0 .752 .432 r
F
0 g
.47855 .95053 m
.47936 .9522 L
s
.47482 .94961 m
.47855 .95053 L
s
.39757 .86227 m .3969 .85507 L .39292 .84924 L 0 1 .399 r
F
.40906 .86376 m .39757 .86227 L .4015 .86805 L 0 .981 .389 r
F
.40906 .86376 m .3969 .85507 L .39757 .86227 L F
0 g
.39465 .86743 m
.39757 .86227 L
s
.37333 .82157 m .3652 .82684 L .36969 .82729 L 0 1 .409 r
F
0 g
.36969 .82729 m
.37323 .83354 L
s
.37333 .82157 m .36212 .82027 L .3652 .82684 L 0 1 .409 r
F
0 g
.36203 .83258 m
.3652 .82684 L
s
.41593 .66117 m .40696 .66349 L .41023 .66615 L 0 1 .378 r
F
.41593 .66117 m .408 .65436 L .40696 .66349 L F
.41593 .66117 m .41267 .64486 L .408 .65436 L F
.41593 .66117 m .41836 .63989 L .41267 .64486 L F
0 g
.41514 .67028 m
.41518 .66976 L
s
.41518 .66976 m
.41518 .66975 L
s
.41518 .66975 m
.41519 .66968 L
s
.41519 .66968 m
.41593 .66117 L
s
.42932 .76134 m .42086 .74568 L .41883 .75352 L 0 1 .357 r
F
0 g
.42086 .74568 m
.42542 .74238 L
s
.41935 .73763 m
.42086 .74568 L
s
.28877 .91574 m
.28877 .91574 L
s
.26292 .91076 m .25657 .91387 L .26103 .91377 L 0 1 .508 r
F
.26292 .91076 m .25167 .9108 L .25657 .91387 L F
0 g
.25557 .917 m
.25657 .91387 L
s
.26103 .91377 m
.26663 .91653 L
s
.43384 .66001 m .42545 .66273 L .42842 .66241 L 0 1 .312 r
F
.43384 .66001 m .42669 .66083 L .42545 .66273 L F
0 g
.42773 .66436 m
.42842 .66241 L
s
.43384 .66001 m .43133 .65798 L .42669 .66083 L 0 1 .312 r
F
.43384 .66001 m .43676 .65556 L .43133 .65798 L F
.43384 .66001 m .43935 .6552 L .43676 .65556 L F
.43384 .66001 m .4381 .65711 L .43935 .6552 L F
0 g
.4381 .65711 m
.44332 .65461 L
s
.4381 .65711 m
.4381 .65711 L
s
.42842 .66241 m
.43384 .66001 L
s
.41345 .67029 m
.41513 .67028 L
s
.41175 .6703 m
.41345 .67029 L
s
.56471 .61442 m .57006 .61521 L .57564 .62047 L 0 .333 .079 r
F
0 g
.57006 .61521 m
.5725 .61001 L
s
.29755 .81778 m .28732 .82484 L .29298 .82477 L 0 1 .458 r
F
0 g
.29298 .82477 m
.2976 .83155 L
s
.52232 .9705 m .52045 .96966 L .52381 .97086 L 0 .31 .193 r
F
.52232 .9705 m .51773 .96857 L .52045 .96966 L F
0 g
.51813 .969 m
.52008 .96956 L
s
.81026 .79158 m .81938 .79004 L .82249 .7923 L 0 0 0 r
F
0 g
.81938 .79004 m
.81974 .7903 L
s
.81938 .79004 m
.82235 .79104 L
s
.40169 .91076 m
.40445 .91215 L
s
.41898 .91616 m .40811 .91069 L .40651 .91318 L 0 1 .513 r
F
0 g
.40445 .91215 m
.40651 .91318 L
s
.41901 .91365 m .41714 .90719 L .41253 .90235 L 0 .869 .399 r
F
.20274 .87117 m .19559 .87727 L .20015 .8772 L 0 1 .533 r
F
.20274 .87117 m .1913 .87116 L .19559 .87727 L F
0 g
.19406 .88343 m
.19559 .87727 L
s
.20015 .8772 m
.20536 .88308 L
s
.42294 .5204 m .41337 .52761 L .41551 .52661 L 0 .924 .184 r
F
0 g
.41725 .52638 m
.41872 .52494 L
s
.42294 .5204 m .4179 .52294 L .41337 .52761 L 0 .924 .184 r
F
.42294 .5204 m .42609 .51572 L .4179 .52294 L F
.42294 .5204 m .43352 .5095 L .42609 .51572 L F
.42294 .5204 m .43524 .50844 L .43352 .5095 L F
0 g
.4307 .51311 m
.43524 .50844 L
s
.41872 .52494 m
.42294 .5204 L
s
.43524 .50844 m
.44259 .50273 L
s
.42932 .76134 m .4205 .76165 L .42477 .76465 L 0 1 .357 r
F
.42932 .76134 m .41883 .75352 L .4205 .76165 L F
0 g
.42477 .76465 m
.42932 .76134 L
s
.42932 .76134 m
.43101 .76895 L
s
.43101 .76895 m
.43103 .76903 L
s
.43103 .76903 m
.43103 .76903 L
s
.29755 .81778 m .28339 .81782 L .28732 .82484 L 0 1 .458 r
F
0 g
.2835 .83187 m
.28732 .82484 L
s
.7628 .89971 m .77259 .89757 L .76805 .89757 L 0 1 .445 r
F
.75156 .89937 m .7628 .89971 L .76126 .89757 L 0 1 .412 r
F
0 g
.65272 .58193 m
.65273 .58197 L
s
.65001 .57364 m
.65272 .58193 L
s
.65273 .58197 m
.65661 .59383 L
s
.65661 .59383 m
.6574 .59623 L
s
.75452 .66294 m
.75684 .66727 L
s
.75426 .65076 m
.75452 .66294 L
s
.43426 .91721 m .42754 .91839 L .42347 .91844 L 0 0 0 r
F
.43426 .91721 m .43217 .91786 L .42754 .91839 L F
.44401 .9172 m .43217 .91786 L .43426 .91721 L F
0 g
.43296 .91695 m
.43426 .91721 L
s
.43426 .91721 m
.43869 .91668 L
s
.52265 .78902 m .52406 .79324 L .52627 .7704 L 0 .703 .26 r
F
0 g
.5225 .77232 m
.52265 .78902 L
s
.22916 .75826 m .21913 .75139 L .21772 .75693 L 0 1 .534 r
F
.22916 .75826 m .2236 .74782 L .21913 .75139 L F
.22916 .75826 m .22815 .74862 L .2236 .74782 L F
.22916 .75826 m .23053 .7531 L .22815 .74862 L F
0 g
.2247 .7618 m
.22916 .75826 L
s
.22916 .75826 m
.23157 .76243 L
s
.23528 .59838 m .23039 .58558 L .22464 .59682 L 0 1 .488 r
F
0 g
.22358 .60565 m
.22464 .59682 L
s
.23528 .59838 m .2378 .57771 L .23039 .58558 L 0 1 .488 r
F
.23528 .59838 m .24192 .57848 L .2378 .57771 L F
.23528 .59838 m .24083 .58735 L .24192 .57848 L F
0 g
.23434 .60708 m
.23528 .59838 L
s
.22789 .60621 m
.23528 .59838 L
s
.80813 .63489 m
.81423 .63962 L
s
.76058 .67178 m
.76072 .66888 L
s
.76097 .66353 m
.76104 .66207 L
s
.45443 .9892 m .45283 .99505 L .45527 .99416 L 0 .599 .402 r
F
.46372 1.00328 m .45527 .99416 L .45283 .99505 L 0 .514 .394 r
F
0 g
.45283 .99505 m
.45415 .99992 L
s
.44805 .99138 m
.45283 .99505 L
s
.31242 .54119 m
.3149 .53124 L
s
.41427 .72626 m .40514 .72822 L .40921 .7307 L 0 1 .37 r
F
.41427 .72626 m .40431 .71978 L .40514 .72822 L F
.41427 .72626 m .40726 .71101 L .40431 .71978 L F
.41427 .72626 m .41233 .70658 L .40726 .71101 L F
.43709 .57321 m .44366 .56465 L .44734 .55683 L 0 1 .404 r
F
0 g
.44366 .56465 m
.44983 .55974 L
s
.81295 .88968 m .81121 .89417 L .8133 .89751 L 0 1 .502 r
F
0 g
.80766 .90084 m
.8133 .89751 L
s
.41836 .63989 m
.41998 .63077 L
s
.41267 .64486 m
.41836 .63989 L
s
.6823 .6212 m .69488 .62158 L .69969 .6209 L 0 .766 .25 r
F
.6823 .6212 m .68743 .62171 L .69488 .62158 L F
0 g
.6945 .62212 m
.69488 .62158 L
s
.68743 .62171 m
.69488 .62158 L
s
.39627 .84414 m .38779 .82977 L .38443 .83488 L 0 1 .395 r
F
.49995 .90613 m .49815 .90095 L .49975 .90333 L 0 .023 .055 r
F
.50339 .90271 m .49975 .90333 L .49815 .90095 L 0 .003 .054 r
F
0 g
.49815 .90095 m
.49833 .89788 L
s
.49561 .9004 m
.49815 .90095 L
s
.40906 .86376 m .4015 .86805 L .40607 .86856 L 0 .981 .389 r
F
.41131 .88077 m .40607 .86856 L .4015 .86805 L 0 .946 .393 r
F
0 g
.39894 .87293 m
.4015 .86805 L
s
.39757 .86227 m
.4015 .86805 L
s
.44577 .97481 m .4425 .96896 L .43766 .96512 L 0 .67 .405 r
F
.41998 .63077 m .41125 .63306 L .41406 .63573 L 0 1 .387 r
F
.41998 .63077 m .41322 .62411 L .41125 .63306 L F
.41998 .63077 m .41867 .61485 L .41322 .62411 L F
.41998 .63077 m .42459 .6099 L .41867 .61485 L F
0 g
.65011 .56821 m
.65084 .57044 L
s
.6479 .56147 m
.65011 .56821 L
s
.64663 .5576 m
.6479 .56147 L
s
.64558 .5544 m
.64663 .5576 L
s
.64329 .5474 m
.64334 .54756 L
s
.64365 .54852 m
.64367 .54856 L
s
.64367 .54856 m
.64414 .55 L
s
.64181 .54481 m
.64329 .5474 L
s
.64014 .54188 m
.64181 .54481 L
s
.27618 .68672 m .26523 .68432 L .26584 .6902 L 0 1 .527 r
F
0 g
.26062 .6949 m
.26584 .6902 L
s
.21798 .91114 m .20577 .90199 L .20424 .90594 L 0 1 .525 r
F
.21798 .91114 m .21034 .90213 L .20577 .90199 L F
.21798 .91114 m .21557 .90606 L .21034 .90213 L F
.2292 .911 m .21557 .90606 L .21798 .91114 L 0 1 .522 r
F
0 g
.21643 .91505 m
.21798 .91114 L
s
.21798 .91114 m
.22311 .91483 L
s
.40906 .86376 m .39988 .85027 L .3969 .85507 L 0 .981 .389 r
F
0 g
.39292 .84924 m
.3969 .85507 L
s
.28712 .68915 m .27967 .68014 L .27618 .68672 L 0 1 .529 r
F
.28712 .68915 m .28549 .67617 L .27967 .68014 L F
.28712 .68915 m .28976 .67747 L .28549 .67617 L F
.28712 .68915 m .29045 .68304 L .28976 .67747 L F
0 g
.28131 .69309 m
.28712 .68915 L
s
.28712 .68915 m
.28794 .69432 L
s
.31199 .76564 m
.3148 .76482 L
s
.3148 .76482 m
.31597 .76448 L
s
.38454 .82327 m .37642 .82808 L .38091 .82869 L 0 1 .4 r
F
0 g
.38091 .82869 m
.38443 .83488 L
s
.38454 .82327 m .37333 .82157 L .37642 .82808 L 0 1 .4 r
F
0 g
.37323 .83354 m
.37642 .82808 L
s
.46079 .94002 m .45822 .93793 L .45389 .93671 L 0 1 .501 r
F
0 g
.28634 .56685 m
.29377 .55982 L
s
.81354 .70362 m .82757 .71602 L .82484 .70203 L 0 1 .449 r
F
0 g
.82619 .727 m
.82757 .71602 L
s
.45025 .78231 m .4398 .77077 L .44179 .77926 L 0 1 .338 r
F
.41883 .75352 m .41529 .73473 L .41056 .73873 L 0 1 .366 r
F
0 g
.41427 .72626 m
.41529 .73473 L
s
.48059 1.03268 m .47599 1.02736 L .47136 1.02404 L 0 .372 .367 r
F
.77144 .67237 m .78126 .698 L .78574 .69718 L 0 1 .418 r
F
.77144 .67237 m .77514 .68737 L .78126 .698 L F
0 g
.77978 .70947 m
.78126 .698 L
s
.41203 .69778 m
.41233 .70658 L
s
.41202 .69778 m .40307 .7002 L .40673 .70262 L 0 1 .374 r
F
.41202 .69778 m .4031 .69147 L .40307 .7002 L F
.41202 .69778 m .40679 .68225 L .4031 .69147 L F
.41202 .69778 m .41209 .67742 L .40679 .68225 L F
.48059 1.03268 m .48206 1.03803 L .48319 1.03726 L 0 .372 .367 r
F
.49231 1.04583 m .48319 1.03726 L .48206 1.03803 L 0 .306 .305 r
F
0 g
.48206 1.03803 m
.4851 1.04238 L
s
.47743 1.03471 m
.48206 1.03803 L
s
.31066 .8867 m .30069 .87652 L .29861 .88097 L 0 1 .524 r
F
.31066 .8867 m .30496 .87658 L .30069 .87652 L F
.31066 .8867 m .30924 .88094 L .30496 .87658 L F
.3212 .88654 m .30924 .88094 L .31066 .8867 L 0 1 .522 r
F
0 g
.30858 .89113 m
.31066 .8867 L
s
.31066 .8867 m
.31486 .89091 L
s
.43103 .76903 m
.43103 .76903 L
s
.40726 .71101 m
.41233 .70658 L
s
.367 .89837 m .35682 .89045 L .35498 .8939 L 0 1 .518 r
F
.367 .89837 m .36102 .89053 L .35682 .89045 L F
.367 .89837 m .36539 .89393 L .36102 .89053 L F
0 g
.36515 .9018 m
.367 .89837 L
s
.37776 .89836 m .36539 .89393 L .367 .89837 L 0 1 .515 r
F
0 g
.367 .89837 m
.3714 .90163 L
s
.50509 .48615 m .49811 .49044 L .49843 .4908 L 0 0 0 r
F
.50509 .48615 m .50464 .48571 L .49811 .49044 L F
.50509 .48615 m .51366 .47978 L .50464 .48571 L F
.50509 .48615 m .52029 .47514 L .51366 .47978 L F
0 g
.49891 .4913 m
.50509 .48615 L
s
.44891 .92902 m .44429 .9313 L .44781 .93101 L 0 1 .505 r
F
.45455 .93469 m .44781 .93101 L .44429 .9313 L F
0 g
.44364 .93332 m
.44429 .9313 L
s
.43987 .9296 m
.44429 .9313 L
s
.50785 .96362 m .50965 .96539 L .50986 .96498 L 0 .472 .254 r
F
.51509 .96708 m .50986 .96498 L .50965 .96539 L 0 .403 .224 r
F
0 g
.50965 .96539 m
.51203 .96661 L
s
.50698 .96471 m
.50965 .96539 L
s
.51381 .90618 m .51412 .8921 L .51501 .89537 L 0 .098 .08 r
F
.51381 .90618 m .51267 .89353 L .51412 .8921 L F
0 g
.51412 .8921 m
.51541 .88788 L
s
.53139 1.08307 m .52564 1.0786 L .52151 1.07514 L 0 0 0 r
F
.50342 1.05976 m .50704 1.06392 L .50724 1.06365 L 0 .273 .233 r
F
0 g
.50704 1.06392 m
.51122 1.06745 L
s
.5026 1.06067 m
.50704 1.06392 L
s
.41883 .75352 m .40983 .75503 L .4141 .75753 L 0 1 .366 r
F
.41883 .75352 m .40831 .74697 L .40983 .75503 L F
.41883 .75352 m .41056 .73873 L .40831 .74697 L F
0 g
.4141 .75753 m
.41883 .75352 L
s
.41883 .75352 m
.4205 .76165 L
s
.41464 .8974 m .41318 .8908 L .40875 .88566 L 0 .909 .396 r
F
.35137 .81936 m .34103 .81002 L .34062 .8187 L 0 1 .424 r
F
.35137 .81936 m .34455 .8038 L .34103 .81002 L F
.35137 .81936 m .34884 .80418 L .34455 .8038 L F
.35137 .81936 m .35177 .81086 L .34884 .80418 L F
.36211 .82027 m .35177 .81086 L .35137 .81936 L 0 1 .417 r
F
0 g
.34785 .82557 m
.35137 .81936 L
s
.35137 .81936 m
.3543 .82596 L
s
.77512 .78028 m .78733 .781 L .78685 .78495 L 0 .145 0 r
F
0 g
.78733 .781 m
.79122 .77961 L
s
.78416 .77621 m
.78733 .781 L
s
.36211 .82027 m .35528 .80485 L .35177 .81086 L 0 1 .417 r
F
.36211 .82027 m .35957 .80536 L .35528 .80485 L F
.36211 .82027 m .3625 .81197 L .35957 .80536 L F
0 g
.3586 .82627 m
.36211 .82027 L
s
.37333 .82157 m .3625 .81197 L .36212 .82027 L 0 1 .409 r
F
0 g
.36212 .82027 m
.3652 .82684 L
s
.27025 .57505 m .25836 .58174 L .26245 .58261 L 0 1 .475 r
F
0 g
.26163 .5912 m
.26245 .58261 L
s
.40997 .67172 m
.41044 .67161 L
s
.40984 .67137 m .41023 .66615 L .40696 .66349 L 0 1 .379 r
F
.41053 .67159 m .41043 .6712 L .40984 .67137 L 0 1 .424 r
F
.4105 .67318 m .41043 .6712 L .40984 .67137 L 0 1 .379 r
F
.41043 .6712 m .41023 .66615 L .40984 .67137 L F
.40984 .67137 m .41016 .67021 L .40684 .67042 L 0 1 .424 r
F
.41043 .6712 m .41016 .67021 L .40984 .67137 L F
.41053 .67159 m .41174 .67071 L .41016 .67021 L F
0 g
.41174 .67071 m
.41331 .67033 L
s
.3254 .91737 m .31416 .91329 L .31278 .91519 L 0 1 .439 r
F
.3254 .91737 m .31836 .91333 L .31416 .91329 L F
.3254 .91737 m .32318 .91508 L .31836 .91333 L F
.33568 .91708 m .32318 .91508 L .3254 .91737 L 0 1 .414 r
F
0 g
.32401 .91926 m
.3254 .91737 L
s
.3254 .91737 m
.33011 .91893 L
s
.49231 1.04583 m .49029 1.0474 L .49468 1.05075 L 0 .306 .305 r
F
.34062 .8187 m .33028 .80941 L .32986 .81825 L 0 1 .432 r
F
.34062 .8187 m .33381 .80299 L .33028 .80941 L F
.34062 .8187 m .33811 .80329 L .33381 .80299 L F
.34062 .8187 m .34103 .81002 L .33811 .80329 L F
0 g
.33709 .82511 m
.34062 .8187 L
s
.34062 .8187 m
.34354 .82536 L
s
.69194 1.07756 m .703 1.07687 L .6995 1.07794 L 0 0 0 r
F
.68142 1.08056 m .69193 1.07756 L .69363 1.07986 L F
0 g
.69193 1.07756 m
.69194 1.07757 L
s
.69194 1.07756 m
.69194 1.07756 L
s
.40427 .53984 m .41161 .53185 L .41551 .52661 L 0 1 .212 r
F
0 g
.41161 .53185 m
.41725 .52638 L
s
.21419 .87118 m .20698 .8771 L .21154 .87704 L 0 1 .533 r
F
.21419 .87118 m .20274 .87117 L .20698 .8771 L F
0 g
.20536 .88308 m
.20698 .8771 L
s
.21154 .87704 m
.21667 .88274 L
s
.53885 1.08894 m .5389 1.08557 L .54083 1.08682 L 0 .136 0 r
F
.53885 1.08894 m .53694 1.08518 L .5389 1.08557 L F
0 g
.5389 1.08557 m
.5389 1.08557 L
s
.37333 .82157 m .36614 .80624 L .3625 .81197 L 0 1 .409 r
F
.37333 .82157 m .37062 .80691 L .36614 .80624 L F
.37333 .82157 m .3737 .81348 L .37062 .80691 L F
.38454 .82327 m .3737 .81348 L .37333 .82157 L 0 1 .4 r
F
0 g
.36969 .82729 m
.37333 .82157 L
s
.37333 .82157 m
.37642 .82808 L
s
.46069 .79661 m .45161 .77602 L .45025 .78231 L 0 .938 .329 r
F
.46069 .79661 m .45564 .77598 L .45161 .77602 L F
0 g
.45068 .77207 m
.45161 .77602 L
s
.45161 .77602 m
.45508 .77598 L
s
.50467 .4685 m .49716 .47489 L .4976 .47249 L 0 0 .013 r
F
0 g
.49669 .47004 m
.49816 .469 L
s
.49122 .47387 m
.49669 .47004 L
s
.50467 .4685 m .50406 .47507 L .49716 .47489 L 0 0 .013 r
F
.50467 .4685 m .51369 .4729 L .50406 .47507 L F
.50467 .4685 m .52075 .46889 L .51369 .4729 L F
.50467 .4685 m .52055 .46572 L .52075 .46889 L F
0 g
.52055 .46572 m
.5271 .46234 L
s
.51366 .46556 m
.52055 .46572 L
s
.43709 .57321 m .44734 .55683 L .44568 .55495 L 0 1 .404 r
F
0 g
.44734 .55683 m
.45372 .55179 L
s
.44366 .56465 m
.44734 .55683 L
s
.42477 .76465 m
.42604 .76927 L
s
.42604 .76927 m
.42609 .76946 L
s
.4105 .67318 m
.41209 .67741 L
s
.41128 .67816 m
.41209 .67742 L
s
.47575 .9095 m .4739 .91092 L .47011 .91172 L 0 0 0 r
F
.48315 .91178 m .47575 .9095 L .47927 .90912 L 0 0 .033 r
F
.48315 .91178 m .4739 .91092 L .47575 .9095 L F
0 g
.475 .90818 m
.47575 .9095 L
s
.20577 .93179 m .19995 .93394 L .20441 .93392 L 0 .906 .347 r
F
.20577 .93179 m .19455 .93159 L .19995 .93394 L F
0 g
.19967 .93623 m
.19995 .93394 L
s
.20441 .93392 m
.21068 .93593 L
s
.42713 .60118 m .41845 .60336 L .42091 .60596 L 0 1 .399 r
F
.42713 .60118 m .42128 .59487 L .41845 .60336 L F
.42713 .60118 m .4275 .58616 L .42128 .59487 L F
.42713 .60118 m .43371 .58139 L .4275 .58616 L F
0 g
.42459 .6099 m
.42713 .60118 L
s
.79688 .63209 m
.79711 .63458 L
s
.46817 .93913 m .46079 .94002 L .46484 .94129 L 0 .935 .488 r
F
.46817 .93913 m .45822 .93793 L .46079 .94002 L F
0 g
.46058 .94203 m
.46079 .94002 L
s
.46369 .7827 m .45564 .77598 L .45966 .78221 L 0 .96 .326 r
F
.46069 .79661 m .45966 .78221 L .45564 .77598 L 0 .938 .329 r
F
0 g
.45508 .77598 m
.45564 .77598 L
s
.45443 .76962 m
.45564 .77598 L
s
.52232 .9705 m .52381 .97086 L .52578 .97168 L 0 .31 .193 r
F
0 g
.52381 .97086 m
.52556 .97159 L
s
.52381 .97086 m
.52574 .97146 L
s
.70707 1.08098 m .703 1.07687 L .71019 1.07643 L 0 0 0 r
F
.70707 1.08098 m .6995 1.07794 L .703 1.07687 L F
0 g
.70046 1.07542 m
.703 1.07687 L
s
.48869 .80895 m .48063 .77648 L .48204 .78928 L 0 .794 .301 r
F
0 g
.47785 .77319 m
.48063 .77648 L
s
.47352 .80291 m .46504 .77711 L .46369 .7827 L 0 .876 .317 r
F
.47352 .80291 m .46885 .77949 L .46504 .77711 L F
0 g
.46387 .77102 m
.46504 .77711 L
s
.46504 .77711 m
.46872 .7794 L
s
.47353 1.01709 m .46481 1.01382 L .46923 1.01927 L 0 .412 .377 r
F
.47353 1.01709 m .46302 1.00906 L .46481 1.01382 L F
0 g
.45999 1.01045 m
.46481 1.01382 L
s
.69097 .74819 m
.69097 .74819 L
s
.47634 .79139 m .47758 .78682 L .47593 .77604 L 0 .891 .314 r
F
0 g
.47593 .77604 m
.47593 .77605 L
s
.63629 .62843 m .6381 .6271 L .63501 .62746 L 0 1 .367 r
F
.63629 .62843 m .64421 .62719 L .6381 .6271 L F
.63629 .62843 m .64927 .62767 L .64421 .62719 L F
0 g
.64927 .62767 m
.6553 .62731 L
s
.64927 .62767 m
.65053 .62864 L
s
.34231 .88654 m .33583 .89042 L .34002 .89038 L 0 1 .518 r
F
.34231 .88654 m .33175 .88648 L .33583 .89042 L F
0 g
.33418 .89431 m
.33583 .89042 L
s
.34002 .89038 m
.34239 .89228 L
s
.34239 .89228 m
.34457 .89403 L
s
.47399 .94381 m .47148 .94608 L .47393 .94557 L 0 .891 .477 r
F
.48021 .94823 m .47393 .94557 L .47148 .94608 L 0 .832 .46 r
F
0 g
.47148 .94608 m
.47186 .9478 L
s
.46757 .94499 m
.47148 .94608 L
s
.39627 .84414 m .39246 .83061 L .38779 .82977 L 0 1 .395 r
F
.39627 .84414 m .3961 .83677 L .39246 .83061 L F
.4079 .84636 m .39627 .84414 L .39988 .85027 L 0 1 .386 r
F
.4079 .84636 m .3961 .83677 L .39627 .84414 L F
0 g
.39292 .84924 m
.39627 .84414 L
s
.43411 .92898 m .42211 .92321 L .42437 .9295 L 0 .775 .389 r
F
.43411 .92898 m .42347 .91844 L .42211 .92321 L F
0 g
.41751 .91878 m
.42211 .92321 L
s
.42211 .92321 m
.42344 .91854 L
s
.42215 .92069 m
.42341 .91855 L
s
.32986 .81825 m .31952 .80899 L .3191 .81798 L 0 1 .439 r
F
.32986 .81825 m .32306 .8024 L .31952 .80899 L F
.32986 .81825 m .32736 .80261 L .32306 .8024 L F
.32986 .81825 m .33028 .80941 L .32736 .80261 L F
0 g
.32632 .82483 m
.32986 .81825 L
s
.32986 .81825 m
.33205 .8233 L
s
.43411 .92898 m .42437 .9295 L .42893 .93402 L 0 .775 .389 r
F
0 g
.42321 .93454 m
.42437 .9295 L
s
.74978 1.06669 m .74402 1.06828 L .74252 1.06852 L 0 0 0 r
F
0 g
.73469 1.07015 m
.74252 1.06852 L
s
.79339 1.04528 m .788 1.04959 L .78695 1.05185 L 0 1 .27 r
F
0 g
.77908 1.05533 m
.78695 1.05185 L
s
.43639 .7878 m .43766 .78102 L .43541 .77322 L 0 1 .352 r
F
0 g
.43541 .77322 m
.4398 .77077 L
s
.21772 .75693 m .20771 .74973 L .20628 .75564 L 0 1 .537 r
F
.21772 .75693 m .21221 .74586 L .20771 .74973 L F
.21772 .75693 m .21677 .74664 L .21221 .74586 L F
.21772 .75693 m .21913 .75139 L .21677 .74664 L F
0 g
.21323 .76077 m
.21772 .75693 L
s
.21772 .75693 m
.22011 .76138 L
s
.41609 .76518 m
.4205 .76165 L
s
.8015 .89039 m .80652 .89752 L .81121 .89417 L 0 1 .49 r
F
.8015 .89039 m .802 .89753 L .80652 .89752 L F
0 g
.80652 .89752 m
.80766 .90084 L
s
.42936 .91369 m .41901 .91365 L .42347 .91844 L 0 .82 .387 r
F
.42936 .91369 m .41714 .90719 L .41901 .91365 L F
0 g
.4183 .91582 m
.41901 .91365 L
s
.44891 .92902 m .43859 .92505 L .4375 .92704 L 0 1 .505 r
F
0 g
.43286 .92533 m
.4375 .92704 L
s
.39621 .82559 m .38779 .82977 L .39246 .83061 L 0 1 .391 r
F
.39621 .82559 m .38454 .82327 L .38779 .82977 L F
0 g
.38443 .83488 m
.38779 .82977 L
s
.61383 .69782 m .62326 .72188 L .61758 .69495 L 0 .408 .253 r
F
.61383 .69782 m .62707 .74314 L .62326 .72188 L F
0 g
.6246 .72778 m
.62467 .72975 L
s
.62406 .72541 m
.62407 .72641 L
s
.61383 .69782 m .6271 .7609 L .62707 .74314 L 0 .408 .253 r
F
.61383 .69782 m .62332 .76325 L .6271 .7609 L F
0 g
.6271 .74479 m
.62748 .75102 L
s
.62588 .76166 m
.62605 .76637 L
s
.62615 .72843 m
.62645 .73159 L
s
.62579 .72467 m
.62615 .72843 L
s
.6266 .73663 m
.62696 .74251 L
s
.62707 .7444 m
.6271 .74479 L
s
.61383 .69782 m .61762 .73607 L .62332 .76325 L 0 .408 .253 r
F
0 g
.61383 .69777 m
.61383 .69782 L
s
.40427 .53984 m .39431 .54797 L .39685 .54675 L 0 1 .212 r
F
0 g
.39907 .54644 m
.40067 .54475 L
s
.40427 .53984 m .3982 .54274 L .39431 .54797 L 0 1 .212 r
F
.40427 .53984 m .40595 .53452 L .3982 .54274 L F
.40427 .53984 m .41337 .52761 L .40595 .53452 L F
.40427 .53984 m .41551 .52661 L .41337 .52761 L F
0 g
.41161 .53185 m
.41551 .52661 L
s
.40032 .54352 m
.40427 .53984 L
s
.40067 .54475 m
.40427 .53984 L
s
.41551 .52661 m
.42294 .5204 L
s
.47125 .91297 m .4621 .91454 L .46097 .91329 L 0 0 .003 r
F
0 g
.4568 .91419 m
.46097 .91329 L
s
.65702 .65638 m .65929 .64047 L .65562 .62886 L 0 .245 .231 r
F
0 g
.65307 .62889 m
.6561 .64996 L
s
.6553 .62731 m
.65562 .62886 L
s
.3868 .56063 m .37654 .57091 L .37948 .56866 L 0 1 .257 r
F
.3868 .56063 m .37975 .56549 L .37654 .57091 L F
0 g
.37704 .57172 m
.37948 .56866 L
s
.3868 .56063 m .38697 .55601 L .37975 .56549 L 0 1 .257 r
F
.3868 .56063 m .39431 .54797 L .38697 .55601 L F
.3868 .56063 m .39685 .54675 L .39431 .54797 L F
.3868 .56063 m .39364 .55217 L .39685 .54675 L F
0 g
.39685 .54675 m
.40032 .54352 L
s
.38388 .56536 m
.3868 .56063 L
s
.37948 .56866 m
.3868 .56063 L
s
.39364 .55217 m
.39907 .54644 L
s
.4397 .94395 m .42804 .93884 L .43067 .94498 L 0 .727 .39 r
F
.4397 .94395 m .42893 .93402 L .42804 .93884 L F
0 g
.42321 .93454 m
.42804 .93884 L
s
.42936 .91369 m .41895 .9025 L .41714 .90719 L 0 .82 .387 r
F
0 g
.41253 .90235 m
.41714 .90719 L
s
.47025 .76643 m .46369 .77117 L .46723 .76826 L 0 .163 .059 r
F
.47025 .76643 m .46149 .77376 L .46369 .77117 L F
.47025 .76643 m .4621 .77431 L .46149 .77376 L F
.47025 .76643 m .46514 .77246 L .4621 .77431 L F
.47025 .76643 m .46857 .76947 L .46514 .77246 L F
0 g
.46723 .76825 m
.46723 .76825 L
s
.46722 .76826 m
.46723 .76825 L
s
.47025 .76643 m .47076 .76689 L .46857 .76947 L 0 .163 .059 r
F
0 g
.47025 .76643 m
.47172 .76422 L
s
.46723 .76825 m
.46874 .76507 L
s
.46723 .76826 m
.47025 .76643 L
s
.47076 .76689 m
.47371 .76407 L
s
.74291 .62337 m
.74292 .62339 L
s
.74292 .62339 m
.7438 .62494 L
s
.7438 .62494 m
.74398 .62526 L
s
.74398 .62526 m
.7458 .62847 L
s
.72679 .61955 m .74291 .62336 L .74212 .62138 L 0 .771 .3 r
F
0 g
.73243 .62371 m
.73244 .62326 L
s
.74291 .62354 m
.74291 .62337 L
s
.41023 .66615 m
.41175 .6703 L
s
.77144 .67237 m .78574 .69718 L .78625 .68556 L 0 1 .418 r
F
0 g
.77514 .68737 m
.78126 .698 L
s
.77456 .69932 m
.77514 .68737 L
s
.78574 .69718 m
.79101 .70729 L
s
.39001 .77031 m
.39419 .77041 L
s
.38845 .77038 m
.38851 .77037 L
s
.38851 .77037 m
.38861 .77037 L
s
.38861 .77037 m
.39001 .77031 L
s
.43639 .7878 m .42688 .77234 L .42544 .7796 L 0 1 .352 r
F
0 g
.42609 .76946 m
.42688 .77234 L
s
.42688 .77234 m
.42934 .77076 L
s
.80227 .70536 m .80817 .69357 L .80367 .69424 L 0 1 .441 r
F
.80227 .70536 m .81354 .70362 L .80817 .69357 L F
.38454 .82327 m .37733 .80806 L .3737 .81348 L 0 1 .4 r
F
.38454 .82327 m .3818 .80892 L .37733 .80806 L F
.38454 .82327 m .38489 .81544 L .3818 .80892 L F
0 g
.38091 .82869 m
.38454 .82327 L
s
.39621 .82559 m .38489 .81544 L .38454 .82327 L 0 1 .391 r
F
0 g
.38454 .82327 m
.38779 .82977 L
s
.39364 .55217 m
.39685 .54675 L
s
.33917 .68775 m .33303 .68143 L .32937 .68528 L 0 1 .542 r
F
.33917 .68775 m .33862 .67944 L .33303 .68143 L F
.33917 .68775 m .34242 .68065 L .33862 .67944 L F
.33917 .68775 m .34265 .68422 L .34242 .68065 L F
0 g
.33917 .68775 m
.33956 .69094 L
s
.33359 .68973 m
.33917 .68775 L
s
.4079 .84636 m .39988 .85027 L .40453 .85106 L 0 1 .386 r
F
.40906 .86376 m .40453 .85106 L .39988 .85027 L 0 .981 .389 r
F
0 g
.3969 .85507 m
.39988 .85027 L
s
.39627 .84414 m
.39988 .85027 L
s
.4397 .94395 m .43067 .94498 L .43528 .94924 L 0 .727 .39 r
F
0 g
.43 .95003 m
.43067 .94498 L
s
.49122 .9044 m .48953 .90594 L .48641 .90634 L 0 0 .028 r
F
.40831 .74697 m .41056 .73873 L .40921 .7307 L 0 1 .375 r
F
0 g
.41056 .73873 m
.41529 .73473 L
s
.4581 .91507 m .44824 .91671 L .44695 .91582 L 0 0 0 r
F
0 g
.4425 .91661 m
.44695 .91582 L
s
.51381 .90618 m .51174 .89849 L .51267 .89353 L 0 .098 .08 r
F
0 g
.51143 .89188 m
.51267 .89353 L
s
.3191 .81798 m .30875 .8087 L .30833 .81783 L 0 1 .446 r
F
.3191 .81798 m .3123 .80196 L .30875 .8087 L F
.3191 .81798 m .3166 .80212 L .3123 .80196 L F
.3191 .81798 m .31952 .80899 L .3166 .80212 L F
0 g
.31555 .8247 m
.3191 .81798 L
s
.3191 .81798 m
.32135 .82322 L
s
.42548 .89808 m .41464 .8974 L .41895 .9025 L 0 .86 .385 r
F
.42548 .89808 m .41318 .8908 L .41464 .8974 L F
0 g
.41253 .90235 m
.41464 .8974 L
s
.41131 .88077 m .41028 .87401 L .40607 .86856 L 0 .946 .393 r
F
.4079 .84636 m .39947 .83207 L .3961 .83677 L 0 1 .386 r
F
0 g
.39246 .83061 m
.3961 .83677 L
s
.49665 .90948 m .49122 .9044 L .49403 .90482 L 0 .045 .056 r
F
.49665 .90948 m .48953 .90594 L .49122 .9044 L F
0 g
.49097 .90239 m
.49122 .9044 L
s
.49122 .9044 m
.49312 .90468 L
s
.45443 .9892 m .45089 .98349 L .44611 .97982 L 0 .599 .402 r
F
0 g
.4141 .75753 m
.41609 .76518 L
s
.42548 .89808 m .41542 .88619 L .41318 .8908 L 0 .86 .385 r
F
0 g
.40875 .88566 m
.41318 .8908 L
s
.45931 .76736 m
.45943 .76734 L
s
.45539 .76829 m
.45931 .76736 L
s
.40831 .74697 m .40921 .7307 L .40514 .72822 L 0 1 .375 r
F
0 g
.40921 .7307 m
.41427 .72626 L
s
.40921 .7307 m
.41056 .73873 L
s
.32937 .68528 m .31967 .68633 L .32365 .68738 L 0 1 .54 r
F
0 g
.32365 .68738 m
.32449 .69165 L
s
.50979 .8374 m .50959 .77545 L .50814 .77601 L 0 .621 .273 r
F
.50979 .8374 m .51093 .79405 L .50959 .77545 L F
0 g
.50959 .77545 m
.51001 .76596 L
s
.82195 .79387 m .82641 .79203 L .83109 .79325 L 0 0 0 r
F
.82195 .79387 m .82249 .7923 L .82641 .79203 L F
0 g
.82235 .79104 m
.82641 .79203 L
s
.75156 .89937 m .76126 .89757 L .75672 .89757 L 0 1 .412 r
F
.7403 .899 m .75156 .89937 L .74992 .89757 L 0 .999 .368 r
F
.8015 .89039 m .79984 .89448 L .802 .89753 L 0 1 .49 r
F
0 g
.79646 .90057 m
.802 .89753 L
s
.40704 .67342 m
.4105 .67318 L
s
.41023 .66615 m
.41024 .66614 L
s
.41024 .66614 m
.41593 .66117 L
s
.22564 .87121 m .21838 .87694 L .22294 .87688 L 0 1 .532 r
F
.22564 .87121 m .21419 .87118 L .21838 .87694 L F
0 g
.21667 .88274 m
.21838 .87694 L
s
.22294 .87688 m
.22799 .88241 L
s
.51223 .83978 m .51178 .77526 L .51093 .79405 L 0 .614 .27 r
F
.51223 .83978 m .51324 .77557 L .51178 .77526 L F
0 g
.51173 .77454 m
.51178 .77526 L
s
.49448 .79425 m .49574 .79164 L .49506 .77683 L 0 .793 .294 r
F
0 g
.76052 .66119 m
.76104 .66207 L
s
.75426 .65076 m
.76052 .66119 L
s
.45025 .78231 m .44179 .77926 L .44604 .7837 L 0 1 .338 r
F
.44732 .79788 m .44179 .77926 L .43766 .78102 L 0 .981 .342 r
F
.44732 .79788 m .44604 .7837 L .44179 .77926 L F
0 g
.4398 .77077 m
.44179 .77926 L
s
.44096 .77962 m
.44179 .77926 L
s
.56471 .61442 m .56354 .62192 L .56191 .61729 L 0 .333 .079 r
F
.56471 .61442 m .56913 .62722 L .56354 .62192 L F
.56471 .61442 m .57496 .62962 L .56913 .62722 L F
.56471 .61442 m .57774 .62672 L .57496 .62962 L F
.56471 .61442 m .57564 .62047 L .57774 .62672 L F
0 g
.57564 .62047 m
.57789 .61767 L
s
.55948 .60963 m
.56471 .61442 L
s
.57006 .61521 m
.57564 .62047 L
s
.50809 .61918 m .51346 .61682 L .5176 .61654 L 0 0 0 r
F
0 g
.50432 .6197 m
.50809 .61918 L
s
.44607 .95863 m .43486 .95408 L .43782 .96008 L 0 .672 .391 r
F
.44607 .95863 m .43528 .94924 L .43486 .95408 L F
0 g
.43 .95003 m
.43486 .95408 L
s
.68237 .90724 m
.68245 .90711 L
s
.68025 .91051 m
.682 .90781 L
s
.682 .90781 m
.68237 .90724 L
s
.27418 .91077 m .26774 .91363 L .27221 .91355 L 0 1 .501 r
F
.27418 .91077 m .26292 .91076 L .26774 .91363 L F
0 g
.26663 .91653 m
.26774 .91363 L
s
.27221 .91355 m
.27769 .91611 L
s
.50979 .8374 m .50814 .77601 L .50765 .79446 L 0 .621 .273 r
F
0 g
.5079 .77364 m
.50814 .77601 L
s
.26523 .68432 m .25476 .68816 L .2592 .68897 L 0 1 .526 r
F
0 g
.2592 .68897 m
.26062 .6949 L
s
.45447 .64735 m
.45641 .6456 L
s
.3548 .59045 m .3463 .57676 L .34457 .56974 L 0 .581 .046 r
F
0 g
.34457 .56974 m
.34636 .57074 L
s
.47634 .79139 m .46885 .77949 L .4726 .78824 L 0 .891 .314 r
F
0 g
.47593 .77604 m
.47743 .77932 L
s
.47352 .80291 m .4726 .78824 L .46885 .77949 L 0 .876 .317 r
F
0 g
.46872 .7794 m
.46885 .77949 L
s
.46747 .77043 m
.46885 .77949 L
s
.39431 .67743 m .3852 .67933 L .38876 .6794 L 0 1 .424 r
F
0 g
.3942 .67944 m
.39431 .67743 L
s
.38876 .6794 m
.38893 .68166 L
s
.30833 .81783 m .29797 .80852 L .29755 .81778 L 0 1 .452 r
F
.30833 .81783 m .30152 .80164 L .29797 .80852 L F
0 g
.29755 .81778 m
.30046 .8247 L
s
.30833 .81783 m .30583 .80176 L .30152 .80164 L 0 1 .452 r
F
.30833 .81783 m .30875 .8087 L .30583 .80176 L F
0 g
.30478 .82468 m
.30833 .81783 L
s
.30833 .81783 m
.31124 .82468 L
s
.44732 .79788 m .43766 .78102 L .43639 .7878 L 0 .981 .342 r
F
0 g
.43541 .77322 m
.43766 .78102 L
s
.43766 .78102 m
.44096 .77962 L
s
.53885 1.08894 m .54083 1.08682 L .54165 1.08843 L 0 .136 0 r
F
.44989 .54742 m .45716 .53927 L .46169 .53214 L 0 1 .381 r
F
0 g
.45716 .53927 m
.46354 .53425 L
s
.40431 .71978 m .40726 .71101 L .40673 .70262 L 0 1 .378 r
F
.51223 .83978 m .51423 .79562 L .51324 .77557 L 0 .614 .27 r
F
0 g
.51324 .77557 m
.51331 .7745 L
s
.42253 .88215 m .41131 .88077 L .41542 .88619 L 0 .898 .382 r
F
.42253 .88215 m .41028 .87401 L .41131 .88077 L F
0 g
.40875 .88566 m
.41131 .88077 L
s
.46817 .93913 m .45869 .93617 L .45822 .93793 L 0 .935 .488 r
F
0 g
.45389 .93671 m
.45822 .93793 L
s
.52712 .47142 m
.52712 .47142 L
s
.52029 .47514 m
.52712 .47142 L
s
.51366 .47978 m
.52029 .47514 L
s
.27025 .57505 m .26019 .57275 L .25836 .58174 L 0 1 .475 r
F
0 g
.25125 .58921 m
.25836 .58174 L
s
.27025 .57505 m .26674 .56163 L .26019 .57275 L 0 1 .475 r
F
.27025 .57505 m .27456 .55404 L .26674 .56163 L F
.27025 .57505 m .27842 .55506 L .27456 .55404 L F
.27025 .57505 m .27656 .56408 L .27842 .55506 L F
0 g
.26858 .58399 m
.27025 .57505 L
s
.26245 .58261 m
.27025 .57505 L
s
.38222 .91913 m .37104 .91783 L .36956 .91857 L 0 .711 .252 r
F
.38222 .91913 m .37531 .91785 L .37104 .91783 L F
.38222 .91913 m .38011 .91841 L .37531 .91785 L F
.39261 .9189 m .38011 .91841 L .38222 .91913 L 0 .651 .233 r
F
0 g
.38222 .91913 m
.38688 .91954 L
s
.38073 .91987 m
.38222 .91913 L
s
.2292 .911 m .21719 .90234 L .21557 .90606 L 0 1 .522 r
F
.2292 .911 m .22176 .90248 L .21719 .90234 L F
.2292 .911 m .22691 .9062 L .22176 .90248 L F
.24043 .91088 m .22691 .9062 L .2292 .911 L 0 1 .518 r
F
0 g
.22757 .91468 m
.2292 .911 L
s
.2292 .911 m
.23425 .91448 L
s
.51669 1.07198 m .51699 1.07191 L .52113 1.07537 L 0 .131 .18 r
F
0 g
.51699 1.07191 m
.52151 1.07514 L
s
.40831 .74697 m .39912 .74946 L .40341 .75157 L 0 1 .375 r
F
.40831 .74697 m .39776 .74142 L .39912 .74946 L F
.40831 .74697 m .40024 .73281 L .39776 .74142 L F
.40831 .74697 m .40514 .72822 L .40024 .73281 L F
0 g
.40831 .74697 m
.40983 .75503 L
s
.39621 .82559 m .38864 .81041 L .38489 .81544 L 0 1 .391 r
F
.61634 .63035 m .63039 .62737 L .62874 .62871 L 0 0 0 r
F
0 g
.63039 .62737 m
.63629 .62843 L
s
.42544 .7796 m .41658 .78056 L .42102 .78313 L 0 1 .361 r
F
.42544 .7796 m .41447 .77287 L .41658 .78056 L F
.43639 .7878 m .42544 .7796 L .42768 .7874 L 0 1 .352 r
F
.46069 .79661 m .45025 .78231 L .45241 .79115 L 0 .938 .329 r
F
.38852 .8986 m .38207 .90151 L .38633 .90153 L 0 1 .512 r
F
.38852 .8986 m .37776 .89836 L .38207 .90151 L F
0 g
.3804 .90451 m
.38207 .90151 L
s
.3212 .88654 m .31138 .87668 L .30924 .88094 L 0 1 .522 r
F
.3212 .88654 m .31567 .87677 L .31138 .87668 L F
.3212 .88654 m .31987 .881 L .31567 .87677 L F
.33175 .88648 m .31987 .881 L .3212 .88654 L 0 1 .52 r
F
0 g
.31905 .89078 m
.3212 .88654 L
s
.3212 .88654 m
.32534 .89061 L
s
.5259 .97172 m
.52622 .9718 L
s
.52624 .9718 m
.52657 .97189 L
s
.52658 .97189 m
.52692 .97198 L
s
.52693 .97199 m
.52711 .97203 L
s
.20628 .75564 m .19629 .74811 L .19482 .75439 L 0 1 .539 r
F
.20628 .75564 m .20082 .74396 L .19629 .74811 L F
0 g
.19482 .75439 m
.19717 .75937 L
s
.20628 .75564 m .20538 .74471 L .20082 .74396 L 0 1 .539 r
F
.20628 .75564 m .20771 .74973 L .20538 .74471 L F
0 g
.20176 .75976 m
.20628 .75564 L
s
.20628 .75564 m
.20864 .76036 L
s
.39621 .82559 m .39329 .81154 L .38864 .81041 L 0 1 .391 r
F
.39621 .82559 m .39654 .81804 L .39329 .81154 L F
.40787 .82857 m .39621 .82559 L .39947 .83207 L 0 1 .382 r
F
.40787 .82857 m .39654 .81804 L .39621 .82559 L F
0 g
.39246 .83061 m
.39621 .82559 L
s
.41447 .77287 m .40547 .77493 L .40992 .77705 L 0 1 .37 r
F
.49147 .80129 m .48538 .77903 L .48835 .79298 L 0 .795 .298 r
F
.48869 .80895 m .48835 .79298 L .48538 .77903 L 0 .794 .301 r
F
0 g
.48486 .77792 m
.48538 .77903 L
s
.48527 .77753 m
.48538 .77903 L
s
.42253 .88215 m .41293 .86951 L .41028 .87401 L 0 .898 .382 r
F
0 g
.40607 .86856 m
.41028 .87401 L
s
.29087 .93529 m .27814 .93457 L .27699 .93497 L 0 .595 .21 r
F
.29087 .93529 m .28262 .93469 L .27814 .93457 L F
.29087 .93529 m .28808 .935 L .28262 .93469 L F
0 g
.2897 .93568 m
.29087 .93529 L
s
.74978 1.06669 m .75356 1.06462 L .75957 1.06239 L 0 0 0 r
F
0 g
.74627 1.06724 m
.75356 1.06462 L
s
.44607 .95863 m .43782 .96008 L .44244 .96411 L 0 .672 .391 r
F
0 g
.43766 .96512 m
.43782 .96008 L
s
.40906 .86376 m .40846 .85684 L .40453 .85106 L 0 .981 .389 r
F
0 g
.38633 .90153 m
.39094 .90438 L
s
.40363 .90805 m .39288 .90165 L .39094 .90438 L 0 1 .513 r
F
.50739 .83649 m .50598 .77736 L .50455 .77861 L 0 .629 .277 r
F
.50739 .83649 m .50765 .79446 L .50598 .77736 L F
0 g
.50598 .77736 m
.50616 .77027 L
s
.56613 .82717 m .5757 .71755 L .57287 .72612 L 0 .966 .238 r
F
.56613 .82717 m .57576 .75156 L .5757 .71755 L F
0 g
.5757 .71755 m
.57643 .7109 L
s
.7597 .62321 m
.7597 .62321 L
s
.7534 .62332 m
.75342 .62333 L
s
.75342 .62333 m
.75486 .62395 L
s
.75486 .62395 m
.755 .62401 L
s
.755 .62401 m
.75679 .62477 L
s
.75679 .62477 m
.758 .62529 L
s
.40787 .82857 m .39947 .83207 L .40414 .83316 L 0 1 .382 r
F
.4079 .84636 m .40414 .83316 L .39947 .83207 L 0 1 .386 r
F
0 g
.3961 .83677 m
.39947 .83207 L
s
.39621 .82559 m
.39947 .83207 L
s
.40431 .71978 m .40673 .70262 L .40307 .7002 L 0 1 .378 r
F
0 g
.40673 .70262 m
.41202 .69778 L
s
.40673 .70262 m
.40726 .71101 L
s
.48315 .91178 m .47927 .90912 L .48212 .91005 L 0 0 .033 r
F
.48705 .90819 m .48212 .91005 L .47927 .90912 L 0 0 .031 r
F
0 g
.47863 .90727 m
.47927 .90912 L
s
.47575 .9095 m
.47927 .90912 L
s
.47353 1.01709 m .46923 1.01927 L .47374 1.02272 L 0 .412 .377 r
F
0 g
.46923 1.01927 m
.47136 1.02404 L
s
.46069 .79661 m .46182 .79105 L .45966 .78221 L 0 .938 .329 r
F
.47352 .80291 m .46369 .7827 L .46568 .79273 L 0 .876 .317 r
F
0 g
.45966 .78221 m
.46369 .7827 L
s
.48733 .81308 m .47924 .78093 L .47882 .78234 L 0 .795 .304 r
F
.48733 .81308 m .48204 .78928 L .47924 .78093 L F
0 g
.47712 .77254 m
.47924 .78093 L
s
.43709 .57321 m .42853 .57571 L .4306 .57795 L 0 1 .404 r
F
.43709 .57321 m .43221 .56787 L .42853 .57571 L F
.43709 .57321 m .43919 .55968 L .43221 .56787 L F
.43709 .57321 m .44568 .55495 L .43919 .55968 L F
0 g
.43371 .58139 m
.43709 .57321 L
s
.53041 .76202 m .532 .80172 L .53032 .78071 L 0 .525 .181 r
F
.53041 .76202 m .53497 .81648 L .532 .80172 L F
.53041 .76202 m .53724 .81499 L .53497 .81648 L F
.53041 .76202 m .5373 .79603 L .53724 .81499 L F
.53041 .76202 m .53513 .77243 L .5373 .79603 L F
0 g
.53219 .75794 m
.53513 .77243 L
s
.53479 .75021 m
.53513 .77243 L
s
.52783 .75312 m
.53041 .76202 L
s
.67338 1.08308 m .6675 1.07973 L .66537 1.0769 L 0 0 0 r
F
0 g
.66425 1.07657 m
.66537 1.0769 L
s
.29755 .81778 m .28381 .80839 L .28339 .81782 L 0 1 .458 r
F
0 g
.28339 .81782 m
.28732 .82484 L
s
.29755 .81778 m .28838 .80138 L .28381 .80839 L 0 1 .458 r
F
.29755 .81778 m .29404 .80148 L .28838 .80138 L F
.29755 .81778 m .29797 .80852 L .29404 .80148 L F
0 g
.29298 .82477 m
.29755 .81778 L
s
.39431 .67743 m .38562 .67739 L .3852 .67933 L 0 1 .424 r
F
.39431 .67743 m .39129 .67575 L .38562 .67739 L F
.39414 .68573 m .39129 .67575 L .38555 .68066 L 0 1 .387 r
F
.39121 .67548 m .38983 .67064 L .38741 .67631 L F
.38665 .67646 m .38983 .67064 L .3906 .66141 L 0 1 .391 r
F
.39129 .67575 m .38741 .67631 L .38562 .67739 L 0 1 .424 r
F
.38741 .67631 m .38983 .67064 L .38665 .67646 L 0 1 .391 r
F
.38665 .67646 m .38974 .67489 L .39036 .67312 L 0 1 .386 r
F
.38562 .67739 m .38741 .67631 L .38665 .67646 L F
.38741 .67631 m .38974 .67489 L .38665 .67646 L F
.38589 .67662 m .3906 .66141 L .38735 .65911 L 0 1 .391 r
F
.38664 .67647 m .38665 .67646 L .38588 .67664 L 0 1 .386 r
F
.38665 .67646 m .38591 .67662 L .38588 .67664 L F
.38562 .67739 m .38664 .67647 L .38588 .67664 L F
.38555 .68066 m .38665 .67646 L .38589 .67662 L 0 1 .391 r
F
.38665 .67646 m .3906 .66141 L .38589 .67662 L F
.38555 .68066 m .38741 .67631 L .38665 .67646 L F
.38665 .67646 m .39036 .67312 L .38591 .67662 L 0 1 .386 r
F
.38562 .67739 m .3763 .6789 L .37986 .67911 L F
.38562 .67739 m .37926 .6772 L .3763 .6789 L F
.37926 .6772 m .3768 .6774 L .3768 .67742 L 0 1 .391 r
F
.37926 .6772 m .37693 .67592 L .3768 .6774 L F
.37926 .6772 m .3769 .67713 L .3768 .67742 L 0 1 .386 r
F
.37926 .6772 m .3768 .67742 L .3763 .6789 L F
.37926 .6772 m .3768 .67742 L .37616 .68516 L 0 1 .391 r
F
.38555 .68066 m .37926 .6772 L .37616 .68516 L F
.38562 .67739 m .38453 .67679 L .37926 .6772 L 0 1 .386 r
F
.38453 .67679 m .38452 .67679 L .37926 .6772 L F
.3796 .67739 m .38149 .66533 L .37693 .67592 L 0 1 .391 r
F
.38555 .68066 m .38452 .67679 L .3796 .67739 L F
.38452 .67679 m .38149 .66533 L .3796 .67739 L F
.38452 .67679 m .38735 .65911 L .38149 .66533 L F
.38457 .67678 m .38735 .65911 L .38452 .67679 L F
.38589 .67662 m .38735 .65911 L .38455 .6769 L F
.38452 .67679 m .38706 .67326 L .38128 .67498 L 0 1 .386 r
F
.38562 .67739 m .38589 .67662 L .38452 .67679 L F
.38589 .67662 m .38706 .67326 L .38452 .67679 L F
.37926 .6772 m .38452 .67679 L .37919 .6772 L F
.37919 .6772 m .38128 .67498 L .3769 .67713 L F
.38452 .67679 m .38128 .67498 L .37919 .6772 L F
.38455 .6769 m .38457 .67678 L .38452 .67679 L 0 1 .391 r
F
.38555 .68066 m .38589 .67662 L .38455 .6769 L F
.38589 .67662 m .39036 .67312 L .38706 .67326 L 0 1 .386 r
F
.38588 .67664 m .38591 .67662 L .38589 .67662 L F
.38591 .67662 m .39036 .67312 L .38589 .67662 L F
.39129 .67575 m .39121 .67548 L .38741 .67631 L 0 1 .387 r
F
.39129 .67575 m .38741 .67631 L .38555 .68066 L F
.39129 .67575 m .38974 .67489 L .38741 .67631 L 0 1 .424 r
F
.39481 .67513 m .3987 .66721 L .39546 .66487 L 0 1 .387 r
F
.39687 .67464 m .3987 .66721 L .39481 .67513 L F
.39431 .67743 m .39816 .67471 L .39825 .67431 L 0 1 .424 r
F
.39414 .68573 m .39814 .67614 L .39825 .67431 L 0 1 .387 r
F
.39687 .67464 m .39825 .67431 L .3987 .66721 L F
.39431 .67743 m .39825 .67431 L .39687 .67464 L 0 1 .424 r
F
.39414 .68573 m .39825 .67431 L .39687 .67464 L 0 1 .387 r
F
.39687 .67464 m .39825 .67431 L .3986 .67277 L 0 1 .424 r
F
.39481 .67513 m .3986 .67277 L .39531 .67291 L F
.39431 .67743 m .39687 .67464 L .39481 .67513 L F
.39687 .67464 m .3986 .67277 L .39481 .67513 L F
.39683 .6748 m .39687 .67464 L .39481 .67513 L 0 1 .387 r
F
.39414 .68573 m .39683 .6748 L .39481 .67513 L F
.39129 .67575 m .39546 .66487 L .38983 .67064 L F
.39431 .67743 m .39481 .67513 L .39129 .67575 L 0 1 .424 r
F
.39414 .68573 m .39481 .67513 L .39129 .67575 L 0 1 .387 r
F
.39481 .67513 m .39546 .66487 L .39129 .67575 L F
.39129 .67575 m .39481 .67513 L .39124 .67572 L 0 1 .424 r
F
.39124 .67572 m .39531 .67291 L .38974 .67489 L F
.39481 .67513 m .39531 .67291 L .39124 .67572 L F
.44732 .79788 m .44841 .79168 L .44604 .7837 L 0 .981 .342 r
F
0 g
.44604 .7837 m
.45025 .78231 L
s
.35626 .91685 m .35048 .91811 L .35456 .91801 L 0 .899 .341 r
F
.35626 .91685 m .34596 .9169 L .35048 .91811 L F
0 g
.3494 .91936 m
.35048 .91811 L
s
.35456 .91801 m
.35947 .91889 L
s
.52552 .4724 m
.52712 .47142 L
s
.51509 .96708 m .51773 .96857 L .51746 .96831 L 0 .403 .224 r
F
.52232 .9705 m .51746 .96831 L .51773 .96857 L 0 .31 .193 r
F
0 g
.5154 .96785 m
.51773 .96857 L
s
.42055 .86589 m .40906 .86376 L .41293 .86951 L 0 .934 .379 r
F
.42055 .86589 m .40846 .85684 L .40906 .86376 L F
0 g
.40607 .86856 m
.40906 .86376 L
s
.44508 .76886 m
.44552 .76882 L
s
.44132 .76916 m
.44508 .76886 L
s
.52815 .9724 m
.52827 .97266 L
s
.40787 .82857 m .40027 .81344 L .39654 .81804 L 0 1 .382 r
F
0 g
.40034 .77045 m
.40077 .77049 L
s
.65761 .62543 m
.65781 .62557 L
s
.38582 .80355 m .37733 .80806 L .3818 .80892 L 0 1 .396 r
F
0 g
.3818 .80892 m
.38489 .81544 L
s
.42249 .79753 m .41658 .78056 L .41236 .78429 L 0 1 .365 r
F
.42249 .79753 m .42102 .78313 L .41658 .78056 L F
0 g
.41447 .77287 m
.41658 .78056 L
s
.42249 .79753 m .42356 .7904 L .42102 .78313 L 0 1 .365 r
F
0 g
.42102 .78313 m
.42544 .7796 L
s
.38582 .80355 m .3747 .8012 L .37733 .80806 L 0 1 .396 r
F
0 g
.3737 .81348 m
.37733 .80806 L
s
.40431 .71978 m
.40514 .72822 L
s
.40024 .73281 m
.40514 .72822 L
s
.3974 .80659 m .38864 .81041 L .39329 .81154 L 0 1 .387 r
F
0 g
.39329 .81154 m
.39654 .81804 L
s
.3974 .80659 m .38582 .80355 L .38864 .81041 L 0 1 .387 r
F
0 g
.38489 .81544 m
.38864 .81041 L
s
.79004 .89111 m .79522 .89754 L .79984 .89448 L 0 1 .475 r
F
.79004 .89111 m .79069 .89754 L .79522 .89754 L F
0 g
.79522 .89754 m
.79646 .90057 L
s
.41898 .91616 m .41239 .91072 L .40811 .91069 L 0 1 .513 r
F
.41898 .91616 m .41705 .91306 L .41239 .91072 L F
.42936 .91369 m .42347 .91844 L .42754 .91839 L 0 .82 .387 r
F
.42932 .91621 m .41898 .91616 L .42347 .91844 L 0 1 .508 r
F
0 g
.41901 .91365 m
.42136 .91617 L
s
.42932 .91621 m .41705 .91306 L .41898 .91616 L 0 1 .508 r
F
0 g
.41737 .91865 m
.41898 .91616 L
s
.23709 .87124 m .22978 .87679 L .23435 .87674 L 0 1 .531 r
F
.23709 .87124 m .22564 .87121 L .22978 .87679 L F
0 g
.22799 .88241 m
.22978 .87679 L
s
.23435 .87674 m
.23931 .88209 L
s
.51469 .84381 m .51543 .77682 L .51423 .79562 L 0 .607 .267 r
F
.51469 .84381 m .51689 .77818 L .51543 .77682 L F
0 g
.51503 .76765 m
.51543 .77682 L
s
.51689 .77818 m
.51716 .77454 L
s
.78244 .67085 m .79246 .69602 L .79694 .69529 L 0 1 .428 r
F
.78244 .67085 m .78625 .68556 L .79246 .69602 L F
0 g
.79101 .70729 m
.79246 .69602 L
s
.408 .65436 m .41267 .64486 L .41406 .63573 L 0 1 .386 r
F
.50692 .89921 m .50549 .90062 L .50356 .89963 L 0 0 .053 r
F
0 g
.30239 .91538 m
.30239 .91538 L
s
.50739 .83649 m .50455 .77861 L .50443 .79651 L 0 .629 .277 r
F
0 g
.50362 .7718 m
.50455 .77861 L
s
.40348 .76728 m .40527 .75921 L .40341 .75157 L 0 1 .379 r
F
0 g
.40527 .75921 m
.40983 .75503 L
s
.43419 .92309 m .42754 .91839 L .42347 .91844 L 0 1 .511 r
F
.43411 .92898 m .42754 .91839 L .42347 .91844 L 0 .775 .389 r
F
.42932 .91621 m .42347 .91844 L .42754 .91839 L 0 1 .508 r
F
.43419 .92309 m .43214 .92038 L .42754 .91839 L 0 1 .511 r
F
.43411 .92898 m .43211 .9229 L .42754 .91839 L 0 .775 .389 r
F
.42929 .91873 m .42347 .91844 L .42754 .91839 L 0 0 0 r
F
.42929 .91873 m .41894 .91868 L .42347 .91844 L F
0 g
.42219 .91817 m
.42347 .91844 L
s
.41898 .91616 m
.42347 .91844 L
s
.70639 .80169 m
.7083 .80544 L
s
.70879 .8064 m
.70922 .80725 L
s
.40431 .71978 m .39524 .72275 L .39916 .72481 L 0 1 .378 r
F
.40431 .71978 m .39471 .71435 L .39524 .72275 L F
.40431 .71978 m .39792 .70522 L .39471 .71435 L F
.40431 .71978 m .40307 .7002 L .39792 .70522 L F
.42055 .86589 m .4115 .85246 L .40846 .85684 L 0 .934 .379 r
F
0 g
.40453 .85106 m
.40846 .85684 L
s
.3747 .8012 m .36614 .80624 L .37062 .80691 L 0 1 .405 r
F
0 g
.37062 .80691 m
.3737 .81348 L
s
.44989 .54742 m .46169 .53214 L .46045 .53077 L 0 1 .381 r
F
0 g
.46169 .53214 m
.46823 .52704 L
s
.45716 .53927 m
.46169 .53214 L
s
.42548 .89808 m .41895 .9025 L .42324 .90269 L 0 .86 .385 r
F
.42936 .91369 m .42324 .90269 L .41895 .9025 L 0 .82 .387 r
F
0 g
.41714 .90719 m
.41895 .9025 L
s
.41464 .8974 m
.41895 .9025 L
s
.41117 .79182 m .40992 .77705 L .40547 .77493 L 0 1 .374 r
F
.41117 .79182 m .41236 .78429 L .40992 .77705 L F
0 g
.40992 .77705 m
.41447 .77287 L
s
.48733 .81308 m .47882 .78234 L .48108 .79251 L 0 .795 .304 r
F
0 g
.47743 .77932 m
.47882 .78234 L
s
.42249 .79753 m .41236 .78429 L .41117 .79182 L 0 1 .365 r
F
0 g
.41236 .78429 m
.41658 .78056 L
s
.40992 .77705 m
.41236 .78429 L
s
.46372 1.00328 m .46302 1.00906 L .46504 1.00816 L 0 .514 .394 r
F
.47353 1.01709 m .46504 1.00816 L .46302 1.00906 L 0 .412 .377 r
F
0 g
.46302 1.00906 m
.46481 1.01382 L
s
.45835 1.00552 m
.46302 1.00906 L
s
.4031 .69147 m .40679 .68225 L .40704 .67343 L 0 1 .382 r
F
0 g
.40679 .68225 m
.40704 .67343 L
s
.40679 .68225 m
.41128 .67816 L
s
.51138 .90828 m .51051 .89567 L .51174 .89849 L 0 .1 .078 r
F
.51138 .90828 m .50906 .89709 L .51051 .89567 L F
0 g
.51051 .89567 m
.51143 .89188 L
s
.43639 .7878 m .42768 .7874 L .43211 .79054 L 0 1 .352 r
F
.44732 .79788 m .43639 .7878 L .43876 .79578 L 0 .981 .342 r
F
.36703 .68335 m .35758 .68424 L .36138 .68485 L 0 1 .488 r
F
0 g
.36138 .68485 m
.36188 .68778 L
s
.82195 .79387 m .83109 .79325 L .83419 .79479 L 0 0 0 r
F
0 g
.83109 .79325 m
.83403 .7945 L
s
.52168 .9006 m .52554 .88572 L .52373 .89398 L 0 .114 .089 r
F
.52391 .89955 m .52373 .89398 L .52554 .88572 L 0 .125 .092 r
F
0 g
.52554 .88572 m
.52649 .88283 L
s
.52554 .88572 m
.52581 .88138 L
s
.4338 .80455 m .42768 .7874 L .42356 .7904 L 0 1 .355 r
F
.4338 .80455 m .43211 .79054 L .42768 .7874 L F
0 g
.42544 .7796 m
.42768 .7874 L
s
.46817 .93913 m .46484 .94129 L .46768 .94089 L 0 .935 .488 r
F
.47399 .94381 m .46768 .94089 L .46484 .94129 L 0 .891 .477 r
F
0 g
.46479 .94305 m
.46484 .94129 L
s
.46079 .94002 m
.46484 .94129 L
s
.4079 .84636 m .40776 .83929 L .40414 .83316 L 0 1 .386 r
F
.32937 .68528 m .31956 .6823 L .31967 .68633 L 0 1 .54 r
F
0 g
.31443 .68933 m
.31967 .68633 L
s
.26523 .68432 m .25426 .68199 L .25476 .68816 L 0 1 .526 r
F
0 g
.24947 .69315 m
.25476 .68816 L
s
.3747 .8012 m .36356 .79934 L .36614 .80624 L 0 1 .405 r
F
0 g
.3625 .81197 m
.36614 .80624 L
s
.77016 .61831 m .77445 .62266 L .77023 .62285 L 0 .057 .018 r
F
0 g
.77023 .62276 m
.77023 .62285 L
s
.77016 .61831 m .78085 .61878 L .77445 .62266 L 0 .057 .018 r
F
0 g
.77021 .62183 m
.77023 .62276 L
s
.77016 .61831 m
.77021 .62183 L
s
.76391 .62309 m
.76395 .62306 L
s
.76395 .62306 m
.76657 .62106 L
s
.76657 .62106 m
.77016 .61831 L
s
.3974 .80659 m .38672 .79552 L .38582 .80355 L 0 1 .387 r
F
0 g
.38582 .80355 m
.38864 .81041 L
s
.38582 .80355 m .37566 .79291 L .3747 .8012 L 0 1 .396 r
F
.38582 .80355 m .37969 .78753 L .37566 .79291 L F
.38582 .80355 m .38409 .78866 L .37969 .78753 L F
.38582 .80355 m .38672 .79552 L .38409 .78866 L F
0 g
.3818 .80892 m
.38582 .80355 L
s
.45314 .97302 m .4425 .96896 L .44577 .97481 L 0 .608 .389 r
F
.45314 .97302 m .44244 .96411 L .4425 .96896 L F
0 g
.43766 .96512 m
.4425 .96896 L
s
.3974 .80659 m .39083 .79057 L .38672 .79552 L 0 1 .387 r
F
.3974 .80659 m .39541 .79201 L .39083 .79057 L F
.3974 .80659 m .39822 .79887 L .39541 .79201 L F
.40896 .81039 m .3974 .80659 L .40027 .81344 L 0 1 .378 r
F
.40896 .81039 m .39822 .79887 L .3974 .80659 L F
0 g
.39329 .81154 m
.3974 .80659 L
s
.43411 .92898 m .42893 .93402 L .43275 .93374 L 0 .775 .389 r
F
.4397 .94395 m .43275 .93374 L .42893 .93402 L 0 .727 .39 r
F
0 g
.42804 .93884 m
.42893 .93402 L
s
.42437 .9295 m
.42893 .93402 L
s
.4338 .80455 m .42356 .7904 L .42249 .79753 L 0 1 .355 r
F
0 g
.42356 .7904 m
.42768 .7874 L
s
.42102 .78313 m
.42356 .7904 L
s
.408 .65436 m .41406 .63573 L .41125 .63306 L 0 1 .386 r
F
0 g
.41406 .63573 m
.41998 .63077 L
s
.41267 .64486 m
.41406 .63573 L
s
.40896 .81039 m .40027 .81344 L .40491 .81486 L 0 1 .378 r
F
.40787 .82857 m .40491 .81486 L .40027 .81344 L 0 1 .382 r
F
0 g
.39654 .81804 m
.40027 .81344 L
s
.3974 .80659 m
.40027 .81344 L
s
.40348 .76728 m .39247 .76262 L .39434 .77026 L 0 1 .379 r
F
0 g
.40034 .77045 m
.40059 .7702 L
s
.40348 .76728 m .39443 .7542 L .39247 .76262 L 0 1 .379 r
F
.40348 .76728 m .39912 .74946 L .39443 .7542 L F
.40348 .76728 m .40341 .75157 L .39912 .74946 L F
0 g
.40341 .75157 m
.40831 .74697 L
s
.40059 .7702 m
.40348 .76728 L
s
.40341 .75157 m
.40527 .75921 L
s
.40348 .76728 m
.40429 .77041 L
s
.42253 .88215 m .41542 .88619 L .41988 .88665 L 0 .898 .382 r
F
.42548 .89808 m .41988 .88665 L .41542 .88619 L 0 .86 .385 r
F
0 g
.41318 .8908 m
.41542 .88619 L
s
.41131 .88077 m
.41542 .88619 L
s
.27618 .68672 m .26886 .67729 L .26523 .68432 L 0 1 .527 r
F
.27618 .68672 m .2748 .67296 L .26886 .67729 L F
.27618 .68672 m .27908 .67423 L .2748 .67296 L F
.27618 .68672 m .27967 .68014 L .27908 .67423 L F
0 g
.27026 .69102 m
.27618 .68672 L
s
.27618 .68672 m
.2769 .69226 L
s
.41117 .79182 m .40547 .77493 L .40115 .77926 L 0 1 .374 r
F
0 g
.40451 .77125 m
.40547 .77493 L
s
.41954 .8493 m .4079 .84636 L .4115 .85246 L 0 .968 .376 r
F
.41954 .8493 m .40776 .83929 L .4079 .84636 L F
0 g
.40453 .85106 m
.4079 .84636 L
s
.35287 .88675 m .34632 .89036 L .35052 .89037 L 0 1 .516 r
F
0 g
.35052 .89037 m
.35498 .8939 L
s
.35287 .88675 m .34231 .88654 L .34632 .89036 L 0 1 .516 r
F
0 g
.34457 .89403 m
.34632 .89036 L
s
.67338 1.08308 m .67525 1.07803 L .68142 1.08056 L 0 0 0 r
F
0 g
.66839 1.07646 m
.67525 1.07803 L
s
.41117 .79182 m .40227 .7944 L .40685 .79616 L 0 1 .374 r
F
.41117 .79182 m .39983 .78716 L .40227 .7944 L F
.41117 .79182 m .40115 .77926 L .39983 .78716 L F
.42249 .79753 m .41117 .79182 L .4137 .7991 L 0 1 .365 r
F
.49362 .95633 m .49085 .95479 L .48758 .95407 L 0 .646 .389 r
F
.50067 .96006 m .49782 .95859 L .49484 .95792 L 0 .524 .329 r
F
.217 .93204 m .21109 .9339 L .21555 .9339 L 0 .83 .318 r
F
.217 .93204 m .20577 .93179 L .21109 .9339 L F
0 g
.21068 .93593 m
.21109 .9339 L
s
.21555 .9339 m
.2217 .93566 L
s
.41447 .90831 m .40811 .91069 L .41239 .91072 L 0 1 .509 r
F
.41447 .90831 m .40363 .90805 L .40811 .91069 L F
0 g
.40651 .91318 m
.40811 .91069 L
s
.40896 .81039 m .40227 .7944 L .39822 .79887 L 0 1 .378 r
F
.50809 .61918 m .50348 .62338 L .50381 .62199 L 0 0 0 r
F
0 g
.50248 .62105 m
.50432 .6197 L
s
.50006 .62283 m
.50248 .62105 L
s
.50809 .61918 m .50763 .62311 L .50348 .62338 L 0 0 0 r
F
.50809 .61918 m .51348 .62135 L .50763 .62311 L F
.50809 .61918 m .51776 .61854 L .51348 .62135 L F
.50809 .61918 m .5176 .61654 L .51776 .61854 L F
0 g
.5176 .61654 m
.52149 .61338 L
s
.51346 .61682 m
.5176 .61654 L
s
.79339 1.04528 m .79807 1.04601 L .80367 1.0412 L 0 1 .27 r
F
0 g
.79092 1.05056 m
.79807 1.04601 L
s
.79686 1.04876 m
.79807 1.04601 L
s
.36356 .79934 m .35528 .80485 L .35957 .80536 L 0 1 .413 r
F
0 g
.35957 .80536 m
.3625 .81197 L
s
.6823 .6212 m .69969 .6209 L .69921 .61964 L 0 .766 .25 r
F
0 g
.69969 .6209 m
.70673 .62106 L
s
.46629 .64017 m
.46874 .63859 L
s
.41954 .8493 m .41115 .83505 L .40776 .83929 L 0 .968 .376 r
F
0 g
.40414 .83316 m
.40776 .83929 L
s
.49254 .76591 m .48728 .7756 L .48954 .76958 L 0 .272 .097 r
F
.49254 .76591 m .48725 .78166 L .48728 .7756 L F
.49254 .76591 m .48946 .78369 L .48725 .78166 L F
.49254 .76591 m .49247 .77998 L .48946 .78369 L F
0 g
.48954 .76958 m
.48997 .76423 L
s
.49254 .76591 m .49428 .77303 L .49247 .77998 L 0 .272 .097 r
F
.49254 .76591 m .4943 .76701 L .49428 .77303 L F
0 g
.49254 .76591 m
.49271 .76284 L
s
.4943 .76701 m
.49697 .76155 L
s
.4338 .80455 m .43473 .79789 L .43211 .79054 L 0 1 .355 r
F
0 g
.43211 .79054 m
.43639 .7878 L
s
.79004 .89111 m .78847 .8948 L .79069 .89754 L 0 1 .475 r
F
0 g
.78525 .9003 m
.79069 .89754 L
s
.39983 .78716 m .40115 .77926 L .39879 .77202 L 0 1 .383 r
F
0 g
.40115 .77926 m
.40547 .77493 L
s
.39879 .77202 m
.40016 .77064 L
s
.3747 .8012 m .36459 .79081 L .36356 .79934 L 0 1 .405 r
F
.3747 .8012 m .36867 .7851 L .36459 .79081 L F
0 g
.36356 .79934 m
.36614 .80624 L
s
.3747 .8012 m .37308 .78601 L .36867 .7851 L 0 1 .405 r
F
.3747 .8012 m .37566 .79291 L .37308 .78601 L F
0 g
.37062 .80691 m
.3747 .8012 L
s
.3747 .8012 m
.37733 .80806 L
s
.39983 .78716 m .39083 .79057 L .39541 .79201 L 0 1 .383 r
F
0 g
.39541 .79201 m
.39822 .79887 L
s
.39983 .78716 m .38847 .78333 L .39083 .79057 L 0 1 .383 r
F
.39983 .78716 m .38991 .77511 L .38847 .78333 L F
0 g
.39541 .79201 m
.39983 .78716 L
s
.39879 .77202 m
.40115 .77926 L
s
.40787 .82857 m .40817 .82134 L .40491 .81486 L 0 1 .382 r
F
.40896 .81039 m .40685 .79616 L .40227 .7944 L 0 1 .378 r
F
0 g
.39983 .78716 m
.40227 .7944 L
s
.39822 .79887 m
.40227 .7944 L
s
.40896 .81039 m .40971 .80301 L .40685 .79616 L 0 1 .378 r
F
0 g
.40685 .79616 m
.41117 .79182 L
s
.81354 .70362 m .81941 .69198 L .81491 .6926 L 0 1 .449 r
F
.81354 .70362 m .82484 .70203 L .81941 .69198 L F
.51935 .902 m .52244 .88844 L .52109 .8959 L 0 .106 .085 r
F
0 g
.51925 .89137 m
.51957 .88687 L
s
.52168 .9006 m .52109 .8959 L .52244 .88844 L 0 .114 .089 r
F
0 g
.52239 .88392 m
.52244 .88844 L
s
.52244 .88844 m
.52369 .88444 L
s
.48227 .4781 m .49122 .47387 L .4976 .47249 L 0 0 0 r
F
0 g
.47617 .47998 m
.48227 .4781 L
s
.7403 .899 m .74992 .89757 L .74538 .89756 L 0 .999 .368 r
F
.72646 .89848 m .7403 .899 L .73779 .89753 L 0 .781 .294 r
F
.71675 .62032 m .73182 .62169 L .72679 .61955 L 0 .683 .253 r
F
0 g
.73182 .62169 m
.73244 .62321 L
s
.73182 .62169 m
.73767 .62308 L
s
.42051 .81512 m .40971 .80301 L .40896 .81039 L 0 1 .369 r
F
.42051 .81512 m .4137 .7991 L .40971 .80301 L F
0 g
.40685 .79616 m
.40971 .80301 L
s
.51689 .77818 m
.51724 .79017 L
s
.51724 .79017 m
.51752 .79958 L
s
.33568 .91708 m .32466 .91342 L .32318 .91508 L 0 1 .414 r
F
.33568 .91708 m .32886 .9135 L .32466 .91342 L F
.33568 .91708 m .33359 .91507 L .32886 .9135 L F
.34596 .9169 m .33359 .91507 L .33568 .91708 L 0 1 .382 r
F
0 g
.33418 .91873 m
.33568 .91708 L
s
.33568 .91708 m
.34029 .91846 L
s
.42055 .86589 m .41293 .86951 L .4175 .87027 L 0 .934 .379 r
F
.42253 .88215 m .4175 .87027 L .41293 .86951 L 0 .898 .382 r
F
0 g
.41028 .87401 m
.41293 .86951 L
s
.40906 .86376 m
.41293 .86951 L
s
.41953 .83238 m .40787 .82857 L .41115 .83505 L 0 1 .372 r
F
.41953 .83238 m .40817 .82134 L .40787 .82857 L F
0 g
.40414 .83316 m
.40787 .82857 L
s
.52603 .89893 m .5313 .88127 L .52865 .89126 L 0 .138 .097 r
F
.52801 .89882 m .52865 .89126 L .5313 .88127 L 0 .151 .101 r
F
0 g
.5313 .88127 m
.53144 .88037 L
s
.5313 .88127 m
.53169 .88014 L
s
.48315 .91178 m .47492 .91265 L .4739 .91092 L 0 0 .033 r
F
0 g
.47011 .91172 m
.4739 .91092 L
s
.36356 .79934 m .35288 .79793 L .35528 .80485 L 0 1 .413 r
F
0 g
.35177 .81086 m
.35528 .80485 L
s
.38672 .79552 m
.39083 .79057 L
s
.77144 .67237 m .77631 .6602 L .77194 .66071 L 0 1 .418 r
F
.77144 .67237 m .78244 .67085 L .77631 .6602 L F
.77144 .67237 m .78625 .68556 L .78244 .67085 L F
0 g
.77144 .67237 m
.77194 .66071 L
s
.7654 .66151 m
.76604 .66266 L
s
.76892 .66784 m
.77144 .67237 L
s
.42051 .81512 m .40896 .81039 L .41188 .81726 L 0 1 .369 r
F
0 g
.40491 .81486 m
.40896 .81039 L
s
.41894 .91868 m .40797 .91906 L .40641 .91903 L 0 0 0 r
F
.44474 .65277 m .43676 .65556 L .43935 .6552 L 0 1 .24 r
F
.44474 .65277 m .43855 .65371 L .43676 .65556 L F
0 g
.4381 .65711 m
.43935 .6552 L
s
.44474 .65277 m .44355 .65088 L .43855 .65371 L 0 1 .24 r
F
.44474 .65277 m .44894 .64844 L .44355 .65088 L F
.44474 .65277 m .45113 .64803 L .44894 .64844 L F
.44474 .65277 m .44932 .64989 L .45113 .64803 L F
0 g
.44933 .64989 m
.45447 .64735 L
s
.44932 .64989 m
.44933 .64989 L
s
.43935 .6552 m
.44474 .65277 L
s
.45455 .93469 m .45221 .93246 L .44781 .93101 L 0 1 .505 r
F
.41953 .83238 m .41188 .81726 L .40817 .82134 L 0 1 .372 r
F
0 g
.40491 .81486 m
.40817 .82134 L
s
.42249 .79753 m .4137 .7991 L .41827 .80126 L 0 1 .365 r
F
.42051 .81512 m .41827 .80126 L .4137 .7991 L 0 1 .369 r
F
0 g
.40971 .80301 m
.4137 .7991 L
s
.41117 .79182 m
.4137 .7991 L
s
.49665 .90948 m .4901 .9085 L .48953 .90594 L 0 .045 .056 r
F
0 g
.48641 .90634 m
.48953 .90594 L
s
.37776 .89836 m .36747 .89072 L .36539 .89393 L 0 1 .515 r
F
.37776 .89836 m .37187 .89089 L .36747 .89072 L F
.37776 .89836 m .37627 .89417 L .37187 .89089 L F
.38852 .8986 m .37627 .89417 L .37776 .89836 L 0 1 .512 r
F
0 g
.37776 .89836 m
.38207 .90151 L
s
.37567 .90156 m
.37776 .89836 L
s
.50504 .83688 m .50244 .7809 L .50106 .7827 L 0 .637 .28 r
F
.50504 .83688 m .50443 .79651 L .50244 .7809 L F
0 g
.50244 .7809 m
.50249 .77149 L
s
.50453 .78221 m
.50455 .77861 L
s
.4338 .80455 m .42249 .79753 L .42511 .80488 L 0 1 .355 r
F
.76934 1.05862 m .781 1.05392 L .77702 1.0554 L 0 .841 .229 r
F
.75957 1.06239 m .76934 1.05862 L .77106 1.05776 L 0 .776 .205 r
F
.24855 .87129 m .24119 .87666 L .24576 .87661 L 0 1 .53 r
F
.24855 .87129 m .23709 .87124 L .24119 .87666 L F
0 g
.23931 .88209 m
.24119 .87666 L
s
.24576 .87661 m
.25064 .8818 L
s
.45314 .97302 m .44577 .97481 L .45035 .97864 L 0 .608 .389 r
F
0 g
.44577 .97481 m
.44611 .97982 L
s
.41322 .62411 m .41867 .61485 L .42091 .60596 L 0 1 .398 r
F
0 g
.41867 .61485 m
.42459 .6099 L
s
.78244 .67085 m .79694 .69529 L .79738 .6839 L 0 1 .428 r
F
0 g
.78574 .69718 m
.78625 .68556 L
s
.78625 .68556 m
.79246 .69602 L
s
.79694 .69529 m
.80227 .70536 L
s
.46281 .93418 m .45455 .93469 L .45869 .93617 L 0 .967 .493 r
F
.46281 .93418 m .45221 .93246 L .45455 .93469 L F
0 g
.45389 .93671 m
.45455 .93469 L
s
.36956 .91857 m
.36956 .91857 L
s
.4397 .94395 m .43528 .94924 L .4388 .94877 L 0 .727 .39 r
F
.44607 .95863 m .4388 .94877 L .43528 .94924 L 0 .672 .391 r
F
0 g
.43486 .95408 m
.43528 .94924 L
s
.43067 .94498 m
.43528 .94924 L
s
.44394 .92303 m .43419 .92309 L .43859 .92505 L 0 1 .504 r
F
.44394 .92303 m .43214 .92038 L .43419 .92309 L F
0 g
.43289 .92528 m
.43419 .92309 L
s
.40363 .90805 m .39733 .9018 L .39288 .90165 L 0 1 .513 r
F
.40363 .90805 m .40194 .90454 L .39733 .9018 L F
.41447 .90831 m .40194 .90454 L .40363 .90805 L 0 1 .509 r
F
0 g
.40169 .91076 m
.40363 .90805 L
s
.40363 .90805 m
.40811 .91069 L
s
.39776 .74142 m .40024 .73281 L .39916 .72481 L 0 1 .383 r
F
.40345 .91892 m .39727 .91916 L .40155 .91908 L 0 .564 .204 r
F
.40345 .91892 m .39261 .9189 L .39727 .91916 L F
0 g
.39588 .91943 m
.39727 .91916 L
s
.40155 .91908 m
.40641 .91903 L
s
.48678 .9524 m .48411 .95076 L .48059 .94996 L 0 .752 .432 r
F
0 g
.38847 .78333 m
.39083 .79057 L
s
.46372 1.00328 m .45993 .99769 L .45527 .99416 L 0 .514 .394 r
F
.53139 1.08307 m .53694 1.08517 L .53624 1.08589 L 0 0 0 r
F
0 g
.5328 1.08171 m
.53694 1.08517 L
s
.53885 1.08894 m .53625 1.0859 L .53694 1.08518 L 0 .136 0 r
F
0 g
.53694 1.08518 m
.5389 1.08557 L
s
.41954 .8493 m .4115 .85246 L .41615 .85354 L 0 .968 .376 r
F
.42055 .86589 m .41615 .85354 L .4115 .85246 L 0 .934 .379 r
F
0 g
.40846 .85684 m
.4115 .85246 L
s
.4079 .84636 m
.4115 .85246 L
s
.42051 .81512 m .42119 .80813 L .41827 .80126 L 0 1 .369 r
F
0 g
.41827 .80126 m
.42249 .79753 L
s
.45825 .81044 m .44841 .79168 L .44732 .79788 L 0 .914 .332 r
F
.45825 .81044 m .45241 .79115 L .44841 .79168 L F
0 g
.44604 .7837 m
.44841 .79168 L
s
.44841 .79168 m
.45171 .79124 L
s
.50785 .96362 m .50496 .96221 L .50229 .96154 L 0 .472 .254 r
F
.24043 .91088 m .22862 .90271 L .22691 .9062 L 0 1 .518 r
F
.24043 .91088 m .23319 .90287 L .22862 .90271 L F
.24043 .91088 m .23826 .90638 L .23319 .90287 L F
.25167 .9108 m .23826 .90638 L .24043 .91088 L 0 1 .513 r
F
0 g
.23871 .91434 m
.24043 .91088 L
s
.24043 .91088 m
.2454 .91416 L
s
.33175 .88648 m .32209 .87694 L .31987 .881 L 0 1 .52 r
F
.33175 .88648 m .32637 .87707 L .32209 .87694 L F
.33175 .88648 m .33051 .88116 L .32637 .87707 L F
.34231 .88654 m .33051 .88116 L .33175 .88648 L 0 1 .518 r
F
0 g
.32953 .89052 m
.33175 .88648 L
s
.33175 .88648 m
.33583 .89042 L
s
.39776 .74142 m
.39912 .74946 L
s
.39443 .7542 m
.39912 .74946 L
s
.51138 .90828 m .50849 .90164 L .50906 .89709 L 0 .1 .078 r
F
0 g
.50747 .8958 m
.50906 .89709 L
s
.42754 .91839 m
.42759 .91838 L
s
.42759 .91838 m
.42768 .91837 L
s
.44401 .9172 m .43366 .91845 L .43217 .91786 L 0 0 0 r
F
0 g
.42768 .91837 m
.43217 .91786 L
s
.35288 .79793 m .34455 .8038 L .34884 .80418 L 0 1 .42 r
F
0 g
.34884 .80418 m
.35177 .81086 L
s
.4031 .69147 m .39391 .69457 L .39758 .69675 L 0 1 .382 r
F
.4031 .69147 m .39415 .68573 L .39391 .69457 L F
.4031 .69147 m .39814 .67614 L .39415 .68573 L F
0 g
.40307 .7002 m
.4031 .69147 L
s
.76504 .64977 m
.7654 .66151 L
s
.42051 .81512 m .41188 .81726 L .41653 .81904 L 0 1 .369 r
F
.41953 .83238 m .41653 .81904 L .41188 .81726 L 0 1 .372 r
F
0 g
.40817 .82134 m
.41188 .81726 L
s
.40896 .81039 m
.41188 .81726 L
s
.36356 .79934 m .35397 .7892 L .35288 .79793 L 0 1 .413 r
F
.36356 .79934 m .35796 .78318 L .35397 .7892 L F
.36356 .79934 m .36219 .78388 L .35796 .78318 L F
.36356 .79934 m .36458 .79081 L .36219 .78388 L F
0 g
.35957 .80536 m
.36356 .79934 L
s
.40696 .66349 m
.408 .65436 L
s
.40349 .66374 m
.40696 .66349 L
s
.79864 .63193 m
.80372 .6348 L
s
.41953 .83238 m .41115 .83505 L .41582 .83647 L 0 1 .372 r
F
.41954 .8493 m .41582 .83647 L .41115 .83505 L 0 .968 .376 r
F
0 g
.40776 .83929 m
.41115 .83505 L
s
.40787 .82857 m
.41115 .83505 L
s
.28545 .91084 m .27892 .91344 L .2834 .91338 L 0 1 .493 r
F
.28545 .91084 m .27418 .91077 L .27892 .91344 L F
0 g
.27769 .91611 m
.27892 .91344 L
s
.2834 .91338 m
.28877 .91574 L
s
.70564 .80638 m
.70639 .80169 L
s
.46548 .52399 m .47341 .51633 L .47876 .50996 L 0 1 .292 r
F
0 g
.47341 .51633 m
.47994 .51126 L
s
.46069 .79661 m .45241 .79115 L .45665 .79665 L 0 .938 .329 r
F
.45825 .81044 m .45665 .79665 L .45241 .79115 L 0 .914 .332 r
F
0 g
.45171 .79124 m
.45241 .79115 L
s
.45025 .78231 m
.45241 .79115 L
s
.50428 1.05886 m .49814 1.05485 L .50342 1.05976 L 0 .207 .208 r
F
.50428 1.05886 m .49468 1.05075 L .49814 1.05485 L F
.38847 .78333 m .37969 .78753 L .38409 .78866 L 0 1 .392 r
F
0 g
.38409 .78866 m
.38672 .79552 L
s
.38847 .78333 m .37755 .78031 L .37969 .78753 L 0 1 .392 r
F
.38847 .78333 m .3791 .7718 L .37755 .78031 L F
0 g
.38409 .78866 m
.38847 .78333 L
s
.53172 .97511 m .53143 .9736 L .53475 .97481 L 0 0 0 r
F
0 g
.53475 .97481 m
.53493 .97485 L
s
.53172 .97511 m .52827 .97266 L .53143 .9736 L 0 0 0 r
F
0 g
.5296 .97269 m
.53143 .9736 L
s
.53021 .97323 m
.53143 .9736 L
s
.41582 .66793 m .40684 .67042 L .41017 .67021 L 0 1 .36 r
F
.41582 .66793 m .40776 .66852 L .40684 .67042 L F
0 g
.41016 .67021 m
.41018 .67021 L
s
.41018 .67021 m
.41174 .67071 L
s
.41582 .66793 m .41232 .66577 L .40776 .66852 L 0 1 .36 r
F
.41582 .66793 m .41799 .66349 L .41232 .66577 L F
.41582 .66793 m .42098 .66319 L .41799 .66349 L F
.41582 .66793 m .42004 .66509 L .42098 .66319 L F
0 g
.41518 .66976 m
.41582 .66793 L
s
.41017 .67021 m
.41582 .66793 L
s
.73856 .77178 m
.73886 .77138 L
s
.48547 .81968 m .47758 .78682 L .47634 .79139 L 0 .788 .306 r
F
.48547 .81968 m .48108 .79251 L .47758 .78682 L F
0 g
.47593 .77605 m
.47758 .78682 L
s
.47882 .78234 m
.4801 .78812 L
s
.47924 .78093 m
.48202 .78921 L
s
.48063 .77648 m
.48189 .78788 L
s
.47758 .78682 m
.48017 .79104 L
s
.4451 .81327 m .43473 .79789 L .4338 .80455 L 0 .953 .346 r
F
.4451 .81327 m .43876 .79578 L .43473 .79789 L F
0 g
.43211 .79054 m
.43473 .79789 L
s
.43473 .79789 m
.43784 .79626 L
s
.39776 .74142 m .38869 .74487 L .39281 .74659 L 0 1 .383 r
F
.39776 .74142 m .38761 .73687 L .38869 .74487 L F
.39776 .74142 m .39029 .72791 L .38761 .73687 L F
.39776 .74142 m .39524 .72275 L .39029 .72791 L F
.39776 .74142 m .39916 .72481 L .39524 .72275 L F
0 g
.39916 .72481 m
.40431 .71978 L
s
.39916 .72481 m
.40024 .73281 L
s
.37566 .79291 m
.37969 .78753 L
s
.41322 .62411 m .42091 .60596 L .41845 .60336 L 0 1 .398 r
F
0 g
.42091 .60596 m
.42713 .60118 L
s
.41867 .61485 m
.42091 .60596 L
s
.39247 .76262 m
.39434 .77026 L
s
.39421 .7704 m
.39434 .77026 L
s
.3942 .77041 m
.39421 .7704 L
s
.39419 .77041 m
.3942 .77041 L
s
.408 .65436 m .399 .65721 L .40215 .65966 L 0 1 .386 r
F
.408 .65436 m .40039 .64808 L .399 .65721 L F
.408 .65436 m .40539 .63835 L .40039 .64808 L F
.408 .65436 m .41125 .63306 L .40539 .63835 L F
0 g
.40215 .65966 m
.408 .65436 L
s
.44732 .79788 m .43876 .79578 L .44318 .79964 L 0 .981 .342 r
F
.4451 .81327 m .44318 .79964 L .43876 .79578 L 0 .953 .346 r
F
0 g
.43784 .79626 m
.43876 .79578 L
s
.43639 .7878 m
.43876 .79578 L
s
.50504 .83688 m .50106 .7827 L .50131 .79991 L 0 .637 .28 r
F
0 g
.49872 .76985 m
.50106 .7827 L
s
.35288 .79793 m .34219 .79683 L .34455 .8038 L 0 1 .42 r
F
0 g
.34103 .81002 m
.34455 .8038 L
s
.77858 .89186 m .78391 .89756 L .78847 .8948 L 0 1 .454 r
F
.77858 .89186 m .77938 .89756 L .78391 .89756 L F
0 g
.78391 .89756 m
.78525 .9003 L
s
.41894 .91868 m .41226 .91911 L .40797 .91906 L 0 0 0 r
F
.41894 .91868 m .41696 .91894 L .41226 .91911 L F
.42929 .91873 m .41696 .91894 L .41894 .91868 L F
0 g
.41894 .91868 m
.42347 .91844 L
s
.41737 .91865 m
.41894 .91868 L
s
.43206 .82103 m .42119 .80813 L .42051 .81512 L 0 .981 .359 r
F
.43206 .82103 m .42511 .80488 L .42119 .80813 L F
0 g
.41827 .80126 m
.42119 .80813 L
s
.40342 .77076 m .3923 .77094 L .39433 .77041 L 0 0 0 r
F
0 g
.38991 .77511 m
.39374 .77091 L
s
.39415 .77046 m
.39419 .77041 L
s
.39419 .77041 m
.39433 .77041 L
s
.47112 .81454 m .46182 .79105 L .46069 .79661 L 0 .858 .32 r
F
.47112 .81454 m .46568 .79273 L .46182 .79105 L F
0 g
.45966 .78221 m
.46182 .79105 L
s
.46182 .79105 m
.46535 .79258 L
s
.38844 .77012 m
.38848 .77026 L
s
.38848 .77026 m
.38851 .77037 L
s
.38851 .77037 m
.38991 .77511 L
s
.51935 .902 m .51836 .89807 L .51925 .89137 L 0 .106 .085 r
F
0 g
.51925 .89137 m
.51953 .89038 L
s
.51747 .90329 m .51925 .89137 L .51836 .89808 L 0 .107 .084 r
F
0 g
.51925 .89137 m
.51925 .89137 L
s
.51772 .88853 m
.51825 .89231 L
s
.44394 .92303 m .43859 .92505 L .44241 .92496 L 0 1 .504 r
F
.44891 .92902 m .44241 .92496 L .43859 .92505 L 0 1 .505 r
F
0 g
.4375 .92704 m
.43859 .92505 L
s
.43419 .92309 m
.43859 .92505 L
s
.4338 .80455 m .42511 .80488 L .42967 .80755 L 0 1 .355 r
F
.43206 .82103 m .42967 .80755 L .42511 .80488 L 0 .981 .359 r
F
0 g
.42119 .80813 m
.42511 .80488 L
s
.42249 .79753 m
.42511 .80488 L
s
.29624 .54988 m .28419 .55671 L .28803 .55788 L 0 1 .454 r
F
0 g
.28634 .56685 m
.28803 .55788 L
s
.29624 .54988 m .28685 .54708 L .28419 .55671 L 0 1 .454 r
F
.29624 .54988 m .29424 .53539 L .28685 .54708 L F
.29624 .54988 m .30247 .52738 L .29424 .53539 L F
.29624 .54988 m .30603 .52838 L .30247 .52738 L F
.29624 .54988 m .30336 .53803 L .30603 .52838 L F
0 g
.29377 .55982 m
.29624 .54988 L
s
.28803 .55788 m
.29624 .54988 L
s
.49665 .90948 m .49403 .90482 L .49607 .90692 L 0 .045 .056 r
F
.49995 .90613 m .49607 .90692 L .49403 .90482 L 0 .023 .055 r
F
0 g
.49383 .90202 m
.49403 .90482 L
s
.49312 .90468 m
.49403 .90482 L
s
.4292 .77066 m .42036 .77088 L .42469 .77023 L 0 0 0 r
F
0 g
.42469 .77023 m
.42597 .76953 L
s
.59699 .64105 m .60783 .63172 L .61056 .63188 L 0 0 .017 r
F
.59699 .64105 m .60202 .63564 L .60783 .63172 L F
0 g
.60783 .63172 m
.60923 .62855 L
s
.60202 .63564 m
.60202 .63564 L
s
.60202 .63564 m
.60364 .63109 L
s
.60202 .63564 m
.60783 .63172 L
s
.47352 .80291 m .4746 .79828 L .4726 .78824 L 0 .876 .317 r
F
0 g
.4728 .78928 m
.47296 .79005 L
s
.4726 .78824 m
.4728 .78928 L
s
.49147 .80129 m .49265 .79838 L .49159 .7846 L 0 .795 .298 r
F
0 g
.49159 .7846 m
.49195 .7858 L
s
.39246 .76262 m .39443 .7542 L .39281 .74659 L 0 1 .387 r
F
.41953 .83238 m .4198 .82552 L .41653 .81904 L 0 1 .372 r
F
.57141 .69026 m .57307 .68041 L .57064 .69175 L 0 .769 .072 r
F
.56524 .74253 m .57141 .69026 L .56704 .71418 L 0 1 .226 r
F
.70707 1.08098 m .70123 1.0797 L .6995 1.07794 L 0 0 0 r
F
0 g
.6995 1.07794 m
.70123 1.0797 L
s
.69194 1.07756 m
.6995 1.07794 L
s
.39246 .76262 m .38349 .76647 L .38778 .76788 L 0 1 .387 r
F
0 g
.38778 .76788 m
.38844 .77012 L
s
.39246 .76262 m .38187 .75887 L .38349 .76647 L 0 1 .387 r
F
.39246 .76262 m .384 .75013 L .38187 .75887 L F
.39246 .76262 m .38869 .74487 L .384 .75013 L F
.39246 .76262 m .39281 .74659 L .38869 .74487 L F
0 g
.38778 .76788 m
.39246 .76262 L
s
.39281 .74659 m
.39776 .74142 L
s
.39281 .74659 m
.39443 .7542 L
s
.44989 .54742 m .4415 .55043 L .44317 .55221 L 0 1 .381 r
F
.44989 .54742 m .44603 .54328 L .4415 .55043 L F
.44989 .54742 m .45374 .53554 L .44603 .54328 L F
.44989 .54742 m .46045 .53077 L .45374 .53554 L F
0 g
.44568 .55495 m
.44989 .54742 L
s
.26001 .87137 m .2526 .87655 L .25717 .87651 L 0 1 .529 r
F
.26001 .87137 m .24855 .87129 L .2526 .87655 L F
0 g
.25064 .8818 m
.2526 .87655 L
s
.25717 .87651 m
.26198 .88153 L
s
.43206 .82103 m .42051 .81512 L .42349 .82205 L 0 .981 .359 r
F
0 g
.41653 .81904 m
.42051 .81512 L
s
.25426 .68199 m .24367 .68618 L .24811 .68697 L 0 1 .525 r
F
0 g
.24811 .68697 m
.24947 .69315 L
s
.63572 .75989 m
.63596 .75747 L
s
.63639 .75318 m
.63648 .75225 L
s
.63648 .75225 m
.63696 .74746 L
s
.47767 .76864 m
.47785 .76763 L
s
.49231 1.04583 m .48758 1.0406 L .48319 1.03726 L 0 .306 .305 r
F
.70772 .65152 m .72195 .63342 L .71766 .64738 L 0 .183 .096 r
F
0 g
.72195 .63342 m
.72201 .62349 L
s
.72195 .63342 m
.72649 .626 L
s
.48377 1.03072 m .47599 1.02736 L .48059 1.03268 L 0 .328 .343 r
F
.48377 1.03072 m .47374 1.02272 L .47599 1.02736 L F
0 g
.47136 1.02404 m
.47599 1.02736 L
s
.34219 .79683 m .33381 .80299 L .33811 .80329 L 0 1 .428 r
F
0 g
.33811 .80329 m
.34103 .81002 L
s
.37849 .77009 m
.37862 .7701 L
s
.37862 .7701 m
.37914 .77016 L
s
.37914 .77016 m
.38043 .77019 L
s
.51747 .90329 m .5175 .89879 L .51825 .89231 L 0 .107 .084 r
F
0 g
.51825 .89231 m
.51912 .88722 L
s
.51622 .90424 m .51825 .89231 L .5175 .89879 L 0 .099 .082 r
F
0 g
.51825 .89231 m
.51825 .89231 L
s
.55095 .61422 m .55652 .61399 L .56191 .61729 L 0 .241 .066 r
F
0 g
.55652 .61399 m
.55948 .60963 L
s
.3548 .59045 m .35062 .58817 L .3463 .57676 L 0 .581 .046 r
F
.3548 .59045 m .35467 .59582 L .35062 .58817 L F
.35467 .59582 m .35102 .58896 L .35062 .58817 L F
.3548 .59045 m .35644 .59731 L .35465 .59634 L F
.35467 .59582 m .35465 .59634 L .35102 .58896 L F
.35985 .59855 m .35062 .58828 L .35465 .5966 L 0 1 .501 r
F
.36006 .5982 m .35989 .59846 L .35985 .59855 L 0 1 .308 r
F
.36252 .59955 m .36037 .59751 L .35985 .59855 L 0 1 .501 r
F
.36037 .59751 m .35062 .58828 L .35985 .59855 L F
.35985 .59855 m .34992 .61431 L .35435 .60778 L 0 1 .308 r
F
.35989 .59846 m .34992 .61431 L .35985 .59855 L F
.36267 .59382 m .36037 .59751 L .36006 .5982 L F
.36037 .59751 m .34992 .61431 L .36006 .5982 L F
.36037 .59751 m .35201 .60675 L .34992 .61431 L F
.36267 .59382 m .36756 .57619 L .36325 .58343 L F
.36267 .59382 m .36933 .58169 L .37143 .57414 L F
.36267 .59382 m .37143 .57414 L .36756 .57619 L F
.36252 .59955 m .36735 .58495 L .36325 .58343 L 0 1 .501 r
F
.36125 .59231 m .36325 .58343 L .35945 .58201 L F
.36267 .59382 m .36325 .58343 L .36275 .58564 L 0 1 .308 r
F
.36267 .59382 m .36277 .58424 L .36125 .59231 L F
.36267 .59382 m .36066 .59625 L .36044 .5974 L F
.36055 .59605 m .35945 .58201 L .35267 .58203 L 0 1 .501 r
F
.36066 .59625 m .36062 .59569 L .36055 .59605 L F
.36062 .59569 m .35945 .58201 L .36055 .59605 L F
.36037 .5975 m .35267 .58203 L .35063 .58825 L F
.36044 .5974 m .36066 .59625 L .36037 .59751 L 0 1 .308 r
F
.36082 .59652 m .35267 .58203 L .36037 .59751 L 0 1 .501 r
F
.36252 .59955 m .35063 .58825 L .35068 .58834 L F
.36066 .59625 m .35924 .59016 L .35201 .60675 L 0 1 .308 r
F
.36267 .59382 m .36125 .59231 L .36066 .59625 L F
.36125 .59231 m .35945 .58201 L .36066 .59625 L 0 1 .501 r
F
.36125 .59231 m .35924 .59016 L .36066 .59625 L 0 1 .308 r
F
.36134 .59281 m .36125 .59231 L .36066 .59625 L 0 1 .501 r
F
.36252 .59955 m .36325 .58343 L .36125 .59231 L F
.36275 .58564 m .36325 .58343 L .36277 .58424 L 0 1 .308 r
F
.36125 .59231 m .36277 .58424 L .35924 .59016 L F
.36252 .59955 m .36134 .59281 L .36066 .59625 L 0 1 .501 r
F
.36066 .59625 m .35201 .60675 L .36037 .59751 L 0 1 .308 r
F
.36252 .59955 m .36082 .59652 L .36037 .59751 L 0 1 .501 r
F
.35068 .58834 m .35063 .58825 L .35062 .58828 L F
0 g
.35048 .57907 m
.35218 .58354 L
s
.42548 .89808 m .42419 .89175 L .41988 .88665 L 0 .86 .385 r
F
.41954 .8493 m .41941 .84257 L .41582 .83647 L 0 .968 .376 r
F
.46084 .98717 m .45089 .98349 L .45443 .9892 L 0 .534 .384 r
F
.46084 .98717 m .45035 .97864 L .45089 .98349 L F
0 g
.44611 .97982 m
.45089 .98349 L
s
.35288 .79793 m .34333 .78792 L .34219 .79683 L 0 1 .42 r
F
.35288 .79793 m .34737 .78166 L .34333 .78792 L F
.35288 .79793 m .35161 .78223 L .34737 .78166 L F
.35288 .79793 m .35397 .7892 L .35161 .78223 L F
0 g
.35288 .79793 m
.35528 .80485 L
s
.34884 .80418 m
.35288 .79793 L
s
.42936 .91369 m .4277 .90749 L .42324 .90269 L 0 .82 .387 r
F
.42253 .88215 m .42162 .87569 L .4175 .87027 L 0 .898 .382 r
F
.77858 .89186 m .77709 .89513 L .77938 .89756 L 0 1 .454 r
F
0 g
.77403 .90001 m
.77938 .89756 L
s
.45825 .81044 m .44732 .79788 L .44982 .80615 L 0 .914 .332 r
F
.4451 .81327 m .4338 .80455 L .43651 .81205 L 0 .953 .346 r
F
.46281 .93418 m .45311 .93073 L .45221 .93246 L 0 .967 .493 r
F
0 g
.44781 .93101 m
.45221 .93246 L
s
.36703 .68335 m .35772 .68198 L .35758 .68424 L 0 1 .488 r
F
0 g
.35226 .68631 m
.35758 .68424 L
s
.42932 .91621 m .41882 .91088 L .41705 .91306 L 0 1 .508 r
F
0 g
.41239 .91072 m
.41705 .91306 L
s
.44607 .95863 m .44244 .96411 L .44564 .96348 L 0 .672 .391 r
F
.45314 .97302 m .44564 .96348 L .44244 .96411 L 0 .608 .389 r
F
0 g
.44244 .96411 m
.4425 .96896 L
s
.43782 .96008 m
.44244 .96411 L
s
.78685 .78495 m .79907 .78554 L .79856 .78865 L 0 .063 0 r
F
0 g
.79907 .78554 m
.80296 .78451 L
s
.79633 .78218 m
.79907 .78554 L
s
.48021 .94823 m .47767 .9465 L .47393 .94557 L 0 .832 .46 r
F
.42055 .86589 m .42002 .8593 L .41615 .85354 L 0 .934 .379 r
F
.76337 .7744 m .77125 .78235 L .76656 .78027 L 0 .216 .019 r
F
.76337 .7744 m .77512 .78028 L .77125 .78235 L F
.47246 .7684 m .46514 .77246 L .46857 .76947 L 0 .191 .065 r
F
.47246 .7684 m .46414 .77616 L .46514 .77246 L F
.47246 .7684 m .46626 .7781 L .46414 .77616 L F
.47246 .7684 m .47017 .77702 L .46626 .7781 L F
0 g
.46857 .76947 m
.4686 .76946 L
s
.47246 .7684 m .47324 .77366 L .47017 .77702 L 0 .191 .065 r
F
0 g
.46857 .76947 m
.46943 .76845 L
s
.46943 .76845 m
.47076 .76689 L
s
.47246 .7684 m .47422 .76997 L .47324 .77366 L 0 .191 .065 r
F
0 g
.47246 .7684 m
.47361 .76442 L
s
.4686 .76946 m
.47246 .7684 L
s
.47422 .76997 m
.47785 .76763 L
s
.46548 .52399 m .47876 .50996 L .47797 .50909 L 0 1 .292 r
F
0 g
.47876 .50996 m
.4854 .50495 L
s
.47341 .51633 m
.47876 .50996 L
s
.73686 .61868 m .7492 .62336 L .7534 .62332 L 0 .922 .361 r
F
.73686 .61868 m .74212 .62138 L .7492 .62336 L F
0 g
.74863 .6232 m
.7492 .62336 L
s
.73767 .64071 m .74248 .63079 L .7492 .62336 L 0 .052 .051 r
F
0 g
.74753 .62521 m
.74854 .62409 L
s
.74854 .62409 m
.7492 .62336 L
s
.74288 .63034 m
.74289 .62727 L
s
.74289 .62727 m
.74291 .62354 L
s
.49473 .62533 m .50006 .62283 L .50381 .62199 L 0 0 0 r
F
0 g
.49136 .62632 m
.49473 .62533 L
s
.40214 .66672 m
.40366 .67087 L
s
.39814 .67614 m
.40055 .67384 L
s
.40324 .67128 m
.40366 .67087 L
s
.40055 .67384 m
.40069 .67371 L
s
.40069 .67371 m
.40076 .67364 L
s
.40076 .67364 m
.40234 .67213 L
s
.36703 .68335 m .3617 .67956 L .35772 .68198 L 0 1 .488 r
F
.36703 .68335 m .36737 .67805 L .3617 .67956 L F
.36703 .68335 m .37094 .67845 L .36737 .67805 L F
.36703 .68335 m .37079 .68072 L .37094 .67845 L F
0 g
.36703 .68335 m
.36706 .6856 L
s
.36138 .68485 m
.36703 .68335 L
s
.48227 .4781 m .47371 .48438 L .47477 .4826 L 0 0 0 r
F
0 g
.47463 .48111 m
.47617 .47998 L
s
.48227 .4781 m .48009 .48301 L .47371 .48438 L 0 0 0 r
F
0 g
.46897 .48526 m
.47463 .48111 L
s
.48227 .4781 m .48966 .4794 L .48009 .48301 L 0 0 0 r
F
.48227 .4781 m .49716 .47489 L .48966 .4794 L F
.48227 .4781 m .4976 .47249 L .49716 .47489 L F
0 g
.4976 .47249 m
.50467 .4685 L
s
.49122 .47387 m
.4976 .47249 L
s
.32937 .68528 m .32341 .67796 L .31956 .6823 L 0 1 .54 r
F
0 g
.31956 .6823 m
.31967 .68633 L
s
.32937 .68528 m .32915 .67585 L .32341 .67796 L 0 1 .54 r
F
.32937 .68528 m .33294 .67738 L .32915 .67585 L F
.32937 .68528 m .33303 .68143 L .33294 .67738 L F
0 g
.32937 .68528 m
.32961 .68883 L
s
.32365 .68738 m
.32937 .68528 L
s
.43206 .82103 m .43265 .81448 L .42967 .80755 L 0 .981 .359 r
F
0 g
.42967 .80755 m
.4338 .80455 L
s
.70707 1.08098 m .71019 1.07643 L .7163 1.07691 L 0 0 0 r
F
0 g
.703 1.07687 m
.71019 1.07643 L
s
.70824 1.07537 m
.71019 1.07643 L
s
.51752 .79958 m
.51907 .7812 L
s
.4451 .81327 m .4459 .80714 L .44318 .79964 L 0 .953 .346 r
F
0 g
.44318 .79964 m
.44732 .79788 L
s
.43118 .83724 m .4198 .82552 L .41953 .83238 L 0 .95 .362 r
F
.43118 .83724 m .42349 .82205 L .4198 .82552 L F
0 g
.41653 .81904 m
.4198 .82552 L
s
.50342 1.05976 m
.50724 1.06365 L
s
.50724 1.06365 m
.51137 1.0671 L
s
.67248 .62244 m
.67309 .62292 L
s
.6674 .62387 m
.66747 .62386 L
s
.67072 .62359 m
.67328 .62337 L
s
.42754 .91839 m
.42764 .9184 L
s
.31956 .6823 m .30753 .68287 L .31276 .6844 L 0 1 .533 r
F
0 g
.31276 .6844 m
.31443 .68933 L
s
.34219 .79683 m .33148 .79598 L .33381 .80299 L 0 1 .428 r
F
0 g
.33028 .80941 m
.33381 .80299 L
s
.79346 .66943 m .80367 .69424 L .80817 .69357 L 0 1 .438 r
F
.79346 .66943 m .79738 .6839 L .80367 .69424 L F
0 g
.80227 .70536 m
.80367 .69424 L
s
.37755 .78031 m .36867 .7851 L .37308 .78601 L 0 1 .4 r
F
0 g
.37308 .78601 m
.37566 .79291 L
s
.51509 .96708 m .51218 .9657 L .50986 .96498 L 0 .403 .224 r
F
.65063 .73081 m .65387 .69996 L .64979 .68179 L 0 .32 .232 r
F
0 g
.64979 .68179 m
.64999 .69355 L
s
.65062 .73013 m
.65063 .73081 L
s
.64999 .69355 m
.65029 .71077 L
s
.65029 .71077 m
.65062 .73013 L
s
.65059 .73035 m
.65063 .73081 L
s
.64916 .71342 m
.65059 .73035 L
s
.64804 .66705 m
.64979 .68179 L
s
.39471 .71435 m .39792 .70522 L .39758 .69675 L 0 1 .385 r
F
0 g
.39792 .70522 m
.40307 .7002 L
s
.41322 .62411 m .40421 .62634 L .40703 .62904 L 0 1 .398 r
F
.41322 .62411 m .40645 .61744 L .40421 .62634 L F
.41322 .62411 m .41225 .60828 L .40645 .61744 L F
.41322 .62411 m .41845 .60336 L .41225 .60828 L F
0 g
.41125 .63306 m
.41322 .62411 L
s
.72551 1.07331 m .7369 1.07057 L .73314 1.07203 L 0 0 0 r
F
.7163 1.07691 m .72551 1.07331 L .7275 1.07437 L F
.47352 .80291 m .46568 .79273 L .4697 .80053 L 0 .876 .317 r
F
.47112 .81454 m .4697 .80053 L .46568 .79273 L 0 .858 .32 r
F
0 g
.46369 .7827 m
.46568 .79273 L
s
.46535 .79258 m
.46568 .79273 L
s
.37755 .78031 m .36661 .77784 L .36867 .7851 L 0 1 .4 r
F
0 g
.37755 .78031 m
.37969 .78753 L
s
.36459 .79081 m
.36867 .7851 L
s
.37308 .78601 m
.37755 .78031 L
s
.79155 .61896 m .80693 .6161 L .80228 .6189 L 0 0 0 r
F
0 g
.80693 .6161 m
.80708 .61349 L
s
.43118 .83724 m .41953 .83238 L .42282 .83889 L 0 .95 .362 r
F
0 g
.41953 .83238 m
.42081 .83491 L
s
.41582 .83647 m
.41953 .83238 L
s
.50279 .83841 m .49902 .78574 L .49769 .78799 L 0 .646 .284 r
F
.50279 .83841 m .50131 .79991 L .49902 .78574 L F
0 g
.49872 .76985 m
.49902 .78574 L
s
.50106 .7827 m
.50113 .78778 L
s
.50244 .7809 m
.50325 .78725 L
s
.36344 .88714 m .35682 .89045 L .36102 .89053 L 0 1 .514 r
F
0 g
.36102 .89053 m
.36539 .89393 L
s
.36344 .88714 m .35287 .88675 L .35682 .89045 L 0 1 .514 r
F
0 g
.35498 .8939 m
.35682 .89045 L
s
.40342 .77076 m .3941 .77152 L .3923 .77094 L 0 0 0 r
F
.40342 .77076 m .39871 .77198 L .3941 .77152 L F
0 g
.3923 .77094 m
.39433 .77041 L
s
.40342 .77076 m .40304 .77202 L .39871 .77198 L 0 0 0 r
F
.40342 .77076 m .40506 .7715 L .40304 .77202 L F
0 g
.40077 .77049 m
.40342 .77076 L
s
.40342 .77076 m
.40429 .77041 L
s
.46281 .93418 m .45869 .93617 L .4619 .93591 L 0 .967 .493 r
F
.46817 .93913 m .4619 .93591 L .45869 .93617 L 0 .935 .488 r
F
0 g
.45822 .93793 m
.45869 .93617 L
s
.45455 .93469 m
.45869 .93617 L
s
.42128 .59487 m .4275 .58616 L .4306 .57795 L 0 1 .414 r
F
0 g
.4275 .58616 m
.43371 .58139 L
s
.58452 .48179 m
.58983 .48035 L
s
.7831 1.0499 m .781 1.05392 L .788 1.04959 L 0 .961 .237 r
F
.7831 1.0499 m .77702 1.0554 L .781 1.05392 L F
0 g
.77908 1.05533 m
.781 1.05392 L
s
.52232 .9705 m .52578 .97168 L .52504 .97159 L 0 .31 .193 r
F
0 g
.52556 .97159 m
.52578 .97168 L
s
.52605 .97228 m .52504 .97159 L .52578 .97169 L 0 0 0 r
F
0 g
.52578 .97169 m
.52588 .97171 L
s
.48547 .81968 m .47634 .79139 L .47821 .80302 L 0 .788 .306 r
F
0 g
.4726 .78824 m
.47634 .79139 L
s
.48869 .80895 m .48204 .78928 L .48538 .80185 L 0 .794 .301 r
F
0 g
.48189 .78788 m
.48204 .78928 L
s
.48733 .81308 m .48538 .80186 L .48204 .78928 L 0 .795 .304 r
F
0 g
.48202 .78921 m
.48204 .78928 L
s
.22824 .93232 m .22224 .9339 L .2267 .93391 L 0 .75 .287 r
F
0 g
.2267 .93391 m
.23273 .93543 L
s
.22824 .93232 m .217 .93204 L .22224 .9339 L 0 .75 .287 r
F
0 g
.2217 .93566 m
.22224 .9339 L
s
.72646 .89848 m .73779 .89753 L .73221 .89751 L 0 .781 .294 r
F
.7159 .89801 m .72646 .89848 L .72483 .89746 L 0 .674 .252 r
F
.45825 .81044 m .45915 .80492 L .45665 .79665 L 0 .914 .332 r
F
.43206 .82103 m .42349 .82205 L .42813 .82428 L 0 .981 .359 r
F
.43118 .83724 m .42813 .82428 L .42349 .82205 L 0 .95 .362 r
F
0 g
.4198 .82552 m
.42349 .82205 L
s
.42051 .81512 m
.42349 .82205 L
s
.44394 .92303 m .43366 .91845 L .43214 .92038 L 0 1 .504 r
F
0 g
.42838 .91875 m
.43214 .92038 L
s
.43118 .85318 m .41941 .84257 L .41954 .8493 L 0 .917 .365 r
F
.43118 .85318 m .42282 .83889 L .41941 .84257 L F
0 g
.41582 .83647 m
.41941 .84257 L
s
.42004 .66509 m
.42545 .66273 L
s
.50898 .91051 m .50692 .89921 L .50849 .90164 L 0 .105 .078 r
F
.50898 .91051 m .50549 .90062 L .50692 .89921 L F
0 g
.50692 .89921 m
.50747 .8958 L
s
.49231 1.04583 m .49468 1.05075 L .49535 1.05019 L 0 .306 .305 r
F
.50428 1.05886 m .49535 1.05019 L .49468 1.05075 L 0 .207 .208 r
F
0 g
.49468 1.05075 m
.49814 1.05485 L
s
.49029 1.0474 m
.49468 1.05075 L
s
.40214 .66671 m .40349 .66373 L .40214 .65967 L 0 1 .386 r
F
.27147 .87147 m .26402 .87647 L .26859 .87645 L 0 1 .527 r
F
.27147 .87147 m .26001 .87137 L .26402 .87647 L F
0 g
.26198 .88153 m
.26402 .87647 L
s
.26859 .87645 m
.27332 .8813 L
s
.47112 .81454 m .46069 .79661 L .46301 .80595 L 0 .858 .32 r
F
0 g
.45665 .79665 m
.46069 .79661 L
s
.71675 .62032 m .72004 .6183 L .71609 .61879 L 0 .683 .253 r
F
.71675 .62032 m .72679 .61955 L .72004 .6183 L F
.36657 .91694 m .36068 .91789 L .36477 .91784 L 0 .765 .292 r
F
.36657 .91694 m .35626 .91685 L .36068 .91789 L F
0 g
.35947 .91889 m
.36068 .91789 L
s
.36477 .91784 m
.36956 .91857 L
s
.43118 .85318 m .41954 .8493 L .42312 .85543 L 0 .917 .365 r
F
0 g
.41954 .8493 m
.42093 .85168 L
s
.41615 .85354 m
.41954 .8493 L
s
.41615 .85354 m
.41662 .85425 L
s
.4397 .94395 m .43737 .938 L .43275 .93374 L 0 .727 .39 r
F
.39976 .89916 m .39288 .90165 L .39733 .9018 L 0 1 .509 r
F
.39976 .89916 m .38853 .8986 L .39288 .90165 L F
0 g
.39094 .90438 m
.39288 .90165 L
s
.82439 .889 m .83391 .89358 L .83583 .88833 L 0 1 .511 r
F
0 g
.8291 .8975 m
.83391 .89358 L
s
.36661 .77784 m
.36867 .7851 L
s
.34231 .88654 m .33279 .87731 L .33051 .88116 L 0 1 .518 r
F
.34231 .88654 m .33707 .87749 L .33279 .87731 L F
.34231 .88654 m .34115 .88145 L .33707 .87749 L F
.35287 .88675 m .34115 .88145 L .34231 .88654 L 0 1 .516 r
F
0 g
.34002 .89038 m
.34231 .88654 L
s
.34231 .88654 m
.34632 .89036 L
s
.25167 .9108 m .24005 .90311 L .23826 .90638 L 0 1 .513 r
F
.25167 .9108 m .24462 .90328 L .24005 .90311 L F
.25167 .9108 m .24961 .90659 L .24462 .90328 L F
.26292 .91076 m .24961 .90659 L .25167 .9108 L 0 1 .508 r
F
0 g
.24987 .91404 m
.25167 .9108 L
s
.25167 .9108 m
.25657 .91387 L
s
.33148 .79598 m .32306 .8024 L .32736 .80261 L 0 1 .435 r
F
0 g
.32736 .80261 m
.33028 .80941 L
s
.53475 .97481 m
.53501 .975 L
s
.25426 .68199 m .24327 .67974 L .24367 .68618 L 0 1 .525 r
F
0 g
.23831 .69145 m
.24367 .68618 L
s
.38043 .77019 m
.38349 .76647 L
s
.3791 .7718 m
.38043 .77019 L
s
.46084 .98717 m .45443 .9892 L .45893 .99287 L 0 .534 .384 r
F
0 g
.45443 .9892 m
.45527 .99416 L
s
.43204 .86884 m .42002 .8593 L .42055 .86589 L 0 .883 .368 r
F
.43204 .86884 m .42312 .85543 L .42002 .8593 L F
0 g
.41662 .85425 m
.42002 .8593 L
s
.26019 .57275 m .2481 .57966 L .25221 .58047 L 0 1 .48 r
F
0 g
.25125 .58921 m
.25221 .58047 L
s
.27656 .56408 m
.28419 .55671 L
s
.4581 .91507 m .45207 .9169 L .44824 .91671 L 0 0 0 r
F
.4581 .91507 m .4563 .9162 L .45207 .9169 L F
.46718 .91621 m .4581 .91507 L .4621 .91454 L 0 0 .005 r
F
.46718 .91621 m .4563 .9162 L .4581 .91507 L F
0 g
.4568 .91419 m
.4581 .91507 L
s
.76712 .89262 m .77259 .89757 L .77709 .89513 L 0 1 .426 r
F
.76712 .89262 m .76805 .89757 L .77259 .89757 L F
0 g
.77259 .89757 m
.77403 .90001 L
s
.37862 .7701 m
.3791 .7718 L
s
.37855 .76986 m
.37862 .7701 L
s
.39471 .71435 m .38544 .71805 L .38936 .71985 L 0 1 .385 r
F
.39471 .71435 m .38509 .70957 L .38544 .71805 L F
.39471 .71435 m .38855 .70006 L .38509 .70957 L F
.39471 .71435 m .39391 .69457 L .38855 .70006 L F
.39471 .71435 m .39758 .69675 L .39391 .69457 L F
0 g
.39471 .71435 m
.39524 .72275 L
s
.39758 .69675 m
.4031 .69147 L
s
.39758 .69675 m
.39792 .70522 L
s
.43204 .86884 m .42055 .86589 L .42437 .87164 L 0 .883 .368 r
F
0 g
.42055 .86589 m
.42203 .86813 L
s
.4175 .87027 m
.42055 .86589 L
s
.4175 .87027 m
.4177 .87053 L
s
.44359 .82845 m .43265 .81448 L .43206 .82103 L 0 .924 .349 r
F
.44359 .82845 m .43651 .81205 L .43265 .81448 L F
0 g
.42967 .80755 m
.43265 .81448 L
s
.43265 .81448 m
.43552 .81267 L
s
.49473 .62533 m .4893 .62888 L .49011 .62792 L 0 0 0 r
F
0 g
.48938 .62756 m
.49136 .62632 L
s
.49473 .62533 m .49305 .62805 L .4893 .62888 L 0 0 0 r
F
0 g
.4868 .62918 m
.48938 .62756 L
s
.49473 .62533 m .49887 .62597 L .49305 .62805 L 0 0 0 r
F
.49473 .62533 m .50348 .62338 L .49887 .62597 L F
.49473 .62533 m .50381 .62199 L .50348 .62338 L F
0 g
.50381 .62199 m
.50809 .61918 L
s
.50006 .62283 m
.50381 .62199 L
s
.34219 .79683 m .33268 .78692 L .33148 .79598 L 0 1 .428 r
F
.34219 .79683 m .33677 .78045 L .33268 .78692 L F
.34219 .79683 m .34101 .7809 L .33677 .78045 L F
.34219 .79683 m .34333 .78792 L .34101 .7809 L F
0 g
.34219 .79683 m
.34455 .8038 L
s
.33811 .80329 m
.34219 .79683 L
s
.55021 1.0985 m .54689 1.09093 L .55305 1.09519 L 0 .18 0 r
F
.55021 1.0985 m .54165 1.08843 L .54689 1.09093 L F
.4292 .77066 m .41854 .77223 L .42036 .77088 L 0 0 0 r
F
.4292 .77066 m .42045 .77339 L .41854 .77223 L F
0 g
.4197 .77085 m
.42036 .77088 L
s
.416 .77071 m
.4197 .77085 L
s
.4292 .77066 m .42497 .77382 L .42045 .77339 L 0 0 0 r
F
.4292 .77066 m .42909 .77324 L .42497 .77382 L F
.4292 .77066 m .4309 .77189 L .42909 .77324 L F
0 g
.4292 .77066 m
.43103 .76903 L
s
.42469 .77023 m
.4292 .77066 L
s
.30336 .53803 m
.31136 .53004 L
s
.40214 .66671 m .39546 .66487 L .3987 .6672 L 0 1 .386 r
F
.40214 .66671 m .39412 .6608 L .39546 .66487 L F
.40214 .66671 m .39556 .6577 L .39412 .6608 L F
.40214 .66671 m .399 .65722 L .39556 .6577 L F
.40214 .66671 m .40214 .65967 L .399 .65722 L F
0 g
.3987 .6672 m
.40214 .66671 L
s
.40214 .65967 m
.40349 .66373 L
s
.26523 .68432 m .25804 .67455 L .25426 .68199 L 0 1 .526 r
F
.26523 .68432 m .2641 .66987 L .25804 .67455 L F
.26523 .68432 m .26838 .67109 L .2641 .66987 L F
.26523 .68432 m .26886 .67729 L .26838 .67109 L F
0 g
.2592 .68897 m
.26523 .68432 L
s
.26523 .68432 m
.26584 .6902 L
s
.43377 .88424 m .42162 .87569 L .42253 .88215 L 0 .847 .37 r
F
.43377 .88424 m .42437 .87164 L .42162 .87569 L F
0 g
.4177 .87053 m
.42162 .87569 L
s
.40069 .67371 m
.40363 .67254 L
s
.40062 .67374 m
.40069 .67371 L
s
.39823 .67468 m
.40062 .67374 L
s
.73998 1.07157 m .7369 1.07057 L .74402 1.06828 L 0 0 0 r
F
.73998 1.07157 m .73314 1.07203 L .7369 1.07057 L F
0 g
.73469 1.07015 m
.7369 1.07057 L
s
.5676 .68782 m .57177 .67871 L .57674 .66749 L 0 .81 .096 r
F
0 g
.57418 .67328 m
.57458 .67238 L
s
.5751 .6712 m
.57674 .66749 L
s
.57458 .67238 m
.5751 .6712 L
s
.5733 .67944 m
.57416 .67594 L
s
.80765 .6308 m
.80813 .63489 L
s
.50279 .83841 m .49769 .78799 L .49831 .80442 L 0 .646 .284 r
F
0 g
.49506 .77683 m
.49769 .78799 L
s
.43377 .88424 m .42253 .88215 L .42656 .88755 L 0 .847 .37 r
F
0 g
.42253 .88215 m
.4241 .88425 L
s
.41988 .88665 m
.42253 .88215 L
s
.45641 .6456 m .44894 .64844 L .45113 .64803 L 0 .905 .215 r
F
.45641 .6456 m .45127 .6467 L .44894 .64844 L F
0 g
.44932 .64989 m
.45113 .64803 L
s
.45641 .6456 m .45657 .64396 L .45127 .6467 L 0 .905 .215 r
F
.45641 .6456 m .46187 .64153 L .45657 .64396 L F
.45641 .6456 m .46362 .64102 L .46187 .64153 L F
.45641 .6456 m .46128 .64277 L .46362 .64102 L F
0 g
.45113 .64803 m
.45641 .6456 L
s
.46128 .64277 m
.46629 .64017 L
s
.46128 .64277 m
.46128 .64277 L
s
.46718 .91621 m .4621 .91454 L .46565 .91497 L 0 0 .005 r
F
.47125 .91297 m .46565 .91497 L .4621 .91454 L 0 0 .003 r
F
0 g
.46097 .91329 m
.4621 .91454 L
s
.4581 .91507 m
.4621 .91454 L
s
.40205 .67204 m
.40363 .67254 L
s
.58629 .65048 m
.58701 .64936 L
s
.39261 .9189 m .38172 .91794 L .38011 .91841 L 0 .651 .233 r
F
.39261 .9189 m .386 .91805 L .38172 .91794 L F
.39261 .9189 m .39067 .91846 L .386 .91805 L F
0 g
.39098 .91936 m
.39261 .9189 L
s
.40345 .91892 m .39067 .91846 L .39261 .9189 L 0 .564 .204 r
F
0 g
.39261 .9189 m
.39727 .91916 L
s
.79346 .66943 m .80817 .69357 L .80853 .68237 L 0 1 .438 r
F
0 g
.80817 .69357 m
.81354 .70362 L
s
.33148 .79598 m .32077 .79534 L .32306 .8024 L 0 1 .435 r
F
0 g
.31952 .80899 m
.32306 .8024 L
s
.4451 .81327 m .43651 .81205 L .44107 .81537 L 0 .953 .346 r
F
.44359 .82845 m .44107 .81537 L .43651 .81205 L 0 .924 .349 r
F
0 g
.43552 .81267 m
.43651 .81205 L
s
.4338 .80455 m
.43651 .81205 L
s
.43634 .89938 m .42419 .89175 L .42548 .89808 L 0 .808 .373 r
F
.43634 .89938 m .42656 .88755 L .42419 .89175 L F
0 g
.41988 .88665 m
.42419 .89175 L
s
.45378 .91782 m .44824 .91671 L .45207 .9169 L 0 0 0 r
F
.45378 .91782 m .44401 .9172 L .44824 .91671 L F
0 g
.44695 .91582 m
.44824 .91671 L
s
.42128 .59487 m .4306 .57795 L .42853 .57571 L 0 1 .414 r
F
0 g
.4306 .57795 m
.43709 .57321 L
s
.4275 .58616 m
.4306 .57795 L
s
.43118 .83724 m .42282 .83889 L .42749 .84071 L 0 .95 .362 r
F
.43118 .85318 m .42749 .84071 L .42282 .83889 L 0 .917 .365 r
F
0 g
.41941 .84257 m
.42282 .83889 L
s
.42081 .83491 m
.42282 .83889 L
s
.80367 1.0412 m .81393 1.03761 L .81518 1.03483 L 0 1 .322 r
F
.34596 .9169 m .33517 .91365 L .33359 .91507 L 0 1 .382 r
F
.34596 .9169 m .33938 .91377 L .33517 .91365 L F
.34596 .9169 m .34401 .91517 L .33938 .91377 L F
.35626 .91685 m .34401 .91517 L .34596 .9169 L 0 .899 .341 r
F
0 g
.34437 .91831 m
.34596 .9169 L
s
.34596 .9169 m
.35048 .91811 L
s
.48378 .50323 m .4923 .49628 L .49843 .4908 L 0 .948 .201 r
F
0 g
.4923 .49628 m
.49891 .4913 L
s
.43634 .89938 m .42548 .89808 L .42967 .90315 L 0 .808 .373 r
F
0 g
.42548 .89808 m
.42711 .90005 L
s
.42324 .90269 m
.42548 .89808 L
s
.43118 .83724 m .43143 .83079 L .42813 .82428 L 0 .95 .362 r
F
.20274 .87117 m .19013 .86291 L .1913 .87116 L 0 1 .533 r
F
0 g
.1913 .87116 m
.19559 .87727 L
s
.51381 .90618 m .51501 .89537 L .51474 .90118 L 0 .098 .08 r
F
0 g
.51412 .8921 m
.51501 .89537 L
s
.51501 .89537 m
.51538 .8938 L
s
.50339 .90271 m .502 .90408 L .49975 .90333 L 0 .003 .054 r
F
0 g
.77165 .66025 m
.77194 .66071 L
s
.76504 .64977 m
.77046 .65836 L
s
.77127 .65965 m
.77165 .66025 L
s
.45639 .82418 m .4459 .80714 L .4451 .81327 L 0 .889 .335 r
F
.45639 .82418 m .44982 .80615 L .4459 .80714 L F
0 g
.44318 .79964 m
.4459 .80714 L
s
.4459 .80714 m
.449 .80636 L
s
.41447 .90831 m .40401 .90212 L .40194 .90454 L 0 1 .509 r
F
0 g
.39733 .9018 m
.40194 .90454 L
s
.2993 .91101 m .29088 .91331 L .29638 .91328 L 0 1 .479 r
F
.2993 .91101 m .28545 .91084 L .29088 .91331 L F
0 g
.28877 .91574 m
.29088 .91331 L
s
.29638 .91328 m
.30239 .91538 L
s
.49683 .95521 m .49085 .95479 L .49362 .95633 L 0 .512 .36 r
F
.49683 .95521 m .48998 .9533 L .49085 .95479 L F
0 g
.48758 .95407 m
.49085 .95479 L
s
.48733 .81308 m .48108 .79251 L .48452 .80468 L 0 .795 .304 r
F
0 g
.4801 .78812 m
.48108 .79251 L
s
.31423 .7626 m .30538 .76273 L .30961 .76344 L 0 .973 .414 r
F
0 g
.30961 .76344 m
.31199 .76564 L
s
.48547 .81968 m .48451 .80469 L .48108 .79251 L 0 .788 .306 r
F
0 g
.48017 .79104 m
.48108 .79251 L
s
.38187 .75887 m .37275 .76337 L .37705 .76454 L 0 1 .395 r
F
0 g
.37705 .76454 m
.37855 .76986 L
s
.38187 .75887 m .37125 .75573 L .37275 .76337 L 0 1 .395 r
F
.38187 .75887 m .37354 .7467 L .37125 .75573 L F
.38187 .75887 m .37836 .74103 L .37354 .7467 L F
.38187 .75887 m .3825 .74249 L .37836 .74103 L F
.38187 .75887 m .384 .75013 L .3825 .74249 L F
0 g
.38187 .75887 m
.38349 .76647 L
s
.37705 .76454 m
.38187 .75887 L
s
.384 .75013 m
.38869 .74487 L
s
.49683 .95521 m .49362 .95633 L .49655 .95715 L 0 .512 .36 r
F
0 g
.49362 .95633 m
.49484 .95792 L
s
.76712 .89262 m .76571 .89546 L .76805 .89757 L 0 1 .426 r
F
0 g
.7628 .89971 m
.76805 .89757 L
s
.47353 1.01709 m .47374 1.02272 L .47532 1.02186 L 0 .412 .377 r
F
.48377 1.03072 m .47532 1.02186 L .47374 1.02272 L 0 .328 .343 r
F
0 g
.47374 1.02272 m
.47599 1.02736 L
s
.46923 1.01927 m
.47374 1.02272 L
s
.30336 .53803 m
.30603 .52838 L
s
.44359 .82845 m .43206 .82103 L .43509 .82806 L 0 .924 .349 r
F
0 g
.42813 .82428 m
.43206 .82103 L
s
.49111 .95134 m .48678 .9524 L .48998 .9533 L 0 .616 .406 r
F
.49111 .95134 m .48411 .95076 L .48678 .9524 L F
0 g
.48678 .9524 m
.48758 .95407 L
s
.38761 .73687 m .39029 .72791 L .38936 .71985 L 0 1 .39 r
F
0 g
.39029 .72791 m
.39524 .72275 L
s
.56731 .47047 m
.57533 .47752 L
s
.56136 .47307 m
.56731 .47047 L
s
.53172 .97511 m .52739 .97263 L .52827 .97266 L 0 0 0 r
F
0 g
.52827 .97266 m
.53021 .97323 L
s
.36661 .77784 m .35796 .78318 L .36219 .78388 L 0 1 .408 r
F
0 g
.36219 .78388 m
.36458 .79081 L
s
.43972 .91425 m .4277 .90749 L .42936 .91369 L 0 .767 .374 r
F
.43972 .91425 m .42967 .90315 L .4277 .90749 L F
0 g
.42324 .90269 m
.4277 .90749 L
s
.61634 .63035 m .6174 .63129 L .61466 .6317 L 0 0 0 r
F
.61634 .63035 m .62344 .63001 L .6174 .63129 L F
.61634 .63035 m .62874 .62871 L .62344 .63001 L F
.48377 1.03072 m .48059 1.03268 L .48489 1.03611 L 0 .328 .343 r
F
0 g
.48059 1.03268 m
.48319 1.03726 L
s
.50428 1.05886 m .50342 1.05976 L .50754 1.06324 L 0 .207 .208 r
F
.47399 .94381 m .4716 .94197 L .46768 .94089 L 0 .891 .477 r
F
.48705 .90819 m .48546 .90965 L .48212 .91005 L 0 0 .031 r
F
.49352 .91276 m .48705 .90819 L .4901 .9085 L 0 .067 .058 r
F
.49352 .91276 m .48546 .90965 L .48705 .90819 L F
0 g
.48641 .90634 m
.48705 .90819 L
s
.48705 .90819 m
.48885 .90837 L
s
.44607 .95863 m .44343 .95279 L .4388 .94877 L 0 .672 .391 r
F
.28294 .87163 m .27544 .87642 L .28001 .87642 L 0 1 .526 r
F
.28294 .87163 m .27147 .87147 L .27544 .87642 L F
0 g
.27332 .8813 m
.27544 .87642 L
s
.28001 .87642 m
.28466 .88112 L
s
.53885 1.08894 m .54165 1.08843 L .54082 1.08934 L 0 .136 0 r
F
0 g
.54083 1.08682 m
.54165 1.08843 L
s
.55021 1.0985 m .54082 1.08934 L .54165 1.08843 L 0 .18 0 r
F
0 g
.54165 1.08843 m
.54689 1.09093 L
s
.52581 .76932 m .52767 .7669 L .53032 .78071 L 0 .511 .172 r
F
0 g
.52767 .7669 m
.52783 .75312 L
s
.52998 1.08434 m .52564 1.0786 L .53139 1.08307 L 0 .049 0 r
F
.52998 1.08434 m .52113 1.07537 L .52564 1.0786 L F
0 g
.52151 1.07514 m
.52564 1.0786 L
s
.49111 .95134 m .48364 .94925 L .48411 .95076 L 0 .616 .406 r
F
0 g
.48059 .94996 m
.48411 .95076 L
s
.38761 .73687 m .37836 .74103 L .3825 .74249 L 0 1 .39 r
F
0 g
.3825 .74249 m
.384 .75013 L
s
.38761 .73687 m .37743 .73296 L .37836 .74103 L 0 1 .39 r
F
.38761 .73687 m .38032 .72367 L .37743 .73296 L F
.38761 .73687 m .38544 .71805 L .38032 .72367 L F
.38761 .73687 m .38936 .71985 L .38544 .71805 L F
0 g
.3825 .74249 m
.38761 .73687 L
s
.38761 .73687 m
.38869 .74487 L
s
.38936 .71985 m
.39471 .71435 L
s
.38936 .71985 m
.39029 .72791 L
s
.54905 .86751 m
.54909 .86731 L
s
.47353 1.01709 m .46954 1.0116 L .46504 1.00816 L 0 .412 .377 r
F
.45314 .97302 m .45035 .97864 L .45319 .97789 L 0 .608 .389 r
F
.46084 .98717 m .45319 .97789 L .45035 .97864 L 0 .534 .384 r
F
0 g
.45035 .97864 m
.45089 .98349 L
s
.44577 .97481 m
.45035 .97864 L
s
.3923 .77094 m .38341 .77028 L .38772 .77041 L 0 0 0 r
F
0 g
.38772 .77041 m
.38845 .77038 L
s
.44401 .9172 m .43774 .91859 L .43366 .91845 L 0 0 0 r
F
.44401 .9172 m .44218 .91805 L .43774 .91859 L F
.45378 .91782 m .44218 .91805 L .44401 .9172 L F
0 g
.4425 .91661 m
.44401 .9172 L
s
.44401 .9172 m
.44824 .91671 L
s
.43972 .91425 m .42936 .91369 L .43366 .91845 L 0 .767 .374 r
F
0 g
.42936 .91369 m
.43103 .91554 L
s
.42854 .91581 m
.42936 .91369 L
s
.50272 .95896 m .49782 .95859 L .50067 .96006 L 0 .448 .299 r
F
.50272 .95896 m .49655 .95715 L .49782 .95859 L F
0 g
.49484 .95792 m
.49782 .95859 L
s
.43118 .85318 m .42312 .85543 L .42777 .85686 L 0 .917 .365 r
F
.43204 .86884 m .42777 .85686 L .42312 .85543 L 0 .883 .368 r
F
0 g
.42002 .8593 m
.42312 .85543 L
s
.42093 .85168 m
.42312 .85543 L
s
.31956 .6823 m .30668 .67785 L .30753 .68287 L 0 1 .533 r
F
0 g
.30122 .68594 m
.30753 .68287 L
s
.36661 .77784 m .35611 .77592 L .35796 .78318 L 0 1 .408 r
F
0 g
.35397 .7892 m
.35796 .78318 L
s
.36219 .78388 m
.36661 .77784 L
s
.45825 .81044 m .44982 .80615 L .45424 .81097 L 0 .914 .332 r
F
.45639 .82418 m .45424 .81097 L .44982 .80615 L 0 .889 .335 r
F
0 g
.449 .80636 m
.44982 .80615 L
s
.44732 .79788 m
.44982 .80615 L
s
.50898 .91051 m .50529 .90479 L .50549 .90062 L 0 .105 .078 r
F
0 g
.50356 .89963 m
.50549 .90062 L
s
.50852 .90146 m
.50906 .89709 L
s
.38852 .8986 m .37846 .89123 L .37627 .89417 L 0 1 .512 r
F
.38852 .8986 m .38286 .89151 L .37846 .89123 L F
.38852 .8986 m .38717 .89467 L .38286 .89151 L F
0 g
.38633 .90153 m
.38852 .8986 L
s
.39976 .89916 m .38717 .89467 L .38853 .8986 L 0 1 .509 r
F
0 g
.38853 .8986 m
.39288 .90165 L
s
.44891 .92902 m .44684 .92666 L .44241 .92496 L 0 1 .505 r
F
.45798 .92898 m .44891 .92902 L .45311 .93073 L 0 .991 .495 r
F
.45798 .92898 m .44684 .92666 L .44891 .92902 L F
0 g
.44781 .93101 m
.44891 .92902 L
s
.55095 .61422 m .54877 .62026 L .54763 .6169 L 0 .241 .066 r
F
.55095 .61422 m .55417 .62358 L .54877 .62026 L F
.55095 .61422 m .56023 .62463 L .55417 .62358 L F
.55095 .61422 m .56354 .62192 L .56023 .62463 L F
.55095 .61422 m .56191 .61729 L .56354 .62192 L F
0 g
.56191 .61729 m
.56471 .61442 L
s
.54592 .61138 m
.55095 .61422 L
s
.55652 .61399 m
.56191 .61729 L
s
.32077 .79534 m .3123 .80196 L .3166 .80212 L 0 1 .442 r
F
0 g
.3166 .80212 m
.31952 .80899 L
s
.48156 .63181 m .4868 .62918 L .49011 .62792 L 0 0 0 r
F
0 g
.47863 .63314 m
.48156 .63181 L
s
.39814 .67614 m
.39825 .67431 L
s
.39835 .67278 m
.3987 .66721 L
s
.42128 .59487 m .41229 .59688 L .41476 .59947 L 0 1 .414 r
F
.42128 .59487 m .4154 .58865 L .41229 .59688 L F
.42128 .59487 m .42201 .58029 L .4154 .58865 L F
.42128 .59487 m .42853 .57571 L .42201 .58029 L F
0 g
.41845 .60336 m
.42128 .59487 L
s
.20274 .87117 m .19272 .85683 L .19013 .86291 L 0 1 .533 r
F
.20274 .87117 m .19735 .857 L .19272 .85683 L F
.20274 .87117 m .20164 .86316 L .19735 .857 L F
.21419 .87118 m .20164 .86316 L .20274 .87117 L F
0 g
.20015 .8772 m
.20274 .87117 L
s
.20274 .87117 m
.20698 .8771 L
s
.31423 .7626 m .30371 .76048 L .30538 .76273 L 0 .973 .414 r
F
0 g
.30137 .76413 m
.30538 .76273 L
s
.7159 .89801 m .72483 .89746 L .72057 .89743 L 0 .674 .252 r
F
.78244 .67085 m .78724 .65893 L .78287 .65943 L 0 1 .428 r
F
.78244 .67085 m .79346 .66943 L .78724 .65893 L F
.78244 .67085 m .79738 .6839 L .79346 .66943 L F
0 g
.78244 .67085 m
.78287 .65943 L
s
.79694 .69529 m
.79738 .6839 L
s
.79738 .6839 m
.80367 .69424 L
s
.77631 .6602 m
.78244 .67085 L
s
.50272 .95896 m .50067 .96006 L .50331 .96083 L 0 .448 .299 r
F
0 g
.50067 .96006 m
.50229 .96154 L
s
.81295 .88968 m .82256 .89387 L .82439 .889 L 0 1 .502 r
F
0 g
.81781 .8975 m
.82256 .89387 L
s
.82256 .89387 m
.82459 .8975 L
s
.44388 .92888 m .43211 .9229 L .43411 .92898 L 0 .721 .376 r
F
.44388 .92888 m .43366 .91845 L .43211 .9229 L F
0 g
.42792 .91875 m
.43211 .9229 L
s
.43211 .9229 m
.43363 .91854 L
s
.43214 .92038 m
.43358 .91855 L
s
.48563 .94733 m .48021 .94823 L .48364 .94925 L 0 .704 .437 r
F
.48563 .94733 m .47767 .9465 L .48021 .94823 L F
0 g
.48021 .94823 m
.48059 .94996 L
s
.49701 .76862 m .49247 .77998 L .49428 .77303 L 0 .298 .104 r
F
.49701 .76862 m .49285 .78685 L .49247 .77998 L F
0 g
.48954 .76958 m
.49254 .76591 L
s
.49701 .76862 m .49516 .78903 L .49285 .78685 L 0 .298 .104 r
F
0 g
.49428 .77303 m
.4943 .76701 L
s
.49701 .76862 m .4979 .78456 L .49516 .78903 L 0 .298 .104 r
F
.49701 .76862 m .49924 .77647 L .4979 .78456 L F
.49701 .76862 m .49885 .76965 L .49924 .77647 L F
0 g
.49885 .76965 m
.50123 .76339 L
s
.49697 .76155 m
.49701 .76862 L
s
.49428 .77303 m
.49701 .76862 L
s
.46548 .52399 m .45735 .52744 L .45859 .52875 L 0 1 .292 r
F
.46548 .52399 m .46271 .52104 L .45735 .52744 L F
.46548 .52399 m .4711 .51384 L .46271 .52104 L F
.46548 .52399 m .47797 .50909 L .4711 .51384 L F
0 g
.46045 .53077 m
.46548 .52399 L
s
.33148 .79598 m .32202 .78615 L .32077 .79534 L 0 1 .435 r
F
.33148 .79598 m .32615 .77951 L .32202 .78615 L F
.33148 .79598 m .3304 .77986 L .32615 .77951 L F
.33148 .79598 m .33268 .78692 L .3304 .77986 L F
0 g
.33148 .79598 m
.33381 .80299 L
s
.32736 .80261 m
.33148 .79598 L
s
.43204 .86884 m .42437 .87164 L .42895 .87272 L 0 .883 .368 r
F
.43377 .88424 m .42895 .87272 L .42437 .87164 L 0 .847 .37 r
F
0 g
.42162 .87569 m
.42437 .87164 L
s
.42203 .86813 m
.42437 .87164 L
s
.46018 .49058 m .46897 .48526 L .47477 .4826 L 0 0 0 r
F
0 g
.45454 .49358 m
.46018 .49058 L
s
.48378 .50323 m .49843 .4908 L .49811 .49044 L 0 .948 .201 r
F
0 g
.49843 .4908 m
.50509 .48615 L
s
.4923 .49628 m
.49843 .4908 L
s
.44359 .82845 m .44411 .8224 L .44107 .81537 L 0 .924 .349 r
F
0 g
.5442 .464 m
.55187 .46233 L
s
.53766 .46798 m
.5442 .464 L
s
.56524 .74253 m .56838 .73684 L .57274 .71282 L 0 1 .226 r
F
.55045 .76675 m .55476 .85546 L .55153 .81143 L 0 .664 .204 r
F
.55045 .76675 m .55883 .87867 L .55476 .85546 L F
.55045 .76675 m .55616 .77301 L .5598 .81948 L F
0 g
.55481 .72809 m
.55616 .77301 L
s
.54685 .76026 m
.55045 .76675 L
s
.55218 .75066 m
.55616 .77301 L
s
.48869 .80895 m .48977 .80581 L .48835 .79298 L 0 .794 .301 r
F
0 g
.48835 .79298 m
.48935 .80195 L
s
.45639 .82418 m .4451 .81327 L .44791 .82099 L 0 .889 .335 r
F
0 g
.44107 .81537 m
.4451 .81327 L
s
.48156 .63181 m .47537 .63496 L .47666 .63429 L 0 0 0 r
F
0 g
.47653 .63432 m
.47863 .63314 L
s
.47563 .63482 m
.47653 .63432 L
s
.48156 .63181 m .47868 .63371 L .47537 .63496 L 0 0 0 r
F
.48156 .63181 m .4844 .63136 L .47868 .63371 L F
.48156 .63181 m .4893 .62888 L .4844 .63136 L F
.48156 .63181 m .49011 .62792 L .4893 .62888 L F
0 g
.4868 .62918 m
.49011 .62792 L
s
.49011 .62792 m
.49473 .62533 L
s
.50065 .84094 m .49574 .79164 L .49448 .79425 L 0 .654 .287 r
F
.50065 .84094 m .49831 .80442 L .49574 .79164 L F
0 g
.49559 .78833 m
.49574 .79164 L
s
.49769 .78799 m
.49792 .79419 L
s
.44283 .84344 m .43143 .83079 L .43118 .83724 L 0 .894 .351 r
F
.44283 .84344 m .43509 .82806 L .43143 .83079 L F
0 g
.42813 .82428 m
.43143 .83079 L
s
.43143 .83079 m
.43403 .82885 L
s
.43118 .85318 m .43107 .84684 L .42749 .84071 L 0 .917 .365 r
F
.32077 .79534 m .31004 .79487 L .3123 .80196 L 0 1 .442 r
F
0 g
.30875 .8087 m
.3123 .80196 L
s
.46874 .63859 m .46187 .64153 L .46362 .64102 L 0 .789 .176 r
F
.46874 .63859 m .4647 .63997 L .46187 .64153 L F
0 g
.46128 .64277 m
.46362 .64102 L
s
.46874 .63859 m .47024 .6374 L .4647 .63997 L 0 .789 .176 r
F
.46874 .63859 m .47537 .63496 L .47024 .6374 L F
.46874 .63859 m .47666 .63429 L .47537 .63496 L F
.46874 .63859 m .47382 .63584 L .47666 .63429 L F
0 g
.47666 .63429 m
.48156 .63181 L
s
.46362 .64102 m
.46874 .63859 L
s
.47382 .63584 m
.47382 .63584 L
s
.47382 .63584 m
.47382 .63584 L
s
.52081 .96994 m .51722 .96797 L .51943 .96913 L 0 .223 .181 r
F
.51722 .96797 m .51706 .96788 L .51943 .96913 L F
.52027 .96957 m .51943 .96913 L .51746 .96831 L 0 .31 .193 r
F
.52232 .9705 m .51943 .96913 L .52027 .96957 L F
0 g
.51746 .96831 m
.51904 .96897 L
s
.48336 .82829 m .4746 .79828 L .47352 .80291 L 0 .779 .308 r
F
.48336 .82829 m .47821 .80302 L .4746 .79828 L F
0 g
.47296 .79005 m
.4746 .79828 L
s
.4746 .79828 m
.47733 .80185 L
s
.62344 .63001 m .63501 .62746 L .6381 .6271 L 0 0 0 r
F
0 g
.63528 .62766 m
.63629 .62843 L
s
.62344 .63001 m .62874 .62871 L .63501 .62746 L 0 0 0 r
F
0 g
.62874 .62871 m
.63039 .62737 L
s
.62874 .62871 m
.63501 .62746 L
s
.46917 .82626 m .45915 .80492 L .45825 .81044 L 0 .839 .323 r
F
.46917 .82626 m .46301 .80595 L .45915 .80492 L F
0 g
.45665 .79665 m
.45915 .80492 L
s
.45915 .80492 m
.46249 .80581 L
s
.7534 .62333 m
.75341 .62335 L
s
.75341 .62335 m
.75426 .62476 L
s
.75426 .62476 m
.75443 .62504 L
s
.75443 .62504 m
.75602 .6277 L
s
.73686 .61868 m .7534 .62332 L .75245 .6209 L 0 .922 .361 r
F
0 g
.75339 .62347 m
.7534 .62333 L
s
.26019 .57275 m .25009 .57064 L .2481 .57966 L 0 1 .48 r
F
0 g
.24083 .58735 m
.2481 .57966 L
s
.26019 .57275 m .25688 .5594 L .25009 .57064 L 0 1 .48 r
F
.26019 .57275 m .26489 .55165 L .25688 .5594 L F
.26019 .57275 m .26876 .55258 L .26489 .55165 L F
.26019 .57275 m .26674 .56163 L .26876 .55258 L F
0 g
.25836 .58174 m
.26019 .57275 L
s
.25221 .58047 m
.26019 .57275 L
s
.40039 .64808 m .40539 .63835 L .40703 .62904 L 0 1 .393 r
F
0 g
.40539 .63835 m
.41125 .63306 L
s
.75565 .8934 m .76126 .89757 L .76571 .89546 L 0 1 .387 r
F
.75565 .8934 m .75672 .89757 L .76126 .89757 L F
0 g
.76126 .89757 m
.7628 .89971 L
s
.44388 .92888 m .43411 .92898 L .43849 .93345 L 0 .721 .376 r
F
0 g
.43275 .93374 m
.43411 .92898 L
s
.4691 1.00112 m .45993 .99769 L .46372 1.00328 L 0 .446 .375 r
F
.4691 1.00112 m .45893 .99287 L .45993 .99769 L F
0 g
.45527 .99416 m
.45993 .99769 L
s
.39391 .69457 m
.39415 .68573 L
s
.38855 .70006 m
.39391 .69457 L
s
.24327 .67974 m .23256 .68425 L .23701 .68502 L 0 1 .525 r
F
0 g
.23701 .68502 m
.23831 .69145 L
s
.47125 .91297 m .46957 .91429 L .46565 .91497 L 0 0 .003 r
F
.47955 .9152 m .47125 .91297 L .47492 .91265 L 0 .025 .035 r
F
.47955 .9152 m .46957 .91429 L .47125 .91297 L F
0 g
.47011 .91172 m
.47125 .91297 L
s
.47382 .63584 m
.47556 .63489 L
s
.48563 .94733 m .47761 .94497 L .47767 .9465 L 0 .704 .437 r
F
0 g
.47393 .94557 m
.47767 .9465 L
s
.43377 .88424 m .42656 .88755 L .43102 .88829 L 0 .847 .37 r
F
.43634 .89938 m .43102 .88829 L .42656 .88755 L 0 .808 .373 r
F
0 g
.42419 .89175 m
.42656 .88755 L
s
.4241 .88425 m
.42656 .88755 L
s
.69374 .61864 m .70625 .62001 L .71018 .61952 L 0 .788 .263 r
F
.69374 .61864 m .69921 .61964 L .70625 .62001 L F
0 g
.70625 .62001 m
.70674 .62106 L
s
.69921 .61964 m
.70625 .62001 L
s
.52614 .80092 m .5275 .80695 L .53001 .78478 L 0 .685 .257 r
F
.26292 .91076 m .25148 .90355 L .24961 .90659 L 0 1 .508 r
F
.26292 .91076 m .25606 .90374 L .25148 .90355 L F
.26292 .91076 m .26097 .90683 L .25606 .90374 L F
.27418 .91077 m .26097 .90683 L .26292 .91076 L 0 1 .501 r
F
0 g
.26103 .91377 m
.26292 .91076 L
s
.26292 .91076 m
.26774 .91363 L
s
.35287 .88675 m .3435 .87782 L .34115 .88145 L 0 1 .516 r
F
.35287 .88675 m .34778 .87807 L .3435 .87782 L F
.35287 .88675 m .3518 .8819 L .34778 .87807 L F
.36344 .88714 m .3518 .8819 L .35287 .88675 L 0 1 .514 r
F
0 g
.35052 .89037 m
.35287 .88675 L
s
.35287 .88675 m
.35682 .89045 L
s
.36828 .76907 m
.37275 .76337 L
s
.47112 .81454 m .47203 .80988 L .4697 .80053 L 0 .858 .32 r
F
0 g
.4697 .80053 m
.4707 .80456 L
s
.37449 .88777 m .36747 .89072 L .37187 .89089 L 0 1 .511 r
F
0 g
.37187 .89089 m
.37627 .89417 L
s
.37449 .88777 m .36344 .88714 L .36747 .89072 L 0 1 .511 r
F
0 g
.36539 .89393 m
.36747 .89072 L
s
.21419 .87118 m .20428 .85726 L .20164 .86316 L 0 1 .533 r
F
.21419 .87118 m .20891 .85744 L .20428 .85726 L F
.21419 .87118 m .21316 .86342 L .20891 .85744 L F
.22564 .87121 m .21316 .86342 L .21419 .87118 L 0 1 .532 r
F
0 g
.21154 .87704 m
.21419 .87118 L
s
.21419 .87118 m
.21838 .87694 L
s
.51669 1.07198 m .52113 1.07537 L .52088 1.07552 L 0 .131 .18 r
F
.52998 1.08434 m .52088 1.07552 L .52113 1.07537 L 0 .049 0 r
F
0 g
.52113 1.07537 m
.52564 1.0786 L
s
.51699 1.07191 m
.52113 1.07537 L
s
.43352 .5095 m
.43864 .50558 L
s
.80451 .66807 m .81491 .6926 L .81941 .69198 L 0 1 .447 r
F
.80451 .66807 m .80853 .68237 L .81491 .6926 L F
0 g
.81354 .70362 m
.81491 .6926 L
s
.50872 .96263 m .50496 .96221 L .50785 .96362 L 0 .393 .233 r
F
.50872 .96263 m .50331 .96083 L .50496 .96221 L F
0 g
.50229 .96154 m
.50496 .96221 L
s
.37125 .75573 m
.37275 .76337 L
s
.29702 .8719 m .28765 .87644 L .29326 .87646 L 0 1 .524 r
F
0 g
.29326 .87646 m
.29861 .88097 L
s
.29702 .8719 m .28294 .87163 L .28765 .87644 L 0 1 .524 r
F
0 g
.28467 .88112 m
.28765 .87644 L
s
.44283 .84344 m .43118 .83724 L .4345 .84383 L 0 .894 .351 r
F
0 g
.42749 .84071 m
.43118 .83724 L
s
.23949 .93264 m .23339 .93394 L .23786 .93396 L 0 .699 .258 r
F
0 g
.23786 .93396 m
.24378 .93524 L
s
.23949 .93264 m .22824 .93232 L .23339 .93394 L 0 .699 .258 r
F
0 g
.23273 .93543 m
.23339 .93394 L
s
.35772 .68198 m .3481 .68222 L .3519 .68312 L 0 1 .492 r
F
0 g
.3519 .68312 m
.35226 .68631 L
s
.44359 .82845 m .43509 .82806 L .43973 .83088 L 0 .924 .349 r
F
.44283 .84344 m .43973 .83088 L .43509 .82806 L 0 .894 .351 r
F
0 g
.43403 .82885 m
.43509 .82806 L
s
.43206 .82103 m
.43509 .82806 L
s
.45789 .77054 m .44983 .77247 L .45367 .77068 L 0 .118 .036 r
F
.45789 .77054 m .44851 .77513 L .44983 .77247 L F
0 g
.45409 .77009 m
.45539 .76829 L
s
.45789 .77054 m .4506 .77688 L .44851 .77513 L 0 .118 .036 r
F
.45789 .77054 m .45483 .77674 L .4506 .77688 L F
0 g
.45367 .77068 m
.45409 .77009 L
s
.45789 .77054 m .45838 .7748 L .45483 .77674 L 0 .118 .036 r
F
.45789 .77054 m .45969 .77214 L .45838 .7748 L F
0 g
.45789 .77054 m
.45943 .76734 L
s
.45367 .77068 m
.45789 .77054 L
s
.56222 .71419 m .57307 .68041 L .57177 .67871 L 0 1 .19 r
F
0 g
.57215 .67922 m
.57278 .68004 L
s
.56222 .71419 m .57064 .69175 L .57307 .68041 L 0 1 .19 r
F
0 g
.57067 .6917 m
.57141 .69026 L
s
.57307 .68041 m
.5733 .67944 L
s
.57274 .71282 m
.57279 .71815 L
s
.56949 .70075 m
.57141 .69026 L
s
.57278 .68004 m
.57307 .68041 L
s
.40039 .64808 m .40703 .62904 L .40421 .62634 L 0 1 .393 r
F
0 g
.40703 .62904 m
.41322 .62411 L
s
.40539 .63835 m
.40703 .62904 L
s
.39414 .68573 m .38498 .6896 L .38851 .6915 L 0 1 .387 r
F
.39414 .68573 m .38555 .68066 L .38498 .6896 L F
.43221 .56787 m .43919 .55968 L .44317 .55221 L 0 1 .422 r
F
0 g
.43919 .55968 m
.44568 .55495 L
s
.77584 .64878 m
.77631 .6602 L
s
.44877 .94326 m .43737 .938 L .4397 .94395 L 0 .671 .376 r
F
.44877 .94326 m .43849 .93345 L .43737 .938 L F
0 g
.43275 .93374 m
.43737 .938 L
s
.30371 .76048 m .29247 .76043 L .29803 .76144 L 0 1 .452 r
F
0 g
.29803 .76144 m
.30136 .76413 L
s
.43634 .89938 m .42967 .90315 L .43396 .90358 L 0 .808 .373 r
F
.43972 .91425 m .43396 .90358 L .42967 .90315 L 0 .767 .374 r
F
0 g
.4277 .90749 m
.42967 .90315 L
s
.42711 .90005 m
.42967 .90315 L
s
.31004 .79487 m .30152 .80164 L .30583 .80176 L 0 1 .449 r
F
0 g
.30583 .80176 m
.30875 .8087 L
s
.75565 .8934 m .75431 .89579 L .75672 .89757 L 0 1 .387 r
F
0 g
.75156 .89937 m
.75672 .89757 L
s
.35611 .77592 m .34737 .78166 L .35161 .78223 L 0 1 .415 r
F
0 g
.35161 .78223 m
.35397 .7892 L
s
.43204 .86884 m .43159 .86261 L .42777 .85686 L 0 .883 .368 r
F
.45314 .97302 m .45022 .9673 L .44564 .96348 L 0 .608 .389 r
F
.44379 .77122 m .43526 .77199 L .43936 .77091 L 0 .027 .002 r
F
0 g
.43936 .77091 m
.44132 .76916 L
s
.42533 .909 m .41882 .91088 L .42312 .91108 L 0 1 .504 r
F
.42533 .909 m .41447 .90831 L .41882 .91088 L F
.42932 .91621 m .42312 .91108 L .41882 .91088 L 0 1 .508 r
F
0 g
.41705 .91306 m
.41882 .91088 L
s
.50065 .84094 m .49448 .79425 L .49547 .80984 L 0 .654 .287 r
F
0 g
.49902 .78574 m
.50041 .79433 L
s
.49195 .7858 m
.49448 .79425 L
s
.77023 .62286 m
.77023 .62286 L
s
.76391 .62309 m
.76393 .6231 L
s
.76393 .6231 m
.76532 .62375 L
s
.76532 .62375 m
.76546 .62381 L
s
.76546 .62381 m
.76719 .62462 L
s
.76719 .62462 m
.76803 .62502 L
s
.45798 .92898 m .45311 .93073 L .45665 .93065 L 0 .991 .495 r
F
.46281 .93418 m .45665 .93065 L .45311 .93073 L 0 .967 .493 r
F
0 g
.45221 .93246 m
.45311 .93073 L
s
.44891 .92902 m
.45311 .93073 L
s
.3923 .77094 m .38162 .77049 L .38341 .77028 L 0 0 0 r
F
0 g
.38043 .77019 m
.38341 .77028 L
s
.45798 .92898 m .44816 .92499 L .44684 .92666 L 0 .991 .495 r
F
0 g
.44241 .92496 m
.44684 .92666 L
s
.45639 .82418 m .45706 .8187 L .45424 .81097 L 0 .889 .335 r
F
.47112 .81454 m .46301 .80595 L .46726 .81286 L 0 .858 .32 r
F
0 g
.4707 .80456 m
.47187 .80925 L
s
.46917 .82626 m .46726 .81286 L .46301 .80595 L 0 .839 .323 r
F
0 g
.46069 .79661 m
.46301 .80595 L
s
.46249 .80581 m
.46301 .80595 L
s
.51138 .90828 m .51174 .89849 L .51195 .9037 L 0 .1 .078 r
F
.51381 .90618 m .51195 .9037 L .51174 .89849 L 0 .098 .08 r
F
0 g
.51174 .89849 m
.51267 .89353 L
s
.51051 .89567 m
.51174 .89849 L
s
.48043 .94315 m .47399 .94381 L .47761 .94497 L 0 .773 .457 r
F
.48043 .94315 m .4716 .94197 L .47399 .94381 L F
0 g
.47393 .94557 m
.47399 .94381 L
s
.50872 .96263 m .50785 .96362 L .51016 .96439 L 0 .393 .233 r
F
0 g
.50785 .96362 m
.50986 .96498 L
s
.42932 .91621 m .42762 .91336 L .42312 .91108 L 0 1 .508 r
F
.43972 .91425 m .43366 .91845 L .43774 .91859 L 0 .767 .374 r
F
.43969 .91675 m .42932 .91621 L .43366 .91845 L 0 1 .501 r
F
0 g
.43103 .91554 m
.43175 .91634 L
s
.43217 .91786 m
.43358 .91842 L
s
.43969 .91675 m .42762 .91336 L .42932 .91621 L 0 1 .501 r
F
0 g
.42754 .91839 m
.42932 .91621 L
s
.41447 .90831 m .40847 .90241 L .40401 .90212 L 0 1 .509 r
F
.41447 .90831 m .41296 .90507 L .40847 .90241 L F
.42533 .909 m .41296 .90507 L .41447 .90831 L 0 1 .504 r
F
0 g
.41447 .90831 m
.41882 .91088 L
s
.41239 .91072 m
.41447 .90831 L
s
.31956 .6823 m .31078 .67269 L .30668 .67785 L 0 1 .533 r
F
0 g
.30668 .67785 m
.30753 .68287 L
s
.31956 .6823 m .3176 .67057 L .31078 .67269 L 0 1 .533 r
F
.31956 .6823 m .32257 .67293 L .3176 .67057 L F
.31956 .6823 m .32341 .67796 L .32257 .67293 L F
0 g
.31276 .6844 m
.31956 .6823 L
s
.22564 .87121 m .21585 .8577 L .21316 .86342 L 0 1 .532 r
F
.22564 .87121 m .22047 .85788 L .21585 .8577 L F
.22564 .87121 m .22467 .86368 L .22047 .85788 L F
.23709 .87124 m .22467 .86368 L .22564 .87121 L 0 1 .531 r
F
0 g
.22294 .87688 m
.22564 .87121 L
s
.22564 .87121 m
.22978 .87679 L
s
.7831 1.0499 m .77791 1.05368 L .77702 1.0554 L 0 .961 .237 r
F
0 g
.76934 1.05862 m
.77702 1.0554 L
s
.59699 .64105 m .61056 .63188 L .60856 .6348 L 0 0 .017 r
F
0 g
.61056 .63188 m
.61634 .63035 L
s
.54375 .9781 m
.54417 .97816 L
s
.65776 .62534 m
.66086 .63862 L
s
.65776 .62533 m
.65776 .62534 L
s
.65761 .62544 m
.65871 .63524 L
s
.65761 .62543 m
.65761 .62544 L
s
.65761 .62543 m
.65761 .62543 L
s
.6576 .62534 m
.65761 .62543 L
s
.44282 .85823 m .43107 .84684 L .43118 .85318 L 0 .862 .354 r
F
0 g
.42777 .85686 m
.42994 .86012 L
s
.44282 .85823 m .4345 .84383 L .43107 .84684 L 0 .862 .354 r
F
0 g
.42749 .84071 m
.43107 .84684 L
s
.62042 .7084 m
.62105 .71142 L
s
.61825 .69814 m
.62042 .7084 L
s
.61774 .69573 m
.61825 .69814 L
s
.61758 .69495 m
.61774 .69573 L
s
.61726 .69272 m
.61754 .69465 L
s
.61754 .69465 m
.61758 .69495 L
s
.46018 .49058 m .45066 .49687 L .45233 .49555 L 0 0 0 r
F
0 g
.45297 .4948 m
.45454 .49358 L
s
.46018 .49058 m .45646 .49422 L .45066 .49687 L 0 0 0 r
F
0 g
.44718 .49929 m
.45297 .4948 L
s
.46018 .49058 m .46586 .48936 L .45646 .49422 L 0 0 0 r
F
.46018 .49058 m .47371 .48438 L .46586 .48936 L F
.46018 .49058 m .47477 .4826 L .47371 .48438 L F
0 g
.46897 .48526 m
.47477 .4826 L
s
.47477 .4826 m
.48227 .4781 L
s
.8015 .89039 m .81121 .89417 L .81295 .88968 L 0 1 .49 r
F
0 g
.80652 .89752 m
.81121 .89417 L
s
.81121 .89417 m
.8133 .89751 L
s
.4143 .91925 m .40797 .91906 L .41226 .91911 L 0 0 0 r
F
.4143 .91925 m .40345 .91892 L .40797 .91906 L F
0 g
.40641 .91903 m
.40797 .91906 L
s
.44877 .94326 m .4397 .94395 L .4441 .94816 L 0 .671 .376 r
F
0 g
.4388 .94877 m
.4397 .94395 L
s
.46917 .82626 m .45825 .81044 L .46088 .81914 L 0 .839 .323 r
F
0 g
.45424 .81097 m
.45825 .81044 L
s
.35611 .77592 m .3456 .77436 L .34737 .78166 L 0 1 .415 r
F
0 g
.35611 .77592 m
.35796 .78318 L
s
.34333 .78792 m
.34737 .78166 L
s
.35161 .78223 m
.35611 .77592 L
s
.32077 .79534 m .31134 .78555 L .31004 .79487 L 0 1 .442 r
F
.32077 .79534 m .31551 .77877 L .31134 .78555 L F
.32077 .79534 m .31977 .77904 L .31551 .77877 L F
.32077 .79534 m .32202 .78615 L .31977 .77904 L F
0 g
.32077 .79534 m
.32306 .8024 L
s
.3166 .80212 m
.32077 .79534 L
s
.45513 .83783 m .44411 .8224 L .44359 .82845 L 0 .862 .338 r
F
.45513 .83783 m .44791 .82099 L .44411 .8224 L F
0 g
.44107 .81537 m
.44411 .8224 L
s
.44411 .8224 m
.44697 .82134 L
s
.31004 .79487 m .2993 .79451 L .30152 .80164 L 0 1 .449 r
F
0 g
.29797 .80852 m
.30152 .80164 L
s
.40336 .6712 m
.40684 .67042 L
s
.40684 .67042 m
.40776 .66852 L
s
.47955 .9152 m .47492 .91265 L .47814 .91354 L 0 .025 .035 r
F
.48315 .91178 m .47814 .91354 L .47492 .91265 L 0 0 .033 r
F
0 g
.4739 .91092 m
.47492 .91265 L
s
.47125 .91297 m
.47492 .91265 L
s
.48336 .82829 m .47352 .80291 L .47572 .81373 L 0 .779 .308 r
F
0 g
.4697 .80053 m
.47352 .80291 L
s
.24327 .67974 m .23226 .67757 L .23256 .68425 L 0 1 .525 r
F
0 g
.22712 .68979 m
.23256 .68425 L
s
.42929 .91873 m .4187 .91929 L .41696 .91894 L 0 0 0 r
F
0 g
.41226 .91911 m
.41696 .91894 L
s
.64421 .62719 m .6458 .62544 L .64272 .62623 L 0 1 .328 r
F
.64421 .62719 m .65214 .62506 L .6458 .62544 L F
.64421 .62719 m .65749 .62535 L .65214 .62506 L F
0 g
.65749 .62535 m
.65776 .62533 L
s
.65749 .62535 m
.65761 .62543 L
s
.44379 .77122 m .43371 .77393 L .43526 .77199 L 0 .027 .002 r
F
.44379 .77122 m .43576 .77544 L .43371 .77393 L F
.44379 .77122 m .4402 .77574 L .43576 .77544 L F
.44379 .77122 m .44405 .77464 L .4402 .77574 L F
.44379 .77122 m .44559 .7727 L .44405 .77464 L F
0 g
.44379 .77122 m
.44552 .76882 L
s
.43936 .77091 m
.44379 .77122 L
s
.4691 1.00112 m .46372 1.00328 L .46808 1.00682 L 0 .446 .375 r
F
0 g
.46372 1.00328 m
.46504 1.00816 L
s
.50661 .91283 m .50339 .90271 L .50529 .90479 L 0 .113 .077 r
F
.50661 .91283 m .502 .90408 L .50339 .90271 L F
0 g
.50339 .90271 m
.50356 .89963 L
s
.40039 .64808 m .39114 .6511 L .39429 .65354 L 0 1 .393 r
F
.40039 .64808 m .39277 .64178 L .39114 .6511 L F
.40039 .64808 m .3981 .6318 L .39277 .64178 L F
.40039 .64808 m .40421 .62634 L .3981 .6318 L F
0 g
.399 .65721 m
.40039 .64808 L
s
.39429 .65354 m
.40039 .64808 L
s
.79856 .78865 m .81079 .78925 L .81026 .79158 L 0 0 0 r
F
0 g
.81079 .78925 m
.81469 .7886 L
s
.80804 .7866 m
.81079 .78925 L
s
.50464 .48571 m .51366 .47978 L .52056 .47541 L 0 0 0 r
F
.37125 .75573 m .36231 .76088 L .36644 .76181 L 0 1 .403 r
F
0 g
.36644 .76181 m
.36828 .76907 L
s
.37125 .75573 m .36105 .75323 L .36231 .76088 L 0 1 .403 r
F
.37125 .75573 m .3635 .74396 L .36105 .75323 L F
.37125 .75573 m .36831 .73788 L .3635 .74396 L F
.37125 .75573 m .37228 .73905 L .36831 .73788 L F
.37125 .75573 m .37354 .7467 L .37228 .73905 L F
0 g
.36644 .76181 m
.37125 .75573 L
s
.49352 .91276 m .4864 .91202 L .48546 .90965 L 0 .067 .058 r
F
0 g
.48212 .91005 m
.48546 .90965 L
s
.44394 .92303 m .43774 .91859 L .43366 .91845 L 0 1 .504 r
F
.44388 .92888 m .43774 .91859 L .43366 .91845 L 0 .721 .376 r
F
.44394 .92303 m .44215 .92055 L .43774 .91859 L 0 1 .504 r
F
.44388 .92888 m .44212 .92306 L .43774 .91859 L 0 .721 .376 r
F
.43966 .91926 m .43366 .91845 L .43774 .91859 L 0 0 0 r
F
.43966 .91926 m .42929 .91873 L .43366 .91845 L F
.43969 .91675 m .43366 .91845 L .43774 .91859 L 0 1 .501 r
F
0 g
.43358 .91842 m
.43366 .91845 L
s
.42932 .91621 m
.43366 .91845 L
s
.38509 .70957 m
.38544 .71805 L
s
.38032 .72367 m
.38544 .71805 L
s
.30371 .76048 m .28989 .75754 L .29247 .76043 L 0 1 .452 r
F
0 g
.28741 .76202 m
.29247 .76043 L
s
.80451 .66807 m .81941 .69198 L .8197 .68091 L 0 1 .447 r
F
0 g
.81941 .69198 m
.82484 .70203 L
s
.46817 .93913 m .46596 .93718 L .4619 .93591 L 0 .935 .488 r
F
0 g
.5811 .65781 m
.58289 .65496 L
s
.43377 .88424 m .43298 .87811 L .42895 .87272 L 0 .847 .37 r
F
0 g
.37743 .73296 m
.37836 .74103 L
s
.37354 .7467 m
.37836 .74103 L
s
.44282 .85823 m .43118 .85318 L .43474 .85935 L 0 .862 .354 r
F
0 g
.43118 .85318 m
.43234 .85518 L
s
.42777 .85686 m
.43118 .85318 L
s
.66585 .62297 m
.6674 .62387 L
s
.52581 .76932 m .52647 .80287 L .52529 .78468 L 0 .511 .172 r
F
0 g
.5259 .77416 m
.52626 .77046 L
s
.52581 .76932 m .52914 .81691 L .52647 .80287 L 0 .511 .172 r
F
0 g
.52625 .77557 m
.52627 .77048 L
s
.52581 .76932 m .5315 .81731 L .52914 .81691 L 0 .511 .172 r
F
.52581 .76932 m .532 .80172 L .5315 .81731 L F
0 g
.52951 .81751 m
.52952 .81698 L
s
.52581 .76932 m .53032 .78071 L .532 .80172 L 0 .511 .172 r
F
0 g
.52767 .7669 m
.53032 .78071 L
s
.52354 .75966 m
.52581 .76932 L
s
.53032 .78071 m
.53041 .76202 L
s
.53885 1.08894 m .53706 1.08751 L .53625 1.0859 L 0 .136 0 r
F
0 g
.65287 .67288 m
.65556 .69174 L
s
.65571 .69281 m
.65777 .70721 L
s
.65556 .69174 m
.65571 .69281 L
s
.65777 .70721 m
.6599 .72219 L
s
.65287 .67288 m
.65387 .69996 L
s
.48043 .94315 m .47195 .94046 L .4716 .94197 L 0 .773 .457 r
F
0 g
.46768 .94089 m
.4716 .94197 L
s
.30668 .67785 m .29615 .67943 L .30041 .68074 L 0 1 .526 r
F
0 g
.30041 .68074 m
.30122 .68594 L
s
.25426 .68199 m .24719 .67192 L .24327 .67974 L 0 1 .525 r
F
.25426 .68199 m .25336 .66691 L .24719 .67192 L F
.25426 .68199 m .25766 .66808 L .25336 .66691 L F
.25426 .68199 m .25804 .67455 L .25766 .66808 L F
0 g
.24811 .68697 m
.25426 .68199 L
s
.25426 .68199 m
.25476 .68816 L
s
.37735 .91722 m .37104 .91783 L .37531 .91785 L 0 .683 .254 r
F
0 g
.37531 .91785 m
.38011 .91841 L
s
.37735 .91722 m .36657 .91694 L .37104 .91783 L 0 .683 .254 r
F
0 g
.36956 .91857 m
.37104 .91783 L
s
.38509 .70957 m .38855 .70006 L .38851 .6915 L 0 1 .391 r
F
.30987 .91123 m .30366 .91325 L .30786 .91326 L 0 1 .465 r
F
0 g
.30786 .91326 m
.31278 .91519 L
s
.30987 .91123 m .29931 .91101 L .30366 .91325 L 0 1 .465 r
F
0 g
.30239 .91538 m
.30366 .91325 L
s
.74417 .89421 m .74992 .89757 L .75431 .89579 L 0 .997 .336 r
F
.74417 .89421 m .74538 .89756 L .74992 .89757 L F
0 g
.74992 .89757 m
.75156 .89937 L
s
.3463 .57676 m
.35062 .58817 L
s
.44283 .84344 m .44305 .83747 L .43973 .83088 L 0 .894 .351 r
F
.46718 .91621 m .45783 .91744 L .4563 .9162 L 0 0 .005 r
F
0 g
.45207 .9169 m
.4563 .9162 L
s
.30776 .87219 m .30069 .87652 L .30496 .87658 L 0 1 .522 r
F
0 g
.30496 .87658 m
.30924 .88094 L
s
.30776 .87219 m .29702 .8719 L .30069 .87652 L 0 1 .522 r
F
0 g
.29861 .88097 m
.30069 .87652 L
s
.78085 .61878 m .78501 .62205 L .78078 .62232 L 0 0 0 r
F
0 g
.78079 .62158 m
.78084 .6191 L
s
.78078 .62225 m
.78079 .62158 L
s
.78078 .62232 m
.78078 .62225 L
s
.78085 .61878 m .79155 .61896 L .78501 .62205 L 0 0 0 r
F
0 g
.78084 .6191 m
.78085 .61878 L
s
.77445 .62266 m
.77449 .62263 L
s
.77449 .62263 m
.77701 .6211 L
s
.77701 .6211 m
.78085 .61878 L
s
.23709 .87124 m .22741 .85814 L .22467 .86368 L 0 1 .531 r
F
.23709 .87124 m .23204 .85832 L .22741 .85814 L F
.23709 .87124 m .23619 .86394 L .23204 .85832 L F
.24855 .87129 m .23619 .86394 L .23709 .87124 L 0 1 .53 r
F
0 g
.23435 .87674 m
.23709 .87124 L
s
.23709 .87124 m
.24119 .87666 L
s
.43221 .56787 m .44317 .55221 L .4415 .55043 L 0 1 .422 r
F
0 g
.44317 .55221 m
.44989 .54742 L
s
.43919 .55968 m
.44317 .55221 L
s
.45639 .82418 m .44791 .82099 L .45246 .82517 L 0 .889 .335 r
F
.45513 .83783 m .45246 .82517 L .44791 .82099 L 0 .862 .338 r
F
0 g
.44697 .82134 m
.44791 .82099 L
s
.4451 .81327 m
.44791 .82099 L
s
.49352 .91276 m .4901 .9085 L .49256 .91038 L 0 .067 .058 r
F
.49665 .90948 m .49256 .91038 L .4901 .9085 L 0 .045 .056 r
F
0 g
.48953 .90594 m
.4901 .9085 L
s
.48885 .90837 m
.4901 .9085 L
s
.40645 .61744 m .41225 .60828 L .41476 .59947 L 0 1 .409 r
F
0 g
.41225 .60828 m
.41845 .60336 L
s
.44283 .84344 m .4345 .84383 L .43917 .84617 L 0 .894 .351 r
F
.44282 .85823 m .43917 .84617 L .4345 .84383 L 0 .862 .354 r
F
0 g
.43107 .84684 m
.4345 .84383 L
s
.43118 .83724 m
.4345 .84383 L
s
.35626 .91685 m .34569 .914 L .34401 .91517 L 0 .899 .341 r
F
.35626 .91685 m .3499 .91418 L .34569 .914 L F
.35626 .91685 m .35444 .9154 L .3499 .91418 L F
.36657 .91694 m .35444 .9154 L .35626 .91685 L 0 .765 .292 r
F
0 g
.35456 .91801 m
.35626 .91685 L
s
.35626 .91685 m
.36068 .91789 L
s
.46084 .98717 m .45893 .99287 L .46137 .99203 L 0 .534 .384 r
F
.4691 1.00112 m .46137 .99203 L .45893 .99287 L 0 .446 .375 r
F
0 g
.45893 .99287 m
.45993 .99769 L
s
.45443 .9892 m
.45893 .99287 L
s
.39437 .66599 m
.39546 .66487 L
s
.38983 .67064 m
.39437 .66599 L
s
.20577 .93179 m .19178 .92842 L .19455 .93159 L 0 .906 .347 r
F
0 g
.19455 .93159 m
.19995 .93394 L
s
.54422 .46709 m
.54611 .46815 L
s
.54611 .46815 m
.55193 .47141 L
s
.53767 .4705 m
.54422 .46709 L
s
.45513 .83783 m .44359 .82845 L .44669 .83567 L 0 .862 .338 r
F
0 g
.43973 .83088 m
.44359 .82845 L
s
.45433 .95743 m .44343 .95279 L .44607 .95863 L 0 .614 .375 r
F
.45433 .95743 m .4441 .94816 L .44343 .95279 L F
0 g
.4388 .94877 m
.44343 .95279 L
s
.44355 .87283 m .43159 .86261 L .43204 .86884 L 0 .829 .356 r
F
0 g
.42895 .87272 m
.43116 .87568 L
s
.44355 .87283 m .43474 .85935 L .43159 .86261 L 0 .829 .356 r
F
0 g
.42994 .86012 m
.43159 .86261 L
s
.51477 .96627 m .51218 .9657 L .51509 .96708 L 0 .318 .212 r
F
.51477 .96627 m .51016 .96439 L .51218 .9657 L F
0 g
.50986 .96498 m
.51218 .9657 L
s
.38509 .70957 m .3759 .71409 L .37967 .71558 L 0 1 .391 r
F
.38509 .70957 m .37585 .70553 L .3759 .71409 L F
.38509 .70957 m .37956 .69562 L .37585 .70553 L F
.38509 .70957 m .38498 .6896 L .37956 .69562 L F
.38509 .70957 m .38851 .6915 L .38498 .6896 L F
0 g
.38851 .6915 m
.39414 .68573 L
s
.38851 .6915 m
.38855 .70006 L
s
.2993 .79451 m .28838 .80138 L .29404 .80148 L 0 1 .456 r
F
0 g
.29404 .80148 m
.29797 .80852 L
s
.73998 1.07157 m .73445 1.07246 L .73314 1.07203 L 0 0 0 r
F
0 g
.72551 1.07331 m
.73314 1.07203 L
s
.48547 .81968 m .47821 .80302 L .48196 .81397 L 0 .788 .306 r
F
.48336 .82829 m .48196 .81397 L .47821 .80302 L 0 .779 .308 r
F
0 g
.47733 .80185 m
.47821 .80302 L
s
.47634 .79139 m
.47821 .80302 L
s
.43634 .89938 m .43521 .89335 L .43102 .88829 L 0 .808 .373 r
F
.49864 .84432 m .49265 .79838 L .49147 .80129 L 0 .66 .291 r
F
.49864 .84432 m .49547 .80984 L .49265 .79838 L F
0 g
.49159 .7846 m
.49265 .79838 L
s
.40204 .67204 m .39531 .6729 L .3986 .67277 L 0 1 .395 r
F
.40204 .67204 m .39389 .67243 L .39531 .6729 L F
0 g
.3986 .67277 m
.3986 .67277 L
s
.39825 .67431 m
.3986 .67277 L
s
.40204 .67204 m .39529 .67165 L .39389 .67243 L 0 1 .395 r
F
.40204 .67204 m .39874 .67092 L .39529 .67165 L F
.40204 .67204 m .40194 .67072 L .39874 .67092 L F
.40204 .67204 m .40335 .6712 L .40194 .67072 L F
0 g
.3986 .67277 m
.40204 .67204 L
s
.64422 .73031 m
.64422 .73076 L
s
.27418 .91077 m .26293 .90403 L .26097 .90683 L 0 1 .501 r
F
.27418 .91077 m .2675 .90424 L .26293 .90403 L F
.27418 .91077 m .27233 .90713 L .2675 .90424 L F
.28545 .91084 m .27233 .90713 L .27418 .91077 L 0 1 .493 r
F
0 g
.27221 .91355 m
.27418 .91077 L
s
.27418 .91077 m
.27892 .91344 L
s
.411 .90011 m .40401 .90212 L .40847 .90241 L 0 1 .505 r
F
.411 .90011 m .39976 .89916 L .40401 .90212 L F
0 g
.40194 .90454 m
.40401 .90212 L
s
.49434 1.04425 m .48758 1.0406 L .49231 1.04583 L 0 .257 .281 r
F
.49434 1.04425 m .48489 1.03611 L .48758 1.0406 L F
0 g
.48319 1.03726 m
.48758 1.0406 L
s
.74417 .89421 m .74291 .89612 L .74538 .89756 L 0 .997 .336 r
F
0 g
.74291 .89612 m
.74538 .89756 L
s
.7403 .899 m
.74538 .89756 L
s
.35772 .68198 m .3484 .67989 L .3481 .68222 L 0 1 .492 r
F
0 g
.34265 .68422 m
.3481 .68222 L
s
.37743 .73296 m .36831 .73788 L .37228 .73905 L 0 1 .397 r
F
0 g
.37228 .73905 m
.37354 .7467 L
s
.37743 .73296 m .36766 .72979 L .36831 .73788 L 0 1 .397 r
F
.37743 .73296 m .37075 .72018 L .36766 .72979 L F
.37743 .73296 m .3759 .71409 L .37075 .72018 L F
.37743 .73296 m .37967 .71558 L .3759 .71409 L F
.37743 .73296 m .38032 .72367 L .37967 .71558 L F
0 g
.37967 .71558 m
.38509 .70957 L
s
.37228 .73905 m
.37743 .73296 L
s
.49111 .95134 m .48998 .9533 L .49158 .95286 L 0 .616 .406 r
F
.49683 .95521 m .49158 .95286 L .48998 .9533 L 0 .512 .36 r
F
0 g
.48998 .9533 m
.49085 .95479 L
s
.48678 .9524 m
.48998 .9533 L
s
.36344 .88714 m .35421 .8785 L .3518 .8819 L 0 1 .514 r
F
.36344 .88714 m .35849 .87882 L .35421 .8785 L F
.36344 .88714 m .36245 .88253 L .35849 .87882 L F
0 g
.36102 .89053 m
.36344 .88714 L
s
.37449 .88777 m .36245 .88253 L .36344 .88714 L 0 1 .511 r
F
0 g
.36344 .88714 m
.36747 .89072 L
s
.72679 .61955 m .74212 .62138 L .73686 .61868 L 0 .771 .3 r
F
0 g
.74212 .62138 m
.74291 .62336 L
s
.74212 .62138 m
.74863 .6232 L
s
.37967 .71558 m
.38032 .72367 L
s
.44388 .92888 m .43849 .93345 L .44232 .93333 L 0 .721 .376 r
F
.44877 .94326 m .44232 .93333 L .43849 .93345 L 0 .671 .376 r
F
0 g
.43737 .938 m
.43849 .93345 L
s
.43411 .92898 m
.43849 .93345 L
s
.28989 .75754 m .28036 .75821 L .28489 .75905 L 0 1 .487 r
F
0 g
.28489 .75905 m
.28741 .76202 L
s
.35789 .76693 m
.36231 .76088 L
s
.44355 .87283 m .43204 .86884 L .43582 .87462 L 0 .829 .356 r
F
0 g
.43204 .86884 m
.43327 .87072 L
s
.42895 .87272 m
.43204 .86884 L
s
.53675 .61594 m .54248 .61505 L .54763 .6169 L 0 .129 .045 r
F
0 g
.54248 .61505 m
.54592 .61138 L
s
.24855 .87129 m .23898 .85858 L .23619 .86394 L 0 1 .53 r
F
.24855 .87129 m .2436 .85876 L .23898 .85858 L F
.24855 .87129 m .24771 .86422 L .2436 .85876 L F
.26001 .87137 m .24771 .86422 L .24855 .87129 L 0 1 .529 r
F
0 g
.24576 .87661 m
.24855 .87129 L
s
.24855 .87129 m
.2526 .87655 L
s
.43221 .56787 m .42332 .57023 L .4254 .5724 L 0 1 .422 r
F
.43221 .56787 m .4273 .56275 L .42332 .57023 L F
.43221 .56787 m .4347 .55494 L .4273 .56275 L F
.43221 .56787 m .4415 .55043 L .4347 .55494 L F
0 g
.42853 .57571 m
.43221 .56787 L
s
.48378 .50323 m .476 .50692 L .47679 .50779 L 0 .948 .201 r
F
.48378 .50323 m .48215 .50142 L .476 .50692 L F
.48378 .50323 m .49114 .49498 L .48215 .50142 L F
.48378 .50323 m .49811 .49044 L .49114 .49498 L F
0 g
.47797 .50909 m
.48378 .50323 L
s
.50979 .8374 m .50765 .79446 L .50846 .81862 L 0 .621 .273 r
F
.50739 .83649 m .50846 .81862 L .50765 .79446 L 0 .629 .277 r
F
0 g
.50765 .79446 m
.50814 .77601 L
s
.50598 .77736 m
.50765 .79446 L
s
.3456 .77436 m .33677 .78045 L .34101 .7809 L 0 1 .423 r
F
0 g
.34101 .7809 m
.34333 .78792 L
s
.39976 .89916 m .38959 .89203 L .38717 .89467 L 0 1 .509 r
F
.79004 .89111 m .79984 .89448 L .8015 .89039 L 0 1 .475 r
F
0 g
.79522 .89754 m
.79984 .89448 L
s
.79984 .89448 m
.802 .89753 L
s
.37079 .68072 m
.3763 .6789 L
s
.64535 .73275 m
.64649 .74638 L
s
.64649 .74638 m
.64687 .7509 L
s
.64687 .7509 m
.64708 .75337 L
s
.64708 .75337 m
.64734 .7565 L
s
.64858 .77129 m
.64879 .77378 L
s
.49683 .95521 m .49655 .95715 L .4977 .9567 L 0 .512 .36 r
F
.50272 .95896 m .4977 .9567 L .49655 .95715 L 0 .448 .299 r
F
0 g
.49655 .95715 m
.49782 .95859 L
s
.49362 .95633 m
.49655 .95715 L
s
.42929 .91873 m .423 .91949 L .4187 .91929 L 0 0 0 r
F
.42929 .91873 m .42754 .91925 L .423 .91949 L F
.43966 .91926 m .42754 .91925 L .42929 .91873 L F
0 g
.42929 .91873 m
.43366 .91845 L
s
.42764 .9184 m
.42929 .91873 L
s
.39412 .6608 m .39556 .6577 L .39428 .65355 L 0 1 .39 r
F
0 g
.39556 .6577 m
.399 .65722 L
s
.3923 .77094 m .38356 .7709 L .38162 .77049 L 0 0 0 r
F
.3923 .77094 m .38815 .77143 L .38356 .7709 L F
.3923 .77094 m .39232 .77173 L .38815 .77143 L F
.3923 .77094 m .3941 .77152 L .39232 .77173 L F
0 g
.38772 .77041 m
.3923 .77094 L
s
.46369 .77117 m
.46369 .77117 L
s
.45969 .77214 m
.46369 .77117 L
s
.40645 .61744 m .41476 .59947 L .41229 .59688 L 0 1 .409 r
F
0 g
.41476 .59947 m
.42128 .59487 L
s
.41225 .60828 m
.41476 .59947 L
s
.47558 .93881 m .46817 .93913 L .47195 .94046 L 0 .825 .47 r
F
.47558 .93881 m .46596 .93718 L .46817 .93913 L F
0 g
.46768 .94089 m
.46817 .93913 L
s
.51223 .83978 m .51093 .79405 L .51125 .81953 L 0 .614 .27 r
F
.50979 .8374 m .51125 .81953 L .51093 .79405 L 0 .621 .273 r
F
0 g
.51093 .79405 m
.51178 .77526 L
s
.50959 .77545 m
.51093 .79405 L
s
.48733 .81308 m .48765 .81207 L .48538 .80186 L 0 .795 .304 r
F
0 g
.48669 .80777 m
.48738 .81086 L
s
.31004 .79487 m .30065 .78509 L .2993 .79451 L 0 1 .449 r
F
.31004 .79487 m .30486 .77818 L .30065 .78509 L F
0 g
.2993 .79451 m
.30152 .80164 L
s
.31004 .79487 m .30912 .7784 L .30486 .77818 L 0 1 .449 r
F
.31004 .79487 m .31134 .78555 L .30912 .7784 L F
0 g
.31004 .79487 m
.3123 .80196 L
s
.30583 .80176 m
.31004 .79487 L
s
.45433 .95743 m .44607 .95863 L .45045 .9626 L 0 .614 .375 r
F
0 g
.44564 .96348 m
.44607 .95863 L
s
.48563 .94733 m .48364 .94925 L .48568 .94886 L 0 .704 .437 r
F
.49111 .95134 m .48568 .94886 L .48364 .94925 L 0 .616 .406 r
F
0 g
.48364 .94925 m
.48411 .95076 L
s
.48021 .94823 m
.48364 .94925 L
s
.50661 .91283 m .50216 .90792 L .502 .90408 L 0 .113 .077 r
F
0 g
.49975 .90333 m
.502 .90408 L
s
.50532 .90418 m
.50549 .90062 L
s
.79346 .66943 m .80853 .68237 L .80451 .66807 L 0 1 .438 r
F
0 g
.80817 .69357 m
.80853 .68237 L
s
.80853 .68237 m
.81491 .6926 L
s
.46768 .83802 m .45706 .8187 L .45639 .82418 L 0 .817 .325 r
F
.46768 .83802 m .46088 .81914 L .45706 .8187 L F
0 g
.45424 .81097 m
.45706 .8187 L
s
.45706 .8187 m
.46019 .81906 L
s
.52998 1.08434 m .53139 1.08307 L .5352 1.08693 L 0 .049 0 r
F
0 g
.53139 1.08307 m
.53624 1.08589 L
s
.31849 .87257 m .31138 .87668 L .31567 .87677 L 0 1 .519 r
F
0 g
.31567 .87677 m
.31987 .881 L
s
.31849 .87257 m .30776 .87219 L .31138 .87668 L 0 1 .519 r
F
0 g
.30924 .88094 m
.31138 .87668 L
s
.2993 .79451 m .28518 .79415 L .28838 .80138 L 0 1 .456 r
F
0 g
.28381 .80839 m
.28838 .80138 L
s
.50428 1.05886 m .49946 1.05366 L .49535 1.05019 L 0 .207 .208 r
F
.42669 .66083 m .41799 .66349 L .42098 .66319 L 0 1 .299 r
F
.42669 .66083 m .4195 .66159 L .41799 .66349 L F
0 g
.42004 .66509 m
.42098 .66319 L
s
.42669 .66083 m .42452 .65877 L .4195 .66159 L 0 1 .299 r
F
.42669 .66083 m .43024 .6564 L .42452 .65877 L F
.42669 .66083 m .43285 .65608 L .43024 .6564 L F
.42669 .66083 m .43133 .65798 L .43285 .65608 L F
0 g
.42545 .66273 m
.42669 .66083 L
s
.42098 .66319 m
.42669 .66083 L
s
.25075 .93302 m .24456 .93402 L .24903 .93406 L 0 .672 .25 r
F
0 g
.24903 .93406 m
.25484 .9351 L
s
.25075 .93302 m .23949 .93264 L .24456 .93402 L 0 .672 .25 r
F
0 g
.24378 .93524 m
.24456 .93402 L
s
.55021 1.0985 m .55305 1.09519 L .55673 1.09951 L 0 .18 0 r
F
.69374 .61864 m .71018 .61952 L .70884 .61808 L 0 .788 .263 r
F
0 g
.71018 .61952 m
.71675 .62032 L
s
.46084 .98717 m .45769 .98154 L .45319 .97789 L 0 .534 .384 r
F
.47955 .9152 m .47097 .91595 L .46957 .91429 L 0 .025 .035 r
F
0 g
.46565 .91497 m
.46957 .91429 L
s
.30668 .67785 m .29618 .67405 L .29615 .67943 L 0 1 .526 r
F
0 g
.29045 .68304 m
.29615 .67943 L
s
.43972 .91425 m .43827 .90833 L .43396 .90358 L 0 .767 .374 r
F
.38554 .88866 m .37846 .89123 L .38286 .89151 L 0 1 .507 r
F
0 g
.38286 .89151 m
.38717 .89467 L
s
.38554 .88866 m .37449 .88777 L .37846 .89123 L 0 1 .507 r
F
0 g
.37627 .89417 m
.37846 .89123 L
s
.43969 .91675 m .42956 .91152 L .42762 .91336 L 0 1 .501 r
F
0 g
.42312 .91108 m
.42762 .91336 L
s
.7831 1.0499 m .788 1.04959 L .79339 1.04528 L 0 .961 .237 r
F
0 g
.781 1.05392 m
.788 1.04959 L
s
.78695 1.05185 m
.788 1.04959 L
s
.39412 .6608 m .38735 .65911 L .3906 .6614 L 0 1 .39 r
F
.39412 .6608 m .38607 .65495 L .38735 .65911 L F
.39412 .6608 m .38761 .6517 L .38607 .65495 L F
.39412 .6608 m .39113 .6511 L .38761 .6517 L F
.39412 .6608 m .39428 .65355 L .39113 .6511 L F
0 g
.3906 .6614 m
.39412 .6608 L
s
.39412 .6608 m
.39546 .66487 L
s
.39428 .65355 m
.39556 .6577 L
s
.44503 .88722 m .43298 .87811 L .43377 .88424 L 0 .793 .358 r
F
.44503 .88722 m .43582 .87462 L .43298 .87811 L F
0 g
.43116 .87568 m
.43298 .87811 L
s
.51477 .96627 m .51509 .96708 L .51706 .96788 L 0 .318 .212 r
F
0 g
.51509 .96708 m
.51746 .96831 L
s
.71766 .64738 m .7322 .63207 L .72765 .64386 L 0 .148 .084 r
F
0 g
.7322 .63207 m
.73243 .62371 L
s
.7322 .63207 m
.737 .62563 L
s
.5228 .97069 m
.52352 .97098 L
s
.52352 .97098 m
.52504 .97159 L
s
.52605 .97228 m .52516 .97185 L .52504 .97159 L 0 0 0 r
F
0 g
.52504 .97159 m
.52504 .9716 L
s
.28989 .75754 m .27863 .75508 L .28036 .75821 L 0 1 .487 r
F
0 g
.27605 .76024 m
.28036 .75821 L
s
.49995 .90613 m .49861 .90748 L .49607 .90692 L 0 .023 .055 r
F
.50166 .7711 m .4979 .78456 L .49924 .77647 L 0 .327 .112 r
F
.50166 .7711 m .49869 .79237 L .4979 .78456 L F
.50166 .7711 m .50108 .79466 L .49869 .79237 L F
0 g
.49885 .76965 m
.49924 .77647 L
s
.50166 .7711 m .50352 .78923 L .50108 .79466 L 0 .327 .112 r
F
.50166 .7711 m .50436 .77974 L .50352 .78923 L F
.50166 .7711 m .50356 .77199 L .50436 .77974 L F
0 g
.50356 .77199 m
.50562 .76478 L
s
.50123 .76339 m
.50166 .7711 L
s
.49924 .77647 m
.50166 .7711 L
s
.50739 .83649 m .50443 .79651 L .50571 .81923 L 0 .629 .277 r
F
.50504 .83688 m .50571 .81923 L .50443 .79651 L 0 .637 .28 r
F
0 g
.50443 .79651 m
.50453 .78221 L
s
.50351 .78924 m
.50443 .79651 L
s
.44282 .85823 m .43474 .85935 L .43939 .86124 L 0 .862 .354 r
F
.44355 .87283 m .43939 .86124 L .43474 .85935 L 0 .829 .356 r
F
0 g
.43159 .86261 m
.43474 .85935 L
s
.43234 .85518 m
.43474 .85935 L
s
.23226 .67757 m .22143 .68238 L .22589 .68312 L 0 1 .525 r
F
0 g
.22589 .68312 m
.22712 .68979 L
s
.48156 .83721 m .47203 .80988 L .47112 .81454 L 0 .768 .311 r
F
.48156 .83721 m .47572 .81373 L .47203 .80988 L F
0 g
.47187 .80925 m
.47203 .80988 L
s
.47203 .80988 m
.47571 .81371 L
s
.40645 .61744 m .39716 .61936 L .39998 .6222 L 0 1 .409 r
F
.40645 .61744 m .39966 .61054 L .39716 .61936 L F
.40645 .61744 m .40582 .60162 L .39966 .61054 L F
.40645 .61744 m .41229 .59688 L .40582 .60162 L F
0 g
.40421 .62634 m
.40645 .61744 L
s
.43774 .91859 m
.43789 .91857 L
s
.45378 .91782 m .44388 .91897 L .44218 .91805 L 0 0 0 r
F
0 g
.43789 .91857 m
.44218 .91805 L
s
.43133 .65798 m
.43676 .65556 L
s
.73998 1.07157 m .74402 1.06828 L .74978 1.06669 L 0 0 0 r
F
0 g
.7369 1.07057 m
.74402 1.06828 L
s
.74252 1.06852 m
.74402 1.06828 L
s
.38162 .77049 m .37261 .76959 L .37693 .76993 L 0 0 0 r
F
0 g
.37693 .76993 m
.37849 .77009 L
s
.49864 .84432 m .49147 .80129 L .49282 .81601 L 0 .66 .291 r
F
0 g
.49574 .79164 m
.49798 .80279 L
s
.49792 .79419 m
.49827 .80341 L
s
.49448 .79425 m
.49493 .80137 L
s
.48835 .79298 m
.49147 .80129 L
s
.39976 .89916 m .39418 .89245 L .38959 .89203 L 0 1 .509 r
F
.39976 .89916 m .39853 .89551 L .39418 .89245 L F
.411 .90011 m .39853 .89551 L .39976 .89916 L 0 1 .505 r
F
0 g
.39976 .89916 m
.40401 .90212 L
s
.39733 .9018 m
.39976 .89916 L
s
.45373 .92355 m .44394 .92303 L .44816 .92499 L 0 1 .494 r
F
.45373 .92355 m .44215 .92055 L .44394 .92303 L F
0 g
.44262 .9247 m
.44394 .92303 L
s
.45449 .85138 m .44305 .83747 L .44283 .84344 L 0 .833 .34 r
F
.45449 .85138 m .44669 .83567 L .44305 .83747 L F
0 g
.43973 .83088 m
.44305 .83747 L
s
.44305 .83747 m
.44566 .83618 L
s
.78278 .6593 m
.78287 .65943 L
s
.77584 .64878 m
.78278 .6593 L
s
.3456 .77436 m .33507 .77313 L .33677 .78045 L 0 1 .423 r
F
0 g
.3456 .77436 m
.34737 .78166 L
s
.33268 .78692 m
.33677 .78045 L
s
.34101 .7809 m
.3456 .77436 L
s
.26001 .87137 m .25054 .85904 L .24771 .86422 L 0 1 .529 r
F
.26001 .87137 m .25517 .85923 L .25054 .85904 L F
.26001 .87137 m .25923 .86452 L .25517 .85923 L F
.27147 .87147 m .25923 .86452 L .26001 .87137 L 0 1 .527 r
F
0 g
.25717 .87651 m
.26001 .87137 L
s
.26001 .87137 m
.26402 .87647 L
s
.4347 .77198 m
.43526 .77199 L
s
.4309 .77189 m
.4347 .77198 L
s
.35772 .68198 m .35259 .67767 L .3484 .67989 L 0 1 .492 r
F
.35772 .68198 m .35843 .67652 L .35259 .67767 L F
.35772 .68198 m .36201 .67722 L .35843 .67652 L F
.35772 .68198 m .3617 .67956 L .36201 .67722 L F
0 g
.35758 .68424 m
.35772 .68198 L
s
.3519 .68312 m
.35772 .68198 L
s
.28685 .54708 m .27456 .55404 L .27842 .55506 L 0 1 .463 r
F
0 g
.27656 .56408 m
.27842 .55506 L
s
.68142 1.08056 m .69363 1.07986 L .68931 1.08135 L 0 0 0 r
F
.69569 1.08664 m .69363 1.07986 L .70123 1.0797 L F
.69569 1.08664 m .68931 1.08135 L .69363 1.07986 L F
0 g
.69194 1.07757 m
.69363 1.07986 L
s
.44282 .85823 m .44274 .85234 L .43917 .84617 L 0 .862 .354 r
F
.48377 1.03072 m .47962 1.02529 L .47532 1.02186 L 0 .328 .343 r
F
.40345 .91892 m .39256 .91829 L .39067 .91846 L 0 .564 .204 r
F
.40345 .91892 m .39702 .91851 L .39256 .91829 L F
.40345 .91892 m .40169 .91878 L .39702 .91851 L F
.4143 .91925 m .40169 .91878 L .40345 .91892 L 0 0 0 r
F
0 g
.40345 .91892 m
.40797 .91906 L
s
.40155 .91908 m
.40345 .91892 L
s
.46917 .82626 m .46989 .82156 L .46726 .81286 L 0 .839 .323 r
F
.62344 .63001 m .6381 .6271 L .63619 .62745 L 0 0 0 r
F
0 g
.6381 .6271 m
.64421 .62719 L
s
.79346 .66943 m .7982 .65769 L .79381 .65819 L 0 1 .438 r
F
.79346 .66943 m .80451 .66807 L .7982 .65769 L F
0 g
.79346 .66943 m
.79381 .65819 L
s
.78724 .65893 m
.79346 .66943 L
s
.44503 .88722 m .43377 .88424 L .43771 .88964 L 0 .793 .358 r
F
0 g
.43377 .88424 m
.43505 .886 L
s
.43102 .88829 m
.43377 .88424 L
s
.43102 .88829 m
.43134 .88867 L
s
.50898 .91051 m .50849 .90164 L .50918 .90631 L 0 .105 .078 r
F
.51138 .90828 m .50918 .90631 L .50849 .90164 L 0 .1 .078 r
F
0 g
.50692 .89921 m
.50849 .90164 L
s
.50849 .90164 m
.50852 .90146 L
s
.28685 .54708 m .27741 .54462 L .27456 .55404 L 0 1 .463 r
F
.28685 .54708 m .28509 .53306 L .27741 .54462 L F
.28685 .54708 m .29354 .52505 L .28509 .53306 L F
.28685 .54708 m .29712 .52595 L .29354 .52505 L F
.28685 .54708 m .29424 .53539 L .29712 .52595 L F
0 g
.28419 .55671 m
.28685 .54708 L
s
.27842 .55506 m
.28685 .54708 L
s
.45513 .83783 m .45556 .83239 L .45246 .82517 L 0 .862 .338 r
F
.73006 .89525 m .73779 .89753 L .74291 .89612 L 0 .769 .26 r
F
.73006 .89525 m .73221 .89751 L .73779 .89753 L F
0 g
.73779 .89753 m
.7403 .899 L
s
.77512 .78028 m .78297 .78672 L .77828 .78511 L 0 .145 0 r
F
.77512 .78028 m .78685 .78495 L .78297 .78672 L F
.42533 .909 m .41516 .90298 L .41296 .90507 L 0 1 .504 r
F
0 g
.40847 .90241 m
.41296 .90507 L
s
.41854 .77223 m .40954 .77185 L .41387 .77157 L 0 0 0 r
F
0 g
.41387 .77157 m
.416 .77071 L
s
.56613 .82717 m .57287 .72612 L .56876 .75811 L 0 .966 .238 r
F
0 g
.57119 .7392 m
.57287 .72612 L
s
.56802 .73748 m
.56855 .76363 L
s
.57279 .71815 m
.57287 .72612 L
s
.50464 .48571 m .52056 .47541 L .52076 .47551 L 0 0 0 r
F
0 g
.52056 .47541 m
.52143 .47488 L
s
.51366 .47978 m
.52056 .47541 L
s
.47558 .93881 m .46672 .93571 L .46596 .93718 L 0 .825 .47 r
F
0 g
.4619 .93591 m
.46596 .93718 L
s
.50272 .95896 m .50331 .96083 L .50399 .9604 L 0 .448 .299 r
F
.50872 .96263 m .50399 .9604 L .50331 .96083 L 0 .393 .233 r
F
0 g
.50331 .96083 m
.50496 .96221 L
s
.50067 .96006 m
.50331 .96083 L
s
.48547 .81968 m .4864 .81634 L .48451 .80469 L 0 .788 .306 r
F
0 g
.48515 .8086 m
.48519 .80883 L
s
.48451 .80469 m
.48515 .8086 L
s
.48451 .80469 m
.48451 .80469 L
s
.48452 .80468 m
.48648 .81053 L
s
.48602 .80475 m
.48669 .80777 L
s
.48538 .80186 m
.48602 .80475 L
s
.47784 1.01492 m .46954 1.0116 L .47353 1.01709 L 0 .347 .356 r
F
.47784 1.01492 m .46808 1.00682 L .46954 1.0116 L F
0 g
.46504 1.00816 m
.46954 1.0116 L
s
.48043 .94315 m .47761 .94497 L .48007 .94467 L 0 .773 .457 r
F
.48563 .94733 m .48007 .94467 L .47761 .94497 L 0 .704 .437 r
F
0 g
.47761 .94497 m
.47767 .9465 L
s
.47399 .94381 m
.47761 .94497 L
s
.56222 .71419 m .566 .70622 L .57064 .69175 L 0 1 .19 r
F
0 g
.56933 .70166 m
.56949 .70075 L
s
.57064 .69175 m
.57067 .6917 L
s
.48226 .773 m
.48239 .77147 L
s
.43864 .50558 m .42828 .51209 L .43054 .51107 L 0 0 0 r
F
0 g
.43194 .51083 m
.43352 .5095 L
s
.43864 .50558 m .43342 .50835 L .42828 .51209 L 0 0 0 r
F
0 g
.42609 .51572 m
.43194 .51083 L
s
.43864 .50558 m .44255 .50236 L .43342 .50835 L 0 0 0 r
F
.43864 .50558 m .45233 .49555 L .45066 .49687 L F
.43864 .50558 m .45066 .49687 L .44255 .50236 L F
0 g
.44851 .49832 m
.45233 .49555 L
s
.45233 .49555 m
.46018 .49058 L
s
.74695 .61769 m .7597 .62321 L .76391 .62309 L 0 1 .41 r
F
.74695 .61769 m .75245 .6209 L .7597 .62321 L F
0 g
.75916 .62303 m
.7597 .62321 L
s
.74773 .63781 m .75279 .62949 L .7597 .62321 L 0 0 .029 r
F
0 g
.75808 .62468 m
.75894 .6239 L
s
.75894 .6239 m
.7597 .62321 L
s
.75329 .62903 m
.75334 .62659 L
s
.75334 .62659 m
.75339 .62347 L
s
.46917 .82626 m .46088 .81914 L .4653 .82522 L 0 .839 .323 r
F
.46768 .83802 m .4653 .82522 L .46088 .81914 L 0 .817 .325 r
F
0 g
.45825 .81044 m
.46088 .81914 L
s
.46019 .81906 m
.46088 .81914 L
s
.46768 .83802 m .45639 .82418 L .4593 .83227 L 0 .817 .325 r
F
0 g
.45246 .82517 m
.45639 .82418 L
s
.51469 .84381 m .51423 .79562 L .51407 .82219 L 0 .607 .267 r
F
.51223 .83978 m .51407 .82219 L .51423 .79562 L 0 .614 .27 r
F
0 g
.51324 .77557 m
.51423 .79562 L
s
.51423 .79562 m
.51543 .77682 L
s
.44877 .94326 m .4441 .94816 L .44764 .94782 L 0 .671 .376 r
F
.45433 .95743 m .44764 .94782 L .4441 .94816 L 0 .614 .375 r
F
0 g
.44343 .95279 m
.4441 .94816 L
s
.4397 .94395 m
.4441 .94816 L
s
.45449 .85138 m .44283 .84344 L .44617 .85017 L 0 .833 .34 r
F
0 g
.43917 .84617 m
.44283 .84344 L
s
.44603 .54328 m .45374 .53554 L .45859 .52875 L 0 1 .398 r
F
0 g
.45374 .53554 m
.46045 .53077 L
s
.25009 .57064 m .2378 .57771 L .24192 .57848 L 0 1 .484 r
F
0 g
.24083 .58735 m
.24192 .57848 L
s
.48377 1.03072 m .48489 1.03611 L .48603 1.03536 L 0 .328 .343 r
F
.49434 1.04425 m .48603 1.03536 L .48489 1.03611 L 0 .257 .281 r
F
0 g
.48489 1.03611 m
.48758 1.0406 L
s
.48059 1.03268 m
.48489 1.03611 L
s
.38983 .67064 m
.3906 .66141 L
s
.45513 .83783 m .44669 .83567 L .45133 .83924 L 0 .862 .338 r
F
.45449 .85138 m .45133 .83924 L .44669 .83567 L 0 .833 .34 r
F
0 g
.44566 .83618 m
.44669 .83567 L
s
.44359 .82845 m
.44669 .83567 L
s
.32044 .91154 m .31416 .91329 L .31836 .91333 L 0 1 .447 r
F
0 g
.31836 .91333 m
.32318 .91508 L
s
.32044 .91154 m .30987 .91123 L .31416 .91329 L 0 1 .447 r
F
0 g
.31278 .91519 m
.31416 .91329 L
s
.27863 .75508 m .26903 .75609 L .27356 .75694 L 0 1 .505 r
F
0 g
.27356 .75694 m
.27605 .76024 L
s
.46053 .9714 m .45022 .9673 L .45314 .97302 L 0 .548 .372 r
F
.46053 .9714 m .45045 .9626 L .45022 .9673 L F
0 g
.44564 .96348 m
.45022 .9673 L
s
.44722 .90143 m .43521 .89335 L .43634 .89938 L 0 .754 .36 r
F
.44722 .90143 m .43771 .88964 L .43521 .89335 L F
0 g
.43134 .88867 m
.43521 .89335 L
s
.39067 .91846 m
.39067 .91846 L
s
.43774 .91859 m
.43785 .91863 L
s
.43774 .91859 m
.438 .91835 L
s
.27147 .87147 m .26211 .85952 L .25923 .86452 L 0 1 .527 r
F
.27147 .87147 m .26673 .85972 L .26211 .85952 L F
.27147 .87147 m .27075 .86485 L .26673 .85972 L F
.28294 .87163 m .27075 .86485 L .27147 .87147 L 0 1 .526 r
F
0 g
.26859 .87645 m
.27147 .87147 L
s
.27147 .87147 m
.27544 .87642 L
s
.6813 .62125 m
.68229 .6212 L
s
.6823 .6212 m .68625 .61877 L .68178 .61994 L 0 .766 .25 r
F
.6823 .6212 m .69373 .61864 L .68625 .61877 L F
.6823 .6212 m .69921 .61964 L .69373 .61864 L F
0 g
.68178 .61994 m
.6823 .6212 L
s
.69921 .61964 m
.69969 .6209 L
s
.32923 .87307 m .32209 .87694 L .32637 .87707 L 0 1 .517 r
F
0 g
.32637 .87707 m
.33051 .88116 L
s
.32923 .87307 m .31849 .87257 L .32209 .87694 L 0 1 .517 r
F
0 g
.31987 .881 m
.32209 .87694 L
s
.36105 .75323 m .35199 .75888 L .35612 .75963 L 0 1 .41 r
F
0 g
.35612 .75963 m
.35789 .76693 L
s
.36105 .75323 m .35084 .7512 L .35199 .75888 L 0 1 .41 r
F
.36105 .75323 m .35344 .7417 L .35084 .7512 L F
.36105 .75323 m .35837 .7353 L .35344 .7417 L F
.36105 .75323 m .36235 .73627 L .35837 .7353 L F
.36105 .75323 m .3635 .74396 L .36235 .73627 L F
0 g
.36105 .75323 m
.36231 .76088 L
s
.35612 .75963 m
.36105 .75323 L
s
.77858 .89186 m .78847 .8948 L .79004 .89111 L 0 1 .454 r
F
0 g
.78391 .89756 m
.78847 .8948 L
s
.78847 .8948 m
.79069 .89754 L
s
.20577 .93179 m .19312 .92626 L .19178 .92842 L 0 .906 .347 r
F
.20577 .93179 m .19769 .92659 L .19312 .92626 L F
.20577 .93179 m .20312 .92896 L .19769 .92659 L F
.217 .93204 m .20312 .92896 L .20577 .93179 L 0 .83 .318 r
F
0 g
.20441 .93392 m
.20577 .93179 L
s
.20577 .93179 m
.21109 .9339 L
s
.50504 .83688 m .50131 .79991 L .50304 .82113 L 0 .637 .28 r
F
.50279 .83841 m .50304 .82113 L .50131 .79991 L 0 .646 .284 r
F
0 g
.50041 .79433 m
.50131 .79991 L
s
.50123 .79434 m
.50131 .79991 L
s
.52105 .77322 m .52297 .77203 L .52529 .78468 L 0 .487 .163 r
F
0 g
.52406 .79324 m
.52497 .78381 L
s
.52503 .78323 m
.52551 .77826 L
s
.52297 .77203 m
.52354 .75966 L
s
.52625 .97233 m
.52656 .97241 L
s
.52678 .97247 m
.5269 .9725 L
s
.52691 .9725 m
.52724 .97259 L
s
.52725 .97259 m
.52739 .97263 L
s
.52658 .97242 m
.52678 .97247 L
s
.53172 .97511 m .52886 .97368 L .52739 .97263 L 0 0 0 r
F
0 g
.52739 .97263 m
.52739 .97263 L
s
.46281 .93418 m .46081 .93213 L .45665 .93065 L 0 .967 .493 r
F
.44355 .87283 m .43582 .87462 L .4404 .87609 L 0 .829 .356 r
F
.44503 .88722 m .4404 .87609 L .43582 .87462 L 0 .793 .358 r
F
0 g
.43298 .87811 m
.43582 .87462 L
s
.43327 .87072 m
.43582 .87462 L
s
.73006 .89525 m .72889 .89653 L .73221 .89751 L 0 .769 .26 r
F
0 g
.72889 .89653 m
.73221 .89751 L
s
.72646 .89848 m
.73221 .89751 L
s
.75957 1.06239 m .77106 1.05776 L .76708 1.05944 L 0 .776 .205 r
F
.74978 1.06669 m .75957 1.06239 L .76111 1.06214 L 0 0 0 r
F
.45373 .92355 m .44816 .92499 L .45199 .92512 L 0 1 .494 r
F
.45798 .92898 m .45199 .92512 L .44816 .92499 L 0 .991 .495 r
F
0 g
.44684 .92666 m
.44816 .92499 L
s
.44394 .92303 m
.44816 .92499 L
s
.59125 .63629 m
.59323 .64027 L
s
.59323 .64027 m
.59454 .64288 L
s
.59675 .64732 m
.59709 .648 L
s
.59607 .64595 m
.59675 .64732 L
s
.59543 .64467 m
.59607 .64595 L
s
.59523 .64428 m
.59543 .64467 L
s
.58902 .63914 m
.59125 .63629 L
s
.48156 .83721 m .47112 .81454 L .47362 .8246 L 0 .768 .311 r
F
0 g
.46726 .81286 m
.47112 .81454 L
s
.23226 .67757 m .22123 .67548 L .22143 .68238 L 0 1 .525 r
F
0 g
.21592 .68818 m
.22143 .68238 L
s
.28545 .91084 m .27437 .90457 L .27233 .90713 L 0 1 .493 r
F
.28545 .91084 m .27896 .9048 L .27437 .90457 L F
.28545 .91084 m .28371 .90749 L .27896 .9048 L F
0 g
.2834 .91338 m
.28545 .91084 L
s
.2993 .91101 m .28371 .90749 L .28545 .91084 L 0 1 .479 r
F
0 g
.28545 .91084 m
.29088 .91331 L
s
.2993 .79451 m .28659 .78461 L .28518 .79415 L 0 1 .456 r
F
.2993 .79451 m .29185 .77761 L .28659 .78461 L F
0 g
.28518 .79415 m
.28838 .80138 L
s
.2993 .79451 m .29746 .77784 L .29185 .77761 L 0 1 .456 r
F
.2993 .79451 m .30064 .78509 L .29746 .77784 L F
0 g
.29404 .80148 m
.2993 .79451 L
s
.6653 1.08576 m .6675 1.07973 L .67338 1.08308 L 0 .079 0 r
F
0 g
.66426 1.07868 m
.6675 1.07973 L
s
.66537 1.0769 m
.6675 1.07973 L
s
.53675 .61594 m .53359 .62078 L .53293 .61839 L 0 .129 .045 r
F
.53675 .61594 m .53875 .62264 L .53359 .62078 L F
.53675 .61594 m .54497 .62272 L .53875 .62264 L F
.53675 .61594 m .54877 .62026 L .54497 .62272 L F
.53675 .61594 m .54763 .6169 L .54877 .62026 L F
0 g
.54763 .6169 m
.55095 .61422 L
s
.53196 .61447 m
.53675 .61594 L
s
.54248 .61505 m
.54763 .6169 L
s
.44722 .90143 m .43634 .89938 L .44041 .90443 L 0 .754 .36 r
F
0 g
.43634 .89938 m
.43766 .90102 L
s
.43396 .90358 m
.43634 .89938 L
s
.26674 .56163 m
.27456 .55404 L
s
.74892 .78915 m .75481 .77401 L .75951 .77669 L 0 .279 .073 r
F
.74892 .78915 m .75028 .77932 L .75481 .77401 L F
0 g
.7516 .76699 m
.75481 .77401 L
s
.27863 .75508 m .26737 .7526 L .26903 .75609 L 0 1 .505 r
F
0 g
.26468 .75843 m
.26903 .75609 L
s
.38162 .77049 m .37093 .7695 L .37261 .76959 L 0 0 0 r
F
0 g
.36827 .76949 m
.37166 .76957 L
s
.3635 .74396 m
.36831 .73788 L
s
.49678 .84845 m .48977 .80581 L .48869 .80895 L 0 .665 .294 r
F
.49678 .84845 m .49282 .81601 L .48977 .80581 L F
0 g
.48935 .80195 m
.48977 .80581 L
s
.31423 .7626 m .30573 .7582 L .30371 .76048 L 0 .973 .414 r
F
0 g
.30371 .76048 m
.30538 .76273 L
s
.31423 .7626 m .31136 .7587 L .30573 .7582 L 0 .973 .414 r
F
.31395 .77143 m .31136 .7587 L .30563 .76127 L 0 1 .446 r
F
.31136 .7587 m .31046 .75428 L .30813 .75764 L F
.31136 .7587 m .31463 .75456 L .31046 .75428 L F
.31423 .7626 m .31442 .75976 L .31136 .7587 L 0 .973 .414 r
F
.31423 .7626 m .31616 .76074 L .31578 .76023 L F
.31442 .75976 m .31578 .76023 L .31463 .75456 L 0 1 .446 r
F
.31442 .75976 m .31578 .76023 L .3145 .75849 L 0 .973 .414 r
F
.31423 .7626 m .31578 .76023 L .31442 .75976 L F
.31395 .77143 m .31612 .76191 L .31578 .76023 L 0 1 .446 r
F
.31395 .77143 m .31578 .76023 L .31442 .75976 L F
.31395 .77143 m .31442 .75976 L .31136 .7587 L F
.31442 .75976 m .31463 .75456 L .31136 .7587 L F
.31442 .75976 m .31442 .75971 L .31136 .7587 L 0 .973 .414 r
F
.31136 .7587 m .3145 .75849 L .31036 .75734 L F
.31442 .75971 m .3145 .75849 L .31136 .7587 L F
.31136 .7587 m .30813 .75764 L .30804 .75777 L 0 1 .446 r
F
.31136 .7587 m .30804 .75777 L .30573 .7582 L 0 .973 .414 r
F
.31136 .7587 m .30804 .75777 L .30563 .76127 L 0 1 .446 r
F
.31136 .7587 m .31036 .75734 L .30804 .75777 L 0 .973 .414 r
F
0 g
.31562 .7641 m
.31597 .76448 L
s
.33507 .77313 m .32615 .77951 L .3304 .77986 L 0 1 .43 r
F
0 g
.3304 .77986 m
.33268 .78692 L
s
.55021 1.0985 m .54448 1.09365 L .54082 1.08934 L 0 .18 0 r
F
.49434 1.04425 m .49231 1.04583 L .49636 1.04933 L 0 .257 .281 r
F
0 g
.49231 1.04583 m
.49535 1.05019 L
s
.67338 1.08308 m .68142 1.08056 L .68359 1.0834 L 0 0 0 r
F
0 g
.68142 1.08056 m
.68142 1.08056 L
s
.68142 1.08056 m
.68142 1.08056 L
s
.52144 .97031 m .52081 .96994 L .52207 .97073 L 0 .155 .175 r
F
.52081 .96994 m .51946 .96914 L .52232 .9705 L 0 .223 .181 r
F
.5193 .96887 m .52081 .96994 L .52144 .97031 L 0 .155 .175 r
F
.52081 .96994 m .51943 .96913 L .51946 .96914 L 0 .223 .181 r
F
0 g
.49811 .49044 m
.50464 .48571 L
s
.49114 .49498 m
.49811 .49044 L
s
.65702 .65638 m .66639 .6821 L .65929 .64047 L 0 .245 .231 r
F
0 g
.65871 .63524 m
.65929 .64047 L
s
.66086 .63862 m
.66175 .64244 L
s
.6561 .64996 m
.65702 .65638 L
s
.65562 .62886 m
.65702 .65638 L
s
.45373 .92355 m .44388 .91897 L .44215 .92055 L 0 1 .494 r
F
0 g
.43924 .91926 m
.44215 .92055 L
s
.477 .77243 m .47017 .77702 L .47324 .77366 L 0 .23 .073 r
F
.477 .77243 m .46959 .7812 L .47017 .77702 L F
.477 .77243 m .47191 .78341 L .46959 .7812 L F
.477 .77243 m .47568 .78217 L .47191 .78341 L F
0 g
.47324 .77366 m
.47422 .76997 L
s
.477 .77243 m .47837 .77832 L .47568 .78217 L 0 .23 .073 r
F
.477 .77243 m .47893 .77415 L .47837 .77832 L F
0 g
.477 .77243 m
.47767 .76864 L
s
.47324 .77366 m
.477 .77243 L
s
.47893 .77415 m
.48239 .77147 L
s
.24327 .67974 m .23632 .6694 L .23226 .67757 L 0 1 .525 r
F
.24327 .67974 m .24261 .66409 L .23632 .6694 L F
.24327 .67974 m .24691 .6652 L .24261 .66409 L F
.24327 .67974 m .24719 .67192 L .24691 .6652 L F
0 g
.23701 .68502 m
.24327 .67974 L
s
.24327 .67974 m
.24367 .68618 L
s
.44355 .87283 m .44317 .86701 L .43939 .86124 L 0 .829 .356 r
F
0 g
.66092 .64998 m
.66395 .66779 L
s
.65929 .64047 m
.66092 .64998 L
s
.66395 .66779 m
.66407 .66849 L
s
.28294 .87163 m .27367 .86003 L .27075 .86485 L 0 1 .526 r
F
.28294 .87163 m .2783 .86025 L .27367 .86003 L F
.28294 .87163 m .28227 .86523 L .2783 .86025 L F
0 g
.28001 .87642 m
.28294 .87163 L
s
.29702 .8719 m .28227 .86523 L .28294 .87163 L 0 1 .524 r
F
0 g
.28294 .87163 m
.28765 .87644 L
s
.38555 .68066 m .37616 .68516 L .37969 .68689 L 0 1 .391 r
F
0 g
.38498 .6896 m
.38555 .68066 L
s
.48315 .91178 m .48167 .91317 L .47814 .91354 L 0 0 .033 r
F
.49058 .91596 m .48315 .91178 L .4864 .91202 L 0 .09 .059 r
F
.49058 .91596 m .48167 .91317 L .48315 .91178 L F
0 g
.48212 .91005 m
.48315 .91178 L
s
.48315 .91178 m
.48483 .9119 L
s
.37449 .88777 m .36507 .87939 L .36245 .88253 L 0 1 .511 r
F
.37449 .88777 m .36955 .87982 L .36507 .87939 L F
.37449 .88777 m .37358 .88342 L .36955 .87982 L F
.38554 .88866 m .37358 .88342 L .37449 .88777 L 0 1 .507 r
F
0 g
.37449 .88777 m
.37846 .89123 L
s
.37187 .89089 m
.37449 .88777 L
s
.4154 .58865 m .42201 .58029 L .4254 .5724 L 0 1 .431 r
F
0 g
.42201 .58029 m
.42853 .57571 L
s
.50428 1.05886 m .50754 1.06324 L .50774 1.06297 L 0 .207 .208 r
F
.51638 1.07197 m .50774 1.06297 L .50754 1.06324 L 0 .058 .167 r
F
0 g
.50342 1.05976 m
.50754 1.06324 L
s
.50754 1.06324 m
.51137 1.0671 L
s
.63443 .75595 m
.63444 .75145 L
s
.63444 .74872 m
.63447 .73117 L
s
.56222 .71419 m .57177 .67871 L .5676 .68782 L 0 1 .19 r
F
0 g
.5698 .729 m
.57274 .71282 L
s
.56809 .69969 m
.57064 .69175 L
s
.56713 .7027 m
.56809 .69969 L
s
.57177 .67871 m
.57418 .67328 L
s
.57177 .67871 m
.57215 .67922 L
s
.34748 .7652 m
.35199 .75888 L
s
.81026 .79158 m .82249 .7923 L .82195 .79387 L 0 0 0 r
F
0 g
.82249 .7923 m
.82641 .79203 L
s
.81974 .7903 m
.82249 .7923 L
s
.78666 .64776 m
.78724 .65893 L
s
.4179 .52295 m .42609 .51572 L .43054 .51107 L 0 .961 .202 r
F
0 g
.41337 .52761 m
.4179 .52294 L
s
.46053 .9714 m .45314 .97302 L .45745 .9768 L 0 .548 .372 r
F
0 g
.45314 .97302 m
.45319 .97789 L
s
.67277 .91821 m
.67331 .91738 L
s
.67191 .91954 m
.67277 .91821 L
s
.67179 .91974 m
.67191 .91954 L
s
.67307 .9149 m
.67331 .91498 L
s
.45447 .86481 m .44274 .85234 L .44282 .85823 L 0 .803 .342 r
F
0 g
.43939 .86124 m
.44188 .86504 L
s
.45447 .86481 m .44617 .85017 L .44274 .85234 L 0 .803 .342 r
F
0 g
.43917 .84617 m
.44274 .85234 L
s
.44274 .85234 m
.44507 .85087 L
s
.47111 .93428 m .46281 .93418 L .46672 .93571 L 0 .866 .477 r
F
.47111 .93428 m .46081 .93213 L .46281 .93418 L F
0 g
.4619 .93591 m
.46281 .93418 L
s
.39277 .64178 m .3981 .6318 L .39998 .6222 L 0 1 .397 r
F
0 g
.3981 .6318 m
.40421 .62634 L
s
.72679 .61955 m .72992 .61704 L .72596 .61755 L 0 .771 .3 r
F
.72679 .61955 m .73686 .61868 L .72992 .61704 L F
.50432 .91522 m .49995 .90613 L .50216 .90792 L 0 .124 .078 r
F
.50432 .91522 m .49861 .90748 L .49995 .90613 L F
0 g
.49975 .90333 m
.49995 .90613 L
s
.29618 .67405 m .28549 .67617 L .28976 .67747 L 0 1 .522 r
F
0 g
.28976 .67747 m
.29045 .68304 L
s
.36657 .91694 m .35622 .91449 L .35444 .9154 L 0 .765 .292 r
F
.36657 .91694 m .36044 .91473 L .35622 .91449 L F
.36657 .91694 m .36487 .91578 L .36044 .91473 L F
0 g
.36477 .91784 m
.36657 .91694 L
s
.37735 .91722 m .36488 .91578 L .36657 .91694 L 0 .683 .254 r
F
0 g
.36657 .91694 m
.37104 .91783 L
s
.45011 .91544 m .43827 .90833 L .43972 .91425 L 0 .712 .361 r
F
.45011 .91544 m .44041 .90443 L .43827 .90833 L F
0 g
.43396 .90358 m
.43827 .90833 L
s
.47558 .93881 m .47195 .94046 L .47481 .94028 L 0 .825 .47 r
F
.48043 .94315 m .47481 .94028 L .47195 .94046 L 0 .773 .457 r
F
0 g
.4716 .94197 m
.47195 .94046 L
s
.46817 .93913 m
.47195 .94046 L
s
.48336 .82829 m .47572 .81373 L .47974 .82354 L 0 .779 .308 r
F
.48156 .83721 m .47974 .82354 L .47572 .81373 L 0 .768 .311 r
F
0 g
.47352 .80291 m
.47572 .81373 L
s
.47571 .81371 m
.47572 .81373 L
s
.3484 .67989 m .33862 .67944 L .34242 .68065 L 0 1 .508 r
F
0 g
.34242 .68065 m
.34265 .68422 L
s
.50872 .96263 m .51016 .96439 L .51037 .96401 L 0 .393 .233 r
F
.51477 .96627 m .51037 .96401 L .51016 .96439 L 0 .318 .212 r
F
0 g
.51016 .96439 m
.51218 .9657 L
s
.50785 .96362 m
.51016 .96439 L
s
.44603 .54328 m .45859 .52875 L .45735 .52744 L 0 1 .398 r
F
0 g
.45859 .52875 m
.46548 .52399 L
s
.45374 .53554 m
.45859 .52875 L
s
.71931 .89609 m .72483 .89746 L .72889 .89653 L 0 .703 .24 r
F
.71931 .89609 m .72057 .89743 L .72483 .89746 L F
0 g
.72483 .89746 m
.72646 .89848 L
s
.67728 .67367 m
.67738 .67962 L
s
.67739 .68016 m
.6774 .68099 L
s
.67347 .69467 m
.67639 .67854 L
s
.67688 .67583 m
.67728 .67367 L
s
.67333 .69544 m
.67347 .69467 L
s
.47784 1.01492 m .47353 1.01709 L .47771 1.02057 L 0 .347 .356 r
F
0 g
.47353 1.01709 m
.47532 1.02186 L
s
.30668 .67785 m .30049 .66816 L .29618 .67405 L 0 1 .526 r
F
.30668 .67785 m .30677 .66525 L .30049 .66816 L F
.30668 .67785 m .31083 .66728 L .30677 .66525 L F
.30668 .67785 m .31078 .67269 L .31083 .66728 L F
0 g
.30041 .68074 m
.30668 .67785 L
s
.33997 .8737 m .33279 .87731 L .33707 .87749 L 0 1 .515 r
F
0 g
.33707 .87749 m
.34115 .88145 L
s
.33997 .8737 m .32923 .87307 L .33279 .87731 L 0 1 .515 r
F
0 g
.33051 .88116 m
.33279 .87731 L
s
.44877 .94326 m .44672 .93754 L .44232 .93333 L 0 .671 .376 r
F
.38815 .91771 m .38172 .91794 L .386 .91805 L 0 .622 .235 r
F
0 g
.386 .91805 m
.39067 .91846 L
s
.38815 .91771 m .37735 .91722 L .38172 .91794 L 0 .622 .235 r
F
0 g
.38011 .91841 m
.38172 .91794 L
s
.46667 .84982 m .45556 .83239 L .45513 .83783 L 0 .793 .327 r
F
.46667 .84982 m .4593 .83227 L .45556 .83239 L F
0 g
.45246 .82517 m
.45556 .83239 L
s
.45556 .83239 m
.45845 .8323 L
s
.52998 1.08434 m .52467 1.07937 L .52088 1.07552 L 0 .049 0 r
F
0 g
.52088 1.07552 m
.52467 1.07937 L
s
.51669 1.07198 m
.52088 1.07552 L
s
.44503 .88722 m .43771 .88964 L .44218 .89072 L 0 .793 .358 r
F
.44722 .90143 m .44218 .89072 L .43771 .88964 L 0 .754 .36 r
F
0 g
.43521 .89335 m
.43771 .88964 L
s
.43505 .886 m
.43771 .88964 L
s
.26203 .93344 m .25574 .93415 L .26022 .93421 L 0 .639 .239 r
F
0 g
.26022 .93421 m
.26591 .935 L
s
.26203 .93344 m .25075 .93302 L .25574 .93415 L 0 .639 .239 r
F
0 g
.25484 .9351 m
.25574 .93415 L
s
.50464 .48571 m .49712 .48908 L .49755 .4897 L 0 0 0 r
F
.50464 .48571 m .50405 .4847 L .49712 .48908 L F
.50464 .48571 m .51369 .47949 L .50405 .4847 L F
.50464 .48571 m .52076 .47551 L .51369 .47949 L F
.52105 .77322 m .52079 .80123 L .52012 .78569 L 0 .487 .163 r
F
.52105 .77322 m .52312 .81406 L .52079 .80123 L F
0 g
.52211 .79402 m
.52265 .78902 L
s
.52105 .77322 m .52555 .81552 L .52312 .81406 L 0 .487 .163 r
F
.52105 .77322 m .52647 .80287 L .52555 .81552 L F
0 g
.52395 .81655 m
.52396 .81456 L
s
.52105 .77322 m .52529 .78468 L .52647 .80287 L 0 .487 .163 r
F
0 g
.52297 .77203 m
.52529 .78468 L
s
.51911 .76344 m
.52105 .77322 L
s
.52529 .78468 m
.52581 .76932 L
s
.4691 1.00112 m .46808 1.00682 L .47011 1.00595 L 0 .446 .375 r
F
.47784 1.01492 m .47011 1.00595 L .46808 1.00682 L 0 .347 .356 r
F
0 g
.46808 1.00682 m
.46954 1.0116 L
s
.46372 1.00328 m
.46808 1.00682 L
s
.66583 .62289 m
.66735 .62279 L
s
.67082 .62255 m
.67248 .62244 L
s
.44949 .77249 m
.44983 .77247 L
s
.44559 .7727 m
.44949 .77249 L
s
.26737 .7526 m .25768 .75398 L .26222 .75482 L 0 1 .518 r
F
0 g
.26222 .75482 m
.26468 .75843 L
s
.4179 .52295 m .40682 .52996 L .40964 .52905 L 0 .961 .202 r
F
0 g
.41179 .52908 m
.41337 .52761 L
s
.4179 .52295 m .41126 .52531 L .40682 .52996 L 0 .961 .202 r
F
0 g
.40595 .53452 m
.41179 .52908 L
s
.4179 .52295 m .42001 .51819 L .41126 .52531 L 0 .961 .202 r
F
.4179 .52295 m .42828 .51209 L .42001 .51819 L F
.4179 .52295 m .43054 .51107 L .42828 .51209 L F
0 g
.42609 .51572 m
.43054 .51107 L
s
.41049 .52842 m
.4179 .52295 L
s
.43054 .51107 m
.43864 .50558 L
s
.33507 .77313 m .32452 .77217 L .32615 .77951 L 0 1 .43 r
F
0 g
.33507 .77313 m
.33677 .78045 L
s
.32202 .78615 m
.32615 .77951 L
s
.3304 .77986 m
.33507 .77313 L
s
.39277 .64178 m .39998 .6222 L .39716 .61936 L 0 1 .397 r
F
0 g
.39998 .6222 m
.40645 .61744 L
s
.3981 .6318 m
.39998 .6222 L
s
.76712 .89262 m .77709 .89513 L .77858 .89186 L 0 1 .426 r
F
0 g
.77259 .89757 m
.77709 .89513 L
s
.77709 .89513 m
.77938 .89756 L
s
.41854 .77223 m .40787 .77285 L .40954 .77185 L 0 0 0 r
F
0 g
.40506 .7715 m
.40954 .77185 L
s
.41854 .77223 m .40998 .77391 L .40787 .77285 L 0 0 0 r
F
.41854 .77223 m .41466 .77457 L .40998 .77391 L F
.41854 .77223 m .41879 .77439 L .41466 .77457 L F
.41854 .77223 m .42045 .77339 L .41879 .77439 L F
0 g
.41854 .77223 m
.42036 .77088 L
s
.41387 .77157 m
.41854 .77223 L
s
.50645 .77315 m .50352 .78923 L .50436 .77974 L 0 .372 .125 r
F
.50645 .77315 m .50471 .79812 L .50352 .78923 L F
0 g
.50356 .77199 m
.50436 .77974 L
s
.50645 .77315 m .50715 .80046 L .50471 .79812 L 0 .372 .125 r
F
.50645 .77315 m .50924 .79379 L .50715 .80046 L F
.50645 .77315 m .50959 .78262 L .50924 .79379 L F
.50645 .77315 m .50839 .7738 L .50959 .78262 L F
0 g
.50562 .76478 m
.50645 .77315 L
s
.50436 .77974 m
.50645 .77315 L
s
.50839 .7738 m
.5101 .7655 L
s
.49678 .84845 m .48869 .80895 L .49038 .82281 L 0 .665 .294 r
F
0 g
.49147 .80129 m
.4922 .80923 L
s
.48538 .80185 m
.48869 .80895 L
s
.45447 .86481 m .44282 .85823 L .44637 .86451 L 0 .803 .342 r
F
0 g
.44282 .85823 m
.44374 .85986 L
s
.43939 .86124 m
.44282 .85823 L
s
.45011 .91544 m .43972 .91425 L .44388 .91897 L 0 .712 .361 r
F
0 g
.43972 .91425 m
.44107 .91579 L
s
.43879 .91629 m
.43972 .91425 L
s
.50279 .83841 m .49831 .80442 L .50049 .82413 L 0 .646 .284 r
F
.50065 .84094 m .50049 .82413 L .49831 .80442 L 0 .654 .287 r
F
0 g
.49827 .80341 m
.49831 .80442 L
s
.49798 .80279 m
.49831 .80442 L
s
.52391 .89955 m .52303 .89992 L .52373 .89398 L 0 .125 .092 r
F
0 g
.5218 .9002 m
.52373 .89398 L
s
.45449 .85138 m .45467 .84597 L .45133 .83924 L 0 .833 .34 r
F
.80367 1.0412 m .81518 1.03483 L .81101 1.0364 L 0 1 .322 r
F
.79339 1.04528 m .80367 1.0412 L .80476 1.03891 L 0 1 .27 r
F
.37585 .70553 m .37956 .69562 L .37969 .68689 L 0 1 .396 r
F
0 g
.37956 .69562 m
.38498 .6896 L
s
.52075 .46889 m
.5281 .47094 L
s
.51369 .4729 m
.52075 .46889 L
s
.36766 .72979 m .35837 .7353 L .36235 .73627 L 0 1 .403 r
F
0 g
.36235 .73627 m
.3635 .74396 L
s
.36766 .72979 m .35785 .72715 L .35837 .7353 L 0 1 .403 r
F
.36766 .72979 m .36115 .71724 L .35785 .72715 L F
.36766 .72979 m .36646 .71075 L .36115 .71724 L F
.36766 .72979 m .37024 .71202 L .36646 .71075 L F
.36766 .72979 m .37075 .72018 L .37024 .71202 L F
0 g
.36766 .72979 m
.36831 .73788 L
s
.36235 .73627 m
.36766 .72979 L
s
.37075 .72018 m
.3759 .71409 L
s
.60393 .65339 m
.60397 .65333 L
s
.60382 .65353 m
.60393 .65339 L
s
.60338 .65407 m
.60382 .65353 L
s
.4691 1.00112 m .46573 .99556 L .46137 .99203 L 0 .446 .375 r
F
0 g
.68648 .67644 m
.68651 .6802 L
s
.68385 .67539 m
.68498 .67059 L
s
.68228 .68206 m
.68385 .67539 L
s
.68115 .68688 m
.68228 .68206 L
s
.77279 1.05513 m .77106 1.05776 L .77791 1.05368 L 0 .878 .216 r
F
.77279 1.05513 m .76708 1.05944 L .77106 1.05776 L F
0 g
.76934 1.05862 m
.77106 1.05776 L
s
.52168 .9006 m .52076 .90112 L .52109 .8959 L 0 .114 .089 r
F
0 g
.61726 .69272 m
.6188 .69809 L
s
.45433 .95743 m .45045 .9626 L .45366 .96206 L 0 .614 .375 r
F
.46053 .9714 m .45366 .96206 L .45045 .9626 L 0 .548 .372 r
F
0 g
.45022 .9673 m
.45045 .9626 L
s
.44607 .95863 m
.45045 .9626 L
s
.25009 .57064 m .23997 .56865 L .2378 .57771 L 0 1 .484 r
F
0 g
.23039 .58558 m
.2378 .57771 L
s
.25009 .57064 m .24699 .5573 L .23997 .56865 L 0 1 .484 r
F
.25009 .57064 m .25519 .54943 L .24699 .5573 L F
.25009 .57064 m .25907 .5503 L .25519 .54943 L F
.25009 .57064 m .25688 .5594 L .25907 .5503 L F
0 g
.2481 .57966 m
.25009 .57064 L
s
.24192 .57848 m
.25009 .57064 L
s
.29702 .8719 m .28603 .86064 L .28227 .86523 L 0 1 .524 r
F
.29702 .8719 m .29171 .86094 L .28603 .86064 L F
.29702 .8719 m .29642 .86577 L .29171 .86094 L F
0 g
.29326 .87646 m
.29702 .8719 L
s
.30776 .87219 m .29642 .86577 L .29702 .8719 L 0 1 .522 r
F
0 g
.29702 .8719 m
.30069 .87652 L
s
.54805 .79116 m
.54806 .79073 L
s
.54806 .79073 m
.54806 .79038 L
s
.54646 .80021 m
.54806 .79038 L
s
.71931 .89609 m .7182 .89684 L .72057 .89743 L 0 .703 .24 r
F
0 g
.7159 .89801 m
.72057 .89743 L
s
.45449 .85138 m .44617 .85017 L .45085 .85318 L 0 .833 .34 r
F
.45447 .86481 m .45085 .85318 L .44617 .85017 L 0 .803 .342 r
F
0 g
.44507 .85087 m
.44617 .85017 L
s
.44283 .84344 m
.44617 .85017 L
s
.29424 .53539 m
.30247 .52738 L
s
.52081 .96994 m .52232 .9705 L .52393 .97138 L 0 .223 .181 r
F
0 g
.52232 .9705 m
.52299 .97087 L
s
.52232 .9705 m
.5228 .97069 L
s
.39706 .88993 m .38959 .89203 L .39418 .89245 L 0 1 .504 r
F
.39706 .88993 m .38554 .88866 L .38959 .89203 L F
0 g
.38717 .89467 m
.38959 .89203 L
s
.47111 .93428 m .46197 .93072 L .46081 .93213 L 0 .866 .477 r
F
0 g
.45665 .93065 m
.46081 .93213 L
s
.52603 .89893 m .5252 .89912 L .52626 .8924 L 0 .138 .097 r
F
0 g
.52401 .89924 m
.52626 .8924 L
s
.411 .90011 m .40105 .8932 L .39853 .89551 L 0 1 .505 r
F
0 g
.39418 .89245 m
.39853 .89551 L
s
.4801 .84639 m .46989 .82156 L .46917 .82626 L 0 .754 .313 r
F
.4801 .84639 m .47362 .8246 L .46989 .82156 L F
0 g
.46726 .81286 m
.46989 .82156 L
s
.46989 .82156 m
.47335 .82437 L
s
.80451 .66807 m .8197 .68091 L .81558 .66673 L 0 1 .447 r
F
0 g
.81941 .69198 m
.8197 .68091 L
s
.4154 .58865 m .40612 .59037 L .40859 .59298 L 0 1 .431 r
F
.4154 .58865 m .40951 .58247 L .40612 .59037 L F
.4154 .58865 m .4165 .57455 L .40951 .58247 L F
.4154 .58865 m .42332 .57023 L .4165 .57455 L F
.4154 .58865 m .4254 .5724 L .42332 .57023 L F
0 g
.42201 .58029 m
.4254 .5724 L
s
.41229 .59688 m
.4154 .58865 L
s
.4254 .5724 m
.43221 .56787 L
s
.37585 .70553 m .36646 .71075 L .37024 .71202 L 0 1 .396 r
F
.37585 .70553 m .36658 .70202 L .36646 .71075 L F
.37585 .70553 m .37054 .69165 L .36658 .70202 L F
.37585 .70553 m .37616 .68516 L .37054 .69165 L F
.37585 .70553 m .37969 .68689 L .37616 .68516 L F
0 g
.37024 .71202 m
.37585 .70553 L
s
.37585 .70553 m
.3759 .71409 L
s
.37969 .68689 m
.38555 .68066 L
s
.37956 .69562 m
.37969 .68689 L
s
.37024 .71202 m
.37075 .72018 L
s
.26737 .7526 m .25609 .75014 L .25768 .75398 L 0 1 .518 r
F
0 g
.25331 .75663 m
.25768 .75398 L
s
.39277 .64178 m .38325 .64478 L .38641 .64734 L 0 1 .397 r
F
.39277 .64178 m .38514 .63517 L .38325 .64478 L F
.39277 .64178 m .3908 .62492 L .38514 .63517 L F
.39277 .64178 m .39716 .61936 L .3908 .62492 L F
0 g
.39114 .6511 m
.39277 .64178 L
s
.38641 .64734 m
.39277 .64178 L
s
.3982 .54274 m .40595 .53452 L .40964 .52905 L 0 1 .256 r
F
0 g
.39431 .54797 m
.3982 .54274 L
s
.42533 .909 m .41963 .90345 L .41516 .90298 L 0 1 .504 r
F
.42533 .909 m .42399 .90603 L .41963 .90345 L F
.43621 .91021 m .42533 .909 L .42956 .91152 L 0 1 .498 r
F
.43621 .91021 m .42399 .90603 L .42533 .909 L F
0 g
.42312 .91108 m
.42533 .909 L
s
.29424 .53539 m
.29712 .52595 L
s
.22123 .67548 m .21029 .68056 L .21475 .68128 L 0 1 .525 r
F
0 g
.21475 .68128 m
.21592 .68818 L
s
.2378 .57771 m
.23997 .56865 L
s
.46768 .83802 m .46822 .83331 L .4653 .82522 L 0 .817 .325 r
F
.44503 .88722 m .44435 .88149 L .4404 .87609 L 0 .793 .358 r
F
.65989 .61458 m .66088 .60442 L .65758 .59677 L 0 .17 .223 r
F
0 g
.65758 .59677 m
.65762 .59709 L
s
.65762 .59709 m
.6589 .60695 L
s
.6589 .60695 m
.65989 .61458 L
s
.6574 .59623 m
.65758 .59677 L
s
.65814 .60707 m
.65989 .61458 L
s
.44603 .54328 m .4373 .54612 L .43898 .54782 L 0 1 .398 r
F
.44603 .54328 m .44216 .53932 L .4373 .54612 L F
.44603 .54328 m .45031 .53196 L .44216 .53932 L F
.44603 .54328 m .45735 .52744 L .45031 .53196 L F
0 g
.4415 .55043 m
.44603 .54328 L
s
.50661 .91283 m .50529 .90479 L .50644 .90897 L 0 .113 .077 r
F
.50898 .91051 m .50644 .90897 L .50529 .90479 L 0 .105 .078 r
F
0 g
.50339 .90271 m
.50529 .90479 L
s
.50529 .90479 m
.50532 .90418 L
s
.43621 .91021 m .42956 .91152 L .43386 .91192 L 0 1 .498 r
F
.43969 .91675 m .43386 .91192 L .42956 .91152 L 0 1 .501 r
F
0 g
.42762 .91336 m
.42956 .91152 L
s
.42533 .909 m
.42956 .91152 L
s
.57533 .47752 m .58452 .4818 L .59271 .48798 L 0 .242 .025 r
F
0 g
.58983 .48035 m
.59186 .48288 L
s
.63239 .52676 m
.63397 .53013 L
s
.63397 .53013 m
.63451 .53128 L
s
.63692 .53642 m
.63706 .53671 L
s
.63221 .52664 m
.63239 .52676 L
s
.217 .93204 m .20455 .92708 L .20312 .92896 L 0 .83 .318 r
F
.217 .93204 m .20912 .92742 L .20455 .92708 L F
.217 .93204 m .21447 .92955 L .20912 .92742 L F
.22824 .93232 m .21447 .92955 L .217 .93204 L 0 .75 .287 r
F
0 g
.21555 .9339 m
.217 .93204 L
s
.217 .93204 m
.22224 .9339 L
s
.76396 .62317 m
.76474 .6244 L
s
.76474 .6244 m
.7649 .62466 L
s
.7649 .62466 m
.76624 .62678 L
s
.76391 .62309 m
.76393 .62312 L
s
.76393 .62312 m
.76396 .62317 L
s
.33102 .91195 m .32466 .91342 L .32886 .9135 L 0 1 .424 r
F
0 g
.32886 .9135 m
.33359 .91507 L
s
.33102 .91195 m .32044 .91154 L .32466 .91342 L 0 1 .424 r
F
0 g
.32318 .91508 m
.32466 .91342 L
s
.74695 .61769 m .76391 .62309 L .76279 .62024 L 0 1 .41 r
F
.46667 .84982 m .45513 .83783 L .45828 .84535 L 0 .793 .327 r
F
0 g
.45133 .83924 m
.45513 .83783 L
s
.76391 .62318 m
.76391 .62309 L
s
.30371 .76048 m .29203 .75468 L .28989 .75754 L 0 1 .452 r
F
.30371 .76048 m .2978 .7538 L .29203 .75468 L F
.30336 .77084 m .2978 .7538 L .29182 .76059 L 0 1 .454 r
F
.2978 .7538 m .29773 .75357 L .29759 .75373 L F
.2978 .7538 m .29759 .75373 L .29203 .75468 L 0 1 .452 r
F
.2978 .7538 m .29759 .75373 L .29182 .76059 L 0 1 .454 r
F
.2978 .7538 m .29772 .75371 L .29759 .75373 L 0 1 .452 r
F
0 g
.28989 .75754 m
.2922 .76014 L
s
.2978 .7538 m .30321 .75386 L .29773 .75357 L 0 1 .454 r
F
.30371 .76048 m .30323 .75593 L .2978 .7538 L 0 1 .452 r
F
.30336 .77084 m .30323 .75593 L .2978 .7538 L 0 1 .454 r
F
.30323 .75593 m .30321 .75386 L .2978 .7538 L F
.2978 .7538 m .30317 .7553 L .29772 .75371 L 0 1 .452 r
F
.30323 .75593 m .30317 .7553 L .2978 .7538 L F
.30371 .76048 m .30573 .7582 L .30398 .75623 L F
.30336 .77084 m .30562 .76127 L .30398 .75623 L 0 1 .454 r
F
.30323 .75593 m .30398 .75623 L .30321 .75386 L F
.30371 .76048 m .30398 .75623 L .30323 .75593 L 0 1 .452 r
F
.30336 .77084 m .30398 .75623 L .30323 .75593 L 0 1 .454 r
F
.30323 .75593 m .30398 .75623 L .30317 .7553 L 0 1 .452 r
F
.29618 .67405 m .28566 .67028 L .28549 .67617 L 0 1 .522 r
F
0 g
.27967 .68014 m
.28549 .67617 L
s
.42518 .91996 m .4187 .91929 L .423 .91949 L 0 0 0 r
F
.42518 .91996 m .4143 .91925 L .4187 .91929 L F
0 g
.41696 .91894 m
.4187 .91929 L
s
.48336 .82829 m .48417 .82481 L .48196 .81397 L 0 .779 .308 r
F
0 g
.48196 .81397 m
.4828 .81809 L
s
.48196 .81397 m
.48205 .81411 L
s
.57774 .62672 m
.58348 .63473 L
s
.57496 .62962 m
.57774 .62672 L
s
.3982 .54274 m .38652 .55083 L .38988 .54973 L 0 1 .256 r
F
0 g
.39275 .54968 m
.39431 .54797 L
s
.3982 .54274 m .3902 .54536 L .38652 .55083 L 0 1 .256 r
F
0 g
.38697 .55601 m
.39275 .54968 L
s
.3982 .54274 m .39848 .53696 L .3902 .54536 L 0 1 .256 r
F
.3982 .54274 m .40682 .52996 L .39848 .53696 L F
.3982 .54274 m .40964 .52905 L .40682 .52996 L F
0 g
.40595 .53452 m
.40964 .52905 L
s
.39418 .54611 m
.3982 .54274 L
s
.40964 .52905 m
.41049 .52842 L
s
.46768 .83802 m .4593 .83227 L .46385 .83758 L 0 .817 .325 r
F
.46667 .84982 m .46385 .83758 L .4593 .83227 L 0 .793 .327 r
F
0 g
.45845 .8323 m
.4593 .83227 L
s
.45639 .82418 m
.4593 .83227 L
s
.45367 .92928 m .44212 .92306 L .44388 .92888 L 0 .666 .361 r
F
.45367 .92928 m .44388 .91897 L .44212 .92306 L F
0 g
.4384 .91926 m
.44212 .92306 L
s
.44212 .92306 m
.44384 .91906 L
s
.44215 .92055 m
.44376 .91908 L
s
.40776 .66852 m .39875 .67092 L .40194 .67072 L 0 1 .328 r
F
.40776 .66852 m .4 .6691 L .39875 .67092 L F
0 g
.40194 .67072 m
.40335 .6712 L
s
.40776 .66852 m .40489 .66647 L .4 .6691 L 0 1 .328 r
F
.40776 .66852 m .41072 .66426 L .40489 .66647 L F
.40776 .66852 m .41359 .66395 L .41072 .66426 L F
.40776 .66852 m .41232 .66577 L .41359 .66395 L F
0 g
.40194 .67072 m
.40776 .66852 L
s
.64924 .56338 m
.65037 .56839 L
s
.64868 .56095 m
.64924 .56338 L
s
.64857 .56046 m
.64868 .56095 L
s
.65084 .57045 m .66078 .59003 L .6522 .56758 L 0 .033 .163 r
F
0 g
.65037 .56839 m
.65084 .57045 L
s
.62372 1.37158 m
.62372 1.37194 L
s
.38735 .65911 m
.38735 .65911 L
s
.38601 .66054 m
.38735 .65911 L
s
.53687 1.09088 m .53706 1.08751 L .53885 1.08894 L 0 .193 0 r
F
.53687 1.09088 m .5352 1.08693 L .53706 1.08751 L F
0 g
.53625 1.0859 m
.53706 1.08751 L
s
.51935 .902 m .5184 .90264 L .51836 .89807 L 0 .106 .085 r
F
.50432 .91522 m .49914 .91102 L .49861 .90748 L 0 .124 .078 r
F
0 g
.49607 .90692 m
.49861 .90748 L
s
.49995 .90613 m
.50194 .90774 L
s
.502 .90408 m
.50203 .90497 L
s
.49588 .85078 m .48765 .81207 L .48733 .81308 L 0 .672 .296 r
F
.49588 .85078 m .49038 .82281 L .48765 .81207 L F
0 g
.48738 .81086 m
.48765 .81207 L
s
.46728 .98522 m .45769 .98154 L .46084 .98717 L 0 .473 .366 r
F
.46728 .98522 m .45745 .9768 L .45769 .98154 L F
0 g
.45319 .97789 m
.45769 .98154 L
s
.45508 .87814 m .44317 .86701 L .44355 .87283 L 0 .77 .344 r
F
0 g
.4404 .87609 m
.44295 .87958 L
s
.45508 .87814 m .44637 .86451 L .44317 .86701 L 0 .77 .344 r
F
0 g
.44188 .86504 m
.44317 .86701 L
s
.44317 .86701 m
.44521 .86542 L
s
.57533 .47752 m .57055 .4801 L .56934 .47679 L 0 .242 .025 r
F
.57533 .47752 m .57874 .48631 L .57055 .4801 L F
.57533 .47752 m .58845 .49125 L .57874 .48631 L F
.57533 .47752 m .59443 .49196 L .58845 .49125 L F
0 g
.59186 .48288 m
.59299 .4843 L
s
.57533 .47752 m .59271 .48798 L .59443 .49196 L 0 .242 .025 r
F
0 g
.59299 .4843 m
.59807 .49065 L
s
.58452 .4818 m
.59065 .48642 L
s
.37093 .7695 m .36213 .76846 L .36627 .76896 L 0 .506 .207 r
F
0 g
.36627 .76896 m
.36827 .76949 L
s
.44722 .90143 m .44041 .90443 L .44471 .90514 L 0 .754 .36 r
F
.45011 .91544 m .44471 .90514 L .44041 .90443 L 0 .712 .361 r
F
0 g
.43827 .90833 m
.44041 .90443 L
s
.43766 .90102 m
.44041 .90443 L
s
.5162 .7747 m .51815 .77437 L .52012 .78569 L 0 .454 .151 r
F
0 g
.51815 .77437 m
.51911 .76344 L
s
.42226 .90151 m .41516 .90298 L .41963 .90345 L 0 1 .499 r
F
.42226 .90151 m .411 .90011 L .41516 .90298 L F
0 g
.41296 .90507 m
.41516 .90298 L
s
.35071 .8745 m .3435 .87782 L .34778 .87807 L 0 1 .512 r
F
0 g
.34778 .87807 m
.3518 .8819 L
s
.35071 .8745 m .33997 .8737 L .3435 .87782 L 0 1 .512 r
F
0 g
.34115 .88145 m
.3435 .87782 L
s
.59807 .49065 m .59443 .49196 L .59271 .48798 L 0 .296 .004 r
F
0 g
.59271 .48798 m
.59312 .48819 L
s
.59065 .48642 m
.59271 .48798 L
s
.59807 .49065 m .60275 .50104 L .59443 .49196 L 0 .296 .004 r
F
.59807 .49065 m .61213 .50916 L .60275 .50104 L F
0 g
.61157 .49843 m
.6143 .503 L
s
.59807 .49065 m .61749 .51181 L .61213 .50916 L 0 .296 .004 r
F
.59807 .49065 m .61527 .50725 L .61749 .51181 L F
.59807 .49065 m .60695 .49818 L .61527 .50725 L F
0 g
.6143 .503 m
.61999 .51249 L
s
.60695 .49818 m
.61157 .49843 L
s
.59312 .48819 m
.59807 .49065 L
s
.46358 .91924 m .45783 .91744 L .46167 .91797 L 0 0 .007 r
F
.46358 .91924 m .45378 .91782 L .45783 .91744 L F
.46718 .91621 m .46167 .91797 L .45783 .91744 L 0 0 .005 r
F
0 g
.4563 .9162 m
.45783 .91744 L
s
.30776 .87219 m .29921 .86136 L .29642 .86577 L 0 1 .522 r
F
.30776 .87219 m .30354 .86163 L .29921 .86136 L F
.30776 .87219 m .3072 .86627 L .30354 .86163 L F
.31849 .87257 m .3072 .86627 L .30776 .87219 L 0 1 .519 r
F
0 g
.30496 .87658 m
.30776 .87219 L
s
.30776 .87219 m
.31138 .87668 L
s
.51638 1.07197 m .51669 1.07198 L .52049 1.07572 L 0 .058 .167 r
F
.37974 .56549 m .38697 .55601 L .38988 .54973 L 0 1 .316 r
F
0 g
.37654 .57091 m
.37975 .56549 L
s
.70855 .89699 m .71419 .89736 L .7182 .89684 L 0 .602 .209 r
F
.70855 .89699 m .70993 .8973 L .71419 .89736 L F
0 g
.71419 .89736 m
.7159 .89801 L
s
.51747 .90329 m .51717 .90351 L .5175 .89879 L 0 .107 .084 r
F
0 g
.51653 .9029 m
.5175 .8988 L
s
.5175 .8988 m
.5175 .89879 L
s
.45378 .91782 m .44797 .91935 L .44388 .91897 L 0 0 0 r
F
.45378 .91782 m .45222 .91886 L .44797 .91935 L F
.46358 .91924 m .45222 .91886 L .45378 .91782 L 0 0 .007 r
F
0 g
.45378 .91782 m
.45783 .91744 L
s
.45207 .9169 m
.45378 .91782 L
s
.77445 .62266 m
.77447 .62267 L
s
.77447 .62267 m
.77449 .62269 L
s
.77449 .62269 m
.77581 .62335 L
s
.77581 .62335 m
.77594 .62342 L
s
.77594 .62342 m
.77762 .62426 L
s
.77762 .62426 m
.77803 .62447 L
s
.32452 .77217 m .31551 .77877 L .31977 .77904 L 0 1 .438 r
F
0 g
.31977 .77904 m
.32202 .78615 L
s
.49588 .85078 m .48733 .81308 L .48968 .82502 L 0 .672 .296 r
F
0 g
.48648 .81053 m
.48733 .81308 L
s
.3484 .67989 m .33908 .67684 L .33862 .67944 L 0 1 .508 r
F
0 g
.33303 .68143 m
.33862 .67944 L
s
.38974 .67489 m
.39531 .67291 L
s
.52801 .89882 m .52724 .8988 L .52865 .89126 L 0 .151 .101 r
F
0 g
.52727 .89864 m
.52865 .89126 L
s
.52609 .89876 m
.52865 .89126 L
s
.5441 .97928 m
.54432 .97933 L
s
.38162 .77049 m .37302 .76972 L .37093 .7695 L 0 0 0 r
F
0 g
.37093 .7695 m
.37261 .76959 L
s
.38162 .77049 m .37772 .77029 L .37302 .76972 L 0 0 0 r
F
.38162 .77049 m .3819 .77081 L .37772 .77029 L F
.38162 .77049 m .38356 .7709 L .3819 .77081 L F
0 g
.38162 .77049 m
.38341 .77028 L
s
.37693 .76993 m
.38162 .77049 L
s
.43966 .91926 m .42945 .91992 L .42754 .91925 L 0 0 0 r
F
.69569 1.08664 m .70123 1.0797 L .70707 1.08098 L F
0 g
.69363 1.07986 m
.70123 1.0797 L
s
.2993 .91101 m .28662 .90521 L .28371 .90749 L 0 1 .479 r
F
.2993 .91101 m .29225 .90553 L .28662 .90521 L F
.2993 .91101 m .29769 .90802 L .29225 .90553 L F
0 g
.29638 .91328 m
.2993 .91101 L
s
.30987 .91123 m .29769 .90802 L .29931 .91101 L 0 1 .465 r
F
0 g
.29931 .91101 m
.30366 .91325 L
s
.60315 .63853 m .61466 .6317 L .6174 .63129 L 0 0 0 r
F
.60315 .63853 m .60856 .6348 L .61466 .6317 L F
0 g
.61466 .6317 m
.61634 .63035 L
s
.7163 1.07691 m .7275 1.07437 L .72374 1.07602 L 0 0 0 r
F
.70707 1.08098 m .7163 1.07691 L .71808 1.07867 L F
.37974 .56549 m .36756 .57619 L .37143 .57414 L 0 1 .316 r
F
0 g
.37513 .57301 m
.37654 .57091 L
s
.37974 .56549 m .37046 .56991 L .36756 .57619 L 0 1 .316 r
F
0 g
.36935 .5816 m
.37455 .57387 L
s
.37455 .57387 m
.37513 .57301 L
s
.37974 .56549 m .37819 .55949 L .37046 .56991 L 0 1 .316 r
F
.37974 .56549 m .38652 .55083 L .37819 .55949 L F
.37974 .56549 m .38988 .54973 L .38652 .55083 L F
0 g
.37143 .57414 m
.37974 .56549 L
s
.38988 .54973 m
.39418 .54611 L
s
.38697 .55601 m
.38988 .54973 L
s
.51131 .77449 m .50924 .79379 L .50959 .78262 L 0 .416 .139 r
F
.51131 .77449 m .51083 .80392 L .50924 .79379 L F
0 g
.50839 .7738 m
.50959 .78262 L
s
.51131 .77449 m .5133 .80619 L .51083 .80392 L 0 .416 .139 r
F
.51131 .77449 m .51502 .79795 L .5133 .80619 L F
.51131 .77449 m .51486 .78477 L .51502 .79795 L F
0 g
.51462 .7652 m
.51555 .77079 L
s
.51131 .77449 m .51327 .77475 L .51486 .78477 L 0 .416 .139 r
F
0 g
.51327 .77475 m
.51462 .7652 L
s
.5101 .7655 m
.51131 .77449 L
s
.50959 .78262 m
.51131 .77449 L
s
.52225 .61901 m .52808 .61764 L .53293 .61839 L 0 0 .014 r
F
0 g
.52808 .61764 m
.53196 .61447 L
s
.70309 .61664 m .71609 .61879 L .72004 .6183 L 0 .889 .305 r
F
.70309 .61664 m .70884 .61808 L .71609 .61879 L F
0 g
.71609 .61879 m
.71675 .62032 L
s
.71601 .61878 m
.71609 .61879 L
s
.25609 .75014 m .24633 .75188 L .25087 .75272 L 0 1 .526 r
F
0 g
.25087 .75272 m
.25331 .75663 L
s
.75565 .8934 m .76571 .89546 L .76712 .89262 L 0 1 .387 r
F
0 g
.76126 .89757 m
.76571 .89546 L
s
.76571 .89546 m
.76805 .89757 L
s
.47111 .93428 m .46672 .93571 L .46994 .93569 L 0 .866 .477 r
F
.47558 .93881 m .46994 .93569 L .46672 .93571 L 0 .825 .47 r
F
0 g
.46596 .93718 m
.46672 .93571 L
s
.46281 .93418 m
.46672 .93571 L
s
.49683 .95521 m .49452 .95368 L .49158 .95286 L 0 .512 .36 r
F
.35084 .7512 m .34164 .75727 L .34579 .75787 L 0 1 .417 r
F
0 g
.34579 .75787 m
.34748 .7652 L
s
.35084 .7512 m .3406 .74958 L .34164 .75727 L 0 1 .417 r
F
.35084 .7512 m .34334 .73991 L .3406 .74958 L F
.35084 .7512 m .3484 .73324 L .34334 .73991 L F
.35084 .7512 m .35239 .734 L .3484 .73324 L F
.35084 .7512 m .35344 .7417 L .35239 .734 L F
0 g
.35084 .7512 m
.35199 .75888 L
s
.34579 .75787 m
.35084 .7512 L
s
.45367 .92928 m .44388 .92888 L .44807 .93329 L 0 .666 .361 r
F
0 g
.44232 .93333 m
.44388 .92888 L
s
.49058 .91596 m .4864 .91202 L .48926 .91373 L 0 .09 .059 r
F
.49352 .91276 m .48926 .91373 L .4864 .91202 L 0 .067 .058 r
F
0 g
.48546 .90965 m
.4864 .91202 L
s
.48483 .9119 m
.4864 .91202 L
s
.45433 .95743 m .45203 .95179 L .44764 .94782 L 0 .614 .375 r
F
.5162 .7747 m .51502 .79795 L .51486 .78477 L 0 .454 .151 r
F
.5162 .7747 m .51699 .80941 L .51502 .79795 L F
.5162 .7747 m .51945 .81144 L .51699 .80941 L F
.5162 .7747 m .52079 .80123 L .51945 .81144 L F
0 g
.52077 .80639 m
.52113 .80307 L
s
.52071 .80182 m
.52077 .80639 L
s
.5162 .7747 m .52012 .78569 L .52079 .80123 L 0 .454 .151 r
F
0 g
.52012 .78569 m
.52105 .77322 L
s
.51486 .78477 m
.5162 .7747 L
s
.51555 .77079 m
.5162 .7747 L
s
.51815 .77437 m
.52012 .78569 L
s
.4801 .84639 m .46917 .82626 L .47194 .83559 L 0 .754 .313 r
F
0 g
.4653 .82522 m
.46917 .82626 L
s
.54247 .79443 m
.54304 .79278 L
s
.49058 .91596 m .48298 .91539 L .48167 .91317 L 0 .09 .059 r
F
0 g
.47814 .91354 m
.48167 .91317 L
s
.411 .90011 m .40564 .89377 L .40105 .8932 L 0 1 .505 r
F
.411 .90011 m .4099 .89674 L .40564 .89377 L F
.42226 .90151 m .4099 .89674 L .411 .90011 L 0 1 .499 r
F
0 g
.40847 .90241 m
.411 .90011 L
s
.411 .90011 m
.41516 .90298 L
s
.45508 .87814 m .44355 .87283 L .44728 .87867 L 0 .77 .344 r
F
0 g
.44355 .87283 m
.44452 .87434 L
s
.4404 .87609 m
.44355 .87283 L
s
.51327 .77475 m
.51486 .78477 L
s
.49111 .95134 m .48889 .94976 L .48568 .94886 L 0 .616 .406 r
F
.80451 .66807 m .80918 .65645 L .80478 .65695 L 0 1 .447 r
F
.80451 .66807 m .81558 .66673 L .80918 .65645 L F
0 g
.7982 .65769 m
.80451 .66807 L
s
.52393 .97186 m .52516 .97185 L .52605 .97228 L 0 0 0 r
F
.52393 .97186 m .52393 .97138 L .52516 .97185 L F
0 g
.52504 .9716 m
.52516 .97185 L
s
.52394 .97138 m
.52516 .97185 L
s
.38607 .65495 m .38761 .6517 L .38641 .64735 L 0 1 .391 r
F
0 g
.38761 .6517 m
.39113 .6511 L
s
.43969 .91675 m .4382 .91417 L .43386 .91192 L 0 1 .501 r
F
.45011 .91544 m .44388 .91897 L .44797 .91935 L 0 .712 .361 r
F
.45009 .91789 m .43969 .91675 L .44388 .91897 L 0 1 .492 r
F
0 g
.44107 .91579 m
.44216 .91702 L
s
.45009 .91789 m .4382 .91417 L .43969 .91675 L 0 1 .492 r
F
0 g
.438 .91835 m
.43969 .91675 L
s
.74892 .78915 m .75951 .77669 L .76196 .785 L 0 .279 .073 r
F
0 g
.75951 .77669 m
.76337 .7744 L
s
.46718 .91621 m .46568 .91744 L .46167 .91797 L 0 0 .005 r
F
.47629 .91847 m .46718 .91621 L .47097 .91595 L 0 .054 .037 r
F
.47629 .91847 m .46568 .91744 L .46718 .91621 L F
0 g
.46565 .91497 m
.46718 .91621 L
s
.45798 .92898 m .45621 .92683 L .45199 .92512 L 0 .991 .495 r
F
.50065 .84094 m .49547 .80984 L .49806 .82806 L 0 .654 .287 r
F
.49864 .84432 m .49806 .82806 L .49547 .80984 L 0 .66 .291 r
F
0 g
.49493 .80137 m
.49547 .80984 L
s
.49265 .79838 m
.49547 .80984 L
s
.70855 .89699 m .70751 .89715 L .70993 .8973 L 0 .602 .209 r
F
0 g
.70751 .89715 m
.70993 .8973 L
s
.70619 .89742 m
.70993 .8973 L
s
.22123 .67548 m .21018 .67345 L .21029 .68056 L 0 1 .525 r
F
0 g
.20471 .68661 m
.21029 .68056 L
s
.46271 .52104 m .4711 .51384 L .47679 .50779 L 0 1 .311 r
F
0 g
.4711 .51384 m
.47797 .50909 L
s
.38554 .88866 m .37626 .88056 L .37358 .88342 L 0 1 .507 r
F
.38554 .88866 m .38074 .88111 L .37626 .88056 L F
.38554 .88866 m .38472 .88458 L .38074 .88111 L F
0 g
.38286 .89151 m
.38554 .88866 L
s
.39706 .88993 m .38472 .88458 L .38554 .88866 L 0 1 .504 r
F
0 g
.38554 .88866 m
.38959 .89203 L
s
.57284 .87073 m .57953 .85118 L .58215 .75533 L 0 .924 .229 r
F
0 g
.58215 .75533 m
.58344 .73936 L
s
.58215 .75533 m
.58216 .73596 L
s
.50272 .95896 m .50034 .95747 L .4977 .9567 L 0 .448 .299 r
F
0 g
.68374 .79422 m
.68698 .80026 L
s
.78666 .64776 m
.79381 .65819 L
s
.51477 .96627 m .51706 .96788 L .51679 .96759 L 0 .318 .212 r
F
.52081 .96994 m .51679 .96759 L .51706 .96788 L 0 .223 .181 r
F
0 g
.51509 .96708 m
.51706 .96788 L
s
.39966 .61054 m .40582 .60162 L .40859 .59298 L 0 1 .422 r
F
0 g
.40582 .60162 m
.41229 .59688 L
s
.49665 .90948 m .49537 .9108 L .49256 .91038 L 0 .045 .056 r
F
.55193 .47141 m .56136 .47307 L .56934 .47679 L 0 .156 .026 r
F
0 g
.54909 .87578 m
.54994 .87305 L
s
.5498 .87587 m
.55011 .8742 L
s
.6136 .50543 m
.61364 .50546 L
s
.60695 .49818 m
.6136 .50543 L
s
.73015 1.0771 m .7275 1.07437 L .73445 1.07246 L 0 0 0 r
F
.73015 1.0771 m .72374 1.07602 L .7275 1.07437 L F
0 g
.72551 1.07331 m
.7275 1.07437 L
s
.38607 .65495 m .37923 .65331 L .38248 .65564 L 0 1 .391 r
F
.38607 .65495 m .37801 .64895 L .37923 .65331 L F
.38607 .65495 m .37965 .64547 L .37801 .64895 L F
.38607 .65495 m .38325 .64479 L .37965 .64547 L F
.38607 .65495 m .38641 .64735 L .38325 .64479 L F
0 g
.38248 .65564 m
.38607 .65495 L
s
.38607 .65495 m
.38735 .65911 L
s
.38641 .64735 m
.38761 .6517 L
s
.33705 .76382 m
.34164 .75727 L
s
.46708 .92959 m .45798 .92898 L .46197 .93072 L 0 .896 .48 r
F
.46708 .92959 m .45621 .92683 L .45798 .92898 L F
0 g
.45665 .93065 m
.45798 .92898 L
s
.44722 .90143 m .44626 .89577 L .44218 .89072 L 0 .754 .36 r
F
0 g
.66358 .72144 m
.66365 .72086 L
s
.66365 .72086 m
.66367 .72074 L
s
.66367 .72074 m
.66438 .71555 L
s
.31849 .87257 m .31003 .86205 L .3072 .86627 L 0 1 .519 r
F
.31849 .87257 m .31436 .86236 L .31003 .86205 L F
.31849 .87257 m .31798 .86687 L .31436 .86236 L F
.32923 .87307 m .31798 .86687 L .31849 .87257 L 0 1 .517 r
F
0 g
.31567 .87677 m
.31849 .87257 L
s
.31849 .87257 m
.32209 .87694 L
s
.25609 .75014 m .2448 .74773 L .24633 .75188 L 0 1 .526 r
F
0 g
.24192 .75485 m
.24633 .75188 L
s
.6826 .89275 m
.68262 .89269 L
s
.45447 .86481 m .44637 .86451 L .45103 .86698 L 0 .803 .342 r
F
.45508 .87814 m .45103 .86698 L .44637 .86451 L 0 .77 .344 r
F
0 g
.44521 .86542 m
.44637 .86451 L
s
.44374 .85986 m
.44637 .86451 L
s
.52393 .97186 m .52605 .97228 L .52606 .97249 L 0 0 0 r
F
0 g
.52605 .97228 m
.52622 .97232 L
s
.46615 .86162 m .45467 .84597 L .45449 .85138 L 0 .767 .329 r
F
.46615 .86162 m .45828 .84535 L .45467 .84597 L F
0 g
.45133 .83924 m
.45467 .84597 L
s
.45467 .84597 m
.4573 .84552 L
s
.46149 .77376 m .45484 .77674 L .45838 .7748 L 0 .151 .043 r
F
.46149 .77376 m .4527 .77865 L .45484 .77674 L F
.46149 .77376 m .45341 .77926 L .4527 .77865 L F
.46149 .77376 m .45653 .77821 L .45341 .77926 L F
.46149 .77376 m .45998 .77621 L .45653 .77821 L F
0 g
.4585 .77457 m
.45861 .77432 L
s
.45861 .77432 m
.45969 .77214 L
s
.45838 .7748 m
.4585 .77457 L
s
.46149 .77376 m .4621 .77431 L .45998 .77621 L 0 .151 .043 r
F
0 g
.46149 .77376 m
.46369 .77117 L
s
.45838 .7748 m
.46149 .77376 L
s
.4621 .77431 m
.46514 .77246 L
s
.32452 .77217 m .31395 .77143 L .31551 .77877 L 0 1 .438 r
F
0 g
.31134 .78555 m
.31551 .77877 L
s
.53687 1.09088 m .53885 1.08894 L .53957 1.09064 L 0 .193 0 r
F
0 g
.53885 1.08894 m
.54082 1.08934 L
s
.68483 .81441 m
.68698 .80026 L
s
.43855 .65371 m .43024 .6564 L .43285 .65608 L 0 1 .242 r
F
.43855 .65371 m .43234 .65452 L .43024 .6564 L F
0 g
.43133 .65798 m
.43285 .65608 L
s
.43855 .65371 m .43775 .65169 L .43234 .65452 L 0 1 .242 r
F
.43855 .65371 m .44346 .64932 L .43775 .65169 L F
.43855 .65371 m .44566 .649 L .44346 .64932 L F
.43855 .65371 m .44355 .65088 L .44566 .649 L F
0 g
.44355 .65088 m
.44894 .64844 L
s
.43676 .65556 m
.43855 .65371 L
s
.43285 .65608 m
.43855 .65371 L
s
.59698 .64105 m
.59699 .64105 L
s
.59573 .64228 m
.59698 .64105 L
s
.59637 .64195 m
.59699 .64105 L
s
.59699 .64105 m .60856 .6348 L .60315 .63853 L 0 0 .017 r
F
0 g
.59699 .64105 m
.59699 .64105 L
s
.60856 .6348 m
.61466 .6317 L
s
.60856 .6348 m
.61056 .63188 L
s
.46728 .98522 m .46084 .98717 L .46505 .99079 L 0 .473 .366 r
F
0 g
.46084 .98717 m
.46137 .99203 L
s
.45447 .86481 m .4544 .85945 L .45085 .85318 L 0 .803 .342 r
F
.49463 .85476 m .4864 .81634 L .48547 .81968 L 0 .668 .297 r
F
.49463 .85476 m .48968 .82502 L .4864 .81634 L F
0 g
.48519 .80883 m
.4864 .81634 L
s
.48798 .81637 m
.488 .8165 L
s
.48733 .81308 m
.48798 .81637 L
s
.48765 .81207 m
.48958 .81967 L
s
.48869 .80895 m
.48998 .8195 L
s
.37093 .7695 m .36069 .76809 L .36213 .76846 L 0 .506 .207 r
F
0 g
.35785 .76843 m
.36213 .76846 L
s
.27331 .93393 m .26693 .93433 L .27141 .93442 L 0 .598 .225 r
F
0 g
.27141 .93442 m
.27699 .93497 L
s
.27331 .93393 m .26203 .93344 L .26693 .93433 L 0 .598 .225 r
F
0 g
.26591 .935 m
.26693 .93433 L
s
.48156 .83721 m .47362 .8246 L .47786 .83335 L 0 .768 .311 r
F
.4801 .84639 m .47786 .83335 L .47362 .8246 L 0 .754 .313 r
F
0 g
.47112 .81454 m
.47362 .8246 L
s
.47335 .82437 m
.47362 .8246 L
s
.48563 .94733 m .48351 .94568 L .48007 .94467 L 0 .704 .437 r
F
.79155 .61896 m .79559 .62126 L .79135 .6216 L 0 0 0 r
F
0 g
.79135 .6216 m
.79139 .62109 L
s
.79155 .61896 m .80228 .6189 L .79559 .62126 L 0 0 0 r
F
0 g
.79139 .62109 m
.79155 .61896 L
s
.78501 .62205 m
.78505 .62203 L
s
.78505 .62203 m
.78749 .62088 L
s
.78749 .62088 m
.79155 .61896 L
s
.32452 .77217 m .31612 .76191 L .31395 .77143 L 0 1 .438 r
F
0 g
.31977 .77904 m
.32452 .77217 L
s
.32452 .77217 m
.32615 .77951 L
s
.23226 .67757 m .22543 .66699 L .22123 .67548 L 0 1 .525 r
F
.23226 .67757 m .23183 .6614 L .22543 .66699 L F
.23226 .67757 m .23614 .66246 L .23183 .6614 L F
.23226 .67757 m .23632 .6694 L .23614 .66246 L F
0 g
.22589 .68312 m
.23226 .67757 L
s
.23226 .67757 m
.23256 .68425 L
s
.69569 1.08664 m .69018 1.08425 L .68931 1.08135 L 0 0 0 r
F
0 g
.68142 1.08056 m
.68931 1.08135 L
s
.35344 .7417 m
.35837 .7353 L
s
.45373 .92355 m .44797 .91935 L .44388 .91897 L 0 1 .494 r
F
.45367 .92928 m .44797 .91935 L .44388 .91897 L 0 .666 .361 r
F
.45373 .92355 m .45219 .92131 L .44797 .91935 L 0 1 .494 r
F
.45367 .92928 m .45217 .92376 L .44797 .91935 L 0 .666 .361 r
F
.45006 .92035 m .44388 .91897 L .44797 .91935 L 0 0 0 r
F
.45006 .92035 m .43966 .91926 L .44388 .91897 L F
.45009 .91789 m .44388 .91897 L .44797 .91935 L 0 1 .492 r
F
0 g
.43969 .91675 m
.44388 .91897 L
s
.69129 .67239 m
.69184 .67052 L
s
.69415 .66277 m
.69557 .65797 L
s
.69085 .67385 m
.69129 .67239 L
s
.69557 .65797 m .70772 .65152 L .70111 .66689 L 0 .216 .109 r
F
0 g
.69557 .65797 m
.69595 .66411 L
s
.51474 .90118 m
.51518 .90442 L
s
.82195 .79387 m .83419 .79479 L .83363 .79565 L 0 0 0 r
F
0 g
.83109 .79325 m
.83419 .79479 L
s
.36936 .5816 m
.37135 .57444 L
s
.37135 .57444 m
.37143 .57414 L
s
.36933 .58169 m
.36936 .5816 L
s
.47629 .91847 m .47097 .91595 L .47452 .91684 L 0 .054 .037 r
F
.47955 .9152 m .47452 .91684 L .47097 .91595 L 0 .025 .035 r
F
0 g
.46957 .91429 m
.47097 .91595 L
s
.46718 .91621 m
.47097 .91595 L
s
.45786 .94295 m .44672 .93754 L .44877 .94326 L 0 .614 .36 r
F
.45786 .94295 m .44807 .93329 L .44672 .93754 L F
0 g
.44232 .93333 m
.44672 .93754 L
s
.4563 .89134 m .44435 .88149 L .44503 .88722 L 0 .735 .345 r
F
.4563 .89134 m .44728 .87867 L .44435 .88149 L F
0 g
.44295 .87958 m
.44435 .88149 L
s
.44218 .89072 m
.44474 .89389 L
s
.48696 1.02866 m .47962 1.02529 L .48377 1.03072 L 0 .291 .321 r
F
.48696 1.02866 m .47771 1.02057 L .47962 1.02529 L F
0 g
.47532 1.02186 m
.47962 1.02529 L
s
.35063 .58825 m
.35267 .58203 L
s
.35062 .58828 m
.35063 .58825 L
s
.36145 .8755 m .35421 .8785 L .35849 .87882 L 0 1 .509 r
F
0 g
.35849 .87882 m
.36245 .88253 L
s
.36145 .8755 m .35071 .8745 L .35421 .8785 L 0 1 .509 r
F
0 g
.3518 .8819 m
.35421 .8785 L
s
.4143 .91925 m .40372 .91892 L .40169 .91878 L 0 0 0 r
F
.4143 .91925 m .40819 .91926 L .40372 .91892 L F
.4143 .91925 m .41273 .9194 L .40819 .91926 L F
.42518 .91996 m .41273 .9194 L .4143 .91925 L F
0 g
.4143 .91925 m
.4187 .91929 L
s
.41226 .91911 m
.4143 .91925 L
s
.423 .91949 m
.42754 .91925 L
s
.43621 .91021 m .42633 .90432 L .42399 .90603 L 0 1 .498 r
F
0 g
.41963 .90345 m
.42399 .90603 L
s
.64782 1.07793 m
.64857 1.0783 L
s
.63055 .62829 m .64272 .62623 L .6458 .62544 L 0 .761 .222 r
F
.63055 .62829 m .63619 .62745 L .64272 .62623 L F
0 g
.64272 .62623 m
.64421 .62719 L
s
.39966 .61054 m .3901 .61181 L .39293 .61491 L 0 1 .422 r
F
.39966 .61054 m .39287 .60316 L .3901 .61181 L F
.39966 .61054 m .39938 .59474 L .39287 .60316 L F
.39966 .61054 m .40612 .59037 L .39938 .59474 L F
.39966 .61054 m .40859 .59298 L .40612 .59037 L F
0 g
.40582 .60162 m
.40859 .59298 L
s
.39716 .61936 m
.39966 .61054 L
s
.40859 .59298 m
.4154 .58865 L
s
.20143 .89781 m .19436 .90167 L .19892 .9018 L 0 1 .527 r
F
0 g
.19892 .9018 m
.20424 .90594 L
s
.20143 .89781 m .18996 .89727 L .19436 .90167 L 0 1 .527 r
F
0 g
.19292 .90584 m
.19436 .90167 L
s
.28566 .67028 m .2748 .67296 L .27908 .67423 L 0 1 .52 r
F
0 g
.27908 .67423 m
.27967 .67388 L
s
.27908 .67423 m
.27967 .68014 L
s
.46053 .9714 m .45745 .9768 L .4603 .9761 L 0 .548 .372 r
F
.46728 .98522 m .4603 .9761 L .45745 .9768 L 0 .473 .366 r
F
0 g
.45745 .9768 m
.45769 .98154 L
s
.45314 .97302 m
.45745 .9768 L
s
.52808 .89863 m
.53028 .89235 L
s
.52802 .8988 m
.52808 .89863 L
s
.5292 .8987 m
.52996 .89503 L
s
.5292 .89873 m
.5292 .8987 L
s
.28989 .75754 m .28087 .75173 L .27863 .75508 L 0 1 .487 r
F
.28989 .75754 m .28588 .75021 L .28087 .75173 L F
.28989 .75754 m .29031 .75153 L .28588 .75021 L F
.28989 .75754 m .29203 .75468 L .29031 .75153 L F
0 g
.28489 .75905 m
.28989 .75754 L
s
.49434 1.04425 m .49008 1.03884 L .48603 1.03536 L 0 .257 .281 r
F
.50872 .96263 m .50631 .96117 L .50399 .9604 L 0 .393 .233 r
F
.37693 .67592 m .38149 .66533 L .38248 .65565 L 0 1 .392 r
F
0 g
.38149 .66533 m
.38601 .66054 L
s
.22824 .93232 m .21599 .92794 L .21447 .92955 L 0 .75 .287 r
F
.22824 .93232 m .22057 .9283 L .21599 .92794 L F
.22824 .93232 m .22582 .93018 L .22057 .9283 L F
.23949 .93264 m .22582 .93018 L .22824 .93232 L 0 .699 .258 r
F
0 g
.2267 .93391 m
.22824 .93232 L
s
.22824 .93232 m
.23339 .93394 L
s
.74417 .89421 m .75431 .89579 L .75565 .8934 L 0 .997 .336 r
F
0 g
.74992 .89757 m
.75431 .89579 L
s
.75431 .89579 m
.75672 .89757 L
s
.37559 .67742 m .3673 .68121 L .37084 .68273 L 0 1 .392 r
F
.37693 .67592 m .37426 .67739 L .37563 .67737 L F
.37693 .67592 m .36828 .67151 L .36767 .67749 L F
.37426 .67739 m .36767 .67749 L .36737 .67805 L 0 1 .315 r
F
.37559 .67742 m .36737 .67805 L .37094 .67845 L F
.37426 .67739 m .36737 .67805 L .37559 .67742 L F
.37426 .67739 m .36767 .67749 L .3673 .68121 L 0 1 .392 r
F
.37693 .67592 m .36767 .67749 L .37426 .67739 L F
.37426 .67739 m .36768 .67748 L .36767 .67749 L 0 1 .315 r
F
.3769 .67713 m .36816 .67659 L .36768 .67748 L F
.3769 .67713 m .36768 .67748 L .37426 .67739 L F
.37563 .67737 m .37426 .67739 L .37559 .67742 L 0 1 .392 r
F
.37426 .67739 m .3673 .68121 L .37559 .67742 L F
.3769 .67713 m .37426 .67739 L .37559 .67742 L 0 1 .315 r
F
0 g
.37559 .67742 m
.37559 .67742 L
s
.3768 .67742 m
.3768 .67742 L
s
.3768 .67743 m
.3768 .67742 L
s
.3763 .6789 m
.3768 .67743 L
s
.37735 .91722 m .36691 .91515 L .36488 .91578 L 0 .683 .254 r
F
.37735 .91722 m .37131 .91547 L .36691 .91515 L F
.37735 .91722 m .37579 .91636 L .37131 .91547 L F
.38815 .91771 m .37579 .91636 L .37735 .91722 L 0 .622 .235 r
F
0 g
.37735 .91722 m
.38172 .91794 L
s
.37531 .91785 m
.37735 .91722 L
s
.52225 .61901 m .51815 .62292 L .51799 .62127 L 0 0 .014 r
F
.52225 .61901 m .52302 .62368 L .51815 .62292 L F
.52225 .61901 m .52934 .62304 L .52302 .62368 L F
.52225 .61901 m .53359 .62078 L .52934 .62304 L F
.52225 .61901 m .53293 .61839 L .53359 .62078 L F
0 g
.51776 .61854 m
.52225 .61901 L
s
.53293 .61839 m
.53675 .61594 L
s
.52808 .61764 m
.53293 .61839 L
s
.81551 1.02718 m .81518 1.03483 L .82169 1.02889 L 0 1 .386 r
F
.81551 1.02718 m .81101 1.0364 L .81518 1.03483 L F
0 g
.81393 1.03761 m
.81518 1.03483 L
s
.55193 .47141 m .54607 .47479 L .54537 .47214 L 0 .156 .026 r
F
.55193 .47141 m .55405 .47852 L .54607 .47479 L F
0 g
.54537 .47214 m
.54674 .47199 L
s
.55193 .47141 m .564 .48085 L .55405 .47852 L 0 .156 .026 r
F
.55193 .47141 m .57055 .4801 L .564 .48085 L F
.55193 .47141 m .56934 .47679 L .57055 .4801 L F
0 g
.57017 .47689 m
.57533 .47752 L
s
.56934 .47679 m
.57017 .47689 L
s
.54674 .47199 m
.55193 .47141 L
s
.56136 .47307 m
.56934 .47679 L
s
.3484 .67989 m .3435 .67459 L .33908 .67684 L 0 1 .508 r
F
.3484 .67989 m .3495 .67383 L .3435 .67459 L F
.3484 .67989 m .35307 .67507 L .3495 .67383 L F
.3484 .67989 m .35259 .67767 L .35307 .67507 L F
0 g
.3481 .68222 m
.3484 .67989 L
s
.34242 .68065 m
.3484 .67989 L
s
.2448 .74773 m .23497 .74983 L .23952 .75064 L 0 1 .532 r
F
0 g
.23952 .75064 m
.24192 .75485 L
s
.50514 1.05784 m .49946 1.05366 L .50428 1.05886 L 0 .151 .194 r
F
.50514 1.05784 m .49636 1.04933 L .49946 1.05366 L F
0 g
.49535 1.05019 m
.49946 1.05366 L
s
.46615 .86162 m .45449 .85138 L .45786 .85835 L 0 .767 .329 r
F
0 g
.45085 .85318 m
.45449 .85138 L
s
.32923 .87307 m .32084 .86285 L .31798 .86687 L 0 1 .517 r
F
.32923 .87307 m .32517 .8632 L .32084 .86285 L F
.32923 .87307 m .32876 .86759 L .32517 .8632 L F
.33997 .8737 m .32876 .86759 L .32923 .87307 L 0 1 .515 r
F
0 g
.32637 .87707 m
.32923 .87307 L
s
.32923 .87307 m
.33279 .87731 L
s
.78685 .78495 m .79466 .79008 L .78999 .78885 L 0 .063 0 r
F
.78685 .78495 m .79856 .78865 L .79466 .79008 L F
0 g
.52395 .81655 m
.5242 .81471 L
s
.37616 .68516 m
.3768 .67745 L
s
.3768 .67745 m
.3768 .67742 L
s
.3768 .67742 m
.3768 .6774 L
s
.3768 .6774 m
.37681 .67735 L
s
.37681 .67735 m
.37682 .67715 L
s
.46271 .52104 m .47679 .50779 L .476 .50692 L 0 1 .311 r
F
0 g
.47679 .50779 m
.48378 .50323 L
s
.4711 .51384 m
.47679 .50779 L
s
.62344 .63001 m .62425 .62954 L .62151 .63037 L 0 0 0 r
F
.62344 .63001 m .63055 .62829 L .62425 .62954 L F
.62344 .63001 m .63619 .62745 L .63055 .62829 L F
0 g
.63619 .62745 m
.64272 .62623 L
s
.63619 .62745 m
.6381 .6271 L
s
.29618 .67405 m .29018 .66373 L .28566 .67028 L 0 1 .522 r
F
.29618 .67405 m .29663 .66029 L .29018 .66373 L F
.29618 .67405 m .30069 .66226 L .29663 .66029 L F
.29618 .67405 m .30049 .66816 L .30069 .66226 L F
0 g
.28976 .67747 m
.29618 .67405 L
s
.29615 .67943 m
.29618 .67405 L
s
.41799 .66349 m
.4195 .66159 L
s
.41232 .66577 m
.41799 .66349 L
s
.65214 .62506 m .65353 .62309 L .65044 .62409 L 0 .992 .294 r
F
.65214 .62506 m .66009 .62258 L .65353 .62309 L F
.3416 .91247 m .33517 .91365 L .33938 .91377 L 0 .999 .394 r
F
0 g
.33938 .91377 m
.34401 .91517 L
s
.3416 .91247 m .33102 .91195 L .33517 .91365 L 0 .999 .394 r
F
0 g
.33359 .91507 m
.33517 .91365 L
s
.47898 .85577 m .46822 .83331 L .46768 .83802 L 0 .737 .315 r
F
.47898 .85577 m .47194 .83559 L .46822 .83331 L F
0 g
.4653 .82522 m
.46822 .83331 L
s
.46822 .83331 m
.47143 .83528 L
s
.46708 .92959 m .45776 .92552 L .45621 .92683 L 0 .896 .48 r
F
0 g
.45261 .92537 m
.45621 .92683 L
s
.49463 .85476 m .48547 .81968 L .48759 .83239 L 0 .668 .297 r
F
0 g
.48998 .8195 m
.49023 .82157 L
s
.48958 .81967 m
.49038 .8228 L
s
.48205 .81411 m
.48547 .81968 L
s
.4563 .89134 m .44503 .88722 L .44889 .89265 L 0 .735 .345 r
F
0 g
.44503 .88722 m
.44603 .88863 L
s
.44218 .89072 m
.44503 .88722 L
s
.46667 .84982 m .46701 .8451 L .46385 .83758 L 0 .793 .327 r
F
.46667 .84982 m .45828 .84535 L .46293 .84993 L F
.46615 .86162 m .46293 .84993 L .45828 .84535 L 0 .767 .329 r
F
0 g
.4573 .84552 m
.45828 .84535 L
s
.45513 .83783 m
.45828 .84535 L
s
.45786 .94295 m .44877 .94326 L .45296 .9474 L 0 .614 .36 r
F
0 g
.44764 .94782 m
.44877 .94326 L
s
.43966 .91926 m .43375 .92029 L .42945 .91992 L 0 0 0 r
F
.43966 .91926 m .43813 .92001 L .43375 .92029 L F
.45006 .92035 m .43813 .92001 L .43966 .91926 L F
0 g
.43966 .91926 m
.44388 .91897 L
s
.43785 .91863 m
.43966 .91926 L
s
.50211 .91767 m .49665 .90948 L .49914 .91102 L 0 .137 .078 r
F
.50211 .91767 m .49537 .9108 L .49665 .90948 L F
0 g
.49607 .90692 m
.49665 .90948 L
s
.49665 .90948 m
.49851 .91063 L
s
.73686 .61868 m .75245 .6209 L .74695 .61769 L 0 .922 .361 r
F
0 g
.75245 .6209 m
.75916 .62303 L
s
.75245 .6209 m
.7534 .62332 L
s
.45009 .91789 m .44031 .91271 L .4382 .91417 L 0 1 .492 r
F
0 g
.43386 .91192 m
.4382 .91417 L
s
.3617 .67956 m
.36737 .67805 L
s
.72765 .64386 m .74248 .63079 L .73767 .64071 L 0 .105 .069 r
F
0 g
.74248 .63079 m
.74291 .62336 L
s
.74248 .63079 m
.74753 .62521 L
s
.73258 .64248 m
.73264 .64229 L
s
.73257 .64231 m
.73258 .64248 L
s
.30987 .91123 m .29969 .90599 L .29769 .90802 L 0 1 .465 r
F
.30987 .91123 m .30398 .90627 L .29969 .90599 L F
.30987 .91123 m .30835 .90852 L .30398 .90627 L F
.32044 .91154 m .30835 .90852 L .30987 .91123 L 0 1 .447 r
F
0 g
.30786 .91326 m
.30987 .91123 L
s
.30987 .91123 m
.31416 .91329 L
s
.48156 .83721 m .48224 .83361 L .47974 .82354 L 0 .768 .311 r
F
0 g
.47976 .82363 m
.47977 .82368 L
s
.47974 .82354 m
.47976 .82363 L
s
.47974 .82354 m
.48109 .82531 L
s
.4273 .56275 m .4347 .55494 L .43898 .54782 L 0 1 .439 r
F
0 g
.4347 .55494 m
.4415 .55043 L
s
.77279 1.05513 m .76781 1.05832 L .76708 1.05944 L 0 .878 .216 r
F
0 g
.75957 1.06239 m
.76708 1.05944 L
s
.45011 .91544 m .44887 .90986 L .44471 .90514 L 0 .712 .361 r
F
.48043 .94315 m .47845 .94143 L .47481 .94028 L 0 .773 .457 r
F
.31395 .77143 m .30486 .77818 L .30912 .7784 L 0 1 .446 r
F
0 g
.30912 .7784 m
.31134 .78555 L
s
.2448 .74773 m .2335 .74537 L .23497 .74983 L 0 1 .532 r
F
0 g
.23053 .7531 m
.23497 .74983 L
s
.37693 .67592 m .38248 .65565 L .37922 .65332 L 0 1 .392 r
F
0 g
.38149 .66533 m
.38248 .65565 L
s
.40859 .8916 m .40105 .8932 L .40564 .89377 L 0 1 .499 r
F
.40859 .8916 m .39706 .88993 L .40105 .8932 L F
0 g
.39853 .89551 m
.40105 .8932 L
s
.43371 .77393 m .42497 .77382 L .42909 .77324 L 0 0 0 r
F
0 g
.42909 .77324 m
.4309 .77189 L
s
.49864 .84432 m .49282 .81601 L .4958 .83279 L 0 .66 .291 r
F
.49678 .84845 m .4958 .83279 L .49282 .81601 L 0 .665 .294 r
F
0 g
.4922 .80923 m
.49282 .81601 L
s
.48977 .80581 m
.49282 .81601 L
s
.39941 .91849 m .39256 .91829 L .39702 .91851 L 0 .534 .207 r
F
0 g
.39702 .91851 m
.40169 .91878 L
s
.39941 .91849 m .38815 .91771 L .39256 .91829 L 0 .534 .207 r
F
0 g
.39067 .91846 m
.39256 .91829 L
s
.46053 .9714 m .45798 .96583 L .45366 .96206 L 0 .548 .372 r
F
0 g
.35435 .60778 m
.35985 .59855 L
s
.33908 .67684 m .32915 .67585 L .33294 .67738 L 0 1 .519 r
F
0 g
.33294 .67738 m
.33303 .68143 L
s
.36 .59861 m
.3601 .59865 L
s
.35985 .59855 m
.36 .59861 L
s
.35465 .5966 m
.35618 .59718 L
s
.52606 .97249 m
.5264 .97263 L
s
.52643 .97264 m
.52677 .97279 L
s
.52679 .9728 m
.52714 .97295 L
s
.52715 .97295 m
.52752 .97311 L
s
.52868 .97494 m .52886 .97368 L .53172 .97511 L 0 0 0 r
F
0 g
.52753 .97311 m
.52886 .97368 L
s
.52739 .97263 m
.52886 .97368 L
s
.37549 .67753 m
.37552 .6775 L
s
.37552 .6775 m
.37559 .67742 L
s
.37693 .67592 m .37314 .66011 L .36828 .67151 L 0 1 .392 r
F
.37693 .67592 m .37922 .65332 L .37314 .66011 L F
0 g
.37683 .67713 m
.37693 .67592 L
s
.3759 .67707 m
.37693 .67592 L
s
.46708 .92959 m .46197 .93072 L .46553 .9309 L 0 .896 .48 r
F
.47111 .93428 m .46553 .9309 L .46197 .93072 L 0 .866 .477 r
F
0 g
.46081 .93213 m
.46197 .93072 L
s
.45798 .92898 m
.46197 .93072 L
s
.64445 .73283 m
.64475 .73281 L
s
.64475 .73281 m
.64504 .73278 L
s
.64504 .73278 m
.64535 .73275 L
s
.45508 .87814 m .44728 .87867 L .45187 .88064 L 0 .77 .344 r
F
.4563 .89134 m .45187 .88064 L .44728 .87867 L 0 .735 .345 r
F
0 g
.44435 .88149 m
.44728 .87867 L
s
.44452 .87434 m
.44728 .87867 L
s
.50432 .91522 m .50216 .90792 L .50377 .91167 L 0 .124 .078 r
F
.50661 .91283 m .50377 .91167 L .50216 .90792 L 0 .113 .077 r
F
0 g
.50194 .90774 m
.50216 .90792 L
s
.50203 .90497 m
.50216 .90792 L
s
.40787 .77285 m .39871 .77198 L .40304 .77202 L 0 0 0 r
F
0 g
.40304 .77202 m
.40506 .7715 L
s
.52998 1.08434 m .5352 1.08693 L .5345 1.08759 L 0 .049 0 r
F
0 g
.53139 1.08307 m
.5352 1.08693 L
s
.53687 1.09088 m .5345 1.08759 L .5352 1.08693 L 0 .193 0 r
F
0 g
.5352 1.08693 m
.53706 1.08751 L
s
.47784 1.01492 m .47429 1.00941 L .47011 1.00595 L 0 .347 .356 r
F
.35785 .72715 m .3484 .73324 L .35239 .734 L 0 1 .409 r
F
0 g
.35239 .734 m
.35344 .7417 L
s
.35785 .72715 m .34802 .72504 L .3484 .73324 L 0 1 .409 r
F
.35785 .72715 m .35151 .71488 L .34802 .72504 L F
.35785 .72715 m .35698 .70801 L .35151 .71488 L F
.35785 .72715 m .36077 .70904 L .35698 .70801 L F
.35785 .72715 m .36115 .71724 L .36077 .70904 L F
0 g
.35785 .72715 m
.35837 .7353 L
s
.35239 .734 m
.35785 .72715 L
s
.36115 .71724 m
.36646 .71075 L
s
.2129 .89836 m .20577 .90199 L .21034 .90213 L 0 1 .525 r
F
0 g
.21034 .90213 m
.21557 .90606 L
s
.2129 .89836 m .20143 .89781 L .20577 .90199 L 0 1 .525 r
F
0 g
.20424 .90594 m
.20577 .90199 L
s
.38514 .63517 m .3908 .62492 L .39293 .61491 L 0 1 .4 r
F
0 g
.3908 .62492 m
.39716 .61936 L
s
.36069 .76809 m .35178 .76691 L .35592 .76758 L 0 .548 .227 r
F
0 g
.35592 .76758 m
.35785 .76843 L
s
.33997 .8737 m .33166 .86378 L .32876 .86759 L 0 1 .515 r
F
.33997 .8737 m .33598 .86419 L .33166 .86378 L F
.33997 .8737 m .33954 .86845 L .33598 .86419 L F
.35071 .8745 m .33954 .86845 L .33997 .8737 L 0 1 .512 r
F
0 g
.33707 .87749 m
.33997 .8737 L
s
.33997 .8737 m
.3435 .87782 L
s
.42226 .90151 m .41253 .89478 L .4099 .89674 L 0 1 .499 r
F
0 g
.40564 .89377 m
.4099 .89674 L
s
.51381 .90618 m .51284 .90701 L .51195 .9037 L 0 .098 .08 r
F
.27741 .54462 m .26489 .55165 L .26876 .55258 L 0 1 .471 r
F
0 g
.26674 .56163 m
.26876 .55258 L
s
.28566 .67028 m .27512 .66668 L .2748 .67296 L 0 1 .52 r
F
0 g
.26886 .67729 m
.2748 .67296 L
s
.70309 .61664 m .72004 .6183 L .71849 .61652 L 0 .889 .305 r
F
0 g
.72004 .6183 m
.72679 .61955 L
s
.45367 .92928 m .44807 .93329 L .45191 .93336 L 0 .666 .361 r
F
.45786 .94295 m .45191 .93336 L .44807 .93329 L 0 .614 .36 r
F
0 g
.44672 .93754 m
.44807 .93329 L
s
.44388 .92888 m
.44807 .93329 L
s
.45508 .87814 m .45476 .87282 L .45103 .86698 L 0 .77 .344 r
F
.45812 .90443 m .44626 .89577 L .44722 .90143 L 0 .697 .346 r
F
.45812 .90443 m .44889 .89265 L .44626 .89577 L F
0 g
.44474 .89389 m
.44626 .89577 L
s
.47898 .85577 m .46768 .83802 L .47069 .84666 L 0 .737 .315 r
F
0 g
.46385 .83758 m
.46768 .83802 L
s
.47784 1.01492 m .47771 1.02057 L .47931 1.0197 L 0 .347 .356 r
F
.48696 1.02866 m .47931 1.0197 L .47771 1.02057 L 0 .291 .321 r
F
0 g
.47771 1.02057 m
.47962 1.02529 L
s
.47353 1.01709 m
.47771 1.02057 L
s
.37267 .87679 m .36507 .87939 L .36955 .87982 L 0 1 .506 r
F
0 g
.36955 .87982 m
.37358 .88342 L
s
.37267 .87679 m .36145 .8755 L .36507 .87939 L 0 1 .506 r
F
0 g
.36245 .88253 m
.36507 .87939 L
s
.51638 1.07197 m .51153 1.06671 L .50774 1.06297 L 0 .058 .167 r
F
.82439 .889 m .83583 .88833 L .83382 .88466 L 0 1 .511 r
F
.46614 .87342 m .4544 .85945 L .45447 .86481 L 0 .739 .33 r
F
0 g
.45103 .86698 m
.45382 .87134 L
s
.46614 .87342 m .45786 .85835 L .4544 .85945 L 0 .739 .33 r
F
0 g
.45085 .85318 m
.4544 .85945 L
s
.4544 .85945 m
.45676 .8587 L
s
.45676 .8587 m
.45722 .85855 L
s
.47452 .99893 m .46573 .99556 L .4691 1.00112 L 0 .386 .355 r
F
.47452 .99893 m .46505 .99079 L .46573 .99556 L F
0 g
.46137 .99203 m
.46573 .99556 L
s
.48727 .77774 m
.48728 .7756 L
s
.49434 1.04425 m .49636 1.04933 L .49704 1.04875 L 0 .257 .281 r
F
.50514 1.05784 m .49704 1.04875 L .49636 1.04933 L 0 .151 .194 r
F
0 g
.49636 1.04933 m
.49946 1.05366 L
s
.49231 1.04583 m
.49636 1.04933 L
s
.73006 .89525 m .74291 .89612 L .74417 .89421 L 0 .769 .26 r
F
0 g
.73779 .89753 m
.74291 .89612 L
s
.75707 .61655 m .77023 .62285 L .77445 .62266 L 0 1 .445 r
F
.75707 .61655 m .76279 .62024 L .77023 .62285 L F
0 g
.7697 .62267 m
.77023 .62285 L
s
.75782 .63505 m .76312 .62815 L .77023 .62286 L 0 0 .004 r
F
0 g
.76865 .62403 m
.76938 .62349 L
s
.76938 .62349 m
.77023 .62286 L
s
.76375 .62768 m
.76381 .62583 L
s
.76381 .62583 m
.76391 .62318 L
s
.56354 .62192 m
.56913 .62722 L
s
.56023 .62463 m
.56354 .62192 L
s
.3406 .74958 m .33127 .756 L .33543 .75647 L 0 1 .424 r
F
0 g
.33543 .75647 m
.33705 .76382 L
s
.31395 .77143 m .30336 .77084 L .30486 .77818 L 0 1 .446 r
F
0 g
.30065 .78509 m
.30486 .77818 L
s
.27863 .75508 m .26969 .74878 L .26737 .7526 L 0 1 .505 r
F
.27863 .75508 m .27478 .7469 L .26969 .74878 L F
.27863 .75508 m .27922 .74822 L .27478 .7469 L F
.27863 .75508 m .28087 .75173 L .27922 .74822 L F
0 g
.27356 .75694 m
.27863 .75508 L
s
.27863 .75508 m
.28036 .75821 L
s
.2335 .74537 m .2236 .74782 L .22815 .74862 L 0 1 .535 r
F
0 g
.22815 .74862 m
.23053 .7531 L
s
.36658 .70202 m .37054 .69165 L .37084 .68273 L 0 1 .4 r
F
0 g
.37054 .69165 m
.37616 .68516 L
s
.51477 .96627 m .51235 .96482 L .51037 .96401 L 0 .318 .212 r
F
.46264 .95648 m .45203 .95179 L .45433 .95743 L 0 .557 .358 r
F
.46264 .95648 m .45296 .9474 L .45203 .95179 L F
0 g
.44764 .94782 m
.45203 .95179 L
s
.46271 .52104 m .45423 .5242 L .45548 .52549 L 0 1 .311 r
F
.46271 .52104 m .45993 .51813 L .45423 .5242 L F
.46271 .52104 m .46878 .51134 L .45993 .51813 L F
.46271 .52104 m .476 .50692 L .46878 .51134 L F
0 g
.45735 .52744 m
.46271 .52104 L
s
.3769 .67713 m .37279 .67503 L .36816 .67659 L 0 1 .315 r
F
.3769 .67713 m .37877 .67372 L .37279 .67503 L F
.3769 .67713 m .38209 .67352 L .37877 .67372 L F
.3769 .67713 m .38128 .67498 L .38209 .67352 L F
0 g
.37559 .67742 m
.3769 .67713 L
s
.3768 .67742 m
.3769 .67713 L
s
.27741 .54462 m .26794 .54236 L .26489 .55165 L 0 1 .471 r
F
.27741 .54462 m .2759 .53089 L .26794 .54236 L F
.27741 .54462 m .28457 .52291 L .2759 .53089 L F
.27741 .54462 m .28816 .52375 L .28457 .52291 L F
.27741 .54462 m .28509 .53306 L .28816 .52375 L F
0 g
.27456 .55404 m
.27741 .54462 L
s
.26876 .55258 m
.27741 .54462 L
s
.61999 .51249 m .61749 .51181 L .61527 .50725 L 0 .281 0 r
F
0 g
.61527 .50725 m
.61538 .50736 L
s
.61364 .50546 m
.61527 .50725 L
s
.61999 .51249 m .62588 .52417 L .61749 .51181 L 0 .281 0 r
F
0 g
.61538 .50736 m
.61981 .51229 L
s
.61999 .51249 m .63485 .53609 L .62588 .52417 L 0 .281 0 r
F
.61999 .51249 m .62849 .52404 L .63688 .5364 L F
0 g
.63451 .53128 m
.63692 .53642 L
s
.62893 .52435 m
.62948 .52472 L
s
.62948 .52472 m
.63221 .52664 L
s
.62849 .52404 m
.62893 .52435 L
s
.61981 .51229 m
.61999 .51249 L
s
.38514 .63517 m .39293 .61491 L .3901 .61181 L 0 1 .4 r
F
0 g
.39293 .61491 m
.39966 .61054 L
s
.3908 .62492 m
.39293 .61491 L
s
.49323 .86016 m .48417 .82481 L .48336 .82829 L 0 .666 .299 r
F
.49323 .86016 m .48759 .83239 L .48417 .82481 L F
0 g
.4828 .81809 m
.48417 .82481 L
s
.48696 1.02866 m .48377 1.03072 L .48774 1.03419 L 0 .291 .321 r
F
0 g
.48377 1.03072 m
.48603 1.03536 L
s
.44797 .91935 m
.44811 .91933 L
s
.46358 .91924 m .45412 .92013 L .45222 .91886 L 0 0 .007 r
F
0 g
.44811 .91933 m
.45222 .91886 L
s
.53767 .4705 m
.54537 .47214 L
s
.47629 .91847 m .46744 .91907 L .46568 .91744 L 0 .054 .037 r
F
0 g
.46167 .91797 m
.46568 .91744 L
s
.3406 .74958 m .33033 .74833 L .33127 .756 L 0 1 .424 r
F
.3406 .74958 m .33322 .73856 L .33033 .74833 L F
.3406 .74958 m .3384 .73166 L .33322 .73856 L F
.3406 .74958 m .3424 .73223 L .3384 .73166 L F
.3406 .74958 m .34334 .73991 L .3424 .73223 L F
0 g
.3406 .74958 m
.34164 .75727 L
s
.33543 .75647 m
.3406 .74958 L
s
.39706 .88993 m .3876 .88205 L .38472 .88458 L 0 1 .504 r
F
.39706 .88993 m .39227 .88277 L .3876 .88205 L F
.39706 .88993 m .39633 .88615 L .39227 .88277 L F
.40859 .8916 m .39633 .88615 L .39706 .88993 L 0 1 .499 r
F
0 g
.39706 .88993 m
.40105 .8932 L
s
.39418 .89245 m
.39706 .88993 L
s
.36658 .70202 m .35698 .70801 L .36077 .70904 L 0 1 .4 r
F
0 g
.36077 .70904 m
.36115 .71724 L
s
.36658 .70202 m .35728 .69909 L .35698 .70801 L 0 1 .4 r
F
.36658 .70202 m .36148 .68822 L .35728 .69909 L F
.36658 .70202 m .3673 .68121 L .36148 .68822 L F
.36658 .70202 m .37084 .68273 L .3673 .68121 L F
0 g
.36077 .70904 m
.36658 .70202 L
s
.36646 .71075 m
.36658 .70202 L
s
.37084 .68273 m
.37549 .67753 L
s
.37054 .69165 m
.37084 .68273 L
s
.43371 .77393 m .4236 .77536 L .42497 .77382 L 0 0 0 r
F
.43371 .77393 m .4259 .77684 L .4236 .77536 L F
.43371 .77393 m .43054 .77753 L .4259 .77684 L F
.43371 .77393 m .43441 .77698 L .43054 .77753 L F
.43371 .77393 m .43576 .77544 L .43441 .77698 L F
0 g
.43371 .77393 m
.43526 .77199 L
s
.42909 .77324 m
.43371 .77393 L
s
.4273 .56275 m .41808 .56496 L .42018 .56705 L 0 1 .439 r
F
.4273 .56275 m .42237 .55783 L .41808 .56496 L F
.4273 .56275 m .43018 .55041 L .42237 .55783 L F
.4273 .56275 m .4373 .54612 L .43018 .55041 L F
.4273 .56275 m .43898 .54782 L .4373 .54612 L F
0 g
.4347 .55494 m
.43898 .54782 L
s
.42332 .57023 m
.4273 .56275 L
s
.43898 .54782 m
.44603 .54328 L
s
.52076 .47551 m
.52195 .47499 L
s
.2846 .93448 m .27814 .93457 L .28262 .93469 L 0 .547 .208 r
F
0 g
.28262 .93469 m
.28808 .935 L
s
.2846 .93448 m .27331 .93393 L .27814 .93457 L 0 .547 .208 r
F
0 g
.27699 .93497 m
.27814 .93457 L
s
.45812 .90443 m .44722 .90143 L .45117 .90647 L 0 .697 .346 r
F
0 g
.44722 .90143 m
.44824 .90273 L
s
.44471 .90514 m
.44722 .90143 L
s
.44471 .90514 m
.44507 .90554 L
s
.55021 1.0985 m .55673 1.09951 L .55546 1.10101 L 0 .18 0 r
F
0 g
.55673 1.09951 m
.55882 1.10042 L
s
.55305 1.09519 m
.55673 1.09951 L
s
.3266 .76274 m
.33127 .756 L
s
.50763 .62311 m .51348 .62135 L .51799 .62127 L 0 0 0 r
F
0 g
.51348 .62135 m
.51776 .61854 L
s
.49547 .95065 m .49111 .95134 L .49399 .9523 L 0 .486 .378 r
F
.49547 .95065 m .48889 .94976 L .49111 .95134 L F
0 g
.49111 .95134 m
.49158 .95286 L
s
.49547 .95065 m .48876 .94841 L .48889 .94976 L 0 .486 .378 r
F
0 g
.48568 .94886 m
.48889 .94976 L
s
.4801 .84639 m .47194 .83559 L .47636 .84334 L 0 .754 .313 r
F
.47898 .85577 m .47636 .84334 L .47194 .83559 L 0 .737 .315 r
F
0 g
.46917 .82626 m
.47194 .83559 L
s
.47143 .83528 m
.47194 .83559 L
s
.50211 .91767 m .49627 .91407 L .49537 .9108 L 0 .137 .078 r
F
0 g
.49256 .91038 m
.49537 .9108 L
s
.46354 .92475 m .45373 .92355 L .45776 .92552 L 0 .92 .481 r
F
.46354 .92475 m .45219 .92131 L .45373 .92355 L F
0 g
.45243 .92472 m
.45373 .92355 L
s
.31395 .77143 m .30563 .76127 L .30336 .77084 L 0 1 .446 r
F
0 g
.30912 .7784 m
.31395 .77143 L
s
.31395 .77143 m
.31551 .77877 L
s
.30336 .77084 m
.30486 .77818 L
s
.38514 .63517 m .37537 .63783 L .37852 .6407 L 0 1 .4 r
F
.38514 .63517 m .3775 .62781 L .37537 .63783 L F
.38514 .63517 m .38349 .61734 L .3775 .62781 L F
.38514 .63517 m .3901 .61181 L .38349 .61734 L F
0 g
.38325 .64478 m
.38514 .63517 L
s
.37852 .6407 m
.38514 .63517 L
s
.38472 .88458 m
.38721 .8824 L
s
.52081 .96994 m .52393 .97138 L .52318 .97119 L 0 .223 .181 r
F
0 g
.52299 .97087 m
.52393 .97138 L
s
.52393 .97186 m .52318 .97119 L .52393 .97138 L 0 0 0 r
F
0 g
.52393 .97138 m
.52394 .97138 L
s
.50006 .95433 m .49452 .95368 L .49683 .95521 L 0 .42 .334 r
F
.50006 .95433 m .49399 .9523 L .49452 .95368 L F
0 g
.49158 .95286 m
.49452 .95368 L
s
.25688 .5594 m
.26489 .55165 L
s
.60315 .63853 m .6174 .63129 L .61512 .63296 L 0 0 0 r
F
0 g
.6174 .63129 m
.62344 .63001 L
s
.77279 1.05513 m .77791 1.05368 L .7831 1.0499 L 0 .878 .216 r
F
0 g
.77106 1.05776 m
.77791 1.05368 L
s
.77702 1.0554 m
.77791 1.05368 L
s
.46614 .87342 m .45447 .86481 L .45802 .87127 L 0 .739 .33 r
F
0 g
.45447 .86481 m
.45515 .86606 L
s
.45103 .86698 m
.45447 .86481 L
s
.49108 .9469 m .48563 .94733 L .48876 .94841 L 0 .572 .41 r
F
.49108 .9469 m .48351 .94568 L .48563 .94733 L F
0 g
.48563 .94733 m
.48568 .94886 L
s
.23949 .93264 m .22744 .92884 L .22582 .93018 L 0 .699 .258 r
F
.23949 .93264 m .23202 .92921 L .22744 .92884 L F
.23949 .93264 m .23719 .93085 L .23202 .92921 L F
.25075 .93302 m .23719 .93085 L .23949 .93264 L 0 .672 .25 r
F
0 g
.23786 .93396 m
.23949 .93264 L
s
.23949 .93264 m
.24456 .93402 L
s
.42045 .77339 m
.42497 .77382 L
s
.37093 .7695 m .36291 .7681 L .36069 .76809 L 0 .506 .207 r
F
.37093 .7695 m .36759 .76864 L .36291 .7681 L F
.37093 .7695 m .37159 .76936 L .36759 .76864 L F
.37093 .7695 m .37302 .76972 L .37159 .76936 L F
0 g
.36627 .76896 m
.37093 .7695 L
s
.2335 .74537 m .22219 .74308 L .2236 .74782 L 0 1 .535 r
F
0 g
.21913 .75139 m
.2236 .74782 L
s
.47955 .9152 m .4782 .91652 L .47452 .91684 L 0 .025 .035 r
F
.48788 .91911 m .47955 .9152 L .48298 .91539 L 0 .112 .061 r
F
.48788 .91911 m .4782 .91652 L .47955 .9152 L F
0 g
.47814 .91354 m
.47955 .9152 L
s
.47955 .9152 m
.4811 .91529 L
s
.36069 .76809 m .35044 .76624 L .35178 .76691 L 0 .548 .227 r
F
0 g
.34743 .76698 m
.35178 .76691 L
s
.33908 .67684 m .32978 .67262 L .32915 .67585 L 0 1 .519 r
F
0 g
.32341 .67796 m
.32915 .67585 L
s
.47558 .93881 m .47374 .93702 L .46994 .93569 L 0 .825 .47 r
F
0 g
.44797 .91935 m
.4481 .91941 L
s
.44797 .91935 m
.44827 .91914 L
s
.44797 .91935 m
.44816 .91944 L
s
.44816 .91944 m
.4483 .9195 L
s
.48215 .50142 m .49114 .49498 L .49755 .4897 L 0 1 .215 r
F
.50006 .95433 m .49683 .95521 L .49943 .95608 L 0 .42 .334 r
F
0 g
.49683 .95521 m
.4977 .9567 L
s
.35071 .8745 m .34247 .86487 L .33954 .86845 L 0 1 .512 r
F
.35071 .8745 m .34679 .86536 L .34247 .86487 L F
.35071 .8745 m .35032 .86949 L .34679 .86536 L F
.36145 .8755 m .35032 .86949 L .35071 .8745 L 0 1 .509 r
F
0 g
.34778 .87807 m
.35071 .8745 L
s
.35071 .8745 m
.35421 .8785 L
s
.67138 .9173 m
.67183 .91633 L
s
.49108 .9469 m .48377 .94438 L .48351 .94568 L 0 .572 .41 r
F
0 g
.48007 .94467 m
.48351 .94568 L
s
.22437 .89894 m .21719 .90234 L .22176 .90248 L 0 1 .522 r
F
0 g
.22176 .90248 m
.22691 .9062 L
s
.22437 .89894 m .2129 .89836 L .21719 .90234 L 0 1 .522 r
F
0 g
.21557 .90606 m
.21719 .90234 L
s
.82439 .889 m .83382 .88466 L .82922 .88504 L 0 1 .511 r
F
.81295 .88968 m .82439 .889 L .82231 .88562 L 0 1 .502 r
F
.39389 .67243 m .38706 .67326 L .39036 .67312 L 0 1 .346 r
F
.39389 .67243 m .3857 .67286 L .38706 .67326 L F
0 g
.39036 .67312 m
.39036 .67312 L
s
.38974 .67489 m
.39036 .67312 L
s
.39389 .67243 m .38719 .67219 L .3857 .67286 L 0 1 .346 r
F
.39389 .67243 m .39072 .6715 L .38719 .67219 L F
.39389 .67243 m .39394 .67126 L .39072 .6715 L F
.39389 .67243 m .39529 .67165 L .39394 .67126 L F
0 g
.39389 .67243 m
.39531 .6729 L
s
.39036 .67312 m
.39389 .67243 L
s
.39529 .67165 m
.39874 .67092 L
s
.52868 .97494 m .53172 .97511 L .53285 .97616 L 0 0 0 r
F
0 g
.53172 .97511 m
.53488 .97605 L
s
.32044 .91154 m .31042 .90672 L .30835 .90852 L 0 1 .447 r
F
.32044 .91154 m .31471 .90703 L .31042 .90672 L F
.32044 .91154 m .31901 .9091 L .31471 .90703 L F
.33102 .91195 m .31901 .9091 L .32044 .91154 L 0 1 .424 r
F
0 g
.31836 .91333 m
.32044 .91154 L
s
.32044 .91154 m
.32466 .91342 L
s
.46264 .95648 m .45433 .95743 L .45848 .96132 L 0 .557 .358 r
F
0 g
.45366 .96206 m
.45433 .95743 L
s
.46615 .86162 m .45786 .85835 L .46253 .86224 L 0 .767 .329 r
F
.46614 .87342 m .46253 .86224 L .45786 .85835 L 0 .739 .33 r
F
0 g
.45722 .85855 m
.45786 .85835 L
s
.45449 .85138 m
.45786 .85835 L
s
.36488 .91578 m
.36488 .91578 L
s
.76052 .79344 m .76656 .78027 L .77125 .78235 L 0 .227 .057 r
F
.76052 .79344 m .76196 .785 L .76656 .78027 L F
0 g
.76337 .7744 m
.76656 .78027 L
s
.4563 .89134 m .44889 .89265 L .45336 .89416 L 0 .735 .345 r
F
.45812 .90443 m .45336 .89416 L .44889 .89265 L 0 .697 .346 r
F
0 g
.44626 .89577 m
.44889 .89265 L
s
.44603 .88863 m
.44889 .89265 L
s
.49323 .86016 m .48336 .82829 L .48577 .84016 L 0 .666 .299 r
F
0 g
.48547 .81968 m
.48712 .82958 L
s
.48109 .82531 m
.48336 .82829 L
s
.3522 .91314 m .34569 .914 L .3499 .91418 L 0 .887 .356 r
F
0 g
.3499 .91418 m
.35444 .9154 L
s
.3522 .91314 m .3416 .91247 L .34569 .914 L 0 .887 .356 r
F
0 g
.34401 .91517 m
.34569 .914 L
s
.36767 .67749 m
.36768 .67748 L
s
.36737 .67805 m
.36767 .67749 L
s
.45127 .6467 m .44346 .64932 L .44566 .649 L 0 .898 .223 r
F
.45127 .6467 m .44611 .64755 L .44346 .64932 L F
0 g
.44355 .65088 m
.44566 .649 L
s
.45127 .6467 m .45185 .64485 L .44611 .64755 L 0 .898 .223 r
F
.45127 .6467 m .45747 .64255 L .45185 .64485 L F
.45127 .6467 m .45923 .64218 L .45747 .64255 L F
.45127 .6467 m .45657 .64396 L .45923 .64218 L F
0 g
.44894 .64844 m
.45127 .6467 L
s
.44566 .649 m
.45127 .6467 L
s
.45657 .64396 m
.46187 .64153 L
s
.81551 1.02718 m .81114 1.03314 L .81101 1.0364 L 0 1 .386 r
F
0 g
.80367 1.0412 m
.81101 1.0364 L
s
.49678 .84845 m .49038 .82281 L .49373 .83818 L 0 .665 .294 r
F
0 g
.49023 .82157 m
.49038 .82281 L
s
.49588 .85078 m .49373 .83818 L .49038 .82281 L 0 .672 .296 r
F
0 g
.49038 .8228 m
.49038 .82281 L
s
.46615 .86162 m .4663 .8569 L .46293 .84993 L 0 .767 .329 r
F
.73015 1.0771 m .72486 1.07719 L .72374 1.07602 L 0 0 0 r
F
0 g
.7163 1.07691 m
.72374 1.07602 L
s
.22123 .67548 m .21451 .66466 L .21018 .67345 L 0 1 .525 r
F
0 g
.21018 .67345 m
.21029 .68056 L
s
.22123 .67548 m .22102 .65881 L .21451 .66466 L 0 1 .525 r
F
.22123 .67548 m .22535 .65983 L .22102 .65881 L F
.22123 .67548 m .22543 .66699 L .22535 .65983 L F
0 g
.21475 .68128 m
.22123 .67548 L
s
.22123 .67548 m
.22143 .68238 L
s
.69374 .61864 m .70884 .61808 L .70309 .61664 L 0 .788 .263 r
F
0 g
.70884 .61808 m
.71018 .61952 L
s
.70884 .61808 m
.71601 .61878 L
s
.47822 .86531 m .46701 .8451 L .46667 .84982 L 0 .717 .316 r
F
.47822 .86531 m .47069 .84666 L .46701 .8451 L F
0 g
.46385 .83758 m
.46701 .8451 L
s
.46701 .8451 m
.46997 .84636 L
s
.43353 .90345 m .42633 .90432 L .4308 .90501 L 0 1 .493 r
F
.43353 .90345 m .42226 .90151 L .42633 .90432 L F
.43621 .91021 m .4308 .90501 L .42633 .90432 L 0 1 .498 r
F
0 g
.42399 .90603 m
.42633 .90432 L
s
.50478 .95796 m .50034 .95747 L .50272 .95896 L 0 .376 .277 r
F
.50478 .95796 m .49943 .95608 L .50034 .95747 L F
0 g
.4977 .9567 m
.50034 .95747 L
s
.47452 .99893 m .4691 1.00112 L .47316 1.00461 L 0 .386 .355 r
F
0 g
.4691 1.00112 m
.47011 1.00595 L
s
.48691 .94306 m .48043 .94315 L .48377 .94438 L 0 .644 .432 r
F
.48691 .94306 m .47845 .94143 L .48043 .94315 L F
0 g
.48007 .94467 m
.48043 .94315 L
s
.50514 1.05784 m .50428 1.05886 L .50805 1.06252 L 0 .151 .194 r
F
0 g
.50428 1.05886 m
.50774 1.06297 L
s
.63055 .62829 m .6458 .62544 L .64365 .62523 L 0 .761 .222 r
F
0 g
.6458 .62544 m
.65214 .62506 L
s
.42226 .90151 m .41712 .89555 L .41253 .89478 L 0 1 .499 r
F
.42226 .90151 m .42129 .89843 L .41712 .89555 L F
.43353 .90345 m .42129 .89843 L .42226 .90151 L 0 1 .493 r
F
0 g
.42226 .90151 m
.42633 .90432 L
s
.41963 .90345 m
.42226 .90151 L
s
.46053 .9174 m .44887 .90986 L .45011 .91544 L 0 .655 .347 r
F
.46053 .9174 m .45117 .90647 L .44887 .90986 L F
0 g
.44507 .90554 m
.44887 .90986 L
s
.4801 .84639 m .48064 .84269 L .47786 .83335 L 0 .754 .313 r
F
0 g
.4791 .83749 m
.48044 .84201 L
s
.47786 .83335 m
.4791 .83749 L
s
.47786 .83335 m
.47982 .8354 L
s
.5281 .47094 m .5212 .47483 L .52103 .4728 L 0 .039 .013 r
F
.50763 .62311 m .50265 .62636 L .50298 .62525 L 0 0 0 r
F
0 g
.50173 .62436 m
.50348 .62338 L
s
.50763 .62311 m .50716 .62628 L .50265 .62636 L 0 0 0 r
F
.50763 .62311 m .51351 .62507 L .50716 .62628 L F
.50763 .62311 m .51815 .62292 L .51351 .62507 L F
.50763 .62311 m .51799 .62127 L .51815 .62292 L F
0 g
.50348 .62338 m
.50763 .62311 L
s
.51799 .62127 m
.52225 .61901 L
s
.51348 .62135 m
.51799 .62127 L
s
.43621 .91021 m .43504 .90753 L .4308 .90501 L 0 1 .498 r
F
.44711 .91205 m .43621 .91021 L .44031 .91271 L 0 1 .489 r
F
.44711 .91205 m .43504 .90753 L .43621 .91021 L F
0 g
.43386 .91192 m
.43621 .91021 L
s
.46728 .98522 m .46505 .99079 L .46751 .98997 L 0 .473 .366 r
F
.47452 .99893 m .46751 .98997 L .46505 .99079 L 0 .386 .355 r
F
0 g
.46505 .99079 m
.46573 .99556 L
s
.46084 .98717 m
.46505 .99079 L
s
.40787 .77285 m .39718 .77266 L .39871 .77198 L 0 0 0 r
F
0 g
.3941 .77152 m
.39871 .77198 L
s
.37801 .64895 m .37965 .64547 L .37852 .64071 L 0 1 .388 r
F
0 g
.37965 .64547 m
.38325 .64479 L
s
.73686 .61868 m .73984 .61569 L .73587 .61624 L 0 .922 .361 r
F
.73686 .61868 m .74695 .61769 L .73984 .61569 L F
.3839 .87837 m .37626 .88056 L .38074 .88111 L 0 1 .502 r
F
0 g
.38074 .88111 m
.38472 .88458 L
s
.3839 .87837 m .37267 .87679 L .37626 .88056 L 0 1 .502 r
F
0 g
.37358 .88342 m
.37626 .88056 L
s
.4563 .89134 m .45574 .88607 L .45187 .88064 L 0 .735 .345 r
F
.44851 .77513 m .4402 .77574 L .44405 .77464 L 0 .086 .014 r
F
0 g
.44405 .77464 m
.44559 .7727 L
s
.51138 .90828 m .51042 .90916 L .50918 .90631 L 0 .1 .078 r
F
.22219 .74308 m .21221 .74586 L .21677 .74664 L 0 1 .538 r
F
0 g
.21677 .74664 m
.21913 .75139 L
s
.26737 .7526 m .25851 .74586 L .25609 .75014 L 0 1 .518 r
F
.26737 .7526 m .26367 .74362 L .25851 .74586 L F
.26737 .7526 m .26812 .74493 L .26367 .74362 L F
.26737 .7526 m .26969 .74878 L .26812 .74493 L F
0 g
.26222 .75482 m
.26737 .7526 L
s
.26737 .7526 m
.26903 .75609 L
s
.71931 .89609 m .72889 .89653 L .73006 .89525 L 0 .703 .24 r
F
0 g
.72483 .89746 m
.72889 .89653 L
s
.30336 .77084 m .29185 .77761 L .29746 .77784 L 0 1 .454 r
F
0 g
.29746 .77784 m
.30064 .78509 L
s
.50478 .95796 m .50272 .95896 L .50501 .95977 L 0 .376 .277 r
F
0 g
.50272 .95896 m
.50399 .9604 L
s
.52393 .97186 m .52606 .97249 L .52517 .97233 L 0 0 0 r
F
0 g
.52605 .97228 m
.52606 .97249 L
s
.48194 .77685 m .47568 .78217 L .47837 .77832 L 0 .267 .081 r
F
.48194 .77685 m .47553 .78695 L .47568 .78217 L F
.48194 .77685 m .47804 .78946 L .47553 .78695 L F
.48194 .77685 m .48163 .78797 L .47804 .78946 L F
0 g
.47837 .77832 m
.47893 .77415 L
s
.48194 .77685 m .48389 .78349 L .48163 .78797 L 0 .267 .081 r
F
.48194 .77685 m .48402 .77872 L .48389 .78349 L F
0 g
.48194 .77685 m
.48226 .773 L
s
.47837 .77832 m
.48194 .77685 L
s
.48402 .77872 m
.48728 .7756 L
s
.79218 .63251 m .80478 .65695 L .80918 .65645 L 0 1 .449 r
F
.79218 .63251 m .7975 .6467 L .80478 .65695 L F
0 g
.80451 .66807 m
.80478 .65695 L
s
.7975 .6467 m
.7982 .65769 L
s
.7975 .6467 m
.80475 .6569 L
s
.80475 .6569 m
.80478 .65695 L
s
.27512 .66668 m .2641 .66987 L .26838 .67109 L 0 1 .519 r
F
0 g
.26838 .67109 m
.26955 .67032 L
s
.26838 .67109 m
.26886 .67729 L
s
.43608 .92109 m .42945 .91992 L .43375 .92029 L 0 0 0 r
F
.43608 .92109 m .42518 .91996 L .42945 .91992 L F
0 g
.42754 .91925 m
.42945 .91992 L
s
.34334 .73991 m
.3484 .73324 L
s
.48691 .94306 m .4791 .9402 L .47845 .94143 L 0 .644 .432 r
F
0 g
.47481 .94028 m
.47845 .94143 L
s
.45786 .94295 m .45296 .9474 L .45651 .9472 L 0 .614 .36 r
F
.46264 .95648 m .45651 .9472 L .45296 .9474 L 0 .557 .358 r
F
0 g
.45203 .95179 m
.45296 .9474 L
s
.44877 .94326 m
.45296 .9474 L
s
.7745 .62274 m
.77525 .62387 L
s
.77525 .62387 m
.7754 .62411 L
s
.7754 .62411 m
.77646 .62571 L
s
.77445 .62267 m
.77446 .62269 L
s
.77446 .62269 m
.7745 .62274 L
s
.49588 .85078 m .48968 .82502 L .49313 .83997 L 0 .672 .296 r
F
0 g
.488 .8165 m
.48968 .82502 L
s
.49463 .85476 m .49313 .83997 L .48968 .82502 L 0 .668 .297 r
F
0 g
.4864 .81634 m
.48968 .82502 L
s
.46354 .92475 m .45412 .92013 L .45219 .92131 L 0 .92 .481 r
F
0 g
.4483 .9195 m
.45219 .92131 L
s
.44851 .77513 m .43909 .77793 L .4402 .77574 L 0 .086 .014 r
F
.44851 .77513 m .44148 .77974 L .43909 .77793 L F
.44851 .77513 m .44594 .78023 L .44148 .77974 L F
.44851 .77513 m .4495 .77907 L .44594 .78023 L F
.44851 .77513 m .4506 .77688 L .4495 .77907 L F
0 g
.44851 .77513 m
.44983 .77247 L
s
.44405 .77464 m
.44851 .77513 L
s
.40951 .58247 m .4165 .57455 L .42018 .56705 L 0 1 .449 r
F
0 g
.4165 .57455 m
.42332 .57023 L
s
.40787 .77285 m .39949 .77362 L .39718 .77266 L 0 0 0 r
F
0 g
.39718 .77266 m
.39871 .77198 L
s
.40787 .77285 m .40433 .77445 L .39949 .77362 L 0 0 0 r
F
.40787 .77285 m .40846 .7746 L .40433 .77445 L F
.40787 .77285 m .40998 .77391 L .40846 .7746 L F
0 g
.40787 .77285 m
.40954 .77185 L
s
.40304 .77202 m
.40787 .77285 L
s
.55693 .75354 m .566 .70622 L .56222 .71419 L 0 1 .265 r
F
.55693 .75354 m .56704 .71418 L .566 .70622 L F
0 g
.566 .70622 m
.56713 .7027 L
s
.46662 .88519 m .45476 .87282 L .45508 .87814 L 0 .708 .331 r
F
0 g
.45187 .88064 m
.45473 .88466 L
s
.46662 .88519 m .45802 .87127 L .45476 .87282 L 0 .708 .331 r
F
0 g
.45382 .87134 m
.45476 .87282 L
s
.45476 .87282 m
.45682 .87184 L
s
.53298 .82983 m
.5335 .80919 L
s
.5311 .82353 m
.53326 .80796 L
s
.5285 1.08542 m .52467 1.07937 L .52998 1.08434 L 0 .114 0 r
F
.5285 1.08542 m .52049 1.07572 L .52467 1.07937 L F
0 g
.52466 1.07935 m
.52467 1.07937 L
s
.73015 1.0771 m .73445 1.07246 L .73998 1.07157 L 0 0 0 r
F
0 g
.7275 1.07437 m
.73445 1.07246 L
s
.73314 1.07203 m
.73445 1.07246 L
s
.37801 .64895 m .37109 .64726 L .37434 .64972 L 0 1 .388 r
F
.37801 .64895 m .36995 .64249 L .37109 .64726 L F
.37801 .64895 m .37169 .6386 L .36995 .64249 L F
.37801 .64895 m .37537 .63784 L .37169 .6386 L F
.37801 .64895 m .37852 .64071 L .37537 .63784 L F
0 g
.37434 .64972 m
.37801 .64895 L
s
.37801 .64895 m
.37923 .65331 L
s
.37852 .64071 m
.37965 .64547 L
s
.46728 .98522 m .46451 .97971 L .4603 .9761 L 0 .473 .366 r
F
0 g
.5271 .82675 m
.52748 .80817 L
s
.46354 .92475 m .45776 .92552 L .4616 .92593 L 0 .92 .481 r
F
.46708 .92959 m .4616 .92593 L .45776 .92552 L 0 .896 .48 r
F
0 g
.45621 .92683 m
.45776 .92552 L
s
.45373 .92355 m
.45776 .92552 L
s
.28566 .67028 m .27984 .65957 L .27512 .66668 L 0 1 .52 r
F
.28566 .67028 m .28645 .6556 L .27984 .65957 L F
.28566 .67028 m .29052 .65743 L .28645 .6556 L F
.28566 .67028 m .29018 .66373 L .29052 .65743 L F
0 g
.27967 .67388 m
.28566 .67028 L
s
.28549 .67617 m
.28566 .67028 L
s
.38815 .91771 m .37793 .91602 L .37579 .91636 L 0 .622 .235 r
F
.38815 .91771 m .38234 .91643 L .37793 .91602 L F
.38815 .91771 m .38672 .91716 L .38234 .91643 L F
0 g
.386 .91805 m
.38815 .91771 L
s
.39941 .91849 m .38672 .91716 L .38815 .91771 L 0 .534 .207 r
F
0 g
.38815 .91771 m
.39256 .91829 L
s
.56524 .74253 m .56704 .71418 L .56466 .7328 L 0 1 .226 r
F
.55693 .75354 m .56466 .7328 L .56704 .71418 L 0 1 .265 r
F
0 g
.566 .70622 m
.56704 .71418 L
s
.56704 .71418 m
.56933 .70166 L
s
.44711 .91205 m .44031 .91271 L .44462 .91335 L 0 1 .489 r
F
.45009 .91789 m .44462 .91335 L .44031 .91271 L 0 1 .492 r
F
0 g
.4382 .91417 m
.44031 .91271 L
s
.43621 .91021 m
.44031 .91271 L
s
.81295 .88968 m .82231 .88562 L .81771 .88601 L 0 1 .502 r
F
.8015 .89039 m .81295 .88968 L .8108 .8866 L 0 1 .49 r
F
.36145 .8755 m .35328 .86615 L .35032 .86949 L 0 1 .509 r
F
.36145 .8755 m .3576 .86672 L .35328 .86615 L F
.36145 .8755 m .3611 .87073 L .3576 .86672 L F
0 g
.35849 .87882 m
.36145 .8755 L
s
.37267 .87679 m .3611 .87073 L .36145 .8755 L 0 1 .506 r
F
0 g
.36145 .8755 m
.36507 .87939 L
s
.54735 1.10154 m .54448 1.09365 L .55021 1.0985 L 0 .232 0 r
F
.54735 1.10154 m .53957 1.09064 L .54448 1.09365 L F
0 g
.54082 1.08934 m
.54448 1.09365 L
s
.46053 .9174 m .45011 .91544 L .45412 .92013 L 0 .655 .347 r
F
0 g
.45011 .91544 m
.45115 .91665 L
s
.44918 .91714 m
.45011 .91544 L
s
.59444 .64618 m
.59452 .64628 L
s
.59398 .64558 m
.59444 .64618 L
s
.58902 .63914 m
.59098 .64168 L
s
.59175 .64269 m
.59276 .644 L
s
.59388 .64545 m
.59398 .64558 L
s
.23585 .89955 m .22862 .90271 L .23319 .90287 L 0 1 .519 r
F
0 g
.23319 .90287 m
.23826 .90638 L
s
.23585 .89955 m .22437 .89894 L .22862 .90271 L 0 1 .519 r
F
0 g
.22691 .9062 m
.22862 .90271 L
s
.47822 .86531 m .46667 .84982 L .46989 .8578 L 0 .717 .316 r
F
0 g
.46293 .84993 m
.46667 .84982 L
s
.49352 .91276 m .49232 .91405 L .48926 .91373 L 0 .067 .058 r
F
.46414 .77616 m .45653 .77821 L .45998 .77621 L 0 .183 .049 r
F
.46414 .77616 m .45579 .78135 L .45653 .77821 L F
0 g
.46182 .77456 m
.4621 .77431 L
s
.46414 .77616 m .45826 .78353 L .45579 .78135 L 0 .183 .049 r
F
.46414 .77616 m .46244 .78348 L .45826 .78353 L F
0 g
.45998 .77621 m
.46182 .77456 L
s
.45998 .77621 m
.46049 .77621 L
s
.46414 .77616 m .46554 .78123 L .46244 .78348 L 0 .183 .049 r
F
.46414 .77616 m .46626 .7781 L .46554 .78123 L F
0 g
.46414 .77616 m
.46514 .77246 L
s
.46049 .77621 m
.46414 .77616 L
s
.22219 .74308 m .21087 .74085 L .21221 .74586 L 0 1 .538 r
F
0 g
.20771 .74973 m
.21221 .74586 L
s
.35044 .76624 m .34143 .76498 L .34557 .7658 L 0 .581 .244 r
F
0 g
.34557 .7658 m
.34743 .76698 L
s
.75707 .61655 m .77445 .62266 L .77317 .61942 L 0 1 .445 r
F
0 g
.77444 .62275 m
.77445 .62267 L
s
.36989 .61879 m .35991 .61006 L .3629 .61943 L 0 1 .407 r
F
.36989 .61879 m .36252 .59969 L .35991 .61006 L F
0 g
.70283 .66289 m
.70381 .66062 L
s
.70111 .66689 m
.70283 .66289 L
s
.70772 .65152 m .7115 .65978 L .7076 .66222 L 0 .183 .096 r
F
0 g
.7076 .66222 m
.70762 .66014 L
s
.70762 .66014 m
.70772 .65152 L
s
.70771 .65153 m
.70772 .65152 L
s
.70381 .66062 m
.70771 .65153 L
s
.70772 .65152 m .71766 .64738 L .7115 .65978 L 0 .183 .096 r
F
0 g
.70772 .65152 m
.70772 .65152 L
s
.40951 .58247 m .39993 .58391 L .40241 .58649 L 0 1 .449 r
F
.40951 .58247 m .4036 .5764 L .39993 .58391 L F
.40951 .58247 m .41098 .56897 L .4036 .5764 L F
.40951 .58247 m .41808 .56496 L .41098 .56897 L F
.40951 .58247 m .42018 .56705 L .41808 .56496 L F
0 g
.4165 .57455 m
.42018 .56705 L
s
.40612 .59037 m
.40951 .58247 L
s
.42018 .56705 m
.4273 .56275 L
s
.52081 .96994 m .5184 .96847 L .51679 .96759 L 0 .223 .181 r
F
.48788 .91911 m .48298 .91539 L .48621 .91698 L 0 .112 .061 r
F
.49058 .91596 m .48621 .91698 L .48298 .91539 L 0 .09 .059 r
F
0 g
.48167 .91317 m
.48298 .91539 L
s
.4811 .91529 m
.48298 .91539 L
s
.48302 .93913 m .47558 .93881 L .4791 .9402 L 0 .703 .447 r
F
.48302 .93913 m .47374 .93702 L .47558 .93881 L F
0 g
.47481 .94028 m
.47558 .93881 L
s
.59709 .648 m .59745 .65288 L .59501 .64691 L 0 .421 .012 r
F
0 g
.59543 .64713 m
.59557 .64721 L
s
.59501 .64691 m
.59543 .64713 L
s
.59452 .64628 m
.59501 .64691 L
s
.59709 .648 m .60352 .6638 L .59745 .65288 L 0 .421 .012 r
F
.59709 .648 m .60916 .67236 L .60352 .6638 L F
0 g
.60397 .65333 m
.60731 .66256 L
s
.59709 .648 m .61123 .67342 L .60916 .67236 L 0 .421 .012 r
F
.59709 .648 m .60837 .6663 L .61123 .67342 L F
.59709 .648 m .60231 .65541 L .60837 .6663 L F
0 g
.60731 .66256 m
.60989 .66969 L
s
.59557 .64721 m
.59709 .648 L
s
.60231 .65541 m
.60338 .65407 L
s
.49203 .866 m .48224 .83361 L .48156 .83721 L 0 .662 .301 r
F
.49203 .866 m .48577 .84016 L .48224 .83361 L F
0 g
.47977 .82368 m
.48224 .83361 L
s
.48224 .83361 m
.4834 .83576 L
s
.68625 .61877 m
.69373 .61864 L
s
.69374 .61864 m .69601 .61626 L .69235 .61719 L 0 .788 .263 r
F
.69374 .61864 m .70309 .61664 L .69601 .61626 L F
0 g
.69235 .61719 m
.69374 .61864 L
s
.5096 .96157 m .50631 .96117 L .50872 .96263 L 0 .318 .223 r
F
.5096 .96157 m .50501 .95977 L .50631 .96117 L F
0 g
.50399 .9604 m
.50631 .96117 L
s
.36189 .63504 m .3599 .61026 L .35605 .61241 L 0 .847 .32 r
F
.36189 .63504 m .3629 .61953 L .3599 .61026 L F
0 g
.78501 .62205 m
.78503 .62206 L
s
.78503 .62206 m
.78505 .62208 L
s
.78505 .62208 m
.78633 .62276 L
s
.78633 .62276 m
.78645 .62283 L
s
.78645 .62283 m
.788 .62366 L
s
.28371 .90749 m
.28371 .90749 L
s
.42013 .89376 m .41253 .89478 L .41712 .89555 L 0 1 .494 r
F
.42013 .89376 m .40859 .8916 L .41253 .89478 L F
0 g
.4099 .89674 m
.41253 .89478 L
s
.6808 .62 m
.68178 .61994 L
s
.46795 .96989 m .45798 .96583 L .46053 .9714 L 0 .491 .354 r
F
.46795 .96989 m .45848 .96132 L .45798 .96583 L F
0 g
.45366 .96206 m
.45798 .96583 L
s
.53687 1.09088 m .53957 1.09064 L .53873 1.09146 L 0 .193 0 r
F
0 g
.53885 1.08894 m
.53957 1.09064 L
s
.54735 1.10154 m .53874 1.09147 L .53957 1.09064 L 0 .232 0 r
F
0 g
.53957 1.09064 m
.54448 1.09365 L
s
.31578 .76023 m
.31581 .76026 L
s
.31581 .76026 m
.31616 .76074 L
s
.31616 .76074 m
.31701 .76063 L
s
.57284 .87073 m .57576 .75156 L .57298 .8062 L 0 .924 .229 r
F
.56613 .82717 m .57298 .8062 L .57576 .75156 L 0 .966 .238 r
F
0 g
.5757 .71755 m
.57576 .75156 L
s
.57576 .75156 m
.57832 .7202 L
s
.56936 .83987 m
.56946 .82581 L
s
.56946 .82581 m
.56953 .81676 L
s
.56947 .75259 m
.57119 .7392 L
s
.74978 1.06669 m .76111 1.06214 L .75712 1.06405 L 0 0 0 r
F
.73998 1.07157 m .74978 1.06669 L .75113 1.06711 L F
.45786 .94295 m .45611 .9375 L .45191 .93336 L 0 .614 .36 r
F
.46662 .88519 m .45508 .87814 L .45876 .8841 L 0 .708 .331 r
F
0 g
.45508 .87814 m
.45579 .87929 L
s
.45187 .88064 m
.45508 .87814 L
s
.58348 .63473 m .58284 .63965 L .58083 .63494 L 0 .378 .044 r
F
0 g
.63538 .53418 m
.63688 .5364 L
s
.62849 .52404 m
.63353 .53145 L
s
.63353 .53145 m
.63513 .53382 L
s
.63513 .53382 m
.63538 .53418 L
s
.45006 .92035 m .44022 .92101 L .43813 .92001 L 0 0 0 r
F
.49305 .62805 m .49887 .62597 L .50298 .62525 L F
0 g
.49887 .62597 m
.50173 .62436 L
s
.47111 .93428 m .46944 .93243 L .46553 .9309 L 0 .866 .477 r
F
.50211 .91767 m .49914 .91102 L .5012 .91439 L 0 .137 .078 r
F
.50432 .91522 m .5012 .91439 L .49914 .91102 L 0 .124 .078 r
F
0 g
.49851 .91063 m
.49914 .91102 L
s
.49861 .90748 m
.49914 .91102 L
s
.79339 1.04528 m .80476 1.03891 L .80058 1.04069 L 0 1 .27 r
F
.7831 1.0499 m .79339 1.04528 L .79432 1.04353 L 0 .961 .237 r
F
0 g
.64446 .73336 m
.64448 .7503 L
s
.64448 .75254 m
.64449 .7616 L
s
.42518 .91996 m .4149 .91987 L .41273 .9194 L 0 0 0 r
F
.25075 .93302 m .23889 .92979 L .23719 .93085 L 0 .672 .25 r
F
.25075 .93302 m .24348 .93018 L .23889 .92979 L F
.25075 .93302 m .24856 .93157 L .24348 .93018 L F
.26203 .93344 m .24856 .93157 L .25075 .93302 L 0 .639 .239 r
F
0 g
.24903 .93406 m
.25075 .93302 L
s
.25075 .93302 m
.25574 .93415 L
s
.54228 .78329 m
.54232 .78587 L
s
.45812 .90443 m .45117 .90647 L .45549 .90754 L 0 .697 .346 r
F
.46053 .9174 m .45549 .90754 L .45117 .90647 L 0 .655 .347 r
F
0 g
.44887 .90986 m
.45117 .90647 L
s
.44824 .90273 m
.45117 .90647 L
s
.51638 1.07197 m .52049 1.07572 L .52023 1.07584 L 0 .058 .167 r
F
.5285 1.08542 m .52023 1.07584 L .52049 1.07572 L 0 .114 0 r
F
0 g
.52049 1.07572 m
.52466 1.07935 L
s
.51669 1.07198 m
.52049 1.07572 L
s
.65632 .72369 m
.65641 .72449 L
s
.65685 .72878 m
.65708 .731 L
s
.65708 .731 m
.65728 .73294 L
s
.65728 .73294 m
.65776 .73761 L
s
.65776 .73761 m
.65818 .74164 L
s
.65818 .74164 m
.65831 .74291 L
s
.65575 .7182 m
.65632 .72369 L
s
.65387 .69996 m
.65575 .7182 L
s
.39287 .60316 m .39938 .59474 L .40241 .58649 L 0 1 .439 r
F
0 g
.39938 .59474 m
.40612 .59037 L
s
.30336 .77084 m .28943 .77022 L .29185 .77761 L 0 1 .454 r
F
0 g
.28659 .78461 m
.29185 .77761 L
s
.36828 .67151 m .37314 .66011 L .37434 .64972 L 0 1 .39 r
F
0 g
.37314 .66011 m
.37922 .65332 L
s
.47898 .85577 m .47069 .84666 L .47525 .85348 L 0 .737 .315 r
F
.47822 .86531 m .47525 .85348 L .47069 .84666 L 0 .717 .316 r
F
0 g
.46768 .83802 m
.47069 .84666 L
s
.46997 .84636 m
.47069 .84666 L
s
.79856 .78865 m .80635 .79263 L .80168 .7917 L 0 0 0 r
F
.79856 .78865 m .81026 .79158 L .80635 .79263 L F
0 g
.476 .50692 m
.48215 .50142 L
s
.46878 .51134 m
.476 .50692 L
s
.70855 .89699 m .7182 .89684 L .71931 .89609 L 0 .602 .209 r
F
0 g
.71419 .89736 m
.7182 .89684 L
s
.7182 .89684 m
.72057 .89743 L
s
.33908 .67684 m .33443 .66983 L .32978 .67262 L 0 1 .519 r
F
.33908 .67684 m .34059 .66929 L .33443 .66983 L F
.33908 .67684 m .34415 .67135 L .34059 .66929 L F
.33908 .67684 m .3435 .67459 L .34415 .67135 L F
0 g
.33862 .67944 m
.33908 .67684 L
s
.33294 .67738 m
.33908 .67684 L
s
.50002 .92017 m .49352 .91276 L .49627 .91407 L 0 .152 .079 r
F
.50002 .92017 m .49232 .91405 L .49352 .91276 L F
0 g
.49256 .91038 m
.49352 .91276 L
s
.49352 .91276 m
.49524 .91358 L
s
.48302 .93913 m .47478 .93587 L .47374 .93702 L 0 .703 .447 r
F
0 g
.46994 .93569 m
.47374 .93702 L
s
.48215 .50142 m .49755 .4897 L .49712 .48908 L 0 1 .215 r
F
0 g
.49755 .4897 m
.50464 .48571 L
s
.49114 .49498 m
.49755 .4897 L
s
.39287 .60316 m .38305 .60345 L .38587 .6069 L 0 1 .439 r
F
.39287 .60316 m .38607 .5952 L .38305 .60345 L F
.39287 .60316 m .39293 .58764 L .38607 .5952 L F
.39287 .60316 m .39993 .58391 L .39293 .58764 L F
.39287 .60316 m .40241 .58649 L .39993 .58391 L F
0 g
.39938 .59474 m
.40241 .58649 L
s
.3901 .61181 m
.39287 .60316 L
s
.40241 .58649 m
.40951 .58247 L
s
.40859 .8916 m .39927 .88397 L .39633 .88615 L 0 1 .499 r
F
0 g
.39633 .88615 m
.398 .88491 L
s
.27512 .66668 m .26456 .66328 L .2641 .66987 L 0 1 .519 r
F
0 g
.25804 .67455 m
.2641 .66987 L
s
.32978 .67262 m .3176 .67057 L .32257 .67293 L 0 1 .5 r
F
0 g
.32978 .67262 m
.32978 .67262 L
s
.32915 .67585 m
.32978 .67262 L
s
.32257 .67293 m
.32341 .67796 L
s
.48788 .91911 m .47986 .91864 L .4782 .91652 L 0 .112 .061 r
F
0 g
.47452 .91684 m
.4782 .91652 L
s
.33102 .91195 m .32116 .90754 L .31901 .9091 L 0 1 .424 r
F
.33102 .91195 m .32545 .90791 L .32116 .90754 L F
.33102 .91195 m .32968 .9098 L .32545 .90791 L F
.3416 .91247 m .32968 .9098 L .33102 .91195 L 0 .999 .394 r
F
0 g
.32886 .9135 m
.33102 .91195 L
s
.33102 .91195 m
.33517 .91365 L
s
.50504 .83688 m .50597 .83657 L .50571 .81923 L 0 .637 .28 r
F
.36252 .59955 m .37108 .58889 L .36735 .58495 L 0 1 .501 r
F
.36252 .59955 m .36901 .59515 L .37108 .58889 L F
0 g
.3601 .59865 m
.36252 .59955 L
s
.46614 .87342 m .45802 .87127 L .46268 .87452 L 0 .739 .33 r
F
.46662 .88519 m .46268 .87452 L .45802 .87127 L 0 .708 .331 r
F
0 g
.45682 .87184 m
.45802 .87127 L
s
.45515 .86606 m
.45802 .87127 L
s
.4647 .63997 m .45747 .64255 L .45923 .64218 L 0 .796 .19 r
F
.4647 .63997 m .46065 .64099 L .45747 .64255 L F
0 g
.45657 .64396 m
.45923 .64218 L
s
.4647 .63997 m .46665 .63855 L .46065 .64099 L 0 .796 .19 r
F
.4647 .63997 m .47213 .63634 L .46665 .63855 L F
.4647 .63997 m .47343 .63584 L .47213 .63634 L F
.4647 .63997 m .47024 .6374 L .47343 .63584 L F
0 g
.46187 .64153 m
.4647 .63997 L
s
.45923 .64218 m
.4647 .63997 L
s
.47024 .6374 m
.47537 .63496 L
s
.33033 .74833 m .32088 .75503 L .32504 .75539 L 0 1 .432 r
F
0 g
.32504 .75539 m
.3266 .76274 L
s
.30336 .77084 m .29182 .76059 L .28943 .77022 L 0 1 .454 r
F
0 g
.29746 .77784 m
.30336 .77084 L
s
.28943 .77022 m
.29185 .77761 L
s
.5096 .96157 m .50872 .96263 L .51068 .96341 L 0 .318 .223 r
F
0 g
.50872 .96263 m
.51037 .96401 L
s
.8015 .89039 m .8108 .8866 L .8062 .887 L 0 1 .49 r
F
.79004 .89111 m .8015 .89039 L .79929 .88762 L 0 1 .475 r
F
.51745 .92369 m .52076 .90112 L .52168 .9006 L 0 .232 .104 r
F
0 g
.5176 .90251 m
.51836 .89808 L
s
.51723 .90267 m
.5175 .89879 L
s
.51944 .90171 m
.52109 .8959 L
s
.51836 .89807 m
.5184 .9022 L
s
.51745 .92369 m .51904 .90814 L .52076 .90112 L 0 .232 .104 r
F
0 g
.52076 .90112 m
.52109 .8959 L
s
.36989 .61879 m .36901 .59521 L .36252 .59969 L 0 1 .407 r
F
0 g
.35991 .61006 m
.36252 .59969 L
s
.42518 .91996 m .41938 .92034 L .4149 .91987 L 0 0 0 r
F
.42518 .91996 m .42378 .92038 L .41938 .92034 L F
.43608 .92109 m .42378 .92038 L .42518 .91996 L F
0 g
.42518 .91996 m
.42945 .91992 L
s
.423 .91949 m
.42518 .91996 L
s
.43375 .92029 m
.43813 .92001 L
s
.21087 .74085 m .20082 .74396 L .20538 .74471 L 0 1 .539 r
F
0 g
.20538 .74471 m
.20771 .74973 L
s
.3673 .68121 m
.36767 .67749 L
s
.36767 .67749 m
.36768 .67738 L
s
.51745 .92369 m .52168 .9006 L .521 .90721 L 0 .232 .104 r
F
0 g
.52168 .9006 m
.5218 .9002 L
s
.44711 .91205 m .43752 .90623 L .43504 .90753 L 0 1 .489 r
F
0 g
.4308 .90501 m
.43504 .90753 L
s
.41068 .91956 m .40372 .91892 L .40819 .91926 L 0 0 0 r
F
.41068 .91956 m .39941 .91849 L .40372 .91892 L F
0 g
.40169 .91878 m
.40372 .91892 L
s
.40819 .91926 m
.41273 .9194 L
s
.2879 .52455 m
.28816 .52375 L
s
.28509 .53306 m
.2879 .52455 L
s
.28509 .53306 m
.29354 .52505 L
s
.49305 .62805 m .48724 .63089 L .48807 .63015 L 0 0 0 r
F
0 g
.48743 .62982 m
.4893 .62888 L
s
.49305 .62805 m .49136 .63016 L .48724 .63089 L 0 0 0 r
F
.49305 .62805 m .49766 .62847 L .49136 .63016 L F
.49305 .62805 m .50265 .62636 L .49766 .62847 L F
.49305 .62805 m .50298 .62525 L .50265 .62636 L F
0 g
.4893 .62888 m
.49305 .62805 L
s
.50298 .62525 m
.50763 .62311 L
s
.49887 .62597 m
.50298 .62525 L
s
.25609 .75014 m .24732 .74301 L .2448 .74773 L 0 1 .526 r
F
.25609 .75014 m .25255 .74041 L .24732 .74301 L F
.25609 .75014 m .257 .74169 L .25255 .74041 L F
.25609 .75014 m .25851 .74586 L .257 .74169 L F
0 g
.25087 .75272 m
.25609 .75014 L
s
.25609 .75014 m
.25768 .75398 L
s
.35044 .76624 m .34019 .76397 L .34143 .76498 L 0 .581 .244 r
F
0 g
.33701 .76519 m
.34143 .76498 L
s
.51628 .92379 m .51935 .902 L .51904 .90814 L 0 .224 .102 r
F
.51628 .92379 m .5184 .90264 L .51935 .902 L F
0 g
.51633 .90375 m
.51653 .9029 L
s
.51935 .902 m
.51944 .90171 L
s
.50279 .83841 m .50368 .83767 L .50304 .82113 L 0 .646 .284 r
F
0 g
.61588 .68157 m
.61696 .68536 L
s
.61771 .68798 m
.61772 .68802 L
s
.61772 .68802 m
.618 .68902 L
s
.618 .68902 m
.61804 .68916 L
s
.62124 .70034 m
.62182 .70237 L
s
.61849 .69071 m
.62124 .70034 L
s
.6149 .68136 m
.61575 .68155 L
s
.61486 .68135 m
.6149 .68136 L
s
.61483 .68135 m
.61486 .68135 L
s
.61477 .68133 m
.61483 .68135 L
s
.61575 .68155 m
.61588 .68157 L
s
.40859 .8916 m .40394 .88485 L .39927 .88397 L 0 1 .499 r
F
.40859 .8916 m .40794 .88813 L .40394 .88485 L F
.42013 .89376 m .40794 .88813 L .40859 .8916 L 0 1 .494 r
F
0 g
.40859 .8916 m
.41253 .89478 L
s
.40564 .89377 m
.40859 .8916 L
s
.60231 .65541 m
.60275 .65621 L
s
.60635 .66266 m
.60641 .66277 L
s
.60275 .65621 m
.60635 .66266 L
s
.46349 .93027 m .45217 .92376 L .45367 .92928 L 0 .609 .346 r
F
.46349 .93027 m .45412 .92013 L .45217 .92376 L F
0 g
.44899 .92042 m
.45217 .92376 L
s
.45217 .92376 m
.45407 .92021 L
s
.45219 .92131 m
.45396 .92022 L
s
.79218 .63251 m .80918 .65645 L .80837 .64557 L 0 1 .449 r
F
0 g
.80918 .65645 m
.81558 .66673 L
s
.76052 .79344 m .77125 .78235 L .77363 .78925 L 0 .227 .057 r
F
0 g
.77125 .78235 m
.77512 .78028 L
s
.31578 .76023 m
.31612 .76191 L
s
.31612 .76191 m
.317 .76064 L
s
.317 .76064 m
.31701 .76063 L
s
.31701 .76063 m
.31715 .76043 L
s
.50406 .47507 m .51369 .4729 L .52103 .4728 L 0 0 0 r
F
0 g
.49716 .47489 m
.50406 .47507 L
s
.50739 .83649 m .50834 .83668 L .50846 .81862 L 0 .629 .277 r
F
.49203 .866 m .48156 .83721 L .48423 .84826 L 0 .662 .301 r
F
0 g
.48336 .82829 m
.48561 .83938 L
s
.47982 .8354 m
.48156 .83721 L
s
.51857 .92384 m .52303 .89992 L .52391 .89955 L 0 .239 .107 r
F
.51857 .92384 m .521 .90721 L .52303 .89992 L F
0 g
.52303 .89992 m
.52373 .89398 L
s
.5207 .90134 m
.52076 .90112 L
s
.51934 .90225 m
.51935 .902 L
s
.52299 .90007 m
.52303 .89992 L
s
.36828 .67151 m .37434 .64972 L .37108 .64726 L 0 1 .39 r
F
0 g
.37314 .66011 m
.37434 .64972 L
s
.46614 .87342 m .46608 .8687 L .46253 .86224 L 0 .739 .33 r
F
.51628 .92379 m .51702 .90935 L .5184 .90264 L 0 .224 .102 r
F
0 g
.51762 .90642 m
.51832 .90303 L
s
.51832 .90303 m
.51838 .90277 L
s
.51838 .90277 m
.5184 .90264 L
s
.5184 .9022 m
.5184 .90264 L
s
.51747 .90324 m
.5176 .90251 L
s
.51717 .9034 m
.51723 .90267 L
s
.34802 .72504 m .3384 .73166 L .3424 .73223 L 0 1 .415 r
F
0 g
.3424 .73223 m
.34334 .73991 L
s
.34802 .72504 m .33815 .72348 L .3384 .73166 L 0 1 .415 r
F
.34802 .72504 m .34184 .71315 L .33815 .72348 L F
.34802 .72504 m .34746 .70596 L .34184 .71315 L F
.34802 .72504 m .35127 .7067 L .34746 .70596 L F
.34802 .72504 m .35151 .71488 L .35127 .7067 L F
0 g
.34802 .72504 m
.3484 .73324 L
s
.3424 .73223 m
.34802 .72504 L
s
.44216 .53932 m .45031 .53196 L .45548 .52549 L 0 1 .414 r
F
0 g
.45031 .53196 m
.45735 .52744 L
s
.45812 .90443 m .45732 .89921 L .45336 .89416 L 0 .697 .346 r
F
.24733 .90019 m .24005 .90311 L .24462 .90328 L 0 1 .515 r
F
0 g
.24462 .90328 m
.24961 .90659 L
s
.24733 .90019 m .23585 .89955 L .24005 .90311 L 0 1 .515 r
F
0 g
.23826 .90638 m
.24005 .90311 L
s
.43353 .90345 m .42401 .89687 L .42129 .89843 L 0 1 .493 r
F
0 g
.41712 .89555 m
.42129 .89843 L
s
.35151 .71488 m
.35698 .70801 L
s
.67338 1.08308 m .68359 1.0834 L .68029 1.08466 L 0 0 0 r
F
.6653 1.08576 m .67338 1.08308 L .67532 1.0866 L 0 .079 0 r
F
.37267 .87679 m .36423 .86768 L .3611 .87073 L 0 1 .506 r
F
.37267 .87679 m .36874 .86839 L .36423 .86768 L F
.37267 .87679 m .37236 .87229 L .36874 .86839 L F
.3839 .87837 m .37236 .87229 L .37267 .87679 L 0 1 .502 r
F
0 g
.36955 .87982 m
.37267 .87679 L
s
.37267 .87679 m
.37626 .88056 L
s
.39559 .88039 m .3876 .88205 L .39227 .88277 L 0 1 .498 r
F
0 g
.39227 .88277 m
.39633 .88615 L
s
.39559 .88039 m .3839 .87837 L .3876 .88205 L 0 1 .498 r
F
0 g
.38721 .8824 m
.3876 .88205 L
s
.49639 1.04245 m .49008 1.03884 L .49434 1.04425 L 0 .216 .262 r
F
.49639 1.04245 m .48774 1.03419 L .49008 1.03884 L F
0 g
.48603 1.03536 m
.49008 1.03884 L
s
.4195 .6616 m .41072 .66426 L .41359 .66395 L 0 1 .285 r
F
.4195 .6616 m .41259 .66236 L .41072 .66426 L F
0 g
.41232 .66577 m
.41359 .66395 L
s
.4195 .6616 m .41797 .6595 L .41259 .66236 L 0 1 .285 r
F
.4195 .6616 m .42389 .65715 L .41797 .6595 L F
.4195 .6616 m .4264 .65686 L .42389 .65715 L F
.4195 .6616 m .42452 .65877 L .4264 .65686 L F
0 g
.41359 .66395 m
.4195 .6616 L
s
.47784 .87498 m .4663 .8569 L .46615 .86162 L 0 .694 .317 r
F
.47784 .87498 m .46989 .8578 L .4663 .8569 L F
0 g
.46293 .84993 m
.4663 .8569 L
s
.4663 .8569 m
.46898 .85757 L
s
.3628 .91395 m .35622 .91449 L .36044 .91473 L 0 .755 .308 r
F
0 g
.36044 .91473 m
.36487 .91578 L
s
.3628 .91395 m .3522 .91314 L .35622 .91449 L 0 .755 .308 r
F
0 g
.35444 .9154 m
.35622 .91449 L
s
.33033 .74833 m .32003 .74741 L .32088 .75503 L 0 1 .432 r
F
0 g
.31715 .76043 m
.32088 .75503 L
s
.33033 .74833 m .32306 .7376 L .32003 .74741 L 0 1 .432 r
F
.33033 .74833 m .32836 .73053 L .32306 .7376 L F
.33033 .74833 m .33238 .73093 L .32836 .73053 L F
.33033 .74833 m .33322 .73856 L .33238 .73093 L F
0 g
.33033 .74833 m
.33127 .756 L
s
.32504 .75539 m
.33033 .74833 L
s
.51533 .92401 m .51747 .90329 L .51702 .90935 L 0 .223 .101 r
F
.51533 .92401 m .51717 .90351 L .51747 .90329 L F
0 g
.51737 .90763 m
.51762 .90642 L
s
.51747 .90329 m
.51747 .90324 L
s
.51746 .90338 m
.51747 .90329 L
s
.51721 .90669 m
.51746 .90338 L
s
.71247 .61462 m .72596 .61755 L .72992 .61704 L 0 1 .352 r
F
.71247 .61462 m .71849 .61652 L .72596 .61755 L F
0 g
.72596 .61755 m
.72679 .61955 L
s
.51857 .92384 m .52391 .89955 L .52288 .90662 L 0 .239 .107 r
F
0 g
.51914 .90625 m
.51934 .90225 L
s
.5206 .90175 m
.5207 .90134 L
s
.52164 .90102 m
.52168 .9006 L
s
.52391 .89955 m
.52401 .89924 L
s
.3775 .62781 m .38349 .61734 L .38587 .6069 L 0 1 .4 r
F
0 g
.38349 .61734 m
.3901 .61181 L
s
.47014 .77722 m
.47017 .77702 L
s
.46626 .7781 m
.47017 .77702 L
s
.51533 .92401 m .51638 .90977 L .51717 .90351 L 0 .223 .101 r
F
0 g
.51652 .90867 m
.51716 .90355 L
s
.51716 .90355 m
.51717 .90351 L
s
.51626 .90405 m
.51633 .90375 L
s
.51717 .90351 m
.51717 .9034 L
s
.5676 .68782 m .56806 .68282 L .566 .68959 L 0 .81 .096 r
F
.5676 .68782 m .57306 .67154 L .56806 .68282 L F
.56222 .71419 m .5676 .68782 L .56294 .70232 L 0 1 .19 r
F
0 g
.5643 .69808 m
.5676 .68782 L
s
.46795 .96989 m .46053 .9714 L .46458 .97508 L 0 .491 .354 r
F
0 g
.4603 .9761 m
.46053 .9714 L
s
.45009 .91789 m .44881 .91558 L .44462 .91335 L 0 1 .492 r
F
.46358 .91924 m .45822 .92079 L .45412 .92013 L 0 0 .007 r
F
.46053 .9174 m .45412 .92013 L .45822 .92079 L 0 .655 .347 r
F
.46051 .91976 m .45009 .91789 L .45412 .92013 L 0 .938 .481 r
F
.46051 .91976 m .44881 .91558 L .45009 .91789 L F
0 g
.44827 .91914 m
.45009 .91789 L
s
.45009 .91789 m
.45322 .91963 L
s
.53453 .97901 m .53285 .97616 L .53595 .97733 L 0 .024 0 r
F
0 g
.53488 .97605 m
.53595 .97733 L
s
.47868 .63371 m .4844 .63136 L .48807 .63015 L 0 0 0 r
F
0 g
.4844 .63136 m
.48743 .62982 L
s
.49463 .85476 m .48759 .83239 L .49135 .84603 L 0 .668 .297 r
F
.49323 .86016 m .49135 .84603 L .48759 .83239 L 0 .666 .299 r
F
0 g
.48417 .82481 m
.48759 .83239 L
s
.48712 .82958 m
.48759 .83239 L
s
.49108 .9469 m .48876 .94841 L .49081 .9482 L 0 .572 .41 r
F
.49547 .95065 m .49081 .9482 L .48876 .94841 L 0 .486 .378 r
F
0 g
.48876 .94841 m
.48889 .94976 L
s
.48563 .94733 m
.48876 .94841 L
s
.48218 1.01259 m .47429 1.00941 L .47784 1.01492 L 0 .314 .335 r
F
.48218 1.01259 m .47316 1.00461 L .47429 1.00941 L F
0 g
.47011 1.00595 m
.47429 1.00941 L
s
.79559 .62126 m
.80228 .6189 L
s
.49547 .95065 m .49399 .9523 L .4956 .952 L 0 .486 .378 r
F
.50006 .95433 m .4956 .952 L .49399 .9523 L 0 .42 .334 r
F
0 g
.49399 .9523 m
.49452 .95368 L
s
.49111 .95134 m
.49399 .9523 L
s
.47868 .63371 m .47213 .63634 L .47343 .63584 L 0 0 0 r
F
.47868 .63371 m .47579 .63513 L .47213 .63634 L F
0 g
.47024 .6374 m
.473 .63605 L
s
.47868 .63371 m .48198 .63302 L .47579 .63513 L 0 0 0 r
F
.47868 .63371 m .48724 .63089 L .48198 .63302 L F
.47868 .63371 m .48807 .63015 L .48724 .63089 L F
0 g
.4844 .63136 m
.48807 .63015 L
s
.47537 .63496 m
.47868 .63371 L
s
.48807 .63015 m
.49305 .62805 L
s
.76248 1.06105 m .76111 1.06214 L .76781 1.05832 L 0 .801 .187 r
F
.76248 1.06105 m .75712 1.06405 L .76111 1.06214 L F
0 g
.75957 1.06239 m
.7603 1.06227 L
s
.47898 .85577 m .47938 .85199 L .47636 .84334 L 0 .737 .315 r
F
.21087 .74085 m .19953 .73868 L .20082 .74396 L 0 1 .539 r
F
0 g
.19629 .74811 m
.20082 .74396 L
s
.46759 .89694 m .45574 .88607 L .4563 .89134 L 0 .674 .332 r
F
.46759 .89694 m .45876 .8841 L .45574 .88607 L F
0 g
.45473 .88466 m
.45574 .88607 L
s
.45336 .89416 m
.45624 .89783 L
s
.45574 .88607 m
.45749 .88493 L
s
.48215 .50142 m .47358 .50415 L .47462 .50536 L 0 1 .215 r
F
.48215 .50142 m .48 .49885 L .47358 .50415 L F
.48215 .50142 m .48961 .49299 L .48 .49885 L F
.48215 .50142 m .49712 .48908 L .48961 .49299 L F
.81551 1.02718 m .82169 1.02889 L .82623 1.0225 L 0 1 .386 r
F
0 g
.81518 1.03483 m
.82169 1.02889 L
s
.36371 .67705 m .35843 .67652 L .36201 .67722 L 0 .822 .243 r
F
.36391 .6768 m .36056 .67654 L .36371 .67705 L 0 1 .39 r
F
.36828 .67151 m .36056 .67654 L .36391 .6768 L F
.36828 .67151 m .3596 .66754 L .35858 .67638 L F
.36056 .67654 m .35858 .67638 L .35843 .67652 L 0 .822 .243 r
F
.36056 .67654 m .35843 .67652 L .36371 .67705 L F
.36056 .67654 m .35858 .67638 L .3584 .67794 L 0 1 .39 r
F
.36828 .67151 m .35858 .67638 L .36056 .67654 L F
.36056 .67654 m .35858 .67638 L .35858 .67638 L 0 .822 .243 r
F
.36816 .67659 m .3594 .6756 L .35858 .67638 L F
.36816 .67659 m .35858 .67638 L .36056 .67654 L F
.36816 .67659 m .36056 .67654 L .36371 .67705 L F
.36371 .67705 m .3584 .67794 L .36196 .67916 L 0 1 .39 r
F
.36056 .67654 m .3584 .67794 L .36371 .67705 L F
0 g
.36768 .67738 m
.36771 .6771 L
s
.36771 .6771 m
.36776 .67663 L
s
.3617 .67956 m
.36176 .67909 L
s
.36828 .67151 m .36477 .65489 L .3596 .66754 L 0 1 .39 r
F
.36828 .67151 m .37108 .64726 L .36477 .65489 L F
0 g
.36443 .67617 m
.36828 .67151 L
s
.36777 .67654 m
.36828 .67151 L
s
.48696 1.02866 m .48327 1.02317 L .47931 1.0197 L 0 .291 .321 r
F
.56913 .62722 m .57496 .62962 L .58083 .63494 L 0 .301 .048 r
F
.50898 .91051 m .50803 .91143 L .50644 .90897 L 0 .105 .078 r
F
0 g
.50644 .90897 m
.50704 .9099 L
s
.50065 .84094 m .50149 .83981 L .50049 .82413 L 0 .654 .287 r
F
0 g
.50134 .8375 m
.50143 .83886 L
s
.50049 .82413 m
.50134 .8375 L
s
.50049 .82413 m
.50267 .83766 L
s
.36069 .76809 m .3528 .76601 L .35044 .76624 L 0 .548 .227 r
F
.36069 .76809 m .35759 .76652 L .3528 .76601 L F
.36069 .76809 m .36159 .76743 L .35759 .76652 L F
.36069 .76809 m .36291 .7681 L .36159 .76743 L F
0 g
.35592 .76758 m
.36069 .76809 L
s
.36069 .76809 m
.36213 .76846 L
s
.54877 .62026 m
.55417 .62358 L
s
.54497 .62272 m
.54877 .62026 L
s
.47944 .9351 m .47111 .93428 L .47478 .93587 L 0 .75 .456 r
F
.47944 .9351 m .46944 .93243 L .47111 .93428 L F
0 g
.46994 .93569 m
.47111 .93428 L
s
.5147 .92426 m .51622 .90424 L .51638 .90977 L 0 .216 .099 r
F
.5147 .92426 m .51526 .90499 L .51622 .90424 L F
0 g
.51622 .90424 m
.51626 .90405 L
s
.51622 .90424 m
.51635 .90864 L
s
.68698 1.09143 m .68359 1.0834 L .69018 1.08425 L 0 .014 .006 r
F
0 g
.68931 1.08135 m
.69018 1.08425 L
s
.68698 1.09143 m .68029 1.08466 L .68359 1.0834 L 0 .014 .006 r
F
0 g
.68142 1.08056 m
.68359 1.0834 L
s
.51964 .92426 m .5252 .89912 L .52603 .89893 L 0 .245 .11 r
F
.51964 .92426 m .52288 .90662 L .5252 .89912 L F
0 g
.5252 .89912 m
.52626 .8924 L
s
.52381 .90023 m
.52391 .89955 L
s
.46349 .93027 m .45367 .92928 L .45769 .93363 L 0 .609 .346 r
F
0 g
.45191 .93336 m
.45367 .92928 L
s
.64585 .76401 m
.64594 .76361 L
s
.64594 .76361 m
.64604 .76314 L
s
.64604 .76314 m
.64691 .75919 L
s
.48691 .94306 m .48377 .94438 L .48625 .94429 L 0 .644 .432 r
F
.49108 .9469 m .48625 .94429 L .48377 .94438 L 0 .572 .41 r
F
0 g
.48351 .94568 m
.48377 .94438 L
s
.48043 .94315 m
.48377 .94438 L
s
.3775 .62781 m .38587 .6069 L .38305 .60345 L 0 1 .4 r
F
0 g
.38587 .6069 m
.39287 .60316 L
s
.38349 .61734 m
.38587 .6069 L
s
.46264 .95648 m .45848 .96132 L .4617 .96087 L 0 .557 .358 r
F
.46795 .96989 m .4617 .96087 L .45848 .96132 L 0 .491 .354 r
F
0 g
.45798 .96583 m
.45848 .96132 L
s
.45433 .95743 m
.45848 .96132 L
s
.79004 .89111 m .79929 .88762 L .79468 .88803 L 0 1 .475 r
F
.77858 .89186 m .79004 .89111 L .78777 .88865 L 0 1 .454 r
F
.50979 .8374 m .51077 .83816 L .51125 .81953 L 0 .621 .273 r
F
.51445 .9652 m .51235 .96482 L .51477 .96627 L 0 .244 .203 r
F
.51445 .9652 m .51068 .96341 L .51235 .96482 L F
0 g
.51037 .96401 m
.51235 .96482 L
s
.5147 .92426 m .51433 .91126 L .51526 .90499 L 0 .216 .099 r
F
0 g
.51523 .90519 m
.51526 .90499 L
s
.51385 .90594 m
.51474 .90118 L
s
.51522 .90472 m
.51526 .90499 L
s
.50006 .95433 m .49943 .95608 L .50058 .95571 L 0 .42 .334 r
F
.50478 .95796 m .50058 .95571 L .49943 .95608 L 0 .376 .277 r
F
0 g
.49943 .95608 m
.50034 .95747 L
s
.49683 .95521 m
.49943 .95608 L
s
.30573 .7582 m
.30804 .75777 L
s
.30382 .75604 m
.30398 .75623 L
s
.30398 .75623 m
.30414 .7564 L
s
.30414 .7564 m
.30573 .7582 L
s
.3775 .62781 m .36751 .62923 L .37065 .63291 L 0 1 .4 r
F
.3775 .62781 m .36989 .61879 L .36751 .62923 L F
.3775 .62781 m .3762 .60854 L .36989 .61879 L F
.3775 .62781 m .38305 .60345 L .3762 .60854 L F
0 g
.37537 .63783 m
.3775 .62781 L
s
.37065 .63291 m
.3775 .62781 L
s
.61746 .76283 m
.61761 .73607 L
s
.43024 .6564 m
.43234 .65452 L
s
.42452 .65877 m
.42453 .65876 L
s
.42453 .65876 m
.43024 .6564 L
s
.50514 1.05784 m .5008 1.05239 L .49704 1.04875 L 0 .151 .194 r
F
.47784 .87498 m .46615 .86162 L .46955 .86898 L 0 .694 .317 r
F
0 g
.46253 .86224 m
.46615 .86162 L
s
.39718 .77266 m .38815 .77143 L .39232 .77173 L 0 0 0 r
F
0 g
.39232 .77173 m
.3941 .77152 L
s
.52998 1.08434 m
.5345 1.08759 L
s
.53687 1.09088 m .53522 1.08928 L .5345 1.08759 L 0 .193 0 r
F
0 g
.5345 1.08759 m
.53522 1.08928 L
s
.51964 .92426 m .52603 .89893 L .52466 .90643 L 0 .245 .11 r
F
0 g
.5249 .90009 m
.5252 .89912 L
s
.51987 .90474 m
.5206 .90175 L
s
.51957 .906 m
.51975 .90525 L
s
.51975 .90525 m
.51987 .90474 L
s
.52603 .89893 m
.52609 .89876 L
s
.65993 .72473 m
.65993 .7248 L
s
.65985 .7218 m
.65993 .72473 L
s
.65505 .75147 m
.65562 .74569 L
s
.65562 .74569 m
.65602 .74172 L
s
.65623 .73959 m
.657 .73184 L
s
.65602 .74172 m
.65623 .73959 L
s
.657 .73184 m
.65708 .731 L
s
.65708 .731 m
.65723 .72947 L
s
.65771 .72461 m
.65779 .72383 L
s
.65779 .72383 m
.65827 .71893 L
s
.65827 .71893 m
.65839 .71775 L
s
.65839 .71775 m
.65875 .71412 L
s
.35259 .67767 m
.35843 .67652 L
s
.46358 .91924 m .46228 .92041 L .45822 .92079 L 0 0 .007 r
F
.47341 .92164 m .46358 .91924 L .46744 .91907 L 0 .082 .038 r
F
.47341 .92164 m .46228 .92041 L .46358 .91924 L F
0 g
.46167 .91797 m
.46358 .91924 L
s
.57306 .67154 m .57309 .66993 L .57109 .67439 L 0 0 0 r
F
.57306 .67154 m .57836 .66153 L .57309 .66993 L F
0 g
.72523 .78101 m
.72635 .78523 L
s
.50406 .47507 m .49622 .47932 L .49657 .47782 L 0 0 0 r
F
0 g
.49533 .47599 m
.49716 .47489 L
s
.48966 .4794 m
.49533 .47599 L
s
.50406 .47507 m .50357 .47922 L .49622 .47932 L 0 0 0 r
F
.50406 .47507 m .51372 .47759 L .50357 .47922 L F
.50406 .47507 m .5212 .47483 L .51372 .47759 L F
0 g
.51369 .47949 m
.52076 .47551 L
s
.50406 .47507 m .52103 .4728 L .5212 .47483 L 0 0 0 r
F
0 g
.52103 .4728 m
.5281 .47094 L
s
.51369 .4729 m
.52103 .4728 L
s
.29769 .90802 m
.29769 .90802 L
s
.73767 .64071 m .75279 .62949 L .74773 .63781 L 0 .052 .051 r
F
0 g
.75279 .62949 m
.75808 .62468 L
s
.75279 .62949 m
.7534 .62333 L
s
.74284 .64022 m
.74326 .6391 L
s
.74284 .64022 m
.74284 .63922 L
s
.46759 .89694 m .4563 .89134 L .46008 .89684 L 0 .674 .332 r
F
0 g
.4563 .89134 m
.45703 .8924 L
s
.45336 .89416 m
.4563 .89134 L
s
.35728 .69909 m .36148 .68822 L .36196 .67916 L 0 1 .403 r
F
0 g
.36148 .68822 m
.3673 .68121 L
s
.47944 .9351 m .47086 .93139 L .46944 .93243 L 0 .75 .456 r
F
0 g
.46553 .9309 m
.46944 .93243 L
s
.5591 .81007 m .56838 .73684 L .56524 .74253 L 0 1 .254 r
F
0 g
.56391 .7425 m
.56426 .75335 L
s
.5591 .81007 m .56876 .75811 L .56838 .73684 L 0 1 .254 r
F
0 g
.56838 .73684 m
.5698 .729 L
s
.34019 .76397 m .33108 .76271 L .33522 .76366 L 0 .607 .267 r
F
0 g
.33522 .76366 m
.33701 .76519 L
s
.50002 .92017 m .49357 .91709 L .49232 .91405 L 0 .152 .079 r
F
0 g
.48926 .91373 m
.49232 .91405 L
s
.32978 .67262 m .31759 .6655 L .3176 .67057 L 0 1 .5 r
F
0 g
.31078 .67269 m
.3176 .67057 L
s
.3539 .62455 m .35605 .61239 L .35434 .60806 L 0 1 .22 r
F
0 g
.35459 .6087 m
.35605 .61239 L
s
.49105 .87222 m .48064 .84269 L .4801 .84639 L 0 .654 .302 r
F
.49105 .87222 m .48423 .84826 L .48064 .84269 L F
0 g
.48044 .84201 m
.48064 .84269 L
s
.36189 .63504 m .35605 .61241 L .3539 .62456 L 0 .847 .32 r
F
0 g
.35605 .61241 m
.3599 .61026 L
s
.35728 .69909 m .34746 .70596 L .35127 .7067 L 0 1 .403 r
F
0 g
.35127 .7067 m
.35151 .71488 L
s
.35728 .69909 m .34794 .69689 L .34746 .70596 L 0 1 .403 r
F
.35728 .69909 m .35239 .68554 L .34794 .69689 L F
.35728 .69909 m .3584 .67794 L .35239 .68554 L F
.35728 .69909 m .36196 .67916 L .3584 .67794 L F
0 g
.35127 .7067 m
.35728 .69909 L
s
.35698 .70801 m
.35728 .69909 L
s
.36196 .67916 m
.36371 .67705 L
s
.36148 .68822 m
.36196 .67916 L
s
.25882 .90087 m .25148 .90355 L .25606 .90374 L 0 1 .51 r
F
0 g
.25606 .90374 m
.26097 .90683 L
s
.25882 .90087 m .24733 .90019 L .25148 .90355 L 0 1 .51 r
F
0 g
.24961 .90659 m
.25148 .90355 L
s
.67563 .76219 m
.67617 .7692 L
s
.67511 .76378 m
.67563 .76219 L
s
.46354 .92475 m .45822 .92079 L .45412 .92013 L 0 .92 .481 r
F
.46349 .93027 m .45822 .92079 L .45412 .92013 L 0 .609 .346 r
F
.46708 .92959 m .4656 .92767 L .4616 .92593 L 0 .896 .48 r
F
.46349 .93027 m .46224 .92513 L .45822 .92079 L 0 .609 .346 r
F
.46354 .92475 m .46226 .92277 L .45822 .92079 L 0 .92 .481 r
F
.46049 .92213 m .45412 .92013 L .45822 .92079 L 0 .02 .009 r
F
.46049 .92213 m .45006 .92035 L .45412 .92013 L F
.46051 .91976 m .45412 .92013 L .45822 .92079 L 0 .938 .481 r
F
0 g
.45322 .91963 m
.45412 .92013 L
s
.45367 .92928 m
.45471 .9304 L
s
.43969 .7757 m
.4402 .77574 L
s
.43576 .77544 m
.43969 .7757 L
s
.46264 .95648 m .46066 .95108 L .45651 .9472 L 0 .557 .358 r
F
0 g
.38128 .67498 m
.38706 .67326 L
s
.49864 .84432 m .49942 .84287 L .49806 .82806 L 0 .66 .291 r
F
0 g
.49903 .83863 m
.49931 .8416 L
s
.49806 .82806 m
.49903 .83863 L
s
.49806 .82806 m
.5003 .83923 L
s
.2448 .74773 m .23611 .74023 L .2335 .74537 L 0 1 .532 r
F
.2448 .74773 m .24141 .73729 L .23611 .74023 L F
.2448 .74773 m .24587 .73853 L .24141 .73729 L F
.2448 .74773 m .24732 .74301 L .24587 .73853 L F
0 g
.23952 .75064 m
.2448 .74773 L
s
.2448 .74773 m
.24633 .75188 L
s
.47341 .92164 m .46744 .91907 L .4713 .92 L 0 .082 .038 r
F
.47629 .91847 m .4713 .92 L .46744 .91907 L 0 .054 .037 r
F
0 g
.46568 .91744 m
.46744 .91907 L
s
.46358 .91924 m
.46744 .91907 L
s
.48696 1.02866 m .48774 1.03419 L .48888 1.03339 L 0 .291 .321 r
F
.49639 1.04245 m .48888 1.03339 L .48774 1.03419 L 0 .216 .262 r
F
0 g
.48774 1.03419 m
.49008 1.03884 L
s
.48377 1.03072 m
.48774 1.03419 L
s
.66318 .61302 m
.66342 .61392 L
s
.66247 .61037 m
.66318 .61302 L
s
.66373 .61507 m
.66411 .61647 L
s
.66118 .60554 m
.66247 .61037 L
s
.66088 .60442 m
.66118 .60554 L
s
.6651 .62016 m
.66838 .63242 L
s
.66509 .62015 m
.6651 .62016 L
s
.66509 .62013 m
.66509 .62015 L
s
.66508 .62009 m
.66509 .62013 L
s
.66467 .61856 m
.66508 .62009 L
s
.65798 .59311 m
.66088 .60442 L
s
.26203 .93344 m .25035 .93079 L .24856 .93157 L 0 .639 .239 r
F
.26203 .93344 m .25494 .9312 L .25035 .93079 L F
.26203 .93344 m .25995 .93234 L .25494 .9312 L F
.27331 .93393 m .25995 .93234 L .26203 .93344 L 0 .598 .225 r
F
0 g
.26022 .93421 m
.26203 .93344 L
s
.26203 .93344 m
.26693 .93433 L
s
.48302 .93913 m .4791 .9402 L .48197 .94027 L 0 .703 .447 r
F
.48691 .94306 m .48197 .94027 L .4791 .9402 L 0 .644 .432 r
F
0 g
.47845 .94143 m
.4791 .9402 L
s
.47558 .93881 m
.4791 .9402 L
s
.44216 .53932 m .45548 .52549 L .45423 .5242 L 0 1 .414 r
F
0 g
.45548 .52549 m
.46271 .52104 L
s
.45031 .53196 m
.45548 .52549 L
s
.74695 .61769 m .76279 .62024 L .75707 .61655 L 0 1 .41 r
F
0 g
.76279 .62024 m
.7697 .62267 L
s
.76279 .62024 m
.76391 .62309 L
s
.51349 .92484 m .51381 .90618 L .51433 .91126 L 0 .211 .098 r
F
.51349 .92484 m .51284 .90701 L .51381 .90618 L F
0 g
.51381 .90618 m
.51385 .90594 L
s
.56913 .62722 m .5675 .63162 L .56593 .62807 L 0 .301 .048 r
F
.56913 .62722 m .57338 .63697 L .5675 .63162 L F
.56913 .62722 m .57966 .64052 L .57338 .63697 L F
.56913 .62722 m .58284 .63965 L .57966 .64052 L F
.56913 .62722 m .58083 .63494 L .58284 .63965 L F
0 g
.58179 .63487 m
.58348 .63473 L
s
.58083 .63494 m
.58179 .63487 L
s
.57496 .62962 m
.58083 .63494 L
s
.46051 .91976 m .45109 .91455 L .44881 .91558 L 0 .938 .481 r
F
0 g
.44462 .91335 m
.44881 .91558 L
s
.66154 .60242 m
.66526 .61214 L
s
.65799 .59311 m
.66154 .60242 L
s
.66526 .61214 m
.66553 .61287 L
s
.66644 .61525 m
.66659 .61562 L
s
.26456 .66328 m .25336 .66691 L .25766 .66808 L 0 1 .519 r
F
0 g
.25766 .66808 m
.25963 .66671 L
s
.25766 .66808 m
.25804 .67455 L
s
.80478 1.03244 m .80476 1.03891 L .81114 1.03314 L 0 1 .344 r
F
.80478 1.03244 m .80058 1.04069 L .80476 1.03891 L F
0 g
.80367 1.0412 m
.80476 1.03891 L
s
.54573 .7953 m .54768 .7859 L .55153 .81143 L 0 .698 .198 r
F
0 g
.54461 .8116 m
.54587 .80388 L
s
.54767 .80827 m
.54783 .80115 L
s
.54685 .76026 m
.54768 .7859 L
s
.3839 .87837 m .37551 .86955 L .37236 .87229 L 0 1 .502 r
F
.3839 .87837 m .38003 .87038 L .37551 .86955 L F
.3839 .87837 m .38362 .87416 L .38003 .87038 L F
0 g
.38074 .88111 m
.3839 .87837 L
s
.39559 .88039 m .38362 .87416 L .3839 .87837 L 0 1 .498 r
F
0 g
.3839 .87837 m
.3876 .88205 L
s
.3416 .91247 m .3319 .90849 L .32968 .9098 L 0 .999 .394 r
F
.3416 .91247 m .33619 .9089 L .3319 .90849 L F
.3416 .91247 m .34036 .91061 L .33619 .9089 L F
.3522 .91314 m .34036 .91061 L .3416 .91247 L 0 .887 .356 r
F
0 g
.33938 .91377 m
.3416 .91247 L
s
.3416 .91247 m
.34569 .914 L
s
.46662 .88519 m .45876 .8841 L .46336 .88674 L 0 .708 .331 r
F
.46759 .89694 m .46336 .88674 L .45876 .8841 L 0 .674 .332 r
F
0 g
.45749 .88493 m
.45876 .8841 L
s
.45579 .87929 m
.45876 .8841 L
s
.44216 .53932 m .43309 .54198 L .43477 .54361 L 0 1 .414 r
F
.44216 .53932 m .43826 .53549 L .43309 .54198 L F
.44216 .53932 m .44685 .52848 L .43826 .53549 L F
.44216 .53932 m .45423 .5242 L .44685 .52848 L F
0 g
.4373 .54612 m
.44216 .53932 L
s
.47452 .99893 m .47157 .99345 L .46751 .98997 L 0 .386 .355 r
F
0 g
.4547 .77674 m
.45483 .77674 L
s
.4506 .77688 m
.4547 .77674 L
s
.36189 .63504 m .36376 .63015 L .3629 .61953 L 0 .847 .32 r
F
.45006 .92035 m .44453 .92159 L .44022 .92101 L 0 0 0 r
F
.45006 .92035 m .44876 .92131 L .44453 .92159 L F
.46049 .92213 m .44876 .92131 L .45006 .92035 L 0 .02 .009 r
F
0 g
.4481 .91941 m
.45006 .92035 L
s
.45006 .92035 m
.45412 .92013 L
s
.47822 .86531 m .46989 .8578 L .47454 .86373 L 0 .717 .316 r
F
.47784 .87498 m .47454 .86373 L .46989 .8578 L 0 .694 .317 r
F
0 g
.46667 .84982 m
.46989 .8578 L
s
.46898 .85757 m
.46989 .8578 L
s
.27512 .66668 m .26948 .6557 L .26456 .66328 L 0 1 .519 r
F
.27512 .66668 m .27624 .65126 L .26948 .6557 L F
.27512 .66668 m .28033 .65295 L .27624 .65126 L F
.27512 .66668 m .27984 .65957 L .28033 .65295 L F
0 g
.26955 .67032 m
.27512 .66668 L
s
.2748 .67296 m
.27512 .66668 L
s
.20098 .85113 m .19272 .85683 L .19735 .857 L 0 1 .534 r
F
0 g
.19735 .857 m
.20164 .86316 L
s
.20098 .85113 m .1894 .85051 L .19272 .85683 L 0 1 .534 r
F
0 g
.19013 .86291 m
.19272 .85683 L
s
.51445 .9652 m .51477 .96627 L .51639 .96704 L 0 .244 .203 r
F
0 g
.51477 .96627 m
.51679 .96759 L
s
.21256 .85174 m .20428 .85726 L .20891 .85744 L 0 1 .533 r
F
0 g
.20891 .85744 m
.21316 .86342 L
s
.21256 .85174 m .20098 .85113 L .20428 .85726 L 0 1 .533 r
F
0 g
.20164 .86316 m
.20428 .85726 L
s
.47452 .99893 m .47316 1.00461 L .4752 1.00371 L 0 .386 .355 r
F
.48218 1.01259 m .4752 1.00371 L .47316 1.00461 L 0 .314 .335 r
F
0 g
.47316 1.00461 m
.47429 1.00941 L
s
.4691 1.00112 m
.47316 1.00461 L
s
.36995 .64249 m .37169 .6386 L .37065 .63292 L 0 1 .375 r
F
0 g
.37169 .6386 m
.37537 .63784 L
s
.49247 .77998 m
.49263 .78285 L
s
.52064 .92497 m .52724 .8988 L .52801 .89882 L 0 .25 .115 r
F
.52064 .92497 m .52466 .90643 L .52724 .8988 L F
0 g
.52724 .8988 m
.52727 .89864 L
s
.52579 .90022 m
.52603 .89893 L
s
.22413 .85235 m .21585 .8577 L .22047 .85788 L 0 1 .532 r
F
0 g
.22047 .85788 m
.22467 .86368 L
s
.22413 .85235 m .21256 .85174 L .21585 .8577 L 0 1 .532 r
F
0 g
.21316 .86342 m
.21585 .8577 L
s
.52118 .97013 m
.5222 .97067 L
s
.5222 .97067 m
.52318 .97119 L
s
.52393 .97186 m .52319 .9714 L .52318 .97119 L 0 0 0 r
F
0 g
.52318 .97119 m
.52318 .97119 L
s
.23571 .85295 m .22741 .85814 L .23204 .85832 L 0 1 .531 r
F
0 g
.23204 .85832 m
.23619 .86394 L
s
.23571 .85295 m .22413 .85235 L .22741 .85814 L 0 1 .531 r
F
0 g
.22467 .86368 m
.22741 .85814 L
s
.46053 .9174 m .4595 .91222 L .45549 .90754 L 0 .655 .347 r
F
0 g
.33322 .73856 m
.3384 .73166 L
s
.77858 .89186 m .78777 .88865 L .78316 .88908 L 0 1 .454 r
F
.76712 .89262 m .77858 .89186 L .77625 .88972 L 0 1 .426 r
F
.46699 .94304 m .45611 .9375 L .45786 .94295 L 0 .558 .344 r
F
.46699 .94304 m .45769 .93363 L .45611 .9375 L F
0 g
.45191 .93336 m
.45611 .9375 L
s
.24729 .85357 m .23898 .85858 L .2436 .85876 L 0 1 .53 r
F
0 g
.2436 .85876 m
.24771 .86422 L
s
.24729 .85357 m .23571 .85295 L .23898 .85858 L 0 1 .53 r
F
0 g
.23619 .86394 m
.23898 .85858 L
s
.73729 .78311 m .75028 .77932 L .74892 .78915 L 0 .325 .086 r
F
0 g
.74775 .7694 m
.75028 .77932 L
s
.75028 .77932 m
.75481 .77401 L
s
.50478 .95796 m .50501 .95977 L .5057 .95936 L 0 .376 .277 r
F
.5096 .96157 m .5057 .95936 L .50501 .95977 L 0 .318 .223 r
F
0 g
.50501 .95977 m
.50631 .96117 L
s
.50272 .95896 m
.50501 .95977 L
s
.25886 .8542 m .25054 .85904 L .25517 .85923 L 0 1 .528 r
F
0 g
.25517 .85923 m
.25923 .86452 L
s
.25886 .8542 m .24729 .85357 L .25054 .85904 L 0 1 .528 r
F
0 g
.24771 .86422 m
.25054 .85904 L
s
.51349 .92484 m .51226 .91292 L .51284 .90701 L 0 .211 .098 r
F
0 g
.51195 .9037 m
.51284 .90701 L
s
.5285 1.08542 m .52998 1.08434 L .53343 1.08851 L 0 .114 0 r
F
.47374 .98323 m .46451 .97971 L .46728 .98522 L 0 .417 .347 r
F
.47374 .98323 m .46458 .97508 L .46451 .97971 L F
0 g
.4603 .9761 m
.46451 .97971 L
s
.66009 .62258 m .66127 .6204 L .65817 .62151 L 0 .957 .285 r
F
.4 .6691 m .39073 .6715 L .39394 .67126 L 0 1 .282 r
F
.4 .6691 m .39221 .66982 L .39073 .6715 L F
0 g
.39394 .67126 m
.39529 .67165 L
s
.4 .6691 m .39742 .66733 L .39221 .66982 L 0 1 .282 r
F
.4 .6691 m .40351 .66517 L .39742 .66733 L F
.4 .6691 m .4064 .66478 L .40351 .66517 L F
.4 .6691 m .40489 .66647 L .4064 .66478 L F
0 g
.39875 .67092 m
.4 .6691 L
s
.39394 .67126 m
.4 .6691 L
s
.48218 1.01259 m .47784 1.01492 L .4817 1.01835 L 0 .314 .335 r
F
0 g
.47784 1.01492 m
.47931 1.0197 L
s
.46662 .88519 m .46637 .88049 L .46268 .87452 L 0 .708 .331 r
F
.34019 .76397 m .32994 .76134 L .33108 .76271 L 0 .607 .267 r
F
0 g
.32659 .76309 m
.33108 .76271 L
s
.27043 .85485 m .26211 .85952 L .26673 .85972 L 0 1 .526 r
F
0 g
.26673 .85972 m
.27075 .86485 L
s
.27043 .85485 m .25886 .8542 L .26211 .85952 L 0 1 .526 r
F
0 g
.25923 .86452 m
.26211 .85952 L
s
.49105 .87222 m .4801 .84639 L .48301 .85663 L 0 .654 .302 r
F
0 g
.48064 .84269 m
.48388 .84772 L
s
.47636 .84334 m
.4801 .84639 L
s
.36995 .64249 m .37065 .63292 L .36751 .62924 L 0 1 .375 r
F
0 g
.37065 .63292 m
.37169 .6386 L
s
.39941 .91849 m .3891 .91714 L .38672 .91716 L 0 .534 .207 r
F
.39941 .91849 m .3937 .91767 L .3891 .91714 L F
.39941 .91849 m .39812 .91825 L .3937 .91767 L F
.41068 .91956 m .39812 .91825 L .39941 .91849 L 0 0 0 r
F
0 g
.39941 .91849 m
.40372 .91892 L
s
.39702 .91851 m
.39941 .91849 L
s
.63767 .62574 m .65044 .62409 L .65353 .62309 L 0 .836 .248 r
F
.63767 .62574 m .64365 .62523 L .65044 .62409 L F
0 g
.65044 .62409 m
.65214 .62506 L
s
.282 .85555 m .27367 .86003 L .2783 .86025 L 0 1 .524 r
F
0 g
.2783 .86025 m
.28227 .86523 L
s
.282 .85555 m .27043 .85485 L .27367 .86003 L 0 1 .524 r
F
0 g
.27075 .86485 m
.27367 .86003 L
s
.42013 .89376 m .41095 .88633 L .40794 .88813 L 0 1 .494 r
F
0 g
.40794 .88813 m
.40911 .88743 L
s
.60932 .6356 m .62151 .63037 L .62425 .62954 L 0 0 0 r
F
0 g
.62278 .63013 m
.62344 .63001 L
s
.60932 .6356 m .61512 .63296 L .62151 .63037 L 0 0 0 r
F
.49323 .86016 m .48577 .84016 L .48979 .85253 L 0 .666 .299 r
F
.49203 .866 m .48979 .85253 L .48577 .84016 L 0 .662 .301 r
F
0 g
.4834 .83576 m
.48577 .84016 L
s
.48561 .83938 m
.48577 .84016 L
s
.52868 .97494 m .53285 .97616 L .53149 .97613 L 0 0 0 r
F
.53453 .97901 m .53149 .97613 L .53285 .97616 L 0 .024 0 r
F
0 g
.53285 .97616 m
.53595 .97733 L
s
.53172 .97511 m
.53285 .97616 L
s
.76722 .61527 m .78078 .62232 L .785 .62205 L 0 1 .471 r
F
.76722 .61527 m .77317 .61942 L .78078 .62232 L F
.76794 .63238 m .77348 .62673 L .78078 .62232 L 0 0 0 r
F
0 g
.77924 .62325 m
.77984 .62288 L
s
.77984 .62288 m
.78078 .62232 L
s
.77424 .62627 m
.77432 .62497 L
s
.77432 .62497 m
.77444 .62275 L
s
.55546 1.10101 m
.55869 1.10609 L
s
.51607 1.07168 m .51153 1.06671 L .51638 1.07197 L 0 .003 .157 r
F
.51607 1.07168 m .50805 1.06252 L .51153 1.06671 L F
0 g
.50774 1.06297 m
.51153 1.06671 L
s
.40729 .88285 m .39927 .88397 L .40394 .88485 L 0 1 .494 r
F
0 g
.40394 .88485 m
.40794 .88813 L
s
.40729 .88285 m .39559 .88039 L .39927 .88397 L 0 1 .494 r
F
0 g
.398 .88491 m
.39927 .88397 L
s
.47622 .93098 m .46708 .92959 L .47086 .93139 L 0 .787 .462 r
F
.47622 .93098 m .4656 .92767 L .46708 .92959 L F
0 g
.46553 .9309 m
.46708 .92959 L
s
.43353 .90345 m .42861 .89787 L .42401 .89687 L 0 1 .493 r
F
.43353 .90345 m .43269 .90069 L .42861 .89787 L F
.44482 .90605 m .43353 .90345 L .43752 .90623 L 0 1 .485 r
F
.44482 .90605 m .43269 .90069 L .43353 .90345 L F
0 g
.4308 .90501 m
.43353 .90345 L
s
.36995 .64249 m .36294 .64072 L .3662 .6434 L 0 1 .375 r
F
.36995 .64249 m .36189 .63504 L .36294 .64072 L F
.36995 .64249 m .36376 .63015 L .36189 .63504 L F
.36995 .64249 m .36751 .62924 L .36376 .63015 L F
0 g
.3629 .61953 m
.36376 .63015 L
s
.36995 .64249 m
.37109 .64726 L
s
.3662 .6434 m
.36995 .64249 L
s
.2962 .85649 m .28603 .86064 L .29171 .86094 L 0 1 .521 r
F
0 g
.29171 .86094 m
.29642 .86577 L
s
.2962 .85649 m .282 .85555 L .28603 .86064 L 0 1 .521 r
F
0 g
.28227 .86523 m
.28603 .86064 L
s
.47782 .88475 m .46608 .8687 L .46614 .87342 L 0 .669 .318 r
F
0 g
.46268 .87452 m
.46573 .87945 L
s
.47782 .88475 m .46955 .86898 L .46608 .8687 L 0 .669 .318 r
F
0 g
.46253 .86224 m
.46608 .8687 L
s
.46268 .87452 m
.46452 .87393 L
s
.46759 .86882 m
.46848 .86889 L
s
.46608 .8687 m
.46759 .86882 L
s
.68489 .61725 m
.68625 .61877 L
s
.46905 .90865 m .45732 .89921 L .45812 .90443 L 0 .638 .332 r
F
.46905 .90865 m .46008 .89684 L .45732 .89921 L F
0 g
.45624 .89783 m
.45732 .89921 L
s
.45732 .89921 m
.45876 .89797 L
s
.26794 .54236 m .25519 .54943 L .25907 .5503 L 0 1 .478 r
F
0 g
.25688 .5594 m
.25907 .5503 L
s
.20143 .89781 m .18866 .8915 L .18996 .89727 L 0 1 .527 r
F
0 g
.18996 .89727 m
.19436 .90167 L
s
.49639 1.04245 m .49434 1.04425 L .49805 1.0478 L 0 .216 .262 r
F
0 g
.49434 1.04425 m
.49704 1.04875 L
s
.52064 .92497 m .52801 .89882 L .52631 .90671 L 0 .25 .115 r
F
0 g
.52783 .89965 m
.52801 .89882 L
s
.52694 .89968 m
.52724 .8988 L
s
.52209 .90329 m
.52299 .90007 L
s
.52104 .9071 m
.52134 .90599 L
s
.52134 .90599 m
.52136 .90594 L
s
.52111 .9062 m
.52111 .90615 L
s
.52101 .90711 m
.52111 .9062 L
s
.52801 .89882 m
.52802 .8988 L
s
.44482 .90605 m .43752 .90623 L .442 .90717 L 0 1 .485 r
F
.44711 .91205 m .442 .90717 L .43752 .90623 L 0 1 .489 r
F
0 g
.43504 .90753 m
.43752 .90623 L
s
.43353 .90345 m
.43752 .90623 L
s
.49769 .84047 m
.49793 .84145 L
s
.49793 .84145 m
.49826 .84278 L
s
.49678 .84845 m .49751 .84671 L .4958 .83279 L 0 .665 .294 r
F
0 g
.4958 .83279 m
.49591 .8337 L
s
.49674 .84045 m
.49731 .84509 L
s
.4958 .83279 m
.49594 .83333 L
s
.30703 .8573 m .29921 .86136 L .30354 .86163 L 0 1 .519 r
F
0 g
.30354 .86163 m
.3072 .86627 L
s
.30703 .8573 m .29621 .85649 L .29921 .86136 L 0 1 .519 r
F
0 g
.29642 .86577 m
.29921 .86136 L
s
.51223 .83978 m .51322 .84118 L .51407 .82219 L 0 .614 .27 r
F
.70707 1.08098 m .71808 1.07867 L .7143 1.08054 L 0 0 0 r
F
.69569 1.08664 m .70707 1.08098 L .70798 1.08389 L F
.47822 .86531 m .47848 .86147 L .47525 .85348 L 0 .717 .316 r
F
.27031 .9016 m .26293 .90403 L .2675 .90424 L 0 1 .504 r
F
0 g
.2675 .90424 m
.27233 .90713 L
s
.27031 .9016 m .25882 .90087 L .26293 .90403 L 0 1 .504 r
F
0 g
.26097 .90683 m
.26293 .90403 L
s
.37389 .915 m .36691 .91515 L .37131 .91547 L 0 .658 .256 r
F
0 g
.37131 .91547 m
.37579 .91636 L
s
.37389 .915 m .3628 .91395 L .36691 .91515 L 0 .658 .256 r
F
0 g
.36488 .91578 m
.36691 .91515 L
s
.71247 .61462 m .72992 .61704 L .72818 .6149 L 0 1 .352 r
F
0 g
.72992 .61704 m
.73686 .61868 L
s
.43169 .8965 m .42401 .89687 L .42861 .89787 L 0 1 .488 r
F
.43169 .8965 m .42013 .89376 L .42401 .89687 L F
0 g
.42129 .89843 m
.42401 .89687 L
s
.60989 .66969 m .61123 .67342 L .60837 .6663 L 0 .313 0 r
F
0 g
.60868 .66699 m
.60989 .66969 L
s
.60849 .66657 m
.60868 .66699 L
s
.60837 .6663 m
.60849 .66657 L
s
.60641 .66277 m
.60837 .6663 L
s
.60315 .63853 m .60932 .6356 L .60319 .63872 L 0 0 0 r
F
.60315 .63853 m .61512 .63296 L .60932 .6356 L F
0 g
.60247 .63902 m
.60315 .63853 L
s
.61512 .63296 m
.62151 .63037 L
s
.61512 .63296 m
.6174 .63129 L
s
.60233 .63909 m
.60315 .63853 L
s
.47944 .9351 m .47478 .93587 L .47802 .93613 L 0 .75 .456 r
F
.48302 .93913 m .47802 .93613 L .47478 .93587 L 0 .703 .447 r
F
0 g
.47374 .93702 m
.47478 .93587 L
s
.47111 .93428 m
.47478 .93587 L
s
.31784 .85821 m .31003 .86205 L .31436 .86236 L 0 1 .516 r
F
0 g
.31436 .86236 m
.31798 .86687 L
s
.31784 .85821 m .30703 .8573 L .31003 .86205 L 0 1 .516 r
F
0 g
.3072 .86627 m
.31003 .86205 L
s
.50002 .92017 m .49627 .91407 L .49875 .91712 L 0 .152 .079 r
F
.50211 .91767 m .49875 .91712 L .49627 .91407 L 0 .137 .078 r
F
0 g
.49524 .91358 m
.49627 .91407 L
s
.49537 .9108 m
.49627 .91407 L
s
.30563 .76127 m
.30802 .7578 L
s
.30802 .7578 m
.30804 .75777 L
s
.30804 .75777 m
.30813 .75764 L
s
.30398 .75623 m
.30562 .76127 L
s
.30373 .75545 m
.30398 .75623 L
s
.39718 .77266 m .38689 .77184 L .38815 .77143 L 0 0 0 r
F
0 g
.38356 .7709 m
.38815 .77143 L
s
.48009 .48301 m .48966 .4794 L .49657 .47782 L 0 0 0 r
F
0 g
.47371 .48438 m
.48009 .48301 L
s
.51227 .9256 m .51138 .90828 L .51226 .91292 L 0 .207 .096 r
F
.51227 .9256 m .51042 .90916 L .51138 .90828 L F
0 g
.51138 .90828 m
.51195 .9037 L
s
.51239 .91159 m
.51284 .90701 L
s
.32003 .74741 m .31046 .75428 L .31463 .75456 L 0 1 .441 r
F
0 g
.31463 .75456 m
.31578 .76023 L
s
.46699 .94304 m .45786 .94295 L .46184 .94699 L 0 .558 .344 r
F
0 g
.45651 .9472 m
.45786 .94295 L
s
.26456 .66328 m .25396 .66008 L .25336 .66691 L 0 1 .519 r
F
0 g
.24719 .67192 m
.25336 .66691 L
s
.4236 .77536 m .41466 .77457 L .41879 .77439 L 0 0 0 r
F
0 g
.41879 .77439 m
.42045 .77339 L
s
.52402 .9719 m
.52459 .97211 L
s
.52459 .97211 m
.52517 .97233 L
s
.52517 .97233 m
.52517 .97233 L
s
.52517 .97233 m
.52548 .97263 L
s
.50661 .91283 m .50568 .91378 L .50377 .91167 L 0 .113 .077 r
F
0 g
.50377 .91167 m
.50498 .91301 L
s
.50377 .91167 m
.50415 .91417 L
s
.77209 .79642 m .77828 .78511 L .78297 .78672 L 0 .165 .038 r
F
.77209 .79642 m .77363 .78925 L .77828 .78511 L F
0 g
.77512 .78028 m
.77828 .78511 L
s
.54735 1.10154 m .55021 1.0985 L .55356 1.10317 L 0 .232 0 r
F
0 g
.55021 1.0985 m
.55546 1.10101 L
s
.7203 1.08333 m .71808 1.07867 L .72486 1.07719 L 0 0 0 r
F
.7203 1.08333 m .7143 1.08054 L .71808 1.07867 L F
0 g
.7163 1.07691 m
.71808 1.07867 L
s
.2335 .74537 m .22488 .73753 L .22219 .74308 L 0 1 .535 r
F
.2335 .74537 m .23026 .73426 L .22488 .73753 L F
.2335 .74537 m .23472 .73546 L .23026 .73426 L F
.2335 .74537 m .23611 .74023 L .23472 .73546 L F
0 g
.22815 .74862 m
.2335 .74537 L
s
.2335 .74537 m
.23497 .74983 L
s
.71766 .64738 m .72127 .65432 L .71736 .65639 L 0 .148 .084 r
F
0 g
.71736 .65639 m
.71741 .65494 L
s
.71766 .64738 m .72765 .64386 L .72127 .65432 L 0 .148 .084 r
F
0 g
.71741 .65494 m
.71766 .64738 L
s
.7135 .65576 m
.71766 .64738 L
s
.71263 .65751 m
.7135 .65576 L
s
.7115 .65978 m
.71263 .65751 L
s
.32865 .85925 m .32084 .86285 L .32517 .8632 L 0 1 .513 r
F
0 g
.32517 .8632 m
.32876 .86759 L
s
.32865 .85925 m .31784 .85821 L .32084 .86285 L 0 1 .513 r
F
0 g
.31798 .86687 m
.32084 .86285 L
s
.36376 .63015 m
.36751 .62924 L
s
.76712 .89262 m .77625 .88972 L .77164 .89016 L 0 1 .426 r
F
.75565 .8934 m .76712 .89262 L .76472 .89082 L 0 1 .387 r
F
.42013 .89376 m .41562 .88742 L .41095 .88633 L 0 1 .494 r
F
.42013 .89376 m .41956 .89061 L .41562 .88742 L F
.43169 .8965 m .41956 .89061 L .42013 .89376 L 0 1 .488 r
F
0 g
.41712 .89555 m
.42013 .89376 L
s
.42013 .89376 m
.42401 .89687 L
s
.32978 .67262 m .32258 .66107 L .31759 .6655 L 0 1 .5 r
F
0 g
.31759 .6655 m
.3176 .67057 L
s
.32978 .67262 m .3298 .66075 L .32258 .66107 L 0 1 .5 r
F
.32978 .67262 m .33444 .66474 L .3298 .66075 L F
.32978 .67262 m .33443 .66983 L .33444 .66474 L F
0 g
.32257 .67293 m
.32978 .67262 L
s
.47629 .91847 m .47509 .91975 L .4713 .92 L 0 .054 .037 r
F
.48544 .92221 m .47629 .91847 L .47986 .91864 L 0 .135 .062 r
F
.48544 .92221 m .47509 .91975 L .47629 .91847 L F
0 g
.47452 .91684 m
.47629 .91847 L
s
.47629 .91847 m
.47768 .91854 L
s
.29203 .75468 m
.29759 .75373 L
s
.47622 .93098 m .46739 .92678 L .4656 .92767 L 0 .787 .462 r
F
0 g
.46254 .92634 m
.4656 .92767 L
s
.26794 .54236 m .25843 .54023 L .25519 .54943 L 0 1 .478 r
F
0 g
.24699 .5573 m
.25519 .54943 L
s
.26794 .54236 m .26667 .52881 L .25843 .54023 L 0 1 .478 r
F
.26794 .54236 m .27556 .52084 L .26667 .52881 L F
.26794 .54236 m .27917 .52166 L .27556 .52084 L F
.26794 .54236 m .2759 .53089 L .27917 .52166 L F
0 g
.26489 .55165 m
.26794 .54236 L
s
.25907 .5503 m
.26794 .54236 L
s
.81026 .79158 m .81803 .79454 L .81336 .79385 L 0 0 0 r
F
.81026 .79158 m .82195 .79387 L .81803 .79454 L F
.46905 .90865 m .45812 .90443 L .46196 .90949 L 0 .638 .332 r
F
0 g
.45812 .90443 m
.45886 .9054 L
s
.45549 .90754 m
.45812 .90443 L
s
.45549 .90754 m
.45644 .90865 L
s
.47782 .88475 m .46614 .87342 L .46968 .88017 L 0 .669 .318 r
F
0 g
.46614 .87342 m
.4666 .87429 L
s
.4666 .87429 m
.46907 .87902 L
s
.46452 .87393 m
.46614 .87342 L
s
.35044 .76624 m .34269 .76345 L .34019 .76397 L 0 .581 .244 r
F
.35044 .76624 m .34758 .76389 L .34269 .76345 L F
.35044 .76624 m .35158 .765 L .34758 .76389 L F
.35044 .76624 m .3528 .76601 L .35158 .765 L F
0 g
.34557 .7658 m
.35044 .76624 L
s
.35044 .76624 m
.35178 .76691 L
s
.63055 .62829 m .63111 .62697 L .62836 .62808 L 0 .761 .222 r
F
.63055 .62829 m .63767 .62574 L .63111 .62697 L F
.63055 .62829 m .64365 .62523 L .63767 .62574 L F
0 g
.64365 .62523 m
.65044 .62409 L
s
.64365 .62523 m
.6458 .62544 L
s
.5193 .96887 m .5184 .96847 L .52081 .96994 L 0 .155 .175 r
F
.5193 .96887 m .51639 .96704 L .5184 .96847 L F
0 g
.51679 .96759 m
.5184 .96847 L
s
.36989 .61879 m .3762 .60854 L .37882 .59816 L 0 1 .407 r
F
0 g
.3762 .60854 m
.38305 .60345 L
s
.50514 1.05784 m .50805 1.06252 L .50825 1.06218 L 0 .151 .194 r
F
.51607 1.07168 m .50825 1.06218 L .50805 1.06252 L 0 .003 .157 r
F
0 g
.50805 1.06252 m
.51153 1.06671 L
s
.50428 1.05886 m
.50805 1.06252 L
s
.3539 .62455 m .35434 .60806 L .34991 .61443 L 0 1 .22 r
F
0 g
.35434 .60806 m
.35459 .6087 L
s
.31759 .66549 m .30677 .66525 L .31083 .66728 L 0 1 .49 r
F
0 g
.31078 .67269 m
.31083 .66728 L
s
.32994 .76134 m .32072 .76014 L .32486 .7612 L 0 .677 .328 r
F
0 g
.32486 .7612 m
.32659 .76309 L
s
.55418 .62358 m .56023 .62463 L .56593 .62807 L 0 .205 .038 r
F
.47374 .98323 m .46728 .98522 L .4712 .98871 L 0 .417 .347 r
F
0 g
.46728 .98522 m
.46751 .98997 L
s
.33946 .86046 m .33166 .86378 L .33598 .86419 L 0 1 .51 r
F
0 g
.33598 .86419 m
.33954 .86845 L
s
.33946 .86046 m .32865 .85925 L .33166 .86378 L 0 1 .51 r
F
0 g
.32876 .86759 m
.33166 .86378 L
s
.20143 .89781 m .19115 .88747 L .18866 .8915 L 0 1 .527 r
F
.20143 .89781 m .19579 .88789 L .19115 .88747 L F
.20143 .89781 m .20019 .89233 L .19579 .88789 L F
.2129 .89836 m .20019 .89233 L .20143 .89781 L 0 1 .525 r
F
0 g
.19892 .9018 m
.20143 .89781 L
s
.20143 .89781 m
.20577 .90199 L
s
.49031 .87875 m .47938 .85199 L .47898 .85577 L 0 .643 .303 r
F
.49031 .87875 m .48301 .85663 L .47938 .85199 L F
0 g
.47636 .84334 m
.47938 .85199 L
s
.79218 .63251 m .80837 .64557 L .80289 .63155 L 0 1 .449 r
F
0 g
.79217 .63239 m
.79218 .63251 L
s
.80837 .64557 m
.80918 .65645 L
s
.78506 .62213 m
.78578 .62318 L
s
.78578 .62318 m
.78593 .6234 L
s
.78593 .6234 m
.78667 .62448 L
s
.78777 .62609 m
.78802 .62645 L
s
.79213 .63244 m
.79218 .63251 L
s
.78501 .62205 m
.78502 .62208 L
s
.78502 .62208 m
.78506 .62213 L
s
.46349 .93027 m .45769 .93363 L .46154 .93391 L 0 .609 .346 r
F
.46699 .94304 m .46154 .93391 L .45769 .93363 L 0 .558 .344 r
F
0 g
.45611 .9375 m
.45769 .93363 L
s
.45471 .9304 m
.45769 .93363 L
s
.49058 .91596 m .48947 .91723 L .48621 .91698 L 0 .09 .059 r
F
.76248 1.06105 m .7577 1.06359 L .75712 1.06405 L 0 .801 .187 r
F
0 g
.74978 1.06669 m
.75712 1.06405 L
s
.51227 .9256 m .51021 .91472 L .51042 .90916 L 0 .207 .096 r
F
0 g
.50918 .90631 m
.51042 .90916 L
s
.36989 .61879 m .376 .59455 L .36901 .59521 L 0 1 .407 r
F
0 g
.36901 .59515 m
.36902 .59509 L
s
.53557 .89552 m
.53635 .89341 L
s
.53399 .90316 m
.53477 .89994 L
s
.53543 .8972 m
.53553 .89679 L
s
.53553 .89679 m
.53635 .89341 L
s
.44711 .91205 m .44611 .90967 L .442 .90717 L 0 1 .489 r
F
.45803 .91466 m .44711 .91205 L .45109 .91455 L 0 .951 .478 r
F
.45803 .91466 m .44611 .90967 L .44711 .91205 L F
0 g
.44881 .91558 m
.45071 .91472 L
s
.44462 .91335 m
.44711 .91205 L
s
.45644 .90865 m
.45833 .91087 L
s
.36989 .61879 m .37882 .59816 L .376 .59455 L 0 1 .407 r
F
0 g
.36751 .62923 m
.36989 .61879 L
s
.3629 .61943 m
.36989 .61879 L
s
.36902 .59509 m
.37085 .58959 L
s
.38672 .91716 m
.38672 .91716 L
s
.39559 .88039 m .38694 .87178 L .38362 .87416 L 0 1 .498 r
F
.39559 .88039 m .39164 .8728 L .38694 .87178 L F
.39559 .88039 m .39535 .87649 L .39164 .8728 L F
.40729 .88285 m .39535 .87649 L .39559 .88039 L 0 1 .494 r
F
0 g
.39559 .88039 m
.39927 .88397 L
s
.39227 .88277 m
.39559 .88039 L
s
.32003 .74741 m .30971 .74674 L .31046 .75428 L 0 1 .441 r
F
0 g
.30813 .75764 m
.31046 .75428 L
s
.32003 .74741 m .31288 .73694 L .30971 .74674 L 0 1 .441 r
F
.32003 .74741 m .31829 .72978 L .31288 .73694 L F
.32003 .74741 m .32232 .73004 L .31829 .72978 L F
.32003 .74741 m .32306 .7376 L .32232 .73004 L F
0 g
.32003 .74741 m
.32088 .75503 L
s
.31463 .75456 m
.32003 .74741 L
s
.46795 .96989 m .46458 .97508 L .46744 .97441 L 0 .491 .354 r
F
.47374 .98323 m .46744 .97441 L .46458 .97508 L 0 .417 .347 r
F
0 g
.46451 .97971 m
.46458 .97508 L
s
.46053 .9714 m
.46458 .97508 L
s
.42237 .55783 m .43018 .55041 L .43477 .54361 L 0 1 .454 r
F
0 g
.43018 .55041 m
.4373 .54612 L
s
.52156 .92598 m .52631 .90671 L .52913 .89904 L 0 .254 .119 r
F
0 g
.52823 .90149 m
.52913 .89904 L
s
.52523 .90329 m
.52579 .90022 L
s
.52394 .9032 m
.5249 .90009 L
s
.52296 .90636 m
.52394 .9032 L
s
.52111 .90615 m
.52164 .90102 L
s
.52136 .90594 m
.52209 .90329 L
s
.52291 .90643 m
.52333 .90356 L
s
.52333 .90356 m
.52381 .90023 L
s
.52593 .90267 m
.52694 .89968 L
s
.52719 .90261 m
.52783 .89965 L
s
.52913 .89904 m
.5292 .89873 L
s
.36816 .67659 m .36427 .67508 L .3594 .6756 L 0 .822 .243 r
F
.36816 .67659 m .37045 .67444 L .36427 .67508 L F
.36816 .67659 m .37378 .67411 L .37045 .67444 L F
.36816 .67659 m .37279 .67503 L .37378 .67411 L F
0 g
.36768 .67748 m
.36816 .67659 L
s
.36371 .67705 m
.36816 .67659 L
s
.5096 .96157 m .51068 .96341 L .51089 .96298 L 0 .318 .223 r
F
.51445 .9652 m .51089 .96298 L .51068 .96341 L 0 .244 .203 r
F
0 g
.51068 .96341 m
.51235 .96482 L
s
.50872 .96263 m
.51068 .96341 L
s
.447 .92272 m .44022 .92101 L .44453 .92159 L 0 0 0 r
F
.447 .92272 m .43608 .92109 L .44022 .92101 L F
0 g
.43813 .92001 m
.44022 .92101 L
s
.64787 1.081 m
.64882 1.08155 L
s
.27331 .93393 m .26182 .93184 L .25995 .93234 L 0 .598 .225 r
F
.27331 .93393 m .26641 .93228 L .26182 .93184 L F
.27331 .93393 m .27134 .93318 L .26641 .93228 L F
.2846 .93448 m .27134 .93318 L .27331 .93393 L 0 .547 .208 r
F
0 g
.27141 .93442 m
.27331 .93393 L
s
.27331 .93393 m
.27814 .93457 L
s
.35843 .67652 m
.35858 .67638 L
s
.38607 .5952 m .376 .59455 L .37882 .59816 L 0 1 .463 r
F
0 g
.3762 .60854 m
.37882 .59816 L
s
.38607 .5952 m .37926 .58704 L .376 .59455 L 0 1 .463 r
F
0 g
.36901 .59521 m
.376 .59455 L
s
.38607 .5952 m .38645 .58063 L .37926 .58704 L 0 1 .463 r
F
.38607 .5952 m .39371 .57767 L .38645 .58063 L F
.38607 .5952 m .3962 .58013 L .39371 .57767 L F
.38607 .5952 m .39293 .58764 L .3962 .58013 L F
0 g
.38305 .60345 m
.38607 .5952 L
s
.37882 .59816 m
.38607 .5952 L
s
.39293 .58764 m
.39993 .58391 L
s
.3596 .66754 m .36477 .65489 L .3662 .64341 L 0 1 .383 r
F
0 g
.36477 .65489 m
.37108 .64726 L
s
.46759 .89694 m .46008 .89684 L .46456 .89891 L 0 .674 .332 r
F
.46905 .90865 m .46456 .89891 L .46008 .89684 L 0 .638 .332 r
F
0 g
.45876 .89797 m
.46008 .89684 L
s
.45703 .8924 m
.46008 .89684 L
s
.49806 .9227 m .49058 .91596 L .49357 .91709 L 0 .167 .08 r
F
.49806 .9227 m .48947 .91723 L .49058 .91596 L F
0 g
.48926 .91373 m
.49058 .91596 L
s
.49058 .91596 m
.49217 .91656 L
s
.43608 .92109 m .4261 .92118 L .42378 .92038 L 0 0 0 r
F
.3596 .66754 m .3662 .64341 L .36294 .64073 L 0 1 .383 r
F
0 g
.36477 .65489 m
.3662 .64341 L
s
.3522 .91314 m .34264 .90956 L .34036 .91061 L 0 .887 .356 r
F
.3522 .91314 m .34694 .91003 L .34264 .90956 L F
.3522 .91314 m .35104 .91156 L .34694 .91003 L F
.3628 .91395 m .35104 .91156 L .3522 .91314 L 0 .755 .308 r
F
0 g
.3499 .91418 m
.3522 .91314 L
s
.3522 .91314 m
.35622 .91449 L
s
.39718 .77266 m .3894 .77268 L .38689 .77184 L 0 0 0 r
F
.39718 .77266 m .39426 .77362 L .3894 .77268 L F
.39718 .77266 m .39824 .77403 L .39426 .77362 L F
.39718 .77266 m .39948 .77362 L .39824 .77403 L F
0 g
.39232 .77173 m
.39718 .77266 L
s
.49588 .85078 m .49608 .85019 L .49373 .83818 L 0 .672 .296 r
F
0 g
.49539 .84668 m
.496 .84977 L
s
.49373 .83818 m
.49373 .83822 L
s
.49543 .84389 m
.49617 .8464 L
s
.49594 .83333 m
.49769 .84047 L
s
.49591 .8337 m
.49674 .84045 L
s
.42198 .92098 m .4149 .91987 L .41938 .92034 L 0 0 0 r
F
.42198 .92098 m .41068 .91956 L .4149 .91987 L F
0 g
.41273 .9194 m
.4149 .91987 L
s
.41938 .92034 m
.42378 .92038 L
s
.35027 .86186 m .34247 .86487 L .34679 .86536 L 0 1 .507 r
F
0 g
.34679 .86536 m
.35032 .86949 L
s
.35027 .86186 m .33946 .86046 L .34247 .86487 L 0 1 .507 r
F
0 g
.33954 .86845 m
.34247 .86487 L
s
.48009 .48301 m .47139 .48758 L .47226 .48652 L 0 0 0 r
F
0 g
.47179 .48559 m
.47371 .48438 L
s
.48009 .48301 m .47831 .48601 L .47139 .48758 L 0 0 0 r
F
0 g
.46586 .48936 m
.47179 .48559 L
s
.48009 .48301 m .48839 .48283 L .47831 .48601 L 0 0 0 r
F
.48009 .48301 m .49622 .47932 L .48839 .48283 L F
.48009 .48301 m .49657 .47782 L .49622 .47932 L F
0 g
.48966 .4794 m
.49657 .47782 L
s
.49657 .47782 m
.50406 .47507 L
s
.46795 .96989 m .46576 .96454 L .4617 .96087 L 0 .491 .354 r
F
.47341 .92164 m .46439 .92204 L .46228 .92041 L 0 .082 .038 r
F
0 g
.45822 .92079 m
.46228 .92041 L
s
.28181 .90239 m .27437 .90457 L .27896 .9048 L 0 1 .497 r
F
0 g
.27896 .9048 m
.28371 .90749 L
s
.28181 .90239 m .27031 .9016 L .27437 .90457 L 0 1 .497 r
F
0 g
.27233 .90713 m
.27437 .90457 L
s
.53359 .62078 m
.53875 .62264 L
s
.52934 .62304 m
.53359 .62078 L
s
.47784 .87498 m .46955 .86898 L .47424 .87407 L 0 .694 .317 r
F
.47782 .88475 m .47424 .87407 L .46955 .86898 L 0 .669 .318 r
F
0 g
.46615 .86162 m
.46955 .86898 L
s
.46848 .86889 m
.46955 .86898 L
s
.68698 1.09143 m .68173 1.08809 L .68029 1.08466 L 0 .014 .006 r
F
0 g
.67338 1.08308 m
.68029 1.08466 L
s
.45837 .92087 m
.45838 .92088 L
s
.45828 .92082 m
.45837 .92087 L
s
.45822 .92079 m
.45828 .92082 L
s
.45822 .92079 m
.45858 .92063 L
s
.45822 .92079 m
.45842 .92089 L
s
.45842 .92089 m
.45857 .92096 L
s
.44482 .90605 m .43551 .89957 L .43269 .90069 L 0 1 .485 r
F
0 g
.42861 .89787 m
.43269 .90069 L
s
.62326 .72188 m .62693 .72357 L .6232 .71351 L 0 .193 .233 r
F
0 g
.6188 .69809 m
.6232 .71351 L
s
.62326 .72188 m .63278 .74492 L .62693 .72357 L 0 .193 .233 r
F
.62326 .72188 m .63685 .76332 L .63278 .74492 L F
0 g
.63447 .73117 m
.63861 .75825 L
s
.62326 .72188 m .62707 .74314 L .63292 .76453 L 0 .193 .233 r
F
0 g
.62921 .76083 m
.62955 .76439 L
s
.62462 .76244 m
.62474 .76711 L
s
.62105 .71142 m
.62326 .72188 L
s
.6232 .71351 m
.62326 .72188 L
s
.5275 .82803 m
.5289 .82073 L
s
.52944 .81791 m
.52951 .81751 L
s
.53687 1.09088 m
.53873 1.09146 L
s
.54735 1.10154 m .54206 1.09613 L .53874 1.09147 L 0 .232 0 r
F
0 g
.53874 1.09147 m
.54206 1.09613 L
s
.33815 .72348 m .32836 .73053 L .33238 .73093 L 0 1 .422 r
F
0 g
.33238 .73093 m
.33322 .73856 L
s
.33815 .72348 m .32824 .72247 L .32836 .73053 L 0 1 .422 r
F
.33815 .72348 m .33212 .71211 L .32824 .72247 L F
.33815 .72348 m .3379 .70466 L .33212 .71211 L F
.33815 .72348 m .34173 .70509 L .3379 .70466 L F
.33815 .72348 m .34184 .71315 L .34173 .70509 L F
0 g
.33815 .72348 m
.3384 .73166 L
s
.33238 .73093 m
.33815 .72348 L
s
.32994 .76134 m .31969 .75837 L .32072 .76014 L 0 .677 .328 r
F
0 g
.31701 .76063 m
.32072 .76014 L
s
.30971 .74674 m
.31046 .75428 L
s
.49203 .866 m .48423 .84826 L .48849 .85941 L 0 .662 .301 r
F
.49105 .87222 m .48849 .85941 L .48423 .84826 L 0 .654 .302 r
F
0 g
.48388 .84772 m
.48423 .84826 L
s
.48156 .83721 m
.48423 .84826 L
s
.70309 .61664 m .71849 .61652 L .71247 .61462 L 0 .889 .305 r
F
0 g
.71849 .61652 m
.72004 .6183 L
s
.71849 .61652 m
.72596 .61755 L
s
.80478 1.03244 m .80058 1.03793 L .80058 1.04069 L 0 1 .344 r
F
0 g
.79339 1.04528 m
.80058 1.04069 L
s
.75565 .8934 m .76472 .89082 L .76011 .89127 L 0 1 .387 r
F
.74417 .89421 m .75565 .8934 L .75319 .89196 L 0 .997 .336 r
F
.46759 .89694 m .46714 .89224 L .46336 .88674 L 0 .674 .332 r
F
.5285 1.08542 m .52366 1.07999 L .52023 1.07584 L 0 .114 0 r
F
.45993 .51813 m .46878 .51134 L .47462 .50536 L 0 1 .333 r
F
.74695 .61769 m .74978 .61422 L .7458 .61482 L 0 1 .41 r
F
.74695 .61769 m .75707 .61655 L .74978 .61422 L F
.47622 .93098 m .47086 .93139 L .47443 .93188 L 0 .787 .462 r
F
.47944 .9351 m .47443 .93188 L .47086 .93139 L 0 .75 .456 r
F
0 g
.46944 .93243 m
.47086 .93139 L
s
.46708 .92959 m
.47086 .93139 L
s
.49031 .87875 m .47898 .85577 L .4821 .86523 L 0 .643 .303 r
F
0 g
.47938 .85199 m
.48279 .85635 L
s
.47525 .85348 m
.47898 .85577 L
s
.49463 .85476 m .49525 .85273 L .49313 .83997 L 0 .668 .297 r
F
0 g
.49457 .84864 m
.49472 .84955 L
s
.49363 .84302 m
.49371 .84346 L
s
.49313 .83999 m
.49336 .84139 L
s
.49313 .83997 m
.49313 .83999 L
s
.49336 .84139 m
.49363 .84302 L
s
.49492 .84703 m
.49568 .85001 L
s
.49483 .84667 m
.49492 .84703 L
s
.49408 .84372 m
.49483 .84667 L
s
.4937 .84223 m
.49408 .84372 L
s
.49313 .83997 m
.49342 .84113 L
s
.49342 .84113 m
.4937 .84223 L
s
.49373 .83818 m
.49493 .84223 L
s
.49493 .84223 m
.49543 .84389 L
s
.49373 .83822 m
.49448 .84202 L
s
.49448 .84202 m
.49474 .84334 L
s
.49474 .84334 m
.49539 .84668 L
s
.5442 .82281 m
.54461 .8116 L
s
.45803 .91466 m .45109 .91455 L .45541 .9155 L 0 .951 .478 r
F
.46051 .91976 m .45541 .9155 L .45109 .91455 L 0 .938 .481 r
F
0 g
.45071 .91472 m
.45109 .91455 L
s
.44711 .91205 m
.45109 .91455 L
s
.48544 .92221 m .47986 .91864 L .48343 .92015 L 0 .135 .062 r
F
.48788 .91911 m .48343 .92015 L .47986 .91864 L 0 .112 .061 r
F
0 g
.4782 .91652 m
.47986 .91864 L
s
.47768 .91854 m
.47986 .91864 L
s
.79559 .62127 m
.80258 .62522 L
s
.2129 .89836 m .20274 .88853 L .20019 .89233 L 0 1 .525 r
F
.2129 .89836 m .20738 .88896 L .20274 .88853 L F
.2129 .89836 m .21173 .89318 L .20738 .88896 L F
.22437 .89894 m .21173 .89318 L .2129 .89836 L 0 1 .522 r
F
0 g
.21034 .90213 m
.2129 .89836 L
s
.2129 .89836 m
.21719 .90234 L
s
.63613 .7851 m
.63614 .78494 L
s
.63611 .78492 m
.63614 .78494 L
s
.47097 .95574 m .46066 .95108 L .46264 .95648 L 0 .502 .341 r
F
.47097 .95574 m .46184 .94699 L .46066 .95108 L F
0 g
.45651 .9472 m
.46066 .95108 L
s
.48725 .78166 m .48163 .78797 L .48389 .78349 L 0 .301 .088 r
F
.48725 .78166 m .48191 .79348 L .48163 .78797 L F
.48725 .78166 m .48457 .79634 L .48191 .79348 L F
0 g
.48389 .78349 m
.48402 .77872 L
s
.48725 .78166 m .48794 .79449 L .48457 .79634 L 0 .301 .088 r
F
.48725 .78166 m .48976 .78918 L .48794 .79449 L F
.48725 .78166 m .48946 .78369 L .48976 .78918 L F
0 g
.48946 .78369 m
.49247 .77998 L
s
.48725 .78166 m
.48727 .77774 L
s
.48389 .78349 m
.48725 .78166 L
s
.36107 .86348 m .35328 .86615 L .3576 .86672 L 0 1 .504 r
F
0 g
.3576 .86672 m
.3611 .87073 L
s
.36107 .86348 m .35027 .86186 L .35328 .86615 L 0 1 .504 r
F
0 g
.35032 .86949 m
.35328 .86615 L
s
.47338 .92679 m .46354 .92475 L .46739 .92678 L 0 .816 .464 r
F
.47338 .92679 m .46226 .92277 L .46354 .92475 L F
0 g
.46233 .92549 m
.46354 .92475 L
s
.4656 .92767 m
.46691 .92702 L
s
.42237 .55783 m .41283 .55994 L .41493 .56192 L 0 1 .454 r
F
.42237 .55783 m .41742 .55314 L .41283 .55994 L F
.42237 .55783 m .42565 .54606 L .41742 .55314 L F
.42237 .55783 m .43309 .54198 L .42565 .54606 L F
.42237 .55783 m .43477 .54361 L .43309 .54198 L F
0 g
.43018 .55041 m
.43477 .54361 L
s
.41808 .56496 m
.42237 .55783 L
s
.43477 .54361 m
.44216 .53932 L
s
.76722 .61527 m .785 .62205 L .78357 .61842 L 0 1 .471 r
F
0 g
.785 .62212 m
.78501 .62205 L
s
.47098 .92031 m .4595 .91222 L .46053 .9174 L 0 .597 .332 r
F
.47098 .92031 m .46196 .90949 L .4595 .91222 L F
0 g
.45833 .91087 m
.4595 .91222 L
s
.45858 .92063 m
.45863 .9206 L
s
.63881 .54048 m
.63912 .54113 L
s
.63912 .54113 m
.64005 .54311 L
s
.49547 .95065 m .49369 .94916 L .49081 .9482 L 0 .486 .378 r
F
.4236 .77536 m .41347 .77577 L .41466 .77457 L 0 0 0 r
F
0 g
.40998 .77391 m
.41466 .77457 L
s
.4236 .77536 m .41603 .77719 L .41347 .77577 L 0 0 0 r
F
.4236 .77536 m .42086 .77816 L .41603 .77719 L F
.4236 .77536 m .42473 .77804 L .42086 .77816 L F
.4236 .77536 m .4259 .77684 L .42473 .77804 L F
0 g
.4236 .77536 m
.42497 .77382 L
s
.41879 .77439 m
.4236 .77536 L
s
.51106 .92652 m .50898 .91051 L .51021 .91472 L 0 .206 .095 r
F
.51106 .92652 m .50803 .91143 L .50898 .91051 L F
0 g
.50898 .91051 m
.50918 .90631 L
s
.47818 .89459 m .46637 .88049 L .46662 .88519 L 0 .641 .318 r
F
.47818 .89459 m .46968 .88017 L .46637 .88049 L F
0 g
.46573 .87945 m
.46637 .88049 L
s
.46336 .88674 m
.46374 .88729 L
s
.46374 .88729 m
.46647 .89127 L
s
.46336 .88674 m
.46418 .88635 L
s
.46637 .88049 m
.46842 .88029 L
s
.46842 .88029 m
.46846 .88029 L
s
.31759 .66549 m .30767 .65931 L .30677 .66525 L 0 1 .49 r
F
0 g
.30049 .66816 m
.30677 .66525 L
s
.3584 .67794 m
.35858 .67638 L
s
.35858 .67638 m
.3586 .67617 L
s
.45595 .77841 m
.45653 .77821 L
s
.38362 .87416 m
.38583 .87258 L
s
.34184 .71315 m
.34746 .70596 L
s
.35924 .59016 m
.36212 .58533 L
s
.36212 .58533 m
.36325 .58343 L
s
.22219 .74308 m .21364 .73492 L .21087 .74085 L 0 1 .538 r
F
.22219 .74308 m .21909 .73132 L .21364 .73492 L F
.22219 .74308 m .22356 .73248 L .21909 .73132 L F
.22219 .74308 m .22488 .73753 L .22356 .73248 L F
0 g
.21677 .74664 m
.22219 .74308 L
s
.22219 .74308 m
.2236 .74782 L
s
.55418 .62358 m .55156 .62731 L .55046 .62472 L 0 .205 .038 r
F
.55418 .62358 m .55727 .63077 L .55156 .62731 L F
.55418 .62358 m .56379 .63278 L .55727 .63077 L F
.55418 .62358 m .5675 .63162 L .56379 .63278 L F
0 g
.56781 .62757 m
.56913 .62722 L
s
.55418 .62358 m .56593 .62807 L .5675 .63162 L 0 .205 .038 r
F
0 g
.56593 .62807 m
.56781 .62757 L
s
.56023 .62463 m
.56593 .62807 L
s
.76248 1.06105 m .76781 1.05832 L .77279 1.05513 L 0 .801 .187 r
F
0 g
.76111 1.06214 m
.76781 1.05832 L
s
.76708 1.05944 m
.76781 1.05832 L
s
.50006 .95433 m .4982 .95287 L .4956 .952 L 0 .42 .334 r
F
.49108 .9469 m .48938 .94537 L .48625 .94429 L 0 .572 .41 r
F
.43608 .92109 m .43058 .92181 L .4261 .92118 L 0 0 0 r
F
.43608 .92109 m .43486 .92177 L .43058 .92181 L F
.447 .92272 m .43486 .92177 L .43608 .92109 L F
0 g
.43608 .92109 m
.44022 .92101 L
s
.43375 .92029 m
.43608 .92109 L
s
.68698 1.09143 m .69018 1.08425 L .69568 1.08664 L 0 .014 .006 r
F
0 g
.68359 1.0834 m
.69018 1.08425 L
s
.82662 .87675 m .83382 .88466 L .83767 .88042 L 0 1 .509 r
F
.82662 .87675 m .82922 .88504 L .83382 .88466 L F
0 g
.83382 .88466 m
.83583 .88833 L
s
.41899 .88582 m .41095 .88633 L .41562 .88742 L 0 1 .488 r
F
.41899 .88582 m .40729 .88285 L .41095 .88633 L F
0 g
.40911 .88743 m
.41095 .88633 L
s
.47784 .87498 m .47795 .87109 L .47454 .86373 L 0 .694 .317 r
F
.77209 .79642 m .78297 .78672 L .78527 .79239 L 0 .165 .038 r
F
0 g
.78297 .78672 m
.78685 .78495 L
s
.25519 .54943 m
.25843 .54023 L
s
.63767 .62574 m .65353 .62309 L .65112 .62251 L 0 .836 .248 r
F
0 g
.65353 .62309 m
.66009 .62258 L
s
.65267 .56883 m
.65434 .57319 L
s
.6522 .56758 m
.65267 .56883 L
s
.64901 .56135 m
.65082 .56489 L
s
.65082 .56489 m
.6522 .56758 L
s
.45803 .91466 m .44872 .90883 L .44611 .90967 L 0 .951 .478 r
F
0 g
.442 .90717 m
.44611 .90967 L
s
.25396 .66008 m .24261 .66409 L .24691 .6652 L 0 1 .519 r
F
0 g
.24691 .6652 m
.24719 .67192 L
s
.44346 .64932 m
.44611 .64755 L
s
.49018 1.0263 m .48327 1.02317 L .48696 1.02866 L 0 .26 .302 r
F
.49018 1.0263 m .4817 1.01835 L .48327 1.02317 L F
0 g
.47931 1.0197 m
.48327 1.02317 L
s
.40489 .66647 m
.41072 .66426 L
s
.46049 .92213 m .45101 .92265 L .44876 .92131 L 0 .02 .009 r
F
0 g
.44453 .92159 m
.44876 .92131 L
s
.4036 .5764 m .39371 .57767 L .3962 .58013 L 0 1 .467 r
F
0 g
.39293 .58764 m
.3962 .58013 L
s
.4036 .5764 m .39766 .57061 L .39371 .57767 L 0 1 .467 r
F
.4036 .5764 m .40542 .56366 L .39766 .57061 L F
.4036 .5764 m .41283 .55994 L .40542 .56366 L F
.4036 .5764 m .41493 .56192 L .41283 .55994 L F
.4036 .5764 m .41098 .56897 L .41493 .56192 L F
0 g
.41493 .56192 m
.42237 .55783 L
s
.39993 .58391 m
.4036 .5764 L
s
.3962 .58013 m
.4036 .5764 L
s
.41098 .56897 m
.41808 .56496 L
s
.41098 .56897 m
.41493 .56192 L
s
.35403 .67515 m .3495 .67383 L .35307 .67507 L 0 0 0 r
F
.35432 .67476 m .35145 .67418 L .35403 .67515 L 0 1 .383 r
F
.3596 .66754 m .35145 .67418 L .35432 .67476 L F
.3596 .66754 m .35088 .66431 L .34969 .67383 L F
.35145 .67418 m .34969 .67383 L .3495 .67383 L 0 0 0 r
F
.35145 .67418 m .3495 .67383 L .35403 .67515 L F
.35145 .67418 m .34969 .67383 L .34945 .67582 L 0 1 .383 r
F
.3596 .66754 m .34969 .67383 L .35145 .67418 L F
.35145 .67418 m .34971 .67383 L .34969 .67383 L 0 0 0 r
F
.3594 .6756 m .35063 .67383 L .34971 .67383 L F
.3594 .6756 m .34971 .67383 L .35145 .67418 L F
.3594 .6756 m .35145 .67418 L .35403 .67515 L F
.35403 .67515 m .34945 .67582 L .35303 .67651 L 0 1 .383 r
F
.35145 .67418 m .34945 .67582 L .35403 .67515 L F
0 g
.3586 .67617 m
.35867 .67562 L
s
.35867 .67562 m
.35868 .67554 L
s
.35259 .67767 m
.35281 .67647 L
s
.3596 .66754 m .35638 .64968 L .35088 .66431 L 0 1 .383 r
F
.3596 .66754 m .36294 .64073 L .35638 .64968 L F
0 g
.35443 .6746 m
.3596 .66754 L
s
.35869 .67546 m
.3596 .66754 L
s
.82662 .87675 m .82613 .88166 L .82922 .88504 L 0 1 .509 r
F
0 g
.82439 .889 m
.82922 .88504 L
s
.43169 .8965 m .42263 .88923 L .41956 .89061 L 0 1 .488 r
F
0 g
.41562 .88742 m
.41956 .89061 L
s
.26456 .66328 m .25908 .6521 L .25396 .66008 L 0 1 .519 r
F
.26456 .66328 m .266 .64727 L .25908 .6521 L F
.26456 .66328 m .2701 .64883 L .266 .64727 L F
.26456 .66328 m .26948 .6557 L .2701 .64883 L F
0 g
.25963 .66671 m
.26456 .66328 L
s
.2641 .66987 m
.26456 .66328 L
s
.37235 .86546 m .36423 .86768 L .36874 .86839 L 0 1 .5 r
F
0 g
.36874 .86839 m
.37236 .87229 L
s
.37235 .86546 m .36107 .86348 L .36423 .86768 L 0 1 .5 r
F
0 g
.3611 .87073 m
.36423 .86768 L
s
.36294 .64073 m
.36294 .64073 L
s
.45423 .5242 m
.45993 .51813 L
s
.44685 .52848 m
.45423 .5242 L
s
.45646 .49422 m .46586 .48936 L .47226 .48652 L 0 0 0 r
F
0 g
.45066 .49687 m
.45646 .49422 L
s
.51106 .92652 m .50818 .91664 L .50803 .91143 L 0 .206 .095 r
F
0 g
.50704 .9099 m
.50803 .91143 L
s
.51024 .91391 m
.51042 .90916 L
s
.31969 .75837 m .31036 .75734 L .3145 .75849 L 0 .801 .388 r
F
0 g
.3145 .75849 m
.31578 .76023 L
s
.38498 .91626 m .37793 .91602 L .38234 .91643 L 0 .597 .239 r
F
0 g
.38234 .91643 m
.38672 .91716 L
s
.38498 .91626 m .37389 .915 L .37793 .91602 L 0 .597 .239 r
F
0 g
.37579 .91636 m
.37793 .91602 L
s
.50478 .95796 m .50288 .95652 L .50058 .95571 L 0 .376 .277 r
F
.74417 .89421 m .75319 .89196 L .74858 .89242 L 0 .997 .336 r
F
.73006 .89525 m .74417 .89421 L .74086 .89322 L 0 .769 .26 r
F
.47338 .92679 m .46439 .92204 L .46226 .92277 L 0 .816 .464 r
F
0 g
.45857 .92096 m
.46226 .92277 L
s
.48691 .94306 m .48532 .9415 L .48197 .94027 L 0 .644 .432 r
F
.43234 .65452 m .42389 .65715 L .4264 .65686 L 0 1 .248 r
F
.43234 .65452 m .42636 .6552 L .42389 .65715 L F
0 g
.42452 .65877 m
.4264 .65686 L
s
.43234 .65452 m .43216 .65231 L .42636 .6552 L 0 1 .248 r
F
.43234 .65452 m .43811 .64997 L .43216 .65231 L F
.43234 .65452 m .44022 .64974 L .43811 .64997 L F
.43234 .65452 m .43775 .65169 L .44022 .64974 L F
0 g
.4264 .65686 m
.43234 .65452 L
s
.43775 .65169 m
.44346 .64932 L
s
.43775 .65169 m
.43775 .65169 L
s
.22437 .89894 m .21433 .88961 L .21173 .89318 L 0 1 .522 r
F
.22437 .89894 m .21897 .89005 L .21433 .88961 L F
.22437 .89894 m .22327 .89405 L .21897 .89005 L F
.23585 .89955 m .22327 .89405 L .22437 .89894 L 0 1 .519 r
F
0 g
.22176 .90248 m
.22437 .89894 L
s
.22437 .89894 m
.22862 .90271 L
s
.47098 .92031 m .46053 .9174 L .46439 .92204 L 0 .597 .332 r
F
0 g
.46053 .9174 m
.46127 .91829 L
s
.4595 .91892 m
.46053 .9174 L
s
.60932 .6356 m .62425 .62954 L .62168 .63033 L 0 0 0 r
F
0 g
.62425 .62954 m
.63055 .62829 L
s
.29594 .90346 m .28662 .90521 L .29225 .90553 L 0 1 .486 r
F
0 g
.29225 .90553 m
.29769 .90802 L
s
.29594 .90346 m .28181 .90239 L .28662 .90521 L 0 1 .486 r
F
0 g
.28371 .90749 m
.28662 .90521 L
s
.376 .59455 m
.37926 .58704 L
s
.38689 .77184 m .37772 .77029 L .3819 .77081 L 0 0 0 r
F
0 g
.3819 .77081 m
.38356 .7709 L
s
.49712 .48908 m
.50405 .4847 L
s
.48961 .49299 m
.49712 .48908 L
s
.47818 .89459 m .46662 .88519 L .47026 .89137 L 0 .641 .318 r
F
0 g
.46662 .88519 m
.46709 .88599 L
s
.46418 .88635 m
.46662 .88519 L
s
.48544 .92221 m .47709 .9218 L .47509 .91975 L 0 .135 .062 r
F
0 g
.4713 .92 m
.47509 .91975 L
s
.51607 1.07168 m .51638 1.07197 L .51983 1.07591 L 0 .003 .157 r
F
0 g
.51638 1.07197 m
.52023 1.07584 L
s
.57836 .66153 m .5781 .66074 L .57609 .66408 L 0 0 0 r
F
.57836 .66153 m .5837 .65428 L .5781 .66074 L F
.47097 .95574 m .46264 .95648 L .46654 .96023 L 0 .502 .341 r
F
0 g
.4617 .96087 m
.46264 .95648 L
s
.49806 .9227 m .49107 .92007 L .48947 .91723 L 0 .167 .08 r
F
0 g
.48621 .91698 m
.48947 .91723 L
s
.36189 .63504 m .35475 .6352 L .35804 .6372 L 0 .847 .32 r
F
.36189 .63504 m .3539 .62456 L .35475 .6352 L F
0 g
.36189 .63504 m
.36294 .64072 L
s
.35804 .6372 m
.36189 .63504 L
s
.4898 .88556 m .47848 .86147 L .47822 .86531 L 0 .629 .304 r
F
.4898 .88556 m .4821 .86523 L .47848 .86147 L F
0 g
.47525 .85348 m
.47848 .86147 L
s
.47848 .86147 m
.48158 .86469 L
s
.49639 1.04245 m .49259 1.03693 L .48888 1.03339 L 0 .216 .262 r
F
.70309 .61664 m .70517 .6139 L .7015 .61484 L 0 .889 .305 r
F
.70309 .61664 m .71247 .61462 L .70517 .6139 L F
0 g
.69601 .61626 m
.70309 .61664 L
s
.48218 1.01259 m .47907 1.00713 L .4752 1.00371 L 0 .314 .335 r
F
.47996 .99653 m .47157 .99345 L .47452 .99893 L 0 .337 .335 r
F
.47996 .99653 m .4712 .98871 L .47157 .99345 L F
0 g
.46751 .98997 m
.47157 .99345 L
s
.53478 1.09257 m .53522 1.08928 L .53687 1.09088 L 0 .245 0 r
F
.53478 1.09257 m .53343 1.08851 L .53522 1.08928 L F
0 g
.53522 1.08928 m
.53522 1.08928 L
s
.61477 .68134 m
.61498 .68184 L
s
.61755 .68799 m
.61828 .68973 L
s
.61876 .69086 m
.61916 .69183 L
s
.61916 .69183 m
.61983 .69342 L
s
.61983 .69342 m
.62086 .69589 L
s
.81505 .87842 m .82231 .88562 L .82613 .88166 L 0 1 .499 r
F
.81505 .87842 m .81771 .88601 L .82231 .88562 L F
0 g
.82231 .88562 m
.82439 .889 L
s
.52181 .97081 m .52319 .9714 L .52393 .97186 L 0 0 0 r
F
.52181 .97081 m .52207 .97073 L .52319 .9714 L F
0 g
.52318 .97119 m
.52319 .9714 L
s
.50432 .91522 m .50342 .9162 L .5012 .91439 L 0 .124 .078 r
F
0 g
.5012 .91439 m
.50284 .91572 L
s
.56222 .71419 m .56294 .70232 L .56091 .71253 L 0 1 .19 r
F
.55693 .75354 m .56222 .71419 L .55788 .73104 L 0 1 .265 r
F
.40729 .88285 m .3987 .87448 L .39535 .87649 L 0 1 .494 r
F
.40729 .88285 m .4034 .87569 L .3987 .87448 L F
.40729 .88285 m .40708 .87928 L .4034 .87569 L F
.41899 .88582 m .40708 .87928 L .40729 .88285 L 0 1 .488 r
F
0 g
.40729 .88285 m
.41095 .88633 L
s
.40394 .88485 m
.40729 .88285 L
s
.3435 .67459 m
.3495 .67383 L
s
.49323 .86016 m .49377 .85794 L .49135 .84603 L 0 .666 .299 r
F
0 g
.4922 .85021 m
.49222 .85034 L
s
.49181 .84832 m
.4922 .85021 L
s
.49135 .84603 m
.49181 .84832 L
s
.49306 .85058 m
.49329 .8512 L
s
.49259 .84934 m
.49306 .85058 L
s
.49135 .84603 m
.49259 .84934 L
s
.49371 .84346 m
.49457 .84864 L
s
.3857 .67286 m .37878 .67372 L .38209 .67352 L 0 1 .262 r
F
.3857 .67286 m .37747 .6735 L .37878 .67372 L F
0 g
.38209 .67352 m
.38209 .67352 L
s
.38128 .67498 m
.38209 .67352 L
s
.3857 .67286 m .37905 .67301 L .37747 .6735 L 0 1 .262 r
F
.3857 .67286 m .38266 .67236 L .37905 .67301 L F
.3857 .67286 m .38589 .67197 L .38266 .67236 L F
.3857 .67286 m .38719 .67219 L .38589 .67197 L F
0 g
.3857 .67286 m
.38706 .67326 L
s
.38209 .67352 m
.3857 .67286 L
s
.38719 .67219 m
.39072 .6715 L
s
.32306 .7376 m
.32836 .73053 L
s
.2846 .93448 m .2733 .93296 L .27134 .93318 L 0 .547 .208 r
F
.2846 .93448 m .27789 .93343 L .2733 .93296 L F
.2846 .93448 m .28274 .93408 L .27789 .93343 L F
0 g
.28262 .93469 m
.2846 .93448 L
s
.51445 .9652 m .51639 .96704 L .51612 .96661 L 0 .244 .203 r
F
.5193 .96887 m .51612 .96661 L .51639 .96704 L 0 .155 .175 r
F
0 g
.51639 .96704 m
.5184 .96847 L
s
.51477 .96627 m
.51639 .96704 L
s
.34019 .76397 m .33258 .76045 L .32994 .76134 L 0 .607 .267 r
F
.34019 .76397 m .33757 .76077 L .33258 .76045 L F
.34019 .76397 m .34157 .76207 L .33757 .76077 L F
.34019 .76397 m .34269 .76345 L .34157 .76207 L F
0 g
.33522 .76366 m
.34019 .76397 L
s
.34019 .76397 m
.34143 .76498 L
s
.40813 .9197 m .4006 .91855 L .40521 .9192 L 0 0 0 r
F
.40813 .9197 m .40236 .91877 L .4006 .91855 L F
.40236 .91877 m .39655 .91784 L .4006 .91855 L F
.39867 .9183 m .4006 .91855 L .39812 .91825 L F
.41068 .91956 m .4006 .91855 L .39867 .9183 L F
.41068 .91956 m .40521 .9192 L .4006 .91855 L F
.41068 .91956 m .40953 .91963 L .40521 .9192 L F
.42198 .92098 m .40953 .91963 L .41068 .91956 L F
0 g
.41068 .91956 m
.4149 .91987 L
s
.40819 .91926 m
.41068 .91956 L
s
.46699 .94304 m .46184 .94699 L .46541 .94692 L 0 .558 .344 r
F
.47097 .95574 m .46541 .94692 L .46184 .94699 L 0 .502 .341 r
F
0 g
.46066 .95108 m
.46184 .94699 L
s
.45786 .94295 m
.46184 .94699 L
s
.66639 .6821 m .66842 .66372 L .66478 .65543 L 0 .282 .248 r
F
0 g
.66478 .65543 m
.66552 .66759 L
s
.66175 .64244 m
.66478 .65543 L
s
.46905 .90865 m .46196 .90949 L .46629 .91101 L 0 .638 .332 r
F
.47098 .92031 m .46629 .91101 L .46196 .90949 L 0 .597 .332 r
F
0 g
.4595 .91222 m
.46196 .90949 L
s
.45886 .9054 m
.46196 .90949 L
s
.81505 .87842 m .81459 .88294 L .81771 .88601 L 0 1 .499 r
F
0 g
.81295 .88968 m
.81771 .88601 L
s
.55693 .75354 m .56033 .74969 L .56466 .7328 L 0 1 .265 r
F
.45646 .49422 m .44701 .49915 L .44838 .49841 L 0 0 0 r
F
0 g
.44868 .49821 m
.45066 .49687 L
s
.44839 .4984 m
.44868 .49821 L
s
.43342 .50835 m .44255 .50236 L .44838 .49841 L 0 .839 .179 r
F
.43342 .50835 m .44838 .49841 L .44701 .49915 L F
.45646 .49422 m .45341 .49631 L .44701 .49915 L 0 0 0 r
F
0 g
.44255 .50236 m
.44255 .50236 L
s
.44255 .50236 m
.44783 .49879 L
s
.45646 .49422 m .46331 .49178 L .45341 .49631 L 0 0 0 r
F
.45646 .49422 m .47139 .48758 L .46331 .49178 L F
.45646 .49422 m .47226 .48652 L .47139 .48758 L F
0 g
.46586 .48936 m
.47226 .48652 L
s
.44838 .49841 m
.45646 .49422 L
s
.47226 .48652 m
.48009 .48301 L
s
.4527 .77865 m .44595 .78023 L .44951 .77907 L 0 .124 .022 r
F
.4527 .77865 m .44388 .78159 L .44595 .78023 L F
0 g
.44973 .77862 m
.4506 .77688 L
s
.4527 .77865 m .44469 .78222 L .44388 .78159 L 0 .124 .022 r
F
.4527 .77865 m .4479 .7818 L .44469 .78222 L F
.4527 .77865 m .45136 .78061 L .4479 .7818 L F
0 g
.4495 .77907 m
.44973 .77862 L
s
.4527 .77865 m .45341 .77926 L .45136 .78061 L 0 .124 .022 r
F
0 g
.4527 .77865 m
.45484 .77674 L
s
.44951 .77907 m
.4527 .77865 L
s
.45341 .77926 m
.45595 .77841 L
s
.34794 .69689 m .3379 .70466 L .34173 .70509 L 0 1 .406 r
F
0 g
.34173 .70509 m
.34184 .71315 L
s
.34794 .69689 m .33854 .69563 L .3379 .70466 L 0 1 .406 r
F
.34794 .69689 m .34323 .68401 L .33854 .69563 L F
.34794 .69689 m .34945 .67582 L .34323 .68401 L F
.34794 .69689 m .35303 .67651 L .34945 .67582 L F
.34794 .69689 m .35239 .68554 L .35303 .67651 L F
0 g
.35239 .68554 m
.3584 .67794 L
s
.35303 .67651 m
.35403 .67515 L
s
.34746 .70596 m
.34794 .69689 L
s
.34173 .70509 m
.34794 .69689 L
s
.35239 .68554 m
.35303 .67651 L
s
.3628 .91395 m .35339 .91078 L .35104 .91156 L 0 .755 .308 r
F
.3628 .91395 m .3577 .91132 L .35339 .91078 L F
.3628 .91395 m .36173 .91268 L .3577 .91132 L F
0 g
.36044 .91473 m
.3628 .91395 L
s
.37389 .915 m .36173 .91268 L .3628 .91395 L 0 .658 .256 r
F
0 g
.3628 .91395 m
.36691 .91515 L
s
.52181 .97081 m .52393 .97186 L .52383 .9719 L 0 0 0 r
F
0 g
.52267 .97109 m
.52319 .9714 L
s
.52393 .97186 m
.52402 .9719 L
s
.31969 .75837 m .30943 .75514 L .31036 .75734 L 0 .801 .388 r
F
0 g
.30804 .75777 m
.31036 .75734 L
s
.38362 .86777 m .37551 .86955 L .38003 .87038 L 0 1 .496 r
F
0 g
.38003 .87038 m
.38362 .87416 L
s
.38362 .86777 m .37235 .86546 L .37551 .86955 L 0 1 .496 r
F
0 g
.37236 .87229 m
.37551 .86955 L
s
.47338 .92679 m .46739 .92678 L .47125 .92751 L 0 .816 .464 r
F
.47622 .93098 m .47125 .92751 L .46739 .92678 L 0 .787 .462 r
F
0 g
.46354 .92475 m
.46739 .92678 L
s
.46691 .92702 m
.46739 .92678 L
s
.47782 .88475 m .46968 .88017 L .47435 .88446 L 0 .669 .318 r
F
.47818 .89459 m .47435 .88446 L .46968 .88017 L 0 .641 .318 r
F
0 g
.46846 .88029 m
.46968 .88017 L
s
.46907 .87902 m
.46968 .88017 L
s
.46709 .88599 m
.47023 .89132 L
s
.49105 .87222 m .48301 .85663 L .48744 .86661 L 0 .654 .302 r
F
.49031 .87875 m .48744 .86661 L .48301 .85663 L 0 .643 .303 r
F
0 g
.48279 .85635 m
.48301 .85663 L
s
.4801 .84639 m
.48301 .85663 L
s
.39535 .87649 m
.39681 .87562 L
s
.7831 1.0499 m .79432 1.04353 L .79014 1.04554 L 0 .961 .237 r
F
.77279 1.05513 m .7831 1.0499 L .78387 1.04875 L 0 .878 .216 r
F
.25396 .66008 m .24334 .65705 L .24261 .66409 L 0 1 .519 r
F
0 g
.23632 .6694 m
.24261 .66409 L
s
.24691 .6652 m
.25027 .66277 L
s
.50795 .89296 m .50368 .83767 L .50279 .83841 L 0 .496 .276 r
F
.50795 .89296 m .50566 .85384 L .50368 .83767 L F
0 g
.50304 .82113 m
.50368 .83767 L
s
.48218 1.01259 m .4817 1.01835 L .48331 1.0174 L 0 .314 .335 r
F
.49018 1.0263 m .48331 1.0174 L .4817 1.01835 L 0 .26 .302 r
F
0 g
.4817 1.01835 m
.48327 1.02317 L
s
.47784 1.01492 m
.4817 1.01835 L
s
.50795 .89296 m .50279 .83841 L .50376 .85508 L 0 .496 .276 r
F
0 g
.50267 .83766 m
.50279 .83841 L
s
.50601 1.05644 m .5008 1.05239 L .50514 1.05784 L 0 .109 .185 r
F
.50601 1.05644 m .49805 1.0478 L .5008 1.05239 L F
0 g
.49704 1.04875 m
.5008 1.05239 L
s
.46699 .94304 m .46553 .93794 L .46154 .93391 L 0 .558 .344 r
F
.21087 .74085 m .20239 .73238 L .19953 .73868 L 0 1 .539 r
F
0 g
.19953 .73868 m
.20082 .74396 L
s
.21087 .74085 m .2079 .72848 L .20239 .73238 L 0 1 .539 r
F
.21087 .74085 m .21238 .7296 L .2079 .72848 L F
.21087 .74085 m .21364 .73492 L .21238 .7296 L F
0 g
.20538 .74471 m
.21087 .74085 L
s
.21087 .74085 m
.21221 .74586 L
s
.48302 .93913 m .48155 .93753 L .47802 .93613 L 0 .703 .447 r
F
.72188 .61255 m .73587 .61624 L .73984 .61569 L 0 1 .395 r
F
.72188 .61255 m .72818 .6149 L .73587 .61624 L F
0 g
.73587 .61624 m
.73686 .61868 L
s
.23585 .89955 m .22593 .89071 L .22327 .89405 L 0 1 .519 r
F
.23585 .89955 m .23057 .89115 L .22593 .89071 L F
.23585 .89955 m .23482 .89495 L .23057 .89115 L F
.24733 .90019 m .23482 .89495 L .23585 .89955 L 0 1 .515 r
F
0 g
.23319 .90287 m
.23585 .89955 L
s
.23585 .89955 m
.24005 .90311 L
s
.50908 .89337 m .50504 .83688 L .50566 .85384 L 0 .492 .273 r
F
.50908 .89337 m .50597 .83657 L .50504 .83688 L F
0 g
.50304 .82113 m
.50504 .83688 L
s
.50846 .81862 m
.5097 .83613 L
s
.50504 .83688 m
.50511 .83869 L
s
.50835 .83642 m
.50846 .81862 L
s
.46905 .90865 m .46841 .90397 L .46456 .89891 L 0 .638 .332 r
F
.45993 .51813 m .45041 .5203 L .45206 .52198 L 0 1 .333 r
F
.45993 .51813 m .45626 .5143 L .45041 .5203 L F
.45993 .51813 m .46571 .50798 L .45626 .5143 L F
.45993 .51813 m .47358 .50415 L .46571 .50798 L F
.45993 .51813 m .47462 .50536 L .47358 .50415 L F
0 g
.46878 .51134 m
.47462 .50536 L
s
.47462 .50536 m
.48215 .50142 L
s
.4898 .88556 m .47822 .86531 L .48152 .87401 L 0 .629 .304 r
F
0 g
.47454 .86373 m
.47822 .86531 L
s
.80478 1.03244 m .81114 1.03314 L .81551 1.02718 L 0 1 .344 r
F
0 g
.80476 1.03891 m
.81114 1.03314 L
s
.81101 1.0364 m
.81114 1.03314 L
s
.30767 .65931 m .29663 .66029 L .30069 .66226 L 0 1 .494 r
F
0 g
.30049 .66816 m
.30069 .66226 L
s
.3097 .74674 m .29773 .75357 L .30321 .75386 L 0 1 .449 r
F
0 g
.30321 .75386 m
.30373 .75545 L
s
.82195 .79387 m .8297 .79592 L .82503 .79543 L 0 0 0 r
F
.82195 .79387 m .83363 .79565 L .8297 .79592 L F
.50687 .89314 m .50149 .83981 L .50065 .84094 L 0 .501 .278 r
F
.50687 .89314 m .50376 .85508 L .50149 .83981 L F
0 g
.50143 .83886 m
.50149 .83981 L
s
.30703 .8573 m .29653 .85024 L .29621 .85649 L 0 1 .519 r
F
.30703 .8573 m .30001 .84588 L .29653 .85024 L F
0 g
.29621 .85649 m
.29921 .86136 L
s
.30703 .8573 m .30434 .84635 L .30001 .84588 L 0 1 .519 r
F
.30703 .8573 m .30735 .85124 L .30434 .84635 L F
.31784 .85821 m .30735 .85124 L .30703 .8573 L 0 1 .516 r
F
0 g
.30354 .86163 m
.30703 .8573 L
s
.30703 .8573 m
.31003 .86205 L
s
.7203 1.08333 m .71524 1.08253 L .7143 1.08054 L 0 0 0 r
F
0 g
.7143 1.08054 m
.71524 1.08253 L
s
.70707 1.08098 m
.7143 1.08054 L
s
.31784 .85821 m .31084 .84708 L .30735 .85124 L 0 1 .516 r
F
.31784 .85821 m .31516 .84758 L .31084 .84708 L F
.31784 .85821 m .31816 .85236 L .31516 .84758 L F
.32865 .85925 m .31816 .85236 L .31784 .85821 L 0 1 .513 r
F
0 g
.31436 .86236 m
.31784 .85821 L
s
.31784 .85821 m
.32084 .86285 L
s
.5096 .96157 m .50766 .96013 L .5057 .95936 L 0 .318 .223 r
F
.50987 .92758 m .50661 .91283 L .50818 .91664 L 0 .207 .095 r
F
.50987 .92758 m .50568 .91378 L .50661 .91283 L F
0 g
.50644 .90897 m
.50661 .91283 L
s
.80347 .88014 m .8108 .8866 L .81459 .88294 L 0 1 .487 r
F
.80347 .88014 m .8062 .887 L .8108 .8866 L F
0 g
.8108 .8866 m
.81295 .88968 L
s
.50908 .89337 m .50763 .85356 L .50597 .83657 L 0 .492 .273 r
F
0 g
.50597 .83657 m
.50616 .83849 L
s
.50571 .81923 m
.50597 .83657 L
s
.2962 .85649 m .28231 .84904 L .282 .85555 L 0 1 .521 r
F
.2962 .85649 m .28681 .84457 L .28231 .84904 L F
0 g
.282 .85555 m
.28603 .86064 L
s
.2962 .85649 m .2925 .84512 L .28681 .84457 L 0 1 .521 r
F
.2962 .85649 m .29652 .85024 L .2925 .84512 L F
0 g
.29171 .86094 m
.2962 .85649 L
s
.74773 .63781 m .76312 .62815 L .75782 .63505 L 0 0 .029 r
F
0 g
.76312 .62815 m
.76865 .62403 L
s
.76312 .62815 m
.76391 .62309 L
s
.75313 .63811 m
.75402 .63609 L
s
.75313 .63811 m
.75316 .63633 L
s
.53875 .62264 m .54497 .62273 L .55046 .62472 L 0 .085 .017 r
F
.49806 .9227 m .49357 .91709 L .49645 .91985 L 0 .167 .08 r
F
.50002 .92017 m .49645 .91985 L .49357 .91709 L 0 .152 .079 r
F
0 g
.49232 .91405 m
.49357 .91709 L
s
.49217 .91656 m
.49357 .91709 L
s
.32865 .85925 m .32165 .84839 L .31816 .85236 L 0 1 .513 r
F
.32865 .85925 m .32597 .84896 L .32165 .84839 L F
.32865 .85925 m .32897 .85362 L .32597 .84896 L F
.33946 .86046 m .32897 .85362 L .32865 .85925 L 0 1 .51 r
F
0 g
.32517 .8632 m
.32865 .85925 L
s
.32865 .85925 m
.33166 .86378 L
s
.44325 .89993 m .43551 .89957 L .44011 .90084 L 0 1 .48 r
F
.44325 .89993 m .43169 .8965 L .43551 .89957 L F
.44482 .90605 m .44011 .90084 L .43551 .89957 L 0 1 .485 r
F
0 g
.43269 .90069 m
.43551 .89957 L
s
.35945 .58201 m
.36325 .58343 L
s
.55666 .70561 m .566 .68959 L .56806 .68282 L 0 1 .248 r
F
.55666 .70561 m .56112 .69936 L .566 .68959 L F
0 g
.566 .68959 m
.5676 .68782 L
s
.50687 .89314 m .50065 .84094 L .50197 .85716 L 0 .501 .278 r
F
0 g
.50616 .83849 m
.50667 .84366 L
s
.50368 .83767 m
.50419 .84184 L
s
.50279 .83841 m
.503 .84196 L
s
.5003 .83923 m
.50065 .84094 L
s
.43169 .8965 m .42731 .89056 L .42263 .88923 L 0 1 .488 r
F
.43169 .8965 m .43119 .89368 L .42731 .89056 L F
.44325 .89993 m .43119 .89368 L .43169 .8965 L 0 1 .48 r
F
0 g
.43169 .8965 m
.43551 .89957 L
s
.42861 .89787 m
.43169 .8965 L
s
.27903 .52207 m
.27917 .52166 L
s
.2759 .53089 m
.27903 .52207 L
s
.2759 .53089 m
.28457 .52291 L
s
.282 .85555 m .27074 .84814 L .27043 .85485 L 0 1 .524 r
F
.282 .85555 m .27444 .84341 L .27074 .84814 L F
.282 .85555 m .27907 .84383 L .27444 .84341 L F
.282 .85555 m .28231 .84904 L .27907 .84383 L F
0 g
.2783 .86025 m
.282 .85555 L
s
.31759 .66549 m .31293 .6534 L .30767 .65931 L 0 1 .49 r
F
.31759 .66549 m .31972 .6516 L .31293 .6534 L F
.31759 .66549 m .32349 .65511 L .31972 .6516 L F
.31759 .66549 m .32257 .66107 L .32349 .65511 L F
0 g
.31083 .66728 m
.31759 .66549 L
s
.51815 .62292 m
.52302 .62368 L
s
.51351 .62507 m
.51815 .62292 L
s
.33946 .86046 m .33246 .84987 L .32897 .85362 L 0 1 .51 r
F
.33946 .86046 m .33678 .85051 L .33246 .84987 L F
.33946 .86046 m .33978 .85505 L .33678 .85051 L F
.35027 .86186 m .33978 .85505 L .33946 .86046 L 0 1 .507 r
F
0 g
.33598 .86419 m
.33946 .86046 L
s
.33946 .86046 m
.34247 .86487 L
s
.68489 .61725 m
.69235 .61719 L
s
.29182 .76059 m
.29756 .75377 L
s
.29756 .75377 m
.29759 .75373 L
s
.29759 .75373 m
.2976 .75373 L
s
.46051 .91976 m .45945 .91773 L .45541 .9155 L 0 .938 .481 r
F
.47892 .9045 m .46714 .89224 L .46759 .89694 L 0 .61 .318 r
F
.47892 .9045 m .47026 .89137 L .46714 .89224 L F
0 g
.46647 .89127 m
.46714 .89224 L
s
.46714 .89224 m
.46892 .89175 L
s
.46892 .89175 m
.47019 .89139 L
s
.47335 .93194 m .46224 .92513 L .46349 .93027 L 0 .553 .33 r
F
.47335 .93194 m .46439 .92204 L .46224 .92513 L F
0 g
.45951 .92218 m
.46224 .92513 L
s
.3539 .62455 m .34428 .64537 L .34886 .63869 L 0 1 .22 r
F
.3539 .62455 m .34255 .64103 L .34428 .64537 L F
.3539 .62455 m .34485 .62856 L .34255 .64103 L F
.3539 .62455 m .34991 .61443 L .34485 .62856 L F
.73006 .89525 m .74086 .89322 L .73519 .89383 L 0 .769 .26 r
F
.71931 .89609 m .73006 .89525 L .7277 .89465 L 0 .703 .24 r
F
0 g
.3539 .62456 m
.35475 .6352 L
s
.47341 .92164 m .4685 .92305 L .46439 .92204 L 0 .082 .038 r
F
.47098 .92031 m .46439 .92204 L .4685 .92305 L 0 .597 .332 r
F
.47341 .92164 m .47238 .92288 L .4685 .92305 L 0 .082 .038 r
F
.47096 .92252 m .46051 .91976 L .46439 .92204 L 0 .839 .465 r
F
.47096 .92252 m .45945 .91773 L .46051 .91976 L F
0 g
.46127 .91829 m
.46152 .91859 L
s
.45863 .9206 m
.46051 .91976 L
s
.46226 .92277 m
.46391 .9222 L
s
.46051 .91976 m
.46255 .92096 L
s
.53009 .97554 m
.53027 .97562 L
s
.52995 .97548 m
.53009 .97554 L
s
.52868 .97494 m
.52995 .97548 L
s
.53453 .97901 m .53221 .97736 L .53149 .97613 L 0 .024 0 r
F
0 g
.53027 .97562 m
.53149 .97613 L
s
.39812 .91825 m
.4006 .91855 L
s
.27043 .85485 m .25915 .84728 L .25886 .8542 L 0 1 .526 r
F
.27043 .85485 m .26285 .84238 L .25915 .84728 L F
.27043 .85485 m .26749 .84279 L .26285 .84238 L F
.27043 .85485 m .27074 .84814 L .26749 .84279 L F
0 g
.26673 .85972 m
.27043 .85485 L
s
.27043 .85485 m
.27367 .86003 L
s
.53478 1.09257 m .53687 1.09088 L .53745 1.09262 L 0 .245 0 r
F
.80347 .88014 m .80305 .88424 L .8062 .887 L 0 1 .487 r
F
0 g
.8015 .89039 m
.8062 .887 L
s
.55666 .70561 m .56806 .68282 L .56593 .68231 L 0 1 .248 r
F
0 g
.56292 .69576 m
.56365 .6943 L
s
.56365 .6943 m
.566 .68959 L
s
.56806 .68282 m
.57306 .67154 L
s
.51026 .89443 m .50739 .83649 L .50763 .85356 L 0 .491 .271 r
F
.51026 .89443 m .50834 .83668 L .50739 .83649 L F
0 g
.50571 .81923 m
.50739 .83649 L
s
.5097 .83613 m
.50973 .83647 L
s
.50739 .83649 m
.50743 .8394 L
s
.42828 .51209 m
.43342 .50835 L
s
.50586 .89389 m .49942 .84287 L .49864 .84432 L 0 .508 .281 r
F
.50586 .89389 m .50197 .85716 L .49942 .84287 L F
0 g
.49931 .8416 m
.49942 .84287 L
s
.50511 .83869 m
.5053 .84386 L
s
.47374 .98323 m .47137 .9779 L .46744 .97441 L 0 .417 .347 r
F
.47782 .88475 m .47778 .88083 L .47424 .87407 L 0 .669 .318 r
F
0 g
.47424 .87407 m
.47508 .87567 L
s
.7203 1.08333 m .72486 1.07719 L .73015 1.0771 L 0 0 0 r
F
0 g
.71808 1.07867 m
.72486 1.07719 L
s
.72374 1.07602 m
.72486 1.07719 L
s
.44482 .90605 m .44411 .90362 L .44011 .90084 L 0 1 .485 r
F
.45614 .90946 m .44482 .90605 L .44872 .90883 L 0 .961 .475 r
F
.45614 .90946 m .44411 .90362 L .44482 .90605 L F
0 g
.44611 .90967 m
.44838 .90894 L
s
.442 .90717 m
.44482 .90605 L
s
.30671 .90437 m .29969 .90599 L .30398 .90627 L 0 1 .474 r
F
0 g
.30398 .90627 m
.30835 .90852 L
s
.30671 .90437 m .29594 .90346 L .29969 .90599 L 0 1 .474 r
F
0 g
.29769 .90802 m
.29969 .90599 L
s
.47374 .98323 m .4712 .98871 L .47367 .98786 L 0 .417 .347 r
F
.47996 .99653 m .47367 .98786 L .4712 .98871 L 0 .337 .335 r
F
0 g
.4712 .98871 m
.47157 .99345 L
s
.46728 .98522 m
.4712 .98871 L
s
.25886 .8542 m .24757 .84644 L .24729 .85357 L 0 1 .528 r
F
.25886 .8542 m .25126 .84137 L .24757 .84644 L F
.25886 .8542 m .2559 .84177 L .25126 .84137 L F
.25886 .8542 m .25915 .84728 L .2559 .84177 L F
0 g
.25517 .85923 m
.25886 .8542 L
s
.25886 .8542 m
.26211 .85952 L
s
.46959 .7812 m .46244 .78348 L .46554 .78123 L 0 .228 .057 r
F
.46959 .7812 m .46215 .78707 L .46244 .78348 L F
0 g
.46556 .78111 m
.46626 .7781 L
s
.46959 .7812 m .46486 .78962 L .46215 .78707 L 0 .228 .057 r
F
.46959 .7812 m .46893 .78959 L .46486 .78962 L F
0 g
.46554 .78123 m
.46556 .78111 L
s
.46959 .7812 m .47164 .787 L .46893 .78959 L 0 .228 .057 r
F
.46959 .7812 m .47191 .78341 L .47164 .787 L F
0 g
.46959 .7812 m
.47014 .77722 L
s
.46554 .78123 m
.46959 .7812 L
s
.43909 .77793 m .43054 .77753 L .43441 .77698 L 0 .04 0 r
F
0 g
.43441 .77698 m
.43576 .77544 L
s
.35027 .86186 m .34325 .85154 L .33978 .85505 L 0 1 .507 r
F
.35027 .86186 m .34757 .85227 L .34325 .85154 L F
.35027 .86186 m .35058 .85669 L .34757 .85227 L F
.36107 .86348 m .35058 .85669 L .35027 .86186 L 0 1 .504 r
F
0 g
.34679 .86536 m
.35027 .86186 L
s
.35027 .86186 m
.35328 .86615 L
s
.38689 .77184 m .3766 .77044 L .37772 .77029 L 0 0 0 r
F
0 g
.37302 .76972 m
.37772 .77029 L
s
.49018 1.0263 m .48696 1.02866 L .4906 1.03208 L 0 .26 .302 r
F
0 g
.48696 1.02866 m
.48888 1.03339 L
s
.38589 .67197 m
.38719 .67219 L
s
.6296 .77533 m
.62986 .77457 L
s
.62902 .77708 m
.6296 .77533 L
s
.5591 .81007 m .56524 .74253 L .56111 .76464 L 0 1 .254 r
F
0 g
.56354 .75161 m
.56524 .74253 L
s
.56466 .7328 m
.56524 .74253 L
s
.56183 .74384 m
.56466 .7328 L
s
.56504 .77814 m
.56558 .79532 L
s
.3097 .74674 m .29612 .74608 L .29773 .75357 L 0 1 .449 r
F
.3097 .74674 m .29947 .73636 L .29612 .74608 L F
.3097 .74674 m .30597 .72922 L .29947 .73636 L F
.3097 .74674 m .31128 .72943 L .30597 .72922 L F
.3097 .74674 m .31288 .73694 L .31128 .72943 L F
0 g
.30321 .75386 m
.3097 .74674 L
s
.47996 .99653 m .47452 .99893 L .47827 1.00228 L 0 .337 .335 r
F
0 g
.47452 .99893 m
.4752 1.00371 L
s
.45136 .78061 m
.45341 .77926 L
s
.39537 .87059 m .38694 .87178 L .39164 .8728 L 0 1 .492 r
F
0 g
.39164 .8728 m
.39535 .87649 L
s
.39537 .87059 m .38362 .86777 L .38694 .87178 L 0 1 .492 r
F
0 g
.38583 .87258 m
.38694 .87178 L
s
.51628 .92379 m .51904 .90814 L .51767 .91702 L 0 .224 .102 r
F
0 g
.51702 .90935 m
.51721 .90669 L
s
.51745 .92369 m .51767 .91702 L .51904 .90814 L 0 .232 .104 r
F
0 g
.51904 .90814 m
.51914 .90625 L
s
.51904 .90814 m
.51957 .906 L
s
.51026 .89443 m .50967 .85435 L .50834 .83668 L 0 .491 .271 r
F
0 g
.5084 .83738 m
.5096 .85336 L
s
.50834 .83668 m
.5084 .83738 L
s
.50834 .83668 m
.50835 .83642 L
s
.24729 .85357 m .23598 .84561 L .23571 .85295 L 0 1 .53 r
F
.24729 .85357 m .23966 .84037 L .23598 .84561 L F
.24729 .85357 m .2443 .84077 L .23966 .84037 L F
.24729 .85357 m .24757 .84644 L .2443 .84077 L F
0 g
.2436 .85876 m
.24729 .85357 L
s
.24729 .85357 m
.25054 .85904 L
s
.50586 .89389 m .49864 .84432 L .50029 .85998 L 0 .508 .281 r
F
0 g
.5053 .84386 m
.50553 .85027 L
s
.50149 .83981 m
.50244 .84618 L
s
.50065 .84094 m
.50105 .84584 L
s
.49826 .84278 m
.49864 .84432 L
s
.4754 .96839 m .46576 .96454 L .46795 .96989 L 0 .439 .337 r
F
.4754 .96839 m .46654 .96023 L .46576 .96454 L F
0 g
.4617 .96087 m
.46576 .96454 L
s
.75707 .61655 m .77317 .61942 L .76722 .61527 L 0 1 .445 r
F
0 g
.77317 .61942 m
.78078 .62232 L
s
.77317 .61942 m
.77445 .62266 L
s
.49203 .866 m .49248 .86361 L .48979 .85253 L 0 .662 .301 r
F
0 g
.48979 .85253 m
.49025 .8544 L
s
.4917 .85676 m
.49304 .85975 L
s
.49103 .85527 m
.4917 .85676 L
s
.49089 .85496 m
.49103 .85527 L
s
.48979 .85253 m
.49089 .85496 L
s
.49222 .85034 m
.49319 .8551 L
s
.73998 1.07157 m .75113 1.06711 L .74714 1.06927 L 0 0 0 r
F
.73015 1.0771 m .73998 1.07157 L .74114 1.07273 L F
.30943 .75514 m .29772 .75371 L .30317 .7553 L 0 .918 .438 r
F
0 g
.2976 .75373 m
.2976 .75372 L
s
.2976 .75372 m
.29773 .75357 L
s
.30317 .7553 m
.30382 .75604 L
s
.43342 .50835 m .42334 .51375 L .42519 .51324 L 0 .839 .179 r
F
0 g
.42627 .51357 m
.42828 .51209 L
s
.43342 .50835 m .42915 .50981 L .42334 .51375 L 0 .839 .179 r
F
0 g
.42001 .51819 m
.42627 .51357 L
s
.43342 .50835 m .43877 .50404 L .42915 .50981 L 0 .839 .179 r
F
.43342 .50835 m .44701 .49915 L .43877 .50404 L F
0 g
.44255 .50236 m
.44781 .49879 L
s
.50987 .92758 m .5062 .91865 L .50568 .91378 L 0 .207 .095 r
F
0 g
.50498 .91301 m
.50568 .91378 L
s
.51745 .92369 m .521 .90721 L .51917 .9166 L 0 .232 .104 r
F
.51857 .92384 m .51917 .9166 L .521 .90721 L 0 .239 .107 r
F
0 g
.521 .90721 m
.52104 .9071 L
s
.521 .90721 m
.52101 .90711 L
s
.24733 .90019 m .23752 .89183 L .23482 .89495 L 0 1 .515 r
F
.24733 .90019 m .24216 .89229 L .23752 .89183 L F
.24733 .90019 m .24637 .89588 L .24216 .89229 L F
.25882 .90087 m .24637 .89588 L .24733 .90019 L 0 1 .51 r
F
0 g
.24462 .90328 m
.24733 .90019 L
s
.24733 .90019 m
.25148 .90355 L
s
.79189 .88189 m .79929 .88762 L .80305 .88424 L 0 1 .47 r
F
.79189 .88189 m .79468 .88803 L .79929 .88762 L F
0 g
.79929 .88762 m
.8015 .89039 L
s
.49639 1.04245 m .49805 1.0478 L .49873 1.04712 L 0 .216 .262 r
F
.50601 1.05644 m .49873 1.04712 L .49805 1.0478 L 0 .109 .185 r
F
0 g
.49805 1.0478 m
.5008 1.05239 L
s
.49434 1.04425 m
.49805 1.0478 L
s
.51628 .92379 m .51612 .91769 L .51702 .90935 L 0 .224 .102 r
F
0 g
.51702 .90935 m
.51737 .90763 L
s
.51533 .92401 m .51702 .90935 L .51612 .91769 L 0 .223 .101 r
F
0 g
.51635 .90864 m
.51638 .90977 L
s
.51702 .90935 m
.51702 .90935 L
s
.23571 .85295 m .22439 .84478 L .22413 .85235 L 0 1 .531 r
F
.23571 .85295 m .22806 .83938 L .22439 .84478 L F
.23571 .85295 m .2327 .83978 L .22806 .83938 L F
.23571 .85295 m .23598 .84561 L .2327 .83978 L F
0 g
.23204 .85832 m
.23571 .85295 L
s
.23571 .85295 m
.23898 .85858 L
s
.72765 .64386 m .73109 .64958 L .72716 .6514 L 0 .105 .069 r
F
.72765 .64386 m .73767 .64071 L .73109 .64958 L F
0 g
.72716 .6514 m
.72765 .64386 L
s
.72235 .65255 m
.72765 .64386 L
s
.72127 .65432 m
.72235 .65255 L
s
.78365 .79839 m .78999 .78885 L .79466 .79008 L 0 .093 .016 r
F
.78365 .79839 m .78527 .79239 L .78999 .78885 L F
0 g
.78685 .78495 m
.78999 .78885 L
s
.61352 .77234 m
.61391 .83407 L
s
.61344 .75993 m
.61352 .77234 L
s
.36107 .86348 m .35404 .85344 L .35058 .85669 L 0 1 .504 r
F
.36107 .86348 m .35836 .85427 L .35404 .85344 L F
.36107 .86348 m .36137 .85858 L .35836 .85427 L F
0 g
.3576 .86672 m
.36107 .86348 L
s
.37235 .86546 m .36137 .85858 L .36107 .86348 L 0 1 .5 r
F
0 g
.36107 .86348 m
.36423 .86768 L
s
.52561 .9739 m .52383 .9719 L .52629 .97338 L 0 0 0 r
F
0 g
.52502 .97262 m
.52561 .97297 L
s
.52482 .9725 m
.52502 .97262 L
s
.52434 .97221 m
.52482 .9725 L
s
.52561 .97297 m
.52629 .97338 L
s
.52548 .97263 m
.52629 .97338 L
s
.45614 .90946 m .44872 .90883 L .45321 .91009 L 0 .961 .475 r
F
.45803 .91466 m .45321 .91009 L .44872 .90883 L 0 .951 .478 r
F
0 g
.44838 .90894 m
.44872 .90883 L
s
.44482 .90605 m
.44872 .90883 L
s
.4307 .88941 m .42263 .88923 L .42731 .89056 L 0 1 .482 r
F
.4307 .88941 m .41899 .88582 L .42263 .88923 L F
0 g
.41956 .89061 m
.42263 .88923 L
s
.51533 .92401 m .51563 .91794 L .51638 .90977 L 0 .223 .101 r
F
0 g
.51638 .90977 m
.51652 .90867 L
s
.5147 .92426 m .51638 .90977 L .51563 .91794 L 0 .216 .099 r
F
0 g
.51638 .90977 m
.51638 .90977 L
s
.47944 .9351 m .47811 .93346 L .47443 .93188 L 0 .75 .456 r
F
.49655 .94691 m .49108 .9469 L .4939 .948 L 0 .446 .382 r
F
.49655 .94691 m .48938 .94537 L .49108 .9469 L F
0 g
.49081 .9482 m
.49108 .9469 L
s
.22413 .85235 m .21279 .84394 L .21256 .85174 L 0 1 .532 r
F
.22413 .85235 m .21645 .83837 L .21279 .84394 L F
.22413 .85235 m .2211 .83877 L .21645 .83837 L F
.22413 .85235 m .22439 .84478 L .2211 .83877 L F
0 g
.22047 .85788 m
.22413 .85235 L
s
.22413 .85235 m
.22741 .85814 L
s
.45747 .64255 m
.46065 .64099 L
s
.35088 .66431 m .35803 .63721 L .35475 .63521 L 0 1 .373 r
F
0 g
.35166 .63085 m
.3539 .62455 L
s
.35088 .66431 m .35638 .64968 L .35803 .63721 L 0 1 .373 r
F
0 g
.35638 .64968 m
.36294 .64073 L
s
.35638 .64968 m
.35803 .63721 L
s
.47892 .9045 m .46759 .89694 L .4713 .90256 L 0 .61 .318 r
F
0 g
.46759 .89694 m
.46807 .89767 L
s
.46456 .89891 m
.46759 .89694 L
s
.46456 .89891 m
.46655 .90152 L
s
.46655 .90152 m
.46771 .90304 L
s
.37926 .58704 m .36735 .58495 L .37108 .58889 L 0 1 .494 r
F
0 g
.37085 .58959 m
.37108 .58889 L
s
.37926 .58704 m .37027 .57798 L .36735 .58495 L 0 1 .494 r
F
0 g
.36325 .58343 m
.36735 .58495 L
s
.36325 .58343 m
.36756 .57619 L
s
.37926 .58704 m .3779 .57262 L .37027 .57798 L 0 1 .494 r
F
.37926 .58704 m .3861 .57076 L .3779 .57262 L F
.37926 .58704 m .38938 .57365 L .3861 .57076 L F
.37926 .58704 m .38645 .58063 L .38938 .57365 L F
0 g
.37108 .58889 m
.37926 .58704 L
s
.49655 .94691 m .48997 .94433 L .48938 .94537 L 0 .446 .382 r
F
0 g
.48625 .94429 m
.48938 .94537 L
s
.48955 .8926 m .47795 .87109 L .47784 .87498 L 0 .612 .304 r
F
.48955 .8926 m .48152 .87401 L .47795 .87109 L F
0 g
.47454 .86373 m
.47795 .87109 L
s
.47795 .87109 m
.48074 .87337 L
s
.30767 .65931 m .29772 .65358 L .29663 .66029 L 0 1 .494 r
F
0 g
.29018 .66373 m
.29663 .66029 L
s
.49986 .95024 m .49369 .94916 L .49547 .95065 L 0 .39 .352 r
F
.49986 .95024 m .4939 .948 L .49369 .94916 L F
0 g
.49081 .9482 m
.49369 .94916 L
s
.50493 .89516 m .49751 .84671 L .49678 .84845 L 0 .515 .283 r
F
.50493 .89516 m .50029 .85998 L .49751 .84671 L F
0 g
.49731 .84509 m
.49751 .84671 L
s
.77739 .61384 m .79135 .6216 L .79559 .62126 L 0 1 .49 r
F
.77739 .61384 m .78357 .61842 L .79135 .6216 L F
.77809 .62975 m .78387 .62522 L .79135 .6216 L 0 0 0 r
F
0 g
.78984 .62233 m
.79135 .6216 L
s
.78478 .62478 m
.78485 .62399 L
s
.78485 .62399 m
.785 .62212 L
s
.47335 .93194 m .46349 .93027 L .46733 .93451 L 0 .553 .33 r
F
0 g
.46349 .93027 m
.46423 .93109 L
s
.46154 .93391 m
.46349 .93027 L
s
.53875 .62264 m .53518 .62573 L .53455 .62392 L 0 .085 .017 r
F
.53875 .62264 m .54067 .62774 L .53518 .62573 L F
.53875 .62264 m .54737 .6286 L .54067 .62774 L F
.53875 .62264 m .55156 .62731 L .54737 .6286 L F
0 g
.55375 .62371 m
.55418 .62358 L
s
.53875 .62264 m .55046 .62472 L .55156 .62731 L 0 .085 .017 r
F
0 g
.55046 .62472 m
.55375 .62371 L
s
.54497 .62273 m
.55046 .62472 L
s
.79189 .88189 m .79151 .88558 L .79468 .88803 L 0 1 .47 r
F
0 g
.79004 .89111 m
.79468 .88803 L
s
.43909 .77793 m .42964 .77931 L .43054 .77753 L 0 .04 0 r
F
.43909 .77793 m .43233 .78113 L .42964 .77931 L F
.43909 .77793 m .43703 .78208 L .43233 .78113 L F
.43909 .77793 m .4406 .78153 L .43703 .78208 L F
.43909 .77793 m .44148 .77974 L .4406 .78153 L F
0 g
.43909 .77793 m
.4402 .77574 L
s
.43441 .77698 m
.43909 .77793 L
s
.47566 .78274 m
.47568 .78217 L
s
.47191 .78341 m
.47568 .78217 L
s
.47096 .92252 m .4619 .9172 L .45945 .91773 L 0 .839 .465 r
F
0 g
.45541 .9155 m
.45945 .91773 L
s
.4635 .92152 m
.46415 .9219 L
s
.46255 .92096 m
.4635 .92152 L
s
.46391 .9222 m
.46418 .92211 L
s
.46434 .92212 m
.46434 .92212 L
s
.46224 .92513 m
.46434 .92212 L
s
.41126 .52531 m .42001 .51819 L .42519 .51324 L 0 1 .219 r
F
0 g
.40682 .52996 m
.41126 .52531 L
s
.49986 .95024 m .49547 .95065 L .49803 .95161 L 0 .39 .352 r
F
0 g
.49547 .95065 m
.4956 .952 L
s
.55234 .7294 m .56294 .70232 L .56112 .69936 L 0 1 .293 r
F
.55234 .7294 m .56091 .71253 L .56294 .70232 L F
0 g
.56058 .72058 m
.56222 .71419 L
s
.56102 .71267 m
.56222 .71419 L
s
.56294 .70232 m
.5643 .69808 L
s
.56143 .69987 m
.56294 .70232 L
s
.51607 1.07168 m .51169 1.06611 L .50825 1.06218 L 0 .003 .157 r
F
.21256 .85174 m .20119 .84309 L .20098 .85113 L 0 1 .533 r
F
.21256 .85174 m .20484 .83735 L .20119 .84309 L F
.21256 .85174 m .20949 .83776 L .20484 .83735 L F
.21256 .85174 m .21279 .84394 L .20949 .83776 L F
0 g
.20891 .85744 m
.21256 .85174 L
s
.21256 .85174 m
.21585 .8577 L
s
.49342 .94355 m .48691 .94306 L .48997 .94433 L 0 .513 .404 r
F
.49342 .94355 m .48532 .9415 L .48691 .94306 L F
0 g
.48625 .94429 m
.48691 .94306 L
s
.53523 .90952 m .53484 .9078 L .53771 .89638 L 0 .205 .127 r
F
0 g
.53711 .8988 m
.53771 .89638 L
s
.53617 .90251 m
.53711 .8988 L
s
.53703 .89816 m
.53771 .89638 L
s
.5351 .90319 m
.53703 .89816 L
s
.53477 .89994 m
.5352 .89817 L
s
.71931 .89609 m .7277 .89465 L .72338 .89515 L 0 .703 .24 r
F
.70855 .89699 m .71931 .89609 L .7169 .89593 L 0 .602 .209 r
F
.51147 .89614 m .50979 .8374 L .50967 .85435 L 0 .49 .269 r
F
.51147 .89614 m .51077 .83816 L .50979 .8374 L F
0 g
.50973 .83647 m
.50979 .8374 L
s
.51857 .92384 m .52288 .90662 L .52061 .91648 L 0 .239 .107 r
F
.51964 .92426 m .52061 .91648 L .52288 .90662 L 0 .245 .11 r
F
0 g
.52288 .90662 m
.52296 .90636 L
s
.52288 .90662 m
.52291 .90643 L
s
.41126 .52531 m .40065 .53135 L .40296 .53095 L 0 1 .219 r
F
0 g
.39848 .53696 m
.40483 .53163 L
s
.40483 .53163 m
.40682 .52996 L
s
.41126 .52531 m .40582 .5264 L .40065 .53135 L 0 1 .219 r
F
.41126 .52531 m .41504 .51939 L .40582 .5264 L F
.41126 .52531 m .42334 .51375 L .41504 .51939 L F
.41126 .52531 m .42519 .51324 L .42334 .51375 L F
0 g
.42001 .51819 m
.42519 .51324 L
s
.40305 .5309 m
.41126 .52531 L
s
.42519 .51324 m
.43342 .50835 L
s
.41899 .88582 m .41045 .87767 L .40708 .87928 L 0 1 .488 r
F
0 g
.40708 .87928 m
.40806 .87881 L
s
.74892 .78915 m .76196 .785 L .76052 .79344 L 0 .279 .073 r
F
0 g
.75951 .77669 m
.76196 .785 L
s
.76196 .785 m
.76656 .78027 L
s
.49342 .94355 m .48628 .94058 L .48532 .9415 L 0 .513 .404 r
F
0 g
.48197 .94027 m
.48532 .9415 L
s
.50493 .89516 m .49678 .84845 L .49876 .86345 L 0 .515 .283 r
F
0 g
.50419 .84184 m
.5051 .84927 L
s
.503 .84196 m
.50338 .84848 L
s
.49617 .8464 m
.49678 .84845 L
s
.43329 .92278 m .4261 .92118 L .43058 .92181 L 0 0 0 r
F
.43329 .92278 m .42198 .92098 L .4261 .92118 L F
0 g
.42378 .92038 m
.4261 .92118 L
s
.20098 .85113 m .18959 .84223 L .1894 .85051 L 0 1 .534 r
F
.20098 .85113 m .19323 .83631 L .18959 .84223 L F
0 g
.1894 .85051 m
.19272 .85683 L
s
.20098 .85113 m .19787 .83673 L .19323 .83631 L 0 1 .534 r
F
.20098 .85113 m .20119 .84309 L .19787 .83673 L F
0 g
.19735 .857 m
.20098 .85113 L
s
.20098 .85113 m
.20428 .85726 L
s
.3902 .54536 m .39848 .53696 L .40296 .53095 L 0 1 .307 r
F
0 g
.3902 .54537 m
.3902 .54536 L
s
.38652 .55083 m
.3902 .54537 L
s
.37235 .86546 m .36497 .85564 L .36137 .85858 L 0 1 .5 r
F
.37235 .86546 m .36948 .85663 L .36497 .85564 L F
.37235 .86546 m .37264 .86084 L .36948 .85663 L F
.38362 .86777 m .37264 .86084 L .37235 .86546 L 0 1 .496 r
F
0 g
.36874 .86839 m
.37235 .86546 L
s
.37235 .86546 m
.37551 .86955 L
s
.3902 .54536 m .3792 .55238 L .38194 .55197 L 0 1 .307 r
F
0 g
.37819 .55949 m
.38464 .55279 L
s
.38464 .55279 m
.38652 .55083 L
s
.3902 .54536 m .38367 .54637 L .3792 .55238 L 0 1 .307 r
F
.3902 .54536 m .39238 .53796 L .38367 .54637 L F
.3902 .54536 m .40065 .53135 L .39238 .53796 L F
.3902 .54536 m .40296 .53095 L .40065 .53135 L F
0 g
.39848 .53696 m
.40296 .53095 L
s
.38422 .55015 m
.3902 .54536 L
s
.40296 .53095 m
.40305 .5309 L
s
.50331 .95355 m .4982 .95287 L .50006 .95433 L 0 .356 .312 r
F
.50331 .95355 m .49803 .95161 L .4982 .95287 L F
0 g
.4956 .952 m
.4982 .95287 L
s
.49031 .87875 m .4821 .86523 L .48667 .87408 L 0 .643 .303 r
F
.4898 .88556 m .48667 .87408 L .4821 .86523 L 0 .629 .304 r
F
0 g
.47898 .85577 m
.4821 .86523 L
s
.48158 .86469 m
.4821 .86523 L
s
.51445 .9652 m .51251 .96374 L .51089 .96298 L 0 .244 .203 r
F
.41899 .88582 m .41515 .8791 L .41045 .87767 L 0 1 .488 r
F
.41899 .88582 m .41881 .88259 L .41515 .8791 L F
.4307 .88941 m .41881 .88259 L .41899 .88582 L 0 1 .482 r
F
0 g
.41899 .88582 m
.42263 .88923 L
s
.41562 .88742 m
.41899 .88582 L
s
.48788 .91911 m .48687 .92035 L .48343 .92015 L 0 .112 .061 r
F
.49625 .92527 m .48788 .91911 L .49107 .92007 L 0 .183 .081 r
F
.49625 .92527 m .48687 .92035 L .48788 .91911 L F
0 g
.48621 .91698 m
.48788 .91911 L
s
.48788 .91911 m
.48931 .91954 L
s
.79405 1.03835 m .79432 1.04353 L .80058 1.03793 L 0 1 .29 r
F
.79405 1.03835 m .79014 1.04554 L .79432 1.04353 L F
0 g
.79339 1.04528 m
.79432 1.04353 L
s
.39655 .91784 m .3891 .91714 L .3937 .91767 L 0 .508 .211 r
F
.39655 .91784 m .38498 .91626 L .3891 .91714 L F
0 g
.38672 .91716 m
.3891 .91714 L
s
.3937 .91767 m
.39812 .91825 L
s
.47338 .92679 m .4685 .92305 L .46439 .92204 L 0 .816 .464 r
F
.47335 .93194 m .4685 .92305 L .46439 .92204 L 0 .553 .33 r
F
.47622 .93098 m .47504 .92931 L .47125 .92751 L 0 .787 .462 r
F
.47335 .93194 m .47235 .9273 L .4685 .92305 L 0 .553 .33 r
F
.47338 .92679 m .47236 .92509 L .4685 .92305 L 0 .816 .464 r
F
.47095 .92473 m .46439 .92204 L .4685 .92305 L 0 .109 .04 r
F
.47095 .92473 m .46049 .92213 L .46439 .92204 L F
.47096 .92252 m .46439 .92204 L .4685 .92305 L 0 .839 .465 r
F
0 g
.4643 .92204 m
.46439 .92204 L
s
.46415 .9219 m
.46439 .92204 L
s
.32994 .76134 m .32246 .75706 L .31969 .75837 L 0 .677 .328 r
F
.32994 .76134 m .32756 .75719 L .32246 .75706 L F
.32994 .76134 m .33156 .75867 L .32756 .75719 L F
.32994 .76134 m .33258 .76045 L .33156 .75867 L F
0 g
.32486 .7612 m
.32994 .76134 L
s
.32994 .76134 m
.33108 .76271 L
s
.56102 .68843 m .57109 .67439 L .57309 .66993 L 0 1 .19 r
F
.56102 .68843 m .56593 .68231 L .57109 .67439 L F
0 g
.57109 .67439 m
.57306 .67154 L
s
.46049 .92213 m .45534 .92348 L .45101 .92265 L 0 .02 .009 r
F
.46049 .92213 m .4594 .92325 L .45534 .92348 L F
.47095 .92473 m .4594 .92325 L .46049 .92213 L 0 .109 .04 r
F
0 g
.45838 .92088 m
.46049 .92213 L
s
.46049 .92213 m
.4643 .92204 L
s
.51349 .92484 m .51433 .91126 L .51406 .91888 L 0 .211 .098 r
F
.5147 .92426 m .51406 .91888 L .51433 .91126 L 0 .216 .099 r
F
0 g
.51381 .90618 m
.51433 .91126 L
s
.51433 .91126 m
.51523 .90519 L
s
.75214 1.06776 m .75113 1.06711 L .7577 1.06359 L 0 0 0 r
F
.75214 1.06776 m .74714 1.06927 L .75113 1.06711 L F
0 g
.74978 1.06669 m
.75113 1.06711 L
s
.30943 .75514 m .29596 .75065 L .29772 .75371 L 0 .918 .438 r
F
0 g
.29612 .74608 m
.29719 .75106 L
s
.29759 .75373 m
.29772 .75371 L
s
.78032 .88369 m .78777 .88865 L .79151 .88558 L 0 1 .448 r
F
.78032 .88369 m .78316 .88908 L .78777 .88865 L F
0 g
.78777 .88865 m
.79004 .89111 L
s
.24334 .65705 m .23183 .6614 L .23614 .66246 L 0 1 .52 r
F
0 g
.23614 .66246 m
.23632 .6694 L
s
.44325 .89993 m .43432 .89277 L .43119 .89368 L 0 1 .48 r
F
0 g
.42731 .89056 m
.43119 .89368 L
s
.47818 .89459 m .47026 .89137 L .47487 .8949 L 0 .641 .318 r
F
.47892 .9045 m .47487 .8949 L .47026 .89137 L 0 .61 .318 r
F
0 g
.47019 .89139 m
.47026 .89137 L
s
.47023 .89132 m
.47026 .89137 L
s
.79559 .62127 m
.80289 .63155 L
s
.31748 .90537 m .31042 .90672 L .31471 .90703 L 0 1 .459 r
F
0 g
.31471 .90703 m
.31901 .9091 L
s
.31748 .90537 m .30671 .90437 L .31042 .90672 L 0 1 .459 r
F
0 g
.30835 .90852 m
.31042 .90672 L
s
.5285 1.08542 m .53343 1.08851 L .5327 1.08908 L 0 .114 0 r
F
0 g
.52998 1.08434 m
.53343 1.08851 L
s
.53478 1.09257 m .5327 1.08908 L .53343 1.08851 L 0 .245 0 r
F
0 g
.53343 1.08851 m
.53522 1.08928 L
s
.447 .92272 m .43732 .9229 L .43486 .92177 L 0 0 0 r
F
.45614 .90946 m .44703 .90299 L .44411 .90362 L 0 .961 .475 r
F
0 g
.44011 .90084 m
.44411 .90362 L
s
.50331 .95355 m .50006 .95433 L .50232 .95516 L 0 .356 .312 r
F
0 g
.50006 .95433 m
.50058 .95571 L
s
.6653 1.08576 m .67532 1.0866 L .672 1.08794 L 0 .079 0 r
F
.25882 .90087 m .24912 .89299 L .24637 .89588 L 0 1 .51 r
F
.25882 .90087 m .25376 .89347 L .24912 .89299 L F
.25882 .90087 m .25792 .89685 L .25376 .89347 L F
.27031 .9016 m .25792 .89685 L .25882 .90087 L 0 1 .504 r
F
0 g
.25606 .90374 m
.25882 .90087 L
s
.25882 .90087 m
.26293 .90403 L
s
.37046 .56991 m .37819 .55949 L .38194 .55197 L 0 1 .364 r
F
0 g
.36756 .57619 m
.37046 .56991 L
s
.50447 .89596 m .49608 .85019 L .49588 .85078 L 0 .524 .286 r
F
.50447 .89596 m .49876 .86345 L .49608 .85019 L F
0 g
.496 .84977 m
.49608 .85019 L
s
.49864 .84432 m
.49928 .85036 L
s
.4905 .94017 m .48302 .93913 L .48628 .94058 L 0 .572 .42 r
F
.4905 .94017 m .48155 .93753 L .48302 .93913 L F
0 g
.48197 .94027 m
.48302 .93913 L
s
.37389 .915 m .3643 .9122 L .36173 .91268 L 0 .658 .256 r
F
.37389 .915 m .36879 .91284 L .3643 .9122 L F
.37389 .915 m .3729 .91404 L .36879 .91284 L F
.38498 .91626 m .3729 .91404 L .37389 .915 L 0 .597 .239 r
F
0 g
.37131 .91547 m
.37389 .915 L
s
.37389 .915 m
.37793 .91602 L
s
.51147 .89614 m .51174 .85634 L .51077 .83816 L 0 .49 .269 r
F
0 g
.51077 .83816 m
.5108 .8388 L
s
.51125 .81953 m
.51218 .83875 L
s
.51077 .83816 m
.51125 .81953 L
s
.4754 .96839 m .46795 .96989 L .47174 .97339 L 0 .439 .337 r
F
0 g
.46744 .97441 m
.46795 .96989 L
s
.66509 .62015 m
.66596 .62009 L
s
.66596 .62009 m
.66706 .62001 L
s
.32824 .72247 m .31829 .72978 L .32232 .73004 L 0 1 .43 r
F
0 g
.32232 .73004 m
.32306 .7376 L
s
.32824 .72247 m .3183 .72193 L .31829 .72978 L 0 1 .43 r
F
.32824 .72247 m .32236 .71171 L .3183 .72193 L F
.32824 .72247 m .32829 .70413 L .32236 .71171 L F
.32824 .72247 m .33214 .70425 L .32829 .70413 L F
.32824 .72247 m .33212 .71211 L .33214 .70425 L F
0 g
.32824 .72247 m
.32836 .73053 L
s
.32232 .73004 m
.32824 .72247 L
s
.48955 .8926 m .47784 .87498 L .48127 .88293 L 0 .612 .304 r
F
0 g
.47784 .87498 m
.47937 .87853 L
s
.47424 .87407 m
.47784 .87498 L
s
.25396 .66008 m .24865 .64874 L .24334 .65705 L 0 1 .519 r
F
.25396 .66008 m .25573 .64358 L .24865 .64874 L F
.25396 .66008 m .25984 .64502 L .25573 .64358 L F
.25396 .66008 m .25908 .6521 L .25984 .64502 L F
0 g
.25027 .66277 m
.25396 .66008 L
s
.25336 .66691 m
.25396 .66008 L
s
.50447 .89596 m .49588 .85078 L .49831 .86464 L 0 .524 .286 r
F
0 g
.49608 .85019 m
.49643 .8519 L
s
.49942 .84287 m
.50098 .85161 L
s
.49678 .84845 m
.49723 .85183 L
s
.49568 .85001 m
.49588 .85078 L
s
.38689 .77184 m .37929 .77117 L .3766 .77044 L 0 0 0 r
F
0 g
.3766 .77044 m
.37772 .77029 L
s
.38689 .77184 m .38431 .7722 L .37929 .77117 L 0 0 0 r
F
.38689 .77184 m .38829 .77284 L .38431 .7722 L F
.38689 .77184 m .3894 .77268 L .38829 .77284 L F
0 g
.38689 .77184 m
.38815 .77143 L
s
.3819 .77081 m
.38689 .77184 L
s
.40711 .87388 m .3987 .87448 L .4034 .87569 L 0 1 .488 r
F
0 g
.4034 .87569 m
.40708 .87928 L
s
.40711 .87388 m .39537 .87059 L .3987 .87448 L 0 1 .488 r
F
0 g
.39681 .87562 m
.3987 .87448 L
s
.47098 .92031 m .47015 .91565 L .46629 .91101 L 0 .597 .332 r
F
.5193 .96887 m .52207 .97073 L .52132 .9703 L 0 .155 .175 r
F
.52181 .97081 m .52132 .9703 L .52207 .97073 L 0 0 0 r
F
0 g
.52207 .97073 m
.52267 .97109 L
s
.78032 .88369 m .77997 .88696 L .78316 .88908 L 0 1 .448 r
F
0 g
.77858 .89186 m
.78316 .88908 L
s
.47097 .95574 m .46654 .96023 L .46978 .95984 L 0 .502 .341 r
F
.4754 .96839 m .46978 .95984 L .46654 .96023 L 0 .439 .337 r
F
0 g
.46576 .96454 m
.46654 .96023 L
s
.46264 .95648 m
.46654 .96023 L
s
.50211 .91767 m .50126 .91867 L .49875 .91712 L 0 .137 .078 r
F
0 g
.49875 .91712 m
.50074 .91835 L
s
.50872 .92877 m .50432 .91522 L .5062 .91865 L 0 .21 .095 r
F
.50872 .92877 m .50342 .9162 L .50432 .91522 L F
0 g
.50415 .91417 m
.50432 .91522 L
s
.43309 .54198 m
.43826 .53549 L
s
.42565 .54606 m
.43309 .54198 L
s
.4905 .94017 m .48288 .93676 L .48155 .93753 L 0 .572 .42 r
F
0 g
.47802 .93613 m
.48155 .93753 L
s
.72188 .61255 m .73984 .61569 L .7379 .61319 L 0 1 .395 r
F
0 g
.73984 .61569 m
.74695 .61769 L
s
.3495 .67383 m
.34969 .67383 L
s
.37046 .56991 m .35916 .57852 L .3623 .57807 L 0 1 .364 r
F
.37046 .56991 m .36291 .57101 L .35916 .57852 L F
.37046 .56991 m .37104 .56054 L .36291 .57101 L F
.37046 .56991 m .3792 .55238 L .37104 .56054 L F
.37046 .56991 m .38194 .55197 L .3792 .55238 L F
0 g
.37819 .55949 m
.38194 .55197 L
s
.38194 .55197 m
.38422 .55015 L
s
.37279 .67503 m
.37877 .67372 L
s
.54573 .7953 m .55153 .81143 L .55476 .85546 L 0 .698 .198 r
F
0 g
.55045 .76675 m
.55153 .81143 L
s
.54228 .78329 m
.54573 .7953 L
s
.54768 .7859 m
.55153 .81143 L
s
.64481 .62273 m .65817 .62151 L .66127 .6204 L 0 .978 .276 r
F
.64481 .62273 m .65112 .62251 L .65817 .62151 L F
0 g
.65817 .62151 m
.66009 .62258 L
s
.47097 .95574 m .46932 .95067 L .46541 .94692 L 0 .502 .341 r
F
.49105 .87222 m .49141 .86969 L .48849 .85941 L 0 .654 .302 r
F
0 g
.48849 .85941 m
.48938 .86254 L
s
.48849 .85941 m
.49007 .86235 L
s
.49025 .8544 m
.49151 .8596 L
s
.38362 .86777 m .37623 .85823 L .37264 .86084 L 0 1 .496 r
F
.38362 .86777 m .38073 .85936 L .37623 .85823 L F
.38362 .86777 m .3839 .86346 L .38073 .85936 L F
0 g
.38003 .87038 m
.38362 .86777 L
s
.39537 .87059 m .3839 .86346 L .38362 .86777 L 0 1 .492 r
F
0 g
.38362 .86777 m
.38694 .87178 L
s
.51964 .92426 m .52466 .90643 L .52198 .91668 L 0 .245 .11 r
F
.52064 .92497 m .52198 .91668 L .52466 .90643 L 0 .25 .115 r
F
0 g
.52466 .90643 m
.52523 .90329 L
s
.52466 .90643 m
.52593 .90267 L
s
.43826 .53549 m .44685 .52848 L .45206 .52198 L 0 1 .428 r
F
.50686 .95684 m .50288 .95652 L .50478 .95796 L 0 .312 .264 r
F
.50686 .95684 m .50232 .95516 L .50288 .95652 L F
0 g
.50058 .95571 m
.50288 .95652 L
s
.67825 1.09661 m .67532 1.0866 L .68173 1.08809 L 0 .105 .03 r
F
.67825 1.09661 m .672 1.08794 L .67532 1.0866 L F
0 g
.67338 1.08308 m
.67532 1.0866 L
s
.48328 .92528 m .47341 .92164 L .47709 .9218 L 0 .157 .063 r
F
.48328 .92528 m .47238 .92288 L .47341 .92164 L F
0 g
.4713 .92 m
.47341 .92164 L
s
.47341 .92164 m
.47462 .92169 L
s
.64901 .56135 m
.65614 .57489 L
s
.65614 .57489 m
.65694 .57641 L
s
.50385 .89752 m .49525 .85273 L .49463 .85476 L 0 .524 .286 r
F
.50385 .89752 m .49831 .86464 L .49525 .85273 L F
0 g
.49472 .84955 m
.49525 .85273 L
s
.49588 .85078 m
.49629 .85315 L
s
.49643 .8519 m
.49699 .85467 L
s
.50105 .84584 m
.50167 .85351 L
s
.39371 .57767 m
.39766 .57061 L
s
.38645 .58063 m
.39371 .57767 L
s
.70855 .89699 m .7169 .89593 L .71257 .89647 L 0 .602 .209 r
F
0 g
.70855 .89699 m
.71011 .89679 L
s
.70731 .89717 m
.70855 .89699 L
s
.48001 .91445 m .46841 .90397 L .46905 .90865 L 0 .576 .317 r
F
.48001 .91445 m .4713 .90256 L .46841 .90397 L F
0 g
.46771 .90304 m
.46841 .90397 L
s
.46841 .90397 m
.46987 .90326 L
s
.78365 .79839 m .79466 .79008 L .79691 .79467 L 0 .093 .016 r
F
0 g
.79466 .79008 m
.79856 .78865 L
s
.50601 1.05644 m .50514 1.05784 L .50856 1.06155 L 0 .109 .185 r
F
0 g
.50514 1.05784 m
.50825 1.06218 L
s
.47213 .63634 m
.47579 .63513 L
s
.47818 .89459 m .478 .89065 L .47435 .88446 L 0 .641 .318 r
F
0 g
.47435 .88446 m
.47544 .88632 L
s
.44611 .64755 m .43811 .64997 L .44022 .64974 L 0 .899 .232 r
F
.44611 .64755 m .44113 .64811 L .43811 .64997 L F
0 g
.43775 .65169 m
.44022 .64974 L
s
.44611 .64755 m .44729 .6454 L .44113 .64811 L 0 .899 .232 r
F
.44611 .64755 m .45319 .6432 L .44729 .6454 L F
.44611 .64755 m .45488 .64299 L .45319 .6432 L F
.44611 .64755 m .45184 .64485 L .45488 .64299 L F
0 g
.44022 .64974 m
.44611 .64755 L
s
.45185 .64485 m
.45747 .64255 L
s
.4259 .77684 m
.43054 .77753 L
s
.51227 .9256 m .51226 .91292 L .51247 .92 L 0 .207 .096 r
F
.51349 .92484 m .51247 .92 L .51226 .91292 L 0 .211 .098 r
F
0 g
.51138 .90828 m
.51226 .91292 L
s
.51226 .91292 m
.51239 .91159 L
s
.45794 .92492 m .45101 .92265 L .45534 .92348 L 0 .051 .01 r
F
.45794 .92492 m .447 .92272 L .45101 .92265 L F
0 g
.44876 .92131 m
.45101 .92265 L
s
.76874 .88554 m .77625 .88972 L .77997 .88696 L 0 1 .419 r
F
.76874 .88554 m .77164 .89016 L .77625 .88972 L F
0 g
.77625 .88972 m
.77858 .89186 L
s
.41347 .77577 m .40433 .77445 L .40846 .7746 L 0 0 0 r
F
0 g
.40846 .7746 m
.40998 .77391 L
s
.47615 .94355 m .46553 .93794 L .46699 .94304 L 0 .505 .328 r
F
.47615 .94355 m .46733 .93451 L .46553 .93794 L F
0 g
.46154 .93391 m
.46553 .93794 L
s
.30767 .65931 m .30324 .64659 L .29772 .65358 L 0 1 .494 r
F
.30767 .65931 m .31025 .64363 L .30324 .64659 L F
.30767 .65931 m .31404 .64668 L .31025 .64363 L F
.30767 .65931 m .31293 .6534 L .31404 .64668 L F
0 g
.30069 .66226 m
.30767 .65931 L
s
.30677 .66525 m
.30767 .65931 L
s
.3766 .77044 m .36759 .76864 L .37159 .76936 L 0 0 0 r
F
0 g
.37301 .76972 m
.37302 .76972 L
s
.45803 .91466 m .4572 .91259 L .45321 .91009 L 0 .951 .478 r
F
.46898 .91821 m .45803 .91466 L .4619 .9172 L 0 .856 .464 r
F
.46898 .91821 m .4572 .91259 L .45803 .91466 L F
0 g
.45945 .91773 m
.46146 .91729 L
s
.45541 .9155 m
.45803 .91466 L
s
.48781 .93675 m .47944 .9351 L .48288 .93676 L 0 .622 .431 r
F
.48781 .93675 m .47811 .93346 L .47944 .9351 L F
0 g
.47802 .93613 m
.47944 .9351 L
s
.52302 .62368 m .52934 .62305 L .53455 .62392 L 0 0 0 r
F
.50686 .95684 m .50478 .95796 L .50673 .95869 L 0 .312 .264 r
F
0 g
.50478 .95796 m
.5057 .95936 L
s
.50385 .89752 m .49463 .85476 L .497 .86879 L 0 .524 .286 r
F
0 g
.49463 .85476 m
.49464 .85482 L
s
.49525 .85273 m
.49584 .85503 L
s
.49723 .85183 m
.49803 .85791 L
s
.49751 .84671 m
.49953 .85633 L
s
.49928 .85036 m
.50007 .85787 L
s
.49329 .8512 m
.49463 .85476 L
s
.27031 .9016 m .26072 .89419 L .25792 .89685 L 0 1 .504 r
F
.27031 .9016 m .26536 .89468 L .26072 .89419 L F
.27031 .9016 m .26947 .89787 L .26536 .89468 L F
.28181 .90239 m .26947 .89787 L .27031 .9016 L 0 1 .497 r
F
0 g
.2675 .90424 m
.27031 .9016 L
s
.27031 .9016 m
.27437 .90457 L
s
.29595 .75065 m .28588 .75021 L .29031 .75153 L 0 1 .482 r
F
0 g
.29031 .75153 m
.29203 .75468 L
s
.35088 .66431 m .35475 .63521 L .34792 .64624 L 0 1 .373 r
F
0 g
.3528 .63836 m
.35287 .63824 L
s
.35287 .63824 m
.35307 .63793 L
s
.35307 .63793 m
.35475 .63521 L
s
.34886 .63869 m
.35137 .63165 L
s
.35137 .63165 m
.35166 .63085 L
s
.5127 .89855 m .51223 .83978 L .51174 .85634 L 0 .491 .268 r
F
.5127 .89855 m .51322 .84118 L .51223 .83978 L F
0 g
.51218 .83875 m
.51223 .83978 L
s
.33212 .71211 m
.3379 .70466 L
s
.76874 .88554 m .76842 .88837 L .77164 .89016 L 0 1 .419 r
F
0 g
.76712 .89262 m
.77164 .89016 L
s
.81551 1.02718 m .82623 1.0225 L .8264 1.01919 L 0 1 .386 r
F
.29772 .65358 m .28645 .6556 L .29052 .65743 L 0 1 .499 r
F
0 g
.29018 .66373 m
.29052 .65743 L
s
.41259 .66236 m .40351 .66517 L .4064 .66478 L 0 1 .274 r
F
.41259 .66236 m .40564 .66325 L .40351 .66517 L F
0 g
.40544 .66585 m
.4064 .66478 L
s
.40489 .66647 m
.40544 .66585 L
s
.41259 .66236 m .41138 .66029 L .40564 .66325 L 0 1 .274 r
F
.41259 .66236 m .41759 .65786 L .41138 .66029 L F
.41259 .66236 m .42012 .65757 L .41759 .65786 L F
.41259 .66236 m .41797 .6595 L .42012 .65757 L F
0 g
.41072 .66426 m
.41259 .66236 L
s
.4064 .66478 m
.41259 .66236 L
s
.52181 .97081 m .52383 .9719 L .52293 .97148 L 0 0 0 r
F
0 g
.52383 .9719 m
.52393 .97186 L
s
.52561 .9739 m .52293 .97148 L .52383 .9719 L 0 0 0 r
F
0 g
.52383 .9719 m
.52434 .97221 L
s
.56613 .82717 m .56876 .75811 L .56611 .79243 L 0 .966 .238 r
F
.5591 .81007 m .56611 .79243 L .56876 .75811 L 0 1 .254 r
F
0 g
.56838 .73684 m
.56876 .75811 L
s
.56876 .75811 m
.56947 .75259 L
s
.56558 .79532 m
.56612 .80164 L
s
.55234 .7294 m .55637 .72413 L .56091 .71253 L 0 1 .293 r
F
0 g
.56091 .71253 m
.56102 .71267 L
s
.56019 .72209 m
.56058 .72058 L
s
.24334 .65705 m .2327 .65417 L .23183 .6614 L 0 1 .52 r
F
0 g
.22543 .66699 m
.23183 .6614 L
s
.23614 .66246 m
.24315 .6572 L
s
.50872 .92877 m .5043 .92073 L .50342 .9162 L 0 .21 .095 r
F
0 g
.50284 .91572 m
.50342 .9162 L
s
.50803 .91143 m
.50817 .91635 L
s
.56102 .68843 m .57309 .66993 L .57059 .67067 L 0 1 .19 r
F
0 g
.56593 .68231 m
.57109 .67439 L
s
.56753 .68269 m
.56806 .68282 L
s
.57309 .66993 m
.57836 .66153 L
s
.48654 1.00988 m .47907 1.00713 L .48218 1.01259 L 0 .289 .316 r
F
.48654 1.00988 m .47827 1.00228 L .47907 1.00713 L F
0 g
.4752 1.00371 m
.47907 1.00713 L
s
.31288 .73694 m
.31829 .72978 L
s
.32825 .90649 m .32116 .90754 L .32545 .90791 L 0 1 .439 r
F
0 g
.32545 .90791 m
.32968 .9098 L
s
.32825 .90649 m .31748 .90537 L .32116 .90754 L 0 1 .439 r
F
0 g
.31901 .9091 m
.32116 .90754 L
s
.42198 .92098 m .41212 .92026 L .40953 .91963 L 0 0 0 r
F
.42198 .92098 m .41673 .92104 L .41212 .92026 L F
.42198 .92098 m .42096 .92135 L .41673 .92104 L F
.43329 .92278 m .42096 .92135 L .42198 .92098 L F
0 g
.42198 .92098 m
.4261 .92118 L
s
.41938 .92034 m
.42198 .92098 L
s
.43058 .92181 m
.43486 .92177 L
s
.48781 .93675 m .47979 .93287 L .47811 .93346 L 0 .622 .431 r
F
0 g
.47443 .93188 m
.47811 .93346 L
s
.48954 .89983 m .47778 .88083 L .47782 .88475 L 0 .592 .304 r
F
0 g
.47544 .88632 m
.47761 .89 L
s
.48954 .89983 m .48127 .88293 L .47778 .88083 L 0 .592 .304 r
F
0 g
.47508 .87567 m
.47778 .88083 L
s
.47435 .88446 m
.47707 .88469 L
s
.47954 .88189 m
.48026 .88232 L
s
.47861 .88133 m
.47954 .88189 L
s
.47778 .88083 m
.47861 .88133 L
s
.77739 .61384 m .79559 .62126 L .79399 .61728 L 0 1 .49 r
F
.48328 .92528 m .47709 .9218 L .48096 .92326 L 0 .157 .063 r
F
.48544 .92221 m .48096 .92326 L .47709 .9218 L 0 .135 .062 r
F
0 g
.47509 .91975 m
.47709 .9218 L
s
.47462 .92169 m
.47709 .9218 L
s
.61551 .63222 m .62836 .62808 L .63111 .62697 L 0 .804 .211 r
F
.61551 .63222 m .62168 .63033 L .62836 .62808 L F
0 g
.62836 .62808 m
.63055 .62829 L
s
.447 .92272 m .44181 .92371 L .43732 .9229 L 0 0 0 r
F
.447 .92272 m .44596 .92363 L .44181 .92371 L F
.45794 .92492 m .44596 .92363 L .447 .92272 L 0 .051 .01 r
F
0 g
.44453 .92159 m
.447 .92272 L
s
.447 .92272 m
.45101 .92265 L
s
.49625 .92527 m .4888 .92302 L .48687 .92035 L 0 .183 .081 r
F
0 g
.48343 .92015 m
.48687 .92035 L
s
.54735 1.10154 m .55356 1.10317 L .55228 1.10456 L 0 .232 0 r
F
0 g
.55356 1.10317 m
.55869 1.10609 L
s
.55021 1.0985 m
.55356 1.10317 L
s
.2001 .92467 m .19312 .92626 L .19769 .92659 L 0 .85 .347 r
F
0 g
.19769 .92659 m
.20312 .92896 L
s
.2001 .92467 m .18861 .9236 L .19312 .92626 L 0 .85 .347 r
F
0 g
.19178 .92842 m
.19312 .92626 L
s
.48001 .91445 m .46905 .90865 L .47278 .91374 L 0 .576 .317 r
F
0 g
.46905 .90865 m
.46953 .9093 L
s
.46629 .91101 m
.46786 .9129 L
s
.46629 .91101 m
.46905 .90865 L
s
.34945 .67582 m
.34969 .67383 L
s
.39537 .87059 m .38762 .86124 L .3839 .86346 L 0 1 .492 r
F
.39537 .87059 m .39231 .86259 L .38762 .86124 L F
.39537 .87059 m .39563 .8666 L .39231 .86259 L F
.40711 .87388 m .39563 .8666 L .39537 .87059 L 0 1 .488 r
F
0 g
.39164 .8728 m
.39537 .87059 L
s
.39537 .87059 m
.3987 .87448 L
s
.41283 .55994 m
.41742 .55314 L
s
.3594 .6756 m .35572 .67507 L .35063 .67383 L 0 0 0 r
F
0 g
.34969 .67383 m
.34973 .67352 L
s
.3594 .6756 m .36543 .67508 L .36207 .67561 L 0 0 0 r
F
.3594 .6756 m .36427 .67508 L .36543 .67508 L F
.3594 .6756 m .36207 .67561 L .35572 .67507 L F
0 g
.35858 .67638 m
.3594 .6756 L
s
.35403 .67515 m
.3594 .6756 L
s
.62984 .7823 m
.63027 .77473 L
s
.49285 .78685 m .48794 .79449 L .48976 .78918 L 0 .341 .096 r
F
.49285 .78685 m .48866 .8009 L .48794 .79449 L F
.49285 .78685 m .49144 .80414 L .48866 .8009 L F
0 g
.48946 .78369 m
.48976 .78918 L
s
.49285 .78685 m .49455 .80177 L .49144 .80414 L 0 .341 .096 r
F
.49285 .78685 m .49589 .79541 L .49455 .80177 L F
.49285 .78685 m .49516 .78903 L .49589 .79541 L F
0 g
.49516 .78903 m
.4979 .78456 L
s
.49263 .78285 m
.49285 .78685 L
s
.48976 .78918 m
.49285 .78685 L
s
.34607 .67209 m .34059 .66929 L .34415 .67135 L 0 0 0 r
F
.34625 .6718 m .34455 .67108 L .34607 .67209 L 0 1 .373 r
F
.35088 .66431 m .34455 .67108 L .34625 .6718 L F
.34455 .67108 m .34059 .66929 L .34607 .67209 L 0 0 0 r
F
.34455 .67108 m .34042 .67549 L .34607 .67209 L 0 1 .373 r
F
.34455 .67108 m .3412 .66965 L .34059 .66929 L 0 0 0 r
F
.35088 .66431 m .34208 .66299 L .3412 .66965 L 0 1 .373 r
F
.3378 .66692 m .33066 .6557 L .3298 .66075 L 0 .211 .269 r
F
.34455 .67108 m .3412 .66965 L .3407 .67335 L 0 1 .373 r
F
.35088 .66431 m .3412 .66965 L .34455 .67108 L F
.34455 .67108 m .34124 .66968 L .3412 .66965 L 0 0 0 r
F
.34455 .67108 m .3407 .67335 L .34126 .67459 L 0 1 .373 r
F
.35063 .67383 m .34188 .67007 L .34124 .66968 L 0 0 0 r
F
.35063 .67383 m .34455 .67108 L .34607 .67209 L F
.35063 .67383 m .34124 .66968 L .34455 .67108 L F
.3388 .66859 m .32928 .678 L .3341 .67661 L 0 1 .178 r
F
.33852 .66766 m .3298 .66075 L .33444 .66474 L 0 .211 .269 r
F
.33879 .66785 m .33848 .66761 L .33852 .66766 L F
.33848 .66761 m .3298 .66075 L .33852 .66766 L F
.33815 .66719 m .33559 .66202 L .3378 .66692 L F
.33836 .66735 m .33816 .66697 L .33815 .66719 L F
.33816 .66697 m .33559 .66202 L .33815 .66719 L F
.3372 .66408 m .33559 .66202 L .33816 .66697 L F
.33817 .66682 m .33816 .66697 L .33836 .66735 L F
.3372 .66408 m .33816 .66697 L .33817 .66682 L F
.33876 .66689 m .33826 .66543 L .33836 .66735 L 0 1 .178 r
F
.34208 .66299 m .33871 .66515 L .33876 .66689 L F
.33871 .66515 m .33826 .66543 L .33876 .66689 L F
.33826 .66543 m .33645 .65296 L .33066 .6557 L 0 .211 .269 r
F
.33871 .66515 m .33855 .66377 L .33826 .66543 L 0 1 .178 r
F
.34208 .66299 m .33888 .66281 L .33871 .66515 L F
.33888 .66281 m .33843 .66279 L .33871 .66515 L F
.33901 .66104 m .33645 .65296 L .33826 .66543 L 0 .211 .269 r
F
.33888 .66281 m .33856 .66075 L .33843 .66279 L 0 1 .178 r
F
.34208 .66299 m .33901 .66104 L .33888 .66281 L F
.33901 .66104 m .33856 .66075 L .33888 .66281 L F
.33901 .66104 m .33838 .65434 L .33854 .65955 L 0 .211 .269 r
F
.34208 .66299 m .33836 .66735 L .3391 .66808 L 0 1 .178 r
F
.34208 .66299 m .34427 .64566 L .33894 .65474 L F
.33896 .65695 m .33838 .65434 L .33901 .66104 L 0 .211 .269 r
F
.34208 .66299 m .33894 .65474 L .33901 .66104 L 0 1 .178 r
F
.33923 .65814 m .33945 .65511 L .33838 .65434 L 0 .211 .269 r
F
.33854 .65955 m .33838 .65434 L .33645 .65296 L F
.33901 .66104 m .33894 .65474 L .33627 .65929 L 0 1 .178 r
F
.33923 .65814 m .33896 .65695 L .33901 .66104 L 0 .211 .269 r
F
.34188 .67007 m .33923 .65814 L .33901 .66104 L F
.34188 .67007 m .33901 .66104 L .33826 .66543 L F
.33855 .66377 m .33843 .66279 L .33826 .66543 L 0 1 .178 r
F
.35088 .66431 m .34792 .64624 L .34208 .66299 L 0 1 .373 r
F
.34208 .66299 m .34792 .64624 L .34886 .63881 L 0 1 .178 r
F
.34208 .66299 m .34886 .63881 L .34427 .64566 L F
.34188 .67007 m .34391 .65829 L .33945 .65511 L 0 .211 .269 r
F
.34188 .67007 m .33945 .65511 L .33923 .65814 L F
.34188 .67007 m .33826 .66543 L .33836 .66735 L F
.33826 .66543 m .3372 .66408 L .33836 .66735 L F
.33826 .66543 m .33727 .66607 L .33836 .66735 L 0 1 .178 r
F
.33559 .66202 m .33066 .6557 L .3378 .66692 L 0 .211 .269 r
F
.33826 .66543 m .33451 .66256 L .33727 .66607 L 0 1 .178 r
F
.33843 .66279 m .33451 .66256 L .33826 .66543 L F
.33843 .66279 m .33627 .65929 L .33451 .66256 L F
.33856 .66075 m .33627 .65929 L .33843 .66279 L F
.33873 .66779 m .3298 .66075 L .33879 .66785 L 0 .211 .269 r
F
.33836 .66735 m .3298 .66075 L .3391 .66808 L F
.33727 .66607 m .33451 .66256 L .33021 .67058 L 0 1 .178 r
F
.33836 .66735 m .33021 .67058 L .32928 .678 L F
.33727 .66607 m .33021 .67058 L .33836 .66735 L F
.3391 .66808 m .33873 .66779 L .33879 .66785 L 0 .211 .269 r
F
.34188 .67007 m .33836 .66735 L .3391 .66808 L F
.3391 .66808 m .33836 .66735 L .3388 .66859 L 0 1 .178 r
F
.33836 .66735 m .32928 .678 L .3388 .66859 L F
.34126 .67459 m .3407 .67335 L .34042 .67549 L 0 1 .373 r
F
.34607 .67209 m .34042 .67549 L .34404 .67538 L F
0 g
.34649 .67141 m
.35088 .66431 L
s
.34625 .6718 m
.34649 .67141 L
s
.34623 .67184 m
.34625 .6718 L
s
.34976 .67329 m
.35088 .66431 L
s
.34973 .67352 m
.34974 .67349 L
s
.34974 .67343 m
.34976 .67329 L
s
.33827 .66949 m
.33963 .66937 L
s
.33963 .66937 m
.34059 .66929 L
s
.34792 .64624 m
.3528 .63836 L
s
.4898 .88556 m .48152 .87401 L .48618 .88178 L 0 .629 .304 r
F
.48955 .8926 m .48618 .88178 L .48152 .87401 L 0 .612 .304 r
F
0 g
.47822 .86531 m
.48152 .87401 L
s
.48074 .87337 m
.48152 .87401 L
s
.53728 .80193 m
.5373 .79603 L
s
.4307 .88941 m .42221 .88143 L .41881 .88259 L 0 1 .482 r
F
0 g
.41881 .88259 m
.41949 .88236 L
s
.49018 1.0263 m .48694 1.02081 L .48331 1.0174 L 0 .26 .302 r
F
.75716 .88744 m .76472 .89082 L .76842 .88837 L 0 1 .38 r
F
.75716 .88744 m .76011 .89127 L .76472 .89082 L F
0 g
.76472 .89082 m
.76712 .89262 L
s
.36735 .58495 m
.37027 .57798 L
s
.50315 .89981 m .49377 .85794 L .49323 .86016 L 0 .53 .288 r
F
.50315 .89981 m .497 .86879 L .49377 .85794 L F
0 g
.49319 .8551 m
.49377 .85794 L
s
.49803 .85791 m
.49812 .85859 L
s
.49629 .85315 m
.49735 .85914 L
s
.75707 .61655 m .75975 .61263 L .75576 .61328 L 0 1 .445 r
F
.75707 .61655 m .76722 .61527 L .75975 .61263 L F
0 g
.40521 .9192 m
.40953 .91963 L
s
.29595 .75065 m .28498 .7469 L .28588 .75021 L 0 1 .482 r
F
0 g
.28087 .75173 m
.28588 .75021 L
s
.66631 .64614 m
.66801 .66033 L
s
.43826 .53549 m .42792 .53714 L .43015 .5392 L 0 1 .428 r
F
.43826 .53549 m .43312 .53063 L .42792 .53714 L F
.43826 .53549 m .4423 .52401 L .43312 .53063 L F
.43826 .53549 m .45041 .5203 L .4423 .52401 L F
.43826 .53549 m .45206 .52198 L .45041 .5203 L F
0 g
.44685 .52848 m
.45206 .52198 L
s
.45206 .52198 m
.45993 .51813 L
s
.52312 .92899 m .53295 .90258 L .53037 .91111 L 0 .258 .126 r
F
0 g
.53245 .90425 m
.53295 .90258 L
s
.53096 .90493 m
.53098 .90488 L
s
.5284 .90608 m
.52877 .90515 L
s
.52827 .90572 m
.52911 .90229 L
s
.53295 .90258 m
.53371 .90054 L
s
.41885 .87772 m .41045 .87767 L .41515 .8791 L 0 1 .482 r
F
0 g
.41515 .8791 m
.41881 .88259 L
s
.41885 .87772 m .40711 .87388 L .41045 .87767 L 0 1 .482 r
F
0 g
.40806 .87881 m
.41045 .87767 L
s
.51048 .96015 m .50766 .96013 L .5096 .96157 L 0 .258 .214 r
F
.51048 .96015 m .50673 .95869 L .50766 .96013 L F
0 g
.5057 .95936 m
.50766 .96013 L
s
.5193 .96887 m .51736 .96739 L .51612 .96661 L 0 .155 .175 r
F
.31969 .75837 m .31234 .75334 L .30943 .75514 L 0 .801 .388 r
F
0 g
.30943 .75514 m
.31036 .75734 L
s
.31969 .75837 m .31754 .75321 L .31234 .75334 L 0 .801 .388 r
F
.31969 .75837 m .32155 .75485 L .31754 .75321 L F
.31969 .75837 m .32246 .75706 L .32155 .75485 L F
0 g
.3145 .75849 m
.31969 .75837 L
s
.31969 .75837 m
.32072 .76014 L
s
.52302 .62368 m .51854 .62628 L .51839 .62506 L 0 0 0 r
F
.52302 .62368 m .52376 .62716 L .51854 .62628 L F
.52302 .62368 m .53055 .62712 L .52376 .62716 L F
.52302 .62368 m .53518 .62573 L .53055 .62712 L F
.52302 .62368 m .53455 .62392 L .53518 .62573 L F
0 g
.53455 .62392 m
.53875 .62264 L
s
.52934 .62305 m
.53455 .62392 L
s
.47615 .94355 m .46699 .94304 L .47076 .94691 L 0 .505 .328 r
F
0 g
.46541 .94692 m
.46699 .94304 L
s
.52064 .92497 m .52631 .90671 L .52324 .91726 L 0 .25 .115 r
F
.52156 .92598 m .52324 .91726 L .52631 .90671 L 0 .254 .119 r
F
0 g
.52631 .90671 m
.52719 .90261 L
s
.52631 .90671 m
.52823 .90149 L
s
.68517 .68436 m
.68651 .6802 L
s
.46898 .91821 m .45995 .91227 L .4572 .91259 L 0 .856 .464 r
F
0 g
.46786 .9129 m
.46941 .91476 L
s
.45321 .91009 m
.4572 .91259 L
s
.31829 .72978 m
.3183 .72193 L
s
.5127 .89855 m .51384 .85966 L .51322 .84118 L 0 .491 .268 r
F
0 g
.51322 .84118 m
.51407 .82219 L
s
.71247 .61462 m .72818 .6149 L .72188 .61255 L 0 1 .352 r
F
0 g
.72818 .6149 m
.72992 .61704 L
s
.72818 .6149 m
.73587 .61624 L
s
.60932 .6356 m .60909 .63482 L .60673 .6364 L 0 0 0 r
F
.60932 .6356 m .61551 .63222 L .60909 .63482 L F
.60932 .6356 m .62168 .63033 L .61551 .63222 L F
0 g
.62168 .63033 m
.62836 .62808 L
s
.62168 .63033 m
.62425 .62954 L
s
.60319 .63872 m
.60932 .6356 L
s
.51106 .92652 m .51021 .91472 L .5109 .92128 L 0 .206 .095 r
F
.51227 .9256 m .5109 .92128 L .51021 .91472 L 0 .207 .096 r
F
0 g
.51021 .91472 m
.51024 .91391 L
s
.50898 .91051 m
.51021 .91472 L
s
.49844 1.04017 m .49259 1.03693 L .49639 1.04245 L 0 .185 .248 r
F
.49844 1.04017 m .4906 1.03208 L .49259 1.03693 L F
0 g
.48888 1.03339 m
.49259 1.03693 L
s
.49625 .92527 m .49107 .92007 L .49432 .92259 L 0 .183 .081 r
F
.49806 .9227 m .49432 .92259 L .49107 .92007 L 0 .167 .08 r
F
0 g
.48947 .91723 m
.49107 .92007 L
s
.48931 .91954 m
.49107 .92007 L
s
.46898 .91821 m .4619 .9172 L .46623 .91852 L 0 .856 .464 r
F
.47096 .92252 m .46623 .91852 L .4619 .9172 L 0 .839 .465 r
F
0 g
.45803 .91466 m
.4619 .9172 L
s
.46146 .91729 m
.4619 .9172 L
s
.47996 .99653 m .47742 .99121 L .47367 .98786 L 0 .337 .335 r
F
.52701 1.08603 m .52366 1.07999 L .5285 1.08542 L 0 .162 0 r
F
.52701 1.08603 m .51983 1.07591 L .52366 1.07999 L F
0 g
.52023 1.07584 m
.52366 1.07999 L
s
.44325 .89993 m .439 .89438 L .43432 .89277 L 0 1 .48 r
F
.44325 .89993 m .44283 .89745 L .439 .89438 L F
.45484 .90421 m .44325 .89993 L .44703 .90299 L 0 .967 .471 r
F
.45484 .90421 m .44283 .89745 L .44325 .89993 L F
0 g
.44411 .90362 m
.44674 .90305 L
s
.44011 .90084 m
.44325 .89993 L
s
.75716 .88744 m .75687 .88982 L .76011 .89127 L 0 1 .38 r
F
0 g
.75565 .8934 m
.76011 .89127 L
s
.48024 .98102 m .47137 .9779 L .47374 .98323 L 0 .37 .329 r
F
.48024 .98102 m .47174 .97339 L .47137 .9779 L F
0 g
.46744 .97441 m
.47137 .9779 L
s
.48539 .93331 m .47622 .93098 L .47979 .93287 L 0 .663 .438 r
F
.48539 .93331 m .47504 .92931 L .47622 .93098 L F
0 g
.47443 .93188 m
.47622 .93098 L
s
.28181 .90239 m .27232 .89544 L .26947 .89787 L 0 1 .497 r
F
.28181 .90239 m .27696 .89596 L .27232 .89544 L F
.28181 .90239 m .28103 .89894 L .27696 .89596 L F
0 g
.27896 .9048 m
.28181 .90239 L
s
.29594 .90346 m .28103 .89894 L .28181 .90239 L 0 1 .486 r
F
0 g
.28181 .90239 m
.28662 .90521 L
s
.39221 .66982 m .38266 .67235 L .38589 .67197 L 0 .924 .243 r
F
.63767 .62574 m .63799 .62388 L .63523 .62517 L 0 .836 .248 r
F
.63767 .62574 m .64481 .62273 L .63799 .62388 L F
.63767 .62574 m .65112 .62251 L .64481 .62273 L F
0 g
.65112 .62251 m
.65817 .62151 L
s
.65112 .62251 m
.65353 .62309 L
s
.49031 .87875 m .49058 .8761 L .48744 .86661 L 0 .643 .303 r
F
0 g
.48744 .86661 m
.4896 .87315 L
s
.48744 .86661 m
.48982 .8703 L
s
.47892 .9045 m .4713 .90256 L .47579 .90537 L 0 .61 .318 r
F
.48001 .91445 m .47579 .90537 L .4713 .90256 L 0 .576 .317 r
F
0 g
.46987 .90326 m
.4713 .90256 L
s
.46807 .89767 m
.4713 .90256 L
s
.68932 .68715 m
.68948 .68494 L
s
.44242 .89372 m .43432 .89277 L .439 .89438 L 0 1 .475 r
F
.44242 .89372 m .4307 .88941 L .43432 .89277 L F
0 g
.43119 .89368 m
.43432 .89277 L
s
.50315 .89981 m .49323 .86016 L .49585 .8734 L 0 .53 .288 r
F
0 g
.49699 .85467 m
.49876 .86345 L
s
.49464 .85482 m
.49604 .86308 L
s
.49304 .85975 m
.49323 .86016 L
s
.48954 .89983 m .47782 .88475 L .48136 .89198 L 0 .592 .304 r
F
0 g
.47782 .88475 m
.47809 .88528 L
s
.47809 .88528 m
.47989 .88897 L
s
.47707 .88469 m
.47782 .88475 L
s
.47335 .93194 m .46733 .93451 L .4712 .93504 L 0 .553 .33 r
F
.47615 .94355 m .4712 .93504 L .46733 .93451 L 0 .505 .328 r
F
0 g
.46553 .93794 m
.46733 .93451 L
s
.46423 .93109 m
.46733 .93451 L
s
.39221 .66982 m .38438 .6709 L .38266 .67235 L 0 .924 .243 r
F
.39221 .66982 m .38991 .66857 L .38438 .6709 L F
.39221 .66982 m .39625 .66641 L .38991 .66857 L F
.39221 .66982 m .39916 .66587 L .39625 .66641 L F
.39221 .66982 m .39742 .66733 L .39916 .66587 L F
0 g
.39073 .6715 m
.39221 .66982 L
s
.38589 .67197 m
.39221 .66982 L
s
.49655 .94691 m .4939 .948 L .49596 .94795 L 0 .446 .382 r
F
.49986 .95024 m .49596 .94795 L .4939 .948 L 0 .39 .352 r
F
0 g
.49369 .94916 m
.4939 .948 L
s
.49108 .9469 m
.4939 .948 L
s
.3766 .77044 m .36674 .76857 L .36759 .76864 L 0 0 0 r
F
0 g
.36291 .7681 m
.36759 .76864 L
s
.49342 .94355 m .48997 .94433 L .49245 .94447 L 0 .513 .404 r
F
.49655 .94691 m .49245 .94447 L .48997 .94433 L 0 .446 .382 r
F
0 g
.48938 .94537 m
.48997 .94433 L
s
.48691 .94306 m
.48997 .94433 L
s
.55234 .7294 m .56112 .69936 L .55666 .70561 L 0 1 .293 r
F
0 g
.55841 .71892 m
.56091 .71253 L
s
.55755 .72112 m
.55841 .71892 L
s
.56112 .69936 m
.56292 .69576 L
s
.56112 .69936 m
.56143 .69987 L
s
.45484 .90421 m .44703 .90299 L .45164 .90459 L 0 .967 .471 r
F
.45614 .90946 m .45164 .90459 L .44703 .90299 L 0 .961 .475 r
F
0 g
.44674 .90305 m
.44703 .90299 L
s
.44325 .89993 m
.44703 .90299 L
s
.79405 1.03835 m .79001 1.04333 L .79014 1.04554 L 0 1 .29 r
F
0 g
.7831 1.0499 m
.79014 1.04554 L
s
.45579 .78135 m .4479 .7818 L .45136 .78061 L 0 .158 .027 r
F
.45579 .78135 m .44741 .78444 L .4479 .7818 L F
.45579 .78135 m .45024 .78676 L .44741 .78444 L F
.45579 .78135 m .45469 .7875 L .45024 .78676 L F
.45579 .78135 m .4578 .78616 L .45469 .7875 L F
.45579 .78135 m .45826 .78353 L .4578 .78616 L F
0 g
.45579 .78135 m
.45653 .77821 L
s
.45136 .78061 m
.45579 .78135 L
s
.4307 .88941 m .42691 .88312 L .42221 .88143 L 0 1 .482 r
F
.4307 .88941 m .43055 .88654 L .42691 .88312 L F
.44242 .89372 m .43055 .88654 L .4307 .88941 L 0 1 .475 r
F
0 g
.42731 .89056 m
.4307 .88941 L
s
.4307 .88941 m
.43432 .89277 L
s
.51048 .96015 m .5096 .96157 L .51121 .9622 L 0 .258 .214 r
F
0 g
.5096 .96157 m
.51089 .96298 L
s
.29772 .65358 m .28772 .64848 L .28645 .6556 L 0 1 .499 r
F
0 g
.27984 .65957 m
.28645 .6556 L
s
.38498 .91626 m .37554 .91387 L .3729 .91404 L 0 .597 .239 r
F
.38498 .91626 m .38004 .9146 L .37554 .91387 L F
.38498 .91626 m .38409 .91562 L .38004 .9146 L F
0 g
.38234 .91643 m
.38498 .91626 L
s
.39655 .91784 m .38409 .91562 L .38498 .91626 L 0 .508 .211 r
F
0 g
.38498 .91626 m
.3891 .91714 L
s
.47996 .99653 m .47827 1.00228 L .48032 1.00128 L 0 .337 .335 r
F
.48654 1.00988 m .48032 1.00128 L .47827 1.00228 L 0 .289 .316 r
F
0 g
.47827 1.00228 m
.47907 1.00713 L
s
.47452 .99893 m
.47827 1.00228 L
s
.46867 .92317 m
.46869 .92318 L
s
.46858 .9231 m
.46867 .92317 L
s
.4685 .92305 m
.46858 .9231 L
s
.4685 .92305 m
.46893 .92296 L
s
.4685 .92305 m
.46871 .92316 L
s
.46871 .92316 m
.46886 .92324 L
s
.54435 1.10426 m .54206 1.09613 L .54735 1.10154 L 0 .282 0 r
F
.54435 1.10426 m .53745 1.09263 L .54206 1.09613 L F
0 g
.54206 1.09613 m
.54206 1.09613 L
s
.41797 .6595 m
.42389 .65715 L
s
.47095 .92473 m .46184 .92493 L .4594 .92325 L 0 .109 .04 r
F
0 g
.45534 .92348 m
.4594 .92325 L
s
.74558 .88941 m .75319 .89196 L .75687 .88982 L 0 1 .33 r
F
.74558 .88941 m .74858 .89242 L .75319 .89196 L F
0 g
.75319 .89196 m
.75565 .8934 L
s
.62547 .77285 m
.62842 .77401 L
s
.62531 .77279 m
.62547 .77285 L
s
.62842 .77401 m
.62846 .77402 L
s
.62846 .77402 m
.63027 .77473 L
s
.49986 .95024 m .49803 .95161 L .49965 .9514 L 0 .39 .352 r
F
.50331 .95355 m .49965 .9514 L .49803 .95161 L 0 .356 .312 r
F
0 g
.49803 .95161 m
.4982 .95287 L
s
.49547 .95065 m
.49803 .95161 L
s
.48539 .93331 m .47705 .92891 L .47504 .92931 L 0 .663 .438 r
F
0 g
.47253 .92812 m
.47504 .92931 L
s
.47811 .93346 m
.47918 .93308 L
s
.4905 .94017 m .48628 .94058 L .48916 .94093 L 0 .572 .42 r
F
.49342 .94355 m .48916 .94093 L .48628 .94058 L 0 .513 .404 r
F
0 g
.48532 .9415 m
.48628 .94058 L
s
.48302 .93913 m
.48628 .94058 L
s
.39766 .57061 m .3861 .57076 L .38938 .57365 L 0 1 .484 r
F
0 g
.38645 .58063 m
.38938 .57365 L
s
.39766 .57061 m .38982 .56373 L .3861 .57076 L 0 1 .484 r
F
.39766 .57061 m .39809 .55725 L .38982 .56373 L F
.39766 .57061 m .40638 .55421 L .39809 .55725 L F
.39766 .57061 m .40916 .55663 L .40638 .55421 L F
.39766 .57061 m .40542 .56366 L .40916 .55663 L F
0 g
.38938 .57365 m
.39766 .57061 L
s
.40542 .56366 m
.41283 .55994 L
s
.50761 .93006 m .50211 .91767 L .5043 .92073 L 0 .215 .095 r
F
.50761 .93006 m .50126 .91867 L .50211 .91767 L F
0 g
.5012 .91439 m
.50211 .91767 L
s
.50568 .91378 m
.50611 .91774 L
s
.51607 1.07168 m .51983 1.07591 L .51956 1.07589 L 0 .003 .157 r
F
.52701 1.08603 m .51956 1.07589 L .51983 1.07591 L 0 .162 0 r
F
0 g
.51983 1.07591 m
.52366 1.07999 L
s
.51638 1.07197 m
.51983 1.07591 L
s
.33903 .90774 m .3319 .90849 L .33619 .9089 L 0 .998 .412 r
F
0 g
.33619 .9089 m
.34036 .91061 L
s
.33903 .90774 m .32825 .90649 L .3319 .90849 L 0 .998 .412 r
F
0 g
.32968 .9098 m
.3319 .90849 L
s
.41347 .77577 m .40332 .77535 L .40433 .77445 L 0 0 0 r
F
0 g
.39949 .77362 m
.40433 .77445 L
s
.41347 .77577 m .40612 .7767 L .40332 .77535 L 0 0 0 r
F
.41347 .77577 m .41115 .77787 L .40612 .7767 L F
.41347 .77577 m .41504 .77809 L .41115 .77787 L F
.41347 .77577 m .41603 .77719 L .41504 .77809 L F
0 g
.41347 .77577 m
.41466 .77457 L
s
.40846 .7746 m
.41347 .77577 L
s
.33854 .69563 m .32829 .70413 L .33214 .70425 L 0 1 .406 r
F
0 g
.33212 .71211 m
.33214 .70425 L
s
.33854 .69563 m .32909 .6955 L .32829 .70413 L 0 1 .406 r
F
.33854 .69563 m .33401 .68412 L .32909 .6955 L F
.33854 .69563 m .34042 .67549 L .33401 .68412 L F
.33854 .69563 m .34404 .67538 L .34042 .67549 L F
.33854 .69563 m .34323 .68401 L .34404 .67538 L F
0 g
.34323 .68401 m
.34945 .67582 L
s
.34404 .67538 m
.34607 .67209 L
s
.3379 .70466 m
.33854 .69563 L
s
.33214 .70425 m
.33854 .69563 L
s
.70804 .80843 m .7188 .77937 L .72063 .79592 L 0 .422 .132 r
F
0 g
.72063 .79592 m
.72063 .79592 L
s
.7188 .77937 m
.72063 .79592 L
s
.7188 .77937 m
.72011 .77718 L
s
.28498 .7469 m .27478 .7469 L .27922 .74822 L 0 1 .505 r
F
0 g
.27922 .74822 m
.28087 .75173 L
s
.47892 .9045 m .47858 .90053 L .47487 .8949 L 0 .61 .318 r
F
0 g
.47487 .8949 m
.47565 .8961 L
s
.47487 .8949 m
.4761 .89479 L
s
.63961 .77411 m
.63978 .77339 L
s
.63928 .77553 m
.63961 .77411 L
s
.63452 .77232 m
.63697 .77397 L
s
.63697 .77397 m
.63864 .7751 L
s
.63864 .7751 m
.63928 .77553 L
s
.79521 .79958 m .80168 .7917 L .80635 .79263 L 0 .01 0 r
F
.79521 .79958 m .79691 .79467 L .80168 .7917 L F
0 g
.79856 .78865 m
.80168 .7917 L
s
.57874 .48631 m .58845 .49125 L .59702 .49734 L 0 .178 0 r
F
0 g
.58845 .49125 m
.59443 .49196 L
s
.59443 .49196 m
.5959 .49356 L
s
.48328 .92528 m .47469 .92489 L .47238 .92288 L 0 .157 .063 r
F
0 g
.4685 .92305 m
.47238 .92288 L
s
.40711 .87388 m .39934 .86478 L .39563 .8666 L 0 1 .488 r
F
.40711 .87388 m .40402 .86634 L .39934 .86478 L F
.40711 .87388 m .40735 .87024 L .40402 .86634 L F
.41885 .87772 m .40735 .87024 L .40711 .87388 L 0 1 .482 r
F
0 g
.40711 .87388 m
.41045 .87767 L
s
.4034 .87569 m
.40711 .87388 L
s
.57874 .48631 m .57359 .48723 L .57238 .48458 L 0 .178 0 r
F
.57874 .48631 m .58217 .49333 L .57359 .48723 L F
.57874 .48631 m .59238 .49881 L .58217 .49333 L F
.57874 .48631 m .59875 .50052 L .59238 .49881 L F
0 g
.5959 .49356 m
.59669 .49443 L
s
.57874 .48631 m .59702 .49734 L .59875 .50052 L 0 .178 0 r
F
0 g
.57055 .4801 m
.57874 .48631 L
s
.58845 .49125 m
.5954 .49619 L
s
.75214 1.06776 m .74756 1.06956 L .74714 1.06927 L 0 0 0 r
F
0 g
.73998 1.07157 m
.74714 1.06927 L
s
.48146 .92443 m .47015 .91565 L .47098 .92031 L 0 .539 .316 r
F
.48146 .92443 m .47278 .91374 L .47015 .91565 L F
0 g
.46941 .91476 m
.47015 .91565 L
s
.46869 .92318 m
.46871 .92319 L
s
.47015 .91565 m
.47128 .91483 L
s
.21159 .92578 m .20455 .92708 L .20912 .92742 L 0 .777 .318 r
F
0 g
.20912 .92742 m
.21447 .92955 L
s
.21159 .92578 m .2001 .92467 L .20455 .92708 L 0 .777 .318 r
F
0 g
.20312 .92896 m
.20455 .92708 L
s
.73205 .78891 m
.73729 .78311 L
s
.73729 .78311 m .74442 .79511 L .7398 .79315 L 0 .325 .086 r
F
.73729 .78311 m .74892 .78915 L .74442 .79511 L F
0 g
.73729 .78311 m
.7398 .79315 L
s
.53478 1.09257 m .53745 1.09262 L .53657 1.09335 L 0 .245 0 r
F
0 g
.53687 1.09088 m
.53745 1.09262 L
s
.54435 1.10426 m .53657 1.09335 L .53745 1.09263 L 0 .282 0 r
F
0 g
.53745 1.09263 m
.54206 1.09613 L
s
.50255 .90247 m .49248 .86361 L .49203 .866 L 0 .534 .289 r
F
.50255 .90247 m .49585 .8734 L .49248 .86361 L F
0 g
.49151 .8596 m
.49248 .86361 L
s
.49584 .85503 m
.49831 .86463 L
s
.74852 .65807 m .76345 .63607 L .75858 .65367 L 0 .171 .095 r
F
0 g
.76345 .63607 m
.76628 .63056 L
s
.76345 .63607 m
.7636 .63199 L
s
.34992 .61431 m
.34993 .61427 L
s
.74558 .88941 m .74531 .89133 L .74858 .89242 L 0 1 .33 r
F
0 g
.74531 .89133 m
.74858 .89242 L
s
.74417 .89421 m
.74858 .89242 L
s
.41742 .55314 m .42565 .54606 L .43015 .5392 L 0 1 .467 r
F
.5303 .97795 m .53221 .97736 L .53453 .97901 L 0 .068 0 r
F
.5303 .97795 m .52944 .9758 L .53221 .97736 L F
0 g
.53149 .97613 m
.53221 .97736 L
s
.53092 .97663 m
.53221 .97736 L
s
.52944 .9758 m
.5299 .97606 L
s
.5299 .97606 m
.53092 .97663 L
s
.52868 .97494 m
.52944 .9758 L
s
.58371 .65428 m .583 .65356 L .58107 .65623 L 0 0 0 r
F
0 g
.58202 .65552 m
.5837 .65428 L
s
.5837 .65428 m
.58371 .65428 L
s
.58154 .65678 m
.5837 .65428 L
s
.5837 .65428 m
.5837 .65428 L
s
.55666 .70561 m .56593 .68231 L .56102 .68843 L 0 1 .248 r
F
0 g
.56593 .68231 m
.56753 .68269 L
s
.64481 .62273 m .66127 .6204 L .65862 .61952 L 0 .978 .276 r
F
0 g
.66127 .6204 m
.66509 .62015 L
s
.34323 .68401 m
.34404 .67538 L
s
.50716 .62628 m .51351 .62507 L .51839 .62506 L 0 0 0 r
F
0 g
.50265 .62636 m
.50716 .62628 L
s
.36173 .91268 m
.36173 .91268 L
s
.68933 .68715 m
.68984 .68594 L
s
.69301 .67853 m
.69367 .67697 L
s
.49018 1.0263 m .4906 1.03208 L .49175 1.03114 L 0 .26 .302 r
F
.49844 1.04017 m .49175 1.03114 L .4906 1.03208 L 0 .185 .248 r
F
0 g
.4906 1.03208 m
.49259 1.03693 L
s
.48696 1.02866 m
.4906 1.03208 L
s
.50601 1.05644 m .50214 1.05082 L .49873 1.04712 L 0 .109 .185 r
F
.48654 1.00988 m .48218 1.01259 L .48572 1.01585 L 0 .289 .316 r
F
0 g
.48218 1.01259 m
.48331 1.0174 L
s
.46065 .64099 m .45319 .6432 L .45488 .64299 L 0 .815 .206 r
F
.46065 .64099 m .45675 .64159 L .45319 .6432 L F
0 g
.45184 .64485 m
.45488 .64299 L
s
.46065 .64099 m .46319 .63921 L .45675 .64159 L 0 .815 .206 r
F
.46065 .64099 m .46896 .63722 L .46319 .63921 L F
.46065 .64099 m .47021 .63693 L .46896 .63722 L F
.46065 .64099 m .46665 .63855 L .47021 .63693 L F
0 g
.45488 .64299 m
.46065 .64099 L
s
.46665 .63855 m
.47213 .63634 L
s
.40332 .77535 m
.40433 .77445 L
s
.35201 .60675 m .35924 .59016 L .3623 .57807 L 0 1 .342 r
F
0 g
.34993 .61427 m
.35201 .60675 L
s
.2327 .65417 m .22102 .65881 L .22535 .65983 L 0 1 .521 r
F
0 g
.22535 .65983 m
.22543 .66699 L
s
.62094 .69644 m
.62158 .70073 L
s
.62182 .70237 m .63017 .7218 L .6241 .70365 L 0 0 .148 r
F
.62182 .70237 m .63502 .73823 L .63017 .7218 L F
.62182 .70237 m .63598 .74474 L .63502 .73823 L F
.62182 .70237 m .63241 .73696 L .63598 .74474 L F
.62182 .70237 m .62634 .7188 L .63241 .73696 L F
0 g
.62158 .70073 m
.62182 .70237 L
s
.63479 .78135 m
.63488 .78352 L
s
.63443 .77291 m
.63479 .78135 L
s
.63579 .79013 m
.63609 .79402 L
s
.63609 .79402 m
.63635 .7973 L
s
.63635 .7973 m
.63685 .80377 L
s
.6354 .78503 m
.63579 .79013 L
s
.63452 .77367 m
.6354 .78503 L
s
.63447 .77302 m
.63452 .77367 L
s
.63445 .77281 m
.63447 .77302 L
s
.75782 .63505 m .77348 .62673 L .76794 .63238 L 0 0 .004 r
F
0 g
.77348 .62673 m
.77924 .62325 L
s
.77348 .62673 m
.77445 .62266 L
s
.59745 .65288 m
.59925 .65611 L
s
.59925 .65611 m
.60019 .6578 L
s
.60019 .6578 m
.60099 .65925 L
s
.59716 .65291 m
.59745 .65288 L
s
.59618 .653 m
.59716 .65291 L
s
.59482 .65312 m
.59618 .653 L
s
.48781 .93675 m .48288 .93676 L .48612 .93734 L 0 .622 .431 r
F
.4905 .94017 m .48612 .93734 L .48288 .93676 L 0 .572 .42 r
F
0 g
.48155 .93753 m
.48288 .93676 L
s
.47944 .9351 m
.48288 .93676 L
s
.55405 .47852 m .564 .48085 L .57238 .48458 L 0 .096 0 r
F
0 g
.564 .48085 m
.57055 .4801 L
s
.4754 .96839 m .47358 .96333 L .46978 .95984 L 0 .439 .337 r
F
.50331 .95355 m .50232 .95516 L .50348 .95481 L 0 .356 .312 r
F
.50686 .95684 m .50348 .95481 L .50232 .95516 L 0 .312 .264 r
F
0 g
.50232 .95516 m
.50288 .95652 L
s
.50006 .95433 m
.50232 .95516 L
s
.41742 .55314 m .40638 .55421 L .40916 .55663 L 0 1 .467 r
F
0 g
.40542 .56366 m
.40916 .55663 L
s
.41742 .55314 m .41088 .54735 L .40638 .55421 L 0 1 .467 r
F
.41742 .55314 m .41966 .54063 L .41088 .54735 L F
.41742 .55314 m .42792 .53714 L .41966 .54063 L F
.41742 .55314 m .43015 .5392 L .42792 .53714 L F
0 g
.42565 .54606 m
.43015 .5392 L
s
.40916 .55663 m
.41742 .55314 L
s
.43015 .5392 m
.43826 .53549 L
s
.47358 .50415 m
.48 .49885 L
s
.46571 .50798 m
.47358 .50415 L
s
.4754 .96839 m .47174 .97339 L .47461 .9727 L 0 .439 .337 r
F
.48024 .98102 m .47461 .9727 L .47174 .97339 L 0 .37 .329 r
F
0 g
.47137 .9779 m
.47174 .97339 L
s
.46795 .96989 m
.47174 .97339 L
s
.50002 .92017 m .49921 .92118 L .49645 .91985 L 0 .152 .079 r
F
0 g
.49645 .91985 m
.49876 .92096 L
s
.71247 .61462 m .71437 .6115 L .71069 .61247 L 0 1 .352 r
F
.71247 .61462 m .72188 .61255 L .71437 .6115 L F
0 g
.4406 .78153 m
.44148 .77974 L
s
.44571 .78021 m
.44594 .78023 L
s
.44148 .77974 m
.44571 .78021 L
s
.45484 .90421 m .44603 .89707 L .44283 .89745 L 0 .967 .471 r
F
0 g
.439 .89438 m
.44283 .89745 L
s
.51393 .90166 m .51469 .84381 L .51384 .85966 L 0 .492 .267 r
F
.51393 .90166 m .51567 .84591 L .51469 .84381 L F
0 g
.51407 .82219 m
.51469 .84381 L
s
.62209 .7682 m
.62209 .7682 L
s
.61746 .76283 m
.62209 .7682 L
s
.29594 .90346 m .28471 .89685 L .28103 .89894 L 0 1 .486 r
F
.29594 .90346 m .29041 .89753 L .28471 .89685 L F
.29594 .90346 m .29522 .90037 L .29041 .89753 L F
0 g
.29225 .90553 m
.29594 .90346 L
s
.30671 .90437 m .29523 .90037 L .29594 .90346 L 0 1 .474 r
F
0 g
.29594 .90346 m
.29969 .90599 L
s
.50987 .92758 m .50818 .91664 L .50934 .92268 L 0 .207 .095 r
F
.51106 .92652 m .50934 .92268 L .50818 .91664 L 0 .206 .095 r
F
0 g
.50817 .91635 m
.50818 .91664 L
s
.50661 .91283 m
.50818 .91664 L
s
.48024 .98102 m .47374 .98323 L .47738 .9865 L 0 .37 .329 r
F
0 g
.47367 .98786 m
.47374 .98323 L
s
.48979 .90722 m .478 .89065 L .47818 .89459 L 0 .568 .304 r
F
.48979 .90722 m .48136 .89198 L .478 .89065 L F
0 g
.47989 .88897 m
.48098 .89121 L
s
.47761 .89 m
.478 .89065 L
s
.4761 .89479 m
.47709 .8947 L
s
.47565 .8961 m
.47637 .89718 L
s
.47637 .89718 m
.47818 .89993 L
s
.48015 .8915 m
.48053 .89165 L
s
.4791 .89108 m
.48015 .8915 L
s
.478 .89065 m
.4791 .89108 L
s
.50255 .90247 m .49203 .866 L .49488 .87841 L 0 .534 .289 r
F
0 g
.49323 .86016 m
.4951 .8696 L
s
.49007 .86235 m
.49203 .866 L
s
.58284 .63965 m
.58461 .64195 L
s
.58461 .64195 m
.58554 .64315 L
s
.58763 .64587 m
.58845 .64694 L
s
.57966 .64052 m
.58284 .63965 L
s
.48326 .92985 m .47338 .92679 L .47705 .92891 L 0 .696 .442 r
F
.48326 .92985 m .47236 .92509 L .47338 .92679 L F
0 g
.47224 .92718 m
.47338 .92679 L
s
.28498 .7469 m .27399 .74317 L .27478 .7469 L 0 1 .505 r
F
0 g
.26969 .74878 m
.27478 .7469 L
s
.73767 .64071 m .74095 .64533 L .737 .64698 L 0 .052 .051 r
F
.73767 .64071 m .74773 .63781 L .74095 .64533 L F
0 g
.73109 .64958 m
.73767 .64071 L
s
.45614 .90946 m .45554 .90736 L .45164 .90459 L 0 .961 .475 r
F
.46747 .91386 m .45614 .90946 L .45995 .91227 L 0 .869 .462 r
F
.46747 .91386 m .45554 .90736 L .45614 .90946 L F
0 g
.4572 .91259 m
.45957 .91232 L
s
.45321 .91009 m
.45614 .90946 L
s
.24334 .65705 m .23819 .64557 L .2327 .65417 L 0 1 .52 r
F
.24334 .65705 m .24542 .64012 L .23819 .64557 L F
.24334 .65705 m .24955 .64148 L .24542 .64012 L F
.24334 .65705 m .24865 .64874 L .24955 .64148 L F
0 g
.24315 .6572 m
.24334 .65705 L
s
.24261 .66409 m
.24334 .65705 L
s
.60275 .50104 m .59875 .50052 L .59702 .49734 L 0 .214 0 r
F
0 g
.59702 .49734 m
.5973 .49752 L
s
.5954 .49619 m
.59702 .49734 L
s
.60275 .50104 m .60744 .50933 L .59875 .50052 L 0 .214 0 r
F
.60275 .50104 m .61731 .51788 L .60744 .50933 L F
.60275 .50104 m .62304 .52157 L .61731 .51788 L F
0 g
.61749 .51181 m
.61899 .51402 L
s
.60275 .50104 m .62082 .51795 L .62304 .52157 L 0 .214 0 r
F
.60275 .50104 m .61213 .50916 L .62082 .51795 L F
0 g
.61213 .50916 m
.61749 .51181 L
s
.59669 .49443 m
.60275 .50104 L
s
.5973 .49752 m
.60275 .50104 L
s
.47934 .95513 m .46932 .95067 L .47097 .95574 L 0 .452 .324 r
F
.47934 .95513 m .47076 .94691 L .46932 .95067 L F
0 g
.46541 .94692 m
.46932 .95067 L
s
.51413 .96347 m .51251 .96374 L .51445 .9652 L 0 .192 .198 r
F
.51413 .96347 m .51121 .9622 L .51251 .96374 L F
0 g
.51089 .96298 m
.51251 .96374 L
s
.48955 .8926 m .48127 .88293 L .48597 .88967 L 0 .612 .304 r
F
.48954 .89983 m .48597 .88967 L .48127 .88293 L 0 .592 .304 r
F
0 g
.47937 .87853 m
.48127 .88293 L
s
.48026 .88232 m
.48127 .88293 L
s
.73135 .89196 m .74086 .89322 L .74531 .89133 L 0 .847 .259 r
F
.73135 .89196 m .73519 .89383 L .74086 .89322 L F
0 g
.74086 .89322 m
.74417 .89421 L
s
.35201 .60675 m .3623 .57807 L .35916 .57852 L 0 1 .342 r
F
0 g
.3623 .57807 m
.37046 .56991 L
s
.35201 .60675 m
.35201 .60675 L
s
.35924 .59016 m
.3623 .57807 L
s
.50716 .62628 m .50183 .62854 L .50215 .62777 L 0 0 0 r
F
0 g
.50096 .62707 m
.50265 .62636 L
s
.49766 .62847 m
.50096 .62707 L
s
.50716 .62628 m .50671 .62855 L .50183 .62854 L 0 0 0 r
F
.50716 .62628 m .51354 .62777 L .50671 .62855 L F
.50716 .62628 m .51854 .62628 L .51354 .62777 L F
.50716 .62628 m .51839 .62506 L .51854 .62628 L F
0 g
.51839 .62506 m
.52302 .62368 L
s
.51351 .62507 m
.51839 .62506 L
s
.63443 .77291 m
.63511 .76848 L
s
.63445 .77317 m
.63452 .77367 L
s
.63519 .77847 m
.6364 .787 L
s
.63692 .79066 m
.63699 .79113 L
s
.6364 .787 m
.63692 .79066 L
s
.63699 .79113 m
.63768 .79607 L
s
.63452 .77367 m
.63519 .77847 L
s
.30943 .75514 m .29906 .74815 L .29596 .75065 L 0 .918 .438 r
F
0 g
.29596 .75065 m
.29772 .75371 L
s
.30943 .75514 m .30534 .74798 L .29906 .74815 L 0 .918 .438 r
F
.30943 .75514 m .31059 .75027 L .30534 .74798 L F
.30943 .75514 m .31234 .75334 L .31059 .75027 L F
0 g
.30317 .7553 m
.30943 .75514 L
s
.62707 .74314 m
.63093 .75724 L
s
.63529 .78745 m
.63592 .79799 L
s
.63592 .79799 m
.63605 .80017 L
s
.63605 .80017 m
.63647 .80724 L
s
.63525 .78679 m
.63529 .78745 L
s
.63507 .78382 m
.63525 .78679 L
s
.63448 .77398 m
.63507 .78382 L
s
.29772 .65358 m .29351 .64081 L .28772 .64848 L 0 1 .499 r
F
.29772 .65358 m .30072 .63694 L .29351 .64081 L F
.29772 .65358 m .30454 .63946 L .30072 .63694 L F
.29772 .65358 m .30324 .64659 L .30454 .63946 L F
0 g
.29663 .66029 m
.29772 .65358 L
s
.29052 .65743 m
.29772 .65358 L
s
.32258 .66107 m
.3298 .66075 L
s
.50761 .93006 m .50248 .92288 L .50126 .91867 L 0 .215 .095 r
F
0 g
.50074 .91835 m
.50126 .91867 L
s
.75214 1.06776 m .7577 1.06359 L .76248 1.06105 L 0 0 0 r
F
0 g
.75113 1.06711 m
.7577 1.06359 L
s
.67825 1.09661 m .67325 1.09222 L .672 1.08794 L 0 .105 .03 r
F
0 g
.6653 1.08576 m
.672 1.08794 L
s
.43059 .88221 m .42221 .88143 L .42691 .88312 L 0 1 .476 r
F
.43059 .88221 m .41885 .87772 L .42221 .88143 L F
0 g
.41949 .88236 m
.42221 .88143 L
s
.62533 .77371 m
.62554 .7995 L
s
.69569 1.08664 m .70798 1.08389 L .70333 1.08648 L 0 0 0 r
F
.70817 1.09203 m .70798 1.08389 L .71524 1.08253 L F
.70817 1.09203 m .70333 1.08648 L .70798 1.08389 L F
0 g
.70707 1.08098 m
.70798 1.08389 L
s
.52156 .92598 m .52782 .90753 L .5244 .91825 L 0 .254 .119 r
F
.52239 .92732 m .5244 .91825 L .52782 .90753 L 0 .256 .123 r
F
0 g
.52782 .90753 m
.5284 .90608 L
s
.52782 .90753 m
.52827 .90572 L
s
.4898 .88556 m .48998 .8828 L .48667 .87408 L 0 .629 .304 r
F
0 g
.48667 .87408 m
.4894 .87759 L
s
.73132 .61039 m .7458 .61482 L .74978 .61422 L 0 1 .43 r
F
.73132 .61039 m .7379 .61319 L .7458 .61482 L F
0 g
.7458 .61482 m
.74695 .61769 L
s
.82662 .87675 m .83767 .88042 L .8382 .87513 L 0 1 .509 r
F
0 g
.83382 .88466 m
.83767 .88042 L
s
.55405 .47852 m .5478 .48045 L .54711 .47835 L 0 .096 0 r
F
.55405 .47852 m .55618 .48419 L .5478 .48045 L F
.55405 .47852 m .56666 .48707 L .55618 .48419 L F
.55405 .47852 m .57359 .48723 L .56666 .48707 L F
.55405 .47852 m .57238 .48458 L .57359 .48723 L F
0 g
.57302 .48476 m
.57874 .48631 L
s
.57238 .48458 m
.57302 .48476 L
s
.54607 .47479 m
.55405 .47852 L
s
.564 .48085 m
.57238 .48458 L
s
.48146 .92443 m .47098 .92031 L .47469 .92489 L 0 .539 .316 r
F
0 g
.47098 .92031 m
.47146 .92091 L
s
.46984 .92157 m
.47098 .92031 L
s
.44462 .925 m .43732 .9229 L .44181 .92371 L 0 0 0 r
F
.44462 .925 m .43329 .92278 L .43732 .9229 L F
0 g
.43486 .92177 m
.43732 .9229 L
s
.56524 .67614 m .57609 .66408 L .5781 .66074 L 0 1 .193 r
F
.56524 .67614 m .57059 .67067 L .57609 .66408 L F
0 g
.57609 .66408 m
.57836 .66153 L
s
.5734 .6673 m
.57609 .66408 L
s
.52374 .931 m .53372 .90424 L .5342 .90554 L 0 .258 .129 r
F
.52374 .931 m .53037 .91111 L .53372 .90424 L F
0 g
.53372 .90424 m
.53399 .90316 L
s
.70111 .66706 m
.70111 .66689 L
s
.44242 .89372 m .43397 .88587 L .43055 .88654 L 0 1 .475 r
F
0 g
.42691 .88312 m
.43055 .88654 L
s
.79405 1.03835 m .80058 1.03793 L .80478 1.03244 L 0 1 .29 r
F
0 g
.79432 1.04353 m
.80058 1.03793 L
s
.80058 1.04069 m
.80058 1.03793 L
s
.73135 .89196 m .73112 .89329 L .73519 .89383 L 0 .847 .259 r
F
0 g
.73112 .89329 m
.73519 .89383 L
s
.73006 .89525 m
.73519 .89383 L
s
.48326 .92985 m .47469 .92489 L .47236 .92509 L 0 .696 .442 r
F
0 g
.46886 .92324 m
.47236 .92509 L
s
.47504 .92931 m
.47643 .92903 L
s
.34059 .66929 m
.3412 .66965 L
s
.48544 .92221 m .48454 .92344 L .48096 .92326 L 0 .135 .062 r
F
.49463 .92788 m .48544 .92221 L .4888 .92302 L 0 .2 .082 r
F
.49463 .92788 m .48454 .92344 L .48544 .92221 L F
0 g
.48343 .92015 m
.48544 .92221 L
s
.48544 .92221 m
.4867 .92251 L
s
.68007 .90144 m
.68016 .90146 L
s
.76722 .61527 m .78357 .61842 L .77739 .61384 L 0 1 .471 r
F
0 g
.78357 .61842 m
.79135 .6216 L
s
.78357 .61842 m
.785 .62205 L
s
.79521 .79958 m .80635 .79263 L .80853 .79625 L 0 .01 0 r
F
0 g
.80635 .79263 m
.81026 .79158 L
s
.48539 .93331 m .47979 .93287 L .48337 .93371 L 0 .663 .438 r
F
.48781 .93675 m .48337 .93371 L .47979 .93287 L 0 .622 .431 r
F
0 g
.47622 .93098 m
.47979 .93287 L
s
.47918 .93308 m
.47979 .93287 L
s
.34981 .90914 m .34264 .90956 L .34694 .91003 L 0 .89 .376 r
F
0 g
.34694 .91003 m
.35104 .91156 L
s
.34981 .90914 m .33903 .90774 L .34264 .90956 L 0 .89 .376 r
F
0 g
.34036 .91061 m
.34264 .90956 L
s
.49136 .63016 m .49766 .62847 L .50215 .62777 L 0 0 0 r
F
0 g
.48724 .63089 m
.49136 .63016 L
s
.36674 .76857 m .35759 .76652 L .36159 .76743 L 0 .443 .203 r
F
0 g
.36159 .76743 m
.36291 .7681 L
s
.50795 .89296 m .50376 .85508 L .50596 .87665 L 0 .496 .276 r
F
.50687 .89314 m .50596 .87665 L .50376 .85508 L 0 .501 .278 r
F
0 g
.50244 .84618 m
.50376 .85508 L
s
.50338 .84848 m
.50376 .85508 L
s
.61551 .63222 m .63111 .62697 L .62827 .62713 L 0 .804 .211 r
F
0 g
.63111 .62697 m
.63767 .62574 L
s
.50206 .90547 m .49141 .86969 L .49105 .87222 L 0 .534 .29 r
F
.50206 .90547 m .49488 .87841 L .49141 .86969 L F
0 g
.48938 .86254 m
.49141 .86969 L
s
.49203 .866 m
.49327 .87138 L
s
.3766 .77044 m .36961 .76919 L .36674 .76857 L 0 0 0 r
F
.3766 .77044 m .37464 .77027 L .36961 .76919 L F
.3766 .77044 m .37846 .7711 L .37464 .77027 L F
.3766 .77044 m .37929 .77117 L .37846 .7711 L F
0 g
.37159 .76936 m
.3766 .77044 L
s
.47579 .63513 m .46896 .63722 L .47021 .63693 L 0 0 0 r
F
.47579 .63513 m .47301 .63599 L .46896 .63722 L F
0 g
.46665 .63855 m
.47021 .63693 L
s
.47579 .63513 m .47966 .63406 L .47301 .63599 L 0 0 0 r
F
0 g
.47021 .63693 m
.4742 .63564 L
s
.47579 .63513 m .48524 .63226 L .47966 .63406 L 0 0 0 r
F
.47579 .63513 m .48603 .63179 L .48524 .63226 L F
.47579 .63513 m .48198 .63302 L .48603 .63179 L F
.48979 .90722 m .47818 .89459 L .48179 .90112 L 0 .568 .304 r
F
0 g
.47818 .89459 m
.47845 .89508 L
s
.47845 .89508 m
.48077 .89928 L
s
.47709 .8947 m
.47818 .89459 L
s
.49844 1.04017 m .49639 1.04245 L .49975 1.04593 L 0 .185 .248 r
F
0 g
.49639 1.04245 m
.49873 1.04712 L
s
.22309 .92692 m .21599 .92794 L .22057 .9283 L 0 .703 .288 r
F
0 g
.22057 .9283 m
.22582 .93018 L
s
.22309 .92692 m .21159 .92578 L .21599 .92794 L 0 .703 .288 r
F
0 g
.21447 .92955 m
.21599 .92794 L
s
.51413 .96347 m .51445 .9652 L .51571 .96574 L 0 .192 .198 r
F
0 g
.51445 .9652 m
.51612 .96661 L
s
.46747 .91386 m .45995 .91227 L .46445 .91393 L 0 .869 .462 r
F
.46898 .91821 m .46445 .91393 L .45995 .91227 L 0 .856 .464 r
F
0 g
.45957 .91232 m
.45995 .91227 L
s
.45614 .90946 m
.45995 .91227 L
s
.50908 .89337 m .50566 .85384 L .50741 .87625 L 0 .492 .273 r
F
.50795 .89296 m .50741 .87625 L .50566 .85384 L 0 .496 .276 r
F
0 g
.5051 .84927 m
.50566 .85384 L
s
.50553 .85027 m
.50566 .85384 L
s
.48001 .91445 m .47278 .91374 L .47712 .91585 L 0 .576 .317 r
F
.48146 .92443 m .47712 .91585 L .47278 .91374 L 0 .539 .316 r
F
0 g
.47128 .91483 m
.47278 .91374 L
s
.46953 .9093 m
.47278 .91374 L
s
.50687 .89314 m .50197 .85716 L .50458 .87775 L 0 .501 .278 r
F
.50586 .89389 m .50458 .87775 L .50197 .85716 L 0 .508 .281 r
F
0 g
.50167 .85351 m
.50197 .85716 L
s
.50098 .85161 m
.50197 .85716 L
s
.61958 .5167 m
.62002 .51715 L
s
.61213 .50916 m
.61958 .5167 L
s
.28772 .64848 m .27624 .65126 L .28033 .65295 L 0 1 .503 r
F
0 g
.27984 .65957 m
.28033 .65295 L
s
.52181 .97081 m .52121 .97034 L .52132 .9703 L 0 0 0 r
F
0 g
.52132 .9703 m
.52132 .9703 L
s
.53602 .91458 m .53573 .91242 L .53882 .90066 L 0 .212 .132 r
F
0 g
.5377 .90492 m
.53882 .90066 L
s
.53674 .90579 m
.53882 .90066 L
s
.5352 .90639 m
.53617 .90251 L
s
.49136 .63016 m .48524 .63226 L .48603 .63179 L 0 0 0 r
F
0 g
.48546 .63161 m
.48724 .63089 L
s
.49136 .63016 m .48973 .63157 L .48524 .63226 L 0 0 0 r
F
0 g
.48198 .63302 m
.48546 .63161 L
s
.49136 .63016 m .49651 .63017 L .48973 .63157 L 0 0 0 r
F
.49136 .63016 m .50183 .62854 L .49651 .63017 L F
.49136 .63016 m .50215 .62777 L .50183 .62854 L F
0 g
.48603 .63179 m
.49136 .63016 L
s
.50215 .62777 m
.50716 .62628 L
s
.49766 .62847 m
.50215 .62777 L
s
.81505 .87842 m .82613 .88166 L .82662 .87675 L 0 1 .499 r
F
0 g
.82231 .88562 m
.82613 .88166 L
s
.82613 .88166 m
.82922 .88504 L
s
.50686 .95684 m .50673 .95869 L .50742 .9582 L 0 .312 .264 r
F
.51048 .96015 m .50742 .9582 L .50673 .95869 L 0 .258 .214 r
F
0 g
.50673 .95869 m
.50766 .96013 L
s
.50478 .95796 m
.50673 .95869 L
s
.48198 .63302 m
.48603 .63179 L
s
.47096 .92252 m .47012 .9208 L .46623 .91852 L 0 .839 .465 r
F
.30671 .90437 m .29795 .89846 L .29523 .90037 L 0 1 .474 r
F
.30671 .90437 m .30229 .89901 L .29795 .89846 L F
.30671 .90437 m .30605 .90155 L .30229 .89901 L F
.31748 .90537 m .30605 .90155 L .30671 .90437 L 0 1 .459 r
F
0 g
.30398 .90627 m
.30671 .90437 L
s
.30671 .90437 m
.31042 .90672 L
s
.41885 .87772 m .41104 .86885 L .40735 .87024 L 0 1 .482 r
F
.41885 .87772 m .41573 .87065 L .41104 .86885 L F
.41885 .87772 m .41907 .87445 L .41573 .87065 L F
.43059 .88221 m .41907 .87445 L .41885 .87772 L 0 1 .476 r
F
0 g
.41885 .87772 m
.42221 .88143 L
s
.41515 .8791 m
.41885 .87772 L
s
.2327 .65417 m .22202 .65141 L .22102 .65881 L 0 1 .521 r
F
0 g
.21451 .66466 m
.22102 .65881 L
s
.51393 .90166 m .51592 .86443 L .51567 .84591 L 0 .492 .267 r
F
0 g
.51567 .84591 m
.51587 .8604 L
s
.51567 .84591 m
.51594 .84171 L
s
.67825 1.09661 m .68173 1.08809 L .68698 1.09143 L 0 .105 .03 r
F
0 g
.67532 1.0866 m
.68173 1.08809 L
s
.68029 1.08466 m
.68173 1.08809 L
s
.27399 .74317 m .26367 .74362 L .26812 .74493 L 0 1 .519 r
F
0 g
.26812 .74493 m
.26969 .74878 L
s
.76052 .79344 m .77363 .78925 L .77209 .79642 L 0 .227 .057 r
F
0 g
.77125 .78235 m
.77363 .78925 L
s
.77363 .78925 m
.77828 .78511 L
s
.34885 .63886 m
.34886 .63881 L
s
.34884 .63895 m
.34885 .63886 L
s
.34883 .63901 m
.34884 .63895 L
s
.34792 .64624 m
.34883 .63901 L
s
.3183 .72193 m .30597 .72922 L .31128 .72943 L 0 1 .439 r
F
0 g
.31128 .72943 m
.31288 .73694 L
s
.3183 .72193 m .30519 .72169 L .30597 .72922 L 0 1 .439 r
F
.3183 .72193 m .30948 .71185 L .30519 .72169 L F
.3183 .72193 m .31651 .70433 L .30948 .71185 L F
.3183 .72193 m .32159 .70417 L .31651 .70433 L F
.3183 .72193 m .32235 .71171 L .32159 .70417 L F
0 g
.31128 .72943 m
.3183 .72193 L
s
.46747 .91386 m .45856 .9073 L .45554 .90736 L 0 .869 .462 r
F
0 g
.45164 .90459 m
.45554 .90736 L
s
.68715 .61343 m .7015 .61484 L .70517 .6139 L 0 1 .366 r
F
.68715 .61343 m .69379 .61464 L .7015 .61484 L F
0 g
.7015 .61484 m
.70309 .61664 L
s
.69379 .61464 m
.69601 .61626 L
s
.69379 .61464 m
.7015 .61484 L
s
.45794 .92492 m .44856 .92508 L .44596 .92363 L 0 .051 .01 r
F
.53478 1.09257 m .53328 1.09082 L .5327 1.08908 L 0 .245 0 r
F
.47934 .95513 m .47097 .95574 L .47464 .95926 L 0 .452 .324 r
F
0 g
.46978 .95984 m
.47097 .95574 L
s
.5303 .97795 m .53453 .97901 L .5349 .97993 L 0 .068 0 r
F
0 g
.53453 .97901 m
.53763 .98018 L
s
.72051 .89407 m .7277 .89465 L .73111 .89329 L 0 .771 .241 r
F
.72051 .89407 m .72338 .89515 L .7277 .89465 L F
0 g
.7277 .89465 m
.73006 .89525 L
s
.26667 .52881 m
.27556 .52084 L
s
.67201 .78979 m
.67223 .79429 L
s
.77279 1.05513 m .78387 1.04875 L .77969 1.05102 L 0 .878 .216 r
F
.76248 1.06105 m .77279 1.05513 L .77341 1.05465 L 0 .801 .187 r
F
.50586 .89389 m .50029 .85998 L .5033 .87948 L 0 .508 .281 r
F
.50493 .89516 m .5033 .87948 L .50029 .85998 L 0 .515 .283 r
F
0 g
.49953 .85633 m
.50029 .85998 L
s
.50007 .85787 m
.50029 .85998 L
s
.52891 .47648 m .53901 .47665 L .54711 .47835 L 0 0 0 r
F
0 g
.53901 .47665 m
.54607 .47479 L
s
.36231 .85112 m .35404 .85344 L .35836 .85427 L 0 1 .498 r
F
0 g
.35836 .85427 m
.36137 .85858 L
s
.37352 .85383 m .36497 .85564 L .36948 .85663 L 0 1 .494 r
F
0 g
.36948 .85663 m
.37264 .86084 L
s
.37352 .85383 m .36231 .85112 L .36497 .85564 L 0 1 .494 r
F
0 g
.36137 .85858 m
.36497 .85564 L
s
.47615 .94355 m .47076 .94691 L .47434 .94698 L 0 .505 .328 r
F
.47934 .95513 m .47434 .94698 L .47076 .94691 L 0 .452 .324 r
F
0 g
.46932 .95067 m
.47076 .94691 L
s
.46699 .94304 m
.47076 .94691 L
s
.50206 .90547 m .49105 .87222 L .49411 .88377 L 0 .534 .29 r
F
0 g
.4951 .8696 m
.49576 .87293 L
s
.49248 .86361 m
.4955 .87239 L
s
.48982 .8703 m
.49105 .87222 L
s
.68698 1.09143 m .69568 1.08664 L .69717 1.09009 L 0 .014 .006 r
F
.51026 .89443 m .50763 .85356 L .50892 .87661 L 0 .491 .271 r
F
.50908 .89337 m .50892 .87661 L .50763 .85356 L 0 .492 .273 r
F
0 g
.50667 .84366 m
.50763 .85356 L
s
.50743 .8394 m
.50763 .85356 L
s
.36231 .85112 m .35156 .84884 L .35404 .85344 L 0 1 .498 r
F
0 g
.35058 .85669 m
.35404 .85344 L
s
.46236 .78348 m
.46244 .78348 L
s
.45826 .78353 m
.46236 .78348 L
s
.51575 1.07082 m .51169 1.06611 L .51607 1.07168 L 0 0 .152 r
F
.51575 1.07082 m .50856 1.06155 L .51169 1.06611 L F
0 g
.50825 1.06218 m
.51169 1.06611 L
s
.35156 .84884 m .34325 .85154 L .34757 .85227 L 0 1 .502 r
F
0 g
.34757 .85227 m
.35058 .85669 L
s
.38473 .85691 m .37623 .85823 L .38073 .85936 L 0 1 .49 r
F
0 g
.38073 .85936 m
.3839 .86346 L
s
.38473 .85691 m .37352 .85383 L .37623 .85823 L 0 1 .49 r
F
0 g
.37264 .86084 m
.37623 .85823 L
s
.48001 .91445 m .47953 .91046 L .47579 .90537 L 0 .576 .317 r
F
0 g
.47579 .90537 m
.47599 .90564 L
s
.47579 .90537 m
.47613 .90527 L
s
.47615 .94355 m .47498 .93891 L .4712 .93504 L 0 .505 .328 r
F
.35156 .84884 m .34081 .84683 L .34325 .85154 L 0 1 .502 r
F
0 g
.33978 .85505 m
.34325 .85154 L
s
.72051 .89407 m .7203 .8949 L .72338 .89515 L 0 .771 .241 r
F
0 g
.71931 .89609 m
.72338 .89515 L
s
.80347 .88014 m .81459 .88294 L .81505 .87842 L 0 1 .487 r
F
0 g
.8108 .8866 m
.81459 .88294 L
s
.81459 .88294 m
.81771 .88601 L
s
.48328 .92528 m .47882 .92634 L .47469 .92489 L 0 .157 .063 r
F
.48146 .92443 m .47469 .92489 L .47882 .92634 L 0 .539 .316 r
F
.48328 .92528 m .48251 .9265 L .47882 .92634 L 0 .157 .063 r
F
.48145 .92639 m .47096 .92252 L .47469 .92489 L 0 .722 .444 r
F
0 g
.47238 .92288 m
.4727 .92316 L
s
.48145 .92639 m .47012 .9208 L .47096 .92252 L 0 .722 .444 r
F
0 g
.47146 .92091 m
.47221 .92183 L
s
.46893 .92296 m
.47096 .92252 L
s
.39655 .91784 m .38693 .91579 L .38409 .91562 L 0 .508 .211 r
F
.39655 .91784 m .39162 .91665 L .38693 .91579 L F
.39655 .91784 m .39574 .91753 L .39162 .91665 L F
.40813 .9197 m .39574 .91753 L .39655 .91784 L 0 0 0 r
F
0 g
.3937 .91767 m
.39655 .91784 L
s
.39655 .91784 m
.4006 .91855 L
s
.43329 .92278 m .42365 .92231 L .42096 .92135 L 0 0 0 r
F
.50872 .92877 m .5062 .91865 L .50783 .9242 L 0 .21 .095 r
F
.50987 .92758 m .50783 .9242 L .5062 .91865 L 0 .207 .095 r
F
0 g
.50432 .91522 m
.5062 .91865 L
s
.50611 .91774 m
.5062 .91865 L
s
.62255 .76835 m .6271 .7609 L .62332 .76325 L 0 1 .479 r
F
0 g
.62209 .7682 m
.6221 .76821 L
s
.62255 .76835 m .63219 .7629 L .6271 .7609 L 0 1 .479 r
F
0 g
.62331 .7632 m
.62332 .76325 L
s
.6233 .76317 m
.62331 .7632 L
s
.61762 .73607 m
.6233 .76317 L
s
.6221 .76821 m
.62256 .76874 L
s
.62707 .74314 m
.6271 .7609 L
s
.62256 .76832 m
.62332 .76325 L
s
.62255 .76835 m
.62256 .76832 L
s
.63093 .75724 m
.63292 .76453 L
s
.37747 .6735 m .37045 .67444 L .37378 .67411 L 0 .772 .215 r
F
.37747 .6735 m .36919 .67459 L .37045 .67444 L F
.37747 .6735 m .37085 .67446 L .36919 .67459 L F
.37747 .6735 m .37455 .67385 L .37085 .67446 L F
0 g
.37377 .67412 m
.37378 .67411 L
s
.37279 .67503 m
.37377 .67412 L
s
.37747 .6735 m .3778 .67316 L .37455 .67385 L 0 .772 .215 r
F
.37747 .6735 m .37905 .67301 L .3778 .67316 L F
0 g
.37747 .6735 m
.37878 .67372 L
s
.37378 .67411 m
.37747 .6735 L
s
.43329 .92278 m .42827 .92323 L .42365 .92231 L 0 0 0 r
F
.43329 .92278 m .4324 .92343 L .42827 .92323 L F
.44462 .925 m .4324 .92343 L .43329 .92278 L F
0 g
.43329 .92278 m
.43732 .9229 L
s
.43058 .92181 m
.43329 .92278 L
s
.44181 .92371 m
.44596 .92363 L
s
.34081 .84683 m .33246 .84987 L .33678 .85051 L 0 1 .505 r
F
0 g
.33678 .85051 m
.33978 .85505 L
s
.27399 .74317 m .26299 .73951 L .26367 .74362 L 0 1 .519 r
F
0 g
.25851 .74586 m
.26367 .74362 L
s
.50656 .93146 m .50002 .92017 L .50248 .92288 L 0 .223 .096 r
F
.50656 .93146 m .49921 .92118 L .50002 .92017 L F
0 g
.49875 .91712 m
.50002 .92017 L
s
.50211 .91767 m
.50406 .9204 L
s
.37905 .67301 m
.38266 .67236 L
s
.66639 .6821 m .67565 .69991 L .66842 .66372 L 0 .282 .248 r
F
0 g
.6756 .69963 m
.67573 .69914 L
s
.66801 .66033 m
.66842 .66372 L
s
.66407 .66849 m
.66639 .6821 L
s
.66552 .66759 m
.66639 .6821 L
s
.63957 .54132 m
.64018 .54248 L
s
.64018 .54248 m
.64105 .54414 L
s
.64105 .54414 m
.64165 .54527 L
s
.63656 .53798 m
.63957 .54132 L
s
.63485 .53609 m
.63656 .53798 L
s
.48324 .93443 m .47235 .9273 L .47335 .93194 L 0 .499 .314 r
F
.48326 .92985 m .47705 .92891 L .48092 .93004 L 0 .696 .442 r
F
.48539 .93331 m .48092 .93004 L .47705 .92891 L 0 .663 .438 r
F
.48324 .93443 m .47469 .92489 L .47235 .9273 L 0 .499 .314 r
F
0 g
.47004 .92475 m
.47235 .9273 L
s
.64003 .77442 m
.6401 .77379 L
s
.52255 .97125 m
.52293 .97148 L
s
.52561 .9739 m .52369 .97233 L .52293 .97148 L 0 0 0 r
F
0 g
.52293 .97148 m
.52333 .97193 L
s
.52293 .97148 m
.52293 .97148 L
s
.39639 .86057 m .38762 .86124 L .39231 .86259 L 0 1 .486 r
F
0 g
.39231 .86259 m
.39563 .8666 L
s
.39639 .86057 m .38473 .85691 L .38762 .86124 L 0 1 .486 r
F
0 g
.3839 .86346 m
.38762 .86124 L
s
.34081 .84683 m .33005 .84506 L .33246 .84987 L 0 1 .505 r
F
0 g
.32897 .85362 m
.33246 .84987 L
s
.50493 .89516 m .49876 .86345 L .50212 .88179 L 0 .515 .283 r
F
0 g
.49812 .85859 m
.49876 .86345 L
s
.50447 .89596 m .50212 .88179 L .49876 .86345 L 0 .524 .286 r
F
0 g
.49876 .86345 m
.49876 .86345 L
s
.62928 .73217 m
.63278 .74492 L
s
.62693 .72357 m
.62928 .73217 L
s
.62634 .7188 m
.62675 .72217 L
s
.62675 .72217 m
.62693 .72357 L
s
.44242 .89372 m .43867 .88786 L .43397 .88587 L 0 1 .475 r
F
.44242 .89372 m .4423 .89122 L .43867 .88786 L F
.45415 .89892 m .44242 .89372 L .44603 .89707 L 0 .971 .466 r
F
.45415 .89892 m .4423 .89122 L .44242 .89372 L F
0 g
.44283 .89745 m
.44583 .89709 L
s
.439 .89438 m
.44242 .89372 L
s
.36674 .76857 m .35687 .76619 L .35759 .76652 L 0 .443 .203 r
F
0 g
.3528 .76601 m
.35759 .76652 L
s
.48955 .8926 m .48962 .88976 L .48618 .88178 L 0 .612 .304 r
F
0 g
.48618 .88178 m
.48731 .88441 L
s
.4868 .88243 m
.48909 .88482 L
s
.48618 .88178 m
.4868 .88243 L
s
.52701 1.08603 m .5285 1.08542 L .53159 1.08977 L 0 .162 0 r
F
0 g
.5285 1.08542 m
.5327 1.08908 L
s
.52374 .931 m .5342 .90554 L .53138 .91402 L 0 .258 .129 r
F
0 g
.53154 .90722 m
.53245 .90425 L
s
.5342 .90554 m
.5351 .90319 L
s
.48954 .89983 m .48136 .89198 L .48604 .89771 L 0 .592 .304 r
F
.48979 .90722 m .48604 .89771 L .48136 .89198 L 0 .568 .304 r
F
0 g
.48098 .89121 m
.48136 .89198 L
s
.48053 .89165 m
.48136 .89198 L
s
.45415 .89892 m .44603 .89707 L .45071 .89903 L 0 .971 .466 r
F
.45484 .90421 m .45071 .89903 L .44603 .89707 L 0 .967 .471 r
F
0 g
.44583 .89709 m
.44603 .89707 L
s
.44242 .89372 m
.44603 .89707 L
s
.70433 .66867 m
.70671 .66397 L
s
.70671 .66397 m
.7076 .66222 L
s
.39742 .66733 m
.40351 .66517 L
s
.49028 .91474 m .47858 .90053 L .47892 .9045 L 0 .542 .303 r
F
.49028 .91474 m .48179 .90112 L .47858 .90053 L F
0 g
.47818 .89993 m
.47858 .90053 L
s
.47613 .90527 m
.47723 .90497 L
s
.47599 .90564 m
.47666 .90655 L
s
.48011 .90081 m
.4804 .90086 L
s
.47858 .90053 m
.48011 .90081 L
s
.50447 .89596 m .49831 .86464 L .50178 .8826 L 0 .524 .286 r
F
0 g
.49735 .85914 m
.49831 .86464 L
s
.50385 .89752 m .50178 .8826 L .49831 .86464 L 0 .524 .286 r
F
0 g
.49831 .86463 m
.49831 .86464 L
s
.31748 .90537 m .3088 .89988 L .30605 .90155 L 0 1 .459 r
F
.31748 .90537 m .31315 .90047 L .3088 .89988 L F
.31748 .90537 m .31687 .90283 L .31315 .90047 L F
.32825 .90649 m .31687 .90283 L .31748 .90537 L 0 1 .439 r
F
0 g
.31471 .90703 m
.31748 .90537 L
s
.31748 .90537 m
.32116 .90754 L
s
.66691 .6187 m
.66694 .61895 L
s
.66659 .61562 m
.66661 .61585 L
s
.52891 .47648 m .52162 .47913 L .52145 .47754 L 0 0 0 r
F
.52891 .47648 m .52973 .48083 L .52162 .47913 L F
.52891 .47648 m .54036 .48152 L .52973 .48083 L F
.52891 .47648 m .5478 .48045 L .54036 .48152 L F
0 g
.54821 .47838 m
.55405 .47852 L
s
.52891 .47648 m .54711 .47835 L .5478 .48045 L 0 0 0 r
F
0 g
.54711 .47835 m
.54821 .47838 L
s
.5212 .47483 m
.52891 .47648 L
s
.53901 .47665 m
.54711 .47835 L
s
.33005 .84506 m .32165 .84839 L .32597 .84896 L 0 1 .509 r
F
0 g
.32597 .84896 m
.32897 .85362 L
s
.70967 .8964 m .7169 .89593 L .7203 .8949 L 0 .693 .212 r
F
.70967 .8964 m .71257 .89647 L .7169 .89593 L F
0 g
.7169 .89593 m
.71931 .89609 L
s
.48543 .99368 m .47742 .99121 L .47996 .99653 L 0 .31 .317 r
F
.48543 .99368 m .47738 .9865 L .47742 .99121 L F
0 g
.47367 .98786 m
.47742 .99121 L
s
.55693 .75354 m .55788 .73104 L .55588 .74554 L 0 1 .265 r
F
.54806 .76127 m .55788 .73104 L .55637 .72413 L 0 1 .298 r
F
.54806 .76127 m .55588 .74554 L .55788 .73104 L F
0 g
.55788 .73104 m
.56019 .72209 L
s
.50601 1.05644 m .50856 1.06155 L .50877 1.06105 L 0 .109 .185 r
F
.51575 1.07082 m .50877 1.06105 L .50856 1.06155 L 0 0 .152 r
F
0 g
.50856 1.06155 m
.51169 1.06611 L
s
.50514 1.05784 m
.50856 1.06155 L
s
.50169 .90878 m .49058 .8761 L .49031 .87875 L 0 .532 .291 r
F
.50169 .90878 m .49411 .88377 L .49058 .8761 L F
0 g
.4896 .87315 m
.49058 .8761 L
s
.49327 .87138 m
.49453 .87687 L
s
.79189 .88189 m .80305 .88424 L .80347 .88014 L 0 1 .47 r
F
0 g
.79929 .88762 m
.80305 .88424 L
s
.80305 .88424 m
.8062 .887 L
s
.51778 .96684 m .51736 .96739 L .5193 .96887 L 0 .117 .177 r
F
.51778 .96684 m .51571 .96574 L .51736 .96739 L F
0 g
.51612 .96661 m
.51736 .96739 L
s
.41972 .92188 m .41212 .92026 L .41673 .92104 L 0 0 0 r
F
.41972 .92188 m .40813 .9197 L .41212 .92026 L F
0 g
.40953 .91963 m
.41212 .92026 L
s
.41673 .92104 m
.42096 .92135 L
s
.51147 .89614 m .50967 .85435 L .51048 .87781 L 0 .49 .269 r
F
.51026 .89443 m .51048 .87781 L .50967 .85435 L 0 .491 .271 r
F
0 g
.50967 .85435 m
.50979 .8374 L
s
.5096 .85336 m
.50967 .85435 L
s
.23459 .92812 m .22744 .92884 L .23202 .92921 L 0 .663 .259 r
F
0 g
.23202 .92921 m
.23719 .93085 L
s
.23459 .92812 m .22309 .92692 L .22744 .92884 L 0 .663 .259 r
F
0 g
.22582 .93018 m
.22744 .92884 L
s
.28772 .64848 m .27769 .64393 L .27624 .65126 L 0 1 .503 r
F
0 g
.26948 .6557 m
.27624 .65126 L
s
.3606 .91071 m .35339 .91078 L .3577 .91132 L 0 .76 .33 r
F
0 g
.3577 .91132 m
.36173 .91268 L
s
.3606 .91071 m .34981 .90914 L .35339 .91078 L 0 .76 .33 r
F
0 g
.35104 .91156 m
.35339 .91078 L
s
.33005 .84506 m .31928 .84348 L .32165 .84839 L 0 1 .509 r
F
0 g
.31816 .85236 m
.32165 .84839 L
s
.48145 .92639 m .47273 .92084 L .47012 .9208 L 0 .722 .444 r
F
0 g
.47236 .92509 m
.4741 .92494 L
s
.46623 .91852 m
.47012 .9208 L
s
.47384 .92435 m
.47422 .92459 L
s
.47276 .92367 m
.47384 .92435 L
s
.47096 .92252 m
.47276 .92367 L
s
.61123 .67342 m
.61305 .67778 L
s
.61305 .67778 m
.61326 .67827 L
s
.6112 .67341 m
.61123 .67342 L
s
.49463 .92788 m .48677 .92596 L .48454 .92344 L 0 .2 .082 r
F
0 g
.48096 .92326 m
.48454 .92344 L
s
.49463 .92788 m .4888 .92302 L .49238 .92534 L 0 .2 .082 r
F
.49625 .92527 m .49238 .92534 L .4888 .92302 L 0 .183 .081 r
F
0 g
.48687 .92035 m
.4888 .92302 L
s
.4867 .92251 m
.4888 .92302 L
s
.55165 .80301 m .56033 .74969 L .55693 .75354 L 0 1 .272 r
F
.55165 .80301 m .56111 .76464 L .56033 .74969 L F
0 g
.56033 .74969 m
.56183 .74384 L
s
.29595 .75065 m .28823 .74381 L .28498 .7469 L 0 1 .482 r
F
.29595 .75065 m .29389 .74292 L .28823 .74381 L F
.29595 .75065 m .29818 .74483 L .29389 .74292 L F
.29595 .75065 m .29905 .74815 L .29818 .74483 L F
0 g
.29031 .75153 m
.29595 .75065 L
s
.48654 1.00988 m .48387 1.00453 L .48032 1.00128 L 0 .289 .316 r
F
.49341 1.02334 m .48694 1.02081 L .49018 1.0263 L 0 .236 .286 r
F
.49341 1.02334 m .48572 1.01585 L .48694 1.02081 L F
0 g
.48331 1.0174 m
.48694 1.02081 L
s
.56524 .67614 m .5781 .66074 L .57528 .66171 L 0 1 .193 r
F
0 g
.5781 .66074 m
.58154 .65678 L
s
.40805 .86475 m .39934 .86478 L .40402 .86634 L 0 1 .481 r
F
0 g
.40402 .86634 m
.40735 .87024 L
s
.40805 .86475 m .39639 .86057 L .39934 .86478 L 0 1 .481 r
F
0 g
.39563 .8666 m
.39934 .86478 L
s
.51048 .96015 m .51121 .9622 L .51141 .96159 L 0 .258 .214 r
F
.51413 .96347 m .51141 .96159 L .51121 .9622 L 0 .192 .198 r
F
0 g
.51121 .9622 m
.51251 .96374 L
s
.5096 .96157 m
.51121 .9622 L
s
.56669 1.11242 m
.56733 1.11271 L
s
.44234 .88747 m .43397 .88587 L .43867 .88786 L 0 1 .469 r
F
.44234 .88747 m .43059 .88221 L .43397 .88587 L F
0 g
.43055 .88654 m
.43397 .88587 L
s
.70967 .8964 m .70948 .89667 L .71257 .89647 L 0 .693 .212 r
F
0 g
.70948 .89667 m
.71257 .89647 L
s
.71011 .89679 m
.71257 .89647 L
s
.73132 .61039 m .74978 .61422 L .74764 .61136 L 0 1 .43 r
F
0 g
.74978 .61422 m
.75707 .61655 L
s
.54806 .76127 m .55637 .72413 L .55234 .7294 L 0 1 .298 r
F
0 g
.55637 .72413 m
.55788 .73104 L
s
.55637 .72413 m
.55755 .72112 L
s
.31928 .84348 m .31084 .84708 L .31516 .84758 L 0 1 .513 r
F
0 g
.31516 .84758 m
.31816 .85236 L
s
.52239 .92732 m .52918 .90897 L .52544 .91969 L 0 .256 .123 r
F
.52312 .92899 m .52544 .91969 L .52918 .90897 L 0 .258 .126 r
F
0 g
.52918 .90897 m
.52978 .90678 L
s
.52918 .90897 m
.53096 .90493 L
s
.80675 .80017 m .81336 .79385 L .81803 .79454 L 0 0 0 r
F
.80675 .80017 m .80853 .79625 L .81336 .79385 L F
0 g
.81026 .79158 m
.81336 .79385 L
s
.47553 .78695 m .46893 .78959 L .47164 .787 L 0 .271 .065 r
F
.47553 .78695 m .46909 .79377 L .46893 .78959 L F
.47553 .78695 m .47202 .79674 L .46909 .79377 L F
0 g
.47164 .787 m
.47191 .78341 L
s
.47553 .78695 m .47594 .79668 L .47202 .79674 L 0 .271 .065 r
F
.47553 .78695 m .47822 .79363 L .47594 .79668 L F
.47553 .78695 m .47804 .78946 L .47822 .79363 L F
0 g
.47553 .78695 m
.47566 .78274 L
s
.47164 .787 m
.47553 .78695 L
s
.49655 .94691 m .49528 .94557 L .49245 .94447 L 0 .446 .382 r
F
.42964 .77931 m .42086 .77816 L .42473 .77804 L 0 0 0 r
F
0 g
.42473 .77804 m
.4259 .77684 L
s
.66496 .72658 m
.66496 .72658 L
s
.66528 .72504 m
.66538 .7246 L
s
.66538 .7246 m
.66567 .72319 L
s
.45484 .90421 m .45449 .90209 L .45071 .89903 L 0 .967 .471 r
F
.46644 .90952 m .45484 .90421 L .45856 .9073 L 0 .878 .459 r
F
.46644 .90952 m .45449 .90209 L .45484 .90421 L F
0 g
.45554 .90736 m
.45828 .9073 L
s
.45164 .90459 m
.45484 .90421 L
s
.78331 1.04502 m .78387 1.04875 L .79001 1.04333 L 0 1 .233 r
F
.78331 1.04502 m .77969 1.05102 L .78387 1.04875 L F
0 g
.7831 1.0499 m
.78387 1.04875 L
s
.49986 .95024 m .49852 .94891 L .49596 .94795 L 0 .39 .352 r
F
0 g
.48163 .78797 m
.48168 .78899 L
s
.47804 .78946 m
.48163 .78797 L
s
.54735 1.10154 m
.55228 1.10456 L
s
.32829 .70413 m
.32909 .6955 L
s
.32236 .71171 m
.32829 .70413 L
s
.40332 .77535 m .39426 .77362 L .39824 .77403 L 0 0 0 r
F
0 g
.39824 .77403 m
.39948 .77362 L
s
.26299 .73951 m .25255 .74041 L .257 .74169 L 0 1 .527 r
F
0 g
.257 .74169 m
.25851 .74586 L
s
.31928 .84348 m .30849 .84207 L .31084 .84708 L 0 1 .513 r
F
0 g
.30735 .85124 m
.31084 .84708 L
s
.50169 .90878 m .49031 .87875 L .49354 .88943 L 0 .532 .291 r
F
0 g
.49058 .8761 m
.49321 .8818 L
s
.4894 .87759 m
.49031 .87875 L
s
.47095 .92473 m .46617 .92604 L .46184 .92493 L 0 .109 .04 r
F
.47095 .92473 m .47008 .92596 L .46617 .92604 L F
.48326 .92985 m .47882 .92634 L .47469 .92489 L 0 .696 .442 r
F
.48324 .93443 m .47882 .92634 L .47469 .92489 L 0 .499 .314 r
F
.48539 .93331 m .4845 .93193 L .48092 .93004 L 0 .663 .438 r
F
.48324 .93443 m .48249 .93042 L .47882 .92634 L 0 .499 .314 r
F
.48144 .92835 m .47095 .92473 L .47469 .92489 L 0 .179 .065 r
F
0 g
.47235 .9273 m
.47387 .92574 L
s
.48326 .92985 m .4825 .92846 L .47882 .92634 L 0 .696 .442 r
F
.48144 .92835 m .47008 .92596 L .47095 .92473 L 0 .179 .065 r
F
0 g
.47422 .92459 m
.47446 .92474 L
s
.46871 .92319 m
.47095 .92473 L
s
.47095 .92473 m
.47194 .92477 L
s
.47194 .92477 m
.4743 .92488 L
s
.4743 .92488 m
.4746 .92489 L
s
.43059 .88221 m .42275 .87353 L .41907 .87445 L 0 1 .476 r
F
.46892 .9278 m .46184 .92493 L .46617 .92604 L 0 .135 .041 r
F
.46892 .9278 m .45794 .92492 L .46184 .92493 L F
0 g
.4594 .92325 m
.46184 .92493 L
s
.49342 .94355 m .49222 .9422 L .48916 .94093 L 0 .513 .404 r
F
.48324 .93443 m .47335 .93194 L .47701 .93603 L 0 .499 .314 r
F
0 g
.47335 .93194 m
.47382 .93247 L
s
.4712 .93504 m
.47335 .93194 L
s
.50656 .93146 m .50078 .92509 L .49921 .92118 L 0 .223 .096 r
F
0 g
.49876 .92096 m
.49921 .92118 L
s
.50002 .92017 m
.50178 .92211 L
s
.29947 .73636 m
.30597 .72922 L
s
.35201 .60675 m .34057 .61587 L .344 .61778 L 0 1 .342 r
F
0 g
.34485 .62856 m
.34714 .62217 L
s
.35201 .60675 m .34364 .60376 L .34057 .61587 L 0 1 .342 r
F
0 g
.34714 .62217 m
.34815 .61934 L
s
.34815 .61934 m
.34991 .61443 L
s
.344 .61778 m
.34566 .6155 L
s
.35201 .60675 m .35116 .58953 L .34364 .60376 L 0 1 .342 r
F
.35201 .60675 m .35916 .57852 L .35116 .58953 L F
0 g
.34566 .6155 m
.35201 .60675 L
s
.78032 .88369 m .79151 .88558 L .79189 .88189 L 0 1 .448 r
F
0 g
.78777 .88865 m
.79151 .88558 L
s
.79151 .88558 m
.79468 .88803 L
s
.50385 .89752 m .497 .86879 L .50078 .88553 L 0 .524 .286 r
F
.50315 .89981 m .50078 .88553 L .497 .86879 L 0 .53 .288 r
F
0 g
.49604 .86308 m
.497 .86879 L
s
.49377 .85794 m
.497 .86879 L
s
.56102 .68843 m .57059 .67067 L .56524 .67614 L 0 1 .19 r
F
0 g
.57059 .67067 m
.57309 .66993 L
s
.57059 .67067 m
.5734 .6673 L
s
.43059 .88221 m .42743 .87559 L .42275 .87353 L 0 1 .476 r
F
.43059 .88221 m .43079 .87931 L .42743 .87559 L F
.44234 .88747 m .43079 .87931 L .43059 .88221 L 0 1 .469 r
F
0 g
.43059 .88221 m
.43397 .88587 L
s
.42691 .88312 m
.43059 .88221 L
s
.49028 .91474 m .47892 .9045 L .48255 .91033 L 0 .542 .303 r
F
0 g
.47892 .9045 m
.47919 .90493 L
s
.47666 .90655 m
.47833 .90883 L
s
.47833 .90883 m
.47912 .90991 L
s
.47723 .90497 m
.47892 .9045 L
s
.48024 .98102 m .47826 .97597 L .47461 .9727 L 0 .37 .329 r
F
0 g
.44684 .78194 m
.4479 .7818 L
s
.48289 .96671 m .47358 .96333 L .4754 .96839 L 0 .394 .319 r
F
.48289 .96671 m .47464 .95926 L .47358 .96333 L F
0 g
.46978 .95984 m
.47358 .96333 L
s
.49869 .79237 m .49455 .80177 L .49589 .79541 L 0 .406 .102 r
F
.49869 .79237 m .4957 .8093 L .49455 .80177 L F
.49869 .79237 m .49858 .81295 L .4957 .8093 L F
0 g
.49516 .78903 m
.49589 .79541 L
s
.49869 .79237 m .50139 .80987 L .49858 .81295 L 0 .406 .102 r
F
.49869 .79237 m .50224 .80214 L .50139 .80987 L F
.49869 .79237 m .50108 .79466 L .50224 .80214 L F
0 g
.4979 .78456 m
.49869 .79237 L
s
.49589 .79541 m
.49869 .79237 L
s
.50108 .79466 m
.50352 .78923 L
s
.81551 1.02718 m .8264 1.01919 L .82206 1.02119 L 0 1 .386 r
F
.80478 1.03244 m .81551 1.02718 L .81555 1.02438 L 0 1 .344 r
F
.46898 .91821 m .46832 .91647 L .46445 .91393 L 0 .856 .464 r
F
0 g
.3778 .67316 m
.37905 .67301 L
s
.30849 .84207 m .30001 .84588 L .30434 .84635 L 0 1 .516 r
F
0 g
.30434 .84635 m
.30735 .85124 L
s
.49806 .9227 m .49732 .92372 L .49432 .92259 L 0 .167 .08 r
F
0 g
.49432 .92259 m
.4957 .92311 L
s
.4957 .92311 m
.49691 .92357 L
s
.49432 .92259 m
.49562 .9244 L
s
.50331 .95355 m .50191 .95223 L .49965 .9514 L 0 .356 .312 r
F
.42636 .6552 m .41759 .65786 L .42012 .65757 L 0 1 .26 r
F
.42636 .6552 m .42034 .6558 L .41759 .65786 L F
0 g
.41797 .6595 m
.42012 .65757 L
s
.42636 .6552 m .42655 .65276 L .42034 .6558 L 0 1 .26 r
F
.42636 .6552 m .4328 .65038 L .42655 .65276 L F
.42636 .6552 m .43493 .65024 L .4328 .65038 L F
.42636 .6552 m .43216 .65231 L .43493 .65024 L F
0 g
.42389 .65715 m
.42636 .6552 L
s
.42012 .65757 m
.42636 .6552 L
s
.45794 .92492 m .45306 .9261 L .44856 .92508 L 0 .051 .01 r
F
.45794 .92492 m .45708 .92603 L .45306 .9261 L F
.46892 .9278 m .45708 .92603 L .45794 .92492 L 0 .135 .041 r
F
0 g
.45534 .92348 m
.45794 .92492 L
s
.45794 .92492 m
.46184 .92493 L
s
.62588 .52417 m .62304 .52157 L .62082 .51795 L 0 .154 0 r
F
0 g
.62457 .52256 m
.62588 .52417 L
s
.62082 .51796 m
.62457 .52256 L
s
.62082 .51795 m
.62082 .51796 L
s
.62002 .51715 m
.62082 .51795 L
s
.61899 .51402 m
.62588 .52417 L
s
.54435 1.10426 m .54735 1.10154 L .55032 1.10653 L 0 .282 0 r
F
0 g
.71045 .66767 m
.7115 .65978 L
s
.51778 .96684 m .5193 .96887 L .52019 .96935 L 0 .117 .177 r
F
0 g
.5193 .96887 m
.52132 .9703 L
s
.48144 .92835 m .47469 .92489 L .47882 .92634 L 0 .179 .065 r
F
.48145 .92639 m .47469 .92489 L .47882 .92634 L 0 .722 .444 r
F
0 g
.47446 .92474 m
.47469 .92489 L
s
.4746 .92489 m
.47469 .92489 L
s
.32825 .90649 m .31966 .90141 L .31687 .90283 L 0 1 .439 r
F
.32825 .90649 m .32401 .90205 L .31966 .90141 L F
.32825 .90649 m .32769 .90423 L .32401 .90205 L F
.33903 .90774 m .32769 .90423 L .32825 .90649 L 0 .998 .412 r
F
0 g
.32545 .90791 m
.32825 .90649 L
s
.32825 .90649 m
.3319 .90849 L
s
.50357 .47922 m .51372 .47759 L .52145 .47754 L 0 0 0 r
F
0 g
.51372 .47759 m
.5212 .47483 L
s
.49844 1.04017 m .49511 1.0346 L .49175 1.03114 L 0 .185 .248 r
F
.45415 .89892 m .44574 .89111 L .4423 .89122 L 0 .971 .466 r
F
0 g
.43867 .88786 m
.4423 .89122 L
s
.43216 .65231 m
.43811 .64997 L
s
.4905 .94017 m .48939 .9388 L .48612 .93734 L 0 .572 .42 r
F
.46644 .90952 m .45856 .9073 L .46318 .90931 L 0 .878 .459 r
F
.46747 .91386 m .46318 .90931 L .45856 .9073 L 0 .869 .462 r
F
0 g
.45828 .9073 m
.45856 .9073 L
s
.45484 .90421 m
.45856 .9073 L
s
.28772 .64848 m .28372 .63583 L .27769 .64393 L 0 1 .503 r
F
.28772 .64848 m .29114 .63134 L .28372 .63583 L F
.28772 .64848 m .29498 .63346 L .29114 .63134 L F
.28772 .64848 m .29351 .64081 L .29498 .63346 L F
0 g
.28645 .6556 m
.28772 .64848 L
s
.28033 .65295 m
.28772 .64848 L
s
.65098 .74475 m
.65114 .74963 L
s
.65149 .76033 m
.65171 .76718 L
s
.65085 .74071 m
.65098 .74475 L
s
.64678 .79566 m
.64683 .79489 L
s
.64848 .77273 m
.64905 .76504 L
s
.6493 .76169 m
.64978 .75518 L
s
.65024 .74892 m
.65062 .7439 L
s
.64683 .79489 m
.64724 .78934 L
s
.65062 .7439 m
.65085 .74071 L
s
.70817 1.09203 m .71524 1.08253 L .7203 1.08333 L 0 0 0 r
F
0 g
.70798 1.08389 m
.71524 1.08253 L
s
.30849 .84207 m .2977 .84079 L .30001 .84588 L 0 1 .516 r
F
0 g
.29653 .85024 m
.30001 .84588 L
s
.47997 .92293 m .46898 .91821 L .47273 .92084 L 0 .743 .445 r
F
.47997 .92293 m .46832 .91647 L .46898 .91821 L F
0 g
.46623 .91852 m
.46898 .91821 L
s
.48024 .98102 m .47738 .9865 L .47986 .98554 L 0 .37 .329 r
F
.48543 .99368 m .47986 .98554 L .47738 .9865 L 0 .31 .317 r
F
0 g
.47738 .9865 m
.47742 .99121 L
s
.47374 .98323 m
.47738 .9865 L
s
.3298 .66075 m
.33066 .6557 L
s
.73015 1.0771 m .74114 1.07273 L .73714 1.07518 L 0 0 0 r
F
.7203 1.08333 m .73015 1.0771 L .73113 1.07909 L F
.2327 .65417 m .2277 .64254 L .22202 .65141 L 0 1 .521 r
F
0 g
.22102 .65881 m
.22202 .65141 L
s
.2327 .65417 m .23508 .63684 L .2277 .64254 L 0 1 .521 r
F
.2327 .65417 m .23922 .63813 L .23508 .63684 L F
.2327 .65417 m .23819 .64557 L .23922 .63813 L F
0 g
.22535 .65983 m
.2327 .65417 L
s
.23183 .6614 m
.2327 .65417 L
s
.4197 .86952 m .41104 .86885 L .41573 .87065 L 0 1 .476 r
F
0 g
.41573 .87065 m
.41907 .87445 L
s
.4197 .86952 m .40805 .86475 L .41104 .86885 L 0 1 .476 r
F
0 g
.40735 .87024 m
.41104 .86885 L
s
.37352 .85383 m .36326 .84608 L .36231 .85112 L 0 1 .494 r
F
.37352 .85383 m .36731 .84327 L .36326 .84608 L F
0 g
.36231 .85112 m
.36497 .85564 L
s
.37352 .85383 m .37175 .84457 L .36731 .84327 L 0 1 .494 r
F
.37352 .85383 m .37442 .84909 L .37175 .84457 L F
.38473 .85691 m .37442 .84909 L .37352 .85383 L 0 1 .49 r
F
0 g
.36948 .85663 m
.37352 .85383 L
s
.37352 .85383 m
.37623 .85823 L
s
.26299 .73951 m .25197 .73595 L .25255 .74041 L 0 1 .527 r
F
0 g
.24732 .74301 m
.25255 .74041 L
s
.30519 .72169 m
.30597 .72922 L
s
.68715 .61343 m .70517 .6139 L .70272 .612 L 0 1 .366 r
F
0 g
.70517 .6139 m
.71247 .61462 L
s
.48654 1.00988 m .48572 1.01585 L .48733 1.01473 L 0 .289 .316 r
F
.49341 1.02334 m .48733 1.01473 L .48572 1.01585 L 0 .236 .286 r
F
0 g
.48572 1.01585 m
.48694 1.02081 L
s
.48218 1.01259 m
.48572 1.01585 L
s
.52701 1.08603 m .52264 1.08022 L .51956 1.07589 L 0 .162 0 r
F
0 g
.53172 .81054 m
.532 .80172 L
s
.50761 .93006 m .5043 .92073 L .50637 .92582 L 0 .215 .095 r
F
.50872 .92877 m .50637 .92582 L .5043 .92073 L 0 .21 .095 r
F
0 g
.50406 .9204 m
.5043 .92073 L
s
.50342 .9162 m
.5043 .92073 L
s
.66262 .70518 m
.66541 .72165 L
s
.66541 .72165 m
.66567 .72319 L
s
.66262 .70518 m
.66345 .7241 L
s
.66345 .7241 m
.6635 .7251 L
s
.76874 .88554 m .77997 .88696 L .78032 .88369 L 0 1 .419 r
F
0 g
.77625 .88972 m
.77997 .88696 L
s
.77997 .88696 m
.78316 .88908 L
s
.38473 .85691 m .37841 .84663 L .37442 .84909 L 0 1 .49 r
F
.38473 .85691 m .38285 .84809 L .37841 .84663 L F
.38473 .85691 m .38556 .8525 L .38285 .84809 L F
0 g
.38073 .85936 m
.38473 .85691 L
s
.39639 .86057 m .38556 .8525 L .38473 .85691 L 0 1 .486 r
F
0 g
.38473 .85691 m
.38762 .86124 L
s
.36231 .85112 m .35257 .84353 L .35156 .84884 L 0 1 .498 r
F
.36231 .85112 m .35652 .84037 L .35257 .84353 L F
.36231 .85112 m .36078 .84147 L .35652 .84037 L F
.36231 .85112 m .36326 .84608 L .36078 .84147 L F
0 g
.35836 .85427 m
.36231 .85112 L
s
.5127 .89855 m .51174 .85634 L .51208 .87992 L 0 .491 .268 r
F
.51147 .89614 m .51208 .87992 L .51174 .85634 L 0 .49 .269 r
F
0 g
.51174 .85634 m
.51223 .83978 L
s
.5108 .8388 m
.51174 .85634 L
s
.38409 .91562 m
.38409 .91562 L
s
.76722 .61527 m .76974 .61091 L .76574 .61162 L 0 1 .471 r
F
.76722 .61527 m .77739 .61384 L .76974 .61091 L F
.35063 .67383 m .34718 .67319 L .34188 .67007 L 0 0 0 r
F
0 g
.3412 .66965 m
.34188 .67007 L
s
.35063 .67383 m .35307 .67531 L .34718 .67319 L 0 0 0 r
F
.35307 .67531 m .35208 .67507 L .35196 .67502 L F
.35287 .67524 m .35196 .67502 L .34718 .67319 L F
.35307 .67531 m .35196 .67502 L .35287 .67524 L F
.34188 .67007 m .34806 .66815 L .34391 .65829 L 0 .211 .269 r
F
.34188 .67007 m .34718 .67319 L .34806 .66815 L F
.34975 .6745 m .34209 .65752 L .34391 .65857 L 0 .652 .056 r
F
.35239 .6817 m .34928 .67439 L .34975 .6745 L F
.34928 .67439 m .34209 .65752 L .34975 .6745 L F
.3501 .67458 m .34391 .65857 L .34806 .66827 L F
.35239 .6817 m .34975 .6745 L .3501 .67458 L F
.34975 .6745 m .34391 .65857 L .3501 .67458 L F
.35307 .67531 m .35369 .67568 L .35208 .67507 L 0 0 0 r
F
.35063 .67383 m .35704 .67587 L .35369 .67568 L F
.35063 .67383 m .35572 .67507 L .35704 .67587 L F
.2461 .92936 m .23889 .92979 L .24348 .93018 L 0 .636 .249 r
F
0 g
.24348 .93018 m
.24856 .93157 L
s
.2461 .92936 m .23459 .92812 L .23889 .92979 L 0 .636 .249 r
F
0 g
.23719 .93085 m
.23889 .92979 L
s
.647 .80191 m
.64707 .80285 L
s
.35687 .76619 m .34758 .76389 L .35158 .765 L 0 .475 .221 r
F
0 g
.35158 .765 m
.3528 .76601 L
s
.50144 .91236 m .48998 .8828 L .4898 .88556 L 0 .527 .291 r
F
.50144 .91236 m .49354 .88943 L .48998 .8828 L F
0 g
.48667 .87408 m
.48998 .8828 L
s
.65197 .61946 m .65862 .61952 L .66666 .61842 L 0 1 .322 r
F
0 g
.65862 .61952 m
.66666 .61842 L
s
.66666 .61842 m
.66691 .6187 L
s
.48954 .89983 m .48951 .89691 L .48597 .88967 L 0 .592 .304 r
F
0 g
.48597 .88967 m
.48795 .89371 L
s
.4872 .89068 m
.48898 .89213 L
s
.48597 .88967 m
.4872 .89068 L
s
.44388 .78159 m .43703 .78209 L .4406 .78153 L 0 .08 0 r
F
.44388 .78159 m .43503 .78299 L .43703 .78209 L F
.44388 .78159 m .43594 .78364 L .43503 .78299 L F
.44388 .78159 m .43923 .78369 L .43594 .78364 L F
.44388 .78159 m .4427 .78313 L .43923 .78369 L F
.44388 .78159 m .44469 .78222 L .4427 .78313 L F
0 g
.44388 .78159 m
.44595 .78023 L
s
.4406 .78153 m
.44388 .78159 L
s
.44469 .78222 m
.44684 .78194 L
s
.48146 .92443 m .48084 .92043 L .47712 .91585 L 0 .539 .316 r
F
0 g
.48133 .92358 m
.48258 .92466 L
s
.46644 .90952 m .45774 .9023 L .45449 .90209 L 0 .878 .459 r
F
0 g
.45071 .89903 m
.45449 .90209 L
s
.42964 .77931 m .42017 .77959 L .42086 .77816 L 0 0 0 r
F
.42964 .77931 m .42315 .78138 L .42017 .77959 L F
.42964 .77931 m .42808 .78266 L .42315 .78138 L F
.42964 .77931 m .43166 .78257 L .42808 .78266 L F
.42964 .77931 m .43233 .78113 L .43166 .78257 L F
0 g
.42964 .77931 m
.43054 .77753 L
s
.42473 .77804 m
.42964 .77931 L
s
.48543 .99368 m .47996 .99653 L .48341 .99962 L 0 .31 .317 r
F
0 g
.47996 .99653 m
.48032 1.00128 L
s
.2977 .84078 m .28681 .84457 L .2925 .84512 L 0 1 .519 r
F
0 g
.2925 .84512 m
.29652 .85024 L
s
.80675 .80017 m .81803 .79454 L .82015 .79729 L 0 0 0 r
F
0 g
.81803 .79454 m
.82195 .79387 L
s
.50315 .89981 m .49585 .8734 L .4999 .88888 L 0 .53 .288 r
F
.50255 .90247 m .4999 .88888 L .49585 .8734 L 0 .534 .289 r
F
0 g
.49576 .87293 m
.49585 .8734 L
s
.4955 .87239 m
.49585 .8734 L
s
.35156 .84884 m .34187 .84127 L .34081 .84683 L 0 1 .502 r
F
.35156 .84884 m .34587 .83783 L .34187 .84127 L F
.35156 .84884 m .35013 .83881 L .34587 .83783 L F
.35156 .84884 m .35257 .84353 L .35013 .83881 L F
0 g
.34757 .85227 m
.35156 .84884 L
s
.35156 .84884 m
.35404 .85344 L
s
.37187 .91256 m .3643 .9122 L .36879 .91284 L 0 .637 .273 r
F
0 g
.36879 .91284 m
.3729 .91404 L
s
.37187 .91256 m .3606 .91071 L .3643 .9122 L 0 .637 .273 r
F
0 g
.36173 .91268 m
.3643 .9122 L
s
.36427 .67508 m
.36994 .67449 L
s
.50686 .95684 m .50543 .95553 L .50348 .95481 L 0 .312 .264 r
F
.39639 .86057 m .38965 .85047 L .38556 .8525 L 0 1 .486 r
F
.39639 .86057 m .39427 .85219 L .38965 .85047 L F
.39639 .86057 m .39716 .85652 L .39427 .85219 L F
.40805 .86475 m .39716 .85652 L .39639 .86057 L 0 1 .481 r
F
0 g
.39231 .86259 m
.39639 .86057 L
s
.39639 .86057 m
.39934 .86478 L
s
.41603 .77719 m
.42086 .77816 L
s
.66838 .63243 m .67946 .64912 L .6709 .62291 L 0 .231 .255 r
F
.66838 .63243 m .68659 .67686 L .67946 .64912 L F
.66838 .63243 m .68841 .69385 L .68659 .67686 L F
0 g
.66631 .64614 m
.66889 .65578 L
s
.66838 .63243 m .6837 .68864 L .68841 .69385 L 0 .231 .255 r
F
0 g
.68125 .69663 m
.68372 .68892 L
s
.66838 .63243 m .67511 .66225 L .6837 .68864 L 0 .231 .255 r
F
0 g
.66842 .66372 m
.66994 .67132 L
s
.66994 .67132 m
.6732 .68761 L
s
.66694 .61895 m
.66838 .63243 L
s
.66889 .65578 m
.6709 .66331 L
s
.68077 .69457 m
.68115 .68688 L
s
.53482 .98225 m .5349 .97993 L .53794 .9816 L 0 .152 0 r
F
0 g
.53763 .98018 m
.53794 .9816 L
s
.3412 .66965 m
.3412 .66958 L
s
.34042 .67549 m
.3407 .67335 L
s
.3407 .67335 m
.34073 .67317 L
s
.34073 .67317 m
.34114 .67004 L
s
.34114 .67004 m
.3412 .66965 L
s
.33877 .66863 m
.3388 .66859 L
s
.3388 .66859 m
.3391 .66808 L
s
.33795 .67004 m
.33855 .66902 L
s
.33855 .66902 m
.33877 .66863 L
s
.7418 1.07536 m .74114 1.07273 L .74756 1.06956 L 0 0 0 r
F
.7418 1.07536 m .73714 1.07518 L .74114 1.07273 L F
0 g
.73998 1.07157 m
.74114 1.07273 L
s
.3861 .57076 m
.38982 .56373 L
s
.3779 .57262 m
.3861 .57076 L
s
.75858 .65367 m .7738 .63406 L .76867 .64959 L 0 .141 .085 r
F
0 g
.7738 .63406 m
.7773 .62818 L
s
.7738 .63406 m
.77405 .62964 L
s
.48979 .90722 m .48179 .90112 L .48641 .90587 L 0 .568 .304 r
F
.49028 .91474 m .48641 .90587 L .48179 .90112 L 0 .542 .303 r
F
0 g
.48077 .89928 m
.48179 .90112 L
s
.4804 .90086 m
.48179 .90112 L
s
.47919 .90493 m
.48185 .90921 L
s
.48185 .90921 m
.4822 .90978 L
s
.48781 .93675 m .48681 .93538 L .48337 .93371 L 0 .622 .431 r
F
.50357 .47922 m .49533 .48243 L .49569 .4813 L 0 0 0 r
F
0 g
.49484 .47994 m
.49622 .47932 L
s
.50357 .47922 m .50307 .48239 L .49533 .48243 L 0 0 0 r
F
.50357 .47922 m .51375 .48121 L .50307 .48239 L F
.50357 .47922 m .52162 .47913 L .51375 .48121 L F
.50357 .47922 m .52145 .47754 L .52162 .47913 L F
0 g
.49622 .47932 m
.50357 .47922 L
s
.52145 .47754 m
.52891 .47648 L
s
.51372 .47759 m
.52145 .47754 L
s
.54435 1.10426 m .53952 1.09833 L .53657 1.09335 L 0 .282 0 r
F
0 g
.45041 .5203 m
.45626 .5143 L
s
.4423 .52401 m
.45041 .5203 L
s
.47997 .92293 m .4712 .91677 L .46832 .91647 L 0 .743 .445 r
F
0 g
.46445 .91393 m
.46832 .91647 L
s
.47012 .9208 m
.47222 .92083 L
s
.2977 .84078 m .28353 .83923 L .28681 .84457 L 0 1 .519 r
F
0 g
.28231 .84904 m
.28681 .84457 L
s
.33943 .67682 m
.34042 .67549 L
s
.28498 .7469 m .27739 .73951 L .27399 .74317 L 0 1 .505 r
F
.28498 .7469 m .28317 .73817 L .27739 .73951 L F
.28498 .7469 m .28746 .74006 L .28317 .73817 L F
.28498 .7469 m .28823 .74381 L .28746 .74006 L F
0 g
.27922 .74822 m
.28498 .7469 L
s
.28498 .7469 m
.28588 .75021 L
s
.47934 .95513 m .47801 .9505 L .47434 .94698 L 0 .452 .324 r
F
.72188 .61255 m .7379 .61319 L .73132 .61039 L 0 1 .395 r
F
0 g
.7379 .61319 m
.73984 .61569 L
s
.7379 .61319 m
.7458 .61482 L
s
.47934 .95513 m .47464 .95926 L .47789 .95889 L 0 .452 .324 r
F
.48289 .96671 m .47789 .95889 L .47464 .95926 L 0 .394 .319 r
F
0 g
.47358 .96333 m
.47464 .95926 L
s
.47097 .95574 m
.47464 .95926 L
s
.55666 .70561 m .55612 .69822 L .55451 .70513 L 0 1 .248 r
F
.55666 .70561 m .56102 .68843 L .55612 .69822 L F
.55234 .7294 m .55666 .70561 L .5521 .71723 L 0 1 .293 r
F
.51966 .96861 m .52121 .97034 L .52181 .97081 L 0 .045 .153 r
F
0 g
.52132 .9703 m
.52132 .9703 L
s
.51966 .96861 m .52019 .96935 L .52121 .97034 L 0 .045 .153 r
F
.75716 .88744 m .76842 .88837 L .76874 .88554 L 0 1 .38 r
F
0 g
.76472 .89082 m
.76842 .88837 L
s
.76842 .88837 m
.77164 .89016 L
s
.49101 .92236 m .47953 .91046 L .48001 .91445 L 0 .513 .302 r
F
.49101 .92236 m .48255 .91033 L .47953 .91046 L F
0 g
.47912 .90991 m
.47953 .91046 L
s
.47953 .91046 m
.48101 .9104 L
s
.48101 .9104 m
.48188 .91036 L
s
.48289 .96671 m .4754 .96839 L .47893 .97158 L 0 .394 .319 r
F
0 g
.47461 .9727 m
.4754 .96839 L
s
.27769 .64393 m .266 .64727 L .2701 .64883 L 0 1 .507 r
F
0 g
.26948 .6557 m
.2701 .64883 L
s
.34081 .84683 m .33116 .83927 L .33005 .84506 L 0 1 .505 r
F
.34081 .84683 m .3352 .83558 L .33116 .83927 L F
.34081 .84683 m .33947 .83645 L .3352 .83558 L F
.34081 .84683 m .34187 .84127 L .33947 .83645 L F
0 g
.33678 .85051 m
.34081 .84683 L
s
.34081 .84683 m
.34325 .85154 L
s
.50144 .91236 m .4898 .88556 L .49318 .89535 L 0 .527 .291 r
F
0 g
.48998 .8828 m
.49337 .88912 L
s
.48909 .88482 m
.4898 .88556 L
s
.40813 .9197 m .39866 .91803 L .39643 .91765 L 0 0 0 r
F
.40813 .9197 m .40335 .91901 L .39866 .91803 L F
.40667 .91976 m .39866 .91803 L .40335 .91901 L F
.40667 .91976 m .40066 .91838 L .39866 .91803 L F
.40066 .91838 m .39491 .91706 L .39866 .91803 L F
.39643 .91765 m .39866 .91803 L .39574 .91753 L F
.40813 .9197 m .40741 .91973 L .40335 .91901 L F
.41972 .92188 m .40741 .91973 L .40813 .9197 L F
0 g
.40813 .9197 m
.41212 .92026 L
s
.36674 .76857 m .35992 .76668 L .35687 .76619 L 0 .443 .203 r
F
.36674 .76857 m .36509 .76783 L .35992 .76668 L F
.36674 .76857 m .36891 .76887 L .36509 .76783 L F
.36674 .76857 m .36961 .76919 L .36891 .76887 L F
0 g
.36159 .76743 m
.36674 .76857 L
s
.70817 1.09203 m .7034 1.08997 L .70333 1.08648 L 0 0 0 r
F
0 g
.70333 1.08648 m
.7034 1.08997 L
s
.69569 1.08664 m
.70333 1.08648 L
s
.48534 .94445 m .47498 .93891 L .47615 .94355 L 0 .455 .311 r
F
.48534 .94445 m .47701 .93603 L .47498 .93891 L F
0 g
.4712 .93504 m
.47498 .93891 L
s
.63271 .76406 m
.63292 .76453 L
s
.63254 .76368 m
.63271 .76406 L
s
.63244 .76344 m
.63254 .76368 L
s
.63225 .76302 m
.63244 .76344 L
s
.63223 .76299 m
.63225 .76302 L
s
.63219 .7629 m
.63223 .76299 L
s
.6271 .7609 m
.62905 .76167 L
s
.62905 .76167 m
.63064 .76229 L
s
.63064 .76229 m
.6321 .76286 L
s
.6321 .76286 m
.63219 .7629 L
s
.74773 .63781 m .75085 .64142 L .74688 .64295 L 0 0 .029 r
F
.74773 .63781 m .75782 .63505 L .75085 .64142 L F
.51413 .96347 m .51571 .96574 L .51544 .96502 L 0 .192 .198 r
F
.51778 .96684 m .51544 .96502 L .51571 .96574 L 0 .117 .177 r
F
0 g
.51571 .96574 m
.51736 .96739 L
s
.51445 .9652 m
.51571 .96574 L
s
.51575 1.07082 m .51607 1.07168 L .51916 1.07566 L 0 0 .152 r
F
0 g
.51796 1.07396 m
.51956 1.07589 L
s
.33903 .90774 m .33052 .90307 L .32769 .90423 L 0 .998 .412 r
F
.33903 .90774 m .33486 .90377 L .33052 .90307 L F
.33903 .90774 m .33851 .90578 L .33486 .90377 L F
.34981 .90914 m .33851 .90578 L .33903 .90774 L 0 .89 .376 r
F
0 g
.33619 .9089 m
.33903 .90774 L
s
.33903 .90774 m
.34264 .90956 L
s
.49341 1.02334 m .49018 1.0263 L .49348 1.02952 L 0 .236 .286 r
F
0 g
.49018 1.0263 m
.49175 1.03114 L
s
.52425 .93332 m .53484 .9078 L .53523 .90952 L 0 .259 .131 r
F
.52425 .93332 m .53138 .91402 L .53484 .9078 L F
0 g
.53484 .9078 m
.5352 .90639 L
s
.44234 .88747 m .43445 .87892 L .43079 .87931 L 0 1 .469 r
F
.50558 .93295 m .49806 .9227 L .50078 .92509 L 0 .232 .096 r
F
.50558 .93295 m .49732 .92372 L .49806 .9227 L F
0 g
.49645 .91985 m
.49806 .9227 L
s
.50689 1.05434 m .50214 1.05082 L .50601 1.05644 L 0 .083 .178 r
F
.50689 1.05434 m .49975 1.04593 L .50214 1.05082 L F
0 g
.49873 1.04712 m
.50214 1.05082 L
s
.40805 .86475 m .40119 .85492 L .39716 .85652 L 0 1 .481 r
F
.40805 .86475 m .40581 .85685 L .40119 .85492 L F
.40805 .86475 m .40875 .86107 L .40581 .85685 L F
.4197 .86952 m .40875 .86107 L .40805 .86475 L 0 1 .476 r
F
0 g
.40402 .86634 m
.40805 .86475 L
s
.40805 .86475 m
.41104 .86885 L
s
.25197 .73595 m .24141 .73729 L .24587 .73853 L 0 1 .532 r
F
0 g
.24587 .73853 m
.24732 .74301 L
s
.28352 .83923 m .27444 .84341 L .27907 .84383 L 0 1 .523 r
F
0 g
.27907 .84383 m
.28231 .84904 L
s
.51966 .96861 m .52181 .97081 L .52158 .97049 L 0 .045 .153 r
F
0 g
.5193 .96887 m
.51972 .96909 L
s
.52181 .97081 m
.52255 .97125 L
s
.76794 .63238 m .78387 .62522 L .77809 .62975 L 0 0 0 r
F
0 g
.78387 .62522 m
.785 .62205 L
s
.78387 .62522 m
.78984 .62233 L
s
.33066 .65564 m .31972 .6516 L .32349 .65511 L 0 .408 .33 r
F
0 g
.32257 .66107 m
.32349 .65511 L
s
.51745 .92369 m .51699 .9237 L .51767 .91702 L 0 .232 .104 r
F
0 g
.51699 .92367 m
.51767 .91702 L
s
.5163 .92367 m
.51767 .91702 L
s
.51628 .92379 m .5158 .92389 L .51612 .91769 L 0 .224 .102 r
F
0 g
.51606 .91819 m
.51612 .91769 L
s
.43136 .87497 m .42275 .87353 L .42743 .87559 L 0 1 .47 r
F
0 g
.42743 .87559 m
.43079 .87931 L
s
.43136 .87497 m .4197 .86952 L .42275 .87353 L 0 1 .47 r
F
0 g
.41907 .87445 m
.42275 .87353 L
s
.72063 .79593 m
.72635 .78523 L
s
.6599 .72219 m
.65996 .7248 L
s
.51533 .92401 m .51518 .92406 L .51563 .91794 L 0 .223 .101 r
F
0 g
.51475 .92395 m
.51562 .91803 L
s
.51562 .91803 m
.51563 .91794 L
s
.59403 .64314 m .60673 .6364 L .60909 .63482 L 0 .878 .204 r
F
.59403 .64314 m .60028 .63997 L .60673 .6364 L F
0 g
.60673 .6364 m
.60932 .6356 L
s
.60028 .63997 m
.60319 .63872 L
s
.60028 .63997 m
.60673 .6364 L
s
.62171 .62847 m .63523 .62517 L .63799 .62388 L 0 .892 .245 r
F
.62171 .62847 m .62827 .62713 L .63523 .62517 L F
0 g
.63523 .62517 m
.63767 .62574 L
s
.40332 .77535 m .39355 .77429 L .39426 .77362 L 0 0 0 r
F
0 g
.3894 .77268 m
.39426 .77362 L
s
.45597 .92769 m .44856 .92508 L .45306 .9261 L 0 .08 .01 r
F
.45597 .92769 m .44462 .925 L .44856 .92508 L F
0 g
.44596 .92363 m
.44856 .92508 L
s
.54053 .81042 m .54266 .80582 L .54629 .82989 L 0 .702 .19 r
F
0 g
.54266 .80582 m
.54629 .82989 L
s
.5373 .79603 m
.54053 .81042 L
s
.54232 .78587 m
.54266 .80582 L
s
.35687 .76619 m .34699 .76328 L .34758 .76389 L 0 .475 .221 r
F
0 g
.34269 .76345 m
.34758 .76389 L
s
.47997 .92293 m .47273 .92084 L .47708 .92262 L 0 .743 .445 r
F
.48145 .92639 m .47708 .92262 L .47273 .92084 L 0 .722 .444 r
F
0 g
.46898 .91821 m
.47273 .92084 L
s
.47222 .92083 m
.47273 .92084 L
s
.32909 .6955 m .31651 .70433 L .32159 .70417 L 0 1 .401 r
F
.32909 .6955 m .31658 .69684 L .31651 .70433 L F
0 g
.32159 .70417 m
.32235 .71171 L
s
.32909 .6955 m .32177 .68668 L .31658 .69684 L 0 1 .401 r
F
.32909 .6955 m .32928 .678 L .32177 .68668 L F
.32909 .6955 m .3341 .67661 L .32928 .678 L F
.32909 .6955 m .33401 .68412 L .3341 .67661 L F
0 g
.3341 .67661 m
.33795 .67004 L
s
.33401 .68412 m
.33943 .67682 L
s
.32159 .70417 m
.32909 .6955 L
s
.33005 .84506 m .32044 .83749 L .31928 .84348 L 0 1 .509 r
F
.33005 .84506 m .32451 .83357 L .32044 .83749 L F
.33005 .84506 m .32879 .83435 L .32451 .83357 L F
.33005 .84506 m .33116 .83927 L .32879 .83435 L F
0 g
.32597 .84896 m
.33005 .84506 L
s
.33005 .84506 m
.33246 .84987 L
s
.50255 .90247 m .49488 .87841 L .49916 .89262 L 0 .534 .289 r
F
.50206 .90547 m .49916 .89262 L .49488 .87841 L 0 .534 .29 r
F
0 g
.49141 .86969 m
.49488 .87841 L
s
.49453 .87687 m
.49488 .87841 L
s
.28352 .83923 m .27197 .83805 L .27444 .84341 L 0 1 .523 r
F
0 g
.27074 .84814 m
.27444 .84341 L
s
.51857 .92384 m .51813 .92375 L .51917 .9166 L 0 .239 .107 r
F
0 g
.51814 .92367 m
.51917 .9166 L
s
.51747 .92361 m
.51917 .9166 L
s
.66948 1.10208 m .66702 1.08998 L .67325 1.09222 L 0 .184 .05 r
F
0 g
.6653 1.08576 m
.66702 1.08998 L
s
.4427 .78313 m
.44469 .78222 L
s
.58682 .64639 m
.5882 .64711 L
s
.74558 .88941 m .75687 .88982 L .75716 .88744 L 0 1 .33 r
F
0 g
.75319 .89196 m
.75687 .88982 L
s
.75687 .88982 m
.76011 .89127 L
s
.59827 .65729 m
.59897 .65813 L
s
.59482 .65312 m
.59827 .65729 L
s
.51048 .96015 m .50902 .95882 L .50742 .9582 L 0 .258 .214 r
F
.56102 .68843 m .56005 .68408 L .55849 .68919 L 0 1 .19 r
F
.56102 .68843 m .56524 .67614 L .56005 .68408 L F
.5147 .92426 m .51422 .92447 L .51406 .91888 L 0 .216 .099 r
F
.40332 .77535 m .39659 .77558 L .39355 .77429 L 0 0 0 r
F
.40332 .77535 m .40169 .7769 L .39659 .77558 L F
.40332 .77535 m .40543 .77736 L .40169 .7769 L F
.40332 .77535 m .40612 .7767 L .40543 .77736 L F
0 g
.39824 .77403 m
.40332 .77535 L
s
.47831 .48601 m .48839 .48283 L .49569 .4813 L 0 0 0 r
F
0 g
.48839 .48283 m
.49484 .47994 L
s
.49319 .93052 m .48328 .92528 L .48677 .92596 L 0 .217 .083 r
F
.49319 .93052 m .48251 .9265 L .48328 .92528 L F
0 g
.48258 .92466 m
.48328 .92528 L
s
.48328 .92528 m
.48435 .92549 L
s
.64481 .62273 m .64489 .62046 L .64212 .62186 L 0 .978 .276 r
F
.64481 .62273 m .65197 .61946 L .64489 .62046 L F
.64481 .62273 m .65862 .61952 L .65197 .61946 L F
0 g
.65862 .61952 m
.66127 .6204 L
s
.71045 .66767 m
.7152 .65992 L
s
.71602 .65858 m
.71655 .6577 L
s
.71655 .6577 m
.71736 .65639 L
s
.48144 .92835 m .47269 .92796 L .47008 .92596 L 0 .179 .065 r
F
0 g
.46617 .92604 m
.47008 .92596 L
s
.66079 .59003 m .66053 .58219 L .65742 .57731 L 0 .137 .222 r
F
0 g
.65694 .57641 m
.65742 .57731 L
s
.65434 .57319 m
.66078 .59003 L
s
.25762 .93066 m .25035 .93079 L .25494 .9312 L 0 .603 .239 r
F
0 g
.25494 .9312 m
.25995 .93234 L
s
.25762 .93066 m .2461 .92936 L .25035 .93079 L 0 .603 .239 r
F
0 g
.24856 .93157 m
.25035 .93079 L
s
.44462 .925 m .4352 .92471 L .4324 .92343 L 0 0 0 r
F
.66079 .59003 m .66886 .60174 L .66053 .58219 L 0 .137 .222 r
F
0 g
.65742 .57731 m
.66079 .59003 L
s
.52694 .9747 m
.52788 .97527 L
s
.52793 .9753 m
.52807 .97538 L
s
.52682 .97463 m
.52694 .9747 L
s
.5261 .97419 m
.52619 .97425 L
s
.52619 .97425 m
.52632 .97433 L
s
.52632 .97433 m
.52682 .97463 L
s
.52575 .97398 m
.5261 .97419 L
s
.52807 .97538 m
.5283 .97595 L
s
.52839 .97617 m
.52844 .9763 L
s
.77209 .79642 m .78527 .79239 L .78365 .79839 L 0 .165 .038 r
F
0 g
.78297 .78672 m
.78527 .79239 L
s
.78527 .79239 m
.78999 .78885 L
s
.49101 .92236 m .48001 .91445 L .48363 .9196 L 0 .513 .302 r
F
0 g
.48001 .91445 m
.48028 .91483 L
s
.47931 .91856 m
.48042 .91992 L
s
.47712 .91585 m
.48001 .91445 L
s
.45409 .89365 m .44574 .89111 L .45045 .89346 L 0 .973 .461 r
F
.45409 .89365 m .44234 .88747 L .44574 .89111 L F
.45415 .89892 m .45045 .89346 L .44574 .89111 L 0 .971 .466 r
F
0 g
.4423 .89122 m
.44574 .89111 L
s
.46747 .91386 m .467 .91212 L .46318 .90931 L 0 .869 .462 r
F
0 g
.46318 .90931 m
.46521 .91081 L
s
.66046 .86181 m
.66047 .86173 L
s
.66047 .86173 m
.66051 .86116 L
s
.47884 .91951 m .46747 .91386 L .4712 .91677 L 0 .758 .444 r
F
.47884 .91951 m .467 .91212 L .46747 .91386 L F
0 g
.47712 .91585 m
.47931 .91856 L
s
.46445 .91393 m
.46747 .91386 L
s
.33066 .65564 m .32157 .64222 L .31972 .6516 L 0 .408 .33 r
F
0 g
.31293 .6534 m
.31972 .6516 L
s
.57966 .64052 m
.58357 .64391 L
s
.25197 .73595 m .24093 .73251 L .24141 .73729 L 0 1 .532 r
F
0 g
.23611 .74023 m
.24141 .73729 L
s
.5303 .97795 m .5349 .97993 L .53307 .97951 L 0 .068 0 r
F
.53482 .98225 m .53307 .97951 L .5349 .97993 L 0 .152 0 r
F
0 g
.5349 .97993 m
.53794 .9816 L
s
.53453 .97901 m
.5349 .97993 L
s
.50131 .91617 m .48962 .88976 L .48955 .8926 L 0 .517 .291 r
F
.50131 .91617 m .49318 .89535 L .48962 .88976 L F
0 g
.48731 .88441 m
.48962 .88976 L
s
.48962 .88976 m
.49081 .89163 L
s
.44234 .88747 m .43914 .8813 L .43445 .87892 L 0 1 .469 r
F
.44234 .88747 m .44252 .88496 L .43914 .8813 L F
.45409 .89365 m .44252 .88496 L .44234 .88747 L 0 .973 .461 r
F
0 g
.44234 .88747 m
.44574 .89111 L
s
.43867 .88786 m
.44234 .88747 L
s
.63485 .53609 m
.64241 .54629 L
s
.64241 .54629 m
.6436 .5479 L
s
.78331 1.04502 m .77944 1.04943 L .77969 1.05102 L 0 1 .233 r
F
0 g
.77279 1.05513 m
.77969 1.05102 L
s
.27197 .83805 m .26285 .84238 L .26749 .84279 L 0 1 .526 r
F
0 g
.26749 .84279 m
.27074 .84814 L
s
.49844 1.04017 m .49975 1.04593 L .50043 1.04503 L 0 .185 .248 r
F
.50689 1.05434 m .50043 1.04503 L .49975 1.04593 L 0 .083 .178 r
F
0 g
.49975 1.04593 m
.50214 1.05082 L
s
.49639 1.04245 m
.49975 1.04593 L
s
.52312 .92899 m .53037 .91111 L .52635 .92162 L 0 .258 .126 r
F
.52374 .931 m .52635 .92162 L .53037 .91111 L 0 .258 .129 r
F
0 g
.53037 .91111 m
.53372 .90424 L
s
.53037 .91111 m
.53154 .90722 L
s
.61551 .63222 m .61501 .63073 L .61264 .63239 L 0 .804 .211 r
F
.61551 .63222 m .62171 .62847 L .61501 .63073 L F
.61551 .63222 m .62827 .62713 L .62171 .62847 L F
0 g
.62827 .62713 m
.63523 .62517 L
s
.62827 .62713 m
.63111 .62697 L
s
.45415 .89892 m .45405 .89681 L .45045 .89346 L 0 .971 .466 r
F
.4659 .90521 m .45415 .89892 L .45774 .9023 L 0 .883 .455 r
F
.4659 .90521 m .45405 .89681 L .45415 .89892 L F
0 g
.45449 .90209 m
.45759 .90229 L
s
.45071 .89903 m
.45415 .89892 L
s
.43133 .9244 m .42365 .92231 L .42827 .92323 L 0 0 0 r
F
.43133 .9244 m .41972 .92188 L .42365 .92231 L F
0 g
.42096 .92135 m
.42365 .92231 L
s
.42827 .92323 m
.4324 .92343 L
s
.53268 1.09369 m .53328 1.09082 L .53478 1.09257 L 0 .287 0 r
F
.53268 1.09369 m .5316 1.08977 L .53328 1.09082 L F
0 g
.5327 1.08908 m
.53328 1.09082 L
s
.51393 .90166 m .51384 .85966 L .51368 .883 L 0 .492 .267 r
F
.5127 .89855 m .51368 .883 L .51384 .85966 L 0 .491 .268 r
F
0 g
.51322 .84118 m
.51384 .85966 L
s
.51384 .85966 m
.51469 .84381 L
s
.51964 .92426 m .51922 .92405 L .52061 .91648 L 0 .245 .11 r
F
0 g
.51924 .92393 m
.51924 .92393 L
s
.49996 .94464 m .49342 .94355 L .49619 .94483 L 0 .394 .374 r
F
0 g
.49245 .94447 m
.49376 .94498 L
s
.49996 .94464 m .49222 .9422 L .49342 .94355 L 0 .394 .374 r
F
0 g
.49245 .94447 m
.49342 .94355 L
s
.8183 .80027 m .82503 .79543 L .8297 .79592 L 0 0 0 r
F
.8183 .80027 m .82015 .79729 L .82503 .79543 L F
0 g
.82195 .79387 m
.82503 .79543 L
s
.4197 .86952 m .41273 .85993 L .40875 .86107 L 0 1 .476 r
F
.4197 .86952 m .41734 .86211 L .41273 .85993 L F
.4197 .86952 m .42033 .86622 L .41734 .86211 L F
.43136 .87497 m .42033 .86622 L .4197 .86952 L 0 1 .47 r
F
0 g
.4197 .86952 m
.42275 .87353 L
s
.41573 .87065 m
.4197 .86952 L
s
.50206 .94729 m .49528 .94557 L .49655 .94691 L 0 .359 .354 r
F
.50206 .94729 m .49619 .94483 L .49528 .94557 L F
0 g
.49376 .94498 m
.49528 .94557 L
s
.48534 .94445 m .47615 .94355 L .47971 .94716 L 0 .455 .311 r
F
0 g
.47615 .94355 m
.47661 .94401 L
s
.47434 .94698 m
.47615 .94355 L
s
.31928 .84348 m .3097 .83589 L .30849 .84207 L 0 1 .513 r
F
.31928 .84348 m .31382 .83177 L .3097 .83589 L F
.31928 .84348 m .3181 .83247 L .31382 .83177 L F
.31928 .84348 m .32044 .83749 L .3181 .83247 L F
0 g
.31516 .84758 m
.31928 .84348 L
s
.31928 .84348 m
.32165 .84839 L
s
.49996 .94464 m .49349 .94167 L .49222 .9422 L 0 .394 .374 r
F
0 g
.48916 .94093 m
.49222 .9422 L
s
.49342 .94355 m
.49362 .94365 L
s
.58592 .64975 m
.58687 .64934 L
s
.58643 .65059 m
.5877 .64948 L
s
.48979 .90722 m .48966 .90424 L .48604 .89771 L 0 .568 .304 r
F
0 g
.48604 .89771 m
.48855 .90224 L
s
.33401 .68412 m
.3341 .67661 L
s
.82413 1.01 m .8264 1.01919 L .83203 1.01198 L 0 1 .438 r
F
.82413 1.01 m .82206 1.02119 L .8264 1.01919 L F
0 g
.82623 1.0225 m
.8264 1.01919 L
s
.50206 .94729 m .49655 .94691 L .49906 .94797 L 0 .359 .354 r
F
0 g
.49655 .94691 m
.49674 .94699 L
s
.49596 .94795 m
.49655 .94691 L
s
.49596 .94795 m
.49613 .94802 L
s
.27197 .83805 m .26041 .83689 L .26285 .84238 L 0 1 .526 r
F
0 g
.25915 .84728 m
.26285 .84238 L
s
.51349 .92484 m .513 .92513 L .51247 .92 L 0 .211 .098 r
F
.74892 .78915 m .75596 .79885 L .75135 .79755 L 0 .279 .073 r
F
.74892 .78915 m .76052 .79344 L .75596 .79885 L F
0 g
.74442 .79511 m
.74892 .78915 L
s
.7089 .69847 m
.70897 .70502 L
s
.28103 .89894 m
.28103 .89894 L
s
.49801 .942 m .4905 .94017 L .49349 .94167 L 0 .443 .389 r
F
.49801 .942 m .48939 .9388 L .4905 .94017 L F
0 g
.48916 .94093 m
.4905 .94017 L
s
.50656 .93146 m .50248 .92288 L .50498 .92753 L 0 .223 .096 r
F
.50761 .93006 m .50498 .92753 L .50248 .92288 L 0 .215 .095 r
F
0 g
.50178 .92211 m
.50248 .92288 L
s
.50126 .91867 m
.50248 .92288 L
s
.50558 .93295 m .4992 .92735 L .49732 .92372 L 0 .232 .096 r
F
0 g
.49691 .92357 m
.49732 .92372 L
s
.49806 .9227 m
.49964 .92409 L
s
.2001 .92467 m .18717 .92036 L .18861 .9236 L 0 .85 .347 r
F
0 g
.18861 .9236 m
.19312 .92626 L
s
.27769 .64393 m .26762 .63982 L .266 .64727 L 0 1 .507 r
F
0 g
.25908 .6521 m
.266 .64727 L
s
.38315 .91463 m .37554 .91387 L .38004 .9146 L 0 .576 .243 r
F
.38315 .91463 m .37187 .91256 L .37554 .91387 L F
0 g
.3729 .91404 m
.37554 .91387 L
s
.38004 .9146 m
.38409 .91562 L
s
.5695 .66637 m .58107 .65623 L .583 .65356 L 0 1 .21 r
F
.5695 .66637 m .57529 .66171 L .58107 .65623 L F
0 g
.58107 .65623 m
.58202 .65552 L
s
.57929 .65791 m
.58107 .65623 L
s
.57529 .66171 m
.57929 .65791 L
s
.47831 .48601 m .46922 .4897 L .47009 .48895 L 0 0 0 r
F
0 g
.46997 .48832 m
.47139 .48758 L
s
.47831 .48601 m .47651 .48817 L .46922 .4897 L 0 0 0 r
F
.47831 .48601 m .48711 .48537 L .47651 .48817 L F
.47831 .48601 m .49533 .48243 L .48711 .48537 L F
.47831 .48601 m .49569 .4813 L .49533 .48243 L F
0 g
.48839 .48283 m
.49569 .4813 L
s
.47139 .48758 m
.47831 .48601 L
s
.49569 .4813 m
.50357 .47922 L
s
.77739 .61384 m .79399 .61728 L .78759 .61227 L 0 1 .49 r
F
0 g
.79399 .61728 m
.79559 .62126 L
s
.73135 .89196 m .74531 .89133 L .74557 .88941 L 0 .847 .259 r
F
0 g
.74086 .89322 m
.74531 .89133 L
s
.44462 .925 m .43983 .92578 L .4352 .92471 L 0 0 0 r
F
.44462 .925 m .44386 .9259 L .43983 .92578 L F
.45597 .92769 m .44386 .9259 L .44462 .925 L 0 .08 .01 r
F
0 g
.44462 .925 m
.44856 .92508 L
s
.44181 .92371 m
.44462 .925 L
s
.52647 .80287 m
.52745 .80801 L
s
.52558 .81507 m
.52647 .80287 L
s
.48324 .93443 m .47701 .93603 L .48089 .93683 L 0 .499 .314 r
F
.48534 .94445 m .48089 .93683 L .47701 .93603 L 0 .455 .311 r
F
0 g
.47498 .93891 m
.47701 .93603 L
s
.47382 .93247 m
.47701 .93603 L
s
.72188 .61255 m .72359 .60903 L .7199 .61003 L 0 1 .395 r
F
.72188 .61255 m .73132 .61039 L .72359 .60903 L F
.34981 .90914 m .34138 .90488 L .33851 .90578 L 0 .89 .376 r
F
.34981 .90914 m .34572 .90565 L .34138 .90488 L F
.34981 .90914 m .34934 .90748 L .34572 .90565 L F
.3606 .91071 m .34934 .90748 L .34981 .90914 L 0 .76 .33 r
F
0 g
.34694 .91003 m
.34981 .90914 L
s
.34981 .90914 m
.35339 .91078 L
s
.50427 .94994 m .49852 .94891 L .49986 .95024 L 0 .332 .329 r
F
.50427 .94994 m .49906 .94797 L .49852 .94891 L F
0 g
.49613 .94802 m
.49852 .94891 L
s
.57338 .63697 m .57142 .6391 L .56985 .63635 L 0 .236 .005 r
F
.57338 .63697 m .57764 .64449 L .57142 .6391 L F
0 g
.5675 .63162 m
.57338 .63697 L
s
.49801 .942 m .491 .93849 L .48939 .9388 L 0 .443 .389 r
F
0 g
.48612 .93734 m
.48939 .9388 L
s
.49222 .9422 m
.49276 .94198 L
s
.4659 .90521 m .45774 .9023 L .46243 .90469 L 0 .883 .455 r
F
.46644 .90952 m .46243 .90469 L .45774 .9023 L 0 .878 .459 r
F
0 g
.45759 .90229 m
.45774 .9023 L
s
.45415 .89892 m
.45774 .9023 L
s
.52252 .97139 m .52369 .97233 L .52561 .9739 L 0 .01 .142 r
F
0 g
.52561 .9739 m
.52575 .97398 L
s
.52252 .97139 m .52158 .97049 L .52369 .97233 L 0 .01 .142 r
F
0 g
.52333 .97193 m
.52369 .97233 L
s
.52158 .97049 m
.52369 .97233 L
s
.74079 .60814 m .75576 .61328 L .75975 .61263 L 0 1 .457 r
F
.74079 .60814 m .74764 .61136 L .75576 .61328 L F
0 g
.75576 .61328 m
.75707 .61655 L
s
.46892 .9278 m .45982 .92778 L .45708 .92603 L 0 .135 .041 r
F
0 g
.45306 .9261 m
.45708 .92603 L
s
.39574 .91753 m
.39866 .91803 L
s
.60352 .6638 m .60358 .66525 L .60113 .66075 L 0 .279 0 r
F
0 g
.60113 .66075 m
.60137 .66105 L
s
.59897 .65813 m
.60113 .66075 L
s
.60586 .6681 m .60995 .67562 L .60573 .66875 L 0 .279 0 r
F
.60513 .66674 m .61599 .68493 L .60995 .67562 L F
.60352 .6638 m .60507 .66643 L .60513 .66674 L F
.60507 .66643 m .61599 .68493 L .60513 .66674 L F
.60995 .67562 m .60972 .67442 L .60726 .67111 L 0 0 .138 r
F
.60562 .66986 m .60726 .67111 L .60972 .67442 L 0 .154 0 r
F
.59421 .65715 m .60553 .66925 L .60562 .66986 L F
.60553 .66925 m .60726 .67111 L .60562 .66986 L F
.60542 .67033 m .60972 .67442 L .60643 .67152 L F
.59421 .65715 m .60554 .66976 L .60542 .67033 L F
.60554 .66976 m .60972 .67442 L .60542 .67033 L F
.60352 .6638 m .60586 .6681 L .60358 .66525 L 0 .279 0 r
F
.60586 .6681 m .60573 .66875 L .60358 .66525 L F
0 g
.60099 .65925 m
.60352 .6638 L
s
.60137 .66105 m
.60352 .6638 L
s
.60916 .67236 m
.6112 .67341 L
s
.61326 .67827 m
.61342 .67867 L
s
.61342 .67867 m
.61426 .68066 L
s
.50131 .91617 m .48955 .8926 L .49302 .90149 L 0 .517 .291 r
F
0 g
.48955 .8926 m
.49018 .8942 L
s
.49081 .89163 m
.49266 .89453 L
s
.48898 .89213 m
.48955 .8926 L
s
.27399 .74317 m .26653 .73531 L .26299 .73951 L 0 1 .519 r
F
.27399 .74317 m .27243 .73353 L .26653 .73531 L F
.27399 .74317 m .27673 .73537 L .27243 .73353 L F
.27399 .74317 m .27739 .73951 L .27673 .73537 L F
0 g
.26812 .74493 m
.27399 .74317 L
s
.27399 .74317 m
.27478 .7469 L
s
.50427 .94994 m .49986 .95024 L .50209 .95109 L 0 .332 .329 r
F
0 g
.49965 .9514 m
.49986 .95024 L
s
.68003 .90156 m
.68016 .90146 L
s
.50206 .90547 m .49411 .88377 L .49857 .89669 L 0 .534 .29 r
F
.50169 .90878 m .49857 .89669 L .49411 .88377 L 0 .532 .291 r
F
0 g
.49321 .8818 m
.49411 .88377 L
s
.49105 .87222 m
.49411 .88377 L
s
.47884 .91951 m .47011 .91271 L .467 .91212 L 0 .758 .444 r
F
0 g
.46521 .91081 m
.467 .91212 L
s
.46832 .91647 m
.47079 .91673 L
s
.49622 .93937 m .48781 .93675 L .491 .93849 L 0 .489 .4 r
F
.49622 .93937 m .48681 .93538 L .48781 .93675 L F
0 g
.48612 .93734 m
.48781 .93675 L
s
.26041 .83689 m .25126 .84137 L .2559 .84177 L 0 1 .528 r
F
0 g
.2559 .84177 m
.25915 .84728 L
s
.49028 .91474 m .48255 .91033 L .48706 .91414 L 0 .542 .303 r
F
.49101 .92236 m .48706 .91414 L .48255 .91033 L 0 .513 .302 r
F
0 g
.48188 .91036 m
.48255 .91033 L
s
.4822 .90978 m
.48255 .91033 L
s
.47904 .92651 m
.47932 .92673 L
s
.47902 .92649 m
.47904 .92651 L
s
.47894 .92643 m
.47902 .92649 L
s
.47891 .92641 m
.47894 .92643 L
s
.47882 .92634 m
.47891 .92641 L
s
.47882 .92634 m
.47888 .92634 L
s
.47888 .92634 m
.47891 .92634 L
s
.47882 .92634 m
.47933 .92635 L
s
.47882 .92634 m
.47904 .92647 L
s
.47904 .92647 m
.47919 .92655 L
s
.51575 1.07082 m .51185 1.06502 L .50877 1.06105 L 0 0 .152 r
F
.52425 .93332 m .53523 .90952 L .53219 .91776 L 0 .259 .131 r
F
0 g
.5341 .91258 m
.53523 .90952 L
s
.53213 .91177 m
.5342 .90554 L
s
.53523 .90952 m
.53674 .90579 L
s
.44301 .88122 m .43445 .87892 L .43914 .8813 L 0 1 .463 r
F
.44301 .88122 m .43136 .87497 L .43445 .87892 L F
0 g
.43079 .87931 m
.43445 .87892 L
s
.42792 .53714 m
.43312 .53063 L
s
.41966 .54063 m
.42792 .53714 L
s
.30849 .84207 m .29895 .83443 L .2977 .84079 L 0 1 .516 r
F
.30849 .84207 m .30311 .83014 L .29895 .83443 L F
0 g
.2977 .84079 m
.30001 .84588 L
s
.30849 .84207 m .30739 .83077 L .30311 .83014 L 0 1 .516 r
F
.30849 .84207 m .3097 .83589 L .30739 .83077 L F
0 g
.30434 .84635 m
.30849 .84207 L
s
.30849 .84207 m
.31084 .84708 L
s
.54806 .76127 m .55167 .7585 L .55588 .74554 L 0 1 .298 r
F
.49622 .93937 m .48875 .9353 L .48681 .93538 L 0 .489 .4 r
F
0 g
.48337 .93371 m
.48681 .93538 L
s
.48939 .9388 m
.49021 .93865 L
s
.49092 1.00642 m .48387 1.00453 L .48654 1.00988 L 0 .271 .299 r
F
.49092 1.00642 m .48341 .99962 L .48387 1.00453 L F
0 g
.48032 1.00128 m
.48387 1.00453 L
s
.48677 .97831 m .47826 .97597 L .48024 .98102 L 0 .334 .311 r
F
.48677 .97831 m .47893 .97158 L .47826 .97597 L F
0 g
.47461 .9727 m
.47826 .97597 L
s
.34699 .76328 m .33757 .76077 L .34157 .76207 L 0 .501 .237 r
F
0 g
.34157 .76207 m
.34269 .76345 L
s
.40638 .55421 m
.41088 .54735 L
s
.39809 .55725 m
.40638 .55421 L
s
.50657 .9526 m .50191 .95223 L .50331 .95355 L 0 .301 .298 r
F
.50657 .9526 m .50209 .95109 L .50191 .95223 L F
0 g
.49965 .9514 m
.50191 .95223 L
s
.51968 .92411 m
.51969 .92411 L
s
.52064 .92497 m .52025 .92465 L .52198 .91668 L 0 .25 .115 r
F
0 g
.52033 .92425 m
.52034 .92424 L
s
.5186 .92375 m
.52061 .91648 L
s
.51924 .92393 m
.52061 .91648 L
s
.24093 .73251 m .23026 .73426 L .23472 .73546 L 0 1 .536 r
F
0 g
.23472 .73546 m
.23611 .74023 L
s
.26041 .83689 m .24885 .83576 L .25126 .84137 L 0 1 .528 r
F
0 g
.24757 .84644 m
.25126 .84137 L
s
.55165 .80301 m .55693 .75354 L .55288 .76991 L 0 1 .272 r
F
0 g
.55528 .76022 m
.55693 .75354 L
s
.55588 .74554 m
.55693 .75354 L
s
.55317 .75387 m
.55588 .74554 L
s
.45045 .89346 m
.45062 .89362 L
s
.45062 .89362 m
.45075 .89374 L
s
.49319 .93052 m .48677 .92596 L .49066 .92811 L 0 .217 .083 r
F
.49463 .92788 m .49066 .92811 L .48677 .92596 L 0 .2 .082 r
F
0 g
.48454 .92344 m
.48677 .92596 L
s
.48435 .92549 m
.48677 .92596 L
s
.72001 .66112 m
.72127 .65432 L
s
.32157 .64222 m .31025 .64363 L .31404 .64668 L 0 1 .447 r
F
0 g
.31293 .6534 m
.31404 .64668 L
s
.45341 .49631 m .46331 .49178 L .47009 .48895 L 0 0 0 r
F
0 g
.46331 .49178 m
.46997 .48832 L
s
.51227 .9256 m .51178 .92595 L .5109 .92128 L 0 .207 .096 r
F
.47884 .91951 m .4712 .91677 L .47571 .91892 L 0 .758 .444 r
F
.47997 .92293 m .47571 .91892 L .4712 .91677 L 0 .743 .445 r
F
0 g
.46747 .91386 m
.4712 .91677 L
s
.47079 .91673 m
.4712 .91677 L
s
.4659 .90521 m .45751 .89732 L .45405 .89681 L 0 .883 .455 r
F
0 g
.45075 .89374 m
.45405 .89681 L
s
.51413 .96347 m .51267 .96214 L .51141 .96159 L 0 .192 .198 r
F
.49625 .92527 m .49558 .92631 L .49238 .92534 L 0 .183 .081 r
F
0 g
.49238 .92534 m
.49424 .9259 L
s
.49424 .9259 m
.49523 .9262 L
s
.48543 .99368 m .48331 .98861 L .47986 .98554 L 0 .31 .317 r
F
0 g
.68656 .78482 m
.68865 .80901 L
s
.6822 .79934 m
.68656 .78482 L
s
.36291 .57101 m .37104 .56054 L .37508 .55268 L 0 1 .399 r
F
0 g
.37104 .56054 m
.3792 .55238 L
s
.40564 .66325 m .39625 .66641 L .39916 .66587 L 0 1 .267 r
F
.40564 .66325 m .39865 .66441 L .39625 .66641 L F
0 g
.39742 .66733 m
.39916 .66587 L
s
.40564 .66325 m .40476 .6612 L .39865 .66441 L 0 1 .267 r
F
.40564 .66325 m .41126 .65857 L .40476 .6612 L F
.40564 .66325 m .4138 .65828 L .41126 .65857 L F
.40564 .66325 m .41138 .66029 L .4138 .65828 L F
0 g
.40351 .66517 m
.40564 .66325 L
s
.39916 .66587 m
.40564 .66325 L
s
.8183 .80027 m .8297 .79592 L .83177 .79787 L 0 0 0 r
F
0 g
.8297 .79592 m
.83363 .79565 L
s
.49319 .93052 m .48503 .92891 L .48251 .9265 L 0 .217 .083 r
F
.49198 .93008 m .48084 .92043 L .48146 .92443 L 0 .481 .3 r
F
0 g
.47919 .92655 m
.47931 .92662 L
s
.47891 .92634 m
.47909 .92635 L
s
.49198 .93008 m .48363 .9196 L .48084 .92043 L 0 .481 .3 r
F
0 g
.48042 .91992 m
.48084 .92043 L
s
.47909 .92635 m
.48251 .9265 L
s
.48084 .92043 m
.48197 .92009 L
s
.66351 .72511 m
.66351 .72469 L
s
.66351 .72469 m
.66358 .72144 L
s
.29523 .90037 m
.29523 .90037 L
s
.53268 1.09369 m .53478 1.09257 L .53525 1.09425 L 0 .287 0 r
F
0 g
.53478 1.09257 m
.53657 1.09335 L
s
.26914 .93202 m .26182 .93184 L .26641 .93228 L 0 .561 .226 r
F
0 g
.26641 .93228 m
.27134 .93318 L
s
.26914 .93202 m .25762 .93066 L .26182 .93184 L 0 .561 .226 r
F
0 g
.25995 .93234 m
.26182 .93184 L
s
.5591 .81007 m .56111 .76464 L .55874 .78851 L 0 1 .254 r
F
.55165 .80301 m .55874 .78851 L .56111 .76464 L 0 1 .272 r
F
0 g
.56033 .74969 m
.56111 .76464 L
s
.56111 .76464 m
.56354 .75161 L
s
.45409 .89365 m .44616 .88515 L .44252 .88496 L 0 .973 .461 r
F
0 g
.43914 .8813 m
.44252 .88496 L
s
.36291 .57101 m .35132 .57825 L .35446 .5786 L 0 1 .399 r
F
0 g
.35773 .58049 m
.35916 .57852 L
s
.36291 .57101 m .35536 .57039 L .35132 .57825 L 0 1 .399 r
F
.36291 .57101 m .36388 .56026 L .35536 .57039 L F
.36291 .57101 m .37234 .55267 L .36388 .56026 L F
.36291 .57101 m .37508 .55268 L .37234 .55267 L F
0 g
.35916 .57852 m
.36291 .57101 L
s
.53658 .92074 m .53639 .91814 L .53966 .90641 L 0 .221 .137 r
F
0 g
.53713 .91546 m
.53966 .90641 L
s
.53622 .91055 m
.5377 .90492 L
s
.38438 .6709 m .37455 .67385 L .3778 .67316 L 0 .832 .218 r
F
.38367 .54637 m .37234 .55267 L .37508 .55268 L 0 1 .349 r
F
0 g
.37104 .56054 m
.37508 .55268 L
s
.38367 .54637 m .37712 .54644 L .37234 .55267 L 0 1 .349 r
F
.38367 .54637 m .38626 .53814 L .37712 .54644 L F
.38367 .54637 m .39486 .53183 L .38626 .53814 L F
.38367 .54637 m .39718 .53173 L .39486 .53183 L F
.38367 .54637 m .39238 .53796 L .39718 .53173 L F
0 g
.3792 .55238 m
.38367 .54637 L
s
.37508 .55268 m
.38367 .54637 L
s
.39238 .53796 m
.40065 .53135 L
s
.78331 1.04502 m .79001 1.04333 L .79405 1.03835 L 0 1 .233 r
F
0 g
.78387 1.04875 m
.79001 1.04333 L
s
.79001 1.04333 m
.79014 1.04554 L
s
.50657 .9526 m .50331 .95355 L .50523 .95419 L 0 .301 .298 r
F
0 g
.50331 .95355 m
.50348 .95481 L
s
.72051 .89407 m .73111 .89329 L .73135 .89196 L 0 .771 .241 r
F
0 g
.7277 .89465 m
.73111 .89329 L
s
.27769 .64393 m .27389 .63142 L .26762 .63982 L 0 1 .507 r
F
.27769 .64393 m .28151 .6265 L .27389 .63142 L F
.27769 .64393 m .28537 .62835 L .28151 .6265 L F
.27769 .64393 m .28372 .63583 L .28537 .62835 L F
0 g
.27624 .65126 m
.27769 .64393 L
s
.2701 .64883 m
.27769 .64393 L
s
.4946 .93677 m .48539 .93331 L .48875 .9353 L 0 .528 .408 r
F
.4946 .93677 m .4845 .93193 L .48539 .93331 L F
0 g
.48337 .93371 m
.48539 .93331 L
s
.51637 .90996 m .51954 .85746 L .51799 .87076 L 0 .489 .265 r
F
.51637 .90996 m .52048 .86115 L .51954 .85746 L F
0 g
.51954 .85746 m
.51956 .85252 L
s
.55727 .63077 m .56379 .63278 L .56985 .63635 L 0 .141 0 r
F
0 g
.56379 .63278 m
.5675 .63162 L
s
.34255 .64102 m .344 .61779 L .34056 .61588 L 0 1 .273 r
F
.34255 .64102 m .34485 .62855 L .344 .61779 L F
0 g
.344 .61779 m
.34467 .6262 L
s
.34467 .6262 m
.34483 .62822 L
s
.34483 .62822 m
.34485 .62855 L
s
.2001 .92467 m .18957 .91842 L .18717 .92036 L 0 .85 .347 r
F
.2001 .92467 m .19422 .91909 L .18957 .91842 L F
.2001 .92467 m .19873 .92178 L .19422 .91909 L F
.21159 .92578 m .19873 .92178 L .2001 .92467 L 0 .777 .318 r
F
0 g
.19769 .92659 m
.2001 .92467 L
s
.2001 .92467 m
.20455 .92708 L
s
.43136 .87497 m .42425 .86558 L .42033 .86622 L 0 1 .47 r
F
.43136 .87497 m .42886 .86804 L .42425 .86558 L F
.43136 .87497 m .43191 .87206 L .42886 .86804 L F
.44301 .88122 m .43191 .87206 L .43136 .87497 L 0 1 .463 r
F
0 g
.43136 .87497 m
.43445 .87892 L
s
.42743 .87559 m
.43136 .87497 L
s
.66932 .61594 m
.67043 .61669 L
s
.45341 .49631 m .44357 .50051 L .44495 .50005 L 0 0 0 r
F
0 g
.44556 .50001 m
.44701 .49915 L
s
.45341 .49631 m .45034 .49767 L .44357 .50051 L 0 0 0 r
F
0 g
.44701 .49915 m
.45018 .49774 L
s
.45341 .49631 m .46075 .49344 L .45034 .49767 L 0 0 0 r
F
.45341 .49631 m .46922 .4897 L .46075 .49344 L F
.45341 .49631 m .47009 .48895 L .46922 .4897 L F
0 g
.46331 .49178 m
.47009 .48895 L
s
.47009 .48895 m
.47831 .48601 L
s
.51778 .96684 m .52019 .96935 L .51944 .96849 L 0 .117 .177 r
F
0 g
.51972 .96909 m
.52019 .96935 L
s
.24885 .83576 m .23966 .84037 L .2443 .84077 L 0 1 .53 r
F
0 g
.2443 .84077 m
.24757 .84644 L
s
.51966 .96861 m .51944 .9685 L .52019 .96935 L 0 .045 .153 r
F
0 g
.52019 .96935 m
.52121 .97034 L
s
.49238 .92534 m
.49412 .9273 L
s
.49341 1.02334 m .49063 1.01794 L .48733 1.01473 L 0 .236 .286 r
F
.38438 .6709 m .37649 .67271 L .37455 .67385 L 0 .832 .218 r
F
.38438 .6709 m .38235 .67049 L .37649 .67271 L F
.38438 .6709 m .38895 .66822 L .38235 .67049 L F
.38438 .6709 m .39188 .66742 L .38895 .66822 L F
.38438 .6709 m .38991 .66857 L .39188 .66742 L F
0 g
.38266 .67235 m
.38438 .6709 L
s
.3778 .67316 m
.38438 .6709 L
s
.50131 .92019 m .48951 .89691 L .48954 .89983 L 0 .505 .29 r
F
0 g
.48855 .90224 m
.48947 .9039 L
s
.50131 .92019 m .49302 .90149 L .48951 .89691 L 0 .505 .29 r
F
0 g
.48795 .89371 m
.48951 .89691 L
s
.48604 .89771 m
.48925 .89965 L
s
.49018 .8942 m
.49237 .89982 L
s
.48994 .89747 m
.49029 .89792 L
s
.48981 .8973 m
.48994 .89747 L
s
.48951 .89691 m
.48981 .8973 L
s
.4946 .93677 m .48675 .93211 L .4845 .93193 L 0 .528 .408 r
F
0 g
.48258 .93091 m
.4845 .93193 L
s
.48781 .93675 m
.49051 .93822 L
s
.48681 .93538 m
.48794 .93533 L
s
.69576 .61041 m .71069 .61247 L .71437 .6115 L 0 1 .399 r
F
.69576 .61041 m .70272 .612 L .71069 .61247 L F
0 g
.71069 .61247 m
.71247 .61462 L
s
.6141 .68041 m
.61552 .68272 L
s
.61375 .67984 m
.6141 .68041 L
s
.60916 .67236 m
.61375 .67984 L
s
.7418 1.07536 m .73741 1.07631 L .73714 1.07518 L 0 0 0 r
F
0 g
.73015 1.0771 m
.73714 1.07518 L
s
.44113 .64811 m .4328 .65038 L .43493 .65024 L 0 .937 .241 r
F
.44113 .64811 m .43614 .6484 L .4328 .65038 L F
0 g
.43216 .65231 m
.43493 .65024 L
s
.44113 .64811 m .44272 .64561 L .43614 .6484 L 0 .937 .241 r
F
.44113 .64811 m .44894 .64348 L .44272 .64561 L F
.44113 .64811 m .45064 .64341 L .44894 .64348 L F
.44113 .64811 m .44729 .6454 L .45064 .64341 L F
0 g
.43811 .64997 m
.44113 .64811 L
s
.43493 .65024 m
.44113 .64811 L
s
.44729 .6454 m
.45319 .6432 L
s
.2977 .84078 m .28483 .83266 L .28353 .83923 L 0 1 .519 r
F
.2977 .84078 m .29004 .8283 L .28483 .83266 L F
0 g
.28353 .83923 m
.28681 .84457 L
s
.2977 .84078 m .29567 .82908 L .29004 .8283 L 0 1 .519 r
F
.2977 .84078 m .29895 .83443 L .29567 .82908 L F
0 g
.2925 .84512 m
.2977 .84078 L
s
.24093 .73251 m .22988 .72919 L .23026 .73426 L 0 1 .536 r
F
0 g
.22488 .73753 m
.23026 .73426 L
s
.24885 .83576 m .23727 .83462 L .23966 .84037 L 0 1 .53 r
F
0 g
.23598 .84561 m
.23966 .84037 L
s
.48289 .96671 m .48143 .96208 L .47789 .95889 L 0 .394 .319 r
F
.40582 .5264 m .39486 .53183 L .39718 .53173 L 0 1 .244 r
F
.40582 .5264 m .40037 .52676 L .39486 .53183 L F
0 g
.39238 .53796 m
.39718 .53173 L
s
.40582 .5264 m .41004 .51989 L .40037 .52676 L 0 1 .244 r
F
.40582 .5264 m .41869 .51456 L .41004 .51989 L F
.40582 .5264 m .42055 .51432 L .41869 .51456 L F
.40582 .5264 m .41504 .51939 L .42055 .51432 L F
0 g
.40065 .53135 m
.40582 .5264 L
s
.39718 .53173 m
.40582 .5264 L
s
.41504 .51939 m
.42334 .51375 L
s
.55234 .7294 m .5521 .71723 L .55051 .72645 L 0 1 .293 r
F
.54806 .76127 m .55234 .7294 L .54812 .74235 L 0 1 .298 r
F
.3606 .91071 m .35224 .90686 L .34934 .90748 L 0 .76 .33 r
F
.3606 .91071 m .35658 .90771 L .35224 .90686 L F
.3606 .91071 m .36017 .90936 L .35658 .90771 L F
0 g
.3577 .91132 m
.3606 .91071 L
s
.37187 .91256 m .36017 .90936 L .3606 .91071 L 0 .637 .273 r
F
0 g
.3606 .91071 m
.3643 .9122 L
s
.50689 1.05434 m .50601 1.05644 L .50908 1.06006 L 0 .083 .178 r
F
0 g
.50601 1.05644 m
.50877 1.06105 L
s
.42915 .50981 m .43877 .50404 L .44495 .50005 L 0 .878 .201 r
F
0 g
.43877 .50404 m
.44556 .50001 L
s
.41972 .92188 m .41039 .92057 L .40741 .91973 L 0 0 0 r
F
.41972 .92188 m .41509 .92167 L .41039 .92057 L F
.41972 .92188 m .41909 .92223 L .41509 .92167 L F
.43133 .9244 m .41909 .92223 L .41972 .92188 L F
0 g
.41972 .92188 m
.42365 .92231 L
s
.41673 .92104 m
.41972 .92188 L
s
.48774 .95449 m .47801 .9505 L .47934 .95513 L 0 .408 .308 r
F
.48774 .95449 m .47971 .94716 L .47801 .9505 L F
0 g
.47434 .94698 m
.47801 .9505 L
s
.50895 .95525 m .50543 .95553 L .50686 .95684 L 0 .264 .262 r
F
.50895 .95525 m .50523 .95419 L .50543 .95553 L F
0 g
.50348 .95481 m
.50543 .95553 L
s
.50169 .90878 m .49354 .88943 L .49813 .90106 L 0 .532 .291 r
F
.50144 .91236 m .49813 .90106 L .49354 .88943 L 0 .527 .291 r
F
0 g
.49337 .88912 m
.49354 .88943 L
s
.49031 .87875 m
.49354 .88943 L
s
.46644 .90952 m .46616 .90779 L .46243 .90469 L 0 .878 .459 r
F
.47807 .91614 m .46644 .90952 L .47011 .91271 L 0 .769 .443 r
F
.47807 .91614 m .46616 .90779 L .46644 .90952 L F
0 g
.467 .91212 m
.46985 .91266 L
s
.46318 .90931 m
.46644 .90952 L
s
.62171 .62847 m .63799 .62388 L .63487 .62358 L 0 .892 .245 r
F
0 g
.63799 .62388 m
.64481 .62273 L
s
.42915 .50981 m .41869 .51456 L .42055 .51432 L 0 .878 .201 r
F
.42915 .50981 m .42487 .51058 L .41869 .51456 L F
0 g
.41504 .51939 m
.42055 .51432 L
s
.42915 .50981 m .43496 .50502 L .42487 .51058 L 0 .878 .201 r
F
.42915 .50981 m .44357 .50051 L .43496 .50502 L F
.42915 .50981 m .44495 .50005 L .44357 .50051 L F
0 g
.43877 .50404 m
.44495 .50005 L
s
.42055 .51432 m
.42915 .50981 L
s
.42334 .51375 m
.42915 .50981 L
s
.44495 .50005 m
.44992 .49785 L
s
.34699 .76328 m .33711 .7598 L .33757 .76077 L 0 .501 .237 r
F
0 g
.33258 .76045 m
.33757 .76077 L
s
.50471 .79812 m .50139 .80987 L .50224 .80214 L 0 .471 .11 r
F
.50471 .79812 m .50295 .81876 L .50139 .80987 L F
0 g
.50108 .79466 m
.50224 .80214 L
s
.50471 .79812 m .5059 .82286 L .50295 .81876 L 0 .471 .11 r
F
.50471 .79812 m .50838 .81878 L .5059 .82286 L F
.50471 .79812 m .50872 .80929 L .50838 .81878 L F
.50471 .79812 m .50715 .80046 L .50872 .80929 L F
0 g
.50352 .78923 m
.50471 .79812 L
s
.50224 .80214 m
.50471 .79812 L
s
.50715 .80046 m
.50924 .79379 L
s
.48543 .99368 m .48341 .99962 L .48547 .9984 L 0 .31 .317 r
F
.49092 1.00642 m .48547 .9984 L .48341 .99962 L 0 .271 .299 r
F
0 g
.48341 .99962 m
.48387 1.00453 L
s
.47996 .99653 m
.48341 .99962 L
s
.59403 .64314 m .60909 .63482 L .60588 .63549 L 0 .878 .204 r
F
0 g
.60909 .63482 m
.61551 .63222 L
s
.32157 .64222 m .31231 .63431 L .31025 .64363 L 0 1 .447 r
F
0 g
.30324 .64659 m
.31025 .64363 L
s
.48145 .92639 m .48081 .925 L .47708 .92262 L 0 .722 .444 r
F
.49028 .91474 m .49005 .91171 L .48641 .90587 L 0 .542 .303 r
F
0 g
.48641 .90587 m
.48927 .91046 L
s
.48641 .90587 m
.48914 .90696 L
s
.50468 .93453 m .49625 .92527 L .4992 .92735 L 0 .242 .097 r
F
.50468 .93453 m .49558 .92631 L .49625 .92527 L F
0 g
.49562 .9244 m
.49625 .92527 L
s
.49625 .92527 m
.49766 .92626 L
s
.46215 .78707 m .45469 .7875 L .4578 .78616 L 0 .208 .035 r
F
0 g
.4578 .78616 m
.45826 .78353 L
s
.46215 .78707 m .45468 .79056 L .45469 .7875 L 0 .208 .035 r
F
.46215 .78707 m .45779 .79331 L .45468 .79056 L F
.46215 .78707 m .46216 .79423 L .45779 .79331 L F
.46215 .78707 m .46487 .79269 L .46216 .79423 L F
.46215 .78707 m .46486 .78962 L .46487 .79269 L F
0 g
.46215 .78707 m
.46244 .78348 L
s
.4578 .78616 m
.46215 .78707 L
s
.48289 .96671 m .47893 .97158 L .48182 .97079 L 0 .394 .319 r
F
.48677 .97831 m .48182 .97079 L .47893 .97158 L 0 .334 .311 r
F
0 g
.47826 .97597 m
.47893 .97158 L
s
.4754 .96839 m
.47893 .97158 L
s
.55727 .63077 m .55432 .63272 L .55321 .63074 L 0 .141 0 r
F
.55727 .63077 m .56039 .6363 L .55432 .63272 L F
.55727 .63077 m .56737 .63909 L .56039 .6363 L F
.55727 .63077 m .57142 .6391 L .56737 .63909 L F
.55727 .63077 m .56985 .63635 L .57142 .6391 L F
0 g
.5709 .63654 m
.57338 .63697 L
s
.56985 .63635 m
.5709 .63654 L
s
.55156 .62731 m
.55727 .63077 L
s
.56379 .63278 m
.56985 .63635 L
s
.46243 .90469 m
.46298 .90515 L
s
.46298 .90515 m
.46341 .90551 L
s
.70967 .8964 m .7203 .8949 L .72051 .89407 L 0 .693 .212 r
F
0 g
.7169 .89593 m
.7203 .8949 L
s
.7203 .8949 m
.72338 .89515 L
s
.51106 .92652 m .51058 .92693 L .50934 .92268 L 0 .206 .095 r
F
.19933 .88412 m .19115 .88747 L .19579 .88789 L 0 1 .527 r
F
0 g
.19579 .88789 m
.20019 .89233 L
s
.19933 .88412 m .18772 .88285 L .19115 .88747 L 0 1 .527 r
F
0 g
.18866 .8915 m
.19115 .88747 L
s
.32157 .64222 m .31886 .62492 L .31231 .63431 L 0 1 .447 r
F
.32157 .64222 m .3264 .62045 L .31886 .62492 L F
.32157 .64222 m .3299 .62389 L .3264 .62045 L F
.32157 .64222 m .32783 .63323 L .3299 .62389 L F
.33066 .65564 m .32783 .63323 L .32157 .64222 L 0 .408 .33 r
F
0 g
.31404 .64668 m
.32157 .64222 L
s
.31972 .6516 m
.32157 .64222 L
s
.32349 .65511 m
.33021 .65561 L
s
.49198 .93008 m .48146 .92443 L .48503 .92891 L 0 .481 .3 r
F
0 g
.48146 .92443 m
.48172 .92476 L
s
.48073 .92495 m
.48146 .92443 L
s
.39355 .77429 m .38431 .7722 L .38829 .77284 L 0 0 0 r
F
0 g
.38829 .77284 m
.3894 .77268 L
s
.49318 .93419 m .48326 .92985 L .48675 .93211 L 0 .561 .414 r
F
.49318 .93419 m .4825 .92846 L .48326 .92985 L F
0 g
.48206 .92995 m
.48326 .92985 L
s
.35687 .76619 m .35022 .76358 L .34699 .76328 L 0 .475 .221 r
F
.35687 .76619 m .35553 .76478 L .35022 .76358 L F
.35687 .76619 m .35935 .76607 L .35553 .76478 L F
.35687 .76619 m .35992 .76668 L .35935 .76607 L F
0 g
.35158 .765 m
.35687 .76619 L
s
.35687 .76619 m
.35759 .76652 L
s
.52079 .92453 m
.52079 .92453 L
s
.52156 .92598 m .5212 .92554 L .52324 .91726 L 0 .254 .119 r
F
0 g
.51969 .92411 m
.52198 .91668 L
s
.52034 .92424 m
.52198 .91668 L
s
.7418 1.07536 m .74756 1.06956 L .75214 1.06776 L 0 0 0 r
F
0 g
.74114 1.07273 m
.74756 1.06956 L
s
.74714 1.06927 m
.74756 1.06956 L
s
.23727 .83462 m .22806 .83938 L .2327 .83978 L 0 1 .532 r
F
0 g
.2327 .83978 m
.23598 .84561 L
s
.82413 1.01 m .82108 1.01727 L .82206 1.02119 L 0 1 .438 r
F
0 g
.81551 1.02718 m
.82206 1.02119 L
s
.39491 .91706 m .38693 .91579 L .39162 .91665 L 0 .486 .217 r
F
.39491 .91706 m .38315 .91463 L .38693 .91579 L F
0 g
.38409 .91562 m
.38693 .91579 L
s
.39162 .91665 m
.39574 .91753 L
s
.69735 .79929 m .70984 .7876 L .70804 .80843 L 0 .495 .147 r
F
0 g
.70816 .77073 m
.70984 .7876 L
s
.70984 .7876 m
.71227 .78105 L
s
.50131 .92019 m .48954 .89983 L .49308 .90782 L 0 .505 .29 r
F
0 g
.48954 .89983 m
.48965 .90008 L
s
.48965 .90008 m
.48971 .90021 L
s
.48971 .90021 m
.49021 .90134 L
s
.49021 .90134 m
.49081 .90268 L
s
.49081 .90268 m
.49148 .90419 L
s
.49029 .89792 m
.49219 .90041 L
s
.48925 .89965 m
.48954 .89983 L
s
.51966 .96861 m .52158 .97049 L .52068 .9696 L 0 .045 .153 r
F
0 g
.52158 .97049 m
.52181 .97081 L
s
.52252 .97139 m .52068 .9696 L .52158 .97049 L 0 .01 .142 r
F
.50895 .95525 m .50686 .95684 L .50845 .9573 L 0 .264 .262 r
F
0 g
.50686 .95684 m
.50742 .9582 L
s
.666 .89048 m
.666 .89047 L
s
.56524 .67614 m .57528 .66171 L .5695 .66638 L 0 1 .193 r
F
0 g
.57528 .66171 m
.5781 .66074 L
s
.26299 .73951 m .25566 .73125 L .25197 .73595 L 0 1 .527 r
F
.26299 .73951 m .26167 .72905 L .25566 .73125 L F
.26299 .73951 m .26598 .73082 L .26167 .72905 L F
.26299 .73951 m .26653 .73531 L .26598 .73082 L F
0 g
.257 .74169 m
.26299 .73951 L
s
.26299 .73951 m
.26367 .74362 L
s
.48677 .97831 m .48024 .98102 L .48359 .98391 L 0 .334 .311 r
F
0 g
.47986 .98554 m
.48024 .98102 L
s
.50051 1.03702 m .49511 1.0346 L .49844 1.04017 L 0 .166 .24 r
F
.50051 1.03702 m .49348 1.02952 L .49511 1.0346 L F
0 g
.49175 1.03114 m
.49511 1.0346 L
s
.34364 .60376 m .35116 .58953 L .35446 .5786 L 0 1 .389 r
F
0 g
.35116 .58953 m
.35773 .58049 L
s
.26762 .63982 m .25573 .64358 L .25984 .64502 L 0 1 .51 r
F
0 g
.25908 .6521 m
.25984 .64502 L
s
.52701 1.08603 m .53159 1.08977 L .53086 1.09012 L 0 .162 0 r
F
0 g
.5285 1.08542 m
.53159 1.08977 L
s
.53268 1.09369 m .53086 1.09013 L .5316 1.08977 L 0 .287 0 r
F
0 g
.5316 1.08977 m
.53328 1.09082 L
s
.39867 .8504 m .38965 .85047 L .39427 .85219 L 0 1 .479 r
F
0 g
.39427 .85219 m
.39716 .85652 L
s
.41012 .85552 m .40119 .85492 L .40581 .85685 L 0 1 .474 r
F
0 g
.40581 .85685 m
.40875 .86107 L
s
.41012 .85552 m .39867 .8504 L .40119 .85492 L 0 1 .474 r
F
0 g
.39716 .85652 m
.40119 .85492 L
s
.39867 .8504 m .38722 .84583 L .38965 .85047 L 0 1 .479 r
F
0 g
.38556 .8525 m
.38965 .85047 L
s
.21094 .88541 m .20274 .88853 L .20738 .88896 L 0 1 .525 r
F
0 g
.20738 .88896 m
.21173 .89318 L
s
.21094 .88541 m .19933 .88412 L .20274 .88853 L 0 1 .525 r
F
0 g
.20019 .89233 m
.20274 .88853 L
s
.51516 .90547 m .51592 .86443 L .51528 .8871 L 0 .492 .266 r
F
.51393 .90166 m .51528 .8871 L .51592 .86443 L 0 .492 .267 r
F
0 g
.51587 .8604 m
.51592 .86443 L
s
.51592 .86443 m
.51684 .85324 L
s
.23727 .83462 m .22569 .83346 L .22806 .83938 L 0 1 .532 r
F
0 g
.22439 .84478 m
.22806 .83938 L
s
.50558 .93295 m .50078 .92509 L .50368 .92931 L 0 .232 .096 r
F
.50656 .93146 m .50368 .92931 L .50078 .92509 L 0 .223 .096 r
F
0 g
.49964 .92409 m
.50078 .92509 L
s
.49921 .92118 m
.50078 .92509 L
s
.5695 .66637 m .583 .65356 L .57981 .65449 L 0 1 .21 r
F
0 g
.583 .65356 m
.58473 .65206 L
s
.49318 .93419 m .48503 .92891 L .4825 .92846 L 0 .561 .414 r
F
0 g
.47931 .92662 m
.4825 .92846 L
s
.4845 .93193 m
.48597 .93204 L
s
.3391 .66808 m
.34188 .67007 L
s
.43166 .78257 m
.43233 .78113 L
s
.43671 .78202 m
.43703 .78208 L
s
.43233 .78113 m
.43671 .78202 L
s
.21159 .92578 m .20119 .92011 L .19873 .92178 L 0 .777 .318 r
F
.21159 .92578 m .20583 .9208 L .20119 .92011 L F
.21159 .92578 m .2103 .92323 L .20583 .9208 L F
.22309 .92692 m .2103 .92323 L .21159 .92578 L 0 .703 .288 r
F
0 g
.20912 .92742 m
.21159 .92578 L
s
.21159 .92578 m
.21599 .92794 L
s
.66433 1.09457 m
.66473 1.09654 L
s
.74079 .60814 m .75975 .61263 L .75741 .60942 L 0 1 .457 r
F
0 g
.75975 .61263 m
.76722 .61527 L
s
.38721 .84583 m .37841 .84663 L .38285 .84809 L 0 1 .483 r
F
0 g
.38285 .84809 m
.38556 .8525 L
s
.28067 .93346 m .2733 .93296 L .27789 .93343 L 0 .511 .21 r
F
.28067 .93346 m .26914 .93202 L .2733 .93296 L F
0 g
.27134 .93318 m
.2733 .93296 L
s
.27789 .93343 m
.28274 .93408 L
s
.47807 .91614 m .46948 .90868 L .46616 .90779 L 0 .769 .443 r
F
0 g
.46341 .90551 m
.46616 .90779 L
s
.45409 .89365 m .45084 .88791 L .44616 .88515 L 0 .973 .461 r
F
.45409 .89365 m .45424 .89155 L .45084 .88791 L F
.46586 .90096 m .45409 .89365 L .45751 .89732 L 0 .886 .45 r
F
.46586 .90096 m .45424 .89155 L .45409 .89365 L F
0 g
.45045 .89346 m
.45409 .89365 L
s
.49092 1.00642 m .48654 1.00988 L .48976 1.0128 L 0 .271 .299 r
F
0 g
.48654 1.00988 m
.48733 1.01473 L
s
.38721 .84583 m .3762 .84191 L .37841 .84663 L 0 1 .483 r
F
0 g
.37442 .84909 m
.37841 .84663 L
s
.56524 .67614 m .56397 .67299 L .5624 .67714 L 0 1 .193 r
F
.56524 .67614 m .5695 .66638 L .56397 .67299 L F
.76248 1.06105 m .77341 1.05465 L .76922 1.05722 L 0 .801 .187 r
F
.75214 1.06776 m .76248 1.06105 L .76294 1.06132 L 0 0 0 r
F
.42156 .86126 m .41273 .85993 L .41734 .86211 L 0 1 .469 r
F
0 g
.41734 .86211 m
.42033 .86622 L
s
.42156 .86126 m .41012 .85552 L .41273 .85993 L 0 1 .469 r
F
0 g
.40875 .86107 m
.41273 .85993 L
s
.41138 .66029 m
.41759 .65786 L
s
.73205 .78891 m
.73472 .80283 L
s
.73472 .80283 m
.73472 .80283 L
s
.33066 .65564 m .33501 .63374 L .32783 .63323 L 0 .408 .33 r
F
.33066 .65564 m .33832 .64343 L .33501 .63374 L F
.33066 .65564 m .33645 .65283 L .33832 .64343 L F
0 g
.33021 .65561 m
.33066 .65564 L
s
.22988 .72919 m .21909 .73132 L .22356 .73248 L 0 1 .538 r
F
0 g
.22356 .73248 m
.22488 .73753 L
s
.28352 .83923 m .27332 .8313 L .27197 .83805 L 0 1 .523 r
F
.28352 .83923 m .27778 .82668 L .27332 .8313 L F
.28352 .83923 m .28237 .82727 L .27778 .82668 L F
.28352 .83923 m .28483 .83266 L .28237 .82727 L F
0 g
.27907 .84383 m
.28352 .83923 L
s
.49101 .92236 m .48363 .9196 L .48798 .92249 L 0 .513 .302 r
F
.49463 .92788 m .49403 .92893 L .49066 .92811 L 0 .2 .082 r
F
.49198 .93008 m .48798 .92249 L .48363 .9196 L 0 .481 .3 r
F
0 g
.48197 .92009 m
.48363 .9196 L
s
.48028 .91483 m
.48363 .9196 L
s
.48251 .9265 m
.48364 .92759 L
s
.22255 .88672 m .21433 .88961 L .21897 .89005 L 0 1 .523 r
F
0 g
.21897 .89005 m
.22327 .89405 L
s
.22255 .88672 m .21094 .88541 L .21433 .88961 L 0 1 .523 r
F
0 g
.21173 .89318 m
.21433 .88961 L
s
.47807 .91614 m .47011 .91271 L .47474 .91524 L 0 .769 .443 r
F
.47884 .91951 m .47474 .91524 L .47011 .91271 L 0 .758 .444 r
F
0 g
.46644 .90952 m
.47011 .91271 L
s
.46985 .91266 m
.47011 .91271 L
s
.40359 .91906 m
.40741 .91973 L
s
.45466 .88843 m .44616 .88515 L .45084 .88791 L 0 .972 .455 r
F
.45466 .88843 m .44301 .88122 L .44616 .88515 L F
0 g
.44252 .88496 m
.44616 .88515 L
s
.49996 .94464 m .49619 .94483 L .49869 .94518 L 0 .394 .374 r
F
.50206 .94729 m .49869 .94518 L .49619 .94483 L 0 .359 .354 r
F
0 g
.49528 .94557 m
.49619 .94483 L
s
.49362 .94365 m
.49619 .94483 L
s
.44301 .88122 m .43578 .87198 L .43191 .87206 L 0 1 .463 r
F
.22569 .83346 m .21645 .83837 L .2211 .83877 L 0 1 .533 r
F
0 g
.2211 .83877 m
.22439 .84478 L
s
.51778 .96684 m .51632 .96549 L .51544 .96502 L 0 .117 .177 r
F
.49801 .942 m .49349 .94167 L .49639 .94231 L 0 .443 .389 r
F
.49996 .94464 m .49639 .94231 L .49349 .94167 L 0 .394 .374 r
F
0 g
.4905 .94017 m
.49349 .94167 L
s
.49276 .94198 m
.49349 .94167 L
s
.44741 .78444 m .43923 .7837 L .4427 .78313 L 0 .114 0 r
F
0 g
.4427 .78313 m
.4427 .78313 L
s
.46586 .90096 m .45751 .89732 L .46223 .90011 L 0 .886 .45 r
F
.4659 .90521 m .46223 .90011 L .45751 .89732 L 0 .883 .455 r
F
0 g
.45405 .89681 m
.45751 .89732 L
s
.45409 .89365 m
.45751 .89732 L
s
.3762 .84191 m .36731 .84327 L .37175 .84457 L 0 1 .487 r
F
0 g
.37175 .84457 m
.37442 .84909 L
s
.48774 .95449 m .47934 .95513 L .48277 .95828 L 0 .408 .308 r
F
0 g
.47789 .95889 m
.47934 .95513 L
s
.51137 .95791 m .50902 .95882 L .51048 .96015 L 0 .22 .222 r
F
.51137 .95791 m .50845 .9573 L .50902 .95882 L F
0 g
.50742 .9582 m
.50902 .95882 L
s
.51637 .90996 m .52 .87873 L .52048 .86115 L 0 .489 .265 r
F
0 g
.52048 .86115 m
.52169 .84993 L
s
.518 .86916 m
.51809 .85431 L
s
.76867 .64959 m .78418 .63204 L .77879 .64574 L 0 .107 .074 r
F
0 g
.78418 .63204 m
.78844 .62584 L
s
.78418 .63204 m
.78457 .6273 L
s
.48534 .94445 m .47971 .94716 L .4833 .94733 L 0 .455 .311 r
F
.48774 .95449 m .4833 .94733 L .47971 .94716 L 0 .408 .308 r
F
0 g
.47801 .9505 m
.47971 .94716 L
s
.47661 .94401 m
.47971 .94716 L
s
.54511 .71838 m .55451 .70513 L .55612 .69822 L 0 1 .348 r
F
0 g
.55431 .71159 m
.55666 .70561 L
s
.54511 .71838 m .54979 .71377 L .55451 .70513 L 0 1 .348 r
F
0 g
.55451 .70513 m
.55666 .70561 L
s
.72648 .65232 m
.72716 .6514 L
s
.50586 .89389 m .50626 .89353 L .50458 .87775 L 0 .508 .281 r
F
0 g
.50624 .89337 m
.50624 .89342 L
s
.50623 .89328 m
.50624 .89337 L
s
.46892 .9278 m .46433 .92902 L .45982 .92778 L 0 .135 .041 r
F
.46892 .9278 m .46823 .92902 L .46433 .92902 L F
.47992 .93144 m .46892 .9278 L .47269 .92796 L 0 .201 .066 r
F
.47992 .93144 m .46823 .92902 L .46892 .9278 L F
0 g
.46617 .92604 m
.46892 .9278 L
s
.46892 .9278 m
.46968 .92783 L
s
.80478 1.03244 m .81555 1.02438 L .8112 1.02662 L 0 1 .344 r
F
.79405 1.03835 m .80478 1.03244 L .80469 1.03019 L 0 1 .29 r
F
.50206 .94729 m .49906 .94797 L .50114 .94804 L 0 .359 .354 r
F
.50427 .94994 m .50114 .94804 L .49906 .94797 L 0 .332 .329 r
F
0 g
.49852 .94891 m
.49906 .94797 L
s
.49674 .94699 m
.49906 .94797 L
s
.44301 .88122 m .44038 .87477 L .43578 .87198 L 0 1 .463 r
F
.44301 .88122 m .44348 .87873 L .44038 .87477 L F
.45466 .88843 m .44348 .87873 L .44301 .88122 L 0 .972 .455 r
F
0 g
.44301 .88122 m
.44616 .88515 L
s
.43914 .8813 m
.44301 .88122 L
s
.49319 .93052 m .48917 .9309 L .48503 .92891 L 0 .217 .083 r
F
.49198 .93008 m .48503 .92891 L .48917 .9309 L 0 .481 .3 r
F
.49319 .93052 m .49268 .93159 L .48917 .9309 L 0 .217 .083 r
F
.49197 .93165 m .48145 .92639 L .48503 .92891 L 0 .588 .418 r
F
.49197 .93165 m .48081 .925 L .48145 .92639 L F
0 g
.47933 .92635 m
.48145 .92639 L
s
.48172 .92476 m
.48291 .92625 L
s
.54067 .62774 m .54737 .6286 L .55321 .63074 L 0 .016 0 r
F
0 g
.54737 .6286 m
.55156 .62731 L
s
.50144 .91236 m .49318 .89535 L .49786 .90568 L 0 .527 .291 r
F
.50131 .91617 m .49786 .90568 L .49318 .89535 L 0 .517 .291 r
F
0 g
.49266 .89453 m
.49318 .89535 L
s
.4898 .88556 m
.49318 .89535 L
s
.49341 1.02334 m .49348 1.02952 L .49463 1.02831 L 0 .236 .286 r
F
.50051 1.03702 m .49463 1.02831 L .49348 1.02952 L 0 .166 .24 r
F
0 g
.49348 1.02952 m
.49511 1.0346 L
s
.49018 1.0263 m
.49348 1.02952 L
s
.50575 .89327 m
.50581 .8936 L
s
.50581 .8936 m
.50582 .89366 L
s
.50493 .89516 m .50529 .89459 L .5033 .87948 L 0 .515 .283 r
F
0 g
.50519 .89381 m
.5052 .89389 L
s
.49622 .93937 m .491 .93849 L .49427 .93944 L 0 .489 .4 r
F
.49801 .942 m .49427 .93944 L .491 .93849 L 0 .443 .389 r
F
0 g
.49021 .93865 m
.491 .93849 L
s
.49051 .93822 m
.491 .93849 L
s
.52374 .931 m .53138 .91402 L .52712 .92407 L 0 .258 .129 r
F
.52425 .93332 m .52712 .92407 L .53138 .91402 L 0 .259 .131 r
F
0 g
.53138 .91402 m
.53484 .9078 L
s
.53138 .91402 m
.53213 .91177 L
s
.50468 .93453 m .49777 .92965 L .49558 .92631 L 0 .242 .097 r
F
0 g
.49523 .9262 m
.49558 .92631 L
s
.48534 .94445 m .48446 .94044 L .48089 .93683 L 0 .455 .311 r
F
.47992 .93144 m .47269 .92796 L .47704 .92941 L 0 .201 .066 r
F
0 g
.47932 .92673 m
.48092 .92795 L
s
.48144 .92835 m .47704 .92941 L .47269 .92796 L 0 .179 .065 r
F
0 g
.47008 .92596 m
.47269 .92796 L
s
.46968 .92783 m
.47269 .92796 L
s
.48077 .92851 m
.48205 .92993 L
s
.3762 .84191 m .36517 .83842 L .36731 .84327 L 0 1 .487 r
F
0 g
.36326 .84608 m
.36731 .84327 L
s
.22569 .83346 m .21411 .83229 L .21645 .83837 L 0 1 .533 r
F
0 g
.21279 .84394 m
.21645 .83837 L
s
.44741 .78444 m .43901 .78589 L .43923 .7837 L 0 .114 0 r
F
.44741 .78444 m .44218 .78826 L .43901 .78589 L F
.44741 .78444 m .44691 .78958 L .44218 .78826 L F
.44741 .78444 m .45003 .78896 L .44691 .78958 L F
.44741 .78444 m .45024 .78676 L .45003 .78896 L F
0 g
.44741 .78444 m
.4479 .7818 L
s
.4427 .78313 m
.44741 .78444 L
s
.23416 .88805 m .22593 .89071 L .23057 .89115 L 0 1 .52 r
F
0 g
.23057 .89115 m
.23482 .89495 L
s
.23416 .88805 m .22255 .88672 L .22593 .89071 L 0 1 .52 r
F
0 g
.22327 .89405 m
.22593 .89071 L
s
.50144 .92438 m .48966 .90424 L .48979 .90722 L 0 .489 .289 r
F
.50144 .92438 m .49308 .90782 L .48966 .90424 L F
0 g
.48914 .90696 m
.48936 .90705 L
s
.48947 .9039 m
.48966 .90424 L
s
.49073 .90536 m
.49198 .90667 L
s
.49023 .90484 m
.49073 .90536 L
s
.48996 .90455 m
.49023 .90484 L
s
.48966 .90424 m
.48996 .90455 L
s
.33711 .7598 m .32756 .75719 L .33156 .75867 L 0 .523 .266 r
F
0 g
.33156 .75867 m
.33258 .76045 L
s
.50687 .89314 m .50729 .893 L .50596 .87665 L 0 .501 .278 r
F
0 g
.50596 .87665 m
.50728 .89284 L
s
.50458 .87775 m
.5062 .89298 L
s
.50458 .87775 m
.50684 .89296 L
s
.5062 .89298 m
.50623 .89328 L
s
.44295 .92727 m .4352 .92471 L .43983 .92578 L 0 .008 0 r
F
.44295 .92727 m .43133 .9244 L .4352 .92471 L F
0 g
.4324 .92343 m
.4352 .92471 L
s
.37187 .91256 m .36325 .90907 L .36017 .90936 L 0 .637 .273 r
F
.37187 .91256 m .36778 .91004 L .36325 .90907 L F
.37187 .91256 m .37148 .91153 L .36778 .91004 L F
.38315 .91463 m .37148 .91153 L .37187 .91256 L 0 .576 .243 r
F
0 g
.36879 .91284 m
.37187 .91256 L
s
.37187 .91256 m
.37554 .91387 L
s
.78365 .79839 m .79691 .79467 L .79521 .79958 L 0 .093 .016 r
F
0 g
.79466 .79008 m
.79691 .79467 L
s
.79691 .79467 m
.80168 .7917 L
s
.50987 .92758 m .5094 .92804 L .50783 .9242 L 0 .207 .095 r
F
0 g
.50934 .92268 m
.51019 .9256 L
s
.34255 .64102 m .34056 .61588 L .33635 .61805 L 0 1 .273 r
F
.45597 .92769 m .44677 .9275 L .44386 .9259 L 0 .08 .01 r
F
0 g
.43983 .92578 m
.44386 .9259 L
s
.43299 .86773 m .42425 .86558 L .42886 .86804 L 0 1 .463 r
F
0 g
.42886 .86804 m
.43191 .87206 L
s
.43299 .86773 m .42156 .86126 L .42425 .86558 L 0 1 .463 r
F
0 g
.42033 .86622 m
.42425 .86558 L
s
.54511 .71838 m .55612 .69822 L .55347 .69658 L 0 1 .348 r
F
0 g
.55211 .70953 m
.55451 .70513 L
s
.55383 .71282 m
.55431 .71159 L
s
.55612 .69822 m
.56102 .68843 L
s
.77739 .61384 m .77976 .60907 L .77575 .60982 L 0 1 .49 r
F
.77739 .61384 m .78759 .61227 L .77976 .60907 L F
0 g
.50475 .8943 m
.50476 .89437 L
s
.50447 .89596 m .50458 .89575 L .50212 .88179 L 0 .524 .286 r
F
0 g
.50212 .88179 m
.50224 .88242 L
s
.50437 .89458 m
.50457 .89567 L
s
.50436 .8945 m
.50437 .89458 L
s
.66948 1.10208 m .67325 1.09222 L .67825 1.09661 L 0 .184 .05 r
F
0 g
.672 1.08794 m
.67325 1.09222 L
s
.66702 1.08998 m
.67325 1.09222 L
s
.75782 .63505 m .76077 .63774 L .7568 .63919 L 0 0 .004 r
F
.75782 .63505 m .76794 .63238 L .76077 .63774 L F
.47997 .92293 m .47947 .92156 L .47571 .91892 L 0 .743 .445 r
F
.54192 .74003 m .5521 .71723 L .54979 .71377 L 0 1 .337 r
F
0 g
.55091 .73378 m
.55234 .7294 L
s
.54192 .74003 m .55051 .72645 L .5521 .71723 L 0 1 .337 r
F
0 g
.55038 .73541 m
.55091 .73378 L
s
.55074 .72683 m
.55234 .7294 L
s
.5521 .71723 m
.55383 .71282 L
s
.55002 .71411 m
.5521 .71723 L
s
.50422 .89468 m
.50423 .89475 L
s
.50423 .89475 m
.50439 .89554 L
s
.50439 .89554 m
.50445 .89582 L
s
.50385 .89752 m .50416 .89672 L .50178 .8826 L 0 .524 .286 r
F
0 g
.50181 .88274 m
.50182 .88281 L
s
.50178 .8826 m
.50181 .88274 L
s
.50401 .89581 m
.50405 .89605 L
s
.50385 .89488 m
.50401 .89581 L
s
.50384 .8948 m
.50385 .89488 L
s
.50383 .89474 m
.50384 .8948 L
s
.50178 .8826 m
.50182 .88278 L
s
.50357 .88867 m
.50475 .8943 L
s
.50212 .88179 m
.50243 .88325 L
s
.50344 .88924 m
.50436 .8945 L
s
.50224 .88242 m
.50242 .88346 L
s
.31231 .63431 m .30072 .63694 L .30454 .63946 L 0 1 .466 r
F
0 g
.30324 .64659 m
.30454 .63946 L
s
.22988 .72919 m .21881 .72599 L .21909 .73132 L 0 1 .538 r
F
0 g
.21364 .73492 m
.21909 .73132 L
s
.4946 .93677 m .48875 .9353 L .49234 .93658 L 0 .528 .408 r
F
.49622 .93937 m .49234 .93658 L .48875 .9353 L 0 .489 .4 r
F
.49317 .93786 m .48249 .93042 L .48324 .93443 L 0 .447 .298 r
F
.49318 .93419 m .48675 .93211 L .49064 .93373 L 0 .561 .414 r
F
.4946 .93677 m .49064 .93373 L .48675 .93211 L 0 .528 .408 r
F
.49317 .93786 m .48503 .92891 L .48249 .93042 L 0 .447 .298 r
F
0 g
.48205 .92993 m
.48249 .93042 L
s
.48326 .92985 m
.48335 .92991 L
s
.53137 .97855 m
.53143 .97858 L
s
.53081 .97824 m
.53137 .97855 L
s
.5303 .97795 m
.53081 .97824 L
s
.53482 .98225 m .53303 .9805 L .53307 .97951 L 0 .152 0 r
F
0 g
.53303 .9805 m
.53304 .98036 L
s
.53304 .98036 m
.53307 .97951 L
s
.53143 .97858 m
.53307 .97951 L
s
.51137 .95791 m .51048 .96015 L .51173 .96041 L 0 .22 .222 r
F
0 g
.51048 .96015 m
.51141 .96159 L
s
.49197 .93165 m .4836 .92574 L .48081 .925 L 0 .588 .418 r
F
0 g
.48249 .93042 m
.48327 .92996 L
s
.47708 .92262 m
.48081 .925 L
s
.48145 .92639 m
.4831 .92755 L
s
.36517 .83842 m .35652 .84037 L .36078 .84147 L 0 1 .491 r
F
0 g
.36078 .84147 m
.36326 .84608 L
s
.624 .70344 m
.6241 .70365 L
s
.50427 .94994 m .50209 .95109 L .50372 .95089 L 0 .332 .329 r
F
.50657 .9526 m .50372 .95089 L .50209 .95109 L 0 .301 .298 r
F
0 g
.50191 .95223 m
.50209 .95109 L
s
.49986 .95024 m
.50209 .95109 L
s
.50689 1.05434 m .50349 1.04863 L .50043 1.04503 L 0 .083 .178 r
F
.21411 .83229 m .20484 .83735 L .20949 .83776 L 0 1 .534 r
F
0 g
.20949 .83776 m
.21279 .84394 L
s
.24576 .8894 m .23752 .89183 L .24216 .89229 L 0 1 .517 r
F
0 g
.24216 .89229 m
.24637 .89588 L
s
.24576 .8894 m .23416 .88805 L .23752 .89183 L 0 1 .517 r
F
0 g
.23482 .89495 m
.23752 .89183 L
s
.52464 .93596 m .53573 .91242 L .53602 .91458 L 0 .26 .133 r
F
.52464 .93596 m .53219 .91776 L .53573 .91242 L F
0 g
.53573 .91242 m
.53622 .91055 L
s
.53533 .91303 m
.53573 .91242 L
s
.50795 .89296 m .50839 .89305 L .50741 .87625 L 0 .496 .276 r
F
0 g
.50596 .87665 m
.50792 .89276 L
s
.50792 .89276 m
.50794 .89287 L
s
.34364 .60376 m .35446 .5786 L .35132 .57825 L 0 1 .389 r
F
0 g
.35446 .5786 m
.36291 .57101 L
s
.35116 .58953 m
.35446 .5786 L
s
.52239 .92732 m .52206 .92675 L .5244 .91825 L 0 .256 .123 r
F
0 g
.52214 .92648 m
.52241 .9255 L
s
.52435 .91843 m
.5244 .91825 L
s
.5238 .92042 m
.52435 .91843 L
s
.52435 .91838 m
.5244 .91825 L
s
.52374 .92004 m
.52435 .91838 L
s
.66049 .86195 m
.66059 .86192 L
s
.22309 .92692 m .2128 .92184 L .2103 .92323 L 0 .703 .288 r
F
.22309 .92692 m .21745 .92255 L .2128 .92184 L F
.22309 .92692 m .22186 .92473 L .21745 .92255 L F
.23459 .92812 m .22186 .92473 L .22309 .92692 L 0 .663 .259 r
F
0 g
.22057 .9283 m
.22309 .92692 L
s
.22309 .92692 m
.22744 .92884 L
s
.52661 .97478 m
.52668 .97484 L
s
.52668 .97484 m
.5268 .97494 L
s
.5268 .97494 m
.52844 .9763 L
s
.5262 .97444 m
.52661 .97478 L
s
.52616 .9744 m
.5262 .97444 L
s
.68698 1.09143 m .69717 1.09009 L .69361 1.09229 L 0 .014 .006 r
F
.67825 1.09661 m .68698 1.09143 L .68826 1.09573 L 0 .105 .03 r
F
.46586 .90096 m .45787 .89239 L .45424 .89155 L 0 .886 .45 r
F
0 g
.45084 .88791 m
.45424 .89155 L
s
.34364 .60376 m .33199 .61026 L .33542 .61265 L 0 1 .389 r
F
.34364 .60376 m .33528 .59932 L .33199 .61026 L F
.34364 .60376 m .3431 .58713 L .33528 .59932 L F
.34364 .60376 m .35132 .57825 L .3431 .58713 L F
0 g
.34057 .61587 m
.34364 .60376 L
s
.33542 .61265 m
.34364 .60376 L
s
.27197 .83805 m .2618 .82997 L .26041 .83689 L 0 1 .526 r
F
.27197 .83805 m .26629 .8252 L .2618 .82997 L F
.27197 .83805 m .27088 .82579 L .26629 .8252 L F
.27197 .83805 m .27332 .8313 L .27088 .82579 L F
0 g
.26749 .84279 m
.27197 .83805 L
s
.27197 .83805 m
.27444 .84341 L
s
.26762 .63982 m .25751 .63604 L .25573 .64358 L 0 1 .51 r
F
0 g
.24865 .64874 m
.25573 .64358 L
s
.31651 .70433 m
.31658 .69684 L
s
.30948 .71185 m
.31651 .70433 L
s
.42017 .77959 m .41115 .77787 L .41504 .77809 L 0 0 0 r
F
0 g
.41504 .77809 m
.41603 .77719 L
s
.77256 1.05256 m .77341 1.05465 L .77944 1.04943 L 0 .938 .212 r
F
.77256 1.05256 m .76922 1.05722 L .77341 1.05465 L F
0 g
.77279 1.05513 m
.77341 1.05465 L
s
.52551 1.08582 m .52264 1.08022 L .52701 1.08603 L 0 .193 0 r
F
.52551 1.08582 m .51916 1.07566 L .52264 1.08022 L F
0 g
.51956 1.07589 m
.52264 1.08022 L
s
.77809 .62975 m .79428 .62363 L .78827 .62713 L 0 0 0 r
F
0 g
.79428 .62363 m
.79559 .62127 L
s
.46735 .93088 m .45982 .92778 L .46433 .92902 L 0 .161 .042 r
F
.46735 .93088 m .45597 .92769 L .45982 .92778 L F
0 g
.45708 .92603 m
.45982 .92778 L
s
.36517 .83842 m .3546 .83545 L .35652 .84037 L 0 1 .491 r
F
0 g
.35257 .84353 m
.35652 .84037 L
s
.54067 .62774 m .53676 .62946 L .53612 .62811 L 0 .016 0 r
F
.54067 .62774 m .54261 .6316 L .53676 .62946 L F
.54067 .62774 m .54977 .6331 L .54261 .6316 L F
.54067 .62774 m .55432 .63272 L .54977 .6331 L F
0 g
.55491 .63075 m
.55727 .63077 L
s
.54067 .62774 m .55321 .63074 L .55432 .63272 L 0 .016 0 r
F
0 g
.55321 .63074 m
.55491 .63075 L
s
.53518 .62573 m
.54067 .62774 L
s
.54737 .6286 m
.55321 .63074 L
s
.39355 .77429 m .38377 .77266 L .38431 .7722 L 0 0 0 r
F
0 g
.37929 .77117 m
.38431 .7722 L
s
.4659 .90521 m .46582 .9035 L .46223 .90011 L 0 .883 .455 r
F
.47767 .91284 m .4659 .90521 L .46948 .90868 L 0 .776 .44 r
F
.47767 .91284 m .46582 .9035 L .4659 .90521 L F
0 g
.46616 .90779 m
.46941 .90866 L
s
.46243 .90469 m
.4659 .90521 L
s
.69576 .61041 m .71437 .6115 L .71169 .6093 L 0 1 .399 r
F
0 g
.71437 .6115 m
.72188 .61255 L
s
.39867 .8504 m .38859 .84134 L .38722 .84583 L 0 1 .479 r
F
.39867 .8504 m .393 .83954 L .38859 .84134 L F
0 g
.38722 .84583 m
.38965 .85047 L
s
.39867 .8504 m .3975 .84164 L .393 .83954 L 0 1 .479 r
F
.39867 .8504 m .39993 .84629 L .3975 .84164 L F
.41012 .85552 m .39993 .84629 L .39867 .8504 L 0 1 .474 r
F
0 g
.39867 .8504 m
.40119 .85492 L
s
.39427 .85219 m
.39867 .8504 L
s
.21411 .83229 m .20252 .8311 L .20484 .83735 L 0 1 .534 r
F
0 g
.20119 .84309 m
.20484 .83735 L
s
.49101 .92236 m .49069 .9193 L .48706 .91414 L 0 .513 .302 r
F
0 g
.48706 .91414 m
.4893 .91733 L
s
.48706 .91414 m
.48956 .91461 L
s
.50144 .92438 m .48979 .90722 L .49335 .9143 L 0 .489 .289 r
F
0 g
.48979 .90722 m
.4899 .90744 L
s
.4899 .90744 m
.48998 .90761 L
s
.48998 .90761 m
.49051 .90865 L
s
.49051 .90865 m
.49141 .91043 L
s
.48927 .91046 m
.48957 .91095 L
s
.48957 .91095 m
.48986 .91141 L
s
.48936 .90705 m
.48979 .90722 L
s
.36919 .67459 m .36208 .67561 L .36543 .67508 L 0 0 0 r
F
.36919 .67459 m .36085 .67663 L .36208 .67561 L F
.36919 .67459 m .36258 .67747 L .36085 .67663 L F
.36919 .67459 m .36636 .67697 L .36258 .67747 L F
0 g
.36427 .67508 m
.36542 .67508 L
s
.36542 .67508 m
.36543 .67508 L
s
.36919 .67459 m .36964 .67548 L .36636 .67697 L 0 0 0 r
F
.36919 .67459 m .37085 .67446 L .36964 .67548 L F
0 g
.36543 .67508 m
.36919 .67459 L
s
.41012 .85552 m .40425 .84495 L .39993 .84629 L 0 1 .474 r
F
.41012 .85552 m .40875 .84728 L .40425 .84495 L F
.41012 .85552 m .41126 .85181 L .40875 .84728 L F
.42156 .86126 m .41126 .85181 L .41012 .85552 L 0 1 .469 r
F
0 g
.40581 .85685 m
.41012 .85552 L
s
.41012 .85552 m
.41273 .85993 L
s
.50368 .89684 m
.50371 .89698 L
s
.50315 .89981 m .50342 .89884 L .50078 .88553 L 0 .53 .288 r
F
0 g
.50078 .88553 m
.50114 .88734 L
s
.50286 .89604 m
.5033 .89823 L
s
.50078 .88553 m
.50111 .88682 L
s
.50334 .89554 m
.50368 .89684 L
s
.5033 .89536 m
.50334 .89554 L
s
.50242 .88346 m
.503 .88675 L
s
.503 .88675 m
.50344 .88924 L
s
.50243 .88325 m
.50307 .88627 L
s
.50307 .88627 m
.50357 .88867 L
s
.5033 .87948 m
.50575 .89327 L
s
.5033 .87948 m
.50519 .89381 L
s
.50303 .88877 m
.50422 .89468 L
s
.50251 .88619 m
.50303 .88877 L
s
.50182 .88278 m
.50251 .88619 L
s
.50294 .88948 m
.50383 .89474 L
s
.50182 .88281 m
.50248 .88673 L
s
.46486 .78962 m
.46893 .78959 L
s
.25737 .8908 m .24912 .89299 L .25376 .89347 L 0 1 .513 r
F
0 g
.25376 .89347 m
.25792 .89685 L
s
.25737 .8908 m .24576 .8894 L .24912 .89299 L 0 1 .513 r
F
0 g
.24637 .89588 m
.24912 .89299 L
s
.33711 .7598 m .32724 .75577 L .32756 .75719 L 0 .523 .266 r
F
0 g
.32246 .75706 m
.32756 .75719 L
s
.48191 .79348 m .47594 .79668 L .47822 .79363 L 0 .312 .073 r
F
.48191 .79348 m .47655 .80158 L .47594 .79668 L F
.48191 .79348 m .47966 .80505 L .47655 .80158 L F
0 g
.47804 .78946 m
.47822 .79363 L
s
.48191 .79348 m .48337 .8049 L .47966 .80505 L 0 .312 .073 r
F
.48191 .79348 m .4852 .80123 L .48337 .8049 L F
.48191 .79348 m .48457 .79634 L .4852 .80123 L F
0 g
.48457 .79634 m
.48794 .79449 L
s
.48168 .78899 m
.48191 .79348 L
s
.47822 .79363 m
.48191 .79348 L
s
.25197 .73595 m .24477 .72736 L .24093 .73251 L 0 1 .532 r
F
.25197 .73595 m .25089 .72475 L .24477 .72736 L F
.25197 .73595 m .2552 .72645 L .25089 .72475 L F
.25197 .73595 m .25566 .73125 L .2552 .72645 L F
0 g
.24587 .73853 m
.25197 .73595 L
s
.25197 .73595 m
.25255 .74041 L
s
.48144 .92835 m .48079 .92958 L .47704 .92941 L 0 .179 .065 r
F
.49318 .93419 m .48917 .9309 L .48503 .92891 L 0 .561 .414 r
F
.49622 .93937 m .49555 .93833 L .49234 .93658 L 0 .489 .4 r
F
.4946 .93677 m .49401 .93573 L .49064 .93373 L 0 .528 .408 r
F
.49317 .93786 m .48917 .9309 L .48503 .92891 L 0 .447 .298 r
F
.49317 .93786 m .49267 .93474 L .48917 .9309 L F
.49197 .93322 m .48144 .92835 L .48503 .92891 L 0 .234 .084 r
F
.49197 .93322 m .48079 .92958 L .48144 .92835 L F
0 g
.48092 .92795 m
.48144 .92835 L
s
.38721 .84583 m .37769 .83707 L .3762 .84191 L 0 1 .483 r
F
.38721 .84583 m .38205 .8348 L .37769 .83707 L F
.38721 .84583 m .38638 .83661 L .38205 .8348 L F
.38721 .84583 m .38859 .84134 L .38638 .83661 L F
0 g
.38285 .84809 m
.38721 .84583 L
s
.63178 .53339 m .64122 .54552 L .64976 .55616 L 0 0 .149 r
F
.6498 .55619 m .64976 .55616 L .65031 .55684 L F
.63178 .53339 m .64976 .55616 L .6498 .55619 L F
.64796 .55726 m .655 .56676 L .64771 .5542 L 0 .034 .169 r
F
.64675 .5533 m .64771 .5542 L .64628 .55174 L F
.64796 .55726 m .64771 .5542 L .64675 .5533 L F
0 g
.64424 .54929 m
.64568 .55237 L
s
.64286 .54756 m
.64532 .55223 L
s
.64796 .55726 m .66394 .58296 L .655 .56676 L 0 .034 .169 r
F
.64796 .55726 m .66832 .59234 L .66394 .58296 L F
.64796 .55726 m .6652 .58863 L .66832 .59234 L F
.64796 .55726 m .65648 .57359 L .6652 .58863 L F
0 g
.64568 .55237 m
.64796 .55726 L
s
.64532 .55223 m
.64796 .55726 L
s
.54435 1.10426 m .55032 1.10653 L .54898 1.10778 L 0 .282 0 r
F
.5562 1.11998 m .55032 1.10653 L .55518 1.10998 L 0 .352 .029 r
F
.5562 1.11998 m .54898 1.10778 L .55032 1.10653 L F
0 g
.55228 1.10456 m
.55518 1.10998 L
s
.54735 1.10154 m
.55032 1.10653 L
s
.55032 1.10653 m
.55518 1.10998 L
s
.55518 1.10998 m
.55518 1.10998 L
s
.72843 .67897 m
.7285 .67073 L
s
.7285 .67073 m
.72851 .66902 L
s
.72851 .66902 m
.72852 .66836 L
s
.72635 .67647 m
.72766 .67156 L
s
.72766 .67156 m
.72829 .66922 L
s
.72829 .66922 m
.72852 .66836 L
s
.6989 1.09947 m .69717 1.09009 L .7034 1.08997 L 0 0 .024 r
F
.6989 1.09947 m .69361 1.09229 L .69717 1.09009 L F
0 g
.69568 1.08664 m
.69717 1.09009 L
s
.51575 1.07082 m .51916 1.07566 L .51889 1.07539 L 0 0 .152 r
F
0 g
.51607 1.07168 m
.51847 1.07478 L
s
.52551 1.08582 m .51889 1.07539 L .51916 1.07566 L 0 .193 0 r
F
0 g
.51916 1.07566 m
.52264 1.08022 L
s
.49098 .92916 m .47997 .92293 L .4836 .92574 L 0 .609 .42 r
F
.49098 .92916 m .47947 .92156 L .47997 .92293 L F
0 g
.47708 .92262 m
.47997 .92293 L
s
.4831 .92755 m
.48426 .92837 L
s
.4825 .92846 m
.48432 .92879 L
s
.48432 .92879 m
.4846 .92884 L
s
.48144 .92835 m
.48229 .92848 L
s
.73132 .61039 m .74764 .61136 L .74079 .60814 L 0 1 .43 r
F
0 g
.74764 .61136 m
.74978 .61422 L
s
.74764 .61136 m
.75576 .61328 L
s
.50908 .89337 m .50955 .89372 L .50892 .87661 L 0 .492 .273 r
F
.45675 .64159 m .44894 .64348 L .45064 .64341 L 0 .839 .222 r
F
.45675 .64159 m .45283 .64177 L .44894 .64348 L F
0 g
.44729 .6454 m
.45064 .64341 L
s
.45675 .64159 m .45971 .63943 L .45283 .64177 L 0 .839 .222 r
F
.45675 .64159 m .46583 .6376 L .45971 .63943 L F
.45675 .64159 m .46708 .6375 L .46583 .6376 L F
.45675 .64159 m .46319 .63921 L .46708 .6375 L F
0 g
.45319 .6432 m
.45675 .64159 L
s
.45064 .64341 m
.45675 .64159 L
s
.46319 .63921 m
.46896 .63722 L
s
.42156 .86126 m .41549 .85096 L .41126 .85181 L 0 1 .469 r
F
.42156 .86126 m .41998 .85355 L .41549 .85096 L F
.42156 .86126 m .42258 .85796 L .41998 .85355 L F
.43299 .86773 m .42258 .85796 L .42156 .86126 L 0 1 .463 r
F
0 g
.41734 .86211 m
.42156 .86126 L
s
.42156 .86126 m
.42425 .86558 L
s
.3546 .83545 m .34587 .83783 L .35013 .83881 L 0 1 .495 r
F
0 g
.35013 .83881 m
.35257 .84353 L
s
.20252 .8311 m .19323 .83631 L .19787 .83673 L 0 1 .534 r
F
0 g
.19787 .83673 m
.20119 .84309 L
s
.50657 .9526 m .50523 .95419 L .50639 .95374 L 0 .301 .298 r
F
.50895 .95525 m .50639 .95374 L .50523 .95419 L 0 .264 .262 r
F
0 g
.50523 .95419 m
.50543 .95553 L
s
.50331 .95355 m
.50523 .95419 L
s
.32783 .63323 m
.3299 .62389 L
s
.45466 .88843 m .4473 .87925 L .44348 .87873 L 0 .972 .455 r
F
.54192 .74003 m .54615 .73622 L .55051 .72645 L 0 1 .337 r
F
0 g
.55051 .72645 m
.55074 .72683 L
s
.61649 .68556 m
.61714 .68745 L
s
.61732 .68799 m .61785 .68895 L .61838 .68797 L 0 0 .138 r
F
.61785 .68895 m .61984 .69106 L .61838 .68797 L F
.60995 .67562 m .62197 .69332 L .62283 .69405 L F
.62197 .69332 m .62552 .69855 L .62313 .69455 L F
.62197 .69332 m .62313 .69455 L .62283 .69405 L F
.61785 .68895 m .62475 .70143 L .61984 .69106 L F
.61732 .68799 m .63218 .71941 L .63038 .71414 L F
.61732 .68799 m .62895 .71374 L .63218 .71941 L F
0 g
.62634 .7188 m
.63129 .73362 L
s
.61732 .68799 m .62258 .70028 L .62895 .71374 L 0 0 .138 r
F
0 g
.6161 .68506 m
.61732 .68799 L
s
.62299 .70118 m
.6232 .70165 L
s
.62258 .70028 m
.62285 .70087 L
s
.62285 .70087 m
.62299 .70118 L
s
.61714 .68745 m
.61732 .68799 L
s
.6232 .70165 m
.624 .70344 L
s
.6241 .70365 m
.62479 .70574 L
s
.62529 .70722 m
.62593 .70913 L
s
.62479 .70574 m
.62529 .70722 L
s
.44442 .87502 m .43578 .87198 L .44038 .87477 L 0 1 .457 r
F
.44442 .87502 m .43299 .86773 L .43578 .87198 L F
0 g
.43191 .87206 m
.43578 .87198 L
s
.44038 .87477 m
.44348 .87873 L
s
.37085 .67446 m
.37455 .67385 L
s
.31231 .63431 m .30297 .62806 L .30072 .63694 L 0 1 .466 r
F
0 g
.29351 .64081 m
.30072 .63694 L
s
.31231 .63431 m .3098 .61873 L .30297 .62806 L 0 1 .466 r
F
.31231 .63431 m .31759 .61357 L .3098 .61873 L F
.31231 .63431 m .32112 .61603 L .31759 .61357 L F
.31231 .63431 m .31886 .62492 L .32112 .61603 L F
0 g
.31025 .64363 m
.31231 .63431 L
s
.30454 .63946 m
.31231 .63431 L
s
.45597 .92769 m .4514 .92872 L .44677 .9275 L 0 .08 .01 r
F
.45597 .92769 m .45535 .9288 L .4514 .92872 L F
.46735 .93088 m .45535 .9288 L .45597 .92769 L 0 .161 .042 r
F
0 g
.45306 .9261 m
.45597 .92769 L
s
.45597 .92769 m
.45982 .92778 L
s
.26898 .89223 m .26072 .89419 L .26536 .89468 L 0 1 .508 r
F
0 g
.26536 .89468 m
.26947 .89787 L
s
.26898 .89223 m .25737 .8908 L .26072 .89419 L 0 1 .508 r
F
0 g
.25792 .89685 m
.26072 .89419 L
s
.82662 .87675 m .8382 .87513 L .83512 .87171 L 0 1 .509 r
F
.54832 .70131 m .55849 .68919 L .56005 .68408 L 0 1 .356 r
F
.54832 .70131 m .55347 .69657 L .55849 .68919 L F
0 g
.55849 .68919 m
.56102 .68843 L
s
.51381 .96057 m .51267 .96214 L .51413 .96347 L 0 .171 .198 r
F
.51381 .96057 m .51173 .96041 L .51267 .96214 L F
0 g
.51141 .96159 m
.51267 .96214 L
s
.49317 .93786 m .48324 .93443 L .48672 .93826 L 0 .447 .298 r
F
0 g
.48324 .93443 m
.4835 .93471 L
s
.48089 .93683 m
.48324 .93443 L
s
.48089 .93683 m
.48096 .9369 L
s
.48096 .9369 m
.48393 .9399 L
s
.82413 1.01 m .83203 1.01198 L .83521 1.00434 L 0 1 .438 r
F
0 g
.8264 1.01919 m
.83203 1.01198 L
s
.50131 .91617 m .49302 .90149 L .49774 .91054 L 0 .517 .291 r
F
.50131 .92019 m .49774 .91054 L .49302 .90149 L 0 .505 .29 r
F
0 g
.49219 .90041 m
.49302 .90149 L
s
.49237 .89982 m
.49302 .90149 L
s
.50255 .90247 m .50277 .90136 L .4999 .88888 L 0 .534 .289 r
F
0 g
.50238 .89722 m
.50244 .89741 L
s
.5027 .8983 m
.50292 .89905 L
s
.50244 .89741 m
.5027 .8983 L
s
.50248 .88673 m
.50294 .88948 L
s
.5598 .81948 m
.56386 .82919 L
s
.49093 .98997 m .48331 .98861 L .48543 .99368 L 0 .295 .3 r
F
.49093 .98997 m .48359 .98391 L .48331 .98861 L F
0 g
.47986 .98554 m
.48331 .98861 L
s
.65657 .75343 m
.65796 .74501 L
s
.65796 .74501 m
.65864 .74093 L
s
.65864 .74093 m
.65977 .73406 L
s
.50051 1.03702 m .49844 1.04017 L .50146 1.04339 L 0 .166 .24 r
F
0 g
.49844 1.04017 m
.50043 1.04503 L
s
.20252 .8311 m .19092 .82988 L .19323 .83631 L 0 1 .534 r
F
0 g
.18959 .84223 m
.19323 .83631 L
s
.39355 .77429 m .38705 .77393 L .38377 .77266 L 0 0 0 r
F
0 g
.38377 .77266 m
.38431 .7722 L
s
.39355 .77429 m .39233 .77538 L .38705 .77393 L 0 0 0 r
F
.39355 .77429 m .39607 .77605 L .39233 .77538 L F
.39355 .77429 m .39659 .77558 L .39607 .77605 L F
0 g
.39355 .77429 m
.39426 .77362 L
s
.38829 .77284 m
.39355 .77429 L
s
.21881 .72599 m .2079 .72848 L .21238 .7296 L 0 1 .539 r
F
0 g
.21238 .7296 m
.21364 .73492 L
s
.3762 .84191 m .36677 .83325 L .36517 .83842 L 0 1 .487 r
F
.3762 .84191 m .37122 .83058 L .36677 .83325 L F
0 g
.36517 .83842 m
.36731 .84327 L
s
.3762 .84191 m .37556 .83221 L .37122 .83058 L 0 1 .487 r
F
.3762 .84191 m .37769 .83707 L .37556 .83221 L F
0 g
.37175 .84457 m
.3762 .84191 L
s
.3762 .84191 m
.37841 .84663 L
s
.68715 .61343 m .70272 .612 L .69576 .61041 L 0 1 .366 r
F
0 g
.70272 .612 m
.71069 .61247 L
s
.70272 .612 m
.70517 .6139 L
s
.3546 .83545 m .34402 .83281 L .34587 .83783 L 0 1 .495 r
F
0 g
.34187 .84127 m
.34587 .83783 L
s
.47767 .91284 m .46948 .90868 L .47418 .91161 L 0 .776 .44 r
F
.47807 .91614 m .47418 .91161 L .46948 .90868 L 0 .769 .443 r
F
0 g
.46941 .90866 m
.46948 .90868 L
s
.4659 .90521 m
.46948 .90868 L
s
.50872 .92877 m .50827 .92927 L .50637 .92582 L 0 .21 .095 r
F
0 g
.50637 .92582 m
.5071 .92715 L
s
.50783 .9242 m
.50849 .92758 L
s
.50783 .9242 m
.50893 .92689 L
s
.26041 .83689 m .25027 .82865 L .24885 .83576 L 0 1 .528 r
F
.26041 .83689 m .25479 .82374 L .25027 .82865 L F
.26041 .83689 m .25939 .82432 L .25479 .82374 L F
.26041 .83689 m .2618 .82997 L .25939 .82432 L F
0 g
.2559 .84177 m
.26041 .83689 L
s
.26041 .83689 m
.26285 .84238 L
s
.47767 .91284 m .4693 .90472 L .46582 .9035 L 0 .776 .44 r
F
0 g
.46223 .90011 m
.46582 .9035 L
s
.67305 .6295 m
.6745 .63393 L
s
.6709 .62291 m
.67305 .6295 L
s
.6745 .63393 m
.67647 .63995 L
s
.66932 .61594 m
.67 .61895 L
s
.66918 .61534 m
.66932 .61594 L
s
.67 .61895 m
.6709 .62291 L
s
.43133 .9244 m .42214 .9234 L .41909 .92223 L 0 0 0 r
F
.43133 .9244 m .42684 .92462 L .42214 .9234 L F
.43133 .9244 m .43078 .92505 L .42684 .92462 L F
.44295 .92727 m .43078 .92505 L .43133 .9244 L 0 .008 0 r
F
0 g
.43133 .9244 m
.4352 .92471 L
s
.42827 .92323 m
.43133 .9244 L
s
.49098 .92916 m .48249 .9226 L .47947 .92156 L 0 .609 .42 r
F
0 g
.47571 .91892 m
.47947 .92156 L
s
.48494 .9289 m
.48494 .9289 L
s
.48489 .92889 m
.48494 .9289 L
s
.4848 .92888 m
.48489 .92889 L
s
.48422 .92879 m
.48466 .92885 L
s
.48466 .92885 m
.48478 .92888 L
s
.48478 .92888 m
.4848 .92888 L
s
.48401 .92875 m
.48422 .92879 L
s
.48229 .92848 m
.48401 .92875 L
s
.4846 .92884 m
.48491 .92889 L
s
.48426 .92837 m
.48456 .92859 L
s
.48456 .92859 m
.4848 .92875 L
s
.4848 .92875 m
.48481 .92876 L
s
.48491 .92889 m
.48495 .9289 L
s
.48081 .925 m
.483 .92558 L
s
.26762 .63982 m .26403 .62741 L .25751 .63604 L 0 1 .51 r
F
.26762 .63982 m .27183 .62218 L .26403 .62741 L F
.26762 .63982 m .27571 .62385 L .27183 .62218 L F
.26762 .63982 m .27389 .63142 L .27571 .62385 L F
0 g
.266 .64727 m
.26762 .63982 L
s
.25984 .64502 m
.26762 .63982 L
s
.49041 .96456 m .48143 .96208 L .48289 .96671 L 0 .358 .302 r
F
.49041 .96456 m .48277 .95828 L .48143 .96208 L F
0 g
.47789 .95889 m
.48143 .96208 L
s
.52376 .62716 m .53055 .62712 L .53612 .62811 L 0 0 0 r
F
0 g
.53055 .62712 m
.53518 .62573 L
s
.82662 .87675 m .83512 .87171 L .83047 .87248 L 0 1 .509 r
F
.81505 .87842 m .82662 .87675 L .82351 .87365 L 0 1 .499 r
F
.23459 .92812 m .22443 .92362 L .22186 .92473 L 0 .663 .259 r
F
.23459 .92812 m .22908 .92434 L .22443 .92362 L F
.23459 .92812 m .23344 .92627 L .22908 .92434 L F
.2461 .92936 m .23344 .92627 L .23459 .92812 L 0 .636 .249 r
F
0 g
.23202 .92921 m
.23459 .92812 L
s
.23459 .92812 m
.23889 .92979 L
s
.50468 .93453 m .4992 .92735 L .50247 .93117 L 0 .242 .097 r
F
.50558 .93295 m .50247 .93117 L .4992 .92735 L 0 .232 .096 r
F
0 g
.49766 .92626 m
.4992 .92735 L
s
.49732 .92372 m
.4992 .92735 L
s
.38315 .91463 m .37459 .91157 L .37148 .91153 L 0 .576 .243 r
F
.38315 .91463 m .37913 .91263 L .37459 .91157 L F
.38315 .91463 m .3828 .91395 L .37913 .91263 L F
0 g
.38004 .9146 m
.38315 .91463 L
s
.39491 .91706 m .3828 .91395 L .38315 .91463 L 0 .486 .217 r
F
0 g
.38315 .91463 m
.38693 .91579 L
s
.48677 .97831 m .48518 .97367 L .48182 .97079 L 0 .334 .311 r
F
.47884 .91951 m .47848 .91815 L .47474 .91524 L 0 .758 .444 r
F
0 g
.47474 .91524 m
.47727 .9172 L
s
.28059 .89373 m .27232 .89544 L .27696 .89596 L 0 1 .503 r
F
0 g
.27696 .89596 m
.28103 .89894 L
s
.28059 .89373 m .26898 .89223 L .27232 .89544 L 0 1 .503 r
F
0 g
.26947 .89787 m
.27232 .89544 L
s
.34699 .76328 m .34053 .75983 L .33711 .7598 L 0 .501 .237 r
F
.34699 .76328 m .34597 .76103 L .34053 .75983 L F
.34699 .76328 m .34979 .76262 L .34597 .76103 L F
.34699 .76328 m .35022 .76358 L .34979 .76262 L F
0 g
.34157 .76207 m
.34699 .76328 L
s
.34699 .76328 m
.34758 .76389 L
s
.50386 .93618 m .49463 .92788 L .49777 .92965 L 0 .253 .098 r
F
.50386 .93618 m .49403 .92893 L .49463 .92788 L F
0 g
.49412 .9273 m
.49463 .92788 L
s
.49092 1.00642 m .48869 1.00131 L .48547 .9984 L 0 .271 .299 r
F
.50168 .92873 m .49005 .91171 L .49028 .91474 L 0 .47 .288 r
F
.50168 .92873 m .49335 .9143 L .49005 .91171 L F
0 g
.49141 .91043 m
.49225 .91211 L
s
.48956 .91461 m
.48964 .91462 L
s
.48986 .91141 m
.49005 .91171 L
s
.49157 .9129 m
.49201 .91325 L
s
.49083 .91232 m
.49157 .9129 L
s
.49036 .91195 m
.49083 .91232 L
s
.49005 .91171 m
.49036 .91195 L
s
.43299 .86773 m .42671 .85764 L .42258 .85796 L 0 1 .463 r
F
.43299 .86773 m .4312 .86052 L .42671 .85764 L F
.43299 .86773 m .43389 .86484 L .4312 .86052 L F
.44442 .87502 m .43389 .86484 L .43299 .86773 L 0 1 .457 r
F
0 g
.43299 .86773 m
.43578 .87198 L
s
.42886 .86804 m
.43299 .86773 L
s
.49197 .93322 m .48503 .92891 L .48917 .9309 L 0 .234 .084 r
F
.49197 .93165 m .48503 .92891 L .48917 .9309 L 0 .588 .418 r
F
0 g
.48494 .9289 m
.48503 .92891 L
s
.48481 .92876 m
.48503 .92891 L
s
.48495 .9289 m
.48503 .92891 L
s
.54132 1.10625 m .53952 1.09833 L .54435 1.10426 L 0 .325 0 r
F
.54132 1.10625 m .53525 1.09425 L .53952 1.09833 L F
0 g
.53657 1.09335 m
.53952 1.09833 L
s
.68715 .61343 m .688 .61021 L .68466 .61153 L 0 1 .366 r
F
.68715 .61343 m .69576 .61041 L .688 .61021 L F
0 g
.68466 .61153 m
.68715 .61343 L
s
.67964 .61348 m
.68715 .61343 L
s
.51966 .96861 m .51921 .96818 L .51944 .9685 L 0 .045 .153 r
F
0 g
.51944 .96849 m
.51944 .9685 L
s
.38991 .66857 m
.39625 .66641 L
s
.36207 .67561 m
.36207 .67561 L
s
.35572 .67507 m
.36207 .67561 L
s
.5303 .97795 m
.53032 .97825 L
s
.33416 .62286 m .33635 .61805 L .33541 .61265 L 0 1 .386 r
F
.34255 .64102 m .33635 .61805 L .33416 .62286 L 0 1 .273 r
F
0 g
.33635 .61805 m
.34056 .61588 L
s
.32783 .63323 m
.3332 .63361 L
s
.52605 .975 m .52464 .97324 L .52601 .97429 L 0 .07 0 r
F
0 g
.52601 .97429 m
.52616 .9744 L
s
.52561 .9739 m
.52601 .97429 L
s
.51381 .96057 m .51413 .96347 L .51503 .96354 L 0 .171 .198 r
F
0 g
.51413 .96347 m
.51544 .96502 L
s
.81505 .87842 m .82351 .87365 L .81887 .87443 L 0 1 .499 r
F
.80347 .88014 m .81505 .87842 L .81191 .87563 L 0 1 .487 r
F
.53268 1.09369 m .53525 1.09425 L .53437 1.09473 L 0 .287 0 r
F
0 g
.53478 1.09257 m
.53525 1.09425 L
s
.54132 1.10625 m .53437 1.09474 L .53525 1.09425 L 0 .325 0 r
F
0 g
.53525 1.09425 m
.53952 1.09833 L
s
.81305 1.01632 m .81555 1.02438 L .82108 1.01727 L 0 1 .413 r
F
.81305 1.01632 m .8112 1.02662 L .81555 1.02438 L F
0 g
.81551 1.02718 m
.81555 1.02438 L
s
.76052 .79344 m .76747 .80123 L .76287 .80043 L 0 .227 .057 r
F
.76052 .79344 m .77209 .79642 L .76747 .80123 L F
.34402 .83281 m .3352 .83558 L .33947 .83645 L 0 1 .499 r
F
0 g
.33947 .83645 m
.34187 .84127 L
s
.51026 .89443 m .51074 .89503 L .51048 .87781 L 0 .491 .271 r
F
.42017 .77959 m .41068 .77902 L .41115 .77787 L 0 0 0 r
F
0 g
.40612 .7767 m
.41115 .77787 L
s
.42017 .77959 m .41395 .78076 L .41068 .77902 L 0 0 0 r
F
.42017 .77959 m .41911 .78227 L .41395 .78076 L F
.42017 .77959 m .4227 .78254 L .41911 .78227 L F
.42017 .77959 m .42315 .78138 L .4227 .78254 L F
0 g
.42017 .77959 m
.42086 .77816 L
s
.41504 .77809 m
.42017 .77959 L
s
.50206 .90547 m .50224 .90423 L .49916 .89262 L 0 .534 .29 r
F
0 g
.50114 .88734 m
.50286 .89604 L
s
.50111 .88682 m
.5033 .89536 L
s
.50189 .89557 m
.50238 .89722 L
s
.50122 .89333 m
.50189 .89557 L
s
.4999 .88888 m
.50122 .89333 L
s
.502 .89801 m
.50259 .90054 L
s
.50197 .89788 m
.502 .89801 L
s
.50112 .8942 m
.50164 .89642 L
s
.4999 .88888 m
.50112 .8942 L
s
.32724 .75577 m .31754 .75321 L .32155 .75485 L 0 .571 .343 r
F
0 g
.32155 .75485 m
.32246 .75706 L
s
.45466 .88843 m .4519 .88243 L .4473 .87925 L 0 .972 .455 r
F
.45466 .88843 m .45506 .88637 L .4519 .88243 L F
.46632 .89681 m .45466 .88843 L .45787 .89239 L 0 .886 .445 r
F
.46632 .89681 m .45506 .88637 L .45466 .88843 L F
0 g
.45084 .88791 m
.45466 .88843 L
s
.45466 .88843 m
.45784 .89235 L
s
.47992 .93144 m .47111 .93105 L .46823 .92902 L 0 .201 .066 r
F
0 g
.46433 .92902 m
.46823 .92902 L
s
.36517 .83842 m .3563 .82998 L .3546 .83545 L 0 1 .491 r
F
.36517 .83842 m .3607 .82692 L .3563 .82998 L F
.36517 .83842 m .36485 .82831 L .3607 .82692 L F
.36517 .83842 m .36677 .83325 L .36485 .82831 L F
0 g
.36078 .84147 m
.36517 .83842 L
s
.52376 .62716 m .51893 .62869 L .51877 .62783 L 0 0 0 r
F
.52376 .62716 m .5245 .62967 L .51893 .62869 L F
.52376 .62716 m .53178 .63013 L .5245 .62967 L F
.52376 .62716 m .53676 .62946 L .53178 .63013 L F
0 g
.53857 .62791 m
.54067 .62774 L
s
.52376 .62716 m .53612 .62811 L .53676 .62946 L 0 0 0 r
F
0 g
.53612 .62811 m
.53857 .62791 L
s
.51854 .62628 m
.52376 .62716 L
s
.53055 .62712 m
.53612 .62811 L
s
.50895 .95525 m .50845 .9573 L .50915 .95658 L 0 .264 .262 r
F
.51137 .95791 m .50915 .95658 L .50845 .9573 L 0 .22 .222 r
F
0 g
.50845 .9573 m
.50902 .95882 L
s
.50686 .95684 m
.50845 .9573 L
s
.21881 .72599 m .20771 .7229 L .2079 .72848 L 0 1 .539 r
F
0 g
.20239 .73238 m
.2079 .72848 L
s
.46632 .89681 m .45787 .89239 L .46256 .89561 L 0 .886 .445 r
F
.46586 .90096 m .46256 .89561 L .45787 .89239 L 0 .886 .45 r
F
0 g
.45424 .89155 m
.45787 .89239 L
s
.45784 .89235 m
.45787 .89239 L
s
.51637 .90996 m .51799 .87076 L .51686 .89227 L 0 .489 .265 r
F
.51516 .90547 m .51686 .89227 L .51799 .87076 L 0 .492 .266 r
F
0 g
.51799 .87076 m
.51954 .85746 L
s
.51799 .87076 m
.518 .86916 L
s
.29485 .89568 m .28471 .89685 L .29041 .89753 L 0 1 .494 r
F
0 g
.29041 .89753 m
.29522 .90037 L
s
.29485 .89568 m .28059 .89373 L .28471 .89685 L 0 1 .494 r
F
0 g
.28103 .89894 m
.28471 .89685 L
s
.52312 .92899 m .52284 .92829 L .52544 .91969 L 0 .258 .126 r
F
0 g
.52293 .92797 m
.52344 .9263 L
s
.52137 .92483 m
.52324 .91726 L
s
.52079 .92453 m
.52324 .91726 L
s
.6685 .61539 m
.66967 .6153 L
s
.66967 .6153 m
.66984 .61528 L
s
.51083 .80392 m .50838 .81878 L .50872 .80929 L 0 .532 .124 r
F
.51081 .85244 m .51037 .82815 L .50836 .83426 L 0 .836 .34 r
F
.51037 .82815 m .51008 .82793 L .50838 .81878 L 0 .532 .124 r
F
.51037 .82815 m .51035 .82695 L .51008 .82793 L 0 .836 .34 r
F
.51037 .82815 m .51008 .82793 L .50836 .83426 L F
.51083 .80392 m .51037 .82815 L .50838 .81878 L 0 .532 .124 r
F
.51037 .82815 m .51035 .82935 L .51008 .82793 L F
0 g
.50715 .80046 m
.50872 .80929 L
s
.51083 .80392 m .51302 .83021 L .51037 .82815 L 0 .532 .124 r
F
.51083 .80392 m .51544 .82846 L .51438 .8312 L F
.51081 .85244 m .51438 .8312 L .51302 .83021 L 0 .836 .34 r
F
.51302 .83021 m .51438 .8312 L .51333 .83391 L 0 .532 .124 r
F
.51083 .80392 m .51438 .8312 L .51302 .83021 L F
.51081 .85244 m .51544 .83535 L .51438 .8312 L 0 .836 .34 r
F
.51302 .83021 m .51438 .8312 L .51333 .82711 L F
.51037 .82815 m .51333 .82711 L .51035 .82695 L F
.51081 .85244 m .51302 .83021 L .51037 .82815 L F
.51302 .83021 m .51333 .82711 L .51037 .82815 L F
.51037 .82815 m .51333 .83391 L .51035 .82935 L 0 .532 .124 r
F
.51302 .83021 m .51333 .83391 L .51037 .82815 L F
.51083 .80392 m .51527 .81668 L .51544 .82846 L F
.51083 .80392 m .5133 .80619 L .51527 .81668 L F
0 g
.50872 .80929 m
.51083 .80392 L
s
.50924 .79379 m
.51083 .80392 L
s
.5133 .80619 m
.51502 .79795 L
s
.51502 .79795 m
.51662 .80722 L
s
.49667 1.01931 m .49063 1.01794 L .49341 1.02334 L 0 .222 .273 r
F
.49667 1.01931 m .48976 1.0128 L .49063 1.01794 L F
0 g
.48733 1.01473 m
.49063 1.01794 L
s
.48677 .97831 m .48359 .98391 L .48608 .98271 L 0 .334 .311 r
F
.49093 .98997 m .48608 .98271 L .48359 .98391 L 0 .295 .3 r
F
0 g
.48331 .98861 m
.48359 .98391 L
s
.48024 .98102 m
.48359 .98391 L
s
.36964 .67548 m
.37085 .67446 L
s
.49023 .92675 m .47884 .91951 L .48249 .9226 L 0 .625 .421 r
F
.49023 .92675 m .47848 .91815 L .47884 .91951 L F
0 g
.47571 .91892 m
.47884 .91951 L
s
.62794 .62447 m .64212 .62186 L .64489 .62046 L 0 1 .296 r
F
.62794 .62447 m .63487 .62358 L .64212 .62186 L F
0 g
.64212 .62186 m
.64481 .62273 L
s
.52464 .93596 m .53602 .91458 L .5328 .92235 L 0 .26 .133 r
F
0 g
.52538 .91984 m
.52544 .91969 L
s
.52538 .91989 m
.52544 .91969 L
s
.53221 .9177 m
.5341 .91258 L
s
.53602 .91458 m
.53966 .90641 L
s
.80347 .88014 m .81191 .87563 L .80727 .87644 L 0 1 .487 r
F
.79189 .88189 m .80347 .88014 L .8003 .87766 L 0 1 .47 r
F
.54192 .74003 m .54979 .71377 L .54511 .71838 L 0 1 .337 r
F
0 g
.5481 .73184 m
.55051 .72645 L
s
.54734 .73354 m
.5481 .73184 L
s
.54979 .71377 m
.55211 .70953 L
s
.54979 .71377 m
.55002 .71411 L
s
.34402 .83281 m .33342 .83046 L .3352 .83558 L 0 1 .499 r
F
0 g
.33116 .83927 m
.3352 .83558 L
s
.54832 .70131 m .56005 .68408 L .55702 .68361 L 0 1 .356 r
F
0 g
.55347 .69657 m
.55849 .68919 L
s
.5546 .69728 m
.55612 .69822 L
s
.56005 .68408 m
.56524 .67614 L
s
.75028 .60578 m .76574 .61162 L .76974 .61091 L 0 1 .477 r
F
.75028 .60578 m .75741 .60942 L .76574 .61162 L F
0 g
.76574 .61162 m
.76722 .61527 L
s
.51316 .94817 m .51533 .92401 L .51476 .9312 L 0 .31 .115 r
F
0 g
.51352 .92453 m
.51406 .91888 L
s
.51471 .92419 m
.51475 .92395 L
s
.51406 .91888 m
.51421 .92435 L
s
.51316 .94817 m .51518 .92406 L .51533 .92401 L 0 .31 .115 r
F
0 g
.51533 .92401 m
.51606 .91819 L
s
.51533 .92403 m
.51533 .92401 L
s
.51316 .94817 m .5145 .93128 L .51518 .92406 L 0 .31 .115 r
F
0 g
.51518 .92407 m
.51518 .92406 L
s
.51352 .92453 m
.51352 .92453 L
s
.51471 .92419 m
.51471 .92419 L
s
.51421 .92435 m
.51421 .92435 L
s
.51518 .92406 m
.51563 .91794 L
s
.33416 .62286 m .3264 .62045 L .3299 .62389 L 0 1 .386 r
F
.33416 .62286 m .32547 .61504 L .3264 .62045 L F
.33416 .62286 m .32772 .61129 L .32547 .61504 L F
.33416 .62286 m .33198 .61026 L .32772 .61129 L F
.33416 .62286 m .33541 .61265 L .33198 .61026 L F
0 g
.33541 .61265 m
.33635 .61805 L
s
.34255 .64102 m .33416 .62286 L .33501 .63364 L 0 1 .273 r
F
0 g
.3299 .62389 m
.33416 .62286 L
s
.33496 .63373 m
.33501 .63374 L
s
.3332 .63361 m
.33496 .63373 L
s
.24885 .83576 m .23873 .82731 L .23727 .83462 L 0 1 .53 r
F
.24885 .83576 m .24328 .82226 L .23873 .82731 L F
.24885 .83576 m .24789 .82285 L .24328 .82226 L F
.24885 .83576 m .25027 .82865 L .24789 .82285 L F
0 g
.2443 .84077 m
.24885 .83576 L
s
.24885 .83576 m
.25126 .84137 L
s
.51316 .94817 m .5158 .92389 L .51628 .92379 L 0 .312 .116 r
F
.51316 .94817 m .51476 .9312 L .5158 .92389 L F
0 g
.5158 .92389 m
.51612 .91769 L
s
.51316 .94817 m .5147 .92426 L .5145 .93128 L 0 .306 .112 r
F
.51316 .94817 m .51422 .92447 L .5147 .92426 L F
0 g
.5147 .92426 m
.51471 .92419 L
s
.65197 .61946 m .65332 .61602 L .64969 .61796 L 0 1 .322 r
F
.65197 .61946 m .6614 .61492 L .65332 .61602 L F
.65197 .61946 m .6685 .61539 L .6614 .61492 L F
0 g
.6685 .61539 m
.66932 .61594 L
s
.50168 .92873 m .49028 .91474 L .49384 .92091 L 0 .47 .288 r
F
0 g
.49028 .91474 m
.49039 .91493 L
s
.49039 .91493 m
.49239 .9184 L
s
.49463 .92788 m
.49584 .92856 L
s
.48964 .91462 m
.49028 .91474 L
s
.59922 .63796 m .61264 .63239 L .61501 .63073 L 0 1 .238 r
F
.59922 .63796 m .60588 .63549 L .61264 .63239 L F
0 g
.61264 .63239 m
.61551 .63222 L
s
.51316 .94817 m .51628 .92379 L .5156 .93101 L 0 .312 .116 r
F
0 g
.51579 .92396 m
.5158 .92389 L
s
.51628 .92379 m
.5163 .92367 L
s
.51316 .94817 m .51365 .93166 L .51422 .92447 L 0 .306 .112 r
F
0 g
.51421 .9245 m
.51422 .92447 L
s
.5135 .92475 m
.5135 .92475 L
s
.5135 .92475 m
.51352 .92453 L
s
.5135 .92475 m
.5135 .92475 L
s
.51421 .92435 m
.51422 .92447 L
s
.51754 .9151 m .52188 .86733 L .52 .87873 L 0 .481 .265 r
F
.51754 .9151 m .5228 .87186 L .52188 .86733 L F
0 g
.52188 .86733 m
.52219 .85249 L
s
.48774 .95449 m .48675 .95047 L .4833 .94733 L 0 .408 .308 r
F
.7203 1.08333 m .73113 1.07909 L .72712 1.08185 L 0 0 0 r
F
.70817 1.09203 m .7203 1.08333 L .72041 1.08682 L F
0 g
.58565 .64996 m
.58592 .64975 L
s
.51994 .96888 m
.52068 .9696 L
s
.52252 .97139 m .52108 .96998 L .52068 .9696 L 0 .01 .142 r
F
0 g
.52068 .9696 m
.52068 .9696 L
s
.45585 .88331 m .4473 .87925 L .4519 .88243 L 0 .97 .449 r
F
.45585 .88331 m .44442 .87502 L .4473 .87925 L F
0 g
.44348 .87873 m
.4473 .87925 L
s
.25751 .63604 m .24542 .64012 L .24955 .64148 L 0 1 .513 r
F
0 g
.24865 .64874 m
.24955 .64148 L
s
.47301 .63599 m .46583 .6376 L .46708 .6375 L 0 0 0 r
F
.47301 .63599 m .47021 .63633 L .46583 .6376 L F
0 g
.46319 .63921 m
.46708 .6375 L
s
.47301 .63599 m .47732 .63454 L .47021 .63633 L 0 0 0 r
F
.47301 .63599 m .48405 .63279 L .48326 .63302 L F
.47301 .63599 m .47966 .63406 L .48405 .63279 L F
.47301 .63599 m .48326 .63302 L .47732 .63454 L F
0 g
.46896 .63722 m
.47301 .63599 L
s
.46708 .6375 m
.47301 .63599 L
s
.48142 .63349 m
.48524 .63226 L
s
.66201 .58566 m
.66247 .58674 L
s
.66053 .58219 m
.66201 .58566 L
s
.65648 .57359 m
.65887 .57868 L
s
.65887 .57868 m
.66053 .58219 L
s
.51316 .94817 m .51699 .9237 L .51745 .92369 L 0 .316 .118 r
F
.51316 .94817 m .5156 .93101 L .51699 .9237 L F
0 g
.51699 .9237 m
.51699 .92367 L
s
.48774 .95449 m .48277 .95828 L .48603 .95784 L 0 .408 .308 r
F
.49041 .96456 m .48603 .95784 L .48277 .95828 L 0 .358 .302 r
F
0 g
.48143 .96208 m
.48277 .95828 L
s
.47934 .95513 m
.48277 .95828 L
s
.51544 1.06897 m .51185 1.06502 L .51575 1.07082 L 0 0 .15 r
F
.51544 1.06897 m .50908 1.06006 L .51185 1.06502 L F
0 g
.50877 1.06105 m
.51185 1.06502 L
s
.49198 .93008 m .49156 .92698 L .48798 .92249 L 0 .481 .3 r
F
.51316 .94817 m .51349 .92484 L .51365 .93166 L 0 .302 .11 r
F
.51316 .94817 m .513 .92513 L .51349 .92484 L F
0 g
.51349 .92484 m
.5135 .92475 L
s
.49197 .93322 m .48357 .93189 L .48079 .92958 L 0 .234 .084 r
F
0 g
.48079 .92958 m
.48166 .9303 L
s
.47704 .92941 m
.48079 .92958 L
s
.73132 .61039 m .73284 .60649 L .72914 .60752 L 0 1 .43 r
F
.73132 .61039 m .74079 .60814 L .73284 .60649 L F
.24093 .73251 m .23385 .72362 L .22988 .72919 L 0 1 .536 r
F
.24093 .73251 m .24009 .72064 L .23385 .72362 L F
.24093 .73251 m .24441 .72227 L .24009 .72064 L F
.24093 .73251 m .24477 .72736 L .24441 .72227 L F
0 g
.23472 .73546 m
.24093 .73251 L
s
.24093 .73251 m
.24141 .73729 L
s
.66984 .61528 m
.67206 .6205 L
s
.67206 .6205 m
.67321 .62322 L
s
.46586 .90096 m .46598 .89928 L .46256 .89561 L 0 .886 .45 r
F
.47764 .90965 m .46586 .90096 L .4693 .90472 L 0 .779 .436 r
F
.47764 .90965 m .46598 .89928 L .46586 .90096 L F
0 g
.46223 .90011 m
.46586 .90096 L
s
.5438 .80016 m .55167 .7585 L .54806 .76127 L 0 1 .292 r
F
.5438 .80016 m .55288 .76991 L .55167 .7585 L F
0 g
.55167 .7585 m
.55317 .75387 L
s
.50131 .92019 m .49308 .90782 L .49779 .91558 L 0 .505 .29 r
F
.50144 .92438 m .49779 .91558 L .49308 .90782 L 0 .489 .289 r
F
0 g
.49198 .90667 m
.49308 .90782 L
s
.49148 .90419 m
.49308 .90782 L
s
.50671 .62855 m .51354 .62777 L .51877 .62783 L 0 0 0 r
F
0 g
.51354 .62777 m
.51854 .62628 L
s
.79189 .88189 m .8003 .87766 L .79566 .87849 L 0 1 .47 r
F
.78032 .88369 m .79189 .88189 L .7887 .87975 L 0 1 .448 r
F
.49098 .92916 m .4836 .92574 L .48796 .92811 L 0 .609 .42 r
F
.49197 .93165 m .48796 .92811 L .4836 .92574 L 0 .588 .418 r
F
0 g
.47997 .92293 m
.4836 .92574 L
s
.483 .92558 m
.4836 .92574 L
s
.49175 .92837 m
.49373 .92886 L
s
.51316 .94817 m .51745 .92369 L .51641 .93099 L 0 .316 .118 r
F
0 g
.51745 .92369 m
.51747 .92361 L
s
.49457 .94568 m .48446 .94044 L .48534 .94445 L 0 .41 .295 r
F
.49457 .94568 m .48672 .93826 L .48446 .94044 L F
0 g
.48393 .9399 m
.48446 .94044 L
s
.2461 .92936 m .23605 .92544 L .23344 .92627 L 0 .636 .249 r
F
.2461 .92936 m .2407 .92618 L .23605 .92544 L F
.2461 .92936 m .24501 .92786 L .2407 .92618 L F
.25762 .93066 m .24501 .92786 L .2461 .92936 L 0 .603 .239 r
F
0 g
.24348 .93018 m
.2461 .92936 L
s
.2461 .92936 m
.25035 .93079 L
s
.50169 .90878 m .50182 .90742 L .49857 .89669 L 0 .532 .291 r
F
0 g
.49889 .89775 m
.49983 .90084 L
s
.49857 .89669 m
.49889 .89775 L
s
.50022 .90085 m
.50024 .90088 L
s
.49905 .89791 m
.50022 .90085 L
s
.49857 .89669 m
.49905 .89791 L
s
.50164 .89642 m
.50197 .89788 L
s
.49916 .89262 m
.50096 .89786 L
s
.50096 .89786 m
.50156 .89958 L
s
.50156 .89958 m
.50217 .90136 L
s
.49916 .89262 m
.50058 .89797 L
s
.50058 .89797 m
.50072 .89849 L
s
.50153 .90156 m
.50192 .903 L
s
.32724 .75577 m .31737 .75124 L .31754 .75321 L 0 .571 .343 r
F
0 g
.31234 .75334 m
.31754 .75321 L
s
.49041 .96456 m .48289 .96671 L .48616 .96941 L 0 .358 .302 r
F
0 g
.48182 .97079 m
.48289 .96671 L
s
.51316 .94817 m .51279 .93216 L .513 .92513 L 0 .302 .11 r
F
0 g
.51247 .92 m
.513 .92513 L
s
.49023 .92675 m .4817 .91952 L .47848 .91815 L 0 .625 .421 r
F
0 g
.49009 .91845 m
.4905 .91903 L
s
.4893 .91733 m
.49009 .91845 L
s
.47727 .9172 m
.47848 .91815 L
s
.47947 .92156 m
.48205 .92245 L
s
.30571 .89727 m .29795 .89846 L .30229 .89901 L 0 1 .485 r
F
0 g
.30229 .89901 m
.30605 .90155 L
s
.30571 .89727 m .29485 .89568 L .29795 .89846 L 0 1 .485 r
F
0 g
.29523 .90037 m
.29795 .89846 L
s
.49093 .98997 m .48543 .99368 L .48857 .99628 L 0 .295 .3 r
F
0 g
.48543 .99368 m
.48547 .9984 L
s
.59403 .64314 m .59275 .64153 L .59079 .64382 L 0 .878 .204 r
F
.59403 .64314 m .59922 .63796 L .59275 .64153 L F
.59403 .64314 m .60588 .63549 L .59922 .63796 L F
0 g
.59079 .64382 m
.59403 .64314 L
s
.60588 .63549 m
.61264 .63239 L
s
.60588 .63549 m
.60909 .63482 L
s
.58786 .64734 m
.58966 .64612 L
s
.58966 .64612 m
.59403 .64314 L
s
.50386 .93618 m .4965 .93201 L .49403 .92893 L 0 .253 .098 r
F
0 g
.49373 .92886 m
.49403 .92893 L
s
.73144 1.08395 m .73113 1.07909 L .73741 1.07631 L 0 0 0 r
F
.73144 1.08395 m .72712 1.08185 L .73113 1.07909 L F
0 g
.73015 1.0771 m
.73113 1.07909 L
s
.41068 .77902 m
.41115 .77787 L
s
.64905 1.09119 m
.64956 1.09148 L
s
.64905 1.09119 m
.64978 1.09445 L
s
.44442 .87502 m .43792 .86509 L .43389 .86484 L 0 1 .457 r
F
.44442 .87502 m .44241 .86831 L .43792 .86509 L F
.44442 .87502 m .44519 .87257 L .44241 .86831 L F
.45585 .88331 m .44519 .87257 L .44442 .87502 L 0 .97 .449 r
F
0 g
.44442 .87502 m
.4473 .87925 L
s
.44038 .87477 m
.44442 .87502 L
s
.3546 .83545 m .34582 .82707 L .34402 .83281 L 0 1 .495 r
F
.3546 .83545 m .3503 .8237 L .34582 .82707 L F
.3546 .83545 m .35446 .82494 L .3503 .8237 L F
.3546 .83545 m .3563 .82998 L .35446 .82494 L F
0 g
.35013 .83881 m
.3546 .83545 L
s
.3546 .83545 m
.35652 .84037 L
s
.50761 .93006 m .50718 .93061 L .50498 .92753 L 0 .215 .095 r
F
0 g
.50637 .92582 m
.50711 .92834 L
s
.33342 .83046 m .32451 .83357 L .32879 .83435 L 0 1 .503 r
F
0 g
.32879 .83435 m
.33116 .83927 L
s
.67565 .69991 m .67747 .68029 L .67386 .67438 L 0 .315 .263 r
F
0 g
.67386 .67438 m
.67466 .68585 L
s
.67466 .68585 m
.67565 .69991 L
s
.6709 .66331 m
.67386 .67438 L
s
.6732 .68761 m
.67513 .6973 L
s
.67513 .6973 m
.67565 .69991 L
s
.50671 .62855 m .50102 .62997 L .50135 .62949 L 0 0 0 r
F
0 g
.50026 .62902 m
.50183 .62854 L
s
.50671 .62855 m .50626 .63004 L .50102 .62997 L 0 0 0 r
F
.50671 .62855 m .51356 .62963 L .50626 .63004 L F
.50671 .62855 m .51893 .62869 L .51356 .62963 L F
.50671 .62855 m .51877 .62783 L .51893 .62869 L F
0 g
.50183 .62854 m
.50671 .62855 L
s
.51877 .62783 m
.52376 .62716 L
s
.51354 .62777 m
.51877 .62783 L
s
.49092 1.00642 m .48976 1.0128 L .49138 1.01135 L 0 .271 .299 r
F
.49667 1.01931 m .49138 1.01135 L .48976 1.0128 L 0 .222 .273 r
F
0 g
.48976 1.0128 m
.49063 1.01794 L
s
.48654 1.00988 m
.48976 1.0128 L
s
.51316 .94817 m .51813 .92375 L .51857 .92384 L 0 .318 .12 r
F
.51316 .94817 m .51641 .93099 L .51813 .92375 L F
0 g
.51813 .92375 m
.51814 .92367 L
s
.79521 .79958 m .80853 .79625 L .80675 .80017 L 0 .01 0 r
F
0 g
.80635 .79263 m
.80853 .79625 L
s
.80853 .79625 m
.81336 .79385 L
s
.38377 .77266 m .37464 .77027 L .37846 .7711 L 0 0 0 r
F
0 g
.37846 .7711 m
.37929 .77117 L
s
.46632 .89681 m .45882 .88756 L .45506 .88637 L 0 .886 .445 r
F
0 g
.4519 .88243 m
.45506 .88637 L
s
.51316 .94817 m .51227 .9256 L .51279 .93216 L 0 .296 .109 r
F
.51316 .94817 m .51178 .92595 L .51227 .9256 L F
0 g
.51227 .9256 m
.51247 .92 L
s
.51625 .96323 m .51632 .96549 L .51778 .96684 L 0 .118 .185 r
F
.51625 .96323 m .51503 .96354 L .51632 .96549 L F
0 g
.51544 .96502 m
.51632 .96549 L
s
.62171 .62847 m .62094 .62644 L .61857 .62818 L 0 .892 .245 r
F
.62171 .62847 m .62794 .62447 L .62094 .62644 L F
.62171 .62847 m .63487 .62358 L .62794 .62447 L F
0 g
.63487 .62358 m
.64212 .62186 L
s
.63487 .62358 m
.63799 .62388 L
s
.50689 1.05434 m .50908 1.06006 L .50929 1.05924 L 0 .083 .178 r
F
.51544 1.06897 m .50929 1.05924 L .50908 1.06006 L 0 0 .15 r
F
0 g
.50908 1.06006 m
.51185 1.06502 L
s
.50601 1.05644 m
.50908 1.06006 L
s
.77256 1.05256 m .76885 1.05633 L .76922 1.05722 L 0 .938 .212 r
F
0 g
.76248 1.06105 m
.76922 1.05722 L
s
.78032 .88369 m .7887 .87975 L .78406 .88059 L 0 1 .448 r
F
.76874 .88554 m .78032 .88369 L .7771 .88188 L 0 1 .419 r
F
.41844 .92276 m .41039 .92057 L .41509 .92167 L 0 0 0 r
F
.41844 .92276 m .40667 .91976 L .41039 .92057 L F
0 g
.40741 .91973 m
.41039 .92057 L
s
.41509 .92167 m
.41909 .92223 L
s
.34255 .64103 m
.34428 .64537 L
s
.43503 .78299 m .42808 .78266 L .43166 .78257 L 0 .023 0 r
F
.43503 .78299 m .42615 .78321 L .42808 .78266 L F
.43503 .78299 m .42717 .78385 L .42615 .78321 L F
.43503 .78299 m .43054 .78427 L .42717 .78385 L F
.43503 .78299 m .43402 .78418 L .43054 .78427 L F
.43503 .78299 m .43594 .78364 L .43402 .78418 L F
0 g
.43503 .78299 m
.43703 .78209 L
s
.43166 .78257 m
.43503 .78299 L
s
.43594 .78364 m
.43923 .78369 L
s
.50051 1.03702 m .49765 1.03151 L .49463 1.02831 L 0 .166 .24 r
F
.51147 .89614 m .51196 .89702 L .51208 .87992 L 0 .49 .269 r
F
.49996 .94464 m .49916 .94359 L .49639 .94231 L 0 .394 .374 r
F
.48973 .63157 m .48326 .63302 L .48405 .63279 L 0 0 0 r
F
.48973 .63157 m .48809 .63234 L .48326 .63302 L F
0 g
.48316 .63305 m
.48405 .63279 L
s
.48973 .63157 m .49534 .6312 L .48809 .63234 L 0 0 0 r
F
.48973 .63157 m .50102 .62997 L .49534 .6312 L F
.48973 .63157 m .50135 .62949 L .50102 .62997 L F
.48973 .63157 m .49651 .63017 L .50135 .62949 L F
0 g
.50135 .62949 m
.50671 .62855 L
s
.48524 .63226 m
.48973 .63157 L
s
.48405 .63279 m
.48973 .63157 L
s
.49651 .63017 m
.50026 .62902 L
s
.49651 .63017 m
.50135 .62949 L
s
.51316 .94817 m .51857 .92384 L .51719 .93115 L 0 .318 .12 r
F
0 g
.51857 .92384 m
.5186 .92375 L
s
.47807 .91614 m .47786 .91481 L .47418 .91161 L 0 .769 .443 r
F
.53268 1.09369 m .53132 1.0918 L .53086 1.09013 L 0 .287 0 r
F
.51316 .94817 m .51194 .93277 L .51178 .92595 L 0 .296 .109 r
F
0 g
.5109 .92128 m
.51178 .92595 L
s
.45434 .78744 m
.45469 .7875 L
s
.45024 .78676 m
.45434 .78744 L
s
.50206 .94729 m .5012 .94623 L .49869 .94518 L 0 .359 .354 r
F
.47764 .90965 m .4693 .90472 L .47403 .90807 L 0 .779 .436 r
F
.47767 .91284 m .47403 .90807 L .4693 .90472 L 0 .776 .44 r
F
0 g
.46582 .9035 m
.4693 .90472 L
s
.46586 .90096 m
.4693 .90472 L
s
.47418 .91161 m
.47565 .91213 L
s
.47418 .91161 m
.47444 .91184 L
s
.47444 .91184 m
.47462 .912 L
s
.30297 .62806 m .29114 .63134 L .29498 .63346 L 0 1 .48 r
F
0 g
.29351 .64081 m
.29498 .63346 L
s
.36017 .90936 m
.36017 .90936 L
s
.33627 .65929 m
.33879 .65499 L
s
.33879 .65499 m
.33894 .65474 L
s
.33894 .65474 m
.33943 .65389 L
s
.33943 .65389 m
.34427 .64566 L
s
.54511 .71838 m .55347 .69658 L .54831 .70131 L 0 1 .348 r
F
0 g
.55347 .69658 m
.5546 .69728 L
s
.45459 .93049 m .44677 .9275 L .4514 .92872 L 0 .109 .01 r
F
.45459 .93049 m .44295 .92727 L .44677 .9275 L F
0 g
.44386 .9259 m
.44677 .9275 L
s
.49801 .942 m .49727 .94095 L .49427 .93944 L 0 .443 .389 r
F
.23727 .83462 m .22719 .82595 L .22569 .83346 L 0 1 .532 r
F
.23727 .83462 m .23177 .82075 L .22719 .82595 L F
.23727 .83462 m .23637 .82136 L .23177 .82075 L F
.23727 .83462 m .23873 .82731 L .23637 .82136 L F
0 g
.2327 .83978 m
.23727 .83462 L
s
.23727 .83462 m
.23966 .84037 L
s
.31657 .89896 m .3088 .89988 L .31315 .90047 L 0 1 .473 r
F
0 g
.31315 .90047 m
.31687 .90283 L
s
.31657 .89896 m .30571 .89727 L .3088 .89988 L 0 1 .473 r
F
0 g
.30605 .90155 m
.3088 .89988 L
s
.39491 .91706 m .38609 .91435 L .3828 .91395 L 0 .486 .217 r
F
.39491 .91706 m .39082 .91556 L .38609 .91435 L F
.39491 .91706 m .3946 .91673 L .39082 .91556 L F
.40667 .91976 m .3946 .91673 L .39491 .91706 L 0 0 0 r
F
0 g
.39491 .91706 m
.39866 .91803 L
s
.39162 .91665 m
.39491 .91706 L
s
.42034 .6558 m .41126 .65857 L .4138 .65828 L 0 1 .282 r
F
.42034 .6558 m .4143 .65632 L .41126 .65857 L F
0 g
.41138 .66029 m
.4138 .65828 L
s
.42034 .6558 m .4209 .65303 L .4143 .65632 L 0 1 .282 r
F
.42034 .6558 m .42747 .65054 L .4209 .65303 L F
.42034 .6558 m .4296 .65051 L .42747 .65054 L F
.42034 .6558 m .42655 .65276 L .4296 .65051 L F
0 g
.41759 .65786 m
.42034 .6558 L
s
.4138 .65828 m
.42034 .6558 L
s
.51137 .95791 m .51173 .96041 L .51194 .95944 L 0 .22 .222 r
F
.51381 .96057 m .51194 .95944 L .51173 .96041 L 0 .171 .198 r
F
0 g
.51173 .96041 m
.51267 .96214 L
s
.51048 .96015 m
.51173 .96041 L
s
.72369 .66496 m .737 .64698 L .74095 .64533 L 0 0 .011 r
F
.72369 .66496 m .72963 .65536 L .737 .64698 L F
0 g
.737 .64698 m
.73767 .64071 L
s
.73643 .64763 m
.737 .64698 L
s
.63278 .74492 m .63598 .74474 L .63241 .73696 L 0 .001 .148 r
F
0 g
.63241 .73696 m
.63278 .74492 L
s
.63129 .73362 m
.63241 .73696 L
s
.63278 .74492 m .64197 .76594 L .63598 .74474 L 0 .001 .148 r
F
.63278 .74492 m .63685 .76333 L .64283 .78456 L F
0 g
.63278 .74492 m
.63278 .74492 L
s
.63838 .78968 m
.64002 .77457 L
s
.33342 .83046 m .3228 .82838 L .32451 .83357 L 0 1 .503 r
F
0 g
.32044 .83749 m
.32451 .83357 L
s
.31886 .62492 m
.32112 .61603 L
s
.32559 .62093 m
.3264 .62045 L
s
.31886 .62492 m
.32559 .62093 L
s
.52425 .93332 m .53219 .91776 L .52774 .92706 L 0 .259 .131 r
F
.52464 .93596 m .52774 .92706 L .53219 .91776 L 0 .26 .133 r
F
0 g
.52465 .92167 m
.52538 .91984 L
s
.52468 .92221 m
.52538 .91989 L
s
.53219 .91776 m
.53533 .91303 L
s
.53219 .91776 m
.53221 .9177 L
s
.62893 .52954 m
.62987 .53081 L
s
.47764 .90965 m .46959 .90086 L .46598 .89928 L 0 .779 .436 r
F
0 g
.46256 .89561 m
.46598 .89928 L
s
.53497 .81648 m .53724 .81499 L .5406 .83605 L 0 .691 .18 r
F
0 g
.532 .80172 m
.53497 .81648 L
s
.53724 .81499 m
.53728 .80193 L
s
.54806 .76127 m .54812 .74235 L .54654 .75434 L 0 1 .298 r
F
.53876 .76713 m .54812 .74235 L .54615 .73622 L 0 1 .323 r
F
.53876 .76713 m .54654 .75434 L .54812 .74235 L F
0 g
.54812 .74235 m
.55038 .73541 L
s
.67522 .80713 m
.67712 .79577 L
s
.50427 .94994 m .50337 .94888 L .50114 .94804 L 0 .332 .329 r
F
.50468 .93453 m .50138 .93309 L .49777 .92965 L 0 .242 .097 r
F
.50205 .93319 m .49069 .9193 L .49101 .92236 L 0 .449 .286 r
F
.50205 .93319 m .49384 .92091 L .49069 .9193 L F
0 g
.4905 .91903 m
.49069 .9193 L
s
.49239 .9184 m
.49324 .91988 L
s
.49187 .92926 m
.49281 .93016 L
s
.49657 .92781 m
.49761 .9294 L
s
.49584 .92856 m
.49766 .92959 L
s
.49228 .92011 m
.49308 .92052 L
s
.4918 .91987 m
.49228 .92011 L
s
.49101 .91947 m
.4918 .91987 L
s
.49069 .9193 m
.49101 .91947 L
s
.76874 .88554 m .7771 .88188 L .77246 .88275 L 0 1 .419 r
F
.75716 .88744 m .76874 .88554 L .7655 .88408 L 0 1 .38 r
F
0 g
.62258 .70028 m
.62733 .71031 L
s
.62733 .71031 m
.62772 .71115 L
s
.62772 .71115 m
.62886 .71355 L
s
.48972 .92441 m .47807 .91614 L .4817 .91952 L 0 .636 .42 r
F
.48972 .92441 m .47786 .91481 L .47807 .91614 L F
0 g
.48798 .92249 m
.49016 .9224 L
s
.48798 .92249 m
.48914 .92394 L
s
.47474 .91524 m
.47807 .91614 L
s
.51316 .94817 m .51106 .92652 L .51194 .93277 L 0 .292 .108 r
F
.51316 .94817 m .51058 .92693 L .51106 .92652 L F
0 g
.5109 .92128 m
.51106 .92652 L
s
.66434 1.09634 m
.66473 1.09654 L
s
.51316 .94817 m .51922 .92405 L .51964 .92426 L 0 .318 .122 r
F
.51316 .94817 m .51719 .93115 L .51922 .92405 L F
0 g
.51922 .92405 m
.51924 .92393 L
s
.73472 .80283 m
.7398 .79315 L
s
.50144 .91236 m .50152 .91089 L .49813 .90106 L 0 .527 .291 r
F
0 g
.49941 .90383 m
.49951 .90405 L
s
.49813 .90106 m
.49941 .90383 L
s
.50072 .89849 m
.50153 .90156 L
s
.50024 .90088 m
.50101 .90282 L
s
.50101 .90282 m
.50119 .90329 L
s
.49983 .90084 m
.50003 .90152 L
s
.50003 .90152 m
.50042 .90278 L
s
.50042 .90278 m
.50076 .90392 L
s
.50076 .90392 m
.50102 .90476 L
s
.7385 .66291 m .74208 .67527 L .73815 .67804 L 0 .197 .104 r
F
0 g
.73815 .67804 m
.7382 .67595 L
s
.73402 .677 m
.73417 .67653 L
s
.73443 .67571 m
.73782 .66504 L
s
.73324 .67944 m
.73402 .677 L
s
.73228 .68248 m
.73324 .67944 L
s
.49457 .94568 m .48534 .94445 L .4887 .94763 L 0 .41 .295 r
F
0 g
.48534 .94445 m
.48559 .94468 L
s
.4833 .94733 m
.48534 .94445 L
s
.4244 .85303 m .41549 .85096 L .41998 .85355 L 0 1 .462 r
F
0 g
.41998 .85355 m
.42258 .85796 L
s
.4244 .85303 m .4133 .84625 L .41549 .85096 L 0 1 .462 r
F
0 g
.41126 .85181 m
.41549 .85096 L
s
.49023 .92675 m .48249 .9226 L .48701 .92537 L 0 .625 .421 r
F
.49098 .92916 m .48701 .92537 L .48249 .9226 L 0 .609 .42 r
F
0 g
.47884 .91951 m
.48249 .9226 L
s
.48205 .92245 m
.48249 .9226 L
s
.46735 .93088 m .45836 .93066 L .45535 .9288 L 0 .161 .042 r
F
.5695 .66637 m .56779 .66393 L .56628 .66733 L 0 1 .21 r
F
0 g
.5695 .66638 m
.5695 .66638 L
s
.5695 .66637 m .5736 .65842 L .56779 .66393 L 0 1 .21 r
F
.5695 .66637 m .57981 .65449 L .5736 .65842 L F
0 g
.56949 .66638 m
.5695 .66637 L
s
.57981 .65449 m
.5838 .6514 L
s
.57981 .65449 m
.583 .65356 L
s
.42655 .65276 m
.43063 .65121 L
s
.43063 .65121 m
.4328 .65038 L
s
.52551 1.08582 m .52701 1.08603 L .52975 1.09039 L 0 .193 0 r
F
0 g
.52701 1.08603 m
.53086 1.09012 L
s
.51625 .96323 m .51778 .96684 L .51831 .96671 L 0 .118 .185 r
F
0 g
.51778 .96684 m
.51944 .96849 L
s
.4133 .84625 m .40425 .84495 L .40875 .84728 L 0 1 .467 r
F
0 g
.40875 .84728 m
.41126 .85181 L
s
.43549 .86055 m .42671 .85764 L .4312 .86052 L 0 1 .456 r
F
.43549 .86055 m .4244 .85303 L .42671 .85764 L F
0 g
.42258 .85796 m
.42671 .85764 L
s
.4312 .86052 m
.43389 .86484 L
s
.51316 .94817 m .5111 .93349 L .51058 .92693 L 0 .292 .108 r
F
0 g
.51019 .9256 m
.51058 .92693 L
s
.7044 .60733 m .7199 .61003 L .72359 .60903 L 0 1 .429 r
F
.7044 .60733 m .71169 .6093 L .7199 .61003 L F
0 g
.7199 .61003 m
.72188 .61255 L
s
.25762 .93066 m .24768 .92731 L .24501 .92786 L 0 .603 .239 r
F
.25762 .93066 m .25233 .92808 L .24768 .92731 L F
.25762 .93066 m .25659 .92951 L .25233 .92808 L F
.26914 .93202 m .25659 .92951 L .25762 .93066 L 0 .561 .226 r
F
0 g
.25494 .9312 m
.25762 .93066 L
s
.25762 .93066 m
.26182 .93184 L
s
.32743 .90079 m .31966 .90141 L .32401 .90205 L 0 1 .457 r
F
0 g
.32401 .90205 m
.32769 .90423 L
s
.32743 .90079 m .31657 .89896 L .31966 .90141 L 0 1 .457 r
F
0 g
.31687 .90283 m
.31966 .90141 L
s
.81305 1.01632 m .81013 1.02318 L .8112 1.02662 L 0 1 .413 r
F
0 g
.80478 1.03244 m
.8112 1.02662 L
s
.6989 1.09947 m .69434 1.09631 L .69361 1.09229 L 0 0 .024 r
F
0 g
.68698 1.09143 m
.69361 1.09229 L
s
.34402 .83281 m .33532 .8245 L .33342 .83046 L 0 1 .499 r
F
.34402 .83281 m .33988 .82084 L .33532 .8245 L F
.34402 .83281 m .34405 .82194 L .33988 .82084 L F
.34402 .83281 m .34582 .82707 L .34405 .82194 L F
0 g
.33947 .83645 m
.34402 .83281 L
s
.34402 .83281 m
.34587 .83783 L
s
.77879 .64574 m .79458 .62999 L .78895 .64206 L 0 .067 .061 r
F
0 g
.79458 .62999 m
.79559 .62127 L
s
.25751 .63604 m .24737 .6325 L .24542 .64012 L 0 1 .513 r
F
0 g
.23819 .64557 m
.24542 .64012 L
s
.51316 .94817 m .51964 .92426 L .51793 .93151 L 0 .318 .122 r
F
0 g
.51964 .92426 m
.51968 .92411 L
s
.4133 .84625 m .40219 .84012 L .40425 .84495 L 0 1 .467 r
F
0 g
.39993 .84629 m
.40425 .84495 L
s
.31737 .75124 m .30534 .74798 L .31059 .75027 L 0 .702 .411 r
F
0 g
.31059 .75027 m
.31234 .75334 L
s
.77256 1.05256 m .77944 1.04943 L .78331 1.04502 L 0 .938 .212 r
F
0 g
.77341 1.05465 m
.77944 1.04943 L
s
.77944 1.04943 m
.77969 1.05102 L
s
.50657 .9526 m .50564 .95154 L .50372 .95089 L 0 .301 .298 r
F
.50386 .93618 m .49777 .92965 L .50138 .93309 L 0 .253 .098 r
F
0 g
.49761 .9294 m
.49777 .92965 L
s
.49766 .92959 m
.49777 .92965 L
s
.75716 .88744 m .7655 .88408 L .76086 .88497 L 0 1 .38 r
F
.74558 .88941 m .75716 .88744 L .75389 .88634 L 0 1 .33 r
F
.45585 .88331 m .44913 .87345 L .44519 .87257 L 0 .97 .449 r
F
.49317 .93786 m .48672 .93826 L .49062 .93937 L 0 .447 .298 r
F
.49457 .94568 m .49062 .93937 L .48672 .93826 L 0 .41 .295 r
F
0 g
.48446 .94044 m
.48672 .93826 L
s
.4835 .93471 m
.48672 .93826 L
s
.53876 .76713 m .54615 .73622 L .54192 .74003 L 0 1 .323 r
F
0 g
.54615 .73622 m
.54812 .74235 L
s
.54615 .73622 m
.54734 .73354 L
s
.53291 .9804 m
.53303 .9805 L
s
.53197 .97961 m
.53291 .9804 L
s
.53145 .97919 m
.53197 .97961 L
s
.53032 .97825 m
.53145 .97919 L
s
.3228 .82838 m .31382 .83177 L .3181 .83247 L 0 1 .508 r
F
0 g
.3181 .83247 m
.32044 .83749 L
s
.33711 .7598 m .33084 .75537 L .32724 .75577 L 0 .523 .266 r
F
.33711 .7598 m .33641 .7565 L .33084 .75537 L F
.33711 .7598 m .34023 .75841 L .33641 .7565 L F
.33711 .7598 m .34053 .75983 L .34023 .75841 L F
0 g
.33156 .75867 m
.33711 .7598 L
s
.33711 .7598 m
.33757 .76077 L
s
.32928 .678 m
.33021 .67058 L
s
.32177 .68668 m
.32928 .678 L
s
.49667 1.01931 m .49341 1.02334 L .49637 1.02614 L 0 .222 .273 r
F
0 g
.49341 1.02334 m
.49463 1.02831 L
s
.53689 .92799 m .53679 .92496 L .54022 .91374 L 0 .231 .141 r
F
0 g
.53856 .91916 m
.54022 .91374 L
s
.53766 .91865 m
.54022 .91374 L
s
.48972 .92441 m .48124 .91651 L .47786 .91481 L 0 .636 .42 r
F
0 g
.48932 .92417 m
.48993 .92494 L
s
.47462 .912 m
.47786 .91481 L
s
.47848 .91815 m
.48148 .91943 L
s
.50144 .92438 m .49335 .9143 L .498 .92078 L 0 .489 .289 r
F
.50168 .92873 m .498 .92078 L .49335 .9143 L 0 .47 .288 r
F
0 g
.49225 .91211 m
.49335 .9143 L
s
.49201 .91325 m
.49335 .9143 L
s
.49324 .91988 m
.49345 .92023 L
s
.49308 .92052 m
.49357 .92077 L
s
.22569 .83346 m .21563 .82456 L .21411 .83229 L 0 1 .533 r
F
.22569 .83346 m .22024 .81921 L .21563 .82456 L F
.22569 .83346 m .22485 .81983 L .22024 .81921 L F
.22569 .83346 m .22719 .82595 L .22485 .81983 L F
0 g
.2211 .83877 m
.22569 .83346 L
s
.22569 .83346 m
.22806 .83938 L
s
.40219 .84012 m .393 .83954 L .3975 .84164 L 0 1 .471 r
F
0 g
.3975 .84164 m
.39993 .84629 L
s
.30297 .62806 m .29358 .62284 L .29114 .63134 L 0 1 .48 r
F
0 g
.28372 .63583 m
.29114 .63134 L
s
.30297 .62806 m .30069 .61362 L .29358 .62284 L 0 1 .48 r
F
.30297 .62806 m .3087 .6082 L .30069 .61362 L F
.30297 .62806 m .31226 .61022 L .3087 .6082 L F
.30297 .62806 m .3098 .61873 L .31226 .61022 L F
0 g
.30072 .63694 m
.30297 .62806 L
s
.29498 .63346 m
.30297 .62806 L
s
.52374 .931 m .5235 .93016 L .52635 .92162 L 0 .258 .129 r
F
0 g
.5259 .92264 m
.52635 .92162 L
s
.52418 .92385 m
.52468 .92221 L
s
.52408 .9231 m
.52465 .92167 L
s
.52241 .9255 m
.5238 .92042 L
s
.52182 .92528 m
.52374 .92004 L
s
.52289 .92605 m
.52408 .9231 L
s
.50205 .93319 m .49101 .92236 L .49452 .92762 L 0 .449 .286 r
F
0 g
.49101 .92236 m
.49112 .92253 L
s
.49112 .92253 m
.49302 .92537 L
s
.48993 .92494 m
.49078 .92601 L
s
.49078 .92601 m
.49137 .92674 L
s
.49016 .9224 m
.49101 .92236 L
s
.75028 .60578 m .76974 .61091 L .76721 .60737 L 0 1 .477 r
F
0 g
.76974 .61091 m
.77739 .61384 L
s
.66574 .74822 m
.66577 .74846 L
s
.43402 .78418 m
.43594 .78364 L
s
.76794 .63238 m .77073 .63421 L .76675 .63561 L 0 0 0 r
F
.76794 .63238 m .77809 .62975 L .77073 .63421 L F
.44657 .86893 m .43792 .86509 L .44241 .86831 L 0 1 .45 r
F
.44657 .86893 m .43549 .86055 L .43792 .86509 L F
0 g
.43389 .86484 m
.43792 .86509 L
s
.44241 .86831 m
.44519 .87257 L
s
.51316 .94817 m .50987 .92758 L .5111 .93349 L 0 .288 .107 r
F
.51316 .94817 m .5094 .92804 L .50987 .92758 L F
0 g
.50934 .92268 m
.50987 .92758 L
s
.5591 .81007 m .56196 .81482 L .56611 .79243 L 0 1 .254 r
F
.55142 .6881 m .5624 .67714 L .56397 .67299 L 0 1 .366 r
F
.55142 .6881 m .55702 .68361 L .5624 .67714 L F
0 g
.5624 .67714 m
.56524 .67614 L
s
.65648 .57359 m
.66504 .58836 L
s
.34255 .64102 m .33501 .63364 L .33833 .6432 L 0 1 .273 r
F
0 g
.33416 .62286 m
.33501 .63364 L
s
.53482 .98225 m
.5358 .98279 L
s
.53912 .98688 m .53743 .98499 L .53787 .98393 L 0 .22 0 r
F
0 g
.5358 .98279 m
.53787 .98393 L
s
.51754 .9151 m .52195 .88835 L .5228 .87186 L 0 .481 .265 r
F
0 g
.5228 .87186 m
.52421 .8617 L
s
.52008 .87575 m
.52048 .86115 L
s
.44295 .92727 m .4339 .92654 L .43078 .92505 L 0 .008 0 r
F
.44295 .92727 m .43861 .92788 L .4339 .92654 L F
.44295 .92727 m .44249 .92819 L .43861 .92788 L F
.45459 .93049 m .44249 .92819 L .44295 .92727 L 0 .109 .01 r
F
0 g
.44295 .92727 m
.44677 .9275 L
s
.43983 .92578 m
.44295 .92727 L
s
.4514 .92872 m
.45535 .9288 L
s
.46728 .8928 m .45882 .88756 L .46343 .89122 L 0 .883 .44 r
F
.46728 .8928 m .45585 .88331 L .45882 .88756 L F
.46632 .89681 m .46343 .89122 L .45882 .88756 L 0 .886 .445 r
F
0 g
.45847 .88707 m
.45882 .88756 L
s
.45506 .88637 m
.45882 .88756 L
s
.40219 .84012 m .39106 .83457 L .393 .83954 L 0 1 .471 r
F
0 g
.38859 .84134 m
.393 .83954 L
s
.22988 .72919 m .22292 .72003 L .21881 .72599 L 0 1 .538 r
F
.22988 .72919 m .22926 .71671 L .22292 .72003 L F
.22988 .72919 m .23359 .71826 L .22926 .71671 L F
.22988 .72919 m .23385 .72362 L .23359 .71826 L F
0 g
.22356 .73248 m
.22988 .72919 L
s
.22988 .72919 m
.23026 .73426 L
s
.67774 .61251 m
.67964 .61348 L
s
.6989 1.09947 m .7034 1.08997 L .70817 1.09203 L 0 0 .024 r
F
0 g
.69717 1.09009 m
.7034 1.08997 L
s
.51316 .94818 m .52025 .92465 L .52064 .92497 L 0 .315 .124 r
F
.51316 .94818 m .51793 .93151 L .52025 .92465 L F
0 g
.52025 .92465 m
.52033 .92425 L
s
.38377 .77266 m .37439 .77061 L .37464 .77027 L 0 0 0 r
F
0 g
.36961 .76919 m
.37464 .77027 L
s
.45585 .88331 m .45362 .87707 L .44913 .87345 L 0 .97 .449 r
F
.45585 .88331 m .4565 .8813 L .45362 .87707 L F
.46728 .8928 m .4565 .8813 L .45585 .88331 L 0 .883 .44 r
F
0 g
.4519 .88243 m
.45585 .88331 L
s
.45585 .88331 m
.45847 .88707 L
s
.74558 .88941 m .75389 .88634 L .74925 .88727 L 0 1 .33 r
F
.73135 .89196 m .74557 .88941 L .7415 .88886 L 0 .847 .259 r
F
.3228 .82838 m .31217 .82652 L .31382 .83177 L 0 1 .508 r
F
0 g
.3097 .83589 m
.31382 .83177 L
s
.33829 .90278 m .33052 .90307 L .33486 .90377 L 0 1 .434 r
F
0 g
.33486 .90377 m
.33851 .90578 L
s
.33829 .90278 m .32743 .90079 L .33052 .90307 L 0 1 .434 r
F
0 g
.32769 .90423 m
.33052 .90307 L
s
.50656 .93146 m .50616 .93205 L .50368 .92931 L 0 .223 .096 r
F
.62794 .62447 m .64489 .62046 L .6415 .61979 L 0 1 .296 r
F
0 g
.64489 .62046 m
.65197 .61946 L
s
.50131 .91617 m .50135 .91462 L .49786 .90568 L 0 .517 .291 r
F
0 g
.49994 .90957 m
.50009 .90984 L
s
.49786 .90568 m
.49994 .90957 L
s
.49951 .90405 m
.50068 .90658 L
s
.50068 .90658 m
.50124 .90781 L
s
.49813 .90106 m
.49978 .90582 L
s
.49978 .90582 m
.50015 .90692 L
s
.50015 .90692 m
.50051 .90796 L
s
.50051 .90796 m
.50103 .90946 L
s
.51751 .96461 m .51921 .96818 L .51966 .96861 L 0 .07 .172 r
F
.51751 .96461 m .51831 .96671 L .51921 .96818 L F
0 g
.51921 .96818 m
.51944 .96849 L
s
.33645 .65283 m
.33832 .64343 L
s
.49318 .93419 m .49267 .93317 L .48917 .9309 L 0 .561 .414 r
F
0 g
.48941 .93106 m
.48956 .93115 L
s
.48917 .9309 m
.48941 .93106 L
s
.48917 .9309 m
.48982 .93107 L
s
.48917 .9309 m
.48928 .93099 L
s
.48928 .93099 m
.48932 .93102 L
s
.48932 .93102 m
.48932 .93103 L
s
.48932 .93103 m
.4894 .93109 L
s
.4894 .93109 m
.48945 .93113 L
s
.48945 .93113 m
.48976 .93139 L
s
.50315 .93789 m .49319 .93052 L .4965 .93201 L 0 .264 .099 r
F
.50315 .93789 m .49268 .93159 L .49319 .93052 L F
0 g
.49403 .92893 m
.49558 .93086 L
s
.49281 .93016 m
.49319 .93052 L
s
.49319 .93052 m
.4942 .93098 L
s
.46632 .89681 m .46664 .89518 L .46343 .89122 L 0 .886 .445 r
F
.47799 .9066 m .46632 .89681 L .46959 .90086 L 0 .779 .432 r
F
.47799 .9066 m .46664 .89518 L .46632 .89681 L F
0 g
.46256 .89561 m
.46632 .89681 L
s
.46632 .89681 m
.46928 .90047 L
s
.49332 .97465 m .48518 .97367 L .48677 .97831 L 0 .311 .295 r
F
.49332 .97465 m .48616 .96941 L .48518 .97367 L F
0 g
.48182 .97079 m
.48518 .97367 L
s
.50895 .95525 m .50799 .95419 L .50639 .95374 L 0 .264 .262 r
F
.51316 .94817 m .51028 .9343 L .5094 .92804 L 0 .288 .107 r
F
0 g
.50893 .92689 m
.5094 .92804 L
s
.34382 .65822 m
.34391 .65829 L
s
.33894 .65474 m
.34382 .65822 L
s
.33645 .65296 m
.33709 .65342 L
s
.33709 .65342 m
.33894 .65474 L
s
.58436 .64798 m
.58786 .64734 L
s
.55165 .80301 m .55288 .76991 L .55088 .78795 L 0 1 .272 r
F
.5438 .80016 m .55088 .78795 L .55288 .76991 L 0 1 .292 r
F
0 g
.55167 .7585 m
.55288 .76991 L
s
.55288 .76991 m
.55528 .76022 L
s
.5127 .89855 m .51319 .89971 L .51368 .883 L 0 .491 .268 r
F
.52551 1.08582 m .52161 1.07973 L .51889 1.07539 L 0 .193 0 r
F
.4244 .85303 m .41487 .84254 L .4133 .84625 L 0 1 .462 r
F
.4244 .85303 m .4193 .84202 L .41487 .84254 L F
.4244 .85303 m .42362 .84503 L .4193 .84202 L F
.4244 .85303 m .4258 .84975 L .42362 .84503 L F
.43549 .86055 m .4258 .84975 L .4244 .85303 L 0 1 .456 r
F
0 g
.41998 .85355 m
.4244 .85303 L
s
.4244 .85303 m
.42671 .85764 L
s
.59922 .63796 m .61501 .63073 L .6115 .6309 L 0 1 .238 r
F
0 g
.61501 .63073 m
.62171 .62847 L
s
.50777 1.05104 m .50349 1.04863 L .50689 1.05434 L 0 .073 .179 r
F
.50777 1.05104 m .50146 1.04339 L .50349 1.04863 L F
0 g
.50043 1.04503 m
.50349 1.04863 L
s
.72369 .66496 m .74095 .64533 L .73928 .65018 L 0 0 .011 r
F
0 g
.73782 .66504 m
.7385 .66291 L
s
.73846 .66446 m
.7385 .66291 L
s
.72963 .65536 m
.73109 .64958 L
s
.72001 .66112 m
.72648 .65232 L
s
.74095 .64533 m
.74773 .63781 L
s
.47767 .91284 m .47761 .91155 L .47403 .90807 L 0 .776 .44 r
F
0 g
.47403 .90807 m
.47458 .90831 L
s
.33833 .6432 m
.34255 .64102 L
s
.31737 .75124 m .30441 .74479 L .30534 .74798 L 0 .702 .411 r
F
0 g
.29906 .74815 m
.30534 .74798 L
s
.48972 .92441 m .4817 .91952 L .48634 .9227 L 0 .636 .42 r
F
.49023 .92675 m .48634 .9227 L .4817 .91952 L 0 .625 .421 r
F
0 g
.47807 .91614 m
.4817 .91952 L
s
.48148 .91943 m
.4817 .91952 L
s
.51316 .94818 m .52064 .92497 L .51861 .93207 L 0 .315 .124 r
F
0 g
.52064 .92497 m
.52079 .92453 L
s
.39106 .83456 m .38205 .8348 L .38638 .83661 L 0 1 .475 r
F
0 g
.38638 .83661 m
.38859 .84134 L
s
.51699 .80941 m .51544 .82846 L .51527 .81668 L 0 .586 .139 r
F
0 g
.5133 .80619 m
.51527 .81668 L
s
.51699 .80941 m .51945 .81144 L .52181 .82395 L 0 .586 .139 r
F
0 g
.51662 .80722 m
.51699 .80941 L
s
.51527 .81668 m
.51699 .80941 L
s
.51945 .81144 m
.52079 .80123 L
s
.52079 .80123 m
.52271 .81178 L
s
.51751 .96461 m .51966 .96861 L .51932 .96771 L 0 .07 .172 r
F
0 g
.51778 .96684 m
.51809 .96676 L
s
.51966 .96861 m
.51994 .96888 L
s
.51381 .96057 m .51503 .96354 L .51475 .9623 L 0 .171 .198 r
F
.51625 .96323 m .51475 .9623 L .51503 .96354 L 0 .118 .185 r
F
0 g
.51413 .96347 m
.51503 .96354 L
s
.51503 .96354 m
.51632 .96549 L
s
.4133 .84625 m .40393 .83599 L .40219 .84012 L 0 1 .467 r
F
.4133 .84625 m .40849 .83495 L .40393 .83599 L F
.4133 .84625 m .41281 .8377 L .40849 .83495 L F
.4133 .84625 m .41487 .84254 L .41281 .8377 L F
0 g
.40875 .84728 m
.4133 .84625 L
s
.4133 .84625 m
.41549 .85096 L
s
.49093 .98997 m .48923 .9853 L .48608 .98271 L 0 .295 .3 r
F
.51316 .94817 m .50529 .89459 L .50493 .89516 L 0 .343 .267 r
F
.51316 .94817 m .50783 .9103 L .50529 .89459 L F
0 g
.5052 .89389 m
.50529 .89459 L
s
.51316 .94817 m .50493 .89516 L .5072 .91129 L 0 .343 .267 r
F
0 g
.50476 .89437 m
.50493 .89516 L
s
.51316 .94817 m .50458 .89575 L .50447 .89596 L 0 .349 .269 r
F
.51316 .94817 m .5072 .91129 L .50458 .89575 L F
0 g
.50457 .89567 m
.50458 .89575 L
s
.48946 .92219 m .47767 .91284 L .48124 .91651 L 0 .642 .419 r
F
.48946 .92219 m .47761 .91155 L .47767 .91284 L F
0 g
.47565 .91213 m
.47767 .91284 L
s
.51316 .94817 m .50447 .89596 L .50701 .91167 L 0 .349 .269 r
F
0 g
.50445 .89582 m
.50447 .89596 L
s
.25751 .63604 m .25412 .62367 L .24737 .6325 L 0 1 .513 r
F
.25751 .63604 m .26212 .6182 L .25412 .62367 L F
.25751 .63604 m .26601 .61975 L .26212 .6182 L F
.25751 .63604 m .26403 .62741 L .26601 .61975 L F
0 g
.25573 .64358 m
.25751 .63604 L
s
.24955 .64148 m
.25751 .63604 L
s
.51316 .94817 m .5111 .93349 L .51228 .94186 L 0 .288 .107 r
F
.51316 .94817 m .51228 .94186 L .5111 .93349 L 0 .292 .108 r
F
.51316 .94817 m .51316 .94817 L .51228 .94186 L F
.51316 .94817 m .50586 .89389 L .50783 .9103 L 0 .339 .265 r
F
.51316 .94817 m .50626 .89353 L .50586 .89389 L F
0 g
.50582 .89366 m
.50586 .89389 L
s
.43549 .86055 m .43009 .84977 L .4258 .84975 L 0 1 .456 r
F
.43549 .86055 m .43441 .85309 L .43009 .84977 L F
.43549 .86055 m .43672 .85771 L .43441 .85309 L F
.44657 .86893 m .43672 .85771 L .43549 .86055 L 0 1 .45 r
F
0 g
.4312 .86052 m
.43549 .86055 L
s
.43549 .86055 m
.43792 .86509 L
s
.51316 .94817 m .50416 .89672 L .50385 .89752 L 0 .353 .269 r
F
.51316 .94817 m .50701 .91167 L .50416 .89672 L F
0 g
.50405 .89605 m
.50416 .89672 L
s
.47875 .93459 m .47111 .93105 L .47563 .93252 L 0 .222 .067 r
F
0 g
.47704 .92941 m
.4796 .93122 L
s
.47875 .93459 m .46735 .93088 L .47111 .93105 L 0 .222 .067 r
F
.47992 .93144 m .47563 .93252 L .47111 .93105 L 0 .201 .066 r
F
0 g
.46785 .9309 m
.47111 .93105 L
s
.46823 .92902 m
.47111 .93105 L
s
.33342 .83046 m .3248 .82222 L .3228 .82838 L 0 1 .503 r
F
.33342 .83046 m .32943 .81832 L .3248 .82222 L F
.33342 .83046 m .33361 .81929 L .32943 .81832 L F
.33342 .83046 m .33532 .8245 L .33361 .81929 L F
0 g
.32879 .83435 m
.33342 .83046 L
s
.33342 .83046 m
.3352 .83558 L
s
.26914 .93202 m .25931 .92925 L .25659 .92951 L 0 .561 .226 r
F
.26914 .93202 m .26397 .93004 L .25931 .92925 L F
.26914 .93202 m .26818 .93123 L .26397 .93004 L F
.28067 .93346 m .26818 .93123 L .26914 .93202 L 0 .511 .21 r
F
0 g
.26641 .93228 m
.26914 .93202 L
s
.26914 .93202 m
.2733 .93296 L
s
.51316 .94817 m .50853 .90966 L .50626 .89353 L 0 .339 .265 r
F
0 g
.5071 .92715 m
.50803 .92884 L
s
.50624 .89342 m
.50626 .89353 L
s
.47799 .9066 m .46959 .90086 L .47429 .90464 L 0 .779 .432 r
F
.47764 .90965 m .47429 .90464 L .46959 .90086 L 0 .779 .436 r
F
0 g
.46598 .89928 m
.46959 .90086 L
s
.46928 .90047 m
.46959 .90086 L
s
.47403 .90807 m
.47503 .90904 L
s
.21411 .83229 m .20407 .82314 L .20252 .8311 L 0 1 .534 r
F
.21411 .83229 m .2087 .81763 L .20407 .82314 L F
.21411 .83229 m .21332 .81827 L .2087 .81763 L F
.21411 .83229 m .21563 .82456 L .21332 .81827 L F
0 g
.20949 .83776 m
.21411 .83229 L
s
.21411 .83229 m
.21645 .83837 L
s
.52396 .97265 m
.52427 .97292 L
s
.52605 .975 m .52465 .97354 L .52464 .97324 L 0 .07 0 r
F
0 g
.52464 .97324 m
.52464 .97333 L
s
.52464 .97333 m
.52464 .97339 L
s
.52427 .97292 m
.52464 .97324 L
s
.51316 .94817 m .50385 .89752 L .50647 .91307 L 0 .353 .269 r
F
0 g
.50498 .92753 m
.50625 .92931 L
s
.50371 .89698 m
.50385 .89752 L
s
.50368 .92931 m
.50412 .9298 L
s
.50368 .92931 m
.50396 .92985 L
s
.19933 .88412 m .18779 .87708 L .18772 .88285 L 0 1 .527 r
F
0 g
.18772 .88285 m
.19115 .88747 L
s
.49533 1.00171 m .48869 1.00131 L .49092 1.00642 L 0 .259 .285 r
F
.49533 1.00171 m .48857 .99628 L .48869 1.00131 L F
0 g
.48547 .9984 m
.48869 1.00131 L
s
.73135 .89196 m .7415 .88886 L .7358 .89006 L 0 .847 .259 r
F
.72051 .89407 m .73135 .89196 L .72827 .89171 L 0 .771 .241 r
F
.40667 .91976 m .39791 .91748 L .39541 .91693 L 0 0 0 r
F
.40667 .91976 m .40264 .91881 L .39791 .91748 L F
.40633 .91985 m .39791 .91748 L .40264 .91881 L 0 .348 .187 r
F
.40633 .91985 m .40014 .91796 L .39791 .91748 L F
.40014 .91796 m .39451 .91624 L .39791 .91748 L F
.39541 .91693 m .39791 .91748 L .3946 .91673 L 0 0 0 r
F
.40667 .91976 m .4064 .91979 L .40264 .91881 L F
.41844 .92276 m .4064 .91979 L .40667 .91976 L F
0 g
.40667 .91976 m
.41039 .92057 L
s
.49041 .96456 m .48931 .96053 L .48603 .95784 L 0 .358 .302 r
F
.39106 .83456 m .38036 .82974 L .38205 .8348 L 0 1 .475 r
F
0 g
.37769 .83707 m
.38205 .8348 L
s
.47992 .93144 m .47941 .93269 L .47563 .93252 L 0 .201 .066 r
F
.49096 .93597 m .47992 .93144 L .48357 .93189 L 0 .251 .085 r
F
.49096 .93597 m .47941 .93269 L .47992 .93144 L F
0 g
.4796 .93122 m
.47992 .93144 L
s
.47992 .93144 m
.48054 .93152 L
s
.51316 .94817 m .50687 .89314 L .50853 .90966 L 0 .338 .264 r
F
.51316 .94817 m .50729 .893 L .50687 .89314 L F
0 g
.50684 .89296 m
.50687 .89314 L
s
.50687 .89314 m
.50691 .89355 L
s
.52491 .93888 m .53639 .91814 L .53658 .92074 L 0 .263 .134 r
F
.52491 .93888 m .5328 .92235 L .53639 .91814 L F
0 g
.53639 .91814 m
.53713 .91546 L
s
.52585 .9231 m
.52635 .92162 L
s
.5562 1.11998 m .55149 1.11354 L .54898 1.10778 L 0 .352 .029 r
F
.51316 .94817 m .50872 .92877 L .51028 .9343 L 0 .285 .108 r
F
.51316 .94817 m .50827 .92927 L .50872 .92877 L F
0 g
.50849 .92758 m
.50872 .92877 L
s
.31217 .82652 m .30311 .83014 L .30739 .83077 L 0 1 .513 r
F
0 g
.30739 .83077 m
.3097 .83589 L
s
.32547 .61504 m .31759 .61356 L .32113 .61602 L 0 1 .433 r
F
.32547 .61504 m .31669 .60922 L .31759 .61356 L F
.32547 .61504 m .31902 .60588 L .31669 .60922 L F
.32547 .61504 m .32337 .60491 L .31902 .60588 L F
.32547 .61504 m .32682 .60694 L .32337 .60491 L F
.32547 .61504 m .32772 .61129 L .32682 .60694 L F
0 g
.32547 .61504 m
.3264 .62045 L
s
.32113 .61602 m
.32547 .61504 L
s
.32772 .61129 m
.33198 .61026 L
s
.34915 .90494 m .34138 .90488 L .34572 .90565 L 0 .908 .403 r
F
0 g
.34572 .90565 m
.34934 .90748 L
s
.34915 .90494 m .33829 .90278 L .34138 .90488 L 0 .908 .403 r
F
0 g
.33851 .90578 m
.34138 .90488 L
s
.45765 .87834 m .44913 .87345 L .45362 .87707 L 0 .966 .443 r
F
.45765 .87834 m .44657 .86893 L .44913 .87345 L F
0 g
.44519 .87257 m
.44913 .87345 L
s
.49618 .95354 m .48675 .95047 L .48774 .95449 L 0 .372 .292 r
F
.49618 .95354 m .4887 .94763 L .48675 .95047 L F
0 g
.4833 .94733 m
.48675 .95047 L
s
.79405 1.03835 m .80469 1.03019 L .80035 1.03271 L 0 1 .29 r
F
.78331 1.04502 m .79405 1.03835 L .79383 1.03673 L 0 1 .233 r
F
.51316 .94817 m .50342 .89884 L .50315 .89981 L 0 .363 .271 r
F
.51316 .94817 m .50647 .91307 L .50342 .89884 L F
0 g
.5033 .89823 m
.50342 .89884 L
s
.19933 .88412 m .19133 .87326 L .18779 .87708 L 0 1 .527 r
F
.19933 .88412 m .19599 .87398 L .19133 .87326 L F
.19933 .88412 m .19942 .87865 L .19599 .87398 L F
.21094 .88541 m .19942 .87865 L .19933 .88412 L 0 1 .525 r
F
0 g
.19579 .88789 m
.19933 .88412 L
s
.19933 .88412 m
.20274 .88853 L
s
.46735 .93088 m .463 .93204 L .45836 .93066 L 0 .161 .042 r
F
.46735 .93088 m .46685 .93213 L .463 .93204 L F
.47875 .93459 m .46685 .93213 L .46735 .93088 L 0 .222 .067 r
F
0 g
.46433 .92902 m
.46735 .93088 L
s
.46735 .93088 m
.46785 .9309 L
s
.67511 .66225 m
.67747 .68029 L
s
.67511 .66225 m
.67866 .67317 L
s
.43022 .92605 m .42214 .9234 L .42684 .92462 L 0 0 0 r
F
.43022 .92605 m .41844 .92276 L .42214 .9234 L F
0 g
.41909 .92223 m
.42214 .9234 L
s
.42684 .92462 m
.43078 .92505 L
s
.40219 .84012 m .39297 .83002 L .39106 .83457 L 0 1 .471 r
F
.40219 .84012 m .39766 .8285 L .39297 .83002 L F
0 g
.39106 .83457 m
.393 .83954 L
s
.40219 .84012 m .40199 .83101 L .39766 .8285 L 0 1 .471 r
F
.40219 .84012 m .40393 .83599 L .40199 .83101 L F
0 g
.3975 .84164 m
.40219 .84012 L
s
.40219 .84012 m
.40425 .84495 L
s
.50051 1.03702 m .50146 1.04339 L .50215 1.04211 L 0 .166 .24 r
F
.50777 1.05104 m .50215 1.04211 L .50146 1.04339 L 0 .073 .179 r
F
0 g
.50146 1.04339 m
.50349 1.04863 L
s
.49844 1.04017 m
.50146 1.04339 L
s
.5438 .80016 m .54806 .76127 L .54417 .7742 L 0 1 .292 r
F
.49197 .93165 m .49155 .93065 L .48796 .92811 L 0 .588 .418 r
F
0 g
.48796 .92811 m
.48931 .92906 L
s
.48796 .92811 m
.48857 .92832 L
s
.48976 .93139 m
.49004 .93162 L
s
.48956 .93115 m
.4907 .93189 L
s
.4905 .93126 m
.49071 .93131 L
s
.48982 .93107 m
.4905 .93126 L
s
.51316 .94817 m .50927 .9094 L .50729 .893 L 0 .338 .264 r
F
0 g
.50735 .89349 m
.50736 .89354 L
s
.50729 .893 m
.50735 .89349 L
s
.50728 .89284 m
.50729 .893 L
s
.58217 .49333 m .57664 .49284 L .57542 .49078 L 0 .094 0 r
F
.58217 .49333 m .58561 .49883 L .57664 .49284 L F
.58217 .49333 m .59633 .50473 L .58561 .49883 L F
.58217 .49333 m .60307 .50728 L .59633 .50473 L F
0 g
.59875 .50052 m
.60066 .50246 L
s
.58217 .49333 m .60134 .50478 L .60307 .50728 L 0 .094 0 r
F
.58217 .49333 m .59238 .49881 L .60134 .50478 L F
0 g
.59238 .49881 m
.59875 .50052 L
s
.57359 .48723 m
.58217 .49333 L
s
.50315 .93789 m .49541 .93441 L .49268 .93159 L 0 .264 .099 r
F
.50315 .93789 m .4965 .93201 L .50041 .93507 L F
.50386 .93618 m .50041 .93507 L .4965 .93201 L 0 .253 .098 r
F
.50315 .93789 m .49957 .93711 L .49541 .93441 L 0 .264 .099 r
F
.50254 .93775 m .49156 .92698 L .49198 .93008 L 0 .425 .285 r
F
.50254 .93775 m .49452 .92762 L .49156 .92698 L F
0 g
.49137 .92674 m
.49156 .92698 L
s
.4927 .93495 m
.49309 .93519 L
s
.49188 .93144 m
.49268 .93159 L
s
.49343 .92739 m
.49376 .92746 L
s
.49277 .92724 m
.49343 .92739 L
s
.49156 .92698 m
.49277 .92724 L
s
.51544 1.06897 m .51575 1.07082 L .51848 1.07465 L 0 0 .15 r
F
0 g
.51575 1.07082 m
.51889 1.07539 L
s
.32682 .60694 m
.32772 .61129 L
s
.51316 .94817 m .51028 .9343 L .51192 .94221 L 0 .285 .108 r
F
.51316 .94817 m .51192 .94221 L .51028 .9343 L 0 .288 .107 r
F
.51316 .94817 m .51316 .94817 L .51192 .94221 L F
.51316 .94817 m .50315 .89981 L .506 .91476 L 0 .363 .271 r
F
0 g
.50292 .89905 m
.50315 .89981 L
s
.46728 .8928 m .46034 .88288 L .4565 .8813 L 0 .883 .44 r
F
.21094 .88541 m .20298 .87506 L .19942 .87865 L 0 1 .525 r
F
.21094 .88541 m .20764 .87578 L .20298 .87506 L F
.21094 .88541 m .21105 .88023 L .20764 .87578 L F
.22255 .88672 m .21105 .88023 L .21094 .88541 L 0 1 .523 r
F
0 g
.20738 .88896 m
.21094 .88541 L
s
.21094 .88541 m
.21433 .88961 L
s
.47799 .9066 m .47035 .89713 L .46664 .89518 L 0 .779 .432 r
F
0 g
.46343 .89122 m
.46664 .89518 L
s
.55618 .48419 m .56666 .48707 L .57542 .49078 L 0 .02 0 r
F
0 g
.56666 .48707 m
.57359 .48723 L
s
.59238 .49881 m
.59992 .50384 L
s
.52414 .87929 m .52501 .88465 L .52752 .87149 L 0 .556 .26 r
F
.48946 .92219 m .48111 .91361 L .47761 .91155 L 0 .642 .419 r
F
0 g
.47503 .90904 m
.47761 .91155 L
s
.47786 .91481 m
.48105 .91642 L
s
.51316 .94818 m .5212 .92554 L .52156 .92598 L 0 .31 .125 r
F
.51316 .94818 m .51861 .93207 L .5212 .92554 L F
0 g
.5212 .92554 m
.52137 .92483 L
s
.33528 .59932 m .32337 .6049 L .32682 .60694 L 0 1 .43 r
F
.33528 .59932 m .32688 .59517 L .32337 .6049 L F
.33528 .59932 m .33502 .58423 L .32688 .59517 L F
.33528 .59932 m .34348 .57661 L .33502 .58423 L F
.33528 .59932 m .34662 .5774 L .34348 .57661 L F
.33528 .59932 m .3431 .58713 L .34662 .5774 L F
0 g
.33199 .61026 m
.33528 .59932 L
s
.32682 .60694 m
.33528 .59932 L
s
.3431 .58713 m
.35132 .57825 L
s
.51754 .9151 m .52 .87873 L .5184 .89853 L 0 .481 .265 r
F
.51637 .90996 m .5184 .89853 L .52 .87873 L 0 .489 .265 r
F
0 g
.52 .87873 m
.52188 .86733 L
s
.52 .87873 m
.52008 .87575 L
s
.49041 .96456 m .48616 .96941 L .48906 .96836 L 0 .358 .302 r
F
.49332 .97465 m .48906 .96836 L .48616 .96941 L 0 .311 .295 r
F
0 g
.48518 .97367 m
.48616 .96941 L
s
.48289 .96671 m
.48616 .96941 L
s
.54132 1.10625 m .54435 1.10426 L .54696 1.10941 L 0 .325 0 r
F
0 g
.54435 1.10426 m
.54898 1.10778 L
s
.51137 .95791 m .5104 .95684 L .50915 .95658 L 0 .22 .222 r
F
0 g
.5346 .98237 m
.53482 .98225 L
s
.80675 .80017 m .82015 .79729 L .8183 .80027 L 0 0 0 r
F
0 g
.81803 .79454 m
.82015 .79729 L
s
.82015 .79729 m
.82503 .79543 L
s
.22255 .88672 m .21463 .87687 L .21105 .88023 L 0 1 .523 r
F
.22255 .88672 m .21928 .8776 L .21463 .87687 L F
.22255 .88672 m .22268 .88183 L .21928 .8776 L F
.23416 .88805 m .22268 .88183 L .22255 .88672 L 0 1 .52 r
F
0 g
.21897 .89005 m
.22255 .88672 L
s
.22255 .88672 m
.22593 .89071 L
s
.51316 .94817 m .50795 .89296 L .50927 .9094 L 0 .341 .264 r
F
.51316 .94817 m .50839 .89305 L .50795 .89296 L F
0 g
.50741 .87625 m
.50839 .89298 L
s
.50794 .89287 m
.50795 .89296 L
s
.50904 .89302 m
.50904 .89302 L
s
.50741 .87625 m
.50904 .89302 L
s
.50795 .89296 m
.50798 .89335 L
s
.50798 .89335 m
.50799 .89354 L
s
.51316 .94817 m .50949 .93519 L .50827 .92927 L 0 .285 .108 r
F
0 g
.50803 .92884 m
.50827 .92927 L
s
.50131 .92019 m .5013 .91856 L .49774 .91054 L 0 .505 .29 r
F
0 g
.49774 .91054 m
.49805 .91124 L
s
.49805 .91124 m
.49912 .91364 L
s
.49774 .91054 m
.49817 .91122 L
s
.49817 .91122 m
.49941 .91316 L
s
.50037 .91469 m
.50077 .91531 L
s
.50025 .91449 m
.50037 .91469 L
s
.49941 .91316 m
.50025 .91449 L
s
.50065 .91088 m
.50073 .91103 L
s
.50073 .91103 m
.50114 .9118 L
s
.50009 .90984 m
.50065 .91088 L
s
.50077 .91314 m
.50102 .91377 L
s
.49786 .90568 m
.50032 .91198 L
s
.50032 .91198 m
.50064 .9128 L
s
.50064 .9128 m
.50077 .91314 L
s
.51316 .94817 m .50277 .90136 L .50255 .90247 L 0 .375 .273 r
F
.51316 .94817 m .506 .91476 L .50277 .90136 L F
0 g
.50259 .90054 m
.50277 .90136 L
s
.50498 .92753 m
.50594 .92993 L
s
.50625 .92931 m
.50657 .92976 L
s
.53876 .76713 m .54253 .76497 L .54654 .75434 L 0 1 .323 r
F
0 g
.54399 .76109 m
.54654 .75434 L
s
.54654 .75434 m
.54806 .76127 L
s
.54649 .7665 m
.54806 .76127 L
s
.44657 .86893 m .44088 .85832 L .43672 .85771 L 0 1 .45 r
F
.44657 .86893 m .44519 .86199 L .44088 .85832 L F
.44657 .86893 m .44763 .86654 L .44519 .86199 L F
.45765 .87834 m .44763 .86654 L .44657 .86893 L 0 .966 .443 r
F
0 g
.44657 .86893 m
.44913 .87345 L
s
.44241 .86831 m
.44657 .86893 L
s
.45362 .87707 m
.4565 .8813 L
s
.49096 .93597 m .48357 .93189 L .48794 .93374 L 0 .251 .085 r
F
.49197 .93322 m .48794 .93374 L .48357 .93189 L 0 .234 .084 r
F
0 g
.48166 .9303 m
.48357 .93189 L
s
.4907 .93189 m
.49126 .93225 L
s
.48054 .93152 m
.48357 .93189 L
s
.51982 .81337 m
.52181 .82395 L
s
.51945 .81144 m
.51982 .81337 L
s
.50168 .92873 m .49384 .92091 L .49837 .92612 L 0 .47 .288 r
F
.50205 .93319 m .49837 .92612 L .49384 .92091 L 0 .449 .286 r
F
0 g
.49345 .92023 m
.49384 .92091 L
s
.49357 .92077 m
.49384 .92091 L
s
.49302 .92537 m
.49388 .92667 L
s
.38377 .77266 m .37789 .77189 L .37439 .77061 L 0 0 0 r
F
.38377 .77266 m .38322 .77346 L .37789 .77189 L F
.38377 .77266 m .38682 .77427 L .38322 .77346 L F
.38377 .77266 m .38705 .77393 L .38682 .77427 L F
0 g
.37846 .7711 m
.38377 .77266 L
s
.81305 1.01632 m .82108 1.01727 L .82413 1.01 L 0 1 .413 r
F
0 g
.81555 1.02438 m
.82108 1.01727 L
s
.82108 1.01727 m
.82206 1.02119 L
s
.50556 .94468 m .49801 .942 L .50074 .9435 L 0 .342 .355 r
F
0 g
.49639 .94231 m
.49843 .94325 L
s
.50556 .94468 m .49727 .94095 L .49801 .942 L 0 .342 .355 r
F
0 g
.49843 .94325 m
.49902 .94352 L
s
.49639 .94231 m
.49801 .942 L
s
.3828 .91395 m
.3828 .91395 L
s
.50556 .94468 m .49917 .94119 L .49727 .94095 L 0 .342 .355 r
F
0 g
.49427 .93944 m
.49727 .94095 L
s
.49801 .942 m
.49809 .94205 L
s
.31217 .82652 m .30152 .82483 L .30311 .83014 L 0 1 .513 r
F
0 g
.29895 .83443 m
.30311 .83014 L
s
.50654 .94625 m .49916 .94359 L .49996 .94464 L 0 .326 .343 r
F
.50654 .94625 m .50074 .9435 L .49916 .94359 L F
0 g
.49869 .94518 m
.50106 .94617 L
s
.49902 .94352 m
.49916 .94359 L
s
.49916 .94359 m
.49971 .94356 L
s
.55618 .48419 m .54955 .48486 L .54885 .48324 L 0 .02 0 r
F
.55618 .48419 m .55832 .48857 L .54955 .48486 L F
.55618 .48419 m .56932 .4919 L .55832 .48857 L F
.55618 .48419 m .57664 .49284 L .56932 .4919 L F
.55618 .48419 m .57542 .49078 L .57664 .49284 L F
0 g
.57592 .49096 m
.58217 .49333 L
s
.57542 .49078 m
.57592 .49096 L
s
.5478 .48045 m
.55618 .48419 L
s
.56666 .48707 m
.57542 .49078 L
s
.38036 .82974 m .37122 .83058 L .37556 .83221 L 0 1 .479 r
F
0 g
.37556 .83221 m
.37769 .83707 L
s
.72051 .89407 m .72827 .89171 L .72392 .8927 L 0 .771 .241 r
F
.70967 .8964 m .72051 .89407 L .71741 .89427 L 0 .693 .212 r
F
.73144 1.08395 m .72724 1.08394 L .72712 1.08185 L 0 0 0 r
F
0 g
.72712 1.08185 m
.72724 1.08394 L
s
.7203 1.08333 m
.72712 1.08185 L
s
.23416 .88805 m .22627 .87869 L .22268 .88183 L 0 1 .52 r
F
.23416 .88805 m .23092 .87942 L .22627 .87869 L F
.23416 .88805 m .2343 .88344 L .23092 .87942 L F
.24576 .8894 m .2343 .88344 L .23416 .88805 L 0 1 .517 r
F
0 g
.23057 .89115 m
.23416 .88805 L
s
.23416 .88805 m
.23752 .89183 L
s
.58789 .64951 m
.58959 .65157 L
s
.58959 .65157 m
.59063 .65283 L
s
.58437 .64892 m
.58789 .64951 L
s
.50467 .94313 m .49622 .93937 L .49917 .94119 L 0 .364 .365 r
F
.50467 .94313 m .49555 .93833 L .49622 .93937 L F
0 g
.49427 .93944 m
.49622 .93937 L
s
.50654 .94625 m .49996 .94464 L .50244 .94582 L 0 .326 .343 r
F
0 g
.49996 .94464 m
.50004 .94468 L
s
.50004 .94468 m
.50068 .94498 L
s
.49869 .94518 m
.49996 .94464 L
s
.51942 .96674 m .52108 .96998 L .52252 .97139 L 0 .045 .166 r
F
0 g
.51961 .96847 m
.51966 .96861 L
s
.51942 .96674 m .51932 .96771 L .52108 .96998 L 0 .045 .166 r
F
0 g
.52068 .9696 m
.52108 .96998 L
s
.51316 .94817 m .50255 .90247 L .5056 .91671 L 0 .375 .273 r
F
0 g
.50217 .90136 m
.50255 .90247 L
s
.51316 .94817 m .51005 .90957 L .50839 .89305 L 0 .341 .264 r
F
0 g
.50844 .89353 m
.50847 .89379 L
s
.50841 .89322 m
.50844 .89353 L
s
.50839 .89305 m
.50841 .89322 L
s
.50907 .89325 m
.50907 .89325 L
s
.50905 .89307 m
.50907 .89325 L
s
.50907 .89325 m
.50907 .89326 L
s
.50905 .89302 m
.50905 .89307 L
s
.50904 .89302 m
.50905 .89302 L
s
.50839 .89298 m
.50839 .89305 L
s
.54511 .71838 m .54359 .70997 L .54244 .71675 L 0 1 .348 r
F
.54511 .71838 m .54831 .70131 L .54359 .70997 L F
.54192 .74003 m .54511 .71838 L .54074 .72816 L 0 1 .337 r
F
.50467 .94313 m .49775 .9389 L .49555 .93833 L 0 .364 .365 r
F
0 g
.49302 .93695 m
.49555 .93833 L
s
.49809 .94205 m
.49925 .94268 L
s
.35536 .57039 m .34348 .57661 L .34662 .5774 L 0 1 .427 r
F
0 g
.3431 .58713 m
.34662 .5774 L
s
.35536 .57039 m .3478 .56875 L .34348 .57661 L 0 1 .427 r
F
.35536 .57039 m .35671 .55907 L .3478 .56875 L F
.35536 .57039 m .36546 .55206 L .35671 .55907 L F
.35536 .57039 m .36821 .55241 L .36546 .55206 L F
.35536 .57039 m .36388 .56026 L .36821 .55241 L F
0 g
.35132 .57825 m
.35536 .57039 L
s
.34662 .5774 m
.35536 .57039 L
s
.36388 .56026 m
.37234 .55267 L
s
.49667 1.01931 m .49434 1.01414 L .49138 1.01135 L 0 .222 .273 r
F
.54132 1.10625 m .53696 1.09987 L .53437 1.09474 L 0 .325 0 r
F
.55142 .6881 m .56397 .67299 L .5606 .67293 L 0 1 .366 r
F
0 g
.56397 .67299 m
.5695 .66638 L
s
.37649 .67271 m .36636 .67697 L .36965 .67548 L 0 0 0 r
F
.77209 .79642 m .77898 .8026 L .77438 .80216 L 0 .165 .038 r
F
.77209 .79642 m .78365 .79839 L .77898 .8026 L F
.49093 .98997 m .48857 .99628 L .49064 .99468 L 0 .295 .3 r
F
.49533 1.00171 m .49064 .99468 L .48857 .99628 L 0 .259 .285 r
F
0 g
.48857 .99628 m
.48869 1.00131 L
s
.48543 .99368 m
.48857 .99628 L
s
.50759 .94785 m .5012 .94623 L .50206 .94729 L 0 .307 .328 r
F
.50759 .94785 m .50244 .94582 L .5012 .94623 L F
0 g
.50106 .94617 m
.5012 .94623 L
s
.5012 .94623 m
.50146 .94615 L
s
.54832 .70131 m .55702 .68361 L .55142 .6881 L 0 1 .356 r
F
0 g
.55702 .68361 m
.56005 .68408 L
s
.55702 .68361 m
.5624 .67714 L
s
.24737 .6325 m .23508 .63684 L .23922 .63813 L 0 1 .516 r
F
0 g
.23819 .64557 m
.23922 .63813 L
s
.24576 .8894 m .23791 .88052 L .2343 .88344 L 0 1 .517 r
F
.24576 .8894 m .24256 .88126 L .23791 .88052 L F
.24576 .8894 m .24593 .88508 L .24256 .88126 L F
.25737 .8908 m .24593 .88508 L .24576 .8894 L 0 1 .513 r
F
0 g
.24216 .89229 m
.24576 .8894 L
s
.24576 .8894 m
.24912 .89299 L
s
.49332 .97465 m .48677 .97831 L .48983 .98057 L 0 .311 .295 r
F
0 g
.48608 .98271 m
.48677 .97831 L
s
.20252 .8311 m .1925 .82169 L .19092 .82988 L 0 1 .534 r
F
.20252 .8311 m .19716 .81601 L .1925 .82169 L F
0 g
.19092 .82988 m
.19323 .83631 L
s
.20252 .8311 m .20178 .81667 L .19716 .81601 L 0 1 .534 r
F
.20252 .8311 m .20407 .82314 L .20178 .81667 L F
0 g
.19787 .83673 m
.20252 .8311 L
s
.20252 .8311 m
.20484 .83735 L
s
.7044 .60733 m .72359 .60903 L .72068 .60652 L 0 1 .429 r
F
0 g
.72359 .60903 m
.73132 .61039 L
s
.30441 .74479 m .29389 .74292 L .29818 .74483 L 0 .889 .471 r
F
0 g
.29818 .74483 m
.29905 .74815 L
s
.73144 1.08395 m .73741 1.07631 L .7418 1.07536 L 0 0 0 r
F
0 g
.73113 1.07909 m
.73741 1.07631 L
s
.73714 1.07518 m
.73741 1.07631 L
s
.50386 .94161 m .4946 .93677 L .49775 .9389 L 0 .393 .373 r
F
.50386 .94161 m .49401 .93573 L .4946 .93677 L F
0 g
.49297 .93663 m
.4946 .93677 L
s
.74079 .60814 m .75741 .60942 L .75028 .60578 L 0 1 .457 r
F
0 g
.75741 .60942 m
.75975 .61263 L
s
.75741 .60942 m
.76574 .61162 L
s
.42315 .78138 m
.42808 .78266 L
s
.51316 .94818 m .52156 .92598 L .51924 .93285 L 0 .31 .125 r
F
0 g
.51493 .92902 m
.51533 .92403 L
s
.52156 .92598 m
.52182 .92528 L
s
.36 .90729 m .35224 .90686 L .35658 .90771 L 0 .78 .36 r
F
0 g
.35658 .90771 m
.36017 .90936 L
s
.36 .90729 m .34915 .90494 L .35224 .90686 L 0 .78 .36 r
F
0 g
.34934 .90748 m
.35224 .90686 L
s
.50759 .94785 m .50206 .94729 L .50426 .94816 L 0 .307 .328 r
F
0 g
.50206 .94729 m
.50211 .94731 L
s
.50114 .94804 m
.50206 .94729 L
s
.39106 .83456 m .38243 .82481 L .38036 .82974 L 0 1 .475 r
F
.39106 .83456 m .38711 .82276 L .38243 .82481 L F
.39106 .83456 m .39128 .82496 L .38711 .82276 L F
.39106 .83456 m .39297 .83002 L .39128 .82496 L F
0 g
.38638 .83661 m
.39106 .83456 L
s
.48946 .92219 m .48124 .91651 L .48595 .92012 L 0 .642 .419 r
F
.48972 .92441 m .48595 .92012 L .48124 .91651 L 0 .636 .42 r
F
0 g
.47767 .91284 m
.48124 .91651 L
s
.48105 .91642 m
.48124 .91651 L
s
.39865 .66441 m .38895 .66822 L .39188 .66742 L 0 1 .276 r
F
.39865 .66441 m .39161 .66602 L .38895 .66822 L F
0 g
.38991 .66857 m
.39188 .66742 L
s
.39865 .66441 m .3981 .66227 L .39161 .66602 L 0 1 .276 r
F
.39865 .66441 m .40489 .65925 L .3981 .66227 L F
.39865 .66441 m .40744 .65898 L .40489 .65925 L F
.39865 .66441 m .40476 .6612 L .40744 .65898 L F
0 g
.39625 .66641 m
.39865 .66441 L
s
.39188 .66742 m
.39865 .66441 L
s
.41068 .77902 m .40169 .7769 L .40543 .77736 L 0 0 0 r
F
0 g
.40543 .77736 m
.40612 .7767 L
s
.37649 .67271 m .36852 .67617 L .36636 .67697 L 0 0 0 r
F
.37649 .67271 m .37472 .67359 L .36852 .67617 L F
.37649 .67271 m .38159 .6708 L .37472 .67359 L F
0 g
.37455 .67385 m
.3756 .67323 L
s
.37649 .67271 m .38454 .66967 L .38159 .6708 L 0 0 0 r
F
.37649 .67271 m .38235 .67049 L .38454 .66967 L F
0 g
.36965 .67548 m
.37649 .67271 L
s
.51316 .94817 m .50224 .90423 L .50206 .90547 L 0 .386 .274 r
F
.51316 .94817 m .5056 .91671 L .50224 .90423 L F
0 g
.50192 .903 m
.50224 .90423 L
s
.50963 .92963 m
.50963 .92963 L
s
.32724 .75577 m .32115 .75025 L .31737 .75124 L 0 .571 .343 r
F
0 g
.31737 .75124 m
.31754 .75321 L
s
.32724 .75577 m .32687 .75117 L .32115 .75025 L 0 .571 .343 r
F
.32724 .75577 m .33069 .7534 L .32687 .75117 L F
.32724 .75577 m .33084 .75537 L .33069 .7534 L F
0 g
.32155 .75485 m
.32724 .75577 L
s
.32724 .75577 m
.32756 .75719 L
s
.50254 .93775 m .49198 .93008 L .49541 .93441 L 0 .425 .285 r
F
0 g
.49198 .93008 m
.49208 .93021 L
s
.49136 .9333 m
.49154 .9335 L
s
.49111 .93033 m
.49198 .93008 L
s
.50386 .94161 m .49649 .93663 L .49401 .93573 L 0 .393 .373 r
F
0 g
.49309 .93519 m
.49401 .93573 L
s
.49727 .94095 m
.49813 .94106 L
s
.38036 .82974 m .36964 .82538 L .37122 .83058 L 0 1 .479 r
F
0 g
.36677 .83325 m
.37122 .83058 L
s
.25737 .8908 m .24954 .88238 L .24593 .88508 L 0 1 .513 r
F
.25737 .8908 m .2542 .88313 L .24954 .88238 L F
.25737 .8908 m .25755 .88674 L .2542 .88313 L F
.26898 .89223 m .25755 .88674 L .25737 .8908 L 0 1 .508 r
F
0 g
.25376 .89347 m
.25737 .8908 L
s
.25737 .8908 m
.26072 .89419 L
s
.75214 1.06776 m .76294 1.06132 L .75874 1.06423 L 0 0 0 r
F
.7418 1.07536 m .75214 1.06776 L .75245 1.06888 L F
.49098 .92916 m .49066 .92819 L .48701 .92537 L 0 .609 .42 r
F
0 g
.48857 .92832 m
.49042 .92897 L
s
.60744 .50933 m .60307 .50728 L .60134 .50478 L 0 .107 0 r
F
0 g
.60134 .50478 m
.60151 .50491 L
s
.59992 .50384 m
.60134 .50478 L
s
.60744 .50933 m .61214 .51581 L .60307 .50728 L 0 .107 0 r
F
.60744 .50933 m .6225 .52468 L .61214 .51581 L F
.60744 .50933 m .62859 .52922 L .6225 .52468 L F
0 g
.62304 .52157 m
.62417 .52311 L
s
.60744 .50933 m .62637 .5264 L .62859 .52922 L 0 .107 0 r
F
0 g
.62417 .52311 m
.62447 .5235 L
s
.62745 .52754 m
.62801 .5283 L
s
.62801 .5283 m
.62893 .52954 L
s
.60744 .50933 m .61731 .51788 L .62637 .5264 L 0 .107 0 r
F
0 g
.61784 .51822 m
.61845 .51862 L
s
.61731 .51788 m
.61784 .51822 L
s
.61845 .51862 m
.62304 .52157 L
s
.60066 .50246 m
.60744 .50933 L
s
.60151 .50491 m
.60744 .50933 L
s
.62447 .5235 m
.62745 .52754 L
s
.51316 .94817 m .51194 .93277 L .51264 .94156 L 0 .292 .108 r
F
.51316 .94817 m .51264 .94156 L .51194 .93277 L 0 .296 .109 r
F
.51316 .94817 m .51316 .94817 L .51264 .94156 L F
.51316 .94817 m .50908 .89337 L .51005 .90957 L 0 .346 .263 r
F
.51316 .94817 m .50955 .89372 L .50908 .89337 L F
0 g
.50907 .89326 m
.50908 .89337 L
s
.50954 .8935 m
.50954 .8935 L
s
.50953 .89338 m
.50954 .8935 L
s
.50953 .89338 m
.50953 .89338 L
s
.50892 .87661 m
.50953 .89338 L
s
.50953 .89338 m
.50953 .89338 L
s
.50954 .8935 m
.50954 .89351 L
s
.5102 .89365 m
.5102 .89365 L
s
.51019 .89348 m
.5102 .89365 L
s
.51019 .89348 m
.51019 .89348 L
s
.50892 .87661 m
.51019 .89348 L
s
.51019 .89348 m
.51019 .89348 L
s
.5102 .89365 m
.5102 .89365 L
s
.51178 .92595 m
.51183 .92814 L
s
.50908 .89337 m
.5091 .89365 L
s
.5091 .89365 m
.50912 .89398 L
s
.50912 .89398 m
.50954 .90105 L
s
.56613 .82717 m .56883 .83892 L .57298 .8062 L 0 .966 .238 r
F
0 g
.56883 .83892 m
.57298 .8062 L
s
.56611 .79243 m
.56613 .82717 L
s
.5691 .83681 m
.57032 .85116 L
s
.5699 .8305 m
.56995 .833 L
s
.56995 .833 m
.57032 .85116 L
s
.28067 .93346 m .27095 .93125 L .26818 .93123 L 0 .511 .21 r
F
.28067 .93346 m .2756 .93208 L .27095 .93125 L F
.28067 .93346 m .27977 .93302 L .2756 .93208 L F
0 g
.27789 .93343 m
.28067 .93346 L
s
.52973 .48083 m .54036 .48152 L .54885 .48324 L 0 0 0 r
F
0 g
.54036 .48152 m
.5478 .48045 L
s
.51316 .94817 m .50761 .93006 L .50949 .93519 L 0 .284 .108 r
F
.51316 .94817 m .50718 .93061 L .50761 .93006 L F
0 g
.50711 .92834 m
.50761 .93006 L
s
.50558 .93295 m .50521 .93357 L .50247 .93117 L 0 .232 .096 r
F
.5087 .94944 m .50337 .94888 L .50427 .94994 L 0 .286 .311 r
F
.5087 .94944 m .50426 .94816 L .50337 .94888 L F
0 g
.50114 .94804 m
.50337 .94888 L
s
.21881 .72599 m .21196 .71657 L .20771 .7229 L 0 1 .539 r
F
0 g
.20771 .7229 m
.2079 .72848 L
s
.21881 .72599 m .21841 .71292 L .21196 .71657 L 0 1 .539 r
F
.21881 .72599 m .22276 .71442 L .21841 .71292 L F
.21881 .72599 m .22292 .72003 L .22276 .71442 L F
0 g
.21238 .7296 m
.21881 .72599 L
s
.21881 .72599 m
.21909 .73132 L
s
.3228 .82838 m .31426 .8202 L .31217 .82652 L 0 1 .508 r
F
.3228 .82838 m .31897 .81609 L .31426 .8202 L F
.3228 .82838 m .32316 .81695 L .31897 .81609 L F
.3228 .82838 m .3248 .82222 L .32316 .81695 L F
0 g
.3181 .83247 m
.3228 .82838 L
s
.3228 .82838 m
.32451 .83357 L
s
.49618 .95354 m .48774 .95449 L .49094 .95703 L 0 .372 .292 r
F
0 g
.48603 .95784 m
.48774 .95449 L
s
.51316 .94817 m .50206 .90547 L .50528 .91888 L 0 .386 .274 r
F
0 g
.50594 .92993 m
.50625 .93069 L
s
.50119 .90329 m
.50206 .90547 L
s
.60358 .66525 m
.6053 .66805 L
s
.6053 .66805 m
.60573 .66875 L
s
.60573 .66875 m
.60704 .67087 L
s
.60351 .66521 m
.60358 .66525 L
s
.59785 1.38088 m
.59791 1.38391 L
s
.26898 .89223 m .26118 .88427 L .25755 .88674 L 0 1 .508 r
F
.26898 .89223 m .26583 .88504 L .26118 .88427 L F
.26898 .89223 m .26917 .88846 L .26583 .88504 L F
.28059 .89373 m .26917 .88846 L .26898 .89223 L 0 1 .503 r
F
0 g
.26536 .89468 m
.26898 .89223 L
s
.26898 .89223 m
.27232 .89544 L
s
.50314 .94014 m .49318 .93419 L .49649 .93663 L 0 .419 .379 r
F
.50314 .94014 m .49267 .93317 L .49318 .93419 L F
0 g
.49197 .93397 m
.49318 .93419 L
s
.49457 .94568 m .4887 .94763 L .49231 .94786 L 0 .41 .295 r
F
.49618 .95354 m .49231 .94786 L .4887 .94763 L 0 .372 .292 r
F
0 g
.48675 .95047 m
.4887 .94763 L
s
.48559 .94468 m
.4887 .94763 L
s
.47764 .90965 m .47774 .90841 L .47429 .90464 L 0 .779 .436 r
F
.48945 .92009 m .47764 .90965 L .48111 .91361 L 0 .645 .417 r
F
.48945 .92009 m .47774 .90841 L .47764 .90965 L F
0 g
.47458 .90831 m
.47764 .90965 L
s
.52914 .81691 m .5315 .81731 L .53456 .83516 L 0 .666 .167 r
F
0 g
.5315 .81731 m
.53172 .81054 L
s
.70967 .8964 m .71741 .89427 L .71307 .89537 L 0 .693 .212 r
F
0 g
.70657 .89715 m
.70967 .8964 L
s
.46909 .79377 m .46216 .79423 L .46487 .79269 L 0 .255 .043 r
F
0 g
.46486 .78962 m
.46487 .79269 L
s
.46909 .79377 m .46263 .79782 L .46216 .79423 L 0 .255 .043 r
F
.46909 .79377 m .46598 .80109 L .46263 .79782 L F
.46909 .79377 m .47022 .80217 L .46598 .80109 L F
.46909 .79377 m .47251 .80034 L .47022 .80217 L F
.46909 .79377 m .47202 .79674 L .47251 .80034 L F
0 g
.46893 .78959 m
.46909 .79377 L
s
.46487 .79269 m
.46909 .79377 L
s
.5087 .94944 m .50427 .94994 L .50617 .9505 L 0 .286 .311 r
F
0 g
.50372 .95089 m
.50427 .94994 L
s
.51316 .94817 m .51087 .91017 L .50955 .89372 L 0 .346 .263 r
F
0 g
.50956 .89384 m
.50958 .89418 L
s
.50955 .89372 m
.50956 .89384 L
s
.50956 .90132 m
.50958 .90164 L
s
.50954 .90105 m
.50956 .90132 L
s
.5102 .89365 m
.51023 .89402 L
s
.51023 .89411 m
.51023 .89411 L
s
.51023 .89402 m
.51023 .89411 L
s
.51023 .89411 m
.51023 .89411 L
s
.51073 .89417 m
.51073 .89417 L
s
.51072 .89404 m
.51072 .89405 L
s
.51048 .87781 m
.51072 .89404 L
s
.51072 .89405 m
.51072 .89405 L
s
.51072 .89405 m
.51073 .89417 L
s
.51073 .89417 m
.51073 .89417 L
s
.51137 .8944 m
.51137 .8944 L
s
.51136 .89424 m
.51136 .89424 L
s
.51048 .87781 m
.51136 .89424 L
s
.51136 .89424 m
.51137 .89425 L
s
.51137 .89425 m
.51137 .89439 L
s
.51137 .89439 m
.51137 .8944 L
s
.50954 .89351 m
.50955 .89372 L
s
.51544 1.06897 m .51201 1.06305 L .50929 1.05924 L 0 0 .15 r
F
0 g
.5336 .86987 m
.5338 .86955 L
s
.74852 .65807 m .75192 .66887 L .74798 .67134 L 0 .171 .095 r
F
0 g
.74798 .67134 m
.74805 .66973 L
s
.74852 .65807 m .75858 .65367 L .75192 .66887 L 0 .171 .095 r
F
0 g
.74301 .67279 m
.7437 .67095 L
s
.74208 .67527 m
.74242 .67436 L
s
.74257 .67396 m
.74301 .67279 L
s
.52312 .81406 m .52555 .81552 L .52827 .83048 L 0 .631 .154 r
F
0 g
.52181 .82395 m
.52312 .81406 L
s
.52745 .80801 m
.52914 .81691 L
s
.52271 .81178 m
.52312 .81406 L
s
.52555 .81552 m
.52558 .81507 L
s
.37439 .77061 m .36509 .76783 L .36891 .76887 L 0 0 0 r
F
0 g
.36954 .76916 m
.36961 .76919 L
s
.52425 .93332 m .52406 .93235 L .52712 .92407 L 0 .259 .131 r
F
0 g
.52424 .92998 m
.52437 .9297 L
s
.52344 .9263 m
.52418 .92385 L
s
.52363 .92977 m
.52423 .92798 L
s
.51393 .90166 m .51442 .9031 L .51528 .8871 L 0 .492 .267 r
F
.50314 .94014 m .49541 .93441 L .49267 .93317 L 0 .419 .379 r
F
0 g
.49126 .93225 m
.49267 .93317 L
s
.30152 .82483 m .29004 .8283 L .29567 .82908 L 0 1 .517 r
F
0 g
.29567 .82908 m
.29895 .83443 L
s
.29358 .62284 m .28151 .6265 L .28537 .62835 L 0 1 .491 r
F
0 g
.28372 .63583 m
.28537 .62835 L
s
.46728 .8928 m .46483 .88699 L .46034 .88288 L 0 .883 .44 r
F
.46728 .8928 m .4678 .89124 L .46483 .88699 L F
.47872 .90372 m .46728 .8928 L .47035 .89713 L 0 .776 .428 r
F
.47872 .90372 m .4678 .89124 L .46728 .8928 L F
0 g
.46343 .89122 m
.46728 .8928 L
s
.46728 .8928 m
.4697 .89622 L
s
.46626 .93404 m .45836 .93066 L .463 .93204 L 0 .186 .042 r
F
.46626 .93404 m .45459 .93049 L .45836 .93066 L F
0 g
.45535 .9288 m
.45836 .93066 L
s
.28059 .89373 m .27281 .88621 L .26917 .88846 L 0 1 .503 r
F
.28059 .89373 m .27746 .887 L .27281 .88621 L F
.28059 .89373 m .28079 .89023 L .27746 .887 L F
0 g
.27696 .89596 m
.28059 .89373 L
s
.29485 .89568 m .28079 .89023 L .28059 .89373 L 0 1 .494 r
F
0 g
.28059 .89373 m
.28471 .89685 L
s
.30441 .74479 m .29385 .73939 L .29389 .74292 L 0 .889 .471 r
F
0 g
.28823 .74381 m
.29389 .74292 L
s
.55165 .80301 m .55469 .80501 L .55874 .78851 L 0 1 .272 r
F
.51625 .96323 m .51831 .96671 L .51755 .96518 L 0 .118 .185 r
F
0 g
.51809 .96676 m
.51831 .96671 L
s
.51751 .96461 m .51755 .96518 L .51831 .96671 L 0 .07 .172 r
F
0 g
.51831 .96671 m
.51921 .96818 L
s
.46872 .88897 m .46034 .88288 L .46483 .88699 L 0 .878 .434 r
F
.46872 .88897 m .45765 .87834 L .46034 .88288 L F
0 g
.4565 .8813 m
.46034 .88288 L
s
.52973 .48083 m .52205 .48238 L .52188 .4812 L 0 0 0 r
F
.52973 .48083 m .53055 .48411 L .52205 .48238 L F
.52973 .48083 m .5417 .48523 L .53055 .48411 L F
.52973 .48083 m .54955 .48486 L .5417 .48523 L F
0 g
.54975 .48336 m
.55618 .48419 L
s
.52973 .48083 m .54885 .48324 L .54955 .48486 L 0 0 0 r
F
0 g
.54885 .48324 m
.54975 .48336 L
s
.52162 .47913 m
.52973 .48083 L
s
.54036 .48152 m
.54885 .48324 L
s
.51316 .94817 m .50949 .93519 L .51159 .9426 L 0 .284 .108 r
F
.51316 .94817 m .51159 .9426 L .50949 .93519 L 0 .285 .108 r
F
.51316 .94817 m .51316 .94817 L .51159 .9426 L F
.51316 .94817 m .50182 .90742 L .50169 .90878 L 0 .395 .275 r
F
.51316 .94817 m .50528 .91888 L .50182 .90742 L F
0 g
.50102 .90476 m
.50182 .90742 L
s
.50736 .89354 m
.50915 .90845 L
s
.51316 .94817 m .50874 .93615 L .50718 .93061 L 0 .284 .108 r
F
0 g
.50657 .92976 m
.50718 .93061 L
s
.51381 .96057 m .51283 .9595 L .51194 .95944 L 0 .171 .198 r
F
.49457 .94568 m .49399 .94255 L .49062 .93937 L 0 .41 .295 r
F
.45765 .87834 m .45166 .86781 L .44763 .86654 L 0 .966 .443 r
F
.51942 .96674 m .52252 .97139 L .52256 .97098 L 0 .045 .166 r
F
0 g
.51932 .96771 m
.52108 .96998 L
s
.52252 .97139 m
.52396 .97265 L
s
.50144 .92438 m .50137 .92269 L .49779 .91558 L 0 .489 .289 r
F
0 g
.49779 .91558 m
.49823 .91646 L
s
.49779 .91558 m
.49841 .91639 L
s
.50063 .9193 m
.50114 .91996 L
s
.49841 .91639 m
.50063 .9193 L
s
.50077 .91531 m
.50109 .91582 L
s
.49912 .91364 m
.5006 .91698 L
s
.5006 .91698 m
.50084 .91753 L
s
.50084 .91753 m
.50105 .918 L
s
.69576 .61041 m .71169 .6093 L .7044 .60733 L 0 1 .399 r
F
0 g
.71169 .6093 m
.7199 .61003 L
s
.71169 .6093 m
.71437 .6115 L
s
.3098 .61873 m
.31226 .61022 L
s
.31687 .61405 m
.31759 .61357 L
s
.3098 .61873 m
.31687 .61405 L
s
.49533 1.00171 m .49092 1.00642 L .49382 1.00876 L 0 .259 .285 r
F
0 g
.49092 1.00642 m
.49138 1.01135 L
s
.36964 .82538 m .3607 .82692 L .36485 .82831 L 0 1 .482 r
F
0 g
.36485 .82831 m
.36677 .83325 L
s
.50986 .95104 m .50564 .95154 L .50657 .9526 L 0 .263 .292 r
F
.50986 .95104 m .50617 .9505 L .50564 .95154 L F
0 g
.50372 .95089 m
.50564 .95154 L
s
.52827 .83048 m
.52914 .81691 L
s
.45765 .87834 m .45597 .87189 L .45166 .86781 L 0 .966 .443 r
F
.45765 .87834 m .45853 .87641 L .45597 .87189 L F
.46872 .88897 m .45853 .87641 L .45765 .87834 L 0 .878 .434 r
F
0 g
.45765 .87834 m
.46034 .88288 L
s
.45362 .87707 m
.45765 .87834 L
s
.51316 .94818 m .52206 .92675 L .52239 .92732 L 0 .306 .125 r
F
.51316 .94818 m .51924 .93285 L .52206 .92675 L F
0 g
.52206 .92675 m
.52214 .92648 L
s
.51491 .92932 m
.51493 .92902 L
s
.51489 .92958 m
.51491 .92932 L
s
.37712 .54644 m .36546 .55206 L .36821 .55241 L 0 1 .386 r
F
0 g
.36388 .56026 m
.36821 .55241 L
s
.37712 .54644 m .37056 .54571 L .36546 .55206 L 0 1 .386 r
F
.37712 .54644 m .38013 .53759 L .37056 .54571 L F
.37712 .54644 m .38905 .53162 L .38013 .53759 L F
.37712 .54644 m .39138 .53178 L .38905 .53162 L F
.37712 .54644 m .38626 .53814 L .39138 .53178 L F
0 g
.37234 .55267 m
.37712 .54644 L
s
.36821 .55241 m
.37712 .54644 L
s
.38626 .53814 m
.39486 .53183 L
s
.80198 1.0234 m .80469 1.03019 L .81013 1.02318 L 0 1 .379 r
F
.80198 1.0234 m .80035 1.03271 L .80469 1.03019 L F
0 g
.80469 1.03019 m
.80478 1.03244 L
s
.52555 .81552 m
.52827 .83048 L
s
.56545 .9119 m
.56562 .92086 L
s
.56544 .91183 m
.56545 .9119 L
s
.56544 .91144 m
.56544 .91183 L
s
.56537 .90779 m
.56544 .91144 L
s
.5639 .83123 m
.56395 .8339 L
s
.56386 .82919 m
.5639 .83123 L
s
.76181 1.06111 m .76294 1.06132 L .76885 1.05633 L 0 .867 .181 r
F
.76181 1.06111 m .75874 1.06423 L .76294 1.06132 L F
.50254 .93775 m .49541 .93441 L .49957 .93711 L 0 .425 .285 r
F
.50315 .93789 m .50289 .9386 L .49957 .93711 L 0 .264 .099 r
F
.50254 .93871 m .49197 .93165 L .49541 .93441 L 0 .44 .383 r
F
.50254 .93871 m .49155 .93065 L .49197 .93165 L F
0 g
.49071 .93131 m
.49197 .93165 L
s
.47872 .90372 m .47035 .89713 L .47496 .90136 L 0 .776 .428 r
F
.47799 .9066 m .47496 .90136 L .47035 .89713 L 0 .779 .432 r
F
0 g
.46664 .89518 m
.47035 .89713 L
s
.4697 .89622 m
.47035 .89713 L
s
.47429 .90464 m
.47598 .90649 L
s
.49096 .93597 m .48243 .93492 L .47941 .93269 L 0 .251 .085 r
F
0 g
.47941 .93269 m
.48001 .93314 L
s
.47563 .93252 m
.47941 .93269 L
s
.37135 .90998 m .36325 .90907 L .36778 .91004 L 0 .628 .301 r
F
0 g
.36778 .91004 m
.37148 .91153 L
s
.37135 .90998 m .36001 .90729 L .36325 .90907 L 0 .628 .301 r
F
0 g
.36017 .90936 m
.36325 .90907 L
s
.35208 .67507 m
.35369 .67568 L
s
.35196 .67502 m
.35208 .67507 L
s
.34718 .67319 m
.34908 .67392 L
s
.35 .67427 m
.35196 .67502 L
s
.34805 .66818 m
.34806 .66815 L
s
.34805 .66822 m
.34805 .66818 L
s
.34718 .67319 m
.34764 .67055 L
s
.34804 .66824 m
.34805 .66822 L
s
.53057 1.09384 m .53132 1.0918 L .53268 1.09369 L 0 .316 0 r
F
.53057 1.09384 m .52975 1.09039 L .53132 1.0918 L F
0 g
.53086 1.09013 m
.53132 1.0918 L
s
.73306 .65835 m .74688 .64295 L .75085 .64142 L 0 0 0 r
F
.73306 .65835 m .73928 .65018 L .74688 .64295 L F
0 g
.74688 .64295 m
.74773 .63781 L
s
.74641 .6434 m
.74688 .64295 L
s
.54832 .70131 m .54637 .69549 L .54527 .70085 L 0 1 .356 r
F
.54832 .70131 m .55142 .6881 L .54637 .69549 L F
.38036 .82974 m .37188 .82007 L .36964 .82538 L 0 1 .479 r
F
0 g
.36964 .82538 m
.37122 .83058 L
s
.38036 .82974 m .37668 .81759 L .37188 .82007 L 0 1 .479 r
F
.38036 .82974 m .38086 .8196 L .37668 .81759 L F
.38036 .82974 m .38243 .82481 L .38086 .8196 L F
0 g
.37556 .83221 m
.38036 .82974 L
s
.38036 .82974 m
.38205 .8348 L
s
.62608 .52613 m
.62637 .5264 L
s
.62534 .52543 m
.62608 .52613 L
s
.61731 .51788 m
.62534 .52543 L
s
.51316 .94817 m .50169 .90878 L .50505 .92127 L 0 .395 .275 r
F
0 g
.50586 .89389 m
.50783 .91027 L
s
.50529 .89459 m
.50782 .91024 L
s
.50626 .89353 m
.50851 .90955 L
s
.50691 .89355 m
.50852 .9096 L
s
.50799 .89354 m
.50923 .90895 L
s
.50412 .9298 m
.50551 .93133 L
s
.50124 .90781 m
.50169 .90878 L
s
.48945 .92009 m .48133 .91084 L .47774 .90841 L 0 .645 .417 r
F
0 g
.47598 .90649 m
.47774 .90841 L
s
.47764 .90965 m
.48097 .91345 L
s
.47761 .91155 m
.47933 .91257 L
s
.29485 .89568 m .28523 .88836 L .28079 .89023 L 0 1 .494 r
F
.29485 .89568 m .29094 .88938 L .28523 .88836 L F
.29485 .89568 m .29506 .89252 L .29094 .88938 L F
0 g
.29041 .89753 m
.29485 .89568 L
s
.30571 .89727 m .29506 .89252 L .29485 .89568 L 0 1 .485 r
F
0 g
.29485 .89568 m
.29795 .89846 L
s
.51316 .94817 m .51026 .89443 L .51087 .91017 L 0 .355 .263 r
F
.51316 .94817 m .51074 .89503 L .51026 .89443 L F
0 g
.51023 .89411 m
.51026 .89443 L
s
.51073 .89457 m
.51073 .89457 L
s
.51073 .89417 m
.51073 .89457 L
s
.51073 .89457 m
.51073 .89457 L
s
.51197 .89503 m
.51197 .89503 L
s
.51197 .89503 m
.51208 .87992 L
s
.5114 .89495 m
.5114 .89496 L
s
.51137 .8944 m
.5114 .89495 L
s
.5114 .89495 m
.5114 .89495 L
s
.51026 .89443 m
.51027 .89467 L
s
.54192 .74003 m .54074 .72816 L .5396 .73657 L 0 1 .337 r
F
.53876 .76713 m .54192 .74003 L .53791 .75064 L 0 1 .323 r
F
.48866 .8009 m .48337 .8049 L .4852 .80123 L 0 .362 .08 r
F
.48866 .8009 m .48444 .8107 L .48337 .8049 L F
.48854 .8306 m .48784 .81332 L .48444 .8119 L 0 .992 .382 r
F
.48784 .81332 m .48784 .8133 L .48774 .81326 L F
.48784 .81332 m .48774 .81326 L .48444 .8119 L F
.48784 .8133 m .48685 .81267 L .4868 .81265 L F
.48774 .81326 m .4868 .81265 L .48444 .8119 L F
.48784 .8133 m .4868 .81265 L .48774 .81326 L F
.48783 .81298 m .48514 .81158 L .48444 .8119 L F
.48866 .8009 m .48783 .81285 L .48444 .8107 L 0 .362 .08 r
F
.48783 .81285 m .48783 .81298 L .48715 .81252 L F
.48783 .81285 m .48715 .81252 L .48444 .8107 L F
.48442 .81122 m .48444 .81114 L .48442 .81113 L 0 1 .392 r
F
.48444 .8119 m .48457 .81129 L .48442 .81122 L F
.48457 .81129 m .48459 .81123 L .48442 .81122 L F
.48458 .81122 m .48459 .81123 L .48459 .81123 L 0 .346 .055 r
F
.48444 .8107 m .48476 .81133 L .48458 .81122 L F
.48444 .8107 m .48458 .81122 L .48442 .81111 L F
.48752 .81277 m .48514 .81158 L .48444 .8107 L 0 .362 .08 r
F
.48783 .81298 m .48514 .81158 L .48752 .81277 L F
.48444 .8107 m .48514 .81158 L .48476 .81133 L 0 .346 .055 r
F
.48474 .81138 m .48477 .81134 L .48457 .81129 L 0 1 .392 r
F
.48476 .81133 m .48477 .81134 L .48458 .81122 L 0 .346 .055 r
F
.48477 .81134 m .48459 .81123 L .48458 .81122 L F
.48854 .8306 m .49117 .81516 L .49068 .81448 L 0 .992 .382 r
F
.48783 .81293 m .49068 .81448 L .48783 .81298 L 0 .362 .08 r
F
.48866 .8009 m .49065 .81428 L .48783 .81293 L F
.49065 .81428 m .49068 .81448 L .48783 .81293 L F
.48866 .8009 m .49117 .81443 L .49068 .81448 L F
.48854 .8306 m .49068 .81448 L .48783 .81298 L 0 .992 .382 r
F
.48477 .81134 m .4877 .81477 L .48914 .81988 L 0 .346 .055 r
F
.48476 .81133 m .48477 .81135 L .48477 .81134 L F
.48477 .81135 m .4877 .81477 L .48477 .81134 L F
.48477 .81134 m .48772 .81038 L .4892 .80379 L 0 1 .392 r
F
.48472 .81143 m .48483 .81138 L .48477 .81134 L F
.48483 .81138 m .48772 .81038 L .48477 .81134 L F
.48444 .8119 m .48508 .8116 L .48472 .81143 L F
.48508 .8116 m .48772 .81038 L .48472 .81143 L F
.48783 .81298 m .49068 .81448 L .48772 .81038 L 0 .992 .382 r
F
.48783 .81298 m .49068 .81448 L .4877 .81477 L 0 .362 .08 r
F
.48477 .81134 m .4892 .80379 L .4846 .81124 L 0 1 .392 r
F
.48477 .81134 m .4846 .81124 L .48457 .81129 L F
.48477 .81134 m .48914 .81988 L .48459 .81123 L 0 .346 .055 r
F
.48459 .81123 m .48914 .81988 L .48459 .81123 L F
.48459 .81123 m .4892 .80379 L .48788 .79653 L 0 1 .392 r
F
.48457 .81129 m .4846 .81124 L .48459 .81123 L F
.4846 .81124 m .4892 .80379 L .48459 .81123 L F
.48444 .8119 m .48474 .81138 L .48457 .81129 L F
.48459 .81123 m .48788 .79653 L .48444 .81114 L F
.48458 .81122 m .48459 .81123 L .48442 .81111 L 0 .346 .055 r
F
.48459 .81123 m .48444 .81114 L .48442 .81122 L 0 1 .392 r
F
.48459 .81123 m .48778 .82265 L .48443 .81113 L 0 .346 .055 r
F
.48459 .81123 m .48443 .81113 L .48442 .81111 L F
.48459 .81123 m .48444 .81114 L .48444 .81114 L 0 1 .392 r
F
.48459 .81123 m .48914 .81988 L .48778 .82265 L 0 .346 .055 r
F
.48854 .8306 m .48331 .81852 L .48509 .82582 L 0 .992 .382 r
F
.48854 .8306 m .48444 .8119 L .48331 .81852 L F
.48263 .81005 m .47885 .80127 L .48063 .808 L 0 1 .392 r
F
.47646 .81611 m .47961 .81436 L .4805 .80879 L 0 1 .401 r
F
.47646 .81611 m .4805 .80879 L .48049 .80879 L F
.48026 .80863 m .4805 .80879 L .48028 .80868 L 0 .301 .049 r
F
.47655 .80158 m .48047 .80874 L .48026 .80863 L F
.48047 .80874 m .4805 .80879 L .48026 .80863 L F
.47655 .80158 m .47966 .80505 L .4805 .80879 L F
.47655 .80158 m .48028 .80868 L .47786 .80741 L F
.47655 .80158 m .47022 .80217 L .47251 .80034 L F
.47655 .80158 m .4728 .80496 L .47022 .80217 L F
.47646 .81611 m .4728 .80496 L .47019 .8065 L 0 1 .401 r
F
.4728 .80496 m .4706 .80391 L .47019 .8065 L F
.4728 .80496 m .47117 .80643 L .4706 .80391 L 0 .301 .049 r
F
.4728 .80496 m .4706 .80391 L .47022 .80217 L F
.4728 .80496 m .47121 .80014 L .4706 .80391 L 0 1 .401 r
F
.47646 .81611 m .47557 .80628 L .4728 .80496 L F
.4728 .80496 m .47473 .81031 L .47117 .80643 L 0 .301 .049 r
F
.47655 .80158 m .47557 .80628 L .4728 .80496 L F
.47557 .80628 m .47473 .81031 L .4728 .80496 L F
.4728 .80496 m .47481 .7979 L .47121 .80014 L 0 1 .401 r
F
.47557 .80628 m .47481 .7979 L .4728 .80496 L F
.47646 .81611 m .47786 .80741 L .47557 .80628 L F
.47791 .80713 m .48063 .808 L .47885 .80127 L F
.47646 .81611 m .4803 .80864 L .47791 .80713 L F
.4803 .80864 m .48063 .808 L .47791 .80713 L F
.47646 .81611 m .48049 .80879 L .48028 .80868 L F
.48265 .81007 m .48385 .81079 L .48263 .81005 L 0 1 .392 r
F
.48444 .8119 m .48385 .81079 L .48265 .81007 L F
.48385 .81079 m .48385 .81079 L .48265 .81007 L F
.48171 .83339 m .48331 .81852 L .47961 .81436 L 0 .999 .392 r
F
.48171 .83339 m .48509 .82582 L .48331 .81852 L F
.48444 .8107 m .48385 .81079 L .48263 .81005 L 0 .346 .055 r
F
.48385 .81079 m .48032 .79468 L .47885 .80127 L 0 1 .392 r
F
.48444 .8119 m .48422 .81101 L .48385 .81079 L F
.48444 .8107 m .48422 .81101 L .48385 .81079 L 0 .346 .055 r
F
.48422 .81101 m .48032 .79468 L .48385 .81079 L 0 1 .392 r
F
.48385 .81079 m .48418 .81107 L .48376 .81081 L 0 .346 .055 r
F
.48422 .81101 m .48418 .81107 L .48385 .81079 L F
.48422 .81102 m .48394 .82127 L .48021 .81666 L F
.48422 .81101 m .48408 .79262 L .48032 .79468 L 0 1 .392 r
F
.48444 .8119 m .48442 .81113 L .48422 .81101 L F
.48444 .8107 m .48442 .81113 L .48422 .81101 L 0 .346 .055 r
F
.48442 .81113 m .48408 .79262 L .48422 .81101 L 0 1 .392 r
F
.48422 .81101 m .48442 .81114 L .48422 .81102 L 0 .346 .055 r
F
.48442 .81113 m .48442 .81114 L .48422 .81101 L F
.48442 .81114 m .48394 .82127 L .48422 .81102 L F
.48376 .81081 m .48021 .81666 L .47879 .81154 L F
.48418 .81107 m .48021 .81666 L .48376 .81081 L F
.47557 .80628 m .47879 .81154 L .47473 .81031 L 0 .301 .049 r
F
.47655 .80158 m .47786 .80741 L .47557 .80628 L F
.47786 .80741 m .47879 .81154 L .47557 .80628 L F
.47557 .80628 m .47786 .80741 L .47557 .80625 L 0 1 .401 r
F
.47557 .80625 m .47885 .80127 L .47481 .7979 L F
.47786 .80741 m .47885 .80127 L .47557 .80625 L F
.48028 .80868 m .48051 .80875 L .48031 .80863 L F
.48049 .80879 m .48051 .80875 L .48028 .80868 L F
.48028 .80868 m .4805 .80879 L .48062 .80932 L 0 .301 .049 r
F
.47786 .80741 m .48062 .80932 L .47879 .81154 L F
.48028 .80868 m .48062 .80932 L .47786 .80741 L F
.48049 .80879 m .4805 .80879 L .48051 .80875 L 0 1 .401 r
F
.48031 .80863 m .48051 .80875 L .48063 .808 L F
.48247 .80999 m .47879 .81154 L .48062 .80932 L 0 .346 .055 r
F
.48263 .81005 m .48259 .81007 L .48247 .80999 L F
.48259 .81007 m .47879 .81154 L .48247 .80999 L F
.48385 .81079 m .47879 .81154 L .48263 .81005 L F
.48385 .81079 m .48385 .81079 L .48263 .81005 L 0 1 .392 r
F
.48385 .81079 m .47885 .80127 L .48263 .81005 L F
.48442 .81114 m .48778 .82265 L .48394 .82127 L 0 .346 .055 r
F
.48442 .81113 m .48442 .81114 L .48442 .81114 L F
.48442 .81114 m .48778 .82265 L .48442 .81114 L F
.48442 .81111 m .48443 .81113 L .48442 .81113 L F
.48443 .81113 m .48778 .82265 L .48442 .81113 L F
.48442 .81113 m .48788 .79653 L .48408 .79262 L 0 1 .392 r
F
.48444 .81114 m .48788 .79653 L .48442 .81113 L F
.48514 .81158 m .4877 .81477 L .48476 .81133 L 0 .346 .055 r
F
.48784 .8133 m .48783 .81298 L .48685 .81267 L 0 .992 .382 r
F
.48783 .81298 m .48772 .81038 L .48514 .81158 L F
.48783 .81298 m .4877 .81477 L .48514 .81158 L 0 .362 .08 r
F
0 g
.48794 .79449 m
.48863 .80065 L
s
.48866 .8009 m .49252 .80993 L .49117 .81443 L 0 .362 .08 r
F
.48866 .8009 m .49144 .80414 L .49252 .80993 L F
0 g
.49144 .80414 m
.49455 .80177 L
s
.5026 1.03243 m .49765 1.03151 L .50051 1.03702 L 0 .16 .236 r
F
.5026 1.03243 m .49637 1.02614 L .49765 1.03151 L F
0 g
.49463 1.02831 m
.49765 1.03151 L
s
.50986 .95104 m .50657 .9526 L .50815 .95283 L 0 .263 .292 r
F
0 g
.50639 .95374 m
.50657 .9526 L
s
.49023 .92675 m .49 .9258 L .48634 .9227 L 0 .625 .421 r
F
0 g
.48634 .9227 m
.4877 .92386 L
s
.48701 .92537 m
.48946 .92641 L
s
.75981 .60332 m .77575 .60982 L .77976 .60907 L 0 1 .493 r
F
.75981 .60332 m .76721 .60737 L .77575 .60982 L F
0 g
.77575 .60982 m
.77739 .61384 L
s
.52831 .90912 m .53277 .8712 L .52989 .88993 L 0 .474 .256 r
F
.52629 .89328 m .52989 .88993 L .53277 .8712 L 0 .523 .258 r
F
0 g
.53277 .8712 m
.53292 .86842 L
s
.53277 .8712 m
.5336 .86987 L
s
.52641 .89113 m
.52687 .88302 L
s
.52687 .88302 m
.52752 .87149 L
s
.5255 .88208 m
.52752 .87149 L
s
.50254 .93871 m .49451 .93225 L .49155 .93065 L 0 .44 .383 r
F
0 g
.49004 .93162 m
.49171 .93301 L
s
.48931 .92906 m
.49155 .93065 L
s
.49555 .93833 m
.49674 .93864 L
s
.49154 .9335 m
.49247 .93453 L
s
.49208 .93021 m
.49308 .93147 L
s
.41844 .92276 m .40974 .92088 L .4064 .91979 L 0 0 0 r
F
.41844 .92276 m .41448 .92232 L .40974 .92088 L F
.41844 .92276 m .41821 .92313 L .41448 .92232 L F
.43022 .92605 m .41821 .92313 L .41844 .92276 L F
0 g
.41844 .92276 m
.42214 .9234 L
s
.41509 .92167 m
.41844 .92276 L
s
.43614 .6484 m .42747 .65054 L .4296 .65051 L 0 1 .255 r
F
.43614 .6484 m .43112 .64838 L .42747 .65054 L F
0 g
.42655 .65276 m
.4296 .65051 L
s
.43614 .6484 m .43813 .64547 L .43112 .64838 L 0 1 .255 r
F
.43614 .6484 m .44467 .64336 L .43813 .64547 L F
.43614 .6484 m .44638 .64345 L .44467 .64336 L F
.43614 .6484 m .44272 .64561 L .44638 .64345 L F
0 g
.4328 .65038 m
.43614 .6484 L
s
.4296 .65051 m
.43614 .6484 L
s
.44272 .64561 m
.44894 .64348 L
s
.3946 .91673 m
.39791 .91748 L
s
.43881 .8535 m .43009 .84977 L .43441 .85309 L 0 1 .449 r
F
0 g
.43441 .85309 m
.43672 .85771 L
s
.43881 .8535 m .42819 .84487 L .43009 .84977 L 0 1 .449 r
F
0 g
.4258 .84975 m
.43009 .84977 L
s
.43441 .85309 m
.43493 .85314 L
s
.50777 1.05104 m .50689 1.05434 L .5096 1.05762 L 0 .073 .179 r
F
0 g
.50689 1.05434 m
.50929 1.05924 L
s
.45459 .93049 m .44568 .92997 L .44249 .92819 L 0 .109 .01 r
F
.43901 .78589 m .43054 .78427 L .43402 .78419 L 0 .055 0 r
F
0 g
.43402 .78419 m
.43402 .78419 L
s
.52491 .93888 m .53658 .92074 L .53321 .92781 L 0 .263 .134 r
F
0 g
.53283 .92232 m
.53639 .91814 L
s
.53658 .92074 m
.53766 .91865 L
s
.30152 .82483 m .28753 .82278 L .29004 .8283 L 0 1 .517 r
F
0 g
.28483 .83266 m
.29004 .8283 L
s
.44943 .86301 m .44088 .85832 L .44519 .86199 L 0 1 .443 r
F
.44943 .86301 m .43881 .8535 L .44088 .85832 L F
0 g
.43672 .85771 m
.44088 .85832 L
s
.44519 .86199 m
.44763 .86654 L
s
.69576 .61041 m .69639 .60685 L .69303 .6082 L 0 1 .399 r
F
.69576 .61041 m .7044 .60733 L .69639 .60685 L F
0 g
.688 .61021 m
.69576 .61041 L
s
.36964 .82538 m .35937 .82164 L .3607 .82692 L 0 1 .482 r
F
0 g
.3563 .82998 m
.3607 .82692 L
s
.51751 .96461 m .51932 .96771 L .51841 .96608 L 0 .07 .172 r
F
0 g
.51932 .96771 m
.51961 .96847 L
s
.51942 .96674 m .51842 .96608 L .51932 .96771 L 0 .045 .166 r
F
0 g
.51932 .96771 m
.51932 .96771 L
s
.52464 .93596 m .5328 .92235 L .52821 .93059 L 0 .26 .133 r
F
.52491 .93888 m .52821 .93059 L .5328 .92235 L 0 .263 .134 r
F
0 g
.52423 .92798 m
.52585 .9231 L
s
.52371 .92764 m
.5259 .92264 L
s
.5328 .92235 m
.53283 .92232 L
s
.5328 .92235 m
.53602 .91458 L
s
.24737 .6325 m .2372 .62914 L .23508 .63684 L 0 1 .516 r
F
0 g
.2277 .64254 m
.23508 .63684 L
s
.63691 .77174 m
.63716 .77189 L
s
.63716 .77189 m
.63735 .772 L
s
.63735 .772 m
.6376 .77214 L
s
.6376 .77214 m
.63967 .77333 L
s
.50205 .93319 m .49452 .92762 L .49889 .93157 L 0 .449 .286 r
F
.50386 .93618 m .50357 .93686 L .50041 .93507 L 0 .253 .098 r
F
.50254 .93775 m .49889 .93157 L .49452 .92762 L 0 .425 .285 r
F
0 g
.49388 .92667 m
.49452 .92762 L
s
.49376 .92746 m
.49452 .92762 L
s
.50386 .94161 m .49775 .9389 L .50136 .9407 L 0 .393 .373 r
F
.50467 .94313 m .50136 .9407 L .49775 .9389 L 0 .364 .365 r
F
.50314 .94238 m .49267 .93474 L .49317 .93786 L 0 .4 .282 r
F
.50314 .94014 m .49649 .93663 L .5004 .93888 L 0 .419 .379 r
F
.50386 .94161 m .5004 .93888 L .49649 .93663 L 0 .393 .373 r
F
.50467 .94313 m .50433 .94252 L .50136 .9407 L 0 .364 .365 r
F
.50314 .94238 m .49541 .93441 L .49267 .93474 L 0 .4 .282 r
F
0 g
.49813 .94106 m
.49881 .94114 L
s
.49622 .93937 m
.49817 .94057 L
s
.49247 .93453 m
.49267 .93474 L
s
.49318 .93419 m
.49375 .93461 L
s
.42819 .84487 m .4193 .84202 L .42362 .84503 L 0 1 .455 r
F
0 g
.42362 .84503 m
.42385 .84502 L
s
.42362 .84503 m
.4258 .84975 L
s
.30571 .89727 m .29848 .89076 L .29506 .89252 L 0 1 .485 r
F
.30571 .89727 m .30283 .89158 L .29848 .89076 L F
.30571 .89727 m .30593 .89437 L .30283 .89158 L F
.31657 .89896 m .30593 .89437 L .30571 .89727 L 0 1 .473 r
F
0 g
.30229 .89901 m
.30571 .89727 L
s
.30571 .89727 m
.3088 .89988 L
s
.48945 .92009 m .48111 .91361 L .48584 .91766 L 0 .645 .417 r
F
.48946 .92219 m .48584 .91766 L .48111 .91361 L 0 .642 .419 r
F
0 g
.48097 .91345 m
.48111 .91361 L
s
.47933 .91257 m
.48111 .91361 L
s
.50307 .48239 m .51375 .48121 L .52188 .4812 L 0 0 0 r
F
0 g
.51375 .48121 m
.52162 .47913 L
s
.51316 .94817 m .51172 .91123 L .51074 .89503 L 0 .355 .263 r
F
0 g
.51074 .89503 m
.51074 .89514 L
s
.51259 .89545 m
.51259 .89545 L
s
.51259 .89531 m
.51259 .89545 L
s
.51259 .89531 m
.51259 .89531 L
s
.51208 .87992 m
.51259 .8953 L
s
.51259 .8953 m
.51259 .89531 L
s
.51259 .89545 m
.51259 .89546 L
s
.51261 .89607 m
.51261 .89607 L
s
.51259 .89546 m
.51261 .89607 L
s
.51261 .89607 m
.51261 .89607 L
s
.51146 .89595 m
.51146 .89595 L
s
.51145 .89583 m
.51146 .89595 L
s
.51145 .89583 m
.51145 .89583 L
s
.5114 .89496 m
.51145 .89583 L
s
.51145 .89583 m
.51145 .89583 L
s
.51146 .89595 m
.51146 .89595 L
s
.51197 .89516 m
.51197 .89516 L
s
.51197 .89516 m
.51197 .89503 L
s
.51197 .89503 m
.51197 .89503 L
s
.51197 .89516 m
.51197 .89516 L
s
.51197 .89566 m
.51197 .89566 L
s
.51197 .89566 m
.51197 .89516 L
s
.51197 .89566 m
.51197 .89566 L
s
.51073 .89457 m
.51074 .89503 L
s
.47872 .90372 m .47155 .89359 L .4678 .89124 L 0 .776 .428 r
F
0 g
.46483 .88699 m
.4678 .89124 L
s
.51316 .94818 m .52239 .92732 L .5198 .93386 L 0 .306 .125 r
F
0 g
.52239 .92732 m
.52289 .92605 L
s
.47875 .93459 m .46997 .9342 L .46685 .93213 L 0 .222 .067 r
F
.51316 .94817 m .50152 .91089 L .50144 .91236 L 0 .402 .275 r
F
.51316 .94817 m .50505 .92127 L .50152 .91089 L F
0 g
.50103 .90946 m
.50152 .91089 L
s
.50811 .93144 m
.50811 .93144 L
s
.50447 .89596 m
.50701 .91161 L
s
.50458 .89575 m
.50717 .91111 L
s
.50493 .89516 m
.5072 .91129 L
s
.50416 .89672 m
.50701 .91166 L
s
.51316 .94818 m .50656 .93146 L .50874 .93615 L 0 .284 .109 r
F
.51316 .94818 m .50616 .93205 L .50656 .93146 L F
0 g
.50625 .93069 m
.50656 .93146 L
s
.45459 .93049 m .45039 .93141 L .44568 .92997 L 0 .109 .01 r
F
.45459 .93049 m .45421 .93164 L .45039 .93141 L F
.46626 .93404 m .45421 .93164 L .45459 .93049 L 0 .186 .042 r
F
0 g
.45459 .93049 m
.45836 .93066 L
s
.4514 .92872 m
.45459 .93049 L
s
.463 .93204 m
.46685 .93213 L
s
.51867 .92084 m .52414 .87929 L .52195 .88835 L 0 .466 .264 r
F
.51867 .92084 m .52501 .88465 L .52414 .87929 L F
0 g
.52414 .87929 m
.52477 .8623 L
s
.52214 .88753 m
.52414 .87929 L
s
.42819 .84487 m .41755 .83701 L .4193 .84202 L 0 1 .455 r
F
0 g
.41487 .84254 m
.4193 .84202 L
s
.50205 .93735 m .49098 .92916 L .49451 .93225 L 0 .457 .386 r
F
.50205 .93735 m .49066 .92819 L .49098 .92916 L F
0 g
.49042 .92897 m
.49098 .92916 L
s
.51105 .95263 m .50799 .95419 L .50895 .95525 L 0 .238 .27 r
F
0 g
.50657 .9526 m
.50683 .95264 L
s
.51105 .95263 m .50815 .95283 L .50799 .95419 L 0 .238 .27 r
F
0 g
.50639 .95374 m
.50799 .95419 L
s
.63687 .76689 m
.63691 .77174 L
s
.63686 .76567 m
.63687 .76689 L
s
.63686 .76484 m
.63686 .76567 L
s
.63685 .76332 m
.63686 .76484 L
s
.63685 .76332 m
.63685 .76332 L
s
.44202 .92962 m .4339 .92654 L .43861 .92788 L 0 .037 0 r
F
.44202 .92962 m .43022 .92605 L .4339 .92654 L F
0 g
.43078 .92505 m
.4339 .92654 L
s
.43861 .92788 m
.44249 .92819 L
s
.49197 .93322 m .49154 .93431 L .48794 .93374 L 0 .234 .084 r
F
.50314 .94014 m .49957 .93711 L .49541 .93441 L 0 .419 .379 r
F
.50386 .94161 m .50356 .94102 L .5004 .93888 L 0 .393 .373 r
F
.50314 .94238 m .49957 .93711 L .49541 .93441 L 0 .4 .282 r
F
.50314 .94238 m .50289 .94052 L .49957 .93711 L F
.50254 .93968 m .49197 .93322 L .49541 .93441 L 0 .276 .1 r
F
.50254 .93968 m .49154 .93431 L .49197 .93322 L F
0 g
.49171 .93301 m
.49197 .93322 L
s
.31217 .82652 m .3037 .81837 L .30152 .82483 L 0 1 .513 r
F
0 g
.30152 .82483 m
.30311 .83014 L
s
.31217 .82652 m .30849 .8141 L .3037 .81837 L 0 1 .513 r
F
.31217 .82652 m .31269 .81487 L .30849 .8141 L F
.31217 .82652 m .31426 .8202 L .31269 .81487 L F
0 g
.30739 .83077 m
.31217 .82652 L
s
.31217 .82652 m
.31382 .83177 L
s
.49667 1.01931 m .49637 1.02614 L .49754 1.02446 L 0 .222 .273 r
F
.5026 1.03243 m .49754 1.02446 L .49637 1.02614 L 0 .16 .236 r
F
0 g
.49637 1.02614 m
.49765 1.03151 L
s
.49341 1.02334 m
.49637 1.02614 L
s
.29385 .73939 m .28317 .73817 L .28746 .74006 L 0 1 .499 r
F
0 g
.28746 .74006 m
.28823 .74381 L
s
.67825 1.09661 m .68826 1.09573 L .68469 1.09812 L 0 .105 .03 r
F
.66948 1.10208 m .67825 1.09661 L .67933 1.10181 L 0 .184 .05 r
F
.31657 .89896 m .30935 .89285 L .30593 .89437 L 0 1 .473 r
F
.31657 .89896 m .3137 .89372 L .30935 .89285 L F
.31657 .89896 m .31679 .89635 L .3137 .89372 L F
.32743 .90079 m .31679 .89635 L .31657 .89896 L 0 1 .457 r
F
0 g
.31315 .90047 m
.31657 .89896 L
s
.31657 .89896 m
.31966 .90141 L
s
.74079 .60814 m .74212 .60385 L .73841 .60491 L 0 1 .457 r
F
.74079 .60814 m .75028 .60578 L .74212 .60385 L F
.29358 .62284 m .28414 .61826 L .28151 .6265 L 0 1 .491 r
F
0 g
.27389 .63142 m
.28151 .6265 L
s
.29358 .62284 m .29153 .60912 L .28414 .61826 L 0 1 .491 r
F
.29358 .62284 m .29977 .60358 L .29153 .60912 L F
.29358 .62284 m .30335 .60536 L .29977 .60358 L F
.29358 .62284 m .30069 .61362 L .30335 .60536 L F
0 g
.29114 .63134 m
.29358 .62284 L
s
.28537 .62835 m
.29358 .62284 L
s
.51316 .94817 m .50144 .91236 L .5049 .92383 L 0 .402 .275 r
F
0 g
.50144 .91236 m
.50203 .91432 L
s
.50152 .91089 m
.50231 .91322 L
s
.50551 .93133 m
.50601 .93188 L
s
.50396 .92985 m
.50534 .93249 L
s
.50342 .89884 m
.50647 .91305 L
s
.50385 .89752 m
.50647 .91306 L
s
.50114 .9118 m
.50144 .91236 L
s
.40476 .6612 m
.41126 .65857 L
s
.46872 .88897 m .46243 .87839 L .45853 .87641 L 0 .878 .434 r
F
.82546 .8645 m .83512 .87171 L .83794 .86718 L 0 1 .509 r
F
.82546 .8645 m .83047 .87248 L .83512 .87171 L F
0 g
.83512 .87171 m
.8382 .87513 L
s
.67748 .61187 m
.68466 .61153 L
s
.50205 .93735 m .49381 .93014 L .49066 .92819 L 0 .457 .386 r
F
0 g
.49197 .93322 m
.49275 .93349 L
s
.48701 .92537 m
.49066 .92819 L
s
.49197 .93165 m
.49361 .93296 L
s
.50307 .48239 m .49444 .48465 L .4948 .48386 L 0 0 0 r
F
0 g
.494 .48291 m
.49533 .48243 L
s
.50307 .48239 m .50257 .48465 L .49444 .48465 L 0 0 0 r
F
.50307 .48239 m .51378 .48386 L .50257 .48465 L F
.50307 .48239 m .52205 .48238 L .51378 .48386 L F
.50307 .48239 m .52188 .4812 L .52205 .48238 L F
0 g
.49533 .48243 m
.50307 .48239 L
s
.52188 .4812 m
.52973 .48083 L
s
.51375 .48121 m
.52188 .4812 L
s
.41068 .77902 m .40154 .77783 L .40169 .7769 L 0 0 0 r
F
0 g
.39659 .77558 m
.40169 .7769 L
s
.41068 .77902 m .4051 .77955 L .40154 .77783 L 0 0 0 r
F
.41068 .77902 m .41036 .78121 L .4051 .77955 L F
.41068 .77902 m .41382 .7817 L .41036 .78121 L F
.41068 .77902 m .41395 .78076 L .41382 .7817 L F
0 g
.40543 .77736 m
.41068 .77902 L
s
.46004 .87358 m .45166 .86781 L .45597 .87189 L 0 .96 .436 r
F
.46004 .87358 m .44943 .86301 L .45166 .86781 L F
0 g
.44763 .86654 m
.45166 .86781 L
s
.45597 .87189 m
.45853 .87641 L
s
.82546 .8645 m .82634 .8694 L .83047 .87248 L 0 1 .509 r
F
0 g
.82662 .87675 m
.83047 .87248 L
s
.47594 .79668 m
.47624 .79909 L
s
.47202 .79674 m
.47594 .79668 L
s
.41755 .83701 m .40849 .83495 L .41281 .8377 L 0 1 .459 r
F
0 g
.41281 .8377 m
.41289 .83769 L
s
.41281 .8377 m
.41487 .84254 L
s
.37439 .77061 m .365 .76804 L .36509 .76783 L 0 0 0 r
F
0 g
.35992 .76668 m
.36509 .76783 L
s
.47799 .9066 m .47824 .90542 L .47496 .90136 L 0 .779 .432 r
F
.48968 .91815 m .47799 .9066 L .48133 .91084 L 0 .643 .414 r
F
.48968 .91815 m .47824 .90542 L .47799 .9066 L F
0 g
.47429 .90464 m
.47799 .9066 L
s
.43901 .78589 m .43057 .78609 L .43054 .78427 L 0 .055 0 r
F
.43901 .78589 m .4341 .78844 L .43057 .78609 L F
.43901 .78589 m .4391 .79016 L .4341 .78844 L F
.43901 .78589 m .44223 .79009 L .4391 .79016 L F
.43901 .78589 m .44218 .78826 L .44223 .79009 L F
0 g
.43901 .78589 m
.43923 .7837 L
s
.43402 .78419 m
.43901 .78589 L
s
.51105 .95263 m .50895 .95525 L .51019 .95517 L 0 .238 .27 r
F
0 g
.50895 .95525 m
.50915 .95658 L
s
.58436 .64798 m
.59079 .64382 L
s
.81388 .86719 m .82351 .87365 L .82634 .8694 L 0 1 .5 r
F
.81388 .86719 m .81887 .87443 L .82351 .87365 L F
0 g
.82351 .87365 m
.82662 .87675 L
s
.31737 .75124 m .30845 .74282 L .30441 .74479 L 0 .702 .411 r
F
0 g
.30441 .74479 m
.30534 .74798 L
s
.31737 .75124 m .31524 .74378 L .30845 .74282 L 0 .702 .411 r
F
.31737 .75124 m .32025 .74705 L .31524 .74378 L F
.31737 .75124 m .32115 .75024 L .32025 .74705 L F
0 g
.31059 .75027 m
.31737 .75124 L
s
.8183 .80027 m .83177 .79787 L .82984 .8 L 0 0 0 r
F
0 g
.8297 .79592 m
.83177 .79787 L
s
.51316 .94818 m .50804 .93718 L .50616 .93205 L 0 .284 .109 r
F
0 g
.50601 .93188 m
.50616 .93205 L
s
.49796 .96142 m .48931 .96053 L .49041 .96456 L 0 .333 .287 r
F
.49796 .96142 m .49094 .95703 L .48931 .96053 L F
0 g
.48603 .95784 m
.48931 .96053 L
s
.38269 .91291 m .37459 .91157 L .37913 .91263 L 0 .558 .248 r
F
.38269 .91291 m .37135 .90998 L .37459 .91157 L F
0 g
.37148 .91153 m
.37459 .91157 L
s
.37913 .91263 m
.3828 .91395 L
s
.65504 .75271 m
.65505 .75147 L
s
.50168 .92873 m .50157 .92697 L .498 .92078 L 0 .47 .288 r
F
0 g
.49823 .91646 m
.50088 .92172 L
s
.50088 .92172 m
.50106 .92206 L
s
.50106 .92206 m
.50118 .92231 L
s
.81388 .86719 m .81474 .87168 L .81887 .87443 L 0 1 .5 r
F
0 g
.81505 .87842 m
.81887 .87443 L
s
.53057 1.09384 m .53268 1.09369 L .53304 1.09517 L 0 .316 0 r
F
0 g
.53268 1.09369 m
.53437 1.09473 L
s
.40037 .52676 m .38905 .53162 L .39138 .53178 L 0 1 .287 r
F
0 g
.38626 .53814 m
.39138 .53178 L
s
.40037 .52676 m .3949 .52646 L .38905 .53162 L 0 1 .287 r
F
.40037 .52676 m .40503 .51976 L .3949 .52646 L F
.40037 .52676 m .41403 .51473 L .40503 .51976 L F
.40037 .52676 m .4159 .51474 L .41403 .51473 L F
.40037 .52676 m .41004 .51989 L .4159 .51474 L F
0 g
.39486 .53183 m
.40037 .52676 L
s
.39138 .53178 m
.40037 .52676 L
s
.41004 .51989 m
.41869 .51456 L
s
.43881 .8535 m .42997 .84165 L .42819 .84487 L 0 1 .449 r
F
.43881 .8535 m .43437 .84206 L .42997 .84165 L F
.43881 .8535 m .43847 .84582 L .43437 .84206 L F
.43881 .8535 m .44037 .85073 L .43847 .84582 L F
.44943 .86301 m .44037 .85073 L .43881 .8535 L 0 1 .443 r
F
0 g
.43493 .85314 m
.43881 .8535 L
s
.43881 .8535 m
.44088 .85832 L
s
.49645 .98478 m .48923 .9853 L .49093 .98997 L 0 .285 .286 r
F
.49645 .98478 m .48983 .98057 L .48923 .9853 L F
0 g
.48608 .98271 m
.48923 .9853 L
s
.51316 .94817 m .51147 .89614 L .51172 .91123 L 0 .364 .264 r
F
0 g
.51229 .92586 m
.51229 .92587 L
s
.51316 .94817 m .51196 .89702 L .51147 .89614 L 0 .364 .264 r
F
0 g
.51264 .89689 m
.51264 .89689 L
s
.51261 .89607 m
.51264 .89689 L
s
.51264 .89689 m
.51264 .89689 L
s
.51196 .8965 m
.51196 .8965 L
s
.51196 .8965 m
.51196 .89641 L
s
.51196 .8965 m
.51196 .8965 L
s
.51196 .89641 m
.51196 .89641 L
s
.51146 .89595 m
.51147 .89614 L
s
.51196 .89641 m
.51197 .89566 L
s
.51196 .89641 m
.51196 .89641 L
s
.51147 .89614 m
.51159 .90345 L
s
.51159 .90345 m
.51159 .90358 L
s
.51159 .90358 m
.51159 .90369 L
s
.52631 .97521 m
.52645 .97533 L
s
.52645 .97533 m
.52658 .97543 L
s
.52658 .97543 m
.52689 .9757 L
s
.52726 .976 m
.52749 .97619 L
s
.52788 .97652 m
.52795 .97657 L
s
.52795 .97657 m
.52802 .97664 L
s
.52802 .97664 m
.52848 .97702 L
s
.52763 .97631 m
.52788 .97652 L
s
.5276 .97629 m
.52763 .97631 L
s
.52754 .97624 m
.5276 .97629 L
s
.52749 .97619 m
.52754 .97624 L
s
.52833 .97709 m
.52848 .97702 L
s
.52828 .97712 m
.52829 .97711 L
s
.52829 .97711 m
.52832 .9771 L
s
.52832 .9771 m
.52833 .97709 L
s
.52827 .97713 m
.52828 .97712 L
s
.52826 .97713 m
.52827 .97713 L
s
.52822 .97716 m
.52826 .97713 L
s
.53267 .98259 m .53743 .98499 L .53912 .98688 L 0 .204 0 r
F
.53267 .98259 m .53445 .98246 L .53743 .98499 L F
0 g
.53743 .98499 m
.53787 .98393 L
s
.53704 .98465 m
.53743 .98499 L
s
.53597 .98375 m
.53704 .98465 L
s
.53454 .98253 m
.53597 .98375 L
s
.35937 .82164 m .3503 .8237 L .35446 .82494 L 0 1 .486 r
F
0 g
.35446 .82494 m
.3563 .82998 L
s
.49332 .97465 m .49213 .97061 L .48906 .96836 L 0 .311 .295 r
F
.36085 .67663 m .35369 .67569 L .35704 .67587 L 0 .095 .081 r
F
.36085 .67663 m .3524 .68169 L .35369 .67569 L F
0 g
.35572 .67507 m
.35704 .67587 L
s
.35704 .67587 m
.35704 .67587 L
s
.36085 .67663 m .35403 .6899 L .3524 .68169 L 0 .095 .081 r
F
.36085 .67663 m .35785 .69066 L .35403 .6899 L F
.36085 .67663 m .36131 .68347 L .35785 .69066 L F
.36085 .67663 m .36258 .67747 L .36131 .68347 L F
0 g
.36085 .67663 m
.36208 .67561 L
s
.35704 .67587 m
.36085 .67663 L
s
.51625 .96323 m .51528 .96216 L .51475 .9623 L 0 .118 .185 r
F
.8023 .86994 m .81191 .87563 L .81474 .87168 L 0 1 .488 r
F
.8023 .86994 m .80727 .87644 L .81191 .87563 L F
0 g
.81191 .87563 m
.81505 .87842 L
s
.50468 .93453 m .50434 .93518 L .50138 .93309 L 0 .242 .097 r
F
.48972 .92441 m .48959 .92351 L .48595 .92012 L 0 .636 .42 r
F
0 g
.48595 .92012 m
.48668 .92081 L
s
.48595 .92012 m
.48762 .92111 L
s
.48634 .9227 m
.4886 .92385 L
s
.4877 .92386 m
.48996 .92577 L
s
.41755 .83701 m .4069 .82981 L .40849 .83495 L 0 1 .459 r
F
0 g
.40393 .83599 m
.40849 .83495 L
s
.50556 .94468 m .50245 .94256 L .49917 .94119 L 0 .342 .355 r
F
.50314 .94238 m .49317 .93786 L .49648 .94127 L 0 .4 .282 r
F
0 g
.49317 .93786 m
.49327 .93796 L
s
.49062 .93937 m
.49317 .93786 L
s
.49062 .93937 m
.49176 .94044 L
s
.49176 .94044 m
.49378 .94235 L
s
.36964 .82538 m .36175 .81599 L .35937 .82164 L 0 1 .482 r
F
.36964 .82538 m .36654 .81304 L .36175 .81599 L F
.36964 .82538 m .37055 .81478 L .36654 .81304 L F
.36964 .82538 m .37187 .82007 L .37055 .81478 L F
0 g
.36485 .82831 m
.36964 .82538 L
s
.32743 .90079 m .32022 .89508 L .31679 .89635 L 0 1 .457 r
F
.32743 .90079 m .32457 .89601 L .32022 .89508 L F
.32743 .90079 m .32766 .89846 L .32457 .89601 L F
.33829 .90278 m .32766 .89846 L .32743 .90079 L 0 1 .434 r
F
0 g
.32401 .90205 m
.32743 .90079 L
s
.32743 .90079 m
.33052 .90307 L
s
.42819 .84487 m .41955 .83335 L .41755 .83701 L 0 1 .455 r
F
.42819 .84487 m .42412 .83319 L .41955 .83335 L F
.42819 .84487 m .42822 .83664 L .42412 .83319 L F
.42819 .84487 m .42997 .84165 L .42822 .83664 L F
0 g
.42385 .84502 m
.42819 .84487 L
s
.42819 .84487 m
.43009 .84977 L
s
.28753 .82278 m .27778 .82668 L .28237 .82727 L 0 1 .522 r
F
0 g
.28237 .82727 m
.28483 .83266 L
s
.6896 1.10761 m .68826 1.09573 L .69434 1.09631 L 0 .093 .048 r
F
.6896 1.10761 m .68469 1.09812 L .68826 1.09573 L F
0 g
.68698 1.09143 m
.68826 1.09573 L
s
.8023 .86994 m .80315 .87401 L .80727 .87644 L 0 1 .488 r
F
0 g
.80347 .88014 m
.80727 .87644 L
s
.51316 .94818 m .50874 .93615 L .51126 .94301 L 0 .284 .109 r
F
.51316 .94817 m .51126 .94301 L .50874 .93615 L 0 .284 .108 r
F
.51316 .94817 m .51316 .94818 L .51126 .94301 L F
.51316 .94817 m .50135 .91462 L .50131 .91617 L 0 .406 .275 r
F
.51316 .94817 m .5049 .92383 L .50135 .91462 L F
0 g
.50102 .91377 m
.50135 .91462 L
s
.50203 .91432 m
.50255 .91603 L
s
.50315 .89981 m
.506 .91476 L
s
.50277 .90136 m
.50599 .91475 L
s
.50169 .90878 m
.50329 .91473 L
s
.50891 .93236 m
.50891 .93236 L
s
.50153 .91508 m
.50178 .91574 L
s
.50135 .91462 m
.50153 .91508 L
s
.50254 .93775 m .50233 .93592 L .49889 .93157 L 0 .425 .285 r
F
.50167 .93606 m .49023 .92675 L .49381 .93014 L 0 .468 .388 r
F
.50167 .93606 m .49 .9258 L .49023 .92675 L F
0 g
.48946 .92641 m
.49023 .92675 L
s
.49275 .93349 m
.4941 .93396 L
s
.4946 .93405 m
.49473 .9341 L
s
.49267 .93317 m
.4946 .93405 L
s
.49361 .93296 m
.49424 .93348 L
s
.64241 .78306 m
.64283 .78456 L
s
.63685 .76333 m
.64241 .78306 L
s
.60444 .63281 m .61857 .62818 L .62094 .62644 L 0 1 .3 r
F
.60444 .63281 m .6115 .6309 L .61857 .62818 L F
0 g
.61857 .62818 m
.62171 .62847 L
s
.50467 .94313 m .49917 .94119 L .50245 .94256 L 0 .364 .365 r
F
.50556 .94468 m .50074 .9435 L .50365 .94444 L 0 .342 .355 r
F
.50654 .94625 m .50365 .94444 L .50074 .9435 L 0 .326 .343 r
F
0 g
.49925 .94268 m
.50074 .9435 L
s
.49971 .94356 m
.50074 .9435 L
s
.52177 .96943 m .52465 .97354 L .52605 .975 L 0 0 .149 r
F
.52177 .96943 m .52256 .97098 L .52465 .97354 L F
0 g
.52252 .97139 m
.52255 .97116 L
s
.44943 .86301 m .44461 .85174 L .44037 .85073 L 0 1 .443 r
F
.44943 .86301 m .4487 .85587 L .44461 .85174 L F
.44943 .86301 m .45077 .8607 L .4487 .85587 L F
.46004 .87358 m .45077 .8607 L .44943 .86301 L 0 .96 .436 r
F
0 g
.44519 .86199 m
.44943 .86301 L
s
.44943 .86301 m
.45166 .86781 L
s
.77809 .62975 m .78072 .63079 L .77673 .63215 L 0 0 0 r
F
.77809 .62975 m .78827 .62713 L .78072 .63079 L F
0 g
.68245 .70181 m
.68385 .70789 L
s
.67904 .6871 m
.68245 .70181 L
s
.67747 .68029 m
.67904 .6871 L
s
.68385 .70789 m
.68387 .70796 L
s
.68387 .70796 m
.68412 .70906 L
s
.68412 .70906 m
.68414 .70915 L
s
.68414 .70915 m
.68424 .70958 L
s
.63017 .7218 m .63218 .71941 L .62895 .71374 L 0 .09 .193 r
F
0 g
.62895 .71374 m
.62909 .71466 L
s
.62886 .71355 m
.62895 .71374 L
s
.63017 .7218 m .63849 .73615 L .63218 .71941 L 0 .09 .193 r
F
.63017 .7218 m .64368 .7528 L .63849 .73615 L F
.63017 .7218 m .6449 .76089 L .64368 .7528 L F
.63017 .7218 m .64134 .755 L .6449 .76089 L F
.63017 .7218 m .63502 .73823 L .64134 .755 L F
0 g
.62593 .70913 m
.63017 .7218 L
s
.62909 .71466 m
.63017 .7218 L
s
.5736 .65842 m .57158 .65602 L .57006 .65908 L 0 1 .247 r
F
.5736 .65842 m .57772 .65126 L .57158 .65602 L F
.47651 .48817 m .48711 .48537 L .4948 .48386 L 0 0 0 r
F
0 g
.48711 .48537 m
.494 .48291 L
s
.79073 .87274 m .8003 .87766 L .80315 .87401 L 0 1 .471 r
F
.79073 .87274 m .79566 .87849 L .8003 .87766 L F
0 g
.8003 .87766 m
.80347 .88014 L
s
.51316 .94818 m .52284 .92829 L .52312 .92899 L 0 .302 .125 r
F
.51316 .94818 m .5198 .93386 L .52284 .92829 L F
0 g
.52284 .92829 m
.52293 .92797 L
s
.51642 .93096 m
.51813 .92375 L
s
.5145 .93127 m
.51518 .92407 L
s
.51476 .93119 m
.51579 .92396 L
s
.5156 .931 m
.51699 .9237 L
s
.29385 .73939 m .28328 .73408 L .28317 .73817 L 0 1 .499 r
F
0 g
.27739 .73951 m
.28317 .73817 L
s
.55454 .67701 m .56628 .66733 L .56779 .66393 L 0 1 .384 r
F
.55454 .67701 m .56061 .67293 L .56628 .66733 L F
0 g
.56628 .66733 m
.56949 .66638 L
s
.56061 .67293 m
.56628 .66733 L
s
.63419 .6203 m .64969 .61796 L .65332 .61602 L 0 1 .356 r
F
.63419 .6203 m .6415 .61979 L .64969 .61796 L F
0 g
.64969 .61796 m
.65197 .61946 L
s
.6415 .61979 m
.64489 .62046 L
s
.6415 .61979 m
.64969 .61796 L
s
.82413 1.01 m .83521 1.00434 L .83425 1.00036 L 0 1 .438 r
F
.73306 .65835 m .75085 .64142 L .74897 .64541 L 0 0 0 r
F
0 g
.7437 .67095 m
.74852 .65807 L
s
.72963 .65536 m
.73643 .64763 L
s
.75085 .64142 m
.75782 .63505 L
s
.79073 .87274 m .79156 .87639 L .79566 .87849 L 0 1 .471 r
F
0 g
.79189 .88189 m
.79566 .87849 L
s
.50654 .94625 m .50244 .94582 L .50496 .94634 L 0 .326 .343 r
F
.50759 .94785 m .50496 .94634 L .50244 .94582 L 0 .307 .328 r
F
0 g
.50146 .94615 m
.50244 .94582 L
s
.50068 .94498 m
.50244 .94582 L
s
.59922 .63796 m .59765 .63592 L .59569 .63815 L 0 1 .238 r
F
.59922 .63796 m .60444 .63281 L .59765 .63592 L F
.59922 .63796 m .6115 .6309 L .60444 .63281 L F
0 g
.6115 .6309 m
.61857 .62818 L
s
.6115 .6309 m
.61501 .63073 L
s
.59275 .64153 m
.59922 .63796 L
s
.50777 1.05104 m .50485 1.04538 L .50215 1.04211 L 0 .073 .179 r
F
.45468 .79056 m .44691 .78958 L .45003 .78896 L 0 .167 .007 r
F
0 g
.45003 .78896 m
.45024 .78676 L
s
.45468 .79056 m .44719 .79216 L .44691 .78958 L 0 .167 .007 r
F
.45468 .79056 m .45068 .795 L .44719 .79216 L F
.45468 .79056 m .45536 .7966 L .45068 .795 L F
.45468 .79056 m .45808 .7959 L .45536 .7966 L F
.45468 .79056 m .45779 .79331 L .45808 .7959 L F
0 g
.45468 .79056 m
.45469 .7875 L
s
.45003 .78896 m
.45468 .79056 L
s
.24737 .6325 m .24419 .62013 L .2372 .62914 L 0 1 .516 r
F
0 g
.23508 .63684 m
.2372 .62914 L
s
.24737 .6325 m .25237 .61446 L .24419 .62013 L 0 1 .516 r
F
.24737 .6325 m .25628 .61593 L .25237 .61446 L F
.24737 .6325 m .25412 .62367 L .25628 .61593 L F
0 g
.24542 .64012 m
.24737 .6325 L
s
.23922 .63813 m
.24737 .6325 L
s
.51226 .95421 m .5104 .95684 L .51137 .95791 L 0 .212 .247 r
F
.51226 .95421 m .51019 .95517 L .5104 .95684 L F
0 g
.50915 .95658 m
.5104 .95684 L
s
.51316 .94817 m .51279 .93216 L .513 .94129 L 0 .296 .109 r
F
.51316 .94817 m .513 .94129 L .51279 .93216 L 0 .302 .11 r
F
.51316 .94817 m .51316 .94817 L .513 .94129 L F
.51316 .94817 m .51258 .91278 L .51196 .89702 L 0 .364 .264 r
F
0 g
.51196 .89702 m
.51196 .89712 L
s
.51286 .92985 m
.513 .92513 L
s
.51265 .89723 m
.51265 .89724 L
s
.51264 .89689 m
.51265 .89723 L
s
.51265 .89724 m
.51265 .89724 L
s
.51269 .89824 m
.51269 .89824 L
s
.51265 .89724 m
.51269 .89824 L
s
.51269 .89824 m
.51269 .89824 L
s
.51196 .89702 m
.51196 .8965 L
s
.48968 .91815 m .48188 .90823 L .47824 .90542 L 0 .643 .414 r
F
0 g
.47496 .90136 m
.47824 .90542 L
s
.47799 .9066 m
.48066 .90998 L
s
.69735 .79929 m
.69818 .80792 L
s
.69497 .80709 m
.69735 .79929 L
s
.74383 .81897 m .75135 .79755 L .75596 .79885 L 0 .239 .087 r
F
.74383 .81897 m .74616 .80613 L .75135 .79755 L F
0 g
.74892 .78915 m
.75135 .79755 L
s
.50167 .93606 m .49331 .92812 L .49 .9258 L 0 .468 .388 r
F
0 g
.48996 .92577 m
.49 .9258 L
s
.49155 .93065 m
.49387 .9319 L
s
.49473 .9341 m
.49505 .93425 L
s
.49424 .93348 m
.495 .93408 L
s
.495 .93408 m
.49521 .93426 L
s
.49521 .93426 m
.49523 .93427 L
s
.4941 .93396 m
.49433 .93404 L
s
.49433 .93404 m
.49473 .93418 L
s
.49473 .93418 m
.49478 .9342 L
s
.49478 .9342 m
.49488 .93423 L
s
.49488 .93423 m
.49496 .93426 L
s
.46872 .88897 m .46674 .88297 L .46243 .87839 L 0 .878 .434 r
F
.46872 .88897 m .46944 .8875 L .46674 .88297 L F
.47981 .90104 m .46872 .88897 L .47155 .89359 L 0 .77 .422 r
F
.47981 .90104 m .46944 .8875 L .46872 .88897 L F
0 g
.46483 .88699 m
.46872 .88897 L
s
.46872 .88897 m
.47069 .89218 L
s
.49533 1.00171 m .49354 .997 L .49064 .99468 L 0 .259 .285 r
F
.51316 .94817 m .50131 .91617 L .50484 .92655 L 0 .406 .275 r
F
0 g
.50131 .91617 m
.50143 .9165 L
s
.50143 .9165 m
.50147 .91665 L
s
.50147 .91665 m
.50162 .91708 L
s
.50462 .93305 m
.50469 .93312 L
s
.50255 .90247 m
.5056 .9167 L
s
.50224 .90423 m
.5056 .9167 L
s
.50247 .93117 m
.50462 .93305 L
s
.50109 .91582 m
.50131 .91617 L
s
.77916 .87561 m .7887 .87975 L .79156 .87639 L 0 1 .45 r
F
.77916 .87561 m .78406 .88059 L .7887 .87975 L F
0 g
.7887 .87975 m
.79189 .88189 L
s
.35937 .82164 m .34907 .8183 L .3503 .8237 L 0 1 .486 r
F
0 g
.34582 .82707 m
.3503 .8237 L
s
.47651 .48817 m .46703 .49107 L .4679 .49061 L 0 0 0 r
F
0 g
.46784 .49031 m
.46922 .4897 L
s
.47651 .48817 m .47471 .48956 L .46703 .49107 L 0 0 0 r
F
.47651 .48817 m .48583 .48709 L .47471 .48956 L F
.47651 .48817 m .49444 .48465 L .48583 .48709 L F
.47651 .48817 m .4948 .48386 L .49444 .48465 L F
0 g
.48711 .48537 m
.4948 .48386 L
s
.46922 .4897 m
.47651 .48817 L
s
.4948 .48386 m
.50307 .48239 L
s
.4069 .82981 m .39766 .8285 L .40199 .83101 L 0 1 .463 r
F
0 g
.40199 .83101 m
.40393 .83599 L
s
.33829 .90278 m .33108 .89746 L .32766 .89846 L 0 1 .434 r
F
.33829 .90278 m .33542 .89846 L .33108 .89746 L F
.33829 .90278 m .33851 .90074 L .33542 .89846 L F
.34915 .90494 m .33851 .90074 L .33829 .90278 L 0 .908 .403 r
F
0 g
.33486 .90377 m
.33829 .90278 L
s
.33829 .90278 m
.34138 .90488 L
s
.41755 .83701 m .40911 .8257 L .4069 .82981 L 0 1 .459 r
F
.41755 .83701 m .41385 .82501 L .40911 .8257 L F
.41755 .83701 m .41796 .8282 L .41385 .82501 L F
.41755 .83701 m .41955 .83335 L .41796 .8282 L F
0 g
.41289 .83769 m
.41755 .83701 L
s
.41755 .83701 m
.4193 .84202 L
s
.53113 .74814 m .54074 .72816 L .53796 .72457 L 0 1 .361 r
F
0 g
.53996 .73711 m
.54192 .74003 L
s
.54066 .74336 m
.54192 .74003 L
s
.53113 .74814 m .5396 .73657 L .54074 .72816 L 0 1 .361 r
F
0 g
.54074 .72816 m
.54511 .71838 L
s
.54007 .74492 m
.54066 .74336 L
s
.77916 .87561 m .77997 .87883 L .78406 .88059 L 0 1 .45 r
F
0 g
.78032 .88369 m
.78406 .88059 L
s
.51316 .94817 m .51476 .9312 L .51385 .94088 L 0 .31 .115 r
F
0 g
.51476 .9312 m
.51489 .92958 L
s
.51316 .94817 m .51385 .94088 L .51476 .9312 L 0 .312 .116 r
F
0 g
.51476 .9312 m
.51476 .93119 L
s
.51316 .94817 m .51374 .94092 L .5145 .93128 L 0 .31 .115 r
F
0 g
.5145 .93128 m
.5145 .93127 L
s
.51316 .94817 m .5145 .93128 L .51374 .94092 L 0 .306 .112 r
F
0 g
.5145 .93128 m
.5147 .92426 L
s
.48968 .91815 m .48133 .91084 L .48603 .91533 L 0 .643 .414 r
F
.48945 .92009 m .48603 .91533 L .48133 .91084 L 0 .645 .417 r
F
0 g
.48066 .90998 m
.48133 .91084 L
s
.47774 .90841 m
.48133 .91084 L
s
.53267 .98259 m .53216 .98097 L .53445 .98246 L 0 .204 0 r
F
0 g
.53445 .98246 m
.5346 .98237 L
s
.53445 .98246 m
.53454 .98253 L
s
.47981 .90104 m .47155 .89359 L .47604 .89828 L 0 .77 .422 r
F
.47872 .90372 m .47604 .89828 L .47155 .89359 L 0 .776 .428 r
F
0 g
.4678 .89124 m
.47155 .89359 L
s
.47069 .89218 m
.47155 .89359 L
s
.50759 .94785 m .50426 .94816 L .50635 .94825 L 0 .307 .328 r
F
.5087 .94944 m .50635 .94825 L .50426 .94816 L 0 .286 .311 r
F
0 g
.50211 .94731 m
.50426 .94816 L
s
.50337 .94888 m
.50426 .94816 L
s
.28753 .82278 m .27611 .8212 L .27778 .82668 L 0 1 .522 r
F
0 g
.27332 .8313 m
.27778 .82668 L
s
.51316 .94818 m .50558 .93295 L .50804 .93718 L 0 .287 .111 r
F
.51316 .94818 m .50521 .93357 L .50558 .93295 L F
0 g
.50534 .93249 m
.50558 .93295 L
s
.40448 .91928 m
.4064 .91979 L
s
.62794 .62447 m .6269 .62202 L .62452 .6238 L 0 1 .296 r
F
.62794 .62447 m .63419 .6203 L .6269 .62202 L F
.62794 .62447 m .6415 .61979 L .63419 .6203 L F
0 g
.6415 .61979 m
.6415 .61979 L
s
.49332 .97465 m .48983 .98057 L .49234 .97892 L 0 .311 .295 r
F
.49645 .98478 m .49234 .97892 L .48983 .98057 L 0 .285 .286 r
F
0 g
.48923 .9853 m
.48983 .98057 L
s
.48677 .97831 m
.48983 .98057 L
s
.51316 .94817 m .5156 .93101 L .51421 .9408 L 0 .312 .116 r
F
.51316 .94817 m .51421 .9408 L .5156 .93101 L 0 .316 .118 r
F
0 g
.5156 .93101 m
.51628 .92379 L
s
.5156 .93101 m
.5156 .931 L
s
.51316 .94817 m .51365 .93166 L .51337 .94108 L 0 .302 .11 r
F
.51316 .94817 m .51337 .94108 L .51365 .93166 L 0 .306 .112 r
F
0 g
.51365 .93166 m
.51421 .9245 L
s
.51349 .92484 m
.51365 .93166 L
s
.42487 .51058 m .41403 .51473 L .4159 .51474 L 0 .908 .22 r
F
0 g
.41004 .51989 m
.4159 .51474 L
s
.42487 .51058 m .42056 .51071 L .41403 .51473 L 0 .908 .22 r
F
.42487 .51058 m .43114 .50535 L .42056 .51071 L F
.42487 .51058 m .44012 .50119 L .43114 .50535 L F
.42487 .51058 m .4415 .50099 L .44012 .50119 L F
.42487 .51058 m .43496 .50502 L .4415 .50099 L F
0 g
.41869 .51456 m
.42487 .51058 L
s
.4159 .51474 m
.42487 .51058 L
s
.43496 .50502 m
.44357 .50051 L
s
.51516 .90547 m .51565 .90718 L .51686 .89227 L 0 .492 .266 r
F
.53561 .79933 m .54253 .76497 L .53876 .76713 L 0 1 .311 r
F
.53561 .79933 m .54417 .7742 L .54253 .76497 L F
0 g
.54253 .76497 m
.54399 .76109 L
s
.6822 .79934 m
.68258 .80655 L
s
.53312 .72822 m .54244 .71675 L .54359 .70997 L 0 1 .381 r
F
.53312 .72822 m .53796 .72457 L .54244 .71675 L F
0 g
.54244 .71675 m
.54511 .71838 L
s
.76759 .87855 m .7771 .88188 L .77997 .87883 L 0 1 .422 r
F
.76759 .87855 m .77246 .88275 L .7771 .88188 L F
0 g
.7771 .88188 m
.78032 .88369 L
s
.47064 .88538 m .46243 .87839 L .46674 .88297 L 0 .872 .427 r
F
.47064 .88538 m .46004 .87358 L .46243 .87839 L F
0 g
.45853 .87641 m
.46243 .87839 L
s
.50254 .93968 m .49449 .93688 L .49154 .93431 L 0 .276 .1 r
F
0 g
.49533 .93439 m
.49533 .93439 L
s
.49532 .93438 m
.49533 .93439 L
s
.49524 .93436 m
.49532 .93438 L
s
.4952 .93434 m
.49524 .93436 L
s
.49496 .93426 m
.49513 .93432 L
s
.49513 .93432 m
.4952 .93434 L
s
.4953 .93437 m
.49534 .93438 L
s
.49524 .93434 m
.4953 .93437 L
s
.49505 .93425 m
.49524 .93434 L
s
.48794 .93374 m
.49154 .93431 L
s
.6285 .52915 m
.6289 .52966 L
s
.6289 .52966 m
.63031 .53149 L
s
.63178 .53339 m .64759 .55279 L .63769 .54053 L 0 0 .149 r
F
.63178 .53339 m .653 .55979 L .64759 .55279 L F
0 g
.64645 .55203 m
.6465 .55212 L
s
.63178 .53339 m .65031 .55684 L .653 .55979 L 0 0 .149 r
F
0 g
.6313 .53276 m
.63178 .53339 L
s
.6465 .55212 m
.64771 .5542 L
s
.80198 1.0234 m .79918 1.02981 L .80035 1.03271 L 0 1 .379 r
F
0 g
.79405 1.03835 m
.80035 1.03271 L
s
.52551 1.08582 m .52975 1.09039 L .529 1.09039 L 0 .193 0 r
F
0 g
.52701 1.08603 m
.52975 1.09039 L
s
.53057 1.09384 m .529 1.09039 L .52975 1.09039 L 0 .316 0 r
F
0 g
.52975 1.09039 m
.53132 1.0918 L
s
.51226 .95421 m .51137 .95791 L .51226 .9575 L 0 .212 .247 r
F
0 g
.51137 .95791 m
.51194 .95944 L
s
.45034 .49767 m .46075 .49344 L .4679 .49061 L 0 0 0 r
F
0 g
.46075 .49344 m
.46784 .49031 L
s
.49618 .95354 m .49094 .95703 L .49422 .95639 L 0 .372 .292 r
F
.49796 .96142 m .49422 .95639 L .49094 .95703 L 0 .333 .287 r
F
0 g
.48931 .96053 m
.49094 .95703 L
s
.48774 .95449 m
.49094 .95703 L
s
.54316 .99192 m .54158 .98985 L .54241 .98874 L 0 .275 .007 r
F
0 g
.54158 .98985 m
.54241 .98874 L
s
.54115 .98803 m
.54241 .98874 L
s
.76759 .87855 m .76838 .88133 L .77246 .88275 L 0 1 .422 r
F
0 g
.76874 .88554 m
.77246 .88275 L
s
.75981 .60332 m .77976 .60907 L .77704 .60519 L 0 1 .493 r
F
0 g
.77976 .60907 m
.78759 .61227 L
s
.49618 .95354 m .49551 .9504 L .49231 .94786 L 0 .372 .292 r
F
.53113 .74814 m .53549 .74514 L .5396 .73657 L 0 1 .361 r
F
0 g
.53733 .7413 m
.5396 .73657 L
s
.5396 .73657 m
.53996 .73711 L
s
.51316 .94817 m .51641 .93099 L .51456 .94079 L 0 .316 .118 r
F
.51316 .94817 m .51456 .94079 L .51641 .93099 L 0 .318 .12 r
F
0 g
.51641 .93099 m
.51642 .93096 L
s
.51641 .93099 m
.51745 .92369 L
s
.51316 .94818 m .52312 .92899 L .52029 .9351 L 0 .302 .125 r
F
0 g
.51793 .93149 m
.51964 .92426 L
s
.51721 .93107 m
.51922 .92405 L
s
.5172 .93111 m
.51857 .92384 L
s
.51794 .93148 m
.52025 .92465 L
s
.52312 .92899 m
.52371 .92764 L
s
.45034 .49767 m .44012 .50119 L .4415 .50099 L 0 0 0 r
F
.45034 .49767 m .44727 .49835 L .44012 .50119 L F
0 g
.43496 .50502 m
.4415 .50099 L
s
.45034 .49767 m .45818 .49439 L .44727 .49835 L 0 0 0 r
F
.45034 .49767 m .4679 .49061 L .46703 .49107 L F
.45034 .49767 m .46703 .49107 L .45818 .49439 L F
0 g
.44357 .50051 m
.45034 .49767 L
s
.4415 .50099 m
.45034 .49767 L
s
.46175 .49305 m
.4679 .49061 L
s
.4679 .49061 m
.47651 .48817 L
s
.50254 .93968 m .49541 .93441 L .49957 .93711 L 0 .276 .1 r
F
.50254 .93871 m .49541 .93441 L .49957 .93711 L 0 .44 .383 r
F
0 g
.49533 .93439 m
.49541 .93441 L
s
.49534 .93438 m
.49541 .93441 L
s
.49523 .93427 m
.49541 .93441 L
s
.50142 .93485 m .48972 .92441 L .49331 .92812 L 0 .474 .389 r
F
.50142 .93485 m .48959 .92351 L .48972 .92441 L F
0 g
.4886 .92385 m
.48972 .92441 L
s
.31669 .60922 m .30871 .6082 L .31227 .61021 L 0 1 .46 r
F
.31669 .60922 m .30785 .60435 L .30871 .6082 L F
.31669 .60922 m .31028 .60123 L .30785 .60435 L F
.31669 .60922 m .31471 .60024 L .31028 .60123 L F
.31669 .60922 m .31818 .60203 L .31471 .60024 L F
.31669 .60922 m .31902 .60588 L .31818 .60203 L F
0 g
.31669 .60922 m
.31759 .61356 L
s
.31227 .61021 m
.31669 .60922 L
s
.31902 .60588 m
.32337 .60491 L
s
.71307 .60417 m .72914 .60752 L .73284 .60649 L 0 1 .454 r
F
.71307 .60417 m .72068 .60652 L .72914 .60752 L F
0 g
.72914 .60752 m
.73132 .61039 L
s
.4069 .82981 m .39623 .8232 L .39766 .8285 L 0 1 .463 r
F
0 g
.39297 .83002 m
.39766 .8285 L
s
.30152 .82483 m .28982 .81618 L .28753 .82278 L 0 1 .517 r
F
.30152 .82483 m .29569 .8119 L .28982 .81618 L F
0 g
.28753 .82278 m
.29004 .8283 L
s
.30152 .82483 m .3012 .81283 L .29569 .8119 L 0 1 .517 r
F
.30152 .82483 m .3037 .81837 L .3012 .81283 L F
0 g
.29567 .82908 m
.30152 .82483 L
s
.46004 .87358 m .45484 .86238 L .45077 .8607 L 0 .96 .436 r
F
.46004 .87358 m .45893 .86694 L .45484 .86238 L F
.46004 .87358 m .46116 .87174 L .45893 .86694 L F
.47064 .88538 m .46116 .87174 L .46004 .87358 L 0 .872 .427 r
F
0 g
.46004 .87358 m
.46243 .87839 L
s
.45597 .87189 m
.46004 .87358 L
s
.49796 .96142 m .49041 .96456 L .49342 .96645 L 0 .333 .287 r
F
0 g
.48906 .96836 m
.49041 .96456 L
s
.61847 .68816 m
.61984 .69106 L
s
.39451 .91624 m .38609 .91435 L .39082 .91556 L 0 .468 .224 r
F
.39451 .91624 m .38269 .91291 L .38609 .91435 L F
0 g
.3828 .91395 m
.38609 .91435 L
s
.39082 .91556 m
.3946 .91673 L
s
.51316 .94817 m .5013 .91856 L .50131 .92019 L 0 .406 .274 r
F
.51316 .94817 m .50484 .92655 L .5013 .91856 L F
0 g
.50114 .91996 m
.50131 .92019 L
s
.50105 .918 m
.5013 .91856 L
s
.50162 .91708 m
.50247 .91958 L
s
.50178 .91574 m
.50287 .91858 L
s
.5119 .9325 m
.5119 .9325 L
s
.50989 .93291 m
.50989 .93291 L
s
.50182 .90742 m
.50528 .91888 L
s
.50469 .93312 m
.50508 .93346 L
s
.50206 .90547 m
.50528 .91888 L
s
.50752 .93353 m
.50752 .93353 L
s
.50159 .91923 m
.50177 .91962 L
s
.50157 .91917 m
.50159 .91923 L
s
.50148 .91897 m
.50157 .91917 L
s
.50147 .91895 m
.50148 .91897 L
s
.50137 .91871 m
.50147 .91895 L
s
.50134 .91866 m
.50137 .91871 L
s
.5013 .91856 m
.50134 .91866 L
s
.75602 .88154 m .7655 .88408 L .76838 .88133 L 0 1 .387 r
F
.75602 .88154 m .76086 .88497 L .7655 .88408 L F
0 g
.7655 .88408 m
.76874 .88554 L
s
.52464 .93596 m .5245 .93487 L .52774 .92706 L 0 .26 .133 r
F
0 g
.5269 .92857 m
.52718 .92807 L
s
.52718 .92807 m
.52731 .92784 L
s
.52731 .92784 m
.52774 .92706 L
s
.52476 .93047 m
.52493 .93 L
s
.52437 .9297 m
.52712 .92407 L
s
.52424 .93187 m
.52476 .93047 L
s
.5087 .94944 m .50617 .9505 L .50781 .95017 L 0 .286 .311 r
F
.50986 .95104 m .50781 .95017 L .50617 .9505 L 0 .263 .292 r
F
0 g
.50564 .95154 m
.50617 .9505 L
s
.50427 .94994 m
.50617 .9505 L
s
.36258 .67747 m
.36636 .67697 L
s
.5026 1.03243 m .50051 1.03702 L .50318 1.03973 L 0 .16 .236 r
F
0 g
.50051 1.03702 m
.50215 1.04211 L
s
.48946 .92219 m .48942 .92133 L .48584 .91766 L 0 .642 .419 r
F
0 g
.48584 .91766 m
.48796 .91983 L
s
.48671 .91824 m
.48725 .9186 L
s
.48646 .91807 m
.48671 .91824 L
s
.48584 .91766 m
.48646 .91807 L
s
.43022 .92605 m .42158 .92456 L .41821 .92313 L 0 0 0 r
F
.43022 .92605 m .42632 .9261 L .42158 .92456 L F
.43022 .92605 m .43002 .92674 L .42632 .9261 L F
.44202 .92962 m .43002 .92674 L .43022 .92605 L 0 .037 0 r
F
0 g
.43022 .92605 m
.4339 .92654 L
s
.42684 .92462 m
.43022 .92605 L
s
.34915 .90494 m .34194 .90002 L .33851 .90074 L 0 .908 .403 r
F
.34915 .90494 m .34628 .9011 L .34194 .90002 L F
.34915 .90494 m .34937 .90321 L .34628 .9011 L F
.36 .90729 m .34937 .90321 L .34915 .90494 L 0 .78 .36 r
F
0 g
.34572 .90565 m
.34915 .90494 L
s
.34915 .90494 m
.35224 .90686 L
s
.51316 .94817 m .5127 .89855 L .51258 .91278 L 0 .374 .265 r
F
.51316 .94817 m .51319 .89971 L .5127 .89855 L F
0 g
.51269 .89824 m
.5127 .89855 L
s
.75602 .88154 m .7568 .88389 L .76086 .88497 L 0 1 .387 r
F
0 g
.75716 .88744 m
.76086 .88497 L
s
.50205 .93319 m .50189 .93139 L .49837 .92612 L 0 .449 .286 r
F
.51316 .94818 m .50739 .93827 L .50521 .93357 L 0 .287 .111 r
F
0 g
.50508 .93346 m
.50521 .93357 L
s
.78365 .79839 m .79047 .80319 L .78587 .80303 L 0 .093 .016 r
F
.78365 .79839 m .79521 .79958 L .79047 .80319 L F
.47981 .90104 m .4732 .89026 L .46944 .8875 L 0 .77 .422 r
F
0 g
.46674 .88297 m
.46944 .8875 L
s
.53312 .72822 m .54359 .70997 L .54045 .70777 L 0 1 .381 r
F
0 g
.53811 .72477 m
.54074 .72816 L
s
.54359 .70997 m
.54831 .70131 L
s
.47202 .79674 m
.47238 .79941 L
s
.51316 .94817 m .51719 .93115 L .51489 .94086 L 0 .318 .12 r
F
.51316 .94817 m .51489 .94086 L .51719 .93115 L 0 .318 .122 r
F
0 g
.51719 .93115 m
.51721 .93107 L
s
.51719 .93115 m
.5172 .93111 L
s
.52177 .96943 m .52605 .975 L .52571 .97433 L 0 0 .149 r
F
0 g
.52605 .975 m
.52631 .97521 L
s
.50385 .94706 m .49399 .94255 L .49457 .94568 L 0 .373 .28 r
F
.50385 .94706 m .49648 .94127 L .49399 .94255 L F
0 g
.49378 .94235 m
.49399 .94255 L
s
.49399 .94255 m
.49435 .94236 L
s
.50142 .93485 m .49302 .92619 L .48959 .92351 L 0 .474 .389 r
F
0 g
.48668 .92081 m
.48959 .92351 L
s
.49154 .93431 m
.49239 .93505 L
s
.49066 .92819 m
.4934 .92989 L
s
.47872 .90372 m .47911 .90262 L .47604 .89828 L 0 .776 .428 r
F
.49017 .91637 m .47872 .90372 L .48188 .90823 L 0 .638 .41 r
F
.49017 .91637 m .47911 .90262 L .47872 .90372 L F
0 g
.47496 .90136 m
.47872 .90372 L
s
.47872 .90372 m
.48086 .90677 L
s
.28328 .73408 m .27243 .73353 L .27673 .73537 L 0 1 .516 r
F
0 g
.27673 .73537 m
.27739 .73951 L
s
.49994 1.01358 m .49434 1.01414 L .49667 1.01931 L 0 .217 .264 r
F
.49994 1.01358 m .49382 1.00876 L .49434 1.01414 L F
0 g
.49138 1.01135 m
.49434 1.01414 L
s
.76181 1.06111 m .75825 1.06414 L .75874 1.06423 L 0 .867 .181 r
F
0 g
.75214 1.06776 m
.75874 1.06423 L
s
.49645 .98478 m .49093 .98997 L .49376 .99178 L 0 .285 .286 r
F
0 g
.49064 .99468 m
.49093 .98997 L
s
.35937 .82164 m .3516 .81234 L .34907 .8183 L 0 1 .486 r
F
.35937 .82164 m .35651 .80903 L .3516 .81234 L F
.35937 .82164 m .36053 .81058 L .35651 .80903 L F
.35937 .82164 m .36175 .81599 L .36053 .81058 L F
0 g
.35446 .82494 m
.35937 .82164 L
s
.35937 .82164 m
.3607 .82692 L
s
.74446 .88461 m .75389 .88634 L .7568 .88389 L 0 1 .344 r
F
.74446 .88461 m .74925 .88727 L .75389 .88634 L F
0 g
.75389 .88634 m
.75716 .88744 L
s
.34907 .8183 m .33988 .82084 L .34405 .82194 L 0 1 .491 r
F
0 g
.34405 .82194 m
.34582 .82707 L
s
.51942 .96674 m .52256 .97098 L .52118 .96902 L 0 .045 .166 r
F
.52177 .96943 m .52118 .96902 L .52256 .97098 L 0 0 .149 r
F
0 g
.52256 .97098 m
.52465 .97354 L
s
.52255 .97116 m
.52256 .97098 L
s
.51316 .94817 m .50131 .92019 L .50486 .92942 L 0 .406 .274 r
F
0 g
.50131 .92019 m
.50133 .92024 L
s
.50133 .92024 m
.50134 .92027 L
s
.50134 .92027 m
.50143 .92049 L
s
.50143 .92049 m
.5015 .92068 L
s
.5015 .92068 m
.50164 .92105 L
s
.50164 .92105 m
.50189 .92169 L
s
.50189 .92169 m
.50215 .92237 L
s
.51109 .93345 m
.51109 .93345 L
s
.50255 .91603 m
.50426 .92173 L
s
.50231 .91322 m
.50504 .92125 L
s
.50504 .92125 m
.50505 .92126 L
s
.50131 .92257 m
.50131 .92257 L
s
.50131 .92257 m
.50131 .92257 L
s
.50438 .93408 m
.50449 .93424 L
s
.50287 .91858 m
.5035 .9202 L
s
.50247 .91958 m
.50292 .92092 L
s
.50131 .92019 m
.50131 .92019 L
s
.31818 .60203 m
.31902 .60588 L
s
.51867 .92084 m .52195 .88835 L .51989 .90585 L 0 .466 .264 r
F
.51754 .9151 m .51989 .90585 L .52195 .88835 L 0 .481 .265 r
F
0 g
.52195 .88835 m
.5228 .87186 L
s
.52195 .88835 m
.52214 .88753 L
s
.47875 .93459 m .47462 .9357 L .46997 .9342 L 0 .222 .067 r
F
.47875 .93459 m .47839 .93587 L .47462 .9357 L F
.49019 .9388 m .47875 .93459 L .48243 .93492 L 0 .267 .086 r
F
.49019 .9388 m .47839 .93587 L .47875 .93459 L F
0 g
.47563 .93252 m
.47875 .93459 L
s
.47875 .93459 m
.4791 .93462 L
s
.4069 .82981 m .39866 .81864 L .39623 .8232 L 0 1 .463 r
F
0 g
.39623 .8232 m
.39766 .8285 L
s
.4069 .82981 m .40357 .81744 L .39866 .81864 L 0 1 .463 r
F
.4069 .82981 m .40769 .8204 L .40357 .81744 L F
.4069 .82981 m .40911 .8257 L .40769 .8204 L F
0 g
.40199 .83101 m
.4069 .82981 L
s
.4069 .82981 m
.40849 .83495 L
s
.37439 .77061 m .36872 .76938 L .365 .76804 L 0 0 0 r
F
.37439 .77061 m .37422 .77113 L .36872 .76938 L F
.37439 .77061 m .37782 .77211 L .37422 .77113 L F
.37439 .77061 m .37789 .77189 L .37782 .77211 L F
0 g
.37439 .77061 m
.37464 .77027 L
s
.36891 .76887 m
.37439 .77061 L
s
.50205 .93735 m .49451 .93225 L .49888 .93539 L 0 .457 .386 r
F
.50254 .93871 m .49888 .93539 L .49451 .93225 L 0 .44 .383 r
F
0 g
.49098 .92916 m
.49451 .93225 L
s
.49387 .9319 m
.49451 .93225 L
s
.50247 .93117 m
.50438 .93408 L
s
.6614 .61492 m .66126 .61171 L .65828 .61334 L 0 1 .372 r
F
.6614 .61492 m .6691 .6111 L .66126 .61171 L F
.27611 .8212 m .26629 .8252 L .27088 .82579 L 0 1 .526 r
F
0 g
.27088 .82579 m
.27332 .8313 L
s
.55142 .6881 m .54915 .68349 L .54803 .68805 L 0 1 .366 r
F
.55142 .6881 m .55454 .67701 L .54915 .68349 L F
.55142 .6881 m .5606 .67293 L .55454 .67701 L F
0 g
.5606 .67293 m
.56397 .67299 L
s
.74446 .88461 m .74521 .88653 L .74925 .88727 L 0 1 .344 r
F
0 g
.74521 .88653 m
.74925 .88727 L
s
.74558 .88941 m
.74925 .88727 L
s
.51349 .95576 m .51283 .9595 L .51381 .96057 L 0 .186 .225 r
F
.51349 .95576 m .51226 .9575 L .51283 .9595 L F
0 g
.51194 .95944 m
.51283 .9595 L
s
.49019 .9388 m .48243 .93492 L .48696 .93664 L 0 .267 .086 r
F
.49096 .93597 m .48696 .93664 L .48243 .93492 L 0 .251 .085 r
F
0 g
.48001 .93314 m
.48243 .93492 L
s
.48794 .93374 m
.49084 .93588 L
s
.4791 .93462 m
.48243 .93492 L
s
.75858 .65367 m .76181 .66305 L .75785 .66531 L 0 .141 .085 r
F
0 g
.75785 .66531 m
.75793 .66406 L
s
.75858 .65367 m .76867 .64959 L .76181 .66305 L 0 .141 .085 r
F
0 g
.75793 .66406 m
.75858 .65367 L
s
.75343 .66543 m
.75858 .65367 L
s
.75282 .66683 m
.75343 .66543 L
s
.75192 .66887 m
.75282 .66683 L
s
.51867 .92084 m .5238 .8996 L .52501 .88465 L 0 .466 .264 r
F
0 g
.52501 .88465 m
.5255 .88208 L
s
.38235 .67049 m
.38331 .67013 L
s
.38288 .67031 m
.38895 .66822 L
s
.51751 .96461 m .51721 .96427 L .51755 .96518 L 0 .07 .172 r
F
0 g
.51755 .96517 m
.51755 .96518 L
s
.39623 .8232 m .38711 .82276 L .39128 .82496 L 0 1 .467 r
F
0 g
.39128 .82496 m
.39297 .83002 L
s
.58876 .65249 m
.58908 .65274 L
s
.58437 .64892 m
.58876 .65249 L
s
.53267 .98259 m .53912 .98688 L .53836 .98695 L 0 .204 0 r
F
0 g
.53897 .98689 m
.53904 .98689 L
s
.53904 .98689 m
.53912 .98688 L
s
.53912 .98688 m
.54115 .98803 L
s
.365 .76804 m .35553 .76478 L .35935 .76607 L 0 0 0 r
F
0 g
.35939 .76611 m
.35992 .76668 L
s
.50986 .95104 m .50815 .95283 L .50933 .95208 L 0 .263 .292 r
F
.51105 .95263 m .50933 .95208 L .50815 .95283 L 0 .238 .27 r
F
0 g
.50683 .95264 m
.50815 .95283 L
s
.50799 .95419 m
.50815 .95283 L
s
.524 1.08429 m .52161 1.07973 L .52551 1.08582 L 0 0 .105 r
F
.524 1.08429 m .51848 1.07465 L .52161 1.07973 L F
0 g
.51889 1.07539 m
.51908 1.0757 L
s
.51316 .94817 m .51344 .91481 L .51319 .89971 L 0 .374 .265 r
F
0 g
.51319 .89971 m
.51368 .883 L
s
.5438 .80016 m .54417 .7742 L .54259 .78869 L 0 1 .292 r
F
.53561 .79933 m .54259 .78869 L .54417 .7742 L 0 1 .311 r
F
0 g
.54253 .76497 m
.54417 .7742 L
s
.54417 .7742 m
.54649 .7665 L
s
.59421 .65715 m .59295 .65693 L .59092 .65424 L 0 .154 0 r
F
0 g
.59092 .65424 m
.59126 .65454 L
s
.58908 .65274 m
.59092 .65424 L
s
.59602 .65956 m .5996 .66433 L .59516 .65939 L 0 .154 0 r
F
.5996 .66433 m .59802 .66227 L .59599 .66037 L 0 .029 .153 r
F
.59313 .65898 m .59802 .66227 L .59383 .65953 L 0 0 0 r
F
.58192 .65007 m .59387 .65913 L .59313 .65898 L F
.59387 .65913 m .59802 .66227 L .59313 .65898 L F
.59421 .65715 m .59602 .65956 L .59295 .65693 L 0 .154 0 r
F
.59602 .65956 m .59516 .65939 L .59295 .65693 L F
.59421 .65715 m .60643 .67152 L .5996 .66433 L F
.59421 .65715 m .60062 .66371 L .60726 .67111 L F
0 g
.60062 .66371 m
.60351 .66521 L
s
.59063 .65283 m
.59421 .65715 L
s
.59126 .65454 m
.59421 .65715 L
s
.73026 .88851 m .7415 .88886 L .74521 .88653 L 0 1 .285 r
F
.73026 .88851 m .7358 .89006 L .7415 .88886 L F
0 g
.7415 .88886 m
.74557 .88941 L
s
.45283 .64177 m .44467 .64336 L .44638 .64345 L 0 .864 .238 r
F
0 g
.44272 .64561 m
.44638 .64345 L
s
.45283 .64177 m .44889 .64152 L .44467 .64336 L 0 .864 .238 r
F
.45283 .64177 m .45622 .63917 L .44889 .64152 L F
.45283 .64177 m .46268 .63749 L .45622 .63917 L F
.45283 .64177 m .46394 .63759 L .46268 .63749 L F
.45283 .64177 m .45971 .63943 L .46394 .63759 L F
0 g
.44894 .64348 m
.45283 .64177 L
s
.44638 .64345 m
.45283 .64177 L
s
.45971 .63943 m
.46583 .6376 L
s
.51316 .94817 m .51793 .93151 L .51521 .94101 L 0 .318 .122 r
F
.51316 .94818 m .51521 .94101 L .51793 .93151 L 0 .315 .124 r
F
0 g
.51793 .93151 m
.51793 .93149 L
s
.51793 .93151 m
.51794 .93148 L
s
.57764 .64449 m .57535 .64473 L .57378 .64269 L 0 .126 0 r
F
0 g
.57142 .6391 m
.57764 .64449 L
s
.42615 .78321 m .41911 .78227 L .4227 .78254 L 0 0 0 r
F
.42615 .78321 m .41725 .78255 L .41911 .78227 L F
0 g
.4227 .78254 m
.42306 .78161 L
s
.42306 .78161 m
.42315 .78138 L
s
.42615 .78321 m .41836 .78317 L .41725 .78255 L 0 0 0 r
F
.42615 .78321 m .42182 .78385 L .41836 .78317 L F
.42615 .78321 m .42531 .78412 L .42182 .78385 L F
.42615 .78321 m .42717 .78385 L .42531 .78412 L F
0 g
.42615 .78321 m
.42808 .78266 L
s
.4227 .78254 m
.42615 .78321 L
s
.50129 .93374 m .48946 .92219 L .49302 .92619 L 0 .475 .388 r
F
.50129 .93374 m .48942 .92133 L .48946 .92219 L F
0 g
.48762 .92111 m
.48946 .92219 L
s
.498 .92078 m
.50095 .92388 L
s
.50118 .92231 m
.50131 .92257 L
s
.36 .90729 m .35279 .90279 L .34937 .90321 L 0 .78 .36 r
F
.36 .90729 m .35713 .90396 L .35279 .90279 L F
.36 .90729 m .36022 .90589 L .35713 .90396 L F
0 g
.35658 .90771 m
.36 .90729 L
s
.37135 .90998 m .36022 .90589 L .36001 .90729 L 0 .628 .301 r
F
0 g
.36001 .90729 m
.36325 .90907 L
s
.46626 .93404 m .45747 .93364 L .45421 .93164 L 0 .186 .042 r
F
.47064 .88538 m .46506 .87415 L .46116 .87174 L 0 .872 .427 r
F
.5438 .80016 m .54699 .80093 L .55088 .78795 L 0 1 .292 r
F
0 g
.54581 .80065 m
.54629 .82989 L
s
.49533 1.00171 m .49382 1.00876 L .49545 1.00675 L 0 .259 .285 r
F
.49994 1.01358 m .49545 1.00675 L .49382 1.00876 L 0 .217 .264 r
F
0 g
.49382 1.00876 m
.49434 1.01414 L
s
.49092 1.00642 m
.49382 1.00876 L
s
.76181 1.06111 m .76885 1.05633 L .77256 1.05256 L 0 .867 .181 r
F
0 g
.76294 1.06132 m
.76885 1.05633 L
s
.76885 1.05633 m
.76922 1.05722 L
s
.51544 1.06897 m .51848 1.07465 L .51821 1.07395 L 0 0 .15 r
F
.524 1.08429 m .51821 1.07395 L .51848 1.07465 L 0 0 .105 r
F
0 g
.51986 1.07689 m
.52161 1.07973 L
s
.51575 1.07082 m
.51848 1.07465 L
s
.42717 .78385 m
.43054 .78427 L
s
.45297 .85732 m .44461 .85174 L .4487 .85587 L 0 1 .436 r
F
.45297 .85732 m .44294 .84664 L .44461 .85174 L F
0 g
.44037 .85073 m
.44461 .85174 L
s
.4487 .85587 m
.45077 .8607 L
s
.49017 .91637 m .48277 .90582 L .47911 .90262 L 0 .638 .41 r
F
0 g
.47604 .89828 m
.47911 .90262 L
s
.30441 .74479 m .2981 .73658 L .29385 .73939 L 0 .889 .471 r
F
.30441 .74479 m .30435 .73653 L .2981 .73658 L F
.30441 .74479 m .30843 .73927 L .30435 .73653 L F
.30441 .74479 m .30845 .74282 L .30843 .73927 L F
0 g
.29818 .74483 m
.30441 .74479 L
s
.45383 .9334 m .44568 .92997 L .45039 .93141 L 0 .137 .01 r
F
.45383 .9334 m .44202 .92962 L .44568 .92997 L F
0 g
.44249 .92819 m
.44568 .92997 L
s
.45039 .93141 m
.45421 .93164 L
s
.51316 .94818 m .5235 .93016 L .52374 .931 L 0 .298 .124 r
F
.51316 .94818 m .52029 .9351 L .5235 .93016 L F
0 g
.5235 .93016 m
.52363 .92977 L
s
.51862 .93205 m
.5212 .92554 L
s
.51861 .93206 m
.52064 .92497 L
s
.73026 .88851 m .73098 .88991 L .7358 .89006 L 0 1 .285 r
F
0 g
.73098 .88991 m
.7358 .89006 L
s
.73135 .89196 m
.7358 .89006 L
s
.49017 .91637 m .48188 .90823 L .4865 .91316 L 0 .638 .41 r
F
.48968 .91815 m .4865 .91316 L .48188 .90823 L 0 .643 .414 r
F
0 g
.48086 .90677 m
.48188 .90823 L
s
.47824 .90542 m
.48188 .90823 L
s
.47795 .93783 m .46997 .9342 L .47462 .9357 L 0 .243 .067 r
F
.47795 .93783 m .46626 .93404 L .46997 .9342 L F
0 g
.46685 .93213 m
.46997 .9342 L
s
.50167 .93606 m .49381 .93014 L .49835 .93373 L 0 .468 .388 r
F
.50205 .93735 m .49835 .93373 L .49381 .93014 L 0 .457 .386 r
F
0 g
.4934 .92989 m
.49381 .93014 L
s
.49023 .92675 m
.49381 .93014 L
s
.34907 .8183 m .33875 .81536 L .33988 .82084 L 0 1 .491 r
F
0 g
.33532 .8245 m
.33988 .82084 L
s
.51316 .94818 m .50804 .93718 L .51096 .94345 L 0 .287 .111 r
F
.51316 .94818 m .51096 .94345 L .50804 .93718 L 0 .284 .109 r
F
.51316 .94818 m .51316 .94818 L .51096 .94345 L F
.51316 .94817 m .50137 .92269 L .50144 .92438 L 0 .402 .273 r
F
0 g
.50558 .93295 m
.50611 .93386 L
s
.51316 .94817 m .50486 .92942 L .50137 .92269 L 0 .402 .273 r
F
0 g
.5013 .92424 m
.50144 .92438 L
s
.50679 .93377 m
.50679 .93377 L
s
.50177 .91962 m
.50329 .92306 L
s
.50388 .93485 m
.50393 .93489 L
s
.50131 .92257 m
.50137 .92269 L
s
.5035 .9202 m
.5049 .92383 L
s
.50138 .93309 m
.50388 .93485 L
s
.50175 .92341 m
.5019 .92371 L
s
.50161 .92316 m
.50175 .92341 L
s
.50156 .92305 m
.50161 .92316 L
s
.50145 .92284 m
.50156 .92305 L
s
.50142 .92278 m
.50145 .92284 L
s
.50137 .92269 m
.50142 .92278 L
s
.44294 .84664 m .43437 .84206 L .43847 .84582 L 0 1 .442 r
F
0 g
.43847 .84582 m
.44037 .85073 L
s
.28328 .73408 m .27268 .72898 L .27243 .73353 L 0 1 .516 r
F
0 g
.26653 .73531 m
.27243 .73353 L
s
.51349 .95576 m .51381 .96057 L .51434 .95982 L 0 .186 .225 r
F
0 g
.51381 .96057 m
.51475 .9623 L
s
.53876 .76713 m .53791 .75064 L .53678 .76099 L 0 1 .323 r
F
.52914 .77199 m .53791 .75064 L .53549 .74514 L 0 1 .343 r
F
.52914 .77199 m .53678 .76099 L .53791 .75064 L F
0 g
.53791 .75064 m
.54007 .74492 L
s
.55454 .67701 m .56779 .66393 L .56405 .66409 L 0 1 .384 r
F
0 g
.56779 .66393 m
.5736 .65842 L
s
.27611 .8212 m .26469 .81964 L .26629 .8252 L 0 1 .526 r
F
0 g
.2618 .82997 m
.26629 .8252 L
s
.51316 .94818 m .50468 .93453 L .50739 .93827 L 0 .291 .113 r
F
.51316 .94818 m .50434 .93518 L .50468 .93453 L F
0 g
.50449 .93424 m
.50468 .93453 L
s
.60525 .66887 m
.60726 .67111 L
s
.60062 .66371 m
.60525 .66887 L
s
.28414 .61826 m .27183 .62218 L .27571 .62385 L 0 1 .499 r
F
0 g
.27389 .63142 m
.27571 .62385 L
s
.39623 .8232 m .38596 .81736 L .38711 .82276 L 0 1 .467 r
F
0 g
.38243 .82481 m
.38711 .82276 L
s
.463 .86907 m .45484 .86238 L .45893 .86694 L 0 .954 .428 r
F
.463 .86907 m .45297 .85732 L .45484 .86238 L F
0 g
.45077 .8607 m
.45484 .86238 L
s
.45893 .86694 m
.46116 .87174 L
s
.74383 .81897 m .75596 .79885 L .75757 .80797 L 0 .239 .087 r
F
0 g
.74616 .80613 m
.75135 .79755 L
s
.74442 .79511 m
.74616 .80613 L
s
.75596 .79885 m
.76052 .79344 L
s
.50385 .94706 m .49457 .94568 L .49773 .94816 L 0 .373 .28 r
F
0 g
.49457 .94568 m
.49468 .94577 L
s
.49231 .94786 m
.49457 .94568 L
s
.51772 .96495 m
.51841 .96608 L
s
.51942 .96674 m .51845 .96567 L .51842 .96608 L 0 .045 .166 r
F
0 g
.51842 .96608 m
.51842 .96608 L
s
.44294 .84664 m .4329 .83689 L .43437 .84206 L 0 1 .442 r
F
0 g
.42997 .84165 m
.43437 .84206 L
s
.43847 .84582 m
.43959 .84603 L
s
.50129 .93374 m .49295 .92438 L .48942 .92133 L 0 .475 .388 r
F
0 g
.48796 .91983 m
.48942 .92133 L
s
.498 .92078 m
.50063 .92535 L
s
.49 .9258 m
.49321 .92805 L
s
.50095 .92388 m
.50128 .92422 L
s
.50128 .92422 m
.5013 .92424 L
s
.49837 .92612 m
.49976 .92821 L
s
.49837 .92612 m
.49993 .92735 L
s
.50063 .92535 m
.50122 .92637 L
s
.48959 .92351 m
.49183 .92526 L
s
.80198 1.0234 m .81013 1.02318 L .81305 1.01632 L 0 1 .379 r
F
0 g
.80469 1.03019 m
.81013 1.02318 L
s
.81013 1.02318 m
.8112 1.02662 L
s
.56039 .6363 m .56737 .63909 L .57378 .64269 L 0 .042 0 r
F
0 g
.56737 .63909 m
.57142 .6391 L
s
.48945 .92009 m .48951 .91929 L .48603 .91533 L 0 .645 .417 r
F
0 g
.48603 .91533 m
.48856 .91821 L
s
.71945 .89164 m .72827 .89171 L .73098 .88992 L 0 .884 .252 r
F
.71945 .89164 m .72392 .8927 L .72827 .89171 L F
0 g
.72827 .89171 m
.73135 .89196 L
s
.53113 .74814 m .53796 .72457 L .53312 .72822 L 0 1 .361 r
F
0 g
.53796 .72457 m
.53811 .72477 L
s
.53796 .72457 m
.54244 .71675 L
s
.52505 .94204 m .53679 .92496 L .53689 .92799 L 0 .269 .135 r
F
.52505 .94204 m .53321 .92781 L .53679 .92496 L F
0 g
.53679 .92496 m
.53856 .91916 L
s
.52493 .93 m
.52712 .92407 L
s
.5336 .92749 m
.53572 .92581 L
s
.53572 .92581 m
.53679 .92496 L
s
.51316 .94817 m .50783 .9103 L .51087 .9319 L 0 .339 .265 r
F
.51316 .94817 m .51087 .9319 L .50783 .9103 L 0 .343 .267 r
F
0 g
.50783 .91027 m
.50783 .9103 L
s
.50782 .91024 m
.50783 .9103 L
s
.51316 .94817 m .5072 .91129 L .5106 .93233 L 0 .343 .267 r
F
0 g
.5072 .91129 m
.5072 .91129 L
s
.51316 .94817 m .5106 .93233 L .5072 .91129 L 0 .349 .269 r
F
0 g
.50717 .91111 m
.5072 .91129 L
s
.47064 .88538 m .46915 .8792 L .46506 .87415 L 0 .872 .427 r
F
.47064 .88538 m .47154 .88402 L .46915 .8792 L F
.48125 .89862 m .47064 .88538 L .4732 .89026 L 0 .761 .416 r
F
.48125 .89862 m .47154 .88402 L .47064 .88538 L F
0 g
.46674 .88297 m
.47064 .88538 L
s
.47064 .88538 m
.47221 .88837 L
s
.51316 .94817 m .50701 .91167 L .51052 .93249 L 0 .349 .269 r
F
0 g
.50701 .91161 m
.50701 .91167 L
s
.51316 .94817 m .51052 .93249 L .50701 .91167 L 0 .353 .269 r
F
0 g
.50701 .91166 m
.50701 .91167 L
s
.53513 .71163 m .54527 .70085 L .54637 .69549 L 0 1 .402 r
F
.53513 .71163 m .54045 .70777 L .54527 .70085 L F
0 g
.54527 .70085 m
.54832 .70131 L
s
.60444 .63281 m .62094 .62644 L .61714 .62622 L 0 1 .3 r
F
0 g
.62094 .62644 m
.62794 .62447 L
s
.5026 1.03243 m .5002 1.02715 L .49754 1.02446 L 0 .16 .236 r
F
.51316 .94817 m .50144 .92438 L .50498 .93239 L 0 .402 .273 r
F
0 g
.50144 .92438 m
.50146 .92443 L
s
.50146 .92443 m
.50147 .92446 L
s
.50147 .92446 m
.50156 .92465 L
s
.50156 .92465 m
.50221 .92613 L
s
.50221 .92613 m
.50255 .9269 L
s
.50411 .92491 m
.50484 .92655 L
s
.50329 .92306 m
.50411 .92491 L
s
.50151 .92687 m
.50151 .92687 L
s
.50151 .92687 m
.50151 .92687 L
s
.50136 .9266 m
.50151 .92687 L
s
.50144 .92438 m
.50144 .92438 L
s
.48125 .89862 m .4732 .89026 L .47751 .89542 L 0 .761 .416 r
F
.47981 .90104 m .47751 .89542 L .4732 .89026 L 0 .77 .422 r
F
0 g
.46944 .8875 m
.4732 .89026 L
s
.47221 .88837 m
.4732 .89026 L
s
.71945 .89164 m .72015 .89267 L .72392 .8927 L 0 .884 .252 r
F
0 g
.72051 .89407 m
.72392 .8927 L
s
.51316 .94817 m .50853 .90966 L .51117 .93162 L 0 .338 .264 r
F
.51316 .94817 m .51117 .93162 L .50853 .90966 L 0 .339 .265 r
F
0 g
.50851 .90955 m
.50853 .90966 L
s
.50852 .9096 m
.50853 .90966 L
s
.32688 .59517 m .31471 .60023 L .31818 .60203 L 0 1 .457 r
F
.32688 .59517 m .31845 .59127 L .31471 .60023 L F
.32688 .59517 m .32691 .5811 L .31845 .59127 L F
.32688 .59517 m .33563 .57423 L .32691 .5811 L F
.32688 .59517 m .33877 .57525 L .33563 .57423 L F
.32688 .59517 m .33502 .58423 L .33877 .57525 L F
0 g
.32337 .6049 m
.32688 .59517 L
s
.31818 .60203 m
.32688 .59517 L
s
.33502 .58423 m
.34348 .57661 L
s
.51105 .95263 m .51019 .95517 L .51089 .95399 L 0 .238 .27 r
F
.51226 .95421 m .51089 .95399 L .51019 .95517 L 0 .212 .247 r
F
0 g
.51019 .95517 m
.5104 .95684 L
s
.50895 .95525 m
.51019 .95517 L
s
.66886 .60174 m .66832 .59234 L .6652 .58863 L 0 .208 .266 r
F
0 g
.6652 .58863 m
.66886 .60174 L
s
.66504 .58836 m
.6652 .58863 L
s
.66247 .58674 m
.66886 .60174 L
s
.63631 .74592 m
.63768 .75075 L
s
.63598 .74474 m
.63631 .74592 L
s
.63502 .73823 m
.63561 .74225 L
s
.63561 .74225 m
.63598 .74474 L
s
.51316 .94818 m .51861 .93207 L .5155 .94126 L 0 .315 .124 r
F
.51316 .94818 m .5155 .94126 L .51861 .93207 L 0 .31 .125 r
F
0 g
.51861 .93207 m
.51862 .93205 L
s
.51861 .93207 m
.51861 .93206 L
s
.51316 .94817 m .50647 .91307 L .51029 .93309 L 0 .353 .269 r
F
.51316 .94817 m .51029 .93309 L .50647 .91307 L 0 .363 .271 r
F
0 g
.50647 .91305 m
.50647 .91307 L
s
.50647 .91306 m
.50647 .91307 L
s
.4329 .83689 m .42412 .83319 L .42822 .83664 L 0 1 .447 r
F
0 g
.42822 .83664 m
.42997 .84165 L
s
.39623 .8232 m .3886 .81237 L .38596 .81736 L 0 1 .467 r
F
.39623 .8232 m .39355 .8106 L .3886 .81237 L F
.39623 .8232 m .39751 .81324 L .39355 .8106 L F
.39623 .8232 m .39866 .81864 L .39751 .81324 L F
0 g
.39128 .82496 m
.39623 .8232 L
s
.64122 .54552 m
.64976 .55616 L
s
.46626 .93404 m .46219 .93516 L .45747 .93364 L 0 .186 .042 r
F
.46626 .93404 m .46596 .93533 L .46219 .93516 L F
.47795 .93783 m .46596 .93533 L .46626 .93404 L 0 .243 .067 r
F
0 g
.463 .93204 m
.46626 .93404 L
s
.46626 .93404 m
.46997 .9342 L
s
.74246 .6523 m .7568 .63919 L .76077 .63774 L 0 0 0 r
F
.74246 .6523 m .74897 .64541 L .7568 .63919 L F
0 g
.7568 .63919 m
.75782 .63505 L
s
.7564 .6395 m
.7568 .63919 L
s
.3025 .60797 m
.30335 .60536 L
s
.30069 .61362 m
.3025 .60797 L
s
.30795 .60871 m
.3087 .6082 L
s
.30069 .61362 m
.30795 .60871 L
s
.67946 .64912 m .68026 .63577 L .67676 .63156 L 0 .279 .283 r
F
0 g
.67676 .63156 m
.67785 .63866 L
s
.67785 .63866 m
.67946 .64909 L
s
.67321 .62322 m
.67676 .63156 L
s
.67946 .64912 m
.67946 .64912 L
s
.67647 .63995 m
.67946 .64912 L
s
.49889 .93157 m
.49894 .9316 L
s
.53694 .93622 m .53695 .93281 L .54049 .9227 L 0 .245 .146 r
F
0 g
.53816 .92934 m
.54049 .9227 L
s
.5374 .92723 m
.53891 .92502 L
s
.53891 .92502 m
.54049 .9227 L
s
.70817 1.09203 m .72041 1.08682 L .71548 1.09068 L 0 0 0 r
F
.71869 1.09605 m .72041 1.08682 L .72724 1.08394 L F
.71869 1.09605 m .71548 1.09068 L .72041 1.08682 L F
0 g
.7203 1.08333 m
.72041 1.08682 L
s
.3524 .68169 m
.35369 .67569 L
s
.51316 .94817 m .51393 .90166 L .51344 .91481 L 0 .384 .266 r
F
.51316 .94817 m .51442 .9031 L .51393 .90166 L F
0 g
.51368 .883 m
.51393 .90166 L
s
.49096 .93597 m .49062 .93709 L .48696 .93664 L 0 .251 .085 r
F
.50204 .94152 m .49096 .93597 L .49449 .93688 L 0 .287 .101 r
F
.50204 .94152 m .49062 .93709 L .49096 .93597 L F
0 g
.49084 .93588 m
.49096 .93597 L
s
.49096 .93597 m
.49149 .93611 L
s
.49149 .93611 m
.49258 .93639 L
s
.49258 .93639 m
.49389 .93672 L
s
.51316 .94818 m .5068 .93941 L .50434 .93518 L 0 .291 .113 r
F
0 g
.50393 .93489 m
.50434 .93518 L
s
.45297 .85732 m .44481 .84397 L .44294 .84664 L 0 1 .436 r
F
.45297 .85732 m .44908 .84542 L .44481 .84397 L F
.45297 .85732 m .45291 .85002 L .44908 .84542 L F
.45297 .85732 m .45458 .85512 L .45291 .85002 L F
.463 .86907 m .45458 .85512 L .45297 .85732 L 0 .954 .428 r
F
0 g
.4487 .85587 m
.45297 .85732 L
s
.45297 .85732 m
.45484 .86238 L
s
.56039 .6363 m .55709 .63673 L .55598 .63529 L 0 .042 0 r
F
.56039 .6363 m .56351 .64034 L .55709 .63673 L F
.56039 .6363 m .57095 .64373 L .56351 .64034 L F
.56039 .6363 m .57535 .64473 L .57095 .64373 L F
.56039 .6363 m .57378 .64269 L .57535 .64473 L F
0 g
.57444 .643 m
.57764 .64449 L
s
.57378 .64269 m
.57444 .643 L
s
.55432 .63272 m
.56039 .6363 L
s
.56737 .63909 m
.57378 .64269 L
s
.50142 .93485 m .49331 .92812 L .49797 .93216 L 0 .474 .389 r
F
.50167 .93606 m .49797 .93216 L .49331 .92812 L 0 .468 .388 r
F
0 g
.49321 .92805 m
.49331 .92812 L
s
.48972 .92441 m
.49331 .92812 L
s
.49239 .93505 m
.4938 .93627 L
s
.50152 .9286 m
.50152 .9286 L
s
.50152 .9286 m
.50152 .9286 L
s
.50153 .93085 m
.50153 .93085 L
s
.50153 .93085 m
.50153 .93085 L
s
.78331 1.04502 m .79383 1.03673 L .78948 1.03957 L 0 1 .233 r
F
.77256 1.05256 m .78331 1.04502 L .78296 1.04411 L 0 .938 .212 r
F
.37135 .90998 m .36379 .90583 L .36022 .90589 L 0 .628 .301 r
F
.37135 .90998 m .36832 .90715 L .36379 .90583 L F
.37135 .90998 m .37156 .90893 L .36832 .90715 L F
.38269 .91291 m .37156 .90893 L .37135 .90998 L 0 .558 .248 r
F
0 g
.36778 .91004 m
.37135 .90998 L
s
.37135 .90998 m
.37459 .91157 L
s
.44294 .84664 m .43503 .83375 L .4329 .83689 L 0 1 .442 r
F
.44294 .84664 m .4395 .83457 L .43503 .83375 L F
.44294 .84664 m .44334 .8388 L .4395 .83457 L F
.44294 .84664 m .44481 .84397 L .44334 .8388 L F
0 g
.43959 .84603 m
.44294 .84664 L
s
.44294 .84664 m
.44461 .85174 L
s
.51316 .94817 m .50927 .9094 L .51149 .93152 L 0 .341 .264 r
F
.51316 .94817 m .51149 .93152 L .50927 .9094 L 0 .338 .264 r
F
0 g
.50847 .89379 m
.51005 .90954 L
s
.50915 .90845 m
.50927 .9094 L
s
.50923 .90895 m
.50927 .9094 L
s
.53561 .79933 m .53876 .76713 L .53509 .77789 L 0 1 .311 r
F
0 g
.53728 .77146 m
.53876 .76713 L
s
.51316 .94818 m .52374 .931 L .5207 .93658 L 0 .298 .124 r
F
0 g
.51924 .93284 m
.52206 .92675 L
s
.51924 .93285 m
.52156 .92598 L
s
.52374 .931 m
.52424 .92998 L
s
.75028 .60578 m .76721 .60737 L .75981 .60332 L 0 1 .477 r
F
0 g
.76721 .60737 m
.76974 .61091 L
s
.76721 .60737 m
.77575 .60982 L
s
.52914 .77199 m .53549 .74514 L .53113 .74814 L 0 1 .343 r
F
0 g
.53549 .74514 m
.53733 .7413 L
s
.53549 .74514 m
.53791 .75064 L
s
.51316 .94817 m .506 .91476 L .51008 .93382 L 0 .363 .271 r
F
.51316 .94817 m .51008 .93382 L .506 .91476 L 0 .375 .273 r
F
0 g
.506 .91476 m
.506 .91476 L
s
.50599 .91475 m
.506 .91476 L
s
.49991 .96931 m .49213 .97061 L .49332 .97465 L 0 .303 .282 r
F
.49991 .96931 m .49342 .96645 L .49213 .97061 L F
0 g
.48906 .96836 m
.49213 .97061 L
s
.50314 .94238 m .49648 .94127 L .50039 .9427 L 0 .4 .282 r
F
.50385 .94706 m .50039 .9427 L .49648 .94127 L 0 .373 .28 r
F
0 g
.49435 .94236 m
.49648 .94127 L
s
.49352 .93822 m
.49648 .94127 L
s
.70864 .89504 m .71741 .89427 L .72015 .89267 L 0 .834 .238 r
F
.70864 .89504 m .71307 .89537 L .71741 .89427 L F
0 g
.71741 .89427 m
.72051 .89407 L
s
.50128 .93274 m .48945 .92009 L .49295 .92438 L 0 .472 .386 r
F
.50128 .93274 m .48951 .91929 L .48945 .92009 L F
0 g
.50122 .92637 m
.50136 .9266 L
s
.48725 .9186 m
.48945 .92009 L
s
.49993 .92735 m
.50101 .9282 L
s
.4329 .83689 m .42284 .82791 L .42412 .83319 L 0 1 .447 r
F
0 g
.41955 .83335 m
.42412 .83319 L
s
.51471 .95727 m .51528 .96216 L .51625 .96323 L 0 .161 .205 r
F
.51471 .95727 m .51434 .95982 L .51528 .96216 L F
0 g
.51475 .9623 m
.51528 .96216 L
s
.47981 .90104 m .48034 .90004 L .47751 .89542 L 0 .77 .422 r
F
.4909 .9148 m .47981 .90104 L .48277 .90582 L 0 .63 .406 r
F
.4909 .9148 m .48034 .90004 L .47981 .90104 L F
0 g
.47604 .89828 m
.47981 .90104 L
s
.47981 .90104 m
.48152 .90381 L
s
.365 .76804 m .3556 .76488 L .35553 .76478 L 0 0 0 r
F
0 g
.35022 .76358 m
.35553 .76478 L
s
.47302 .88207 m .46506 .87415 L .46915 .8792 L 0 .863 .42 r
F
.47302 .88207 m .463 .86907 L .46506 .87415 L F
0 g
.46116 .87174 m
.46506 .87415 L
s
.34907 .8183 m .34143 .80914 L .33875 .81536 L 0 1 .491 r
F
.34907 .8183 m .34646 .80549 L .34143 .80914 L F
.34907 .8183 m .35049 .80685 L .34646 .80549 L F
.34907 .8183 m .3516 .81234 L .35049 .80685 L F
0 g
.34907 .8183 m
.3503 .8237 L
s
.34405 .82194 m
.34907 .8183 L
s
.26469 .81964 m .25479 .82374 L .25939 .82432 L 0 1 .529 r
F
0 g
.25939 .82432 m
.2618 .82997 L
s
.38596 .81736 m .37668 .81759 L .38086 .8196 L 0 1 .47 r
F
0 g
.38086 .8196 m
.38243 .82481 L
s
.28753 .82278 m .2785 .81447 L .27611 .8212 L 0 1 .522 r
F
.28753 .82278 m .28367 .80996 L .2785 .81447 L F
.28753 .82278 m .28817 .81067 L .28367 .80996 L F
.28753 .82278 m .28982 .81618 L .28817 .81067 L F
0 g
.28237 .82727 m
.28753 .82278 L
s
.40154 .77783 m .39233 .77538 L .39607 .77605 L 0 0 0 r
F
0 g
.39607 .77605 m
.39659 .77558 L
s
.6896 1.10761 m .68526 1.1032 L .68469 1.09812 L 0 .093 .048 r
F
0 g
.67825 1.09661 m
.68469 1.09812 L
s
.33875 .81536 m .32943 .81832 L .33361 .81929 L 0 1 .496 r
F
0 g
.33361 .81929 m
.33532 .8245 L
s
.71307 .60417 m .73284 .60649 L .7297 .60367 L 0 1 .454 r
F
0 g
.73284 .60649 m
.74079 .60814 L
s
.51512 1.06556 m .51201 1.06305 L .51544 1.06897 L 0 0 .151 r
F
.51512 1.06556 m .5096 1.05762 L .51201 1.06305 L F
0 g
.50929 1.05924 m
.51201 1.06305 L
s
.52404 .97211 m .52571 .97433 L .5281 .97722 L 0 0 .133 r
F
0 g
.52702 .97591 m
.5281 .97722 L
s
.5258 .97451 m
.52605 .975 L
s
.70864 .89504 m .70932 .8957 L .71307 .89537 L 0 .834 .238 r
F
0 g
.70932 .8957 m
.71307 .89537 L
s
.70967 .8964 m
.71307 .89537 L
s
.51316 .94817 m .5056 .91671 L .50991 .93466 L 0 .375 .273 r
F
.51316 .94817 m .50991 .93466 L .5056 .91671 L 0 .386 .274 r
F
0 g
.5056 .9167 m
.5056 .91671 L
s
.5056 .9167 m
.5056 .91671 L
s
.42531 .78412 m
.42717 .78385 L
s
.51316 .94818 m .50739 .93827 L .51068 .94392 L 0 .291 .113 r
F
.51316 .94818 m .51068 .94392 L .50739 .93827 L 0 .287 .111 r
F
.51316 .94818 m .51316 .94818 L .51068 .94392 L F
.51316 .94817 m .50157 .92697 L .50168 .92873 L 0 .394 .272 r
F
0 g
.50521 .93357 m
.50537 .93393 L
s
.51316 .94817 m .50498 .93239 L .50157 .92697 L 0 .394 .272 r
F
0 g
.5019 .92371 m
.50401 .92777 L
s
.50364 .9359 m
.50372 .936 L
s
.50151 .92687 m
.50157 .92697 L
s
.50138 .93309 m
.50364 .9359 L
s
.50152 .9286 m
.50158 .92865 L
s
.50158 .92865 m
.50168 .92873 L
s
.5019 .9275 m
.50209 .9278 L
s
.50162 .92705 m
.5019 .9275 L
s
.50157 .92697 m
.50162 .92705 L
s
.51316 .94817 m .51005 .90957 L .51183 .93159 L 0 .346 .263 r
F
.51316 .94817 m .51183 .93159 L .51005 .90957 L 0 .341 .264 r
F
0 g
.50958 .90164 m
.51005 .90957 L
s
.51005 .90954 m
.51005 .90957 L
s
.50958 .89418 m
.51087 .91016 L
s
.49645 .98478 m .49518 .98073 L .49234 .97892 L 0 .285 .286 r
F
.48125 .89862 m .47528 .88721 L .47154 .88402 L 0 .761 .416 r
F
.27268 .72898 m .26167 .72905 L .26598 .73082 L 0 1 .525 r
F
0 g
.26598 .73082 m
.26653 .73531 L
s
.60995 .67562 m .61051 .67637 L .60972 .67442 L 0 0 .138 r
F
.61051 .67637 m .61133 .6768 L .60972 .67442 L F
.5996 .66433 m .61223 .67728 L .61225 .67704 L 0 .029 .153 r
F
.61223 .67728 m .61585 .681 L .6127 .67754 L F
.61223 .67728 m .6127 .67754 L .61225 .67704 L F
.61051 .67637 m .61639 .68425 L .61133 .6768 L 0 0 .138 r
F
.60995 .67562 m .62283 .69405 L .61639 .68425 L F
.60995 .67562 m .62266 .69475 L .62552 .69855 L F
0 g
.61984 .69106 m
.6201 .69162 L
s
.60995 .67562 m .61599 .68493 L .62266 .69475 L 0 0 .138 r
F
0 g
.60885 .67382 m
.60995 .67562 L
s
.60893 .6739 m
.60995 .67562 L
s
.463 .86907 m .45865 .85724 L .45458 .85512 L 0 .954 .428 r
F
.463 .86907 m .46247 .86228 L .45865 .85724 L F
.463 .86907 m .46433 .86735 L .46247 .86228 L F
.47302 .88207 m .46433 .86735 L .463 .86907 L 0 .863 .42 r
F
0 g
.463 .86907 m
.46506 .87415 L
s
.45893 .86694 m
.463 .86907 L
s
.46915 .8792 m
.47154 .88402 L
s
.45779 .79331 m
.46216 .79423 L
s
.63419 .6203 m .65332 .61602 L .65022 .6146 L 0 1 .356 r
F
0 g
.65332 .61602 m
.6614 .61492 L
s
.4329 .83689 m .42523 .82432 L .42284 .82791 L 0 1 .447 r
F
.4329 .83689 m .42991 .82456 L .42523 .82432 L F
.4329 .83689 m .43375 .82847 L .42991 .82456 L F
.4329 .83689 m .43503 .83375 L .43375 .82847 L F
0 g
.42822 .83664 m
.4329 .83689 L
s
.4329 .83689 m
.43437 .84206 L
s
.49019 .9388 m .4816 .93803 L .47839 .93587 L 0 .267 .086 r
F
0 g
.47462 .9357 m
.47839 .93587 L
s
.49994 1.01358 m .49667 1.01931 L .49929 1.02139 L 0 .217 .264 r
F
0 g
.49667 1.01931 m
.49754 1.02446 L
s
.53049 .97959 m
.53056 .97964 L
s
.53005 .97922 m
.53015 .97931 L
s
.53025 .97939 m
.53049 .97959 L
s
.52991 .97911 m
.53005 .97922 L
s
.52976 .97898 m
.52991 .97911 L
s
.52976 .97898 m
.52976 .97898 L
s
.52973 .97895 m
.52976 .97898 L
s
.52964 .97889 m
.52973 .97895 L
s
.531 .98001 m
.53131 .98026 L
s
.53136 .9803 m
.53216 .98097 L
s
.53098 .97999 m
.531 .98001 L
s
.5308 .97984 m
.53093 .97995 L
s
.53073 .97979 m
.5308 .97984 L
s
.53062 .97969 m
.53073 .97979 L
s
.53169 .981 m
.5317 .981 L
s
.53173 .981 m
.53216 .98097 L
s
.53168 .98101 m
.53169 .981 L
s
.53162 .98101 m
.53168 .98101 L
s
.53161 .98101 m
.53162 .98101 L
s
.53155 .98101 m
.53161 .98101 L
s
.53143 .98102 m
.53151 .98102 L
s
.53154 .98102 m
.53155 .98101 L
s
.5314 .98103 m
.53143 .98102 L
s
.5314 .98103 m
.5314 .98103 L
s
.50128 .93274 m .49309 .92271 L .48951 .91929 L 0 .472 .386 r
F
0 g
.48856 .91821 m
.48951 .91929 L
s
.49889 .93157 m
.49985 .93278 L
s
.49974 .93201 m
.49998 .93213 L
s
.49976 .92821 m
.50088 .92989 L
s
.50101 .9282 m
.50135 .92847 L
s
.54132 1.10625 m .54696 1.10941 L .54561 1.11034 L 0 .325 0 r
F
.55203 1.12317 m .54696 1.10941 L .55149 1.11354 L 0 .392 .029 r
F
.55203 1.12317 m .54561 1.11034 L .54696 1.10941 L F
0 g
.54435 1.10426 m
.54696 1.10941 L
s
.54261 .6316 m .54977 .6331 L .55598 .63529 L 0 0 0 r
F
0 g
.54977 .6331 m
.55432 .63272 L
s
.50777 1.05104 m .5096 1.05762 L .50981 1.05629 L 0 .073 .179 r
F
.51512 1.06556 m .50981 1.05629 L .5096 1.05762 L 0 0 .151 r
F
0 g
.5096 1.05762 m
.51201 1.06305 L
s
.50689 1.05434 m
.5096 1.05762 L
s
.49796 .96142 m .49723 .95827 L .49422 .95639 L 0 .333 .287 r
F
.52914 .77199 m .53302 .77014 L .53678 .76099 L 0 1 .343 r
F
0 g
.53442 .76675 m
.53678 .76099 L
s
.53678 .76099 m
.53876 .76713 L
s
.51316 .94817 m .51316 .94817 L .51337 .94108 L 0 .306 .112 r
F
.51316 .94817 m .51431 .91734 L .51442 .9031 L 0 .384 .266 r
F
0 g
.51442 .9031 m
.51528 .8871 L
s
.4143 .65632 m .40489 .65925 L .40744 .65898 L 0 1 .317 r
F
.4143 .65632 m .40823 .65672 L .40489 .65925 L F
0 g
.40476 .6612 m
.40744 .65898 L
s
.4143 .65632 m .41524 .65307 L .40823 .65672 L 0 1 .317 r
F
.4143 .65632 m .42211 .6504 L .41524 .65307 L F
.4143 .65632 m .42426 .6505 L .42211 .6504 L F
.4143 .65632 m .4209 .65303 L .42426 .6505 L F
0 g
.41126 .65857 m
.4143 .65632 L
s
.40744 .65898 m
.4143 .65632 L
s
.51637 .90996 m .51684 .91194 L .5184 .89853 L 0 .489 .265 r
F
0 g
.51749 .90637 m
.5184 .89853 L
s
.51808 .90481 m
.5184 .89853 L
s
.51582 .90503 m
.51686 .89227 L
s
.44202 .92962 m .43343 .92848 L .43002 .92674 L 0 .037 0 r
F
.44202 .92962 m .43817 .9301 L .43343 .92848 L F
.44202 .92962 m .44186 .93059 L .43817 .9301 L F
.45383 .9334 m .44186 .93059 L .44202 .92962 L 0 .137 .01 r
F
0 g
.44202 .92962 m
.44568 .92997 L
s
.43861 .92788 m
.44202 .92962 L
s
.51316 .94818 m .51924 .93285 L .51577 .94159 L 0 .31 .125 r
F
.51316 .94818 m .51577 .94159 L .51924 .93285 L 0 .306 .125 r
F
0 g
.51924 .93285 m
.51924 .93284 L
s
.51924 .93285 m
.51924 .93285 L
s
.67526 .74168 m
.6776 .7535 L
s
.6776 .7535 m
.67951 .76307 L
s
.67297 .74086 m
.67297 .74086 L
s
.67307 .74279 m
.67308 .74305 L
s
.67362 .75336 m
.67368 .75453 L
s
.67345 .7501 m
.67362 .75336 L
s
.42284 .82791 m .41385 .82501 L .41796 .8282 L 0 1 .452 r
F
0 g
.41796 .8282 m
.41955 .83335 L
s
.4909 .9148 m .48277 .90582 L .48726 .9112 L 0 .63 .406 r
F
.49017 .91637 m .48726 .9112 L .48277 .90582 L 0 .638 .41 r
F
0 g
.47911 .90262 m
.48277 .90582 L
s
.48152 .90381 m
.48277 .90582 L
s
.48603 .91533 m
.48803 .91687 L
s
.50129 .93374 m .49302 .92619 L .49775 .93068 L 0 .475 .388 r
F
.50142 .93485 m .49775 .93068 L .49302 .92619 L 0 .474 .389 r
F
0 g
.49998 .93213 m
.5013 .93281 L
s
.49183 .92526 m
.49302 .92619 L
s
.48946 .92219 m
.49302 .92619 L
s
.50135 .92847 m
.50152 .9286 L
s
.51226 .95421 m .51226 .9575 L .51247 .95589 L 0 .212 .247 r
F
.51349 .95576 m .51247 .95589 L .51226 .9575 L 0 .186 .225 r
F
0 g
.51226 .9575 m
.51283 .9595 L
s
.51137 .95791 m
.51226 .9575 L
s
.28414 .61826 m .27466 .61411 L .27183 .62218 L 0 1 .499 r
F
0 g
.26403 .62741 m
.27183 .62218 L
s
.28414 .61826 m .28233 .60501 L .27466 .61411 L 0 1 .499 r
F
.28414 .61826 m .29079 .59939 L .28233 .60501 L F
.28414 .61826 m .29439 .60103 L .29079 .59939 L F
.28414 .61826 m .29153 .60912 L .29439 .60103 L F
0 g
.28151 .6265 m
.28414 .61826 L
s
.27571 .62385 m
.28414 .61826 L
s
.51471 .95727 m .51625 .96323 L .51641 .96214 L 0 .161 .205 r
F
0 g
.51625 .96323 m
.51755 .96518 L
s
.44218 .78826 m
.44691 .78958 L
s
.51316 .94817 m .50528 .91888 L .50978 .93559 L 0 .386 .274 r
F
.51316 .94817 m .50978 .93559 L .50528 .91888 L 0 .395 .275 r
F
0 g
.50528 .91888 m
.50528 .91888 L
s
.50528 .91888 m
.50528 .91888 L
s
.53513 .71163 m .54637 .69549 L .54286 .69433 L 0 1 .402 r
F
0 g
.54045 .70777 m
.54527 .70085 L
s
.54135 .7084 m
.54359 .70997 L
s
.54637 .69549 m
.55142 .6881 L
s
.70657 .89715 m
.70932 .8957 L
s
.55203 1.12317 m .55149 1.11354 L .5562 1.11998 L 0 .392 .029 r
F
0 g
.54696 1.10941 m
.55149 1.11354 L
s
.54898 1.10778 m
.55149 1.11354 L
s
.52491 .93888 m .53321 .92781 L .52851 .93464 L 0 .263 .134 r
F
0 g
.52582 .93051 m
.5269 .92857 L
s
.52505 .94204 m .52851 .93464 L .53321 .92781 L 0 .269 .135 r
F
0 g
.53321 .92781 m
.53658 .92074 L
s
.52596 .93135 m
.52774 .92706 L
s
.52516 .93169 m
.52582 .93051 L
s
.53321 .92781 m
.5336 .92749 L
s
.26469 .81964 m .25325 .81807 L .25479 .82374 L 0 1 .529 r
F
0 g
.25027 .82865 m
.25479 .82374 L
s
.48968 .91815 m .48985 .91741 L .4865 .91316 L 0 .643 .414 r
F
.53057 1.09384 m .53304 1.09517 L .53215 1.09526 L 0 .316 0 r
F
0 g
.53268 1.09369 m
.53304 1.09517 L
s
.53827 1.10705 m .53304 1.09517 L .53696 1.09987 L 0 .356 0 r
F
.53827 1.10705 m .53215 1.09526 L .53304 1.09517 L F
.4909 .9148 m .48398 .90364 L .48034 .90004 L 0 .63 .406 r
F
0 g
.4865 .91316 m
.48744 .91398 L
s
.4865 .91316 m
.48693 .9137 L
s
.48693 .9137 m
.48918 .91656 L
s
.47751 .89542 m
.48034 .90004 L
s
.50465 .95176 m .49551 .9504 L .49618 .95354 L 0 .345 .277 r
F
.50465 .95176 m .49773 .94816 L .49551 .9504 L F
0 g
.49231 .94786 m
.49551 .9504 L
s
.6896 1.10761 m .69434 1.09631 L .6989 1.09947 L 0 .093 .048 r
F
0 g
.68826 1.09573 m
.69434 1.09631 L
s
.69361 1.09229 m
.69434 1.09631 L
s
.38596 .81736 m .37568 .81201 L .37668 .81759 L 0 1 .47 r
F
0 g
.37188 .82007 m
.37668 .81759 L
s
.51316 .94817 m .50168 .92873 L .50518 .93547 L 0 .394 .272 r
F
0 g
.50168 .92873 m
.5017 .92877 L
s
.5017 .92877 m
.50172 .9288 L
s
.50172 .9288 m
.50181 .92897 L
s
.50181 .92897 m
.50272 .93072 L
s
.50468 .93453 m
.50472 .93459 L
s
.5013 .93281 m
.50188 .9331 L
s
.50153 .93085 m
.50175 .93119 L
s
.50168 .92873 m
.50168 .92873 L
s
.50188 .9331 m
.50188 .9331 L
s
.50188 .9331 m
.50188 .9331 L
s
.50326 .93668 m
.50347 .9368 L
s
.50236 .93617 m
.50326 .93668 L
s
.50183 .93131 m
.50183 .93131 L
s
.50183 .93131 m
.50183 .93131 L
s
.50175 .93119 m
.50183 .93131 L
s
.53827 1.10705 m .53696 1.09987 L .54132 1.10625 L 0 .356 0 r
F
0 g
.53304 1.09517 m
.53696 1.09987 L
s
.53437 1.09474 m
.53696 1.09987 L
s
.49796 .96142 m .49342 .96645 L .49633 .96493 L 0 .333 .287 r
F
.49991 .96931 m .49633 .96493 L .49342 .96645 L 0 .303 .282 r
F
0 g
.49213 .97061 m
.49342 .96645 L
s
.49041 .96456 m
.49342 .96645 L
s
.51316 .94818 m .50386 .93618 L .5068 .93941 L 0 .296 .115 r
F
.51316 .94818 m .50357 .93686 L .50386 .93618 L F
0 g
.50372 .936 m
.50386 .93618 L
s
.50556 .94468 m .50519 .94406 L .50245 .94256 L 0 .342 .355 r
F
.51316 .94817 m .51087 .91017 L .51218 .93185 L 0 .355 .263 r
F
.51316 .94817 m .51218 .93185 L .51087 .91017 L 0 .346 .263 r
F
0 g
.51027 .89467 m
.51087 .91017 L
s
.51087 .91016 m
.51087 .91017 L
s
.51074 .89514 m
.51172 .91123 L
s
.29385 .73939 m .28773 .7305 L .28328 .73408 L 0 1 .499 r
F
.29385 .73939 m .29414 .72981 L .28773 .7305 L F
.29385 .73939 m .29823 .73247 L .29414 .72981 L F
.29385 .73939 m .2981 .73658 L .29823 .73247 L F
0 g
.28746 .74006 m
.29385 .73939 L
s
.29385 .73939 m
.29389 .74292 L
s
.47021 .63633 m .46268 .63749 L .46394 .63759 L 0 .762 .214 r
F
0 g
.45971 .63943 m
.46394 .63759 L
s
.47021 .63633 m .4674 .63614 L .46268 .63749 L 0 .762 .214 r
F
.47021 .63633 m .47498 .63446 L .4674 .63614 L F
.47021 .63633 m .48126 .63319 L .47498 .63446 L F
.47021 .63633 m .48206 .6332 L .48126 .63319 L F
.47021 .63633 m .47732 .63454 L .48206 .6332 L F
0 g
.46583 .6376 m
.47021 .63633 L
s
.46394 .63759 m
.47021 .63633 L
s
.47732 .63454 m
.48326 .63302 L
s
.50204 .94152 m .49449 .93688 L .49887 .9392 L 0 .287 .101 r
F
.50254 .93968 m .49887 .9392 L .49449 .93688 L 0 .276 .1 r
F
0 g
.4938 .93627 m
.49449 .93688 L
s
.49389 .93672 m
.49449 .93688 L
s
.38269 .91291 m .37512 .90921 L .37156 .90893 L 0 .558 .248 r
F
.38269 .91291 m .37965 .91063 L .37512 .90921 L F
.38269 .91291 m .38289 .91222 L .37965 .91063 L F
0 g
.37913 .91263 m
.38269 .91291 L
s
.39451 .91624 m .3829 .91222 L .38269 .91291 L 0 .468 .224 r
F
0 g
.38269 .91291 m
.38609 .91435 L
s
.6989 1.09947 m .70817 1.09203 L .70894 1.09605 L 0 0 .024 r
F
.49977 .99497 m .49354 .997 L .49533 1.00171 L 0 .256 .274 r
F
.49977 .99497 m .49376 .99178 L .49354 .997 L F
0 g
.49064 .99468 m
.49354 .997 L
s
.50654 .94625 m .50614 .94562 L .50365 .94444 L 0 .326 .343 r
F
.33875 .81536 m .32841 .81279 L .32943 .81832 L 0 1 .496 r
F
0 g
.3248 .82222 m
.32943 .81832 L
s
.53312 .72822 m .54045 .70777 L .53513 .71164 L 0 1 .381 r
F
0 g
.54045 .70777 m
.54135 .7084 L
s
.54261 .6316 m .53834 .63209 L .53771 .63117 L 0 0 0 r
F
.54261 .6316 m .54455 .63429 L .53834 .63209 L F
.54261 .6316 m .55219 .6363 L .54455 .63429 L F
.54261 .6316 m .55709 .63673 L .55219 .6363 L F
.54261 .6316 m .55598 .63529 L .55709 .63673 L F
0 g
.55705 .63554 m
.56039 .6363 L
s
.55598 .63529 m
.55705 .63554 L
s
.53676 .62946 m
.54261 .6316 L
s
.54977 .6331 m
.55598 .63529 L
s
.41816 .92372 m .40974 .92088 L .41448 .92232 L 0 0 0 r
F
.41816 .92372 m .40633 .91985 L .40974 .92088 L F
0 g
.4064 .91979 m
.40974 .92088 L
s
.41448 .92232 m
.41821 .92313 L
s
.7001 .89887 m
.70223 .89843 L
s
.42284 .82791 m .41276 .81959 L .41385 .82501 L 0 1 .452 r
F
0 g
.40911 .8257 m
.41385 .82501 L
s
.50759 .94785 m .50717 .94721 L .50496 .94634 L 0 .307 .328 r
F
.5014 .93185 m .48968 .91815 L .49309 .92271 L 0 .466 .384 r
F
.5014 .93185 m .48985 .91741 L .48968 .91815 L F
0 g
.48945 .92009 m
.49242 .92373 L
s
.50088 .92989 m
.50153 .93085 L
s
.48803 .91687 m
.48968 .91815 L
s
.38596 .81736 m .37853 .80657 L .37568 .81201 L 0 1 .47 r
F
0 g
.37568 .81201 m
.37668 .81759 L
s
.38596 .81736 m .38364 .80433 L .37853 .80657 L 0 1 .47 r
F
.38596 .81736 m .38761 .80678 L .38364 .80433 L F
.38596 .81736 m .3886 .81237 L .38761 .80678 L F
0 g
.38596 .81736 m
.38711 .82276 L
s
.38086 .8196 m
.38596 .81736 L
s
.4209 .65303 m
.42747 .65054 L
s
.27268 .72898 m .26207 .72413 L .26167 .72905 L 0 1 .525 r
F
0 g
.25566 .73125 m
.26167 .72905 L
s
.52177 .96943 m .52571 .97433 L .52386 .972 L 0 0 .149 r
F
.52404 .97211 m .52386 .972 L .52571 .97433 L 0 0 .133 r
F
0 g
.52571 .97433 m
.52702 .97591 L
s
.52571 .97433 m
.5258 .97451 L
s
.51316 .94818 m .52406 .93235 L .52425 .93332 L 0 .294 .123 r
F
.51316 .94818 m .5207 .93658 L .52406 .93235 L F
0 g
.52406 .93235 m
.52424 .93187 L
s
.5198 .93386 m
.52239 .92732 L
s
.5198 .93385 m
.52284 .92829 L
s
.50204 .94152 m .49378 .9394 L .49062 .93709 L 0 .287 .101 r
F
0 g
.49116 .93749 m
.4922 .93825 L
s
.49062 .93709 m
.49116 .93749 L
s
.48696 .93664 m
.49062 .93709 L
s
.51316 .94817 m .50505 .92127 L .50968 .93662 L 0 .395 .275 r
F
.51316 .94817 m .50968 .93662 L .50505 .92127 L 0 .402 .275 r
F
0 g
.50505 .92126 m
.50505 .92127 L
s
.50329 .91473 m
.50505 .92127 L
s
.7044 .60733 m .72068 .60652 L .71307 .60417 L 0 1 .429 r
F
0 g
.72068 .60652 m
.72914 .60752 L
s
.72068 .60652 m
.72359 .60903 L
s
.79091 1.03138 m .79383 1.03673 L .79918 1.02981 L 0 1 .335 r
F
.79091 1.03138 m .78948 1.03957 L .79383 1.03673 L F
0 g
.79383 1.03673 m
.79405 1.03835 L
s
.47302 .88207 m .4682 .87022 L .46433 .86735 L 0 .863 .42 r
F
0 g
.41395 .78076 m
.41911 .78227 L
s
.52491 .93888 m .52482 .93768 L .52821 .93059 L 0 .263 .134 r
F
0 g
.5246 .9327 m
.52516 .93169 L
s
.49991 .96931 m .49332 .97465 L .49611 .97588 L 0 .303 .282 r
F
0 g
.49234 .97892 m
.49332 .97465 L
s
.42284 .82791 m .41542 .81554 L .41276 .81959 L 0 1 .452 r
F
.42284 .82791 m .4203 .81525 L .41542 .81554 L F
.42284 .82791 m .42415 .81889 L .4203 .81525 L F
.42284 .82791 m .42523 .82432 L .42415 .81889 L F
0 g
.42284 .82791 m
.42412 .83319 L
s
.41796 .8282 m
.42284 .82791 L
s
.51534 .95805 m .51721 .96427 L .51751 .96461 L 0 .14 .192 r
F
.51534 .95805 m .51641 .96214 L .51721 .96427 L F
0 g
.51721 .96427 m
.51755 .96517 L
s
.50314 .94014 m .50289 .93956 L .49957 .93711 L 0 .419 .379 r
F
0 g
.49997 .9374 m
.50003 .93745 L
s
.49983 .9373 m
.49997 .9374 L
s
.49957 .93711 m
.49983 .9373 L
s
.49957 .93711 m
.49998 .93733 L
s
.49957 .93711 m
.49961 .93714 L
s
.49961 .93714 m
.49971 .93723 L
s
.49971 .93723 m
.49975 .93726 L
s
.49975 .93726 m
.49979 .9373 L
s
.49979 .9373 m
.49984 .93734 L
s
.49984 .93734 m
.49984 .93734 L
s
.50182 .93905 m
.50182 .93905 L
s
.50182 .93905 m
.50182 .93905 L
s
.74246 .6523 m .76077 .63774 L .75869 .64093 L 0 0 0 r
F
0 g
.76077 .63774 m
.76794 .63238 L
s
.5087 .94944 m .50825 .9488 L .50635 .94825 L 0 .286 .311 r
F
.52177 .96943 m .52084 .96836 L .52118 .96902 L 0 0 .149 r
F
0 g
.63502 .73823 m
.63714 .74386 L
s
.63714 .74386 m
.63869 .74798 L
s
.63869 .74798 m
.63929 .74957 L
s
.63929 .74957 m
.63951 .75015 L
s
.49645 .98478 m .49376 .99178 L .49585 .98953 L 0 .285 .286 r
F
.49977 .99497 m .49585 .98953 L .49376 .99178 L 0 .256 .274 r
F
0 g
.49354 .997 m
.49376 .99178 L
s
.49093 .98997 m
.49376 .99178 L
s
.5245 .62967 m .53178 .63013 L .53771 .63117 L 0 0 0 r
F
0 g
.53178 .63013 m
.53676 .62946 L
s
.51316 .94818 m .50628 .9406 L .50357 .93686 L 0 .296 .115 r
F
0 g
.50347 .9368 m
.50357 .93686 L
s
.50128 .93274 m .49295 .92438 L .49769 .92931 L 0 .472 .386 r
F
.50129 .93374 m .49769 .92931 L .49295 .92438 L 0 .475 .388 r
F
0 g
.49242 .92373 m
.49295 .92438 L
s
.48942 .92133 m
.49295 .92438 L
s
.49985 .93278 m
.50121 .9345 L
s
.79521 .79958 m .80196 .80318 L .79736 .80325 L 0 .01 0 r
F
.79521 .79958 m .80675 .80017 L .80196 .80318 L F
.51316 .94818 m .5068 .93941 L .51043 .94441 L 0 .296 .115 r
F
.51316 .94818 m .51043 .94441 L .5068 .93941 L 0 .291 .113 r
F
.51316 .94818 m .51316 .94818 L .51043 .94441 L F
.51316 .94818 m .50189 .93139 L .50205 .93319 L 0 .384 .27 r
F
.51316 .94818 m .50518 .93547 L .50189 .93139 L F
0 g
.50272 .93072 m
.50317 .93159 L
s
.50188 .9331 m
.50205 .93319 L
s
.50183 .93131 m
.50189 .93139 L
s
.50236 .93197 m
.50263 .93231 L
s
.50194 .93145 m
.50236 .93197 L
s
.50189 .93139 m
.50194 .93145 L
s
.47302 .88207 m .47202 .87576 L .4682 .87022 L 0 .863 .42 r
F
.47302 .88207 m .47409 .88084 L .47202 .87576 L F
.48303 .89648 m .47302 .88207 L .47528 .88721 L 0 .751 .41 r
F
.48303 .89648 m .47409 .88084 L .47302 .88207 L F
0 g
.46915 .8792 m
.47302 .88207 L
s
.47302 .88207 m
.47424 .88485 L
s
.48303 .89648 m .47528 .88721 L .47936 .89283 L 0 .751 .41 r
F
.48125 .89862 m .47936 .89283 L .47528 .88721 L 0 .761 .416 r
F
0 g
.47154 .88402 m
.47528 .88721 L
s
.47424 .88485 m
.47528 .88721 L
s
.51534 .95805 m .51751 .96461 L .51705 .96286 L 0 .14 .192 r
F
0 g
.51751 .96461 m
.51772 .96495 L
s
.51316 .94817 m .51172 .91123 L .51254 .93231 L 0 .364 .264 r
F
.51316 .94817 m .51254 .93231 L .51172 .91123 L 0 .355 .263 r
F
0 g
.51172 .91123 m
.51172 .91123 L
s
.51159 .90369 m
.51172 .91123 L
s
.61599 .68493 m
.62104 .69236 L
s
.62104 .69236 m
.62179 .69347 L
s
.5014 .93185 m .49344 .92119 L .48985 .91741 L 0 .466 .384 r
F
0 g
.48918 .91656 m
.48985 .91741 L
s
.48968 .91815 m
.49204 .9213 L
s
.25325 .81807 m .24328 .82226 L .24789 .82285 L 0 1 .531 r
F
0 g
.24789 .82285 m
.25027 .82865 L
s
.51316 .94817 m .51516 .90547 L .51431 .91734 L 0 .392 .267 r
F
.51316 .94817 m .51565 .90718 L .51516 .90547 L F
0 g
.51516 .90547 m
.51528 .8871 L
s
.45717 .85192 m .44908 .84542 L .45291 .85002 L 0 1 .428 r
F
0 g
.45291 .85002 m
.45458 .85512 L
s
.51316 .94818 m .5198 .93386 L .51601 .94203 L 0 .306 .125 r
F
.51316 .94818 m .51601 .94203 L .5198 .93386 L 0 .302 .125 r
F
0 g
.5198 .93386 m
.5198 .93386 L
s
.5198 .93386 m
.5198 .93385 L
s
.50254 .93871 m .50233 .93816 L .49888 .93539 L 0 .44 .383 r
F
0 g
.50166 .93762 m
.50188 .9378 L
s
.49931 .93573 m
.49954 .93592 L
s
.49931 .93573 m
.49931 .93573 L
s
.49888 .93539 m
.49931 .93573 L
s
.50142 .93811 m
.50198 .93841 L
s
.50122 .93833 m
.50193 .93885 L
s
.50155 .93754 m
.5016 .93755 L
s
.5016 .93755 m
.5016 .93755 L
s
.50104 .93838 m
.50152 .93879 L
s
.50064 .93803 m
.50104 .93838 L
s
.50051 .93792 m
.50064 .93803 L
s
.50027 .93771 m
.50051 .93792 L
s
.50025 .9377 m
.50027 .93771 L
s
.5001 .93757 m
.50025 .9377 L
s
.50006 .93753 m
.5001 .93757 L
s
.49993 .93742 m
.50006 .93753 L
s
.49984 .93734 m
.49993 .93742 L
s
.50079 .93777 m
.50142 .93811 L
s
.50048 .9376 m
.50079 .93777 L
s
.50045 .93759 m
.50048 .9376 L
s
.50037 .93754 m
.50045 .93759 L
s
.50022 .93746 m
.50037 .93754 L
s
.5002 .93745 m
.50022 .93746 L
s
.50011 .9374 m
.5002 .93745 L
s
.49998 .93733 m
.50011 .9374 L
s
.50003 .93745 m
.50025 .93761 L
s
.50025 .93761 m
.50028 .93763 L
s
.50028 .93763 m
.50044 .93775 L
s
.50044 .93775 m
.50122 .93833 L
s
.46649 .86488 m .45865 .85724 L .46247 .86228 L 0 .946 .421 r
F
.46649 .86488 m .45717 .85192 L .45865 .85724 L F
0 g
.45458 .85512 m
.45865 .85724 L
s
.46247 .86228 m
.46433 .86735 L
s
.50465 .95176 m .49618 .95354 L .49914 .95508 L 0 .345 .277 r
F
0 g
.49422 .95639 m
.49618 .95354 L
s
.53569 .98663 m .54158 .98985 L .54316 .99192 L 0 .255 0 r
F
0 g
.53851 .98693 m
.53897 .98689 L
s
.53569 .98663 m .53836 .98695 L .54158 .98985 L 0 .255 0 r
F
0 g
.54158 .98985 m
.54158 .98985 L
s
.54134 .98964 m
.54158 .98985 L
s
.54046 .98884 m
.54134 .98964 L
s
.53887 .98741 m
.54046 .98884 L
s
.53876 .9873 m
.53887 .98741 L
s
.48125 .89862 m .48192 .89772 L .47936 .89283 L 0 .761 .416 r
F
.49187 .91346 m .48125 .89862 L .48398 .90364 L 0 .62 .4 r
F
.49187 .91346 m .48192 .89772 L .48125 .89862 L F
0 g
.47751 .89542 m
.48125 .89862 L
s
.48125 .89862 m
.4826 .90111 L
s
.82413 1.01 m .83425 1.00036 L .82978 1.00274 L 0 1 .438 r
F
.81305 1.01632 m .82413 1.01 L .82308 1.00651 L 0 1 .413 r
F
.45717 .85192 m .44783 .84006 L .44908 .84542 L 0 1 .428 r
F
0 g
.44481 .84397 m
.44908 .84542 L
s
.37568 .81201 m .36654 .81304 L .37055 .81478 L 0 1 .472 r
F
0 g
.37055 .81478 m
.37187 .82007 L
s
.51316 .94817 m .5049 .92383 L .50961 .93772 L 0 .402 .275 r
F
.51316 .94817 m .50961 .93772 L .5049 .92383 L 0 .406 .275 r
F
0 g
.50426 .92173 m
.5049 .92383 L
s
.5049 .92383 m
.5049 .92383 L
s
.53057 1.09384 m .52935 1.09187 L .529 1.09039 L 0 .316 0 r
F
.49994 1.01358 m .49807 1.00882 L .49545 1.00675 L 0 .217 .264 r
F
.5245 .62967 m .51931 .63022 L .51916 .62971 L 0 0 0 r
F
.5245 .62967 m .52525 .63126 L .51931 .63022 L F
.5245 .62967 m .533 .63213 L .52525 .63126 L F
.5245 .62967 m .53834 .63209 L .533 .63213 L F
0 g
.53923 .6313 m
.54261 .6316 L
s
.5245 .62967 m .53771 .63117 L .53834 .63209 L 0 0 0 r
F
0 g
.53771 .63117 m
.53923 .6313 L
s
.51893 .62869 m
.5245 .62967 L
s
.53178 .63013 m
.53771 .63117 L
s
.50866 1.04588 m .50485 1.04538 L .50777 1.05104 L 0 .081 .187 r
F
.50866 1.04588 m .50318 1.03973 L .50485 1.04538 L F
0 g
.50215 1.04211 m
.50485 1.04538 L
s
.50986 .95104 m .50939 .9504 L .50781 .95017 L 0 .263 .292 r
F
.46566 .93732 m .45747 .93364 L .46219 .93516 L 0 .211 .043 r
F
.46566 .93732 m .45383 .9334 L .45747 .93364 L F
0 g
.45421 .93164 m
.45747 .93364 L
s
.51349 .95576 m .51434 .95982 L .51406 .95777 L 0 .186 .225 r
F
.51471 .95727 m .51406 .95777 L .51434 .95982 L 0 .161 .205 r
F
0 g
.51381 .96057 m
.51434 .95982 L
s
.51434 .95982 m
.51528 .96216 L
s
.75508 .81892 m .76287 .80043 L .76747 .80123 L 0 .188 .072 r
F
.75508 .81892 m .75757 .80797 L .76287 .80043 L F
0 g
.76052 .79344 m
.76287 .80043 L
s
.41276 .81959 m .40357 .81744 L .40769 .8204 L 0 1 .456 r
F
0 g
.40769 .8204 m
.40911 .8257 L
s
.3556 .76488 m .34597 .76103 L .34979 .76262 L 0 .348 .194 r
F
0 g
.34979 .76262 m
.35022 .76358 L
s
.52505 .94204 m .53689 .92799 L .5334 .93408 L 0 .269 .135 r
F
0 g
.53632 .92898 m
.53689 .92799 L
s
.52517 .93326 m
.52535 .93282 L
s
.52535 .93282 m
.52596 .93135 L
s
.52593 .93402 m
.52821 .93059 L
s
.52568 .93439 m
.52593 .93402 L
s
.52494 .93552 m
.52568 .93439 L
s
.52753 .932 m
.52821 .93059 L
s
.52645 .93426 m
.52753 .932 L
s
.53689 .92799 m
.5374 .92723 L
s
.7044 .60733 m .70481 .60343 L .70144 .60481 L 0 1 .429 r
F
.7044 .60733 m .71307 .60417 L .70481 .60343 L F
.33875 .81536 m .33123 .80637 L .32841 .81279 L 0 1 .496 r
F
.33875 .81536 m .33638 .80243 L .33123 .80637 L F
.33875 .81536 m .34042 .80359 L .33638 .80243 L F
.33875 .81536 m .34143 .80914 L .34042 .80359 L F
0 g
.33875 .81536 m
.33988 .82084 L
s
.33361 .81929 m
.33875 .81536 L
s
.27611 .8212 m .26716 .81279 L .26469 .81964 L 0 1 .526 r
F
.27611 .8212 m .27241 .80817 L .26716 .81279 L F
.27611 .8212 m .27691 .80888 L .27241 .80817 L F
.27611 .8212 m .2785 .81447 L .27691 .80888 L F
0 g
.27088 .82579 m
.27611 .8212 L
s
.27611 .8212 m
.27778 .82668 L
s
.75028 .60578 m .75143 .60111 L .7477 .60222 L 0 1 .477 r
F
.75028 .60578 m .75981 .60332 L .75143 .60111 L F
.48809 .63234 m .48126 .63319 L .48206 .6332 L 0 0 0 r
F
0 g
.47732 .63454 m
.48206 .6332 L
s
.48809 .63234 m .48645 .63249 L .48126 .63319 L 0 0 0 r
F
.48809 .63234 m .50054 .63049 L .50021 .63069 L F
.48809 .63234 m .49417 .63155 L .48645 .63249 L F
.48809 .63234 m .50021 .63069 L .49417 .63155 L F
.48809 .63234 m .49534 .6312 L .50054 .63049 L F
0 g
.49534 .6312 m
.50102 .62997 L
s
.48206 .6332 m
.48809 .63234 L
s
.53267 .98259 m .53836 .98695 L .53566 .98513 L 0 .204 0 r
F
.53569 .98663 m .53566 .98513 L .53836 .98695 L 0 .255 0 r
F
0 g
.53836 .98695 m
.53851 .98693 L
s
.53836 .98695 m
.53876 .9873 L
s
.67946 .64912 m .68845 .65855 L .68026 .63577 L 0 .279 .283 r
F
.67946 .64912 m .69589 .6848 L .68845 .65855 L F
0 g
.67946 .64909 m
.67946 .64912 L
s
.67866 .67317 m
.6837 .68864 L
s
.44783 .84006 m .4395 .83457 L .44334 .8388 L 0 1 .435 r
F
0 g
.44334 .8388 m
.44481 .84397 L
s
.51316 .94818 m .50205 .93319 L .50546 .93862 L 0 .384 .27 r
F
0 g
.50205 .93319 m
.50207 .93322 L
s
.50207 .93322 m
.50211 .93328 L
s
.50211 .93328 m
.50219 .93341 L
s
.50219 .93341 m
.50352 .93552 L
s
.50386 .93618 m
.50407 .9364 L
s
.50226 .93582 m
.50228 .93585 L
s
.50228 .93585 m
.50228 .93585 L
s
.50228 .93585 m
.50228 .93585 L
s
.50198 .93841 m
.50217 .93851 L
s
.50217 .93851 m
.50217 .93851 L
s
.50217 .93851 m
.50217 .93851 L
s
.50248 .9372 m
.50305 .93779 L
s
.50188 .9378 m
.50209 .93797 L
s
.50205 .93319 m
.50205 .93319 L
s
.47795 .93783 m .46928 .93745 L .46596 .93533 L 0 .243 .067 r
F
0 g
.46219 .93516 m
.46596 .93533 L
s
.50385 .94706 m .49773 .94816 L .50135 .94834 L 0 .373 .28 r
F
.50465 .95176 m .50135 .94834 L .49773 .94816 L 0 .345 .277 r
F
0 g
.49551 .9504 m
.49773 .94816 L
s
.49468 .94577 m
.49773 .94816 L
s
.32841 .81279 m .31897 .81609 L .32316 .81695 L 0 1 .501 r
F
0 g
.32316 .81695 m
.3248 .82222 L
s
.49017 .91637 m .49043 .91572 L .48726 .9112 L 0 .638 .41 r
F
.51316 .94818 m .52425 .93332 L .52103 .93828 L 0 .294 .123 r
F
0 g
.52029 .9351 m
.52312 .92899 L
s
.52029 .9351 m
.5235 .93016 L
s
.52425 .93332 m
.5246 .9327 L
s
.39451 .91624 m .38659 .9129 L .3829 .91222 L 0 .468 .224 r
F
.39451 .91624 m .39131 .9145 L .38659 .9129 L F
.39451 .91624 m .3947 .91593 L .39131 .9145 L F
.40633 .91985 m .3947 .91593 L .39451 .91624 L 0 .348 .187 r
F
0 g
.39451 .91624 m
.39791 .91748 L
s
.39082 .91556 m
.39451 .91624 L
s
.4957 .8093 m .49117 .81443 L .49252 .80993 L 0 .442 .087 r
F
.49564 .82853 m .49391 .81647 L .49117 .81516 L 0 .984 .372 r
F
.4957 .8093 m .49391 .81647 L .49117 .81443 L 0 .442 .087 r
F
.49391 .81647 m .49125 .8148 L .49117 .81443 L F
.49391 .81647 m .49272 .80826 L .49125 .8148 L 0 .984 .372 r
F
.49391 .81647 m .49125 .8148 L .49117 .81516 L F
.49564 .82853 m .49117 .81516 L .49248 .82306 L F
.49391 .81647 m .49268 .82138 L .49125 .8148 L 0 .442 .087 r
F
0 g
.49144 .80414 m
.49244 .8095 L
s
.49391 .81647 m .49611 .80697 L .49272 .80826 L 0 .984 .372 r
F
.49564 .82853 m .49588 .81772 L .49391 .81647 L F
.4957 .8093 m .49588 .81772 L .49391 .81647 L 0 .442 .087 r
F
.49564 .82853 m .49781 .81893 L .49588 .81772 L 0 .984 .372 r
F
.49564 .82853 m .5001 .82102 L .50003 .82033 L F
.4957 .8093 m .5001 .81988 L .50003 .82033 L 0 .442 .087 r
F
.4957 .8093 m .50003 .82033 L .49781 .81893 L F
.4957 .8093 m .49858 .81295 L .5001 .81988 L F
.49781 .81893 m .50003 .82033 L .49927 .81243 L 0 .984 .372 r
F
.49564 .82853 m .50003 .82033 L .49781 .81893 L F
.49564 .82853 m .49854 .82792 L .5001 .82102 L F
.49781 .81893 m .50003 .82033 L .49924 .82549 L 0 .442 .087 r
F
.49588 .81772 m .49924 .82549 L .49606 .82614 L F
.4957 .8093 m .49781 .81893 L .49588 .81772 L F
.49781 .81893 m .49924 .82549 L .49588 .81772 L F
.49588 .81772 m .49927 .81243 L .49611 .80697 L 0 .984 .372 r
F
.49781 .81893 m .49927 .81243 L .49588 .81772 L F
.49588 .81772 m .49611 .80697 L .49391 .81647 L F
.49391 .81647 m .49606 .82614 L .49268 .82138 L 0 .442 .087 r
F
.49588 .81772 m .49606 .82614 L .49391 .81647 L F
0 g
.49455 .80177 m
.49538 .80724 L
s
.49918 .81228 m
.50139 .80987 L
s
.3478 .56875 m .33563 .57423 L .33877 .57525 L 0 1 .451 r
F
0 g
.33502 .58423 m
.33877 .57525 L
s
.3478 .56875 m .34023 .56652 L .33563 .57423 L 0 1 .451 r
F
.3478 .56875 m .34951 .55725 L .34023 .56652 L F
.3478 .56875 m .35856 .55074 L .34951 .55725 L F
.3478 .56875 m .36132 .55135 L .35856 .55074 L F
.3478 .56875 m .35671 .55907 L .36132 .55135 L F
0 g
.34348 .57661 m
.3478 .56875 L
s
.33877 .57525 m
.3478 .56875 L
s
.35671 .55907 m
.36546 .55206 L
s
.50626 .63004 m .51356 .62963 L .51916 .62971 L 0 0 0 r
F
0 g
.51356 .62963 m
.51893 .62869 L
s
.50205 .93735 m .50188 .93683 L .49835 .93373 L 0 .457 .386 r
F
0 g
.50114 .93618 m
.50153 .93652 L
s
.50111 .93615 m
.50114 .93618 L
s
.50195 .93544 m
.50226 .93582 L
s
.50121 .9345 m
.50195 .93544 L
s
.50195 .93544 m
.50195 .93544 L
s
.50195 .93544 m
.50195 .93544 L
s
.50059 .93645 m
.50111 .93677 L
s
.49888 .93539 m
.49967 .93587 L
s
.50111 .93677 m
.5012 .93683 L
s
.5012 .93683 m
.50156 .93705 L
s
.50156 .93705 m
.50185 .93723 L
s
.50049 .93668 m
.50131 .93734 L
s
.50131 .93734 m
.50131 .93734 L
s
.50131 .93734 m
.50166 .93762 L
s
.76867 .64959 m .77174 .65769 L .76776 .65979 L 0 .107 .074 r
F
.76867 .64959 m .77879 .64574 L .77174 .65769 L F
0 g
.76776 .65979 m
.76867 .64959 L
s
.76267 .66137 m
.76867 .64959 L
s
.76181 .66305 m
.76267 .66137 L
s
.55754 .66773 m .57006 .65908 L .57158 .65602 L 0 1 .407 r
F
.55754 .66773 m .56405 .66409 L .57006 .65908 L F
0 g
.57006 .65908 m
.5736 .65842 L
s
.5681 .66072 m
.57006 .65908 L
s
.5026 1.03243 m .50318 1.03973 L .50388 1.03783 L 0 .16 .236 r
F
.50866 1.04588 m .50388 1.03783 L .50318 1.03973 L 0 .081 .187 r
F
0 g
.50318 1.03973 m
.50485 1.04538 L
s
.50051 1.03702 m
.50318 1.03973 L
s
.49187 .91346 m .48398 .90364 L .48829 .90945 L 0 .62 .4 r
F
.4909 .9148 m .48829 .90945 L .48398 .90364 L 0 .63 .406 r
F
0 g
.48034 .90004 m
.48398 .90364 L
s
.4826 .90111 m
.48398 .90364 L
s
.48726 .9112 m
.48837 .91278 L
s
.48744 .91398 m
.48911 .91544 L
s
.53312 .72822 m .53064 .71947 L .52998 .72604 L 0 1 .381 r
F
.53312 .72822 m .53513 .71164 L .53064 .71947 L F
.53113 .74814 m .53312 .72822 L .529 .73679 L 0 1 .361 r
F
.40154 .77783 m .39238 .77617 L .39233 .77538 L 0 0 0 r
F
0 g
.38705 .77393 m
.39233 .77538 L
s
.524 1.08429 m .52551 1.08582 L .52788 1.08996 L 0 0 .105 r
F
0 g
.52551 1.08582 m
.529 1.09039 L
s
.47582 .87911 m .4682 .87022 L .47202 .87576 L 0 .853 .413 r
F
.47582 .87911 m .46649 .86488 L .4682 .87022 L F
0 g
.46433 .86735 m
.4682 .87022 L
s
.25325 .81807 m .24181 .81647 L .24328 .82226 L 0 1 .531 r
F
0 g
.23873 .82731 m
.24328 .82226 L
s
.50626 .63004 m .50021 .63069 L .50054 .63049 L 0 0 0 r
F
.50626 .63004 m .50581 .63077 L .50021 .63069 L F
0 g
.49534 .6312 m
.50054 .63049 L
s
.50626 .63004 m .51359 .63068 L .50581 .63077 L 0 0 0 r
F
.50626 .63004 m .51931 .63022 L .51359 .63068 L F
.50626 .63004 m .51916 .62971 L .51931 .63022 L F
0 g
.50054 .63049 m
.50626 .63004 L
s
.50102 .62997 m
.50626 .63004 L
s
.51916 .62971 m
.5245 .62967 L
s
.51356 .62963 m
.51916 .62971 L
s
.7418 1.07536 m .75245 1.06888 L .74826 1.07217 L 0 0 0 r
F
.73144 1.08395 m .7418 1.07536 L .74196 1.07743 L F
.53113 .74814 m .529 .73679 L .52834 .74457 L 0 1 .361 r
F
.52914 .77199 m .53113 .74814 L .52737 .75729 L 0 1 .343 r
F
.5163 .9592 m .51845 .96567 L .51942 .96674 L 0 .131 .19 r
F
0 g
.51738 .96411 m
.51751 .96461 L
s
.5163 .9592 m .51705 .96286 L .51845 .96567 L 0 .131 .19 r
F
0 g
.51842 .96608 m
.51845 .96567 L
s
.51668 .96286 m
.51721 .96427 L
s
.51625 .96323 m
.51637 .96244 L
s
.51637 .96244 m
.51639 .96226 L
s
.45717 .85192 m .44998 .83751 L .44783 .84006 L 0 1 .428 r
F
.45717 .85192 m .45424 .83941 L .44998 .83751 L F
.45717 .85192 m .45776 .84449 L .45424 .83941 L F
.45717 .85192 m .45902 .84985 L .45776 .84449 L F
.46649 .86488 m .45902 .84985 L .45717 .85192 L 0 .946 .421 r
F
0 g
.45717 .85192 m
.45865 .85724 L
s
.45291 .85002 m
.45717 .85192 L
s
.35239 .6817 m .34382 .66583 L .34209 .65752 L 0 .652 .056 r
F
0 g
.34209 .65752 m
.34391 .65857 L
s
.50165 .93109 m .49017 .91637 L .49344 .92119 L 0 .456 .381 r
F
.50165 .93109 m .49043 .91572 L .49017 .91637 L F
0 g
.48911 .91544 m
.49017 .91637 L
s
.34209 .65753 m .33412 .66384 L .33794 .65668 L 0 .705 .102 r
F
.34209 .65753 m .33278 .66963 L .33412 .66384 L F
.34209 .65753 m .33482 .67016 L .33278 .66963 L F
.34209 .65753 m .33898 .67102 L .33482 .67016 L F
.34209 .65753 m .34249 .67163 L .33898 .67102 L F
.34209 .65753 m .34381 .66584 L .34249 .67163 L F
0 g
.33794 .65668 m
.34209 .65753 L
s
.40154 .77783 m .39621 .77789 L .39238 .77617 L 0 0 0 r
F
.40128 .79253 m .40168 .7795 L .39619 .77937 L 0 1 .452 r
F
.40128 .79253 m .40515 .78143 L .40385 .78011 L F
.40868 .7813 m .40533 .78052 L .40517 .78034 L 0 0 0 r
F
.40533 .78052 m .40529 .78051 L .40529 .78051 L F
.40533 .78052 m .40529 .78051 L .40517 .78034 L F
.40529 .78052 m .40528 .78051 L .40523 .7805 L 0 1 .448 r
F
.40128 .79253 m .40385 .78011 L .40168 .7795 L 0 1 .452 r
F
.40533 .78052 m .40008 .77964 L .4017 .77968 L 0 0 0 r
F
.40868 .7813 m .40672 .78092 L .40533 .78052 L F
.40865 .78294 m .40529 .78052 L .40515 .78143 L 0 1 .448 r
F
.40528 .78051 m .40383 .78009 L .40517 .78034 L 0 0 0 r
F
.40523 .78048 m .40383 .78009 L .40384 .7801 L 0 1 .448 r
F
.40523 .7805 m .40384 .7801 L .40515 .78143 L F
.40523 .78048 m .40384 .7801 L .40523 .7805 L F
.40154 .77783 m .4051 .77955 L .40517 .78034 L 0 0 0 r
F
.40528 .78051 m .40018 .77413 L .40174 .77795 L 0 1 .448 r
F
.40865 .78294 m .4067 .78092 L .40528 .78051 L F
.40672 .78092 m .4067 .78092 L .40533 .78052 L 0 0 0 r
F
.4067 .78092 m .40646 .78085 L .40533 .78052 L F
.40669 .78091 m .40531 .78052 L .40533 .78052 L F
.40529 .78051 m .40528 .78051 L .40528 .78051 L F
.40529 .78051 m .40528 .78051 L .40517 .78034 L F
.4067 .78092 m .40018 .77413 L .40528 .78051 L 0 1 .448 r
F
.4067 .78092 m .40669 .78091 L .40646 .78085 L 0 0 0 r
F
.40669 .78091 m .40008 .77964 L .40531 .78052 L F
.40529 .78052 m .40523 .7805 L .40515 .78143 L 0 1 .448 r
F
.4074 .78111 m .4049 .7812 L .40139 .78025 L 0 0 0 r
F
.40868 .7813 m .40797 .78128 L .4074 .78111 L F
.40797 .78128 m .4049 .7812 L .4074 .78111 L F
.40865 .78294 m .40798 .7813 L .40741 .78113 L 0 1 .448 r
F
.40865 .78294 m .4074 .78111 L .4067 .78092 L F
.40797 .78128 m .40827 .78187 L .4049 .7812 L 0 0 0 r
F
.40868 .7813 m .40856 .78146 L .40797 .78128 L F
.40856 .78147 m .40856 .78146 L .40798 .7813 L 0 1 .448 r
F
.40856 .78146 m .40839 .7814 L .40798 .7813 L F
.40856 .78145 m .40798 .78128 L .40798 .7813 L F
.40798 .7813 m .40798 .78128 L .40797 .78128 L F
.40865 .78294 m .40856 .78147 L .40798 .7813 L F
.40856 .78146 m .40827 .78187 L .40797 .78128 L 0 0 0 r
F
.40856 .78146 m .40856 .78145 L .40839 .7814 L 0 1 .448 r
F
.40856 .78145 m .40834 .77766 L .40798 .78128 L F
.40797 .78128 m .40834 .77766 L .40502 .77402 L F
.40798 .78128 m .40834 .77766 L .40797 .78128 L F
.40741 .78113 m .40502 .77402 L .40153 .77251 L F
.40868 .7813 m .40744 .78112 L .40676 .78093 L 0 0 0 r
F
.40798 .7813 m .40502 .77402 L .40741 .78113 L 0 1 .448 r
F
.40528 .78051 m .40523 .7805 L .40523 .7805 L F
.40528 .78051 m .4017 .77968 L .40383 .78009 L 0 0 0 r
F
.40528 .78051 m .40523 .78048 L .40523 .7805 L 0 1 .448 r
F
.4067 .78092 m .40153 .77251 L .40018 .77413 L F
.40744 .78112 m .4074 .78111 L .40676 .78093 L 0 0 0 r
F
.4074 .78111 m .40729 .78108 L .40676 .78093 L F
.40739 .78111 m .40672 .78092 L .40676 .78093 L F
.4074 .78111 m .40153 .77251 L .4067 .78092 L 0 1 .448 r
F
.4074 .78111 m .40739 .78111 L .40729 .78108 L 0 0 0 r
F
.40739 .78111 m .40139 .78025 L .40672 .78092 L F
.40154 .77783 m .40517 .78034 L .40383 .78008 L F
.40523 .78048 m .40174 .77795 L .40383 .78009 L 0 1 .448 r
F
.40168 .7795 m .40385 .78011 L .40383 .78008 L 0 1 .452 r
F
.40168 .7795 m .40383 .78008 L .40169 .77949 L F
.40169 .77949 m .40383 .78008 L .4017 .77968 L 0 0 0 r
F
.40154 .77783 m .40383 .78008 L .40169 .77949 L F
.40169 .77949 m .40383 .78008 L .40173 .77795 L 0 1 .452 r
F
.40666 .78091 m .40139 .78025 L .40008 .77964 L 0 0 0 r
F
.40676 .78093 m .4067 .78092 L .40666 .78091 L F
.4067 .78092 m .40139 .78025 L .40666 .78091 L F
.40168 .7795 m .40169 .77949 L .40165 .77948 L 0 1 .452 r
F
.40168 .7795 m .40165 .77948 L .39619 .77937 L F
.40154 .77783 m .40168 .77948 L .39621 .77789 L 0 0 0 r
F
.40168 .77948 m .40169 .77949 L .40156 .77945 L F
.40168 .77948 m .40156 .77945 L .39621 .77789 L F
.39221 .78474 m .39618 .77937 L .39629 .77807 L 0 1 .451 r
F
.40169 .77949 m .39875 .77872 L .39621 .77789 L 0 0 0 r
F
.39221 .78474 m .39629 .77807 L .39488 .7777 L 0 1 .451 r
F
.39238 .77617 m .39489 .77763 L .39283 .77705 L 0 0 0 r
F
.39489 .77763 m .3949 .77764 L .39283 .77705 L F
.39238 .77617 m .38322 .77346 L .38682 .77427 L F
.39238 .77617 m .38359 .7742 L .38322 .77346 L F
.38359 .7742 m .37422 .77113 L .37782 .77211 L F
.38359 .7742 m .37737 .77258 L .37422 .77113 L F
.38352 .77757 m .37716 .77253 L .37408 .77758 L 0 1 .447 r
F
.37737 .77258 m .37716 .77253 L .37468 .77177 L 0 0 0 r
F
.37716 .77253 m .37469 .77178 L .37468 .77177 L F
.37737 .77258 m .37468 .77177 L .37422 .77113 L F
.37716 .77253 m .37481 .77066 L .37469 .77178 L 0 1 .447 r
F
.37339 .77135 m .36521 .7683 L .36882 .7695 L 0 0 0 r
F
.37346 .77138 m .36513 .77156 L .36871 .77391 L 0 1 .441 r
F
.37346 .77138 m .37173 .77076 L .37339 .77135 L 0 0 0 r
F
.37212 .77091 m .37173 .77076 L .37346 .77138 L F
.37481 .77066 m .37212 .77091 L .37346 .77138 L 0 1 .441 r
F
.37212 .77091 m .36513 .77156 L .37346 .77138 L F
.37478 .77191 m .37212 .77091 L .37346 .77138 L 0 0 0 r
F
.37173 .77076 m .36521 .7683 L .37339 .77135 L F
.37716 .77253 m .37469 .77178 L .37468 .77181 L 0 1 .447 r
F
.37709 .77265 m .37468 .77181 L .37408 .77758 L F
.37716 .77253 m .37468 .77181 L .37709 .77265 L F
.37716 .77253 m .37478 .77191 L .37469 .77178 L 0 0 0 r
F
.37716 .77253 m .37935 .76397 L .37481 .77066 L 0 1 .447 r
F
.38352 .77757 m .38246 .77413 L .37723 .77258 L F
.38248 .77419 m .38249 .77414 L .38246 .77413 L F
.38352 .77757 m .38384 .77456 L .38248 .77419 L F
.39221 .78474 m .38932 .77619 L .38352 .77757 L 0 1 .451 r
F
.39238 .77617 m .38933 .77606 L .38359 .7742 L 0 0 0 r
F
.38933 .77606 m .38928 .77606 L .38905 .77598 L F
.38933 .77606 m .38905 .77598 L .38359 .7742 L F
.38928 .77606 m .38534 .77497 L .38359 .7742 L F
.38932 .77619 m .38535 .775 L .38352 .77757 L 0 1 .451 r
F
.39283 .77705 m .39283 .77705 L .38928 .77606 L 0 0 0 r
F
.39238 .77617 m .39283 .77705 L .38928 .77606 L F
.38928 .77606 m .39283 .77705 L .38927 .77604 L 0 1 .451 r
F
.39221 .78474 m .39283 .77705 L .38928 .77606 L F
.39488 .7777 m .39629 .77807 L .39629 .77804 L F
.39488 .7777 m .39629 .77804 L .3949 .77764 L F
.39238 .77617 m .39621 .77789 L .3966 .77864 L 0 0 0 r
F
.39283 .77705 m .39671 .77288 L .39343 .7696 L 0 1 .451 r
F
.39221 .78474 m .39491 .77764 L .39283 .77705 L F
.39491 .77764 m .39671 .77288 L .39283 .77705 L F
.39283 .77705 m .39327 .77791 L .38928 .77606 L 0 0 0 r
F
.38928 .77606 m .39327 .77791 L .38769 .77601 L F
.38932 .77619 m .38928 .77606 L .38535 .775 L 0 1 .451 r
F
.38928 .77606 m .38778 .77161 L .38537 .77498 L F
.38928 .77606 m .38537 .77498 L .38535 .775 L F
.38928 .77606 m .38769 .77601 L .38537 .77498 L 0 0 0 r
F
.38928 .77606 m .38537 .77498 L .38534 .77497 L F
.38928 .77606 m .38537 .77498 L .38537 .77498 L 0 1 .451 r
F
.38352 .77757 m .3846 .77477 L .38384 .77454 L 0 1 .447 r
F
.38461 .77476 m .38778 .77161 L .38851 .76469 L F
.38352 .77757 m .38537 .77498 L .38461 .77476 L F
.38537 .77498 m .38778 .77161 L .38461 .77476 L F
.38461 .77476 m .38769 .77601 L .38827 .7768 L 0 0 0 r
F
.38359 .7742 m .38537 .77498 L .38461 .77476 L F
.38537 .77498 m .38769 .77601 L .38461 .77476 L F
.38384 .77454 m .38827 .7768 L .38493 .77604 L F
.38359 .7742 m .38461 .77476 L .38384 .77454 L F
.3846 .77477 m .38461 .77476 L .38384 .77454 L 0 1 .447 r
F
.38461 .77476 m .38827 .7768 L .38384 .77454 L 0 0 0 r
F
.38461 .77476 m .38851 .76469 L .38384 .77454 L 0 1 .447 r
F
.38384 .77454 m .38851 .76469 L .38523 .76141 L F
.38384 .77456 m .38384 .77455 L .38248 .77419 L F
.38384 .77455 m .38249 .77414 L .38248 .77419 L F
.38339 .77441 m .38493 .77604 L .38246 .77413 L 0 0 0 r
F
.38384 .77454 m .38384 .77454 L .38339 .77441 L F
.38384 .77454 m .38493 .77604 L .38339 .77441 L F
.38246 .77413 m .38493 .77604 L .37914 .77394 L F
.38246 .77413 m .38247 .77414 L .38246 .77413 L F
.38247 .77414 m .38493 .77604 L .38246 .77413 L F
.38359 .7742 m .38384 .77454 L .38246 .77413 L F
.37723 .77258 m .38246 .77413 L .37716 .77253 L 0 1 .447 r
F
.37737 .77258 m .37739 .7726 L .37716 .77253 L 0 0 0 r
F
.38359 .7742 m .38246 .77413 L .37737 .77258 L F
.38246 .77413 m .37935 .76397 L .37716 .77253 L 0 1 .447 r
F
.37716 .77253 m .37914 .77394 L .37478 .77191 L 0 0 0 r
F
.37739 .7726 m .37914 .77394 L .37716 .77253 L F
.38246 .77413 m .37914 .77394 L .37737 .77258 L F
.38384 .77455 m .38523 .76141 L .38249 .77414 L 0 1 .447 r
F
.38246 .77413 m .38523 .76141 L .37935 .76397 L F
.38249 .77414 m .38523 .76141 L .38246 .77413 L F
.39164 .77672 m .39343 .7696 L .38927 .77604 L 0 1 .451 r
F
.39283 .77705 m .39283 .77704 L .39164 .77672 L F
.39283 .77704 m .39343 .7696 L .39164 .77672 L F
.38927 .77604 m .39343 .7696 L .38778 .77161 L F
.39283 .77705 m .3966 .77864 L .39327 .77791 L 0 0 0 r
F
.3949 .77764 m .3966 .77864 L .39283 .77705 L F
.3949 .77764 m .39629 .77804 L .39671 .77288 L 0 1 .451 r
F
.40169 .77949 m .40173 .77795 L .39875 .77872 L 0 1 .452 r
F
.40169 .77949 m .39875 .77872 L .39619 .77937 L F
.40169 .77949 m .4017 .77968 L .39875 .77872 L 0 0 0 r
F
0 g
.40154 .77783 m
.40158 .77757 L
s
.39644 .77617 m
.40154 .77783 L
s
.52629 .89328 m .52711 .89942 L .52989 .88993 L 0 .523 .258 r
F
.48303 .89648 m .47776 .88448 L .47409 .88084 L 0 .751 .41 r
F
.44783 .84006 m .43848 .82915 L .4395 .83457 L 0 1 .435 r
F
0 g
.43503 .83375 m
.4395 .83457 L
s
.365 .76804 m .35954 .76632 L .3556 .76488 L 0 0 0 r
F
.365 .76804 m .36521 .7683 L .35954 .76632 L F
.365 .76804 m .36882 .7695 L .36521 .7683 L F
.365 .76804 m .36872 .76938 L .36882 .7695 L F
0 g
.365 .76804 m
.36509 .76783 L
s
.35935 .76607 m
.365 .76804 L
s
.26207 .72413 m .25089 .72475 L .2552 .72645 L 0 1 .53 r
F
0 g
.2552 .72645 m
.25566 .73125 L
s
.51105 .95263 m .51057 .952 L .50933 .95208 L 0 .238 .27 r
F
.49187 .91346 m .4855 .90173 L .48192 .89772 L 0 .62 .4 r
F
0 g
.47936 .89283 m
.48192 .89772 L
s
.48726 .9112 m
.48931 .91323 L
s
.48837 .91278 m
.48994 .91502 L
s
.51974 .92711 m .52629 .89328 L .5238 .8996 L 0 .443 .263 r
F
.51974 .92711 m .52711 .89942 L .52629 .89328 L F
0 g
.52629 .89328 m
.52641 .89113 L
s
.52453 .89775 m
.52629 .89328 L
s
.51316 .94817 m .50484 .92655 L .50959 .93889 L 0 .406 .275 r
F
.51316 .94817 m .50959 .93889 L .50484 .92655 L 0 .406 .274 r
F
0 g
.50292 .92092 m
.50484 .92655 L
s
.50484 .92655 m
.50484 .92655 L
s
.50401 .92777 m
.50486 .92941 L
s
.51316 .94817 m .51258 .91278 L .51291 .93297 L 0 .374 .265 r
F
.51316 .94817 m .51291 .93297 L .51258 .91278 L 0 .364 .264 r
F
0 g
.51196 .89712 m
.51258 .91278 L
s
.51258 .91278 m
.5127 .89855 L
s
.51316 .94817 m .51516 .92035 L .51565 .90718 L 0 .392 .267 r
F
0 g
.51565 .90718 m
.51582 .90503 L
s
.51319 .89971 m
.51344 .91481 L
s
.5014 .93185 m .49309 .92271 L .4978 .92807 L 0 .466 .384 r
F
.50128 .93274 m .4978 .92807 L .49309 .92271 L 0 .472 .386 r
F
0 g
.49204 .9213 m
.49309 .92271 L
s
.48951 .91929 m
.49309 .92271 L
s
.37568 .81201 m .36582 .80735 L .36654 .81304 L 0 1 .472 r
F
0 g
.36175 .81599 m
.36654 .81304 L
s
.41276 .81959 m .40267 .81184 L .40357 .81744 L 0 1 .456 r
F
0 g
.39866 .81864 m
.40357 .81744 L
s
.71869 1.09605 m .72724 1.08394 L .73144 1.08395 L 0 0 0 r
F
0 g
.72041 1.08682 m
.72724 1.08394 L
s
.53561 .79933 m .53892 .79947 L .54259 .78869 L 0 1 .311 r
F
.54633 .85298 m .55469 .80501 L .55165 .80301 L 0 .85 .275 r
F
.54633 .85298 m .55517 .8237 L .55469 .80501 L F
0 g
.55469 .80501 m
.55874 .78851 L
s
.67684 .60719 m .69303 .6082 L .69639 .60685 L 0 1 .434 r
F
.67684 .60719 m .68467 .60835 L .69303 .6082 L F
0 g
.69303 .6082 m
.69576 .61041 L
s
.68467 .60835 m
.69303 .6082 L
s
.68467 .60835 m
.688 .61021 L
s
.41276 .81959 m .40559 .80733 L .40267 .81184 L 0 1 .456 r
F
0 g
.40267 .81184 m
.40357 .81744 L
s
.41276 .81959 m .41068 .80652 L .40559 .80733 L 0 1 .456 r
F
.41276 .81959 m .41453 .80994 L .41068 .80652 L F
.41276 .81959 m .41542 .81554 L .41453 .80994 L F
0 g
.41276 .81959 m
.41385 .82501 L
s
.40769 .8204 m
.41276 .81959 L
s
.46649 .86488 m .46304 .85245 L .45902 .84985 L 0 .946 .421 r
F
.46649 .86488 m .46656 .85798 L .46304 .85245 L F
.46649 .86488 m .46804 .86331 L .46656 .85798 L F
.47582 .87911 m .46804 .86331 L .46649 .86488 L 0 .853 .413 r
F
0 g
.46247 .86228 m
.46649 .86488 L
s
.46649 .86488 m
.4682 .87022 L
s
.47202 .87576 m
.47409 .88084 L
s
.51316 .94818 m .50315 .93789 L .50628 .9406 L 0 .301 .116 r
F
.51316 .94818 m .50289 .9386 L .50315 .93789 L F
0 g
.50305 .93779 m
.50315 .93789 L
s
.57772 .65126 m .57539 .64875 L .57387 .65159 L 0 1 .306 r
F
.44783 .84006 m .44094 .82614 L .43848 .82915 L 0 1 .435 r
F
.44783 .84006 m .44543 .8274 L .44094 .82614 L F
.44783 .84006 m .44896 .83209 L .44543 .8274 L F
.44783 .84006 m .44998 .83751 L .44896 .83209 L F
0 g
.44334 .8388 m
.44783 .84006 L
s
.44783 .84006 m
.44908 .84542 L
s
.55454 .67701 m .55185 .67335 L .55078 .67719 L 0 1 .384 r
F
.55454 .67701 m .55754 .66773 L .55185 .67335 L F
.55454 .67701 m .56405 .66409 L .55754 .66773 L F
0 g
.56405 .66409 m
.5681 .66072 L
s
.56405 .66409 m
.56779 .66393 L
s
.49977 .99497 m .49533 1.00171 L .4979 1.00308 L 0 .256 .274 r
F
0 g
.49533 1.00171 m
.49545 1.00675 L
s
.30785 .60435 m .29977 .60358 L .30335 .60535 L 0 1 .479 r
F
.30785 .60435 m .29897 .6 L .29977 .60358 L F
.30785 .60435 m .3015 .59701 L .29897 .6 L F
.30785 .60435 m .30601 .59601 L .3015 .59701 L F
.30785 .60435 m .30949 .59765 L .30601 .59601 L F
.30785 .60435 m .31028 .60123 L .30949 .59765 L F
0 g
.30785 .60435 m
.30871 .6082 L
s
.30335 .60535 m
.30785 .60435 L
s
.31028 .60123 m
.31471 .60024 L
s
.58185 .64457 m .59569 .63815 L .59765 .63592 L 0 1 .363 r
F
.58185 .64457 m .58892 .64185 L .59569 .63815 L F
0 g
.59569 .63815 m
.59922 .63796 L
s
.58892 .64185 m
.59275 .64153 L
s
.58892 .64185 m
.59569 .63815 L
s
.50167 .93606 m .50155 .93557 L .49797 .93216 L 0 .468 .388 r
F
0 g
.49954 .93592 m
.50049 .93668 L
s
.49967 .93587 m
.50059 .93645 L
s
.50024 .93506 m
.50035 .93514 L
s
.50035 .93514 m
.50099 .93558 L
s
.50099 .93558 m
.50138 .93586 L
s
.50079 .93587 m
.50111 .93615 L
s
.524 1.08429 m .52057 1.07807 L .51821 1.07395 L 0 0 .105 r
F
.28328 .73408 m .27734 .72474 L .27268 .72898 L 0 1 .516 r
F
.28328 .73408 m .28391 .72342 L .27734 .72474 L F
.28328 .73408 m .28801 .72593 L .28391 .72342 L F
.28328 .73408 m .28773 .7305 L .28801 .72593 L F
0 g
.27673 .73537 m
.28328 .73408 L
s
.28317 .73817 m
.28328 .73408 L
s
.41725 .78255 m
.41911 .78227 L
s
.75105 1.07082 m .75245 1.06888 L .75825 1.06414 L 0 0 0 r
F
.75105 1.07082 m .74826 1.07217 L .75245 1.06888 L F
0 g
.75214 1.06776 m
.75245 1.06888 L
s
.55283 .87189 m .5591 .81007 L .55517 .8237 L 0 .814 .263 r
F
.55283 .87189 m .56196 .81482 L .5591 .81007 L F
0 g
.55874 .78851 m
.5591 .81007 L
s
.55469 .80501 m
.55484 .81099 L
s
.53707 .69814 m .54803 .68805 L .54915 .68349 L 0 1 .421 r
F
.53707 .69814 m .54286 .69433 L .54803 .68805 L F
0 g
.54803 .68805 m
.55142 .6881 L
s
.42999 .92783 m .42158 .92456 L .42632 .9261 L 0 0 0 r
F
.42999 .92783 m .41816 .92372 L .42158 .92456 L F
0 g
.41821 .92313 m
.42158 .92456 L
s
.42632 .9261 m
.43002 .92674 L
s
.52716 .79969 m .53302 .77014 L .52914 .77199 L 0 1 .329 r
F
.52716 .79969 m .53509 .77789 L .53302 .77014 L F
0 g
.53302 .77014 m
.53442 .76675 L
s
.50165 .93109 m .494 .91984 L .49043 .91572 L 0 .456 .381 r
F
0 g
.48994 .91502 m
.49043 .91572 L
s
.49017 .91637 m
.49205 .91914 L
s
.37568 .81201 m .36886 .80149 L .36582 .80735 L 0 1 .472 r
F
.37568 .81201 m .374 .79871 L .36886 .80149 L F
.37568 .81201 m .37781 .80087 L .374 .79871 L F
.37568 .81201 m .37853 .80657 L .37781 .80087 L F
0 g
.37055 .81478 m
.37568 .81201 L
s
.32841 .81279 m .31805 .81055 L .31897 .81609 L 0 1 .501 r
F
0 g
.31426 .8202 m
.31897 .81609 L
s
.51316 .94818 m .50628 .9406 L .51021 .94493 L 0 .301 .116 r
F
.51316 .94818 m .51021 .94493 L .50628 .9406 L 0 .296 .115 r
F
.51316 .94818 m .51316 .94818 L .51021 .94493 L F
.51316 .94818 m .50233 .93592 L .50254 .93775 L 0 .372 .269 r
F
.51316 .94818 m .50546 .93862 L .50233 .93592 L F
0 g
.50352 .93552 m
.50412 .93648 L
s
.50228 .93585 m
.50233 .93592 L
s
.50217 .93851 m
.5024 .93864 L
s
.50241 .93838 m
.50269 .93851 L
s
.50235 .93771 m
.50254 .93775 L
s
.5016 .93755 m
.50235 .93771 L
s
.50235 .93771 m
.50235 .93771 L
s
.50235 .93771 m
.50235 .93771 L
s
.50201 .93962 m
.50278 .93997 L
s
.50193 .93885 m
.50246 .93924 L
s
.50357 .93686 m
.50381 .9372 L
s
.50305 .93654 m
.50352 .93694 L
s
.50237 .93595 m
.50305 .93654 L
s
.50233 .93592 m
.50237 .93595 L
s
.43848 .82915 m .42991 .82456 L .43375 .82847 L 0 1 .44 r
F
0 g
.43375 .82847 m
.43503 .83375 L
s
.64725 .80147 m
.64777 .79743 L
s
.64777 .79743 m
.64835 .79301 L
s
.65023 .77854 m
.65139 .76962 L
s
.65169 .76734 m
.65171 .76718 L
s
.64678 .80509 m
.64725 .80147 L
s
.54633 .85298 m .55165 .80301 L .54787 .81548 L 0 .85 .275 r
F
0 g
.55088 .78795 m
.55165 .80301 L
s
.51316 .94818 m .52029 .9351 L .51622 .94256 L 0 .302 .125 r
F
.51316 .94818 m .51622 .94256 L .52029 .9351 L 0 .298 .124 r
F
0 g
.52029 .9351 m
.52029 .9351 L
s
.52029 .9351 m
.52029 .9351 L
s
.48966 .94171 m .4816 .93803 L .48627 .93962 L 0 .283 .087 r
F
.48966 .94171 m .47795 .93783 L .4816 .93803 L F
.49019 .9388 m .48627 .93962 L .4816 .93803 L 0 .267 .086 r
F
0 g
.47799 .93783 m
.4816 .93803 L
s
.47839 .93587 m
.4816 .93803 L
s
.50385 .94706 m .50355 .94518 L .50039 .9427 L 0 .373 .28 r
F
.5163 .9592 m .51942 .96674 L .5191 .96518 L 0 .131 .19 r
F
0 g
.51942 .96674 m
.52118 .96902 L
s
.3556 .76488 m .3462 .76097 L .34597 .76103 L 0 .348 .194 r
F
0 g
.34053 .75983 m
.34597 .76103 L
s
.34979 .76262 m
.35518 .76472 L
s
.45383 .9334 m .44529 .93258 L .44186 .93059 L 0 .137 .01 r
F
.45383 .9334 m .45004 .93426 L .44529 .93258 L F
.45383 .9334 m .4537 .93461 L .45004 .93426 L F
.46566 .93732 m .4537 .93461 L .45383 .9334 L 0 .211 .043 r
F
0 g
.45383 .9334 m
.45747 .93364 L
s
.45039 .93141 m
.45383 .9334 L
s
.51226 .95421 m .51178 .95358 L .51089 .95399 L 0 .212 .247 r
F
.24181 .81647 m .23177 .82075 L .23637 .82136 L 0 1 .533 r
F
0 g
.23637 .82136 m
.23873 .82731 L
s
.51316 .94817 m .50486 .92942 L .5096 .94012 L 0 .406 .274 r
F
.51316 .94817 m .5096 .94012 L .50486 .92942 L 0 .402 .273 r
F
0 g
.50215 .92237 m
.50486 .92942 L
s
.50486 .92941 m
.50486 .92942 L
s
.50209 .9278 m
.50498 .93239 L
s
.51512 1.06556 m .51544 1.06897 L .51781 1.07238 L 0 0 .151 r
F
0 g
.51544 1.06897 m
.51821 1.07395 L
s
.45776 .84449 m
.45902 .84985 L
s
.45902 .84985 m
.46304 .85245 L
s
.51471 .95727 m .51641 .96214 L .51565 .95962 L 0 .161 .205 r
F
0 g
.51639 .96226 m
.51641 .96214 L
s
.51534 .95805 m .51565 .95962 L .51641 .96214 L 0 .14 .192 r
F
0 g
.51641 .96214 m
.51668 .96286 L
s
.53561 .79933 m .53509 .77789 L .53396 .79008 L 0 1 .311 r
F
.52716 .79969 m .53396 .79008 L .53509 .77789 L 0 1 .329 r
F
0 g
.53302 .77014 m
.53509 .77789 L
s
.53509 .77789 m
.53728 .77146 L
s
.60967 .62766 m .62452 .6238 L .6269 .62202 L 0 1 .365 r
F
.60967 .62766 m .61714 .62622 L .62452 .6238 L F
0 g
.62452 .6238 m
.62794 .62447 L
s
.26207 .72413 m .25142 .71954 L .25089 .72475 L 0 1 .53 r
F
0 g
.24477 .72736 m
.25089 .72475 L
s
.47795 .93783 m .47401 .93899 L .46928 .93745 L 0 .243 .067 r
F
.47795 .93783 m .47772 .93915 L .47401 .93899 L F
.48966 .94171 m .47772 .93915 L .47795 .93783 L 0 .283 .087 r
F
0 g
.47462 .9357 m
.47795 .93783 L
s
.47795 .93783 m
.47799 .93783 L
s
.49991 .96931 m .49911 .96615 L .49633 .96493 L 0 .303 .282 r
F
.50555 .95645 m .49723 .95827 L .49796 .96142 L 0 .319 .274 r
F
.50555 .95645 m .49914 .95508 L .49723 .95827 L F
0 g
.49422 .95639 m
.49723 .95827 L
s
.19767 .91746 m .18957 .91842 L .19422 .91909 L 0 .809 .352 r
F
0 g
.19422 .91909 m
.19873 .92178 L
s
.19767 .91746 m .18603 .91552 L .18957 .91842 L 0 .809 .352 r
F
0 g
.18717 .92036 m
.18957 .91842 L
s
.50142 .93485 m .50135 .9344 L .49775 .93068 L 0 .474 .389 r
F
0 g
.49775 .93068 m
.49781 .93074 L
s
.49775 .93068 m
.49784 .93077 L
s
.49835 .93373 m
.50079 .93587 L
s
.49835 .93373 m
.50024 .93506 L
s
.49797 .93216 m
.49892 .93291 L
s
.49892 .93291 m
.49902 .93298 L
s
.49902 .93298 m
.49905 .93301 L
s
.49905 .93301 m
.49992 .93368 L
s
.50036 .93403 m
.50093 .93448 L
s
.49797 .93216 m
.49925 .93338 L
s
.49925 .93338 m
.49948 .9336 L
s
.49948 .9336 m
.49982 .93392 L
s
.49982 .93392 m
.50042 .93449 L
s
.50042 .93449 m
.50098 .93502 L
s
.49019 .9388 m .48995 .93995 L .48627 .93962 L 0 .267 .086 r
F
.50166 .94341 m .49019 .9388 L .49378 .9394 L 0 .299 .101 r
F
0 g
.50039 .9427 m
.50064 .94289 L
s
.50166 .94341 m .48995 .93995 L .49019 .9388 L 0 .299 .101 r
F
0 g
.50152 .93879 m
.50182 .93905 L
s
.50039 .9427 m
.50099 .94263 L
s
.48696 .93664 m
.49019 .9388 L
s
.49019 .9388 m
.49043 .93884 L
s
.49043 .93884 m
.49122 .93897 L
s
.51316 .94818 m .50583 .94184 L .50289 .9386 L 0 .301 .116 r
F
0 g
.50269 .93851 m
.50289 .9386 L
s
.50299 .9413 m
.50363 .94153 L
s
.30949 .59765 m
.31028 .60123 L
s
.43848 .82915 m .42911 .81903 L .42991 .82456 L 0 1 .44 r
F
0 g
.42523 .82432 m
.42991 .82456 L
s
.82546 .8645 m .83794 .86718 L .83705 .86188 L 0 1 .509 r
F
0 g
.83512 .87171 m
.83794 .86718 L
s
.27466 .61411 m .26212 .6182 L .26601 .61975 L 0 1 .506 r
F
0 g
.26403 .62741 m
.26601 .61975 L
s
.81388 .86719 m .82634 .8694 L .82546 .8645 L 0 1 .5 r
F
0 g
.82351 .87365 m
.82634 .8694 L
s
.82634 .8694 m
.83047 .87248 L
s
.60444 .63281 m .60257 .63039 L .6006 .63259 L 0 1 .3 r
F
.60444 .63281 m .60967 .62766 L .60257 .63039 L F
.60444 .63281 m .61714 .62622 L .60967 .62766 L F
0 g
.61714 .62622 m
.62452 .6238 L
s
.61714 .62622 m
.62094 .62644 L
s
.54457 .99277 m
.5446 .99279 L
s
.54373 .99227 m
.54457 .99277 L
s
.54373 .99226 m
.54373 .99227 L
s
.54353 .99214 m
.54373 .99226 L
s
.54351 .99213 m
.54353 .99214 L
s
.43057 .78609 m .42182 .78385 L .42531 .78413 L 0 0 0 r
F
.50201 .97719 m .49518 .98073 L .49645 .98478 L 0 .283 .275 r
F
.50201 .97719 m .49611 .97588 L .49518 .98073 L F
0 g
.49234 .97892 m
.49518 .98073 L
s
.43848 .82915 m .43188 .81557 L .42911 .81903 L 0 1 .44 r
F
.43848 .82915 m .43661 .81624 L .43188 .81557 L F
.43848 .82915 m .44014 .82061 L .43661 .81624 L F
.43848 .82915 m .44094 .82614 L .44014 .82061 L F
0 g
.43848 .82915 m
.4395 .83457 L
s
.43375 .82847 m
.43848 .82915 L
s
.51974 .92711 m .5238 .8996 L .52131 .91418 L 0 .443 .263 r
F
.51867 .92084 m .52131 .91418 L .5238 .8996 L 0 .466 .264 r
F
0 g
.5238 .8996 m
.52501 .88465 L
s
.5238 .8996 m
.52453 .89775 L
s
.47582 .87911 m .47183 .86665 L .46804 .86331 L 0 .853 .413 r
F
.8023 .86994 m .81474 .87168 L .81388 .86719 L 0 1 .488 r
F
0 g
.81191 .87563 m
.81474 .87168 L
s
.81474 .87168 m
.81887 .87443 L
s
.40267 .81184 m .39355 .8106 L .39751 .81324 L 0 1 .458 r
F
0 g
.39751 .81324 m
.39866 .81864 L
s
.51316 .94818 m .50254 .93775 L .50583 .94184 L 0 .372 .269 r
F
0 g
.50254 .93775 m
.50256 .93778 L
s
.50363 .94153 m
.50378 .94159 L
s
.50305 .94174 m
.50423 .94246 L
s
.50289 .94057 m
.50338 .9409 L
s
.50278 .93997 m
.50304 .94009 L
s
.50245 .94256 m
.50515 .94403 L
s
.50261 .93935 m
.50272 .93943 L
s
.50246 .93924 m
.50261 .93935 L
s
.50254 .93775 m
.50254 .93775 L
s
.48514 .89468 m .47776 .88448 L .48158 .89057 L 0 .739 .403 r
F
0 g
.47936 .89283 m
.48058 .89404 L
s
.48514 .89468 m .47582 .87911 L .47776 .88448 L 0 .739 .403 r
F
.48303 .89648 m .48158 .89057 L .47776 .88448 L 0 .751 .41 r
F
0 g
.47674 .88165 m
.47776 .88448 L
s
.47409 .88084 m
.47776 .88448 L
s
.48303 .89648 m .48384 .89572 L .48158 .89057 L 0 .751 .41 r
F
.49306 .91239 m .48303 .89648 L .4855 .90173 L 0 .608 .395 r
F
.49306 .91239 m .48384 .89572 L .48303 .89648 L F
0 g
.48058 .89404 m
.48303 .89648 L
s
.48303 .89648 m
.48407 .89869 L
s
.40633 .91985 m .39839 .91697 L .3947 .91593 L 0 .348 .187 r
F
.40633 .91985 m .40311 .91868 L .39839 .91697 L F
.40633 .91985 m .40651 .91991 L .40311 .91868 L F
0 g
.4064 .91987 m
.40974 .92088 L
s
.41816 .92372 m .40651 .91991 L .40633 .91985 L 0 0 0 r
F
.4909 .9148 m .49126 .91424 L .48829 .90945 L 0 .63 .406 r
F
.39161 .66602 m .38159 .6708 L .38454 .66967 L 0 1 .314 r
F
.39161 .66602 m .38453 .66814 L .38159 .6708 L F
.39161 .66602 m .3914 .66346 L .38453 .66814 L F
.39161 .66602 m .39849 .65979 L .3914 .66346 L F
.39161 .66602 m .40106 .6596 L .39849 .65979 L F
.39161 .66602 m .3981 .66227 L .40106 .6596 L F
0 g
.38895 .66822 m
.39161 .66602 L
s
.38454 .66967 m
.39161 .66602 L
s
.50165 .93109 m .49344 .92119 L .49807 .92696 L 0 .456 .381 r
F
0 g
.49781 .93074 m
.49803 .93097 L
s
.5014 .93185 m .49807 .92696 L .49344 .92119 L 0 .466 .384 r
F
0 g
.49205 .91914 m
.49344 .92119 L
s
.48985 .91741 m
.49344 .92119 L
s
.49803 .93097 m
.49904 .93202 L
s
.49814 .93102 m
.49865 .93146 L
s
.49784 .93077 m
.49814 .93102 L
s
.55283 .87189 m .56206 .83978 L .56196 .81482 L 0 .814 .263 r
F
0 g
.56196 .81482 m
.56203 .83216 L
s
.56196 .81482 m
.56611 .79243 L
s
.75508 .81892 m .76747 .80123 L .76897 .80875 L 0 .188 .072 r
F
0 g
.76747 .80123 m
.77209 .79642 L
s
.51316 .94818 m .5245 .93487 L .52464 .93596 L 0 .291 .122 r
F
.51316 .94818 m .52103 .93828 L .5245 .93487 L F
0 g
.5245 .93487 m
.52517 .93326 L
s
.5207 .93658 m
.52406 .93235 L
s
.79073 .87274 m .80315 .87401 L .8023 .86994 L 0 1 .471 r
F
0 g
.8003 .87766 m
.80315 .87401 L
s
.80315 .87401 m
.80727 .87644 L
s
.47582 .87911 m .47534 .87269 L .47183 .86665 L 0 .853 .413 r
F
.47582 .87911 m .47705 .87803 L .47534 .87269 L F
.48514 .89468 m .47705 .87803 L .47582 .87911 L 0 .739 .403 r
F
0 g
.47202 .87576 m
.47582 .87911 L
s
.47582 .87911 m
.47674 .88165 L
s
.72177 .60093 m .73841 .60491 L .74212 .60385 L 0 1 .473 r
F
.72177 .60093 m .7297 .60367 L .73841 .60491 L F
0 g
.73841 .60491 m
.74079 .60814 L
s
.51316 .94817 m .51344 .91481 L .51328 .93385 L 0 .384 .266 r
F
.51316 .94817 m .51328 .93385 L .51344 .91481 L 0 .374 .265 r
F
0 g
.51344 .91481 m
.51344 .91481 L
s
.51344 .91481 m
.51393 .90166 L
s
.50202 .93048 m .4909 .9148 L .494 .91984 L 0 .445 .377 r
F
.50202 .93048 m .49126 .91424 L .4909 .9148 L F
0 g
.48931 .91323 m
.4909 .9148 L
s
.4909 .9148 m
.49239 .91722 L
s
.655 .56676 m .653 .55979 L .65031 .55684 L 0 .14 .21 r
F
0 g
.64976 .55616 m
.65031 .55684 L
s
.655 .56676 m .66203 .57399 L .653 .55979 L 0 .14 .21 r
F
.655 .56676 m .6714 .59001 L .66203 .57399 L F
.655 .56676 m .6761 .59996 L .6714 .59001 L F
.655 .56676 m .67298 .59719 L .6761 .59996 L F
.655 .56676 m .66394 .58296 L .67298 .59719 L F
0 g
.64771 .5542 m
.655 .56676 L
s
.65031 .55684 m
.655 .56676 L
s
.66985 .75004 m
.67 .75557 L
s
.6706 .77842 m
.6706 .77863 L
s
.67048 .77416 m
.6706 .77842 L
s
.50469 1.02564 m .5002 1.02715 L .5026 1.03243 L 0 .166 .237 r
F
.50469 1.02564 m .49929 1.02139 L .5002 1.02715 L F
0 g
.49754 1.02446 m
.5002 1.02715 L
s
.77916 .87561 m .79156 .87639 L .79073 .87274 L 0 1 .45 r
F
0 g
.7887 .87975 m
.79156 .87639 L
s
.79156 .87639 m
.79566 .87849 L
s
.79091 1.03138 m .78822 1.03729 L .78948 1.03957 L 0 1 .335 r
F
0 g
.78331 1.04502 m
.78948 1.03957 L
s
.51316 .94818 m .50433 .94252 L .50467 .94313 L 0 .3 .328 r
F
0 g
.50365 .94444 m
.50581 .94546 L
s
.50365 .94444 m
.50543 .94466 L
s
.50515 .94403 m
.50515 .94403 L
s
.51316 .94818 m .5068 .94389 L .50433 .94252 L 0 .3 .328 r
F
0 g
.50423 .94246 m
.50433 .94252 L
s
.50245 .94256 m
.50467 .94313 L
s
.51316 .94818 m .50467 .94313 L .50738 .94496 L 0 .3 .328 r
F
0 g
.50467 .94313 m
.50468 .94314 L
s
.50467 .94313 m
.50467 .94313 L
s
.36582 .80735 m .35651 .80903 L .36053 .81058 L 0 1 .475 r
F
0 g
.36053 .81058 m
.36175 .81599 L
s
.51316 .94818 m .50386 .94161 L .5068 .94389 L 0 .308 .333 r
F
.51316 .94818 m .50356 .94102 L .50386 .94161 L F
0 g
.50378 .94159 m
.50386 .94161 L
s
.50433 .94252 m
.50436 .94254 L
s
.50468 .94314 m
.50471 .94316 L
s
.51316 .94818 m .50519 .94406 L .50556 .94468 L 0 .29 .322 r
F
0 g
.50496 .94634 m
.50648 .94694 L
s
.50496 .94634 m
.50625 .94627 L
s
.51316 .94818 m .50738 .94496 L .50519 .94406 L 0 .29 .322 r
F
0 g
.50515 .94403 m
.50519 .94406 L
s
.51316 .94818 m .50628 .94285 L .50356 .94102 L 0 .308 .333 r
F
0 g
.50519 .94406 m
.50522 .94407 L
s
.50543 .94466 m
.50556 .94468 L
s
.50338 .9409 m
.50356 .94102 L
s
.50386 .94161 m
.50396 .94169 L
s
.50471 .94316 m
.50477 .9432 L
s
.50254 .93968 m .50232 .94041 L .49887 .9392 L 0 .276 .1 r
F
0 g
.50243 .94005 m
.50246 .94008 L
s
.50246 .94008 m
.50246 .94008 L
s
.50246 .94008 m
.50246 .94008 L
s
.5302 .97957 m
.53051 .97995 L
s
.53068 .98015 m
.53117 .98075 L
s
.52925 .97841 m
.5293 .97846 L
s
.5293 .97846 m
.5302 .97957 L
s
.53134 .98095 m
.5314 .98103 L
s
.53128 .98088 m
.53134 .98095 L
s
.51316 .94818 m .50556 .94468 L .50803 .94606 L 0 .29 .322 r
F
0 g
.50556 .94468 m
.50558 .94469 L
s
.50581 .94546 m
.5061 .9456 L
s
.5061 .9456 m
.5061 .9456 L
s
.5061 .9456 m
.5061 .9456 L
s
.50556 .94468 m
.50556 .94468 L
s
.51534 .95805 m .51705 .96286 L .51614 .96019 L 0 .14 .192 r
F
0 g
.51705 .96286 m
.51738 .96411 L
s
.5163 .9592 m .51614 .96019 L .51705 .96286 L 0 .131 .19 r
F
0 g
.51705 .96286 m
.51845 .96567 L
s
.26469 .81964 m .25581 .81108 L .25325 .81807 L 0 1 .529 r
F
.26469 .81964 m .26113 .80637 L .25581 .81108 L F
.26469 .81964 m .26564 .8071 L .26113 .80637 L F
.26469 .81964 m .26716 .81279 L .26564 .8071 L F
0 g
.25939 .82432 m
.26469 .81964 L
s
.26469 .81964 m
.26629 .8252 L
s
.76759 .87855 m .77997 .87883 L .77916 .87561 L 0 1 .422 r
F
0 g
.7771 .88188 m
.77997 .87883 L
s
.77997 .87883 m
.78406 .88059 L
s
.51316 .94818 m .50314 .94014 L .50628 .94285 L 0 .314 .337 r
F
.51316 .94818 m .50289 .93956 L .50314 .94014 L F
0 g
.50304 .94009 m
.50314 .94014 L
s
.5061 .9456 m
.50613 .94562 L
s
.51316 .94817 m .51316 .94817 L .51374 .94092 L 0 .31 .115 r
F
.51316 .94817 m .51637 .90996 L .51516 .92035 L 0 .397 .267 r
F
.51316 .94817 m .51316 .94817 L .51385 .94088 L 0 .312 .116 r
F
.51316 .94817 m .51684 .91194 L .51637 .90996 L 0 .397 .267 r
F
0 g
.51637 .90996 m
.51686 .89227 L
s
.63419 .6203 m .6342 .61649 L .63105 .61888 L 0 1 .356 r
F
.63419 .6203 m .64242 .61465 L .6342 .61649 L F
.63419 .6203 m .65022 .6146 L .64242 .61465 L F
.24181 .81647 m .23035 .81483 L .23177 .82075 L 0 1 .533 r
F
0 g
.22719 .82595 m
.23177 .82075 L
s
.49306 .91239 m .4855 .90173 L .48959 .90797 L 0 .608 .395 r
F
0 g
.48829 .90945 m
.48984 .91195 L
s
.49187 .91346 m .48959 .90797 L .4855 .90173 L 0 .62 .4 r
F
0 g
.48192 .89772 m
.4855 .90173 L
s
.48407 .89869 m
.4855 .90173 L
s
.48984 .91195 m
.4909 .91366 L
s
.52404 .97211 m .52314 .97104 L .52386 .972 L 0 0 .133 r
F
.71869 1.09605 m .71473 1.09463 L .71548 1.09068 L 0 0 0 r
F
0 g
.71473 1.09463 m
.71548 1.09068 L
s
.70817 1.09203 m
.71548 1.09068 L
s
.51316 .94818 m .50614 .94562 L .50654 .94625 L 0 .28 .315 r
F
.51316 .94818 m .50803 .94606 L .50614 .94562 L F
0 g
.50613 .94562 m
.50614 .94562 L
s
.50614 .94562 m
.50615 .94562 L
s
.51754 .9151 m .518 .91733 L .51989 .90585 L 0 .481 .265 r
F
0 g
.51765 .91307 m
.51808 .90481 L
s
.36852 .67617 m .35785 .69087 L .36131 .68356 L 0 0 0 r
F
.36852 .67617 m .36026 .68989 L .35785 .69087 L F
.3581 .69168 m .35698 .67835 L .35019 .67477 L 0 .837 .463 r
F
.35239 .6817 m .35222 .68834 L .34815 .67929 L 0 .652 .056 r
F
.35222 .68834 m .35221 .6889 L .34859 .68034 L F
.35222 .68834 m .34859 .68034 L .34815 .67929 L F
.36025 .69003 m .358 .69287 L .35773 .69325 L 0 1 .396 r
F
.358 .69287 m .35794 .69295 L .35773 .69325 L F
.35239 .6817 m .35402 .68992 L .35221 .6889 L 0 .652 .056 r
F
.35742 .69365 m .34815 .67941 L .3522 .68917 L 0 .837 .463 r
F
.35794 .69295 m .34815 .67941 L .35742 .69365 L F
.35794 .69295 m .34743 .70623 L .35763 .69338 L 0 1 .396 r
F
.35794 .69295 m .35763 .69338 L .35773 .69325 L F
.35239 .6817 m .34815 .67929 L .34382 .66583 L 0 .652 .056 r
F
.35794 .69295 m .3495 .70027 L .34743 .70623 L 0 1 .396 r
F
.36025 .69003 m .35823 .69195 L .35794 .69295 L F
.35794 .69295 m .35019 .67477 L .34816 .67938 L 0 .837 .463 r
F
.35804 .69281 m .35019 .67477 L .35794 .69295 L F
.3584 .69232 m .35823 .69195 L .35804 .69281 L F
.35823 .69195 m .35019 .67477 L .35804 .69281 L F
.3601 .69595 m .34816 .67938 L .34821 .67949 L F
.35823 .69195 m .35676 .68676 L .3495 .70027 L 0 1 .396 r
F
.36025 .69003 m .35893 .68879 L .35823 .69195 L F
.35823 .69195 m .35881 .68868 L .3581 .69168 L 0 .837 .463 r
F
.35893 .68879 m .35881 .68868 L .35823 .69195 L 0 1 .396 r
F
.3584 .69232 m .35881 .68868 L .35823 .69195 L 0 .837 .463 r
F
.35881 .68868 m .35698 .67835 L .3581 .69168 L F
.35881 .68868 m .35676 .68676 L .35823 .69195 L 0 1 .396 r
F
.35823 .69195 m .3495 .70027 L .35794 .69295 L F
.3601 .69595 m .3584 .69232 L .35794 .69295 L 0 .837 .463 r
F
.34821 .67949 m .34816 .67938 L .34815 .67941 L F
.35773 .69325 m .35749 .69356 L .35742 .69365 L 0 1 .396 r
F
.3601 .69595 m .35794 .69295 L .35742 .69365 L 0 .837 .463 r
F
.35742 .69365 m .34743 .70623 L .3519 .7007 L 0 1 .396 r
F
.35749 .69356 m .34743 .70623 L .35742 .69365 L F
.3601 .69595 m .35925 .69114 L .3584 .69232 L 0 .837 .463 r
F
.35925 .69114 m .35881 .68868 L .3584 .69232 L F
.36022 .68999 m .36513 .67608 L .36079 .68162 L 0 1 .396 r
F
.36852 .67617 m .36726 .68022 L .36026 .68989 L 0 0 0 r
F
.36726 .68022 m .36069 .68934 L .36026 .68989 L F
.36031 .68986 m .36513 .67608 L .36022 .68999 L 0 1 .396 r
F
.36726 .68022 m .36694 .68126 L .36069 .68934 L 0 0 0 r
F
.36852 .67617 m .37418 .67384 L .36694 .68126 L F
.36852 .67617 m .37715 .67259 L .37418 .67384 L F
.36852 .67617 m .37472 .67359 L .37715 .67259 L F
.36025 .69003 m .36903 .67533 L .36513 .67608 L 0 1 .396 r
F
.36025 .69003 m .36694 .68132 L .36903 .67533 L F
.3601 .69595 m .36491 .68514 L .36079 .68162 L 0 .837 .463 r
F
.35881 .68868 m .36079 .68162 L .35698 .67835 L F
.36022 .68999 m .36079 .68162 L .36033 .68327 L 0 1 .396 r
F
.36022 .68999 m .36035 .68218 L .35881 .68868 L F
.36025 .69003 m .36031 .68986 L .36022 .68999 L F
.3601 .69595 m .36079 .68162 L .35881 .68868 L 0 .837 .463 r
F
.36033 .68327 m .36079 .68162 L .36035 .68218 L 0 1 .396 r
F
.35881 .68868 m .36035 .68218 L .35676 .68676 L F
0 g
.36204 .68003 m
.36258 .67747 L
s
.51316 .94818 m .50583 .94184 L .50289 .93956 L 0 .314 .337 r
F
0 g
.50625 .94627 m
.50654 .94625 L
s
.50272 .93943 m
.50289 .93956 L
s
.5057 .94476 m
.50572 .94477 L
s
.50558 .94469 m
.5057 .94476 L
s
.50356 .94102 m
.50372 .94112 L
s
.7519 .64668 m .76675 .63561 L .77073 .63421 L 0 0 0 r
F
.7519 .64668 m .75869 .64093 L .76675 .63561 L F
0 g
.76675 .63561 m
.76794 .63238 L
s
.76642 .63582 m
.76675 .63561 L
s
.53513 .71163 m .54286 .69433 L .53707 .69814 L 0 1 .402 r
F
0 g
.54286 .69433 m
.54803 .68805 L
s
.54286 .69433 m
.54637 .69549 L
s
.53569 .98663 m .54316 .99192 L .54202 .99179 L 0 .255 0 r
F
0 g
.54316 .99192 m
.54351 .99213 L
s
.53952 .84139 m .54699 .80093 L .5438 .80016 L 0 .88 .289 r
F
0 g
.54053 .81042 m
.54059 .8311 L
s
.53952 .84139 m .54787 .81548 L .54699 .80093 L 0 .88 .289 r
F
0 g
.53724 .81499 m
.54028 .83405 L
s
.54699 .80093 m
.55088 .78795 L
s
.51316 .94818 m .50654 .94625 L .50874 .94716 L 0 .28 .315 r
F
0 g
.50654 .94625 m
.50655 .94626 L
s
.50654 .94625 m
.50654 .94625 L
s
.64882 .81518 m
.6491 .81376 L
s
.51512 1.06556 m .51217 1.05968 L .50981 1.05629 L 0 0 .151 r
F
.75602 .88154 m .76838 .88133 L .76759 .87855 L 0 1 .387 r
F
0 g
.7655 .88408 m
.76838 .88133 L
s
.76838 .88133 m
.77246 .88275 L
s
.50166 .94341 m .49378 .9394 L .49833 .94136 L 0 .299 .101 r
F
.50204 .94152 m .49833 .94136 L .49378 .9394 L 0 .287 .101 r
F
0 g
.4922 .93825 m
.49378 .9394 L
s
.49122 .93897 m
.49378 .9394 L
s
.51316 .94818 m .51002 .94546 L .50583 .94184 L 0 .301 .116 r
F
.51316 .94818 m .50583 .94184 L .51002 .94546 L 0 .372 .269 r
F
.51316 .94818 m .51316 .94818 L .51002 .94546 L 0 .301 .116 r
F
.51316 .94818 m .50254 .93871 L .50583 .94184 L 0 .319 .34 r
F
.51316 .94818 m .50233 .93816 L .50254 .93871 L F
0 g
.5024 .93864 m
.50254 .93871 L
s
.50396 .94169 m
.50424 .94191 L
s
.50289 .9386 m
.50335 .93911 L
s
.50648 .94694 m
.50713 .9472 L
s
.53513 .71163 m .53224 .70507 L .5316 .71048 L 0 1 .402 r
F
.53513 .71163 m .53707 .69814 L .53224 .70507 L F
.49994 1.01358 m .49929 1.02139 L .50046 1.01898 L 0 .217 .264 r
F
.50469 1.02564 m .50046 1.01898 L .49929 1.02139 L 0 .166 .237 r
F
0 g
.49929 1.02139 m
.5002 1.02715 L
s
.49667 1.01931 m
.49929 1.02139 L
s
.51349 .95576 m .513 .95514 L .51247 .95589 L 0 .186 .225 r
F
.46959 .86178 m .46304 .85245 L .46656 .85798 L 0 .95 .418 r
F
.46959 .86178 m .46087 .84784 L .46304 .85245 L F
0 g
.46656 .85798 m
.46804 .86331 L
s
.46656 .85798 m
.46656 .85798 L
s
.51316 .94817 m .50498 .93239 L .50965 .9414 L 0 .402 .273 r
F
.51316 .94817 m .50965 .9414 L .50498 .93239 L 0 .394 .272 r
F
0 g
.50498 .93239 m
.50498 .93239 L
s
.50255 .9269 m
.50498 .93239 L
s
.50263 .93231 m
.50518 .93547 L
s
.50713 .9472 m
.50714 .9472 L
s
.50714 .9472 m
.50714 .9472 L
s
.32841 .81279 m .32101 .804 L .31805 .81055 L 0 1 .501 r
F
.32841 .81279 m .32627 .79983 L .32101 .804 L F
.32841 .81279 m .33032 .80081 L .32627 .79983 L F
.32841 .81279 m .33123 .80637 L .33032 .80081 L F
0 g
.32841 .81279 m
.32943 .81832 L
s
.32316 .81695 m
.32841 .81279 L
s
.2093 .91945 m .20119 .92011 L .20583 .9208 L 0 .739 .325 r
F
0 g
.20583 .9208 m
.2103 .92323 L
s
.2093 .91945 m .19767 .91746 L .20119 .92011 L 0 .739 .325 r
F
0 g
.19873 .92178 m
.20119 .92011 L
s
.50129 .93374 m .50127 .93333 L .49769 .92931 L 0 .475 .388 r
F
0 g
.49982 .93248 m
.49986 .93251 L
s
.49908 .93183 m
.49982 .93248 L
s
.49865 .93146 m
.49908 .93183 L
s
.49992 .93368 m
.50036 .93403 L
s
.49904 .93202 m
.49984 .93284 L
s
.49984 .93284 m
.50056 .93359 L
s
.49991 .96931 m .49611 .97588 L .49862 .97348 L 0 .303 .282 r
F
.50201 .97719 m .49862 .97348 L .49611 .97588 L 0 .283 .275 r
F
0 g
.49518 .98073 m
.49611 .97588 L
s
.49332 .97465 m
.49611 .97588 L
s
.51316 .94818 m .50717 .94721 L .50759 .94785 L 0 .269 .307 r
F
.51316 .94818 m .50874 .94716 L .50717 .94721 L F
0 g
.50714 .9472 m
.50717 .94721 L
s
.50202 .93048 m .49477 .9187 L .49126 .91424 L 0 .445 .377 r
F
0 g
.4909 .91366 m
.49126 .91424 L
s
.51316 .94818 m .50546 .94087 L .50233 .93816 L 0 .319 .34 r
F
0 g
.50209 .93797 m
.50233 .93816 L
s
.50436 .94254 m
.5047 .94273 L
s
.5047 .94273 m
.50481 .94279 L
s
.49977 .99497 m .49842 .99089 L .49585 .98953 L 0 .256 .274 r
F
.46087 .84784 m .45424 .83941 L .45776 .84449 L 0 1 .425 r
F
.74446 .88461 m .7568 .88389 L .75602 .88154 L 0 1 .344 r
F
0 g
.75389 .88634 m
.7568 .88389 L
s
.7568 .88389 m
.76086 .88497 L
s
.31805 .81055 m .30849 .8141 L .31269 .81487 L 0 1 .507 r
F
0 g
.31269 .81487 m
.31426 .8202 L
s
.52009 .7549 m .52834 .74457 L .529 .73679 L 0 1 .377 r
F
0 g
.5294 .75234 m
.53113 .74814 L
s
.52009 .7549 m .52453 .75233 L .52834 .74457 L 0 1 .377 r
F
0 g
.52834 .74457 m
.53113 .74814 L
s
.40267 .81184 m .39296 .80489 L .39355 .8106 L 0 1 .458 r
F
0 g
.3886 .81237 m
.39355 .8106 L
s
.49306 .91239 m .48731 .90013 L .48384 .89572 L 0 .608 .395 r
F
0 g
.48384 .89572 m
.48647 .89906 L
s
.48158 .89057 m
.48384 .89572 L
s
.48829 .90945 m
.49089 .91237 L
s
.46087 .84784 m .45215 .83503 L .45424 .83941 L 0 1 .425 r
F
.46087 .84784 m .45288 .83426 L .45215 .83503 L F
.46087 .84784 m .45599 .83761 L .45288 .83426 L F
0 g
.45188 .83836 m
.45424 .83941 L
s
.44998 .83751 m
.45188 .83836 L
s
.46087 .84784 m .45941 .84284 L .45599 .83761 L 0 1 .425 r
F
.46087 .84784 m .4615 .84722 L .45941 .84284 L F
.46959 .86178 m .4615 .84722 L .46087 .84784 L 0 .95 .418 r
F
0 g
.45776 .84449 m
.46087 .84784 L
s
.46087 .84784 m
.46304 .85245 L
s
.51316 .94818 m .50759 .94785 L .50949 .94828 L 0 .269 .307 r
F
0 g
.50759 .94785 m
.50761 .94785 L
s
.50635 .94825 m
.50759 .94785 L
s
.50635 .94825 m
.50822 .94879 L
s
.40267 .81184 m .39614 .7999 L .39296 .80489 L 0 1 .458 r
F
.40267 .81184 m .4013 .7985 L .39614 .7999 L F
.40267 .81184 m .40501 .80161 L .4013 .7985 L F
.40267 .81184 m .40559 .80733 L .40501 .80161 L F
0 g
.39751 .81324 m
.40267 .81184 L
s
.72369 .66496 m .73928 .65018 L .73306 .65835 L 0 0 .011 r
F
0 g
.73928 .65018 m
.74641 .6434 L
s
.73928 .65018 m
.74095 .64533 L
s
.7382 .67595 m
.73846 .66446 L
s
.42911 .81903 m .4203 .81525 L .42415 .81889 L 0 1 .445 r
F
0 g
.42415 .81889 m
.42523 .82432 L
s
.51316 .94818 m .50205 .93735 L .50546 .94087 L 0 .321 .341 r
F
0 g
.50256 .93778 m
.50284 .93813 L
s
.51316 .94818 m .50188 .93683 L .50205 .93735 L 0 .321 .341 r
F
0 g
.50185 .93723 m
.50205 .93735 L
s
.5029 .93906 m
.5029 .93906 L
s
.5029 .93906 m
.5029 .93906 L
s
.50254 .93871 m
.5029 .93906 L
s
.50246 .94008 m
.50283 .94047 L
s
.50283 .94047 m
.50283 .94047 L
s
.50283 .94047 m
.50283 .94047 L
s
.52404 .97211 m .52873 .97777 L .52643 .975 L 0 0 .133 r
F
.52619 .97477 m .52643 .975 L .52873 .97777 L 0 .101 0 r
F
0 g
.52873 .97777 m
.52925 .97841 L
s
.52009 .7549 m .529 .73679 L .52579 .73328 L 0 1 .377 r
F
0 g
.52568 .74998 m
.52834 .74457 L
s
.529 .73679 m
.53312 .72822 L
s
.51747 .96061 m .52084 .96836 L .52177 .96943 L 0 .113 .186 r
F
.51747 .96061 m .5191 .96518 L .52084 .96836 L F
0 g
.52084 .96836 m
.52118 .96902 L
s
.51915 .96544 m
.51942 .96674 L
s
.29372 .60292 m
.29439 .60103 L
s
.29153 .60912 m
.29372 .60292 L
s
.29894 .60414 m
.29977 .60358 L
s
.29153 .60912 m
.29894 .60414 L
s
.46959 .86178 m .46453 .85103 L .4615 .84722 L 0 .95 .418 r
F
.46959 .86178 m .46794 .85672 L .46453 .85103 L F
.46959 .86178 m .47011 .86133 L .46794 .85672 L F
.47829 .87699 m .46959 .86178 L .47183 .86665 L 0 .856 .41 r
F
.47829 .87699 m .47011 .86133 L .46959 .86178 L F
0 g
.46804 .86331 m
.47183 .86665 L
s
.46656 .85798 m
.46959 .86178 L
s
.48514 .89468 m .48061 .88213 L .47705 .87803 L 0 .739 .403 r
F
.55754 .66773 m .57158 .65602 L .56752 .65612 L 0 1 .407 r
F
0 g
.57158 .65602 m
.57772 .65126 L
s
.47829 .87699 m .47183 .86665 L .47534 .87269 L 0 .856 .41 r
F
0 g
.46959 .86178 m
.47183 .86665 L
s
.51316 .94818 m .5068 .94389 L .51043 .94634 L 0 .308 .333 r
F
.51316 .94818 m .51043 .94634 L .5068 .94389 L 0 .3 .328 r
F
.51316 .94818 m .51316 .94818 L .51043 .94634 L F
.51316 .94818 m .50289 .94052 L .50314 .94238 L 0 .358 .267 r
F
.51316 .94818 m .50628 .94285 L .51021 .94589 L 0 .314 .337 r
F
.51316 .94818 m .51021 .94589 L .50628 .94285 L 0 .308 .333 r
F
.51316 .94818 m .51316 .94818 L .51021 .94589 L F
.51316 .94818 m .50583 .94184 L .50289 .94052 L 0 .358 .267 r
F
0 g
.50283 .94047 m
.50289 .94052 L
s
.50465 .95176 m .49914 .95508 L .50243 .95399 L 0 .345 .277 r
F
.50555 .95645 m .50243 .95399 L .49914 .95508 L 0 .319 .274 r
F
0 g
.49723 .95827 m
.49914 .95508 L
s
.49618 .95354 m
.49914 .95508 L
s
.82935 .9893 m .83425 1.00036 L .83891 .99185 L 0 1 .46 r
F
.82935 .9893 m .82978 1.00274 L .83425 1.00036 L F
0 g
.83425 1.00036 m
.83521 1.00434 L
s
.73026 .88851 m .74521 .88653 L .74446 .88461 L 0 1 .285 r
F
0 g
.7415 .88886 m
.74521 .88653 L
s
.53707 .69814 m .54915 .68349 L .54529 .68278 L 0 1 .421 r
F
0 g
.54915 .68349 m
.55454 .67701 L
s
.66948 1.10208 m .67933 1.10181 L .67574 1.10435 L 0 .184 .05 r
F
.51316 .94818 m .50517 .93995 L .50188 .93683 L 0 .321 .341 r
F
0 g
.50522 .94407 m
.50576 .94429 L
s
.50153 .93652 m
.50188 .93683 L
s
.50182 .93905 m
.50247 .93962 L
s
.50247 .93962 m
.50248 .93962 L
s
.50555 .95645 m .49796 .96142 L .50071 .96201 L 0 .319 .274 r
F
0 g
.49633 .96493 m
.49796 .96142 L
s
.51316 .94818 m .50825 .9488 L .5087 .94944 L 0 .258 .3 r
F
.51316 .94818 m .50949 .94828 L .50825 .9488 L F
0 g
.50822 .94879 m
.50825 .9488 L
s
.62475 .70143 m .62552 .69855 L .62266 .69475 L 0 .08 .182 r
F
0 g
.62266 .69475 m
.62415 .69953 L
s
.62179 .69347 m
.62266 .69475 L
s
.62475 .70143 m .63216 .71109 L .62552 .69855 L 0 .08 .182 r
F
.62475 .70143 m .63816 .72402 L .63216 .71109 L F
.62475 .70143 m .64024 .73071 L .63816 .72402 L F
.62475 .70143 m .63702 .72669 L .64024 .73071 L F
.62475 .70143 m .63038 .71414 L .63702 .72669 L F
0 g
.63286 .72123 m
.63388 .72392 L
s
.63218 .71941 m
.63286 .72123 L
s
.63038 .71414 m
.63104 .71609 L
s
.63104 .71609 m
.63218 .71941 L
s
.6201 .69162 m
.62475 .70143 L
s
.62415 .69953 m
.62475 .70143 L
s
.37056 .54571 m .35856 .55074 L .36132 .55135 L 0 1 .416 r
F
0 g
.35671 .55907 m
.36132 .55135 L
s
.37056 .54571 m .36397 .54435 L .35856 .55074 L 0 1 .416 r
F
.37056 .54571 m .37397 .53643 L .36397 .54435 L F
.37056 .54571 m .38322 .53079 L .37397 .53643 L F
.37056 .54571 m .38556 .53119 L .38322 .53079 L F
.37056 .54571 m .38013 .53759 L .38556 .53119 L F
0 g
.36546 .55206 m
.37056 .54571 L
s
.36132 .55135 m
.37056 .54571 L
s
.38013 .53759 m
.38905 .53162 L
s
.51316 .94818 m .5207 .93658 L .5164 .9432 L 0 .298 .124 r
F
.51316 .94818 m .5164 .9432 L .5207 .93658 L 0 .294 .123 r
F
0 g
.5207 .93658 m
.5207 .93658 L
s
.5207 .93658 m
.52374 .931 L
s
.45941 .84284 m
.4615 .84722 L
s
.4615 .84722 m
.46453 .85103 L
s
.52914 .77199 m .52737 .75729 L .52671 .76648 L 0 1 .343 r
F
.52716 .79969 m .52914 .77199 L .52574 .78132 L 0 1 .329 r
F
.36582 .80735 m .35593 .80317 L .35651 .80903 L 0 1 .475 r
F
0 g
.3516 .81234 m
.35651 .80903 L
s
.51316 .94818 m .51002 .94546 L .50583 .94184 L 0 .314 .337 r
F
.51316 .94818 m .51002 .94546 L .50583 .94184 L 0 .358 .267 r
F
.51316 .94818 m .51316 .94818 L .51002 .94546 L F
.51316 .94818 m .50254 .93968 L .50583 .94184 L 0 .307 .118 r
F
.51316 .94818 m .50232 .94041 L .50254 .93968 L F
0 g
.50248 .93962 m
.50254 .93968 L
s
.53479 .98439 m
.53529 .98482 L
s
.53423 .98392 m
.53479 .98439 L
s
.53381 .98357 m
.53423 .98392 L
s
.53364 .98342 m
.53381 .98357 L
s
.53299 .98287 m
.53364 .98342 L
s
.53297 .98285 m
.53299 .98287 L
s
.53288 .98277 m
.53297 .98285 L
s
.53288 .98277 m
.53288 .98277 L
s
.53287 .98276 m
.53288 .98277 L
s
.53267 .98259 m
.53287 .98276 L
s
.53569 .98663 m .53451 .98499 L .53566 .98513 L 0 .255 0 r
F
0 g
.53451 .98499 m
.53467 .98501 L
s
.53467 .98501 m
.53471 .98502 L
s
.53471 .98502 m
.53489 .98504 L
s
.53489 .98504 m
.53515 .98507 L
s
.53515 .98507 m
.53543 .9851 L
s
.53543 .9851 m
.53566 .98513 L
s
.53529 .98482 m
.53566 .98513 L
s
.50866 1.04588 m .50777 1.05104 L .51012 1.05369 L 0 .081 .187 r
F
0 g
.50777 1.05104 m
.50981 1.05629 L
s
.43057 .78609 m .42211 .78535 L .42182 .78385 L 0 0 0 r
F
.43043 .79698 m .42757 .78751 L .42209 .78661 L 0 1 .441 r
F
.42757 .78751 m .42751 .7873 L .42673 .7872 L F
.42757 .78751 m .42673 .7872 L .42209 .78661 L F
.42751 .7873 m .42685 .78708 L .42624 .78702 L F
.42673 .7872 m .42624 .78702 L .42209 .78661 L F
.42751 .7873 m .42624 .78702 L .42673 .7872 L F
.42747 .78714 m .42287 .7858 L .42209 .78661 L F
.43057 .78609 m .4275 .78713 L .42211 .78535 L 0 0 0 r
F
.4275 .78713 m .42747 .78714 L .42696 .78698 L F
.4275 .78713 m .42696 .78698 L .42211 .78535 L F
.42211 .78535 m .41332 .78275 L .41668 .78326 L F
.42211 .78535 m .42088 .78515 L .41332 .78275 L F
.4171 .79201 m .41663 .7869 L .41331 .78318 L 0 1 .447 r
F
.42209 .7866 m .41332 .78317 L .41663 .7869 L 0 1 .444 r
F
.42209 .7866 m .42088 .78515 L .41332 .78317 L F
.42088 .78515 m .42088 .78515 L .41336 .78282 L 0 0 0 r
F
.42088 .78515 m .41336 .78282 L .41336 .78282 L F
.42088 .78515 m .41336 .78282 L .41332 .78275 L F
.41725 .78255 m .41037 .78121 L .41382 .78171 L F
.41725 .78255 m .40868 .7813 L .41037 .78121 L F
.4171 .79201 m .41021 .78194 L .40865 .78294 L 0 1 .447 r
F
.41725 .78255 m .41021 .78194 L .40868 .7813 L 0 0 0 r
F
.41021 .78194 m .40989 .78148 L .40964 .78178 L 0 1 .447 r
F
.41021 .78194 m .40964 .78178 L .40865 .78294 L F
.41021 .78194 m .41019 .78193 L .41018 .78193 L 0 0 0 r
F
.40857 .78149 m .40989 .78148 L .40834 .77766 L 0 1 .448 r
F
.40865 .78294 m .40964 .78178 L .40857 .78149 L F
.4102 .78193 m .41017 .78192 L .40868 .7813 L 0 0 0 r
F
.41019 .78193 m .40965 .78179 L .40868 .7813 L F
.40964 .78178 m .40989 .78148 L .40857 .78149 L 0 1 .448 r
F
.41021 .78194 m .41018 .78193 L .41017 .78192 L 0 0 0 r
F
.41021 .78194 m .41017 .78192 L .4102 .78193 L F
.41019 .78193 m .40989 .78191 L .40965 .78179 L F
.42088 .78515 m .42052 .78472 L .41336 .78282 L 0 1 .444 r
F
.41725 .78255 m .41332 .78275 L .41161 .78233 L 0 0 0 r
F
.4171 .79201 m .41161 .78233 L .41021 .78194 L 0 1 .447 r
F
.41021 .78194 m .41161 .78233 L .40989 .78191 L 0 0 0 r
F
.41725 .78255 m .41161 .78233 L .41021 .78194 L F
.4171 .79201 m .41331 .78318 L .41161 .78233 L 0 1 .447 r
F
.41021 .78194 m .41161 .78233 L .40989 .78148 L F
.41725 .78255 m .41668 .78326 L .41332 .78275 L 0 0 0 r
F
.41725 .78255 m .41836 .78317 L .41668 .78326 L F
.42052 .78472 m .41407 .777 L .41336 .78279 L 0 1 .444 r
F
.42052 .78472 m .41336 .78279 L .41336 .78282 L F
.42088 .78515 m .41336 .78282 L .41332 .78317 L F
.42088 .78515 m .41396 .78402 L .41336 .78282 L 0 0 0 r
F
.42088 .78515 m .41819 .78623 L .41396 .78402 L F
.42211 .78535 m .42178 .78543 L .42088 .78515 L F
.42088 .78515 m .4184 .77249 L .41407 .777 L 0 1 .444 r
F
.42209 .7866 m .42178 .78543 L .42088 .78515 L F
.42178 .78543 m .42088 .78515 L .42088 .78515 L 0 0 0 r
F
.42178 .78543 m .4184 .77249 L .42088 .78515 L 0 1 .444 r
F
.42178 .78543 m .41819 .78623 L .42088 .78515 L 0 0 0 r
F
.42178 .78543 m .42387 .7722 L .4184 .77249 L 0 1 .444 r
F
.42178 .78543 m .42178 .78543 L .42178 .78543 L F
.4218 .78549 m .42181 .78544 L .42178 .78543 L F
.42209 .7866 m .42221 .78561 L .4218 .78549 L F
.43043 .79698 m .42209 .78661 L .42169 .79271 L 0 1 .441 r
F
.42252 .78567 m .42252 .78568 L .42252 .78568 L 0 0 0 r
F
.42211 .78535 m .42287 .7858 L .42252 .78567 L F
.42747 .78714 m .42287 .7858 L .42211 .78535 L F
.42222 .78557 m .42683 .77632 L .42387 .7722 L 0 1 .444 r
F
.42209 .7866 m .42252 .78568 L .42222 .78557 L F
.42222 .78557 m .42222 .78557 L .42222 .78557 L 0 0 0 r
F
.42211 .78535 m .42252 .78567 L .42222 .78557 L F
.42252 .78568 m .42683 .77632 L .42222 .78557 L 0 1 .444 r
F
.42209 .7866 m .42287 .7858 L .42252 .78568 L F
.42222 .78557 m .42665 .78892 L .42363 .78834 L 0 0 0 r
F
.42222 .78557 m .42665 .78892 L .42222 .78557 L F
.42178 .78543 m .42363 .78834 L .41819 .78623 L F
.42179 .78543 m .42179 .78543 L .42178 .78543 L F
.42179 .78543 m .42363 .78834 L .42178 .78543 L F
.42178 .78543 m .42387 .7722 L .42178 .78543 L 0 1 .444 r
F
.42181 .78544 m .42387 .7722 L .42178 .78543 L F
.42211 .78535 m .42222 .78557 L .42179 .78543 L 0 0 0 r
F
.42221 .78561 m .42387 .7722 L .4218 .78549 L 0 1 .444 r
F
.42252 .78568 m .42607 .78249 L .42683 .77632 L F
.42287 .7858 m .42607 .78249 L .42252 .78568 L F
.42252 .78568 m .42599 .78764 L .42665 .78892 L 0 0 0 r
F
.42252 .78568 m .42599 .78764 L .42252 .78568 L F
.42287 .7858 m .42599 .78764 L .42252 .78567 L F
.42252 .78567 m .42665 .78892 L .42222 .78557 L F
.42222 .78557 m .42363 .78834 L .42179 .78543 L F
.42751 .7873 m .42747 .78714 L .42685 .78708 L 0 1 .441 r
F
.42747 .78714 m .42607 .78249 L .42287 .7858 L F
.42747 .78714 m .426 .78764 L .42287 .7858 L 0 0 0 r
F
.42747 .78714 m .43136 .78274 L .42607 .78249 L 0 1 .441 r
F
.43043 .79698 m .431 .78825 L .42747 .78714 L F
.43057 .78609 m .431 .78825 L .42747 .78714 L 0 0 0 r
F
.43057 .78609 m .43362 .78917 L .431 .78825 L F
.43057 .78609 m .4341 .78844 L .4343 .7894 L F
.43043 .79698 m .4343 .7894 L .43363 .78917 L 0 1 .441 r
F
.43363 .78917 m .4343 .7894 L .43441 .78995 L 0 0 0 r
F
.43057 .78609 m .4343 .7894 L .43363 .78917 L F
.43043 .79698 m .43404 .79329 L .4343 .7894 L 0 1 .441 r
F
.43363 .78917 m .4343 .7894 L .43444 .78718 L F
.431 .78825 m .43444 .78718 L .43136 .78274 L F
.43043 .79698 m .43363 .78917 L .431 .78825 L F
.43362 .78917 m .43363 .78917 L .431 .78825 L 0 0 0 r
F
.43363 .78917 m .43444 .78718 L .431 .78825 L 0 1 .441 r
F
.43363 .78917 m .43441 .78995 L .431 .78825 L 0 0 0 r
F
.431 .78825 m .43441 .78995 L .43127 .78962 L F
.431 .78825 m .43136 .78274 L .42755 .78705 L 0 1 .441 r
F
.431 .78825 m .42755 .78705 L .42747 .78714 L F
.42747 .78714 m .43127 .78962 L .426 .78764 L 0 0 0 r
F
.431 .78825 m .43127 .78962 L .42747 .78714 L F
.51316 .94818 m .52464 .93596 L .52128 .94019 L 0 .291 .122 r
F
0 g
.52103 .93828 m
.5245 .93487 L
s
.52464 .93596 m
.52494 .93552 L
s
.80675 .80017 m .81344 .80271 L .80885 .80295 L 0 0 0 r
F
.80675 .80017 m .8183 .80027 L .81344 .80271 L F
.47829 .87699 m .47306 .86562 L .47011 .86133 L 0 .856 .41 r
F
0 g
.47535 .87269 m
.47705 .87803 L
s
.47534 .87269 m
.47535 .87269 L
s
.51316 .94818 m .5087 .94944 L .51027 .9494 L 0 .258 .3 r
F
0 g
.50781 .95017 m
.5087 .94944 L
s
.51932 .77638 m .52737 .75729 L .52453 .75233 L 0 1 .36 r
F
.51932 .77638 m .52671 .76648 L .52737 .75729 L F
0 g
.52737 .75729 m
.5294 .75234 L
s
.52778 .77573 m
.52914 .77199 L
s
.50202 .93048 m .494 .91984 L .4985 .926 L 0 .445 .377 r
F
.50165 .93109 m .4985 .926 L .494 .91984 L 0 .456 .381 r
F
0 g
.49239 .91722 m
.494 .91984 L
s
.49043 .91572 m
.494 .91984 L
s
.51316 .94818 m .50167 .93606 L .50517 .93995 L 0 .321 .341 r
F
.51316 .94818 m .50155 .93557 L .50167 .93606 L F
0 g
.50138 .93586 m
.50167 .93606 L
s
.50576 .94429 m
.50597 .94438 L
s
.50281 .94242 m
.50281 .94242 L
s
.50281 .94242 m
.50281 .94242 L
s
.50099 .94263 m
.50281 .94242 L
s
.25142 .71954 m .24009 .72064 L .24441 .72227 L 0 1 .534 r
F
0 g
.24441 .72227 m
.24477 .72736 L
s
.44184 .93212 m .43343 .92848 L .43817 .9301 L 0 .065 0 r
F
.44184 .93212 m .42999 .92783 L .43343 .92848 L F
0 g
.43002 .92674 m
.43343 .92848 L
s
.43817 .9301 m
.44186 .93059 L
s
.45215 .83503 m .44543 .8274 L .44896 .83208 L 0 1 .431 r
F
.45215 .83503 m .44341 .8232 L .44543 .8274 L F
.45215 .83503 m .44425 .82229 L .44341 .8232 L F
.45215 .83503 m .44744 .82523 L .44425 .82229 L F
0 g
.44436 .8271 m
.44543 .8274 L
s
.44094 .82614 m
.44436 .8271 L
s
.45215 .83503 m .45086 .83006 L .44744 .82523 L 0 1 .431 r
F
0 g
.44896 .83209 m
.44896 .83209 L
s
.44896 .83209 m
.44918 .83325 L
s
.44918 .83325 m
.44998 .83751 L
s
.45215 .83503 m .45288 .83426 L .45086 .83006 L 0 1 .431 r
F
0 g
.45215 .83503 m
.45424 .83941 L
s
.44896 .83208 m
.45215 .83503 L
s
.64242 .61465 m .65828 .61334 L .66126 .61171 L 0 1 .409 r
F
.64242 .61465 m .65022 .6146 L .65828 .61334 L F
0 g
.65828 .61334 m
.6614 .61492 L
s
.65022 .6146 m
.65332 .61602 L
s
.65022 .6146 m
.65022 .6146 L
s
.65022 .6146 m
.65828 .61334 L
s
.42911 .81903 m .41972 .80958 L .4203 .81525 L 0 1 .445 r
F
.42911 .81903 m .4228 .80566 L .41972 .80958 L F
0 g
.41542 .81554 m
.4203 .81525 L
s
.42911 .81903 m .42776 .8058 L .4228 .80566 L 0 1 .445 r
F
.42911 .81903 m .4313 .8099 L .42776 .8058 L F
.42911 .81903 m .43188 .81557 L .4313 .8099 L F
0 g
.42911 .81903 m
.42991 .82456 L
s
.42415 .81889 m
.42911 .81903 L
s
.47186 .85996 m .46453 .85103 L .46794 .85672 L 0 .935 .41 r
F
.47186 .85996 m .4636 .84536 L .46453 .85103 L F
0 g
.46794 .85672 m
.47011 .86133 L
s
.46794 .85672 m
.46794 .85672 L
s
.53952 .84139 m .5438 .80016 L .54022 .81122 L 0 .88 .289 r
F
0 g
.54259 .78869 m
.5438 .80016 L
s
.51316 .94817 m .51599 .92383 L .51684 .91194 L 0 .397 .267 r
F
0 g
.51684 .91194 m
.51749 .90637 L
s
.51431 .91734 m
.51442 .9031 L
s
.3462 .76097 m .33641 .7565 L .34023 .75841 L 0 .353 .212 r
F
0 g
.34023 .75841 m
.34053 .75983 L
s
.23035 .81483 m .22024 .81921 L .22485 .81983 L 0 1 .534 r
F
0 g
.22485 .81983 m
.22719 .82595 L
s
.27268 .72898 m .26692 .71933 L .26207 .72413 L 0 1 .525 r
F
.27268 .72898 m .27365 .71746 L .26692 .71933 L F
.27268 .72898 m .27776 .71979 L .27365 .71746 L F
.27268 .72898 m .27734 .72474 L .27776 .71979 L F
0 g
.26598 .73082 m
.27268 .72898 L
s
.27243 .73353 m
.27268 .72898 L
s
.71945 .89164 m .73098 .88992 L .73026 .88851 L 0 .884 .252 r
F
0 g
.72827 .89171 m
.73098 .88992 L
s
.47751 .94119 m .46928 .93745 L .47401 .93899 L 0 .263 .068 r
F
.47751 .94119 m .46566 .93732 L .46928 .93745 L F
0 g
.46596 .93533 m
.46928 .93745 L
s
.22094 .92147 m .2128 .92184 L .21745 .92255 L 0 .67 .295 r
F
0 g
.21745 .92255 m
.22186 .92473 L
s
.22094 .92147 m .2093 .91945 L .2128 .92184 L 0 .67 .295 r
F
0 g
.2103 .92323 m
.2128 .92184 L
s
.36582 .80735 m .35917 .7969 L .35593 .80317 L 0 1 .475 r
F
.36582 .80735 m .36447 .79366 L .35917 .7969 L F
.36582 .80735 m .36828 .79562 L .36447 .79366 L F
.36582 .80735 m .36886 .80149 L .36828 .79562 L F
0 g
.36582 .80735 m
.36654 .81304 L
s
.36053 .81058 m
.36582 .80735 L
s
.51316 .94818 m .50497 .93908 L .50155 .93557 L 0 .321 .341 r
F
0 g
.50098 .93502 m
.50155 .93557 L
s
.50281 .94242 m
.50314 .94238 L
s
.50166 .94341 m .49327 .942 L .48995 .93995 L 0 .299 .101 r
F
0 g
.48995 .93995 m
.49017 .94009 L
s
.48627 .93962 m
.48995 .93995 L
s
.50128 .93274 m .50131 .93237 L .4978 .92807 L 0 .472 .386 r
F
0 g
.49769 .92931 m
.49936 .93118 L
s
.49972 .93125 m
.49992 .93143 L
s
.49936 .93118 m
.49945 .93128 L
s
.49986 .93251 m
.50045 .93302 L
s
.49992 .93143 m
.50022 .93172 L
s
.49945 .93128 m
.49949 .93132 L
s
.49949 .93132 m
.50042 .93237 L
s
.50042 .93237 m
.50089 .9329 L
s
.6691 .6111 m .66871 .60757 L .66573 .60924 L 0 1 .406 r
F
.79091 1.03138 m .79918 1.02981 L .80198 1.0234 L 0 1 .335 r
F
0 g
.79383 1.03673 m
.79918 1.02981 L
s
.79918 1.02981 m
.80035 1.03271 L
s
.53827 1.10705 m .53439 1.10035 L .53215 1.09526 L 0 .356 0 r
F
.4636 .84536 m .45599 .83761 L .45941 .84284 L 0 1 .418 r
F
.52505 .94204 m .52501 .94075 L .52851 .93464 L 0 .269 .135 r
F
0 g
.52546 .93633 m
.52645 .93426 L
s
.51316 .94817 m .51431 .91734 L .51365 .93494 L 0 .392 .267 r
F
.51316 .94817 m .51365 .93494 L .51431 .91734 L 0 .384 .266 r
F
0 g
.51431 .91734 m
.51431 .91734 L
s
.51431 .91734 m
.51516 .90547 L
s
.55203 1.12317 m .54778 1.11623 L .54561 1.11034 L 0 .392 .029 r
F
.51316 .94818 m .50939 .9504 L .50986 .95104 L 0 .248 .293 r
F
.51316 .94818 m .51027 .9494 L .50939 .9504 L F
0 g
.50781 .95017 m
.50939 .9504 L
s
.49187 .91346 m .49232 .913 L .48959 .90797 L 0 .62 .4 r
F
.5025 .93002 m .49187 .91346 L .49477 .9187 L 0 .433 .372 r
F
.5025 .93002 m .49232 .913 L .49187 .91346 L F
0 g
.4978 .92807 m
.49866 .92912 L
s
.4978 .92807 m
.4986 .9289 L
s
.49769 .92931 m
.49972 .93125 L
s
.49089 .91237 m
.49187 .91346 L
s
.49187 .91346 m
.49301 .91553 L
s
.50465 .95176 m .50432 .94988 L .50135 .94834 L 0 .345 .277 r
F
.51316 .94817 m .50518 .93547 L .50973 .94272 L 0 .394 .272 r
F
.51316 .94818 m .50973 .94272 L .50518 .93547 L 0 .384 .27 r
F
0 g
.50518 .93547 m
.50518 .93547 L
s
.50317 .93159 m
.50518 .93547 L
s
.50201 .97719 m .49645 .98478 L .49898 .98535 L 0 .283 .275 r
F
0 g
.49585 .98953 m
.49645 .98478 L
s
.52086 .73638 m .52998 .72604 L .53064 .71947 L 0 1 .397 r
F
.52086 .73638 m .52579 .73328 L .52998 .72604 L F
0 g
.52998 .72604 m
.53312 .72822 L
s
.43112 .64838 m .42211 .6504 L .42426 .6505 L 0 1 .296 r
F
0 g
.4209 .65303 m
.42426 .6505 L
s
.43112 .64838 m .42607 .64802 L .42211 .6504 L 0 1 .296 r
F
.43112 .64838 m .43351 .64494 L .42607 .64802 L F
.43112 .64838 m .44039 .64282 L .43351 .64494 L F
.43112 .64838 m .4421 .64309 L .44039 .64282 L F
.43112 .64838 m .43813 .64547 L .4421 .64309 L F
0 g
.42747 .65054 m
.43112 .64838 L
s
.42426 .6505 m
.43112 .64838 L
s
.43813 .64547 m
.44467 .64336 L
s
.45086 .83006 m
.45288 .83426 L
s
.45288 .83426 m
.45599 .83761 L
s
.51316 .94818 m .50738 .94496 L .51068 .9468 L 0 .3 .328 r
F
.51316 .94818 m .51068 .9468 L .50738 .94496 L 0 .29 .322 r
F
.51316 .94818 m .51316 .94818 L .51068 .9468 L F
.51316 .94818 m .50314 .94238 L .50628 .9451 L 0 .358 .267 r
F
0 g
.50314 .94238 m
.50316 .9424 L
s
.50572 .94477 m
.50621 .94504 L
s
.50314 .94238 m
.50314 .94238 L
s
.68027 1.11641 m .67933 1.10181 L .68526 1.1032 L 0 .174 .068 r
F
.68027 1.11641 m .67574 1.10435 L .67933 1.10181 L F
0 g
.67825 1.09661 m
.67933 1.10181 L
s
.47829 .87699 m .47647 .87181 L .47306 .86562 L 0 .856 .41 r
F
0 g
.47011 .86133 m
.47306 .86562 L
s
.48011 .87582 m .47306 .86562 L .47647 .87181 L 0 .837 .402 r
F
0 g
.47534 .87269 m
.47659 .87451 L
s
.48011 .87582 m .47186 .85996 L .47306 .86562 L 0 .837 .402 r
F
0 g
.47268 .86383 m
.47306 .86562 L
s
.53827 1.10705 m .54132 1.10625 L .54357 1.11136 L 0 .356 0 r
F
0 g
.54132 1.10625 m
.54561 1.11034 L
s
.67684 .60719 m .69639 .60685 L .69279 .60471 L 0 1 .434 r
F
0 g
.69639 .60685 m
.7044 .60733 L
s
.51471 .95727 m .51422 .95667 L .51406 .95777 L 0 .161 .205 r
F
.31805 .81055 m .30766 .80857 L .30849 .8141 L 0 1 .507 r
F
0 g
.3037 .81837 m
.30849 .8141 L
s
.41816 .92372 m .41019 .92131 L .40651 .91991 L 0 0 0 r
F
.41816 .92372 m .41491 .92312 L .41019 .92131 L F
.41816 .92372 m .41833 .92415 L .41491 .92312 L F
.42999 .92783 m .41833 .92415 L .41816 .92372 L F
0 g
.41448 .92232 m
.41816 .92372 L
s
.41816 .92372 m
.42158 .92456 L
s
.4636 .84536 m .45533 .83192 L .45599 .83761 L 0 1 .418 r
F
.51316 .94818 m .50142 .93485 L .50497 .93908 L 0 .318 .34 r
F
.51316 .94818 m .50135 .9344 L .50142 .93485 L F
0 g
.50093 .93448 m
.50142 .93485 L
s
.50348 .94029 m
.50348 .94029 L
s
.50348 .94029 m
.50348 .94029 L
s
.50254 .93968 m
.50348 .94029 L
s
.50306 .93839 m
.50411 .9397 L
s
.49887 .9392 m
.50223 .94037 L
s
.51316 .94818 m .50986 .95104 L .51109 .95052 L 0 .248 .293 r
F
0 g
.5087 .94944 m
.51027 .9494 L
s
.50933 .95208 m
.50986 .95104 L
s
.70864 .89504 m .72015 .89267 L .71945 .89164 L 0 .834 .238 r
F
0 g
.71741 .89427 m
.72015 .89267 L
s
.72015 .89267 m
.72392 .8927 L
s
.47829 .87699 m .47871 .87669 L .47647 .87181 L 0 .856 .41 r
F
.487 .89349 m .47829 .87699 L .48061 .88213 L 0 .739 .4 r
F
.487 .89349 m .47871 .87669 L .47829 .87699 L F
0 g
.47659 .87451 m
.47829 .87699 L
s
.47829 .87699 m
.47859 .87765 L
s
.27466 .61411 m .26515 .61023 L .26212 .6182 L 0 1 .506 r
F
0 g
.25412 .62367 m
.26212 .6182 L
s
.27466 .61411 m .27309 .60113 L .26515 .61023 L 0 1 .506 r
F
.27466 .61411 m .28177 .59546 L .27309 .60113 L F
.27466 .61411 m .28538 .59701 L .28177 .59546 L F
.27466 .61411 m .28233 .60501 L .28538 .59701 L F
0 g
.27183 .62218 m
.27466 .61411 L
s
.26601 .61975 m
.27466 .61411 L
s
.68647 .82014 m
.68865 .80901 L
s
.75981 .60332 m .77704 .60519 L .76936 .60076 L 0 1 .493 r
F
0 g
.77704 .60519 m
.77976 .60907 L
s
.67687 .62297 m
.68177 .63333 L
s
.68177 .63333 m
.68217 .63417 L
s
.67687 .62297 m
.67947 .63278 L
s
.67947 .63278 m
.68026 .63577 L
s
.58185 .64457 m .59765 .63592 L .59351 .63592 L 0 1 .363 r
F
0 g
.59765 .63592 m
.60444 .63281 L
s
.70405 .72623 m
.70897 .70502 L
s
.67538 .60724 m
.67538 .60725 L
s
.66832 .59234 m
.66973 .59533 L
s
.66394 .58296 m
.66832 .59234 L
s
.51747 .96061 m .52177 .96943 L .52108 .96748 L 0 .113 .186 r
F
0 g
.52177 .96943 m
.52386 .972 L
s
.71208 .71809 m
.71257 .70671 L
s
.68026 .63577 m
.68172 .63983 L
s
.51974 .92711 m .52556 .91233 L .52711 .89942 L 0 .443 .263 r
F
0 g
.51847 .91451 m
.51989 .90585 L
s
.52711 .89942 m
.52989 .88993 L
s
.48514 .89468 m .48413 .88869 L .48061 .88213 L 0 .739 .403 r
F
.48514 .89468 m .48607 .89407 L .48413 .88869 L F
.49447 .9116 m .48514 .89468 L .48731 .90013 L 0 .594 .389 r
F
.49447 .9116 m .48607 .89407 L .48514 .89468 L F
0 g
.48158 .89057 m
.48514 .89468 L
s
.48514 .89468 m
.4859 .89659 L
s
.51932 .77638 m .52327 .77466 L .52671 .76648 L 0 1 .36 r
F
0 g
.52671 .76648 m
.52914 .77199 L
s
.53158 .98131 m
.53182 .98159 L
s
.5319 .98168 m
.53233 .9822 L
s
.53242 .9823 m
.53267 .98259 L
s
.51316 .94818 m .50485 .93828 L .50135 .9344 L 0 .318 .34 r
F
0 g
.50056 .93359 m
.50135 .9344 L
s
.51316 .94818 m .50546 .94312 L .50232 .94041 L 0 .307 .118 r
F
0 g
.50223 .94037 m
.50232 .94041 L
s
.50288 .94465 m
.50288 .94465 L
s
.50287 .94465 m
.50288 .94465 L
s
.5012 .94334 m
.50287 .94465 L
s
.3981 .66227 m
.40489 .65925 L
s
.39296 .80489 m .38364 .80433 L .38761 .80678 L 0 1 .46 r
F
0 g
.38761 .80678 m
.3886 .81237 L
s
.4636 .84536 m .45786 .82955 L .45533 .83192 L 0 1 .418 r
F
.4636 .84536 m .46205 .83207 L .45786 .82955 L F
.4636 .84536 m .4651 .8378 L .46205 .83207 L F
.4636 .84536 m .46576 .84349 L .4651 .8378 L F
.47186 .85996 m .46576 .84349 L .4636 .84536 L 0 .935 .41 r
F
0 g
.45941 .84284 m
.4636 .84536 L
s
.4636 .84536 m
.46453 .85103 L
s
.47647 .87181 m
.47647 .87182 L
s
.48966 .94171 m .48111 .94124 L .47772 .93915 L 0 .283 .087 r
F
.31845 .59127 m .30601 .596 L .3095 .59765 L 0 1 .477 r
F
.31845 .59127 m .30998 .58752 L .30601 .596 L F
.31845 .59127 m .31878 .57786 L .30998 .58752 L F
.31845 .59127 m .32776 .57146 L .31878 .57786 L F
.31845 .59127 m .33091 .57261 L .32776 .57146 L F
.31845 .59127 m .32691 .5811 L .33091 .57261 L F
0 g
.31471 .60023 m
.31845 .59127 L
s
.3095 .59765 m
.31845 .59127 L
s
.50866 1.04588 m .50622 1.04046 L .50388 1.03783 L 0 .081 .187 r
F
.23035 .81483 m .21888 .81313 L .22024 .81921 L 0 1 .534 r
F
0 g
.21563 .82456 m
.22024 .81921 L
s
.487 .89349 m .48158 .88148 L .47871 .87669 L 0 .739 .4 r
F
0 g
.47647 .87182 m
.47871 .87669 L
s
.48061 .88213 m
.48061 .88213 L
s
.47705 .87803 m
.48061 .88213 L
s
.47186 .85996 m .46968 .84674 L .46576 .84349 L 0 .935 .41 r
F
.47186 .85996 m .47273 .85294 L .46968 .84674 L F
.47186 .85996 m .47366 .85861 L .47273 .85294 L F
.48011 .87582 m .47366 .85861 L .47186 .85996 L 0 .837 .402 r
F
0 g
.46794 .85672 m
.47186 .85996 L
s
.47186 .85996 m
.47268 .86383 L
s
.62544 .93118 m .63605 .81115 L .63416 .86471 L 0 .306 .198 r
F
0 g
.63488 .78352 m
.63605 .81115 L
s
.63605 .81115 m
.63838 .78968 L
s
.62613 .87197 m
.62613 .87316 L
s
.62653 .84011 m
.62984 .7823 L
s
.62675 .83625 m
.62688 .82182 L
s
.62554 .7995 m
.62651 .83918 L
s
.487 .89349 m .48061 .88213 L .48413 .88869 L 0 .739 .4 r
F
0 g
.47859 .87765 m
.48061 .88213 L
s
.51932 .77638 m .52453 .75233 L .52009 .7549 L 0 1 .36 r
F
0 g
.5236 .77387 m
.52671 .76648 L
s
.52453 .75233 m
.52737 .75729 L
s
.52453 .75233 m
.52568 .74998 L
s
.51316 .94818 m .51057 .952 L .51105 .95263 L 0 .24 .286 r
F
.51316 .94818 m .51109 .95052 L .51057 .952 L F
0 g
.50933 .95208 m
.51057 .952 L
s
.5025 .93002 m .49573 .91779 L .49232 .913 L 0 .433 .372 r
F
0 g
.48959 .90797 m
.49232 .913 L
s
.49301 .91553 m
.49465 .9185 L
s
.49866 .92912 m
.49948 .93012 L
s
.49126 .91424 m
.49448 .91833 L
s
.49447 .9116 m .48731 .90013 L .49113 .90678 L 0 .594 .389 r
F
.49306 .91239 m .49113 .90678 L .48731 .90013 L 0 .608 .395 r
F
0 g
.48647 .89906 m
.48731 .90013 L
s
.4859 .89659 m
.48731 .90013 L
s
.5163 .9592 m .5191 .96518 L .5177 .96202 L 0 .131 .19 r
F
.51747 .96061 m .5177 .96202 L .5191 .96518 L 0 .113 .186 r
F
0 g
.5191 .96518 m
.52084 .96836 L
s
.5191 .96518 m
.51915 .96544 L
s
.55203 1.12317 m .5562 1.11998 L .55839 1.12589 L 0 .392 .029 r
F
0 g
.5562 1.11998 m
.56049 1.12302 L
s
.50323 1.00521 m .49807 1.00882 L .49994 1.01358 L 0 .223 .259 r
F
.50323 1.00521 m .4979 1.00308 L .49807 1.00882 L F
0 g
.49545 1.00675 m
.49807 1.00882 L
s
.45533 .83192 m .44744 .82523 L .45086 .83006 L 0 1 .425 r
F
0 g
.45242 .83071 m
.45444 .83155 L
s
.45086 .83006 m
.45242 .83071 L
s
.71208 .71809 m
.71439 .70978 L
s
.71626 .70305 m
.7173 .69928 L
s
.23258 .92354 m .22443 .92362 L .22908 .92434 L 0 .633 .266 r
F
0 g
.22908 .92434 m
.23344 .92627 L
s
.23258 .92354 m .22094 .92147 L .22443 .92362 L 0 .633 .266 r
F
0 g
.22186 .92473 m
.22443 .92362 L
s
.25142 .71954 m .24076 .71517 L .24009 .72064 L 0 1 .534 r
F
0 g
.23385 .72362 m
.24009 .72064 L
s
.51316 .94818 m .50129 .93374 L .50485 .93828 L 0 .313 .337 r
F
0 g
.50408 .93743 m
.50439 .93769 L
s
.51316 .94818 m .50546 .93862 L .50986 .94408 L 0 .384 .27 r
F
.51316 .94818 m .50986 .94408 L .50546 .93862 L 0 .372 .269 r
F
.51316 .94818 m .51316 .94818 L .50986 .94408 L F
.51316 .94818 m .50127 .93333 L .50129 .93374 L 0 .313 .337 r
F
0 g
.50045 .93302 m
.50129 .93374 L
s
.50412 .93648 m
.50529 .93835 L
s
.50446 .94053 m
.50446 .94053 L
s
.50446 .94053 m
.50446 .94053 L
s
.5029 .93906 m
.50446 .94053 L
s
.50289 .93956 m
.50461 .94089 L
s
.7519 .64668 m .77073 .63421 L .76845 .63667 L 0 0 0 r
F
0 g
.77073 .63421 m
.77809 .62975 L
s
.25325 .81807 m .24445 .80933 L .24181 .81647 L 0 1 .531 r
F
.25325 .81807 m .24983 .80451 L .24445 .80933 L F
.25325 .81807 m .25435 .80526 L .24983 .80451 L F
.25325 .81807 m .25581 .81108 L .25435 .80526 L F
0 g
.24789 .82285 m
.25325 .81807 L
s
.25325 .81807 m
.25479 .82374 L
s
.5014 .93185 m .50149 .93153 L .49807 .92696 L 0 .466 .384 r
F
0 g
.4986 .9289 m
.49946 .92981 L
s
.50022 .93172 m
.50086 .93233 L
s
.50063 .93104 m
.50086 .93127 L
s
.50003 .9308 m
.50026 .93107 L
s
.50026 .93107 m
.50074 .93166 L
s
.50074 .93166 m
.50107 .93207 L
s
.51316 .94818 m .51105 .95263 L .51193 .95163 L 0 .24 .286 r
F
0 g
.51089 .95399 m
.51105 .95263 L
s
.52716 .79969 m .53057 .79943 L .53396 .79008 L 0 1 .329 r
F
.44341 .8232 m .43661 .81624 L .44014 .82061 L 0 1 .436 r
F
.44341 .8232 m .43466 .81218 L .43661 .81624 L F
.44341 .8232 m .4356 .81113 L .43466 .81218 L F
.44341 .8232 m .43887 .81372 L .4356 .81113 L F
.44341 .8232 m .4423 .81823 L .43887 .81372 L F
0 g
.44014 .82061 m
.44026 .82144 L
s
.44026 .82144 m
.44094 .82614 L
s
.44341 .8232 m .44425 .82229 L .4423 .81823 L 0 1 .436 r
F
0 g
.44341 .8232 m
.44543 .8274 L
s
.44014 .82061 m
.44341 .8232 L
s
.52086 .73638 m .53064 .71947 L .52706 .71705 L 0 1 .397 r
F
0 g
.52589 .73339 m
.529 .73679 L
s
.53064 .71947 m
.53513 .71164 L
s
.70804 .80843 m
.70804 .80846 L
s
.70803 .80846 m
.70804 .80843 L
s
.5025 .93002 m .49477 .9187 L .49909 .92523 L 0 .433 .372 r
F
0 g
.50046 .93086 m
.50063 .93104 L
s
.50202 .93048 m .49909 .92523 L .49477 .9187 L 0 .445 .377 r
F
0 g
.49465 .9185 m
.49477 .9187 L
s
.49448 .91833 m
.49477 .9187 L
s
.49807 .92696 m
.49836 .92735 L
s
.49807 .92696 m
.49831 .92724 L
s
.49946 .92981 m
.50046 .93086 L
s
.49948 .93012 m
.50003 .9308 L
s
.3462 .76097 m .33681 .75609 L .33641 .7565 L 0 .353 .212 r
F
0 g
.33084 .75537 m
.33641 .7565 L
s
.46566 .93732 m .45716 .93677 L .4537 .93461 L 0 .211 .043 r
F
.46566 .93732 m .46192 .93844 L .45716 .93677 L F
.46566 .93732 m .46556 .93868 L .46192 .93844 L F
.47751 .94119 m .46556 .93868 L .46566 .93732 L 0 .263 .068 r
F
0 g
.46566 .93732 m
.46928 .93745 L
s
.46219 .93516 m
.46566 .93732 L
s
.47401 .93899 m
.47772 .93915 L
s
.51316 .94818 m .50482 .93755 L .50127 .93333 L 0 .313 .337 r
F
0 g
.50089 .9329 m
.50127 .93333 L
s
.50288 .94465 m
.5035 .94514 L
s
.5035 .94514 m
.5035 .94514 L
s
.5035 .94514 m
.5035 .94514 L
s
.50461 .94089 m
.50493 .94114 L
s
.50348 .94029 m
.50452 .94098 L
s
.50452 .94098 m
.50452 .94098 L
s
.50452 .94098 m
.50452 .94098 L
s
.50467 .94107 m
.50467 .94107 L
s
.50452 .94098 m
.50467 .94107 L
s
.50467 .94107 m
.50467 .94107 L
s
.50314 .94111 m
.50314 .94111 L
s
.50314 .94111 m
.50314 .94111 L
s
.50232 .94041 m
.50314 .94111 L
s
.50233 .93816 m
.50426 .93983 L
s
.50426 .93983 m
.50426 .93983 L
s
.50426 .93983 m
.50426 .93983 L
s
.50188 .93683 m
.50367 .93852 L
s
.52507 .94539 m .53695 .93281 L .53694 .93622 L 0 .277 .136 r
F
.52507 .94539 m .5334 .93408 L .53695 .93281 L F
0 g
.53695 .93281 m
.53816 .92934 L
s
.53416 .93381 m
.53669 .9329 L
s
.53669 .9329 m
.53695 .93281 L
s
.52844 1.0925 m .52935 1.09187 L .53057 1.09384 L 0 .326 0 r
F
.52844 1.0925 m .52789 1.08996 L .52935 1.09187 L F
0 g
.529 1.09039 m
.52935 1.09187 L
s
.60967 .62766 m .6269 .62202 L .6228 .62145 L 0 1 .365 r
F
0 g
.6269 .62202 m
.63419 .6203 L
s
.35593 .80317 m .34646 .80549 L .35049 .80685 L 0 1 .479 r
F
0 g
.35049 .80685 m
.3516 .81234 L
s
.75105 1.07082 m .74765 1.07301 L .74826 1.07217 L 0 0 0 r
F
0 g
.7418 1.07536 m
.74826 1.07217 L
s
.49977 .99497 m .4979 1.00308 L .49954 1.0002 L 0 .256 .274 r
F
.50323 1.00521 m .49954 1.0002 L .4979 1.00308 L 0 .223 .259 r
F
0 g
.4979 1.00308 m
.49807 1.00882 L
s
.49533 1.00171 m
.4979 1.00308 L
s
.72177 .60093 m .74212 .60385 L .73875 .60072 L 0 1 .473 r
F
0 g
.74212 .60385 m
.75028 .60578 L
s
.45533 .83192 m .44704 .81948 L .44744 .82523 L 0 1 .425 r
F
.45533 .83192 m .44993 .81665 L .44704 .81948 L F
.45533 .83192 m .4544 .8185 L .44993 .81665 L F
.45533 .83192 m .45746 .82381 L .4544 .8185 L F
.45533 .83192 m .45786 .82955 L .45746 .82381 L F
0 g
.45533 .83192 m
.45599 .83761 L
s
.45444 .83155 m
.45533 .83192 L
s
.41972 .80958 m .41068 .80652 L .41453 .80994 L 0 1 .448 r
F
0 g
.41453 .80994 m
.41542 .81554 L
s
.76633 .81803 m .77438 .80216 L .77898 .8026 L 0 .127 .054 r
F
.76633 .81803 m .76897 .80875 L .77438 .80216 L F
0 g
.77209 .79642 m
.77438 .80216 L
s
.52505 .94204 m .5334 .93408 L .52865 .93918 L 0 .269 .135 r
F
0 g
.52507 .93715 m
.52546 .93633 L
s
.52507 .94539 m .52865 .93918 L .5334 .93408 L 0 .277 .136 r
F
0 g
.5334 .93408 m
.53632 .92898 L
s
.52547 .93822 m
.52851 .93464 L
s
.52506 .9387 m
.52547 .93822 L
s
.5334 .93408 m
.53416 .93381 L
s
.51316 .94818 m .50874 .94716 L .51126 .94774 L 0 .28 .315 r
F
.51316 .94818 m .51126 .94774 L .50874 .94716 L 0 .269 .307 r
F
.51316 .94818 m .51316 .94818 L .51126 .94774 L F
.51316 .94818 m .50355 .94518 L .50385 .94706 L 0 .343 .266 r
F
.51316 .94818 m .50803 .94606 L .51096 .94727 L 0 .29 .322 r
F
.51316 .94818 m .51096 .94727 L .50803 .94606 L 0 .28 .315 r
F
.51316 .94818 m .51316 .94818 L .51096 .94727 L F
.51316 .94818 m .50628 .9451 L .50355 .94518 L 0 .343 .266 r
F
0 g
.5035 .94514 m
.50355 .94518 L
s
.50646 .94518 m
.50646 .94518 L
s
.49447 .9116 m .4894 .89888 L .48607 .89407 L 0 .594 .389 r
F
0 g
.48607 .89407 m
.48787 .89668 L
s
.48959 .90797 m
.49248 .91165 L
s
.52009 .7549 m .52579 .73328 L .52086 .73638 L 0 1 .377 r
F
0 g
.52579 .73328 m
.52589 .73339 L
s
.52579 .73328 m
.52998 .72604 L
s
.44425 .82229 m
.44744 .82523 L
s
.44739 .82457 m
.44744 .82523 L
s
.43597 .81615 m
.43661 .81624 L
s
.43188 .81557 m
.43597 .81615 L
s
.77879 .64574 m .78169 .65268 L .77771 .65464 L 0 .067 .061 r
F
.77879 .64574 m .78895 .64206 L .78169 .65268 L F
0 g
.77174 .65769 m
.77879 .64574 L
s
.53245 .83427 m .53892 .79947 L .53561 .79933 L 0 .907 .304 r
F
0 g
.5315 .79686 m
.53396 .79008 L
s
.5315 .81731 m
.53313 .82679 L
s
.53245 .83427 m .54022 .81122 L .53892 .79947 L 0 .907 .304 r
F
0 g
.53892 .79947 m
.54259 .78869 L
s
.50469 1.02564 m .5026 1.03243 L .50492 1.03427 L 0 .166 .237 r
F
0 g
.5026 1.03243 m
.50388 1.03783 L
s
.487 .89349 m .48499 .88819 L .48158 .88148 L 0 .739 .4 r
F
0 g
.4856 .89276 m
.48607 .89407 L
s
.47871 .87669 m
.48158 .88148 L
s
.48836 .89292 m .48158 .88148 L .48499 .88819 L 0 .72 .393 r
F
0 g
.48507 .8913 m
.4856 .89276 L
s
.48836 .89292 m .48011 .87582 L .48158 .88148 L 0 .72 .393 r
F
0 g
.48413 .8887 m
.48507 .8913 L
s
.48413 .88869 m
.48413 .8887 L
s
.48094 .87901 m
.48158 .88148 L
s
.4423 .81823 m
.44425 .82229 L
s
.3556 .76488 m .35036 .76249 L .3462 .76097 L 0 .348 .194 r
F
.3556 .76488 m .35619 .76476 L .35036 .76249 L F
.3556 .76488 m .3598 .76627 L .35619 .76476 L F
.3556 .76488 m .35954 .76632 L .3598 .76627 L F
0 g
.35518 .76472 m
.3556 .76488 L
s
.39296 .80489 m .38323 .79838 L .38364 .80433 L 0 1 .46 r
F
.39296 .80489 m .38666 .79289 L .38323 .79838 L F
0 g
.37853 .80657 m
.38364 .80433 L
s
.39296 .80489 m .39202 .79099 L .38666 .79289 L 0 1 .46 r
F
.39296 .80489 m .39574 .79395 L .39202 .79099 L F
.39296 .80489 m .39614 .7999 L .39574 .79395 L F
0 g
.39296 .80489 m
.39355 .8106 L
s
.38761 .80678 m
.39296 .80489 L
s
.75105 1.07082 m .75825 1.06414 L .76181 1.06111 L 0 0 0 r
F
0 g
.75245 1.06888 m
.75825 1.06414 L
s
.75841 1.06417 m
.75874 1.06423 L
s
.51316 .94818 m .51178 .95358 L .51226 .95421 L 0 .234 .281 r
F
.51316 .94818 m .51193 .95163 L .51178 .95358 L F
0 g
.51089 .95399 m
.51178 .95358 L
s
.51316 .94818 m .52103 .93828 L .51654 .94393 L 0 .294 .123 r
F
.51316 .94818 m .51654 .94393 L .52103 .93828 L 0 .291 .122 r
F
0 g
.52103 .93828 m
.52103 .93828 L
s
.52103 .93828 m
.52425 .93332 L
s
.62859 .52922 m
.62939 .53021 L
s
.62939 .53021 m
.62997 .53093 L
s
.62997 .53093 m
.63063 .53176 L
s
.63072 .53187 m
.63076 .53191 L
s
.63171 .5331 m
.6321 .53358 L
s
.62598 .52728 m
.62859 .52922 L
s
.62388 .52571 m
.62598 .52728 L
s
.6225 .52468 m
.62388 .52571 L
s
.51316 .94818 m .52482 .93768 L .52491 .93888 L 0 .29 .12 r
F
.51316 .94818 m .52128 .94019 L .52482 .93768 L F
0 g
.52482 .93768 m
.52507 .93715 L
s
.38323 .79838 m
.38364 .80433 L
s
.50653 .96112 m .49911 .96615 L .49991 .96931 L 0 .301 .27 r
F
0 g
.49796 .96142 m
.49844 .96152 L
s
.50653 .96112 m .50071 .96201 L .49911 .96615 L 0 .301 .27 r
F
0 g
.49633 .96493 m
.49911 .96615 L
s
.48011 .87582 m .47731 .86261 L .47366 .85861 L 0 .837 .402 r
F
.48011 .87582 m .48036 .86931 L .47731 .86261 L F
.48011 .87582 m .48156 .87497 L .48036 .86931 L F
.48836 .89292 m .48156 .87497 L .48011 .87582 L 0 .72 .393 r
F
0 g
.48011 .87582 m
.48094 .87901 L
s
.47647 .87181 m
.48011 .87582 L
s
.48413 .88869 m
.48647 .89261 L
s
.51316 .94818 m .50128 .93274 L .50482 .93755 L 0 .306 .332 r
F
.51316 .94818 m .50131 .93237 L .50128 .93274 L F
0 g
.50086 .93233 m
.50128 .93274 L
s
.50205 .93735 m
.50455 .93993 L
s
.50455 .93993 m
.50455 .93993 L
s
.50455 .93993 m
.50455 .93994 L
s
.82935 .9893 m .82768 .99801 L .82978 1.00274 L 0 1 .46 r
F
0 g
.82413 1.01 m
.82978 1.00274 L
s
.51534 .95805 m .51519 .95786 L .51565 .95962 L 0 .14 .192 r
F
0 g
.51564 .95959 m
.51565 .95962 L
s
.51316 .94817 m .51754 .9151 L .51599 .92383 L 0 .399 .268 r
F
.51316 .94817 m .51316 .94817 L .51421 .9408 L 0 .316 .118 r
F
.51316 .94817 m .518 .91733 L .51754 .9151 L 0 .399 .268 r
F
0 g
.51754 .9151 m
.51765 .91307 L
s
.51516 .92035 m
.51565 .90718 L
s
.50204 .94152 m .50187 .94227 L .49833 .94136 L 0 .287 .101 r
F
.49306 .91239 m .4936 .91203 L .49113 .90678 L 0 .608 .395 r
F
.5031 .92973 m .49306 .91239 L .49573 .91779 L 0 .422 .368 r
F
.5031 .92973 m .4936 .91203 L .49306 .91239 L F
0 g
.49232 .913 m
.4945 .91607 L
s
.49248 .91165 m
.49306 .91239 L
s
.4939 .91409 m
.49518 .91669 L
s
.49306 .91239 m
.4939 .91409 L
s
.44719 .79216 m .4391 .79016 L .44223 .79009 L 0 .105 0 r
F
0 g
.44218 .78826 m
.44223 .79009 L
s
.68426 .70007 m
.68461 .70725 L
s
.6837 .68864 m
.68426 .70007 L
s
.68461 .70725 m
.68461 .70728 L
s
.21888 .81313 m .2087 .81763 L .21332 .81827 L 0 1 .535 r
F
0 g
.21332 .81827 m
.21563 .82456 L
s
.48052 .80887 m
.48062 .80932 L
s
.48052 .80885 m
.48052 .80887 L
s
.48051 .8088 m
.48052 .80885 L
s
.4805 .80879 m
.48051 .8088 L
s
.24422 .92565 m .23605 .92544 L .2407 .92618 L 0 .606 .25 r
F
0 g
.2407 .92618 m
.24501 .92786 L
s
.24422 .92565 m .23258 .92354 L .23605 .92544 L 0 .606 .25 r
F
0 g
.23344 .92627 m
.23605 .92544 L
s
.51316 .94817 m .51516 .92035 L .51402 .93624 L 0 .397 .267 r
F
.51316 .94817 m .51402 .93624 L .51516 .92035 L 0 .392 .267 r
F
0 g
.51516 .92035 m
.51637 .90996 L
s
.51516 .92035 m
.51516 .92035 L
s
.41972 .80958 m .41032 .80067 L .41068 .80652 L 0 1 .448 r
F
.41972 .80958 m .4137 .79629 L .41032 .80067 L F
0 g
.40559 .80733 m
.41068 .80652 L
s
.41972 .80958 m .4189 .79592 L .4137 .79629 L 0 1 .448 r
F
.41972 .80958 m .42245 .79981 L .4189 .79592 L F
.41972 .80958 m .4228 .80566 L .42245 .79981 L F
0 g
.41972 .80958 m
.4203 .81525 L
s
.41453 .80994 m
.41972 .80958 L
s
.31805 .81055 m .31076 .80196 L .30766 .80857 L 0 1 .507 r
F
0 g
.30766 .80857 m
.30849 .8141 L
s
.31805 .81055 m .31613 .79762 L .31076 .80196 L 0 1 .507 r
F
.31805 .81055 m .32019 .79846 L .31613 .79762 L F
.31805 .81055 m .32101 .804 L .32019 .79846 L F
0 g
.31805 .81055 m
.31897 .81609 L
s
.31269 .81487 m
.31805 .81055 L
s
.51316 .94818 m .51226 .95421 L .51279 .95273 L 0 .234 .281 r
F
0 g
.51226 .95421 m
.51247 .95589 L
s
.51316 .94818 m .50488 .93691 L .50131 .93237 L 0 .306 .332 r
F
0 g
.50202 .94151 m
.50203 .94151 L
s
.49887 .9392 m
.50202 .94151 L
s
.50107 .93207 m
.50131 .93237 L
s
.50167 .93606 m
.50427 .93894 L
s
.50427 .93894 m
.50427 .93895 L
s
.50518 .94141 m
.50518 .94141 L
s
.50517 .94141 m
.50518 .94141 L
s
.50517 .9414 m
.50517 .94141 L
s
.50517 .9414 m
.50517 .9414 L
s
.50467 .94107 m
.50517 .9414 L
s
.50517 .9414 m
.50517 .9414 L
s
.50528 .94132 m
.50528 .94132 L
s
.50528 .94132 m
.50528 .94132 L
s
.50446 .94053 m
.50528 .94132 L
s
.50545 .94154 m
.50545 .94154 L
s
.50545 .94154 m
.50545 .94154 L
s
.50542 .94152 m
.50545 .94154 L
s
.50493 .94114 m
.50542 .94152 L
s
.46263 .79782 m .45536 .7966 L .45808 .7959 L 0 .216 .013 r
F
0 g
.45779 .79331 m
.45808 .7959 L
s
.46256 .80609 m .45534 .79852 L .45801 .8039 L 0 1 .418 r
F
.46256 .80609 m .45919 .7988 L .45534 .79852 L F
.46263 .79782 m .4592 .7988 L .45536 .7966 L 0 .216 .013 r
F
.4592 .7988 m .45919 .7988 L .45913 .79877 L F
.4592 .7988 m .45913 .79877 L .45536 .7966 L F
.45919 .7988 m .46003 .78949 L .4562 .79235 L 0 1 .418 r
F
.46256 .80609 m .4616 .7998 L .45919 .7988 L F
.4592 .7988 m .4592 .7988 L .45919 .7988 L 0 .216 .013 r
F
.46263 .79782 m .4616 .7998 L .4592 .7988 L F
.4616 .7998 m .46003 .78949 L .45919 .7988 L 0 1 .418 r
F
.45919 .7988 m .45991 .80305 L .45614 .79966 L 0 .216 .013 r
F
.4592 .7988 m .45991 .80305 L .45919 .7988 L F
.4616 .7998 m .45991 .80305 L .4592 .7988 L F
.4616 .7998 m .46458 .7917 L .46003 .78949 L 0 1 .418 r
F
.4616 .79983 m .46161 .79981 L .4616 .7998 L F
.46256 .80609 m .46334 .80057 L .4616 .79983 L F
.4689 .82087 m .46596 .80365 L .46256 .80609 L 0 1 .41 r
F
.46263 .79782 m .46492 .80131 L .46334 .80057 L 0 .216 .013 r
F
.46492 .80131 m .46492 .80133 L .46334 .80057 L F
.46263 .79782 m .46334 .80057 L .4616 .7998 L F
.46263 .79782 m .46598 .80109 L .4662 .80194 L F
.46256 .80609 m .46596 .80365 L .4662 .80194 L 0 1 .418 r
F
.46256 .80609 m .4662 .80194 L .46492 .80133 L F
.46492 .80133 m .4662 .80194 L .46678 .80415 L 0 .216 .013 r
F
.46263 .79782 m .4662 .80194 L .46492 .80133 L F
.46492 .80133 m .4662 .80194 L .46683 .79748 L 0 1 .418 r
F
.46334 .80057 m .46458 .7917 L .46163 .79976 L F
.46334 .80057 m .46163 .79976 L .4616 .79983 L F
.46334 .80057 m .46683 .79748 L .46458 .7917 L F
.46256 .80609 m .46492 .80133 L .46334 .80057 L F
.46492 .80133 m .46683 .79748 L .46334 .80057 L F
.4689 .82087 m .47019 .8065 L .46596 .80365 L 0 1 .41 r
F
.46334 .80057 m .46678 .80415 L .46448 .80498 L 0 .216 .013 r
F
.46492 .80133 m .46678 .80415 L .46334 .80057 L F
.4616 .7998 m .46448 .80498 L .45991 .80305 L F
.46334 .80057 m .46448 .80498 L .4616 .7998 L F
.46161 .79981 m .46458 .7917 L .4616 .7998 L 0 1 .418 r
F
.45919 .7988 m .45552 .79724 L .45536 .7966 L 0 .216 .013 r
F
.45919 .7988 m .4562 .79235 L .45552 .79724 L 0 1 .418 r
F
.45919 .7988 m .45552 .79724 L .45534 .79852 L F
.45919 .7988 m .45614 .79966 L .45552 .79724 L 0 .216 .013 r
F
.50201 .97719 m .50115 .97404 L .49862 .97348 L 0 .283 .275 r
F
.77256 1.05256 m .78296 1.04411 L .77862 1.04731 L 0 .938 .212 r
F
.76181 1.06111 m .77256 1.05256 L .7721 1.05245 L 0 .867 .181 r
F
0 g
.32691 .5811 m
.33563 .57423 L
s
.51316 .94818 m .50204 .94152 L .50546 .94312 L 0 .316 .119 r
F
.51316 .94818 m .50187 .94227 L .50204 .94152 L F
0 g
.50203 .94151 m
.50204 .94152 L
s
.50556 .94166 m
.50556 .94166 L
s
.50556 .94166 m
.50556 .94166 L
s
.50518 .94141 m
.50552 .94163 L
s
.50552 .94163 m
.50552 .94163 L
s
.50552 .94163 m
.50556 .94166 L
s
.50552 .94163 m
.50552 .94163 L
s
.50569 .9417 m
.50569 .9417 L
s
.50569 .9417 m
.50569 .9417 L
s
.50528 .94132 m
.50569 .9417 L
s
.50165 .93109 m .50178 .93083 L .4985 .926 L 0 .456 .381 r
F
0 g
.49836 .92735 m
.50075 .93055 L
s
.50075 .93055 m
.50081 .93063 L
s
.50118 .93055 m
.50133 .93072 L
s
.50081 .93063 m
.50132 .9313 L
s
.52619 .97477 m .52534 .97371 L .52643 .975 L 0 .101 0 r
F
0 g
.52571 .97414 m
.52643 .975 L
s
.5254 .97376 m
.52643 .975 L
s
.5163 .9592 m .51581 .95862 L .51614 .96019 L 0 .131 .19 r
F
0 g
.51614 .96018 m
.51614 .96019 L
s
.51592 .95915 m
.51614 .96018 L
s
.51586 .95883 m
.51592 .95915 L
s
.51542 .95827 m
.51614 .96019 L
s
.34806 .66827 m
.35017 .67481 L
s
.51861 .96195 m .52314 .97104 L .52404 .97211 L 0 .099 .184 r
F
.51861 .96195 m .52108 .96748 L .52314 .97104 L F
0 g
.52314 .97104 m
.52386 .972 L
s
.487 .89349 m .48731 .89333 L .48499 .88819 L 0 .739 .4 r
F
0 g
.48499 .88819 m
.48501 .88822 L
s
.51316 .94818 m .50949 .94828 L .51158 .94822 L 0 .269 .307 r
F
.51316 .94818 m .51158 .94822 L .50949 .94828 L 0 .258 .3 r
F
.51316 .94818 m .51316 .94818 L .51158 .94822 L F
.51316 .94818 m .50385 .94706 L .50679 .94838 L 0 .343 .266 r
F
0 g
.50385 .94706 m
.50387 .94707 L
s
.50135 .94834 m
.50385 .94706 L
s
.50135 .94834 m
.50427 .94985 L
s
.50825 .9488 m
.50945 .9483 L
s
.30766 .80857 m .29569 .8119 L .3012 .81283 L 0 1 .513 r
F
0 g
.3012 .81283 m
.3037 .81837 L
s
.3949 .52646 m .38322 .53079 L .38556 .53119 L 0 1 .33 r
F
0 g
.38013 .53759 m
.38556 .53119 L
s
.3949 .52646 m .3894 .52558 L .38322 .53079 L 0 1 .33 r
F
.3949 .52646 m .39999 .51904 L .3894 .52558 L F
.3949 .52646 m .40935 .5143 L .39999 .51904 L F
.3949 .52646 m .41122 .51454 L .40935 .5143 L F
.3949 .52646 m .40503 .51976 L .41122 .51454 L F
0 g
.38905 .53162 m
.3949 .52646 L
s
.38556 .53119 m
.3949 .52646 L
s
.40503 .51976 m
.41403 .51473 L
s
.41032 .80067 m
.41068 .80652 L
s
.49571 .91117 m .487 .89349 L .4894 .89888 L 0 .593 .387 r
F
.49571 .91117 m .48731 .89333 L .487 .89349 L F
0 g
.48647 .89261 m
.487 .89349 L
s
.487 .89349 m
.48719 .89391 L
s
.45369 .9365 m .44529 .93258 L .45004 .93426 L 0 .164 .009 r
F
.45369 .9365 m .44184 .93212 L .44529 .93258 L F
0 g
.44186 .93059 m
.44529 .93258 L
s
.45004 .93426 m
.4537 .93461 L
s
.51855 .80087 m .52327 .77466 L .51932 .77638 L 0 1 .345 r
F
.51855 .80087 m .52574 .78132 L .52327 .77466 L F
0 g
.52327 .77466 m
.5236 .77387 L
s
.42999 .92783 m .42199 .92588 L .41833 .92415 L 0 0 0 r
F
.42999 .92783 m .42672 .92776 L .42199 .92588 L F
.42999 .92783 m .43015 .9286 L .42672 .92776 L F
.44184 .93212 m .43015 .9286 L .42999 .92783 L 0 .065 0 r
F
0 g
.42632 .9261 m
.42999 .92783 L
s
.42999 .92783 m
.43343 .92848 L
s
.4471 .79986 m .4424 .79226 L .43906 .79401 L 0 1 .431 r
F
.44719 .79216 m .44241 .79226 L .4391 .79016 L 0 .105 0 r
F
.44241 .79226 m .4424 .79226 L .44239 .79225 L F
.44241 .79226 m .44239 .79225 L .4391 .79016 L F
.4424 .79226 m .43937 .79117 L .43936 .79119 L 0 1 .431 r
F
.4424 .79226 m .43936 .79119 L .43906 .79401 L F
.4424 .79226 m .44355 .79514 L .43967 .79232 L 0 .105 0 r
F
.4424 .79226 m .44367 .78446 L .43972 .78792 L 0 1 .431 r
F
.4471 .79986 m .44567 .79341 L .4424 .79226 L F
.44241 .79226 m .44241 .79226 L .4424 .79226 L 0 .105 0 r
F
.44719 .79216 m .44567 .79341 L .44241 .79226 L F
.44567 .79341 m .44367 .78446 L .4424 .79226 L 0 1 .431 r
F
.44241 .79226 m .44355 .79514 L .4424 .79226 L 0 .105 0 r
F
.44567 .79341 m .44355 .79514 L .44241 .79226 L F
.44567 .79341 m .44865 .78566 L .44367 .78446 L 0 1 .431 r
F
.44567 .79344 m .44568 .79341 L .44567 .79341 L F
.4471 .79986 m .44772 .79418 L .44567 .79344 L F
.44719 .79216 m .4494 .79488 L .44772 .79418 L 0 .105 0 r
F
.4494 .79488 m .4494 .79488 L .44772 .79418 L F
.44719 .79216 m .44772 .79418 L .44567 .79341 L F
.45447 .81255 m .45534 .79852 L .45066 .79679 L 0 1 .424 r
F
.44719 .79216 m .45068 .795 L .45081 .79547 L 0 .105 0 r
F
.4471 .79986 m .45066 .79679 L .45081 .79547 L 0 1 .431 r
F
.4471 .79986 m .45081 .79547 L .4494 .79488 L F
.4494 .79488 m .45081 .79547 L .45126 .79717 L 0 .105 0 r
F
.44719 .79216 m .45081 .79547 L .4494 .79488 L F
.4494 .79488 m .45081 .79547 L .45133 .79071 L 0 1 .431 r
F
.44772 .79418 m .44865 .78566 L .44571 .79334 L F
.44772 .79418 m .44571 .79334 L .44567 .79344 L F
.44772 .79418 m .45133 .79071 L .44865 .78566 L F
.4471 .79986 m .4494 .79488 L .44772 .79418 L F
.4494 .79488 m .45133 .79071 L .44772 .79418 L F
.45447 .81255 m .45066 .79679 L .4471 .79986 L 0 1 .424 r
F
.44772 .79418 m .45126 .79717 L .44853 .79722 L 0 .105 0 r
F
.4494 .79488 m .45126 .79717 L .44772 .79418 L F
.44567 .79341 m .44853 .79722 L .44355 .79514 L F
.44772 .79418 m .44853 .79722 L .44567 .79341 L F
.44568 .79341 m .44568 .79341 L .44567 .79341 L 0 1 .431 r
F
.44568 .79341 m .44865 .78566 L .44567 .79341 L F
.4424 .79226 m .43937 .79117 L .4391 .79016 L 0 .105 0 r
F
.4424 .79226 m .43972 .78792 L .43937 .79117 L 0 1 .431 r
F
.4424 .79226 m .43967 .79232 L .43937 .79117 L 0 .105 0 r
F
.44704 .81948 m .43888 .81372 L .4423 .81823 L 0 1 .431 r
F
0 g
.44307 .81843 m
.44361 .81857 L
s
.4423 .81823 m
.44307 .81843 L
s
.81305 1.01632 m .82308 1.00651 L .81861 1.00916 L 0 1 .413 r
F
.80198 1.0234 m .81305 1.01632 L .81191 1.01338 L 0 1 .379 r
F
.31776 .89238 m .30935 .89285 L .3137 .89372 L 0 1 .489 r
F
0 g
.3137 .89372 m
.31679 .89635 L
s
.32859 .89491 m .32022 .89508 L .32457 .89601 L 0 1 .477 r
F
0 g
.32457 .89601 m
.32766 .89846 L
s
.32859 .89491 m .31776 .89238 L .32022 .89508 L 0 1 .477 r
F
0 g
.31679 .89635 m
.32022 .89508 L
s
.31776 .89238 m .30692 .89 L .30935 .89285 L 0 1 .489 r
F
0 g
.30593 .89437 m
.30935 .89285 L
s
.51316 .94818 m .5014 .93185 L .50488 .93691 L 0 .298 .327 r
F
.51316 .94818 m .50149 .93153 L .5014 .93185 L F
0 g
.50086 .93127 m
.5014 .93185 L
s
.50583 .94184 m
.50583 .94184 L
s
.50583 .94184 m
.50583 .94184 L
s
.50583 .94184 m
.50583 .94184 L
s
.50582 .94183 m
.50583 .94184 L
s
.50576 .94179 m
.50582 .94183 L
s
.50576 .94179 m
.50576 .94179 L
s
.50576 .94179 m
.50576 .94179 L
s
.50575 .94179 m
.50576 .94179 L
s
.50575 .94179 m
.50575 .94179 L
s
.50575 .94179 m
.50575 .94179 L
s
.50573 .94177 m
.50575 .94179 L
s
.50573 .94177 m
.50573 .94177 L
s
.50573 .94177 m
.50573 .94177 L
s
.50556 .94166 m
.50573 .94177 L
s
.50583 .94184 m
.50583 .94184 L
s
.50583 .94184 m
.50583 .94184 L
s
.50583 .94184 m
.50583 .94184 L
s
.50569 .9417 m
.50583 .94184 L
s
.50583 .94184 m
.50583 .94184 L
s
.50581 .94182 m
.50583 .94184 L
s
.50583 .94184 m
.50583 .94184 L
s
.50578 .9418 m
.50578 .9418 L
s
.50572 .94175 m
.50578 .9418 L
s
.50578 .9418 m
.50581 .94182 L
s
.50572 .94175 m
.50572 .94175 L
s
.50572 .94175 m
.50572 .94175 L
s
.50545 .94154 m
.50572 .94175 L
s
.35593 .80317 m .34602 .7995 L .34646 .80549 L 0 1 .479 r
F
0 g
.34143 .80914 m
.34646 .80549 L
s
.4765 .85673 m .46968 .84674 L .47273 .85294 L 0 .925 .402 r
F
.4765 .85673 m .46917 .84084 L .46968 .84674 L F
0 g
.46576 .84349 m
.46968 .84674 L
s
.47273 .85294 m
.47366 .85861 L
s
.5031 .92973 m .49687 .91712 L .4936 .91203 L 0 .422 .368 r
F
0 g
.4936 .91203 m
.49507 .91432 L
s
.49113 .90678 m
.4936 .91203 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.30692 .89 m .29848 .89076 L .30283 .89158 L 0 1 .498 r
F
0 g
.30283 .89158 m
.30593 .89437 L
s
.52716 .79969 m .52574 .78132 L .52509 .79193 L 0 1 .329 r
F
.51855 .80087 m .52509 .79193 L .52574 .78132 L 0 1 .345 r
F
0 g
.52327 .77466 m
.52574 .78132 L
s
.52574 .78132 m
.52778 .77573 L
s
.53245 .83427 m .53561 .79933 L .53228 .80919 L 0 .907 .304 r
F
0 g
.5345 .8026 m
.53561 .79933 L
s
.53456 .83516 m
.53473 .82751 L
s
.53375 .83042 m
.53456 .83516 L
s
.53396 .79008 m
.53561 .79933 L
s
.50555 .95645 m .50071 .96201 L .50363 .95964 L 0 .319 .274 r
F
.50653 .96112 m .50363 .95964 L .50071 .96201 L 0 .301 .27 r
F
0 g
.49844 .96152 m
.50071 .96201 L
s
.49911 .96615 m
.50071 .96201 L
s
.7243 .69803 m
.72464 .69699 L
s
.33941 .89765 m .33108 .89746 L .33542 .89846 L 0 1 .459 r
F
0 g
.33542 .89846 m
.33851 .90074 L
s
.33941 .89765 m .32859 .89491 L .33108 .89746 L 0 1 .459 r
F
0 g
.32766 .89846 m
.33108 .89746 L
s
.51316 .94818 m .513 .95514 L .51349 .95576 L 0 .231 .278 r
F
.51316 .94818 m .51279 .95273 L .513 .95514 L F
0 g
.51247 .95589 m
.513 .95514 L
s
.51279 .95274 m
.513 .95514 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.30692 .89 m .29608 .88776 L .29848 .89076 L 0 1 .498 r
F
0 g
.29506 .89252 m
.29848 .89076 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.49571 .91117 m .4901 .89858 L .48731 .89333 L 0 .593 .387 r
F
0 g
.48731 .89333 m
.4877 .89406 L
s
.48501 .88822 m
.48731 .89333 L
s
.48787 .89668 m
.4894 .89888 L
s
.50469 1.02564 m .50277 1.02079 L .50046 1.01898 L 0 .166 .237 r
F
.50555 .95645 m .50518 .95457 L .50243 .95399 L 0 .319 .274 r
F
.51316 .94818 m .50583 .94184 L .51002 .94546 L 0 .307 .118 r
F
.51316 .94818 m .50583 .94184 L .51002 .94546 L 0 .319 .34 r
F
0 g
.50583 .94184 m
.50583 .94184 L
s
.50583 .94184 m
.50583 .94184 L
s
.50583 .94184 m
.50583 .94184 L
s
.21888 .81313 m .2074 .81138 L .2087 .81763 L 0 1 .535 r
F
0 g
.20407 .82314 m
.2087 .81763 L
s
.48836 .89292 m .48493 .8797 L .48156 .87497 L 0 .72 .393 r
F
.26207 .72413 m .25647 .71425 L .25142 .71954 L 0 1 .53 r
F
.26207 .72413 m .26336 .71191 L .25647 .71425 L F
.26207 .72413 m .26748 .71408 L .26336 .71191 L F
.26207 .72413 m .26692 .71933 L .26748 .71408 L F
0 g
.2552 .72645 m
.26207 .72413 L
s
.26167 .72905 m
.26207 .72413 L
s
.5031 .92973 m .49573 .91779 L .49982 .92464 L 0 .422 .368 r
F
0 g
.50105 .9304 m
.50118 .93055 L
s
.5025 .93002 m .49982 .92464 L .49573 .91779 L 0 .433 .372 r
F
0 g
.49831 .92724 m
.50105 .9304 L
s
.49518 .91669 m
.49573 .91779 L
s
.4945 .91607 m
.49573 .91779 L
s
.29608 .88776 m .28523 .88836 L .29094 .88938 L 0 1 .504 r
F
0 g
.29094 .88938 m
.29506 .89252 L
s
.51316 .94817 m .51316 .94817 L .51456 .94079 L 0 .318 .12 r
F
0 g
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.46917 .84084 m .46205 .83207 L .4651 .8378 L 0 1 .41 r
F
0 g
.4651 .8378 m
.46576 .84349 L
s
.44704 .81948 m .43874 .80789 L .43888 .81372 L 0 1 .431 r
F
.44704 .81948 m .44199 .80462 L .43874 .80789 L F
.44704 .81948 m .44674 .80587 L .44199 .80462 L F
.44704 .81948 m .4498 .81082 L .44674 .80587 L F
.44704 .81948 m .44993 .81665 L .4498 .81082 L F
0 g
.44704 .81948 m
.44739 .82457 L
s
.44361 .81857 m
.44704 .81948 L
s
.24076 .71517 m .22926 .71671 L .23359 .71826 L 0 1 .536 r
F
0 g
.23359 .71826 m
.23385 .72362 L
s
.48383 .87386 m .47731 .86261 L .48036 .86931 L 0 .824 .394 r
F
.48383 .87386 m .4765 .85673 L .47731 .86261 L F
0 g
.47366 .85861 m
.47731 .86261 L
s
.48036 .86931 m
.48156 .87497 L
s
.63038 .71414 m
.6355 .72383 L
s
.6355 .72383 m
.63585 .72449 L
s
.63585 .72449 m
.63688 .72642 L
s
.35593 .80317 m .34945 .79287 L .34602 .7995 L 0 1 .479 r
F
.35593 .80317 m .3549 .78918 L .34945 .79287 L F
.35593 .80317 m .35873 .7909 L .3549 .78918 L F
.35593 .80317 m .35917 .7969 L .35873 .7909 L F
0 g
.35593 .80317 m
.35651 .80903 L
s
.35049 .80685 m
.35593 .80317 L
s
.35023 .90059 m .34194 .90002 L .34628 .9011 L 0 .938 .432 r
F
0 g
.34628 .9011 m
.34937 .90321 L
s
.35023 .90059 m .33941 .89765 L .34194 .90002 L 0 .938 .432 r
F
0 g
.33851 .90074 m
.34194 .90002 L
s
.71307 .60417 m .7297 .60367 L .72177 .60093 L 0 1 .454 r
F
0 g
.7297 .60367 m
.73284 .60649 L
s
.7297 .60367 m
.73841 .60491 L
s
.53902 .6864 m .55078 .67719 L .55185 .67335 L 0 1 .44 r
F
.53902 .6864 m .54529 .68278 L .55078 .67719 L F
0 g
.55078 .67719 m
.55454 .67701 L
s
.54529 .68278 m
.55078 .67719 L
s
.29608 .88776 m .28184 .88498 L .28523 .88836 L 0 1 .504 r
F
0 g
.28079 .89023 m
.28523 .88836 L
s
.52844 1.0925 m .53057 1.09384 L .53081 1.09493 L 0 .326 0 r
F
0 g
.53057 1.09384 m
.53215 1.09526 L
s
.51316 .94818 m .50503 .93635 L .50149 .93153 L 0 .298 .327 r
F
0 g
.50132 .9313 m
.50149 .93153 L
s
.50343 .94217 m
.50343 .94217 L
s
.50204 .94152 m
.50343 .94217 L
s
.50426 .93983 m
.50546 .94087 L
s
.505 .93979 m
.50517 .93995 L
s
.505 .93978 m
.505 .93979 L
s
.505 .93978 m
.505 .93978 L
s
.50367 .93852 m
.505 .93978 L
s
.48966 .94171 m .48585 .9427 L .48111 .94124 L 0 .283 .087 r
F
.48966 .94171 m .48951 .9429 L .48585 .9427 L F
.5014 .94536 m .48966 .94171 L .49327 .942 L 0 .309 .102 r
F
.5014 .94536 m .48951 .9429 L .48966 .94171 L F
0 g
.48627 .93962 m
.48966 .94171 L
s
.53707 .69814 m .53383 .6927 L .53319 .69745 L 0 1 .421 r
F
.53707 .69814 m .53902 .68641 L .53383 .6927 L F
.53707 .69814 m .54529 .68278 L .53902 .68641 L F
0 g
.54529 .68278 m
.54915 .68349 L
s
.53569 .98663 m .54202 .99179 L .53891 .98954 L 0 .255 0 r
F
.53849 .99082 m .54202 .99179 L .54543 .99517 L 0 .296 0 r
F
0 g
.54335 .9931 m
.54356 .99331 L
s
.54356 .99331 m
.54478 .99452 L
s
.54478 .99452 m
.54499 .99473 L
s
.54499 .99473 m
.54543 .99517 L
s
.54543 .99517 m
.54559 .99502 L
s
.53849 .99082 m .53891 .98954 L .54202 .99179 L 0 .296 0 r
F
0 g
.54202 .99179 m
.54316 .99192 L
s
.54202 .99179 m
.54335 .9931 L
s
.51316 .94818 m .50546 .94087 L .50986 .94504 L 0 .321 .341 r
F
.51316 .94818 m .50986 .94504 L .50546 .94087 L 0 .319 .34 r
F
0 g
.50455 .93994 m
.50546 .94087 L
s
.50546 .94087 m
.50546 .94087 L
s
.49447 .9116 m .49291 .90592 L .4894 .89888 L 0 .594 .389 r
F
0 g
.4894 .89888 m
.4894 .89888 L
s
.49571 .91117 m .4894 .89888 L .49291 .90592 L 0 .593 .387 r
F
0 g
.49113 .90678 m
.49422 .91124 L
s
.48719 .89391 m
.4894 .89888 L
s
.25587 .92782 m .24768 .92731 L .25233 .92808 L 0 .574 .241 r
F
0 g
.25233 .92808 m
.25659 .92951 L
s
.25587 .92782 m .24422 .92565 L .24768 .92731 L 0 .574 .241 r
F
0 g
.24501 .92786 m
.24768 .92731 L
s
.51316 .94817 m .51316 .94817 L .51489 .94086 L 0 .318 .122 r
F
0 g
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.33681 .75609 m .32687 .75117 L .33069 .7534 L 0 .364 .235 r
F
0 g
.33069 .7534 m
.33084 .75537 L
s
.28184 .88498 m .27281 .88621 L .27746 .887 L 0 1 .509 r
F
0 g
.27746 .887 m
.28079 .89023 L
s
.5014 .94536 m .49327 .942 L .49794 .94358 L 0 .309 .102 r
F
.50166 .94341 m .49794 .94358 L .49327 .942 L 0 .299 .101 r
F
0 g
.49017 .94009 m
.49327 .942 L
s
.49833 .94136 m
.50183 .94226 L
s
.49833 .94136 m
.50163 .9434 L
s
.48966 .94171 m
.49327 .942 L
s
.43466 .81218 m .42777 .8058 L .43131 .8099 L 0 1 .441 r
F
.43466 .81218 m .42589 .80183 L .42777 .8058 L F
.43466 .81218 m .42693 .80065 L .42589 .80183 L F
.43466 .81218 m .43029 .80294 L .42693 .80065 L F
.43466 .81218 m .43373 .80717 L .43029 .80294 L F
0 g
.4313 .8099 m
.43137 .81055 L
s
.43137 .81055 m
.43188 .81557 L
s
.43466 .81218 m .4356 .81113 L .43373 .80717 L 0 1 .441 r
F
0 g
.43466 .81218 m
.43661 .81624 L
s
.43131 .8099 m
.43466 .81218 L
s
.51316 .94818 m .51349 .95576 L .51365 .95381 L 0 .231 .278 r
F
0 g
.51349 .95576 m
.51406 .95777 L
s
.52009 .7549 m .51703 .74414 L .51687 .7514 L 0 1 .377 r
F
.52009 .7549 m .52086 .73638 L .51703 .74414 L F
.51932 .77638 m .52009 .7549 L .51663 .76308 L 0 1 .36 r
F
.51316 .94818 m .52491 .93888 L .52144 .9423 L 0 .29 .12 r
F
0 g
.52128 .94019 m
.52482 .93768 L
s
.52491 .93888 m
.52506 .9387 L
s
.51316 .94817 m .51679 .92775 L .518 .91733 L 0 .399 .268 r
F
0 g
.518 .91733 m
.51847 .91451 L
s
.51599 .92383 m
.51754 .9151 L
s
.51599 .92383 m
.51684 .91194 L
s
.46917 .84084 m .46183 .82615 L .46205 .83207 L 0 1 .41 r
F
0 g
.45786 .82955 m
.46205 .83207 L
s
.28184 .88498 m .27024 .88281 L .27281 .88621 L 0 1 .509 r
F
0 g
.26917 .88846 m
.27281 .88621 L
s
.52163 .72039 m .5316 .71048 L .53224 .70507 L 0 1 .417 r
F
.52163 .72039 m .52706 .71704 L .5316 .71048 L F
0 g
.5316 .71048 m
.53513 .71163 L
s
.52706 .71704 m
.5316 .71048 L
s
.64242 .61465 m .66126 .61171 L .65736 .61026 L 0 1 .409 r
F
0 g
.66126 .61171 m
.6691 .6111 L
s
.36104 .90377 m .35279 .90279 L .35713 .90396 L 0 .81 .394 r
F
0 g
.35713 .90396 m
.36022 .90589 L
s
.36104 .90377 m .35023 .90059 L .35279 .90279 L 0 .81 .394 r
F
0 g
.34937 .90321 m
.35279 .90279 L
s
.50653 .96112 m .49991 .96931 L .50241 .96893 L 0 .301 .27 r
F
0 g
.49862 .97348 m
.49991 .96931 L
s
.50422 .98505 m .49842 .99089 L .49977 .99497 L 0 .261 .267 r
F
0 g
.49645 .98478 m
.49713 .98494 L
s
.50422 .98505 m .49898 .98535 L .49842 .99089 L 0 .261 .267 r
F
0 g
.49585 .98953 m
.49842 .99089 L
s
.51316 .94818 m .50517 .93995 L .50973 .94465 L 0 .321 .341 r
F
.51316 .94818 m .50973 .94465 L .50517 .93995 L F
0 g
.50427 .93895 m
.50517 .93995 L
s
.50517 .93995 m
.50517 .93995 L
s
.51316 .94818 m .50517 .94443 L .50187 .94227 L 0 .316 .119 r
F
0 g
.50183 .94226 m
.50187 .94227 L
s
.4356 .81113 m
.43887 .81372 L
s
.43886 .81323 m
.43888 .81372 L
s
.46917 .84084 m .4646 .82398 L .46183 .82615 L 0 1 .41 r
F
.46917 .84084 m .46867 .82702 L .4646 .82398 L F
.46917 .84084 m .47133 .83324 L .46867 .82702 L F
.46917 .84084 m .47154 .83917 L .47133 .83324 L F
.4765 .85673 m .47154 .83917 L .46917 .84084 L 0 .925 .402 r
F
0 g
.4651 .8378 m
.46917 .84084 L
s
.46917 .84084 m
.46968 .84674 L
s
.51747 .96061 m .52108 .96748 L .51922 .9638 L 0 .113 .186 r
F
.51861 .96195 m .51922 .9638 L .52108 .96748 L 0 .099 .184 r
F
0 g
.52108 .96748 m
.52177 .96943 L
s
.52108 .96748 m
.52314 .97104 L
s
.76633 .81803 m .77898 .8026 L .78035 .80873 L 0 .127 .054 r
F
0 g
.77898 .8026 m
.78365 .79839 L
s
.4765 .85673 m .47531 .84296 L .47154 .83917 L 0 .925 .402 r
F
.4765 .85673 m .47797 .84968 L .47531 .84296 L F
.4765 .85673 m .47848 .85558 L .47797 .84968 L F
.48383 .87386 m .47848 .85558 L .4765 .85673 L 0 .824 .394 r
F
0 g
.47273 .85294 m
.4765 .85673 L
s
.4765 .85673 m
.47731 .86261 L
s
.8183 .80027 m .82493 .80188 L .82034 .80225 L 0 0 0 r
F
.8183 .80027 m .82984 .8 L .82493 .80188 L F
.55754 .66773 m .55453 .66435 L .55346 .66784 L 0 1 .407 r
F
.55754 .66773 m .56057 .65932 L .55453 .66435 L F
.55754 .66773 m .56752 .65612 L .56057 .65932 L F
0 g
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.38323 .79838 m .374 .79871 L .37781 .80087 L 0 1 .461 r
F
0 g
.37781 .80087 m
.37853 .80657 L
s
.27024 .88281 m .26118 .88427 L .26583 .88504 L 0 1 .513 r
F
0 g
.26583 .88504 m
.26917 .88846 L
s
.51316 .94818 m .51316 .94818 L .51521 .94101 L 0 .315 .124 r
F
0 g
.4097 .781 m
.41036 .78121 L
s
.50202 .93048 m .5022 .93027 L .49909 .92523 L 0 .445 .377 r
F
0 g
.4985 .926 m
.50131 .93014 L
s
.50173 .93012 m
.50182 .93023 L
s
.50131 .93014 m
.50135 .9302 L
s
.50135 .9302 m
.50166 .93065 L
s
.51316 .94818 m .51027 .9494 L .51192 .9487 L 0 .258 .3 r
F
.51316 .94818 m .51192 .9487 L .51027 .9494 L 0 .248 .293 r
F
0 g
.50939 .9504 m
.51027 .9494 L
s
.51027 .9494 m
.51027 .9494 L
s
.51316 .94818 m .50165 .93109 L .50503 .93635 L 0 .29 .321 r
F
.51316 .94818 m .50178 .93083 L .50165 .93109 L F
0 g
.50133 .93072 m
.50165 .93109 L
s
.50155 .93557 m
.50497 .93908 L
s
.50314 .94111 m
.5047 .94246 L
s
.5047 .94246 m
.5047 .94246 L
s
.5047 .94246 m
.5047 .94247 L
s
.50343 .94217 m
.50426 .94256 L
s
.50426 .94256 m
.50426 .94256 L
s
.77984 1.04039 m .78296 1.04411 L .78822 1.03729 L 0 1 .277 r
F
.77984 1.04039 m .77862 1.04731 L .78296 1.04411 L F
0 g
.78296 1.04411 m
.78331 1.04502 L
s
.24181 .81647 m .23308 .8075 L .23035 .81483 L 0 1 .533 r
F
.24181 .81647 m .23852 .80258 L .23308 .8075 L F
.24181 .81647 m .24305 .80336 L .23852 .80258 L F
.24181 .81647 m .24445 .80933 L .24305 .80336 L F
0 g
.23637 .82136 m
.24181 .81647 L
s
.24181 .81647 m
.24328 .82226 L
s
.75981 .60332 m .76077 .59828 L .75703 .59942 L 0 1 .493 r
F
.75981 .60332 m .76936 .60076 L .76077 .59828 L F
.50323 1.00521 m .49994 1.01358 L .50222 1.01451 L 0 .223 .259 r
F
0 g
.49994 1.01358 m
.50046 1.01898 L
s
.27024 .88281 m .25864 .8807 L .26118 .88427 L 0 1 .513 r
F
0 g
.25755 .88674 m
.26118 .88427 L
s
.43373 .80717 m
.4356 .81113 L
s
.51861 .96195 m .52404 .97211 L .52298 .96975 L 0 .099 .184 r
F
0 g
.52404 .97211 m
.5254 .97376 L
s
.48836 .89292 m .48798 .88687 L .48493 .8797 L 0 .72 .393 r
F
.48836 .89292 m .48945 .89253 L .48798 .88687 L F
.49662 .91106 m .48836 .89292 L .49011 .89858 L 0 .576 .38 r
F
.49662 .91106 m .48945 .89253 L .48836 .89292 L F
0 g
.4877 .89406 m
.4901 .89858 L
s
.48499 .88819 m
.48836 .89292 L
s
.48903 .89509 m
.48907 .89521 L
s
.48836 .89292 m
.48903 .89509 L
s
.73219 .68348 m
.73228 .68248 L
s
.51316 .94818 m .50432 .94988 L .50465 .95176 L 0 .329 .264 r
F
0 g
.51178 .95358 m
.51193 .95164 L
s
.51105 .95263 m
.51193 .95163 L
s
.50986 .95104 m
.51109 .95052 L
s
.51316 .94818 m .50679 .94838 L .50432 .94988 L 0 .329 .264 r
F
0 g
.50427 .94985 m
.50432 .94988 L
s
.59295 .65693 m
.59516 .65939 L
s
.59516 .65939 m
.59629 .66065 L
s
.51316 .94818 m .50497 .93908 L .50965 .94428 L 0 .318 .34 r
F
.51316 .94818 m .50965 .94428 L .50497 .93908 L 0 .321 .341 r
F
0 g
.50497 .93908 m
.50497 .93908 L
s
.50142 .93485 m
.50497 .93908 L
s
.51867 .92084 m .51911 .9233 L .52131 .91418 L 0 .466 .264 r
F
0 g
.51882 .91908 m
.51989 .90585 L
s
.49571 .91117 m .49352 .90573 L .4901 .89858 L 0 .593 .387 r
F
0 g
.4901 .89858 m
.4901 .89858 L
s
.49662 .91106 m .49011 .89858 L .49352 .90573 L 0 .576 .38 r
F
0 g
.48907 .89521 m
.49011 .89858 L
s
.50201 .97719 m .49898 .98535 L .50107 .98204 L 0 .283 .275 r
F
.50422 .98505 m .50107 .98204 L .49898 .98535 L 0 .261 .267 r
F
0 g
.49713 .98494 m
.49898 .98535 L
s
.49842 .99089 m
.49898 .98535 L
s
.49447 .9116 m .49509 .91137 L .49291 .90592 L 0 .594 .389 r
F
.50381 .92962 m .49447 .9116 L .49687 .91712 L 0 .411 .363 r
F
.50381 .92962 m .49509 .91137 L .49447 .9116 L F
0 g
.4985 .926 m
.50173 .93012 L
s
.49422 .91124 m
.49447 .9116 L
s
.49504 .91291 m
.496 .91512 L
s
.49447 .9116 m
.49504 .91291 L
s
.25864 .8807 m .24954 .88238 L .2542 .88313 L 0 1 .516 r
F
0 g
.2542 .88313 m
.25755 .88674 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m .51316 .94817 L .51087 .9319 L 0 .343 .267 r
F
.51316 .94817 m .51316 .94817 L .5106 .93233 L 0 .349 .269 r
F
.51316 .94817 m .51316 .94817 L .51052 .93249 L 0 .353 .269 r
F
.55832 .48857 m .56932 .4919 L .57848 .49557 L 0 0 0 r
F
0 g
.56932 .4919 m
.57664 .49284 L
s
.57664 .49284 m
.578 .49375 L
s
.53223 .98212 m
.53243 .98237 L
s
.53252 .98249 m
.53451 .98499 L
s
.53158 .98131 m
.53185 .98165 L
s
.53194 .98176 m
.53223 .98212 L
s
.42728 .80579 m
.42776 .8058 L
s
.4228 .80566 m
.42728 .80579 L
s
.51316 .94818 m .51422 .95667 L .51471 .95727 L 0 .231 .277 r
F
.51316 .94818 m .51365 .95381 L .51422 .95667 L F
0 g
.51406 .95777 m
.51422 .95667 L
s
.37233 .90735 m .36379 .90583 L .36832 .90715 L 0 .651 .338 r
F
.37233 .90735 m .36104 .90377 L .36379 .90583 L F
0 g
.36022 .90589 m
.36379 .90583 L
s
.36832 .90715 m
.37156 .90893 L
s
.48937 .94471 m .48111 .94124 L .48585 .9427 L 0 .298 .087 r
F
.48937 .94471 m .47751 .94119 L .48111 .94124 L F
0 g
.47772 .93915 m
.48111 .94124 L
s
.51316 .94817 m .51316 .94817 L .51117 .93162 L 0 .339 .265 r
F
.56057 .65932 m .57387 .65159 L .57539 .64875 L 0 1 .431 r
F
.56057 .65932 m .56752 .65612 L .57387 .65159 L F
0 g
.57387 .65159 m
.57772 .65126 L
s
.56752 .65612 m
.57158 .65602 L
s
.56752 .65612 m
.57387 .65159 L
s
.51316 .94818 m .51316 .94818 L .5155 .94126 L 0 .31 .125 r
F
.51316 .94817 m .51316 .94817 L .51029 .93309 L 0 .363 .271 r
F
.51316 .94818 m .50526 .93589 L .50178 .93083 L 0 .29 .321 r
F
0 g
.50166 .93065 m
.50178 .93083 L
s
.50135 .9344 m
.50485 .93828 L
s
.50129 .93374 m
.50485 .93828 L
s
.58561 .49883 m .57971 .49712 L .57848 .49557 L 0 0 0 r
F
.58561 .49883 m .58905 .50298 L .57971 .49712 L F
.58561 .49883 m .60029 .50922 L .58905 .50298 L F
.58561 .49883 m .60741 .51247 L .60029 .50922 L F
0 g
.60307 .50728 m
.60466 .50877 L
s
.58561 .49883 m .60568 .51057 L .60741 .51247 L 0 0 0 r
F
.58561 .49883 m .59633 .50473 L .60568 .51057 L F
0 g
.59633 .50473 m
.60307 .50728 L
s
.578 .49375 m
.58561 .49883 L
s
.25864 .8807 m .24703 .87863 L .24954 .88238 L 0 1 .516 r
F
0 g
.24593 .88508 m
.24954 .88238 L
s
.41032 .80066 m .4013 .7985 L .40501 .80161 L 0 1 .451 r
F
0 g
.40501 .80161 m
.40559 .80733 L
s
.46183 .82615 m .4544 .8185 L .45746 .82381 L 0 1 .417 r
F
0 g
.45746 .82381 m
.45786 .82955 L
s
.57535 .64473 m
.57812 .64698 L
s
.30766 .80857 m .29399 .80624 L .29569 .8119 L 0 1 .513 r
F
0 g
.28982 .81618 m
.29569 .8119 L
s
.524 1.08429 m .52788 1.08996 L .52713 1.08939 L 0 0 .105 r
F
0 g
.52551 1.08582 m
.52788 1.08996 L
s
.52844 1.0925 m .52714 1.08939 L .52789 1.08996 L 0 .326 0 r
F
0 g
.52789 1.08996 m
.52935 1.09187 L
s
.29897 .6 m .29079 .59939 L .29439 .60102 L 0 1 .492 r
F
.29897 .6 m .29005 .59598 L .29079 .59939 L F
.29897 .6 m .29267 .59306 L .29005 .59598 L F
.29897 .6 m .29726 .59205 L .29267 .59306 L F
.29897 .6 m .30077 .5936 L .29726 .59205 L F
.29897 .6 m .3015 .59701 L .30077 .5936 L F
0 g
.29897 .6 m
.29977 .60358 L
s
.29439 .60102 m
.29897 .6 L
s
.3015 .59701 m
.30601 .59601 L
s
.55832 .48857 m .5513 .48814 L .5506 .48695 L 0 0 0 r
F
.55832 .48857 m .56047 .49181 L .5513 .48814 L F
.55832 .48857 m .57199 .49551 L .56047 .49181 L F
.55832 .48857 m .57971 .49712 L .57199 .49551 L F
.55832 .48857 m .57848 .49557 L .57971 .49712 L F
0 g
.57692 .49494 m
.57848 .49557 L
s
.57885 .49574 m
.58561 .49883 L
s
.57848 .49557 m
.57885 .49574 L
s
.54955 .48486 m
.55832 .48857 L
s
.56932 .4919 m
.57692 .49494 L
s
.2074 .81138 m .19716 .81601 L .20178 .81667 L 0 1 .536 r
F
0 g
.20178 .81667 m
.20407 .82314 L
s
.51316 .94818 m .51109 .95052 L .51227 .94918 L 0 .248 .293 r
F
.51316 .94818 m .51227 .94918 L .51109 .95052 L 0 .24 .286 r
F
0 g
.51109 .95052 m
.51109 .95052 L
s
.51057 .952 m
.51109 .95052 L
s
.51316 .94817 m .51316 .94817 L .51149 .93152 L 0 .338 .264 r
F
.51316 .94817 m .51316 .94817 L .51008 .93382 L 0 .375 .273 r
F
0 g
.53722 .93598 m
.54048 .93323 L
s
.53856 .93764 m
.54048 .93323 L
s
.26515 .61023 m .25237 .61446 L .25628 .61593 L 0 1 .511 r
F
0 g
.25412 .62367 m
.25628 .61593 L
s
.51316 .94818 m .52128 .94019 L .51665 .94475 L 0 .291 .122 r
F
.51316 .94818 m .51665 .94475 L .52128 .94019 L 0 .29 .12 r
F
0 g
.52128 .94019 m
.52128 .94019 L
s
.52128 .94019 m
.52464 .93596 L
s
.68456 .70922 m
.68461 .70731 L
s
.68461 .70731 m
.68461 .70728 L
s
.68284 .71119 m
.68385 .70802 L
s
.68385 .70802 m
.68387 .70796 L
s
.68387 .70796 m
.68454 .70586 L
s
.49115 .8921 m .48493 .8797 L .48798 .88687 L 0 .704 .385 r
F
.49115 .8921 m .48383 .87386 L .48493 .8797 L F
0 g
.48156 .87497 m
.48493 .8797 L
s
.51747 .96061 m .51701 .96006 L .5177 .96202 L 0 .113 .186 r
F
0 g
.51724 .96071 m
.5177 .96202 L
s
.51707 .96024 m
.51724 .96071 L
s
.51669 .96 m
.5177 .96202 L
s
.71307 .60417 m .71326 .59992 L .70988 .60133 L 0 1 .454 r
F
.71307 .60417 m .72177 .60093 L .71326 .59992 L F
.24703 .87863 m .23791 .88052 L .24256 .88126 L 0 1 .518 r
F
0 g
.24256 .88126 m
.24593 .88508 L
s
.51316 .94818 m .50485 .93828 L .5096 .94393 L 0 .313 .337 r
F
.51316 .94818 m .5096 .94393 L .50485 .93828 L 0 .318 .34 r
F
0 g
.50507 .94294 m
.50508 .94294 L
s
.50507 .94294 m
.50507 .94294 L
s
.50426 .94256 m
.50507 .94294 L
s
.50355 .94518 m
.50626 .9451 L
s
.50485 .93828 m
.50485 .93828 L
s
.50485 .93828 m
.50485 .93828 L
s
.54633 .85298 m .54787 .81548 L .54586 .83417 L 0 .85 .275 r
F
.53952 .84139 m .54586 .83417 L .54787 .81548 L 0 .88 .289 r
F
0 g
.54699 .80093 m
.54787 .81548 L
s
.54787 .81548 m
.55165 .80301 L
s
.51932 .77638 m .51663 .76308 L .51648 .77142 L 0 1 .36 r
F
.51855 .80087 m .51932 .77638 L .51624 .78475 L 0 1 .345 r
F
.24076 .71517 m .23007 .711 L .22926 .71671 L 0 1 .536 r
F
0 g
.22292 .72003 m
.22926 .71671 L
s
.51316 .94817 m .51599 .92383 L .51438 .93773 L 0 .399 .268 r
F
.51316 .94817 m .51438 .93773 L .51599 .92383 L 0 .397 .267 r
F
0 g
.51599 .92383 m
.51599 .92383 L
s
.51599 .92383 m
.51599 .92383 L
s
.46183 .82615 m .45447 .81255 L .4544 .8185 L 0 1 .417 r
F
0 g
.44993 .81665 m
.4544 .8185 L
s
.46183 .82615 m .45764 .80991 L .45447 .81255 L 0 1 .417 r
F
.46183 .82615 m .46201 .81225 L .45764 .80991 L F
.46183 .82615 m .46467 .81802 L .46201 .81225 L F
.46183 .82615 m .4646 .82398 L .46467 .81802 L F
0 g
.46183 .82615 m
.46205 .83207 L
s
.45746 .82381 m
.46183 .82615 L
s
.26751 .93006 m .25931 .92925 L .26397 .93004 L 0 .534 .229 r
F
.26751 .93006 m .25587 .92782 L .25931 .92925 L F
0 g
.25659 .92951 m
.25931 .92925 L
s
.26397 .93004 m
.26818 .93123 L
s
.51316 .94818 m .50628 .9451 L .51021 .94686 L 0 .358 .267 r
F
.51316 .94818 m .51021 .94686 L .50628 .9451 L 0 .343 .266 r
F
0 g
.50626 .9451 m
.50628 .9451 L
s
.50592 .94479 m
.50628 .9451 L
s
.49291 .90592 m
.49293 .90596 L
s
.49293 .90596 m
.49474 .91051 L
s
.49474 .91051 m
.49488 .91086 L
s
.37622 .67298 m
.38159 .6708 L
s
.59633 .50473 m
.60444 .5098 L
s
.51316 .94817 m .51316 .94817 L .50991 .93466 L 0 .386 .274 r
F
.33681 .75609 m .32744 .75002 L .32687 .75117 L 0 .364 .235 r
F
0 g
.32115 .75025 m
.32687 .75117 L
s
.51316 .94817 m .51316 .94817 L .51183 .93159 L 0 .341 .264 r
F
0 g
.6906 .70301 m
.6909 .70231 L
s
.69052 .7032 m
.6906 .70301 L
s
.6909 .70231 m
.69094 .70221 L
s
.69094 .70221 m
.69165 .70055 L
s
.69275 .69796 m
.69351 .69617 L
s
.69165 .70055 m
.69275 .69796 L
s
.52518 .83003 m .53057 .79943 L .52716 .79969 L 0 .929 .319 r
F
.52518 .83003 m .53228 .80919 L .53057 .79943 L F
0 g
.53057 .79943 m
.5315 .79686 L
s
.52086 .73638 m .52706 .71705 L .52163 .72039 L 0 1 .397 r
F
0 g
.52706 .71705 m
.53064 .71947 L
s
.53017 .92649 m .53538 .89789 L .53211 .9111 L 0 .407 .252 r
F
.53017 .92649 m .53862 .89855 L .53538 .89789 L F
.52831 .90912 m .53211 .9111 L .53538 .89789 L 0 .474 .256 r
F
0 g
.53538 .89789 m
.53687 .89819 L
s
.53538 .89789 m
.53667 .88205 L
s
.48383 .87386 m .48195 .86013 L .47848 .85558 L 0 .824 .394 r
F
.48383 .87386 m .4846 .86734 L .48195 .86013 L F
.48383 .87386 m .48541 .87323 L .4846 .86734 L F
.49115 .8921 m .48541 .87323 L .48383 .87386 L 0 .704 .385 r
F
0 g
.48383 .87386 m
.48493 .8797 L
s
.48036 .86931 m
.48383 .87386 L
s
.52086 .73638 m .51744 .72764 L .51728 .73396 L 0 1 .397 r
F
.52086 .73638 m .52163 .72039 L .51744 .72764 L F
.24703 .87863 m .23542 .87659 L .23791 .88052 L 0 1 .518 r
F
0 g
.2343 .88344 m
.23791 .88052 L
s
.51316 .94818 m .51471 .95727 L .5145 .95486 L 0 .231 .277 r
F
0 g
.51471 .95727 m
.51565 .95962 L
s
.73306 .65835 m .74897 .64541 L .74246 .6523 L 0 0 0 r
F
0 g
.74897 .64541 m
.7564 .6395 L
s
.74897 .64541 m
.75085 .64142 L
s
.74805 .66973 m
.74852 .65807 L
s
.53055 .48411 m .5417 .48523 L .5506 .48695 L 0 0 0 r
F
0 g
.5417 .48523 m
.54955 .48486 L
s
.38323 .79838 m .3739 .79258 L .374 .79871 L 0 1 .461 r
F
0 g
.36886 .80149 m
.374 .79871 L
s
.38323 .79838 m .37757 .78656 L .3739 .79258 L 0 1 .461 r
F
.38323 .79838 m .383 .78406 L .37757 .78656 L F
.38323 .79838 m .38656 .78675 L .383 .78406 L F
.38323 .79838 m .38666 .79289 L .38656 .78675 L F
0 g
.37781 .80087 m
.38323 .79838 L
s
.51316 .94818 m .51316 .94818 L .51577 .94159 L 0 .306 .125 r
F
.50381 .92962 m .49687 .91712 L .5007 .92426 L 0 .411 .363 r
F
0 g
.50192 .92983 m
.50194 .92986 L
s
.5031 .92973 m .5007 .92426 L .49687 .91712 L 0 .422 .368 r
F
0 g
.49507 .91432 m
.49687 .91712 L
s
.496 .91512 m
.49687 .91712 L
s
.51316 .94818 m .50202 .93048 L .50526 .93589 L 0 .283 .316 r
F
.51316 .94818 m .51316 .94818 L .50973 .94272 L 0 .384 .27 r
F
.51316 .94818 m .5022 .93027 L .50202 .93048 L 0 .283 .316 r
F
0 g
.50182 .93023 m
.50202 .93048 L
s
.50128 .93274 m
.50482 .93755 L
s
.50127 .93333 m
.50482 .93755 L
s
.50508 .94294 m
.50545 .94311 L
s
.5047 .94247 m
.50544 .9431 L
s
.51316 .94817 m .51316 .94817 L .50978 .93559 L 0 .395 .275 r
F
.76137 .64138 m .77673 .63215 L .78072 .63079 L 0 0 0 r
F
.76137 .64138 m .76845 .63667 L .77673 .63215 L F
0 g
.77673 .63215 m
.77809 .62975 L
s
.77646 .63229 m
.77673 .63215 L
s
.50381 .92962 m .49819 .91673 L .49509 .91137 L 0 .411 .363 r
F
0 g
.49509 .91137 m
.49602 .91298 L
s
.49909 .92523 m
.50192 .92983 L
s
.49488 .91086 m
.49509 .91137 L
s
.51512 1.06556 m .51781 1.07238 L .51753 1.071 L 0 0 .151 r
F
.52247 1.08075 m .51781 1.07238 L .52057 1.07807 L 0 0 .116 r
F
.52247 1.08075 m .51753 1.071 L .51781 1.07238 L F
0 g
.51544 1.06897 m
.51781 1.07238 L
s
.42056 .51071 m .40935 .5143 L .41122 .51454 L 0 .971 .236 r
F
0 g
.40503 .51976 m
.41122 .51454 L
s
.42056 .51071 m .41624 .51025 L .40935 .5143 L 0 .971 .236 r
F
.42056 .51071 m .42731 .50508 L .41624 .51025 L F
.42056 .51071 m .43666 .50124 L .42731 .50508 L F
.42056 .51071 m .43805 .50129 L .43666 .50124 L F
.42056 .51071 m .43114 .50535 L .43805 .50129 L F
0 g
.41403 .51473 m
.42056 .51071 L
s
.41122 .51454 m
.42056 .51071 L
s
.43114 .50535 m
.44012 .50119 L
s
.23542 .87659 m .22627 .87869 L .23092 .87942 L 0 1 .521 r
F
0 g
.23092 .87942 m
.2343 .88344 L
s
.51316 .94817 m .51316 .94817 L .51218 .93185 L 0 .346 .263 r
F
.47751 .94119 m .46905 .94087 L .46556 .93868 L 0 .263 .068 r
F
.51316 .94818 m .51316 .94818 L .51192 .9487 L 0 .248 .293 r
F
.51316 .94818 m .50465 .95176 L .50738 .95167 L 0 .329 .264 r
F
0 g
.50243 .95399 m
.50465 .95176 L
s
.51316 .94818 m .51193 .95163 L .51264 .94966 L 0 .24 .286 r
F
.51316 .94818 m .51264 .94966 L .51193 .95163 L 0 .234 .281 r
F
0 g
.51193 .95163 m
.51193 .95163 L
s
.51193 .95164 m
.51193 .95163 L
s
.38362 .9112 m .37512 .90921 L .37965 .91063 L 0 .54 .267 r
F
.38362 .9112 m .37233 .90735 L .37512 .90921 L F
0 g
.37156 .90893 m
.37512 .90921 L
s
.37965 .91063 m
.38289 .91222 L
s
.51855 .80087 m .52201 .80031 L .52509 .79193 L 0 1 .345 r
F
.41032 .80066 m .40128 .79253 L .4013 .7985 L 0 1 .451 r
F
.41032 .80066 m .40495 .78768 L .40128 .79253 L F
0 g
.39614 .7999 m
.4013 .7985 L
s
.41032 .80066 m .41027 .78673 L .40495 .78768 L 0 1 .451 r
F
.41032 .80066 m .41368 .79032 L .41027 .78673 L F
.41032 .80066 m .4137 .79629 L .41368 .79032 L F
0 g
.40501 .80161 m
.41032 .80066 L
s
.49662 .91106 m .49255 .89786 L .48945 .89253 L 0 .576 .38 r
F
0 g
.48945 .89253 m
.49034 .89406 L
s
.48798 .88687 m
.48945 .89253 L
s
.52247 1.08075 m .52057 1.07807 L .524 1.08429 L 0 0 .116 r
F
0 g
.51781 1.07238 m
.52057 1.07807 L
s
.51821 1.07395 m
.52057 1.07807 L
s
.34602 .7995 m .33638 .80243 L .34042 .80359 L 0 1 .483 r
F
0 g
.34042 .80359 m
.34143 .80914 L
s
.51316 .94818 m .50546 .94312 L .50986 .94601 L 0 .316 .119 r
F
.51316 .94818 m .50986 .94601 L .50546 .94312 L 0 .307 .118 r
F
0 g
.50545 .94311 m
.50546 .94312 L
s
.50544 .9431 m
.50546 .94312 L
s
.50323 1.00521 m .50183 1.00111 L .49954 1.0002 L 0 .223 .259 r
F
.68027 1.11641 m .67614 1.1106 L .67574 1.10435 L 0 .174 .068 r
F
0 g
.66948 1.10208 m
.67574 1.10435 L
s
.51316 .94818 m .50482 .93755 L .50958 .94362 L 0 .306 .332 r
F
.51316 .94818 m .50958 .94362 L .50482 .93755 L 0 .313 .337 r
F
0 g
.50482 .93755 m
.50482 .93755 L
s
.50482 .93755 m
.50482 .93755 L
s
.44889 .64152 m .44039 .64282 L .4421 .64309 L 0 .947 .252 r
F
0 g
.43813 .64547 m
.4421 .64309 L
s
.44889 .64152 m .44493 .64083 L .44039 .64282 L 0 .947 .252 r
F
.44889 .64152 m .45272 .63844 L .44493 .64083 L F
.44889 .64152 m .45951 .63688 L .45272 .63844 L F
.44889 .64152 m .46078 .63718 L .45951 .63688 L F
.44889 .64152 m .45622 .63917 L .46078 .63718 L F
0 g
.44467 .64336 m
.44889 .64152 L
s
.4421 .64309 m
.44889 .64152 L
s
.45622 .63917 m
.46268 .63749 L
s
.43874 .80789 m .43029 .80293 L .43373 .80717 L 0 1 .437 r
F
0 g
.43457 .80729 m
.43542 .80741 L
s
.43427 .80725 m
.43457 .80729 L
s
.43373 .80717 m
.43427 .80725 L
s
.23542 .87659 m .2238 .87456 L .22627 .87869 L 0 1 .521 r
F
0 g
.22268 .88183 m
.22627 .87869 L
s
.53055 .48411 m .52248 .48468 L .5223 .48387 L 0 0 0 r
F
.53055 .48411 m .53137 .48641 L .52248 .48468 L F
.53055 .48411 m .54306 .4879 L .53137 .48641 L F
.53055 .48411 m .5513 .48814 L .54306 .4879 L F
0 g
.55134 .48711 m
.55832 .48857 L
s
.53055 .48411 m .5506 .48695 L .5513 .48814 L 0 0 0 r
F
0 g
.5506 .48695 m
.55134 .48711 L
s
.52205 .48238 m
.53055 .48411 L
s
.5417 .48523 m
.5506 .48695 L
s
.47751 .94119 m .47381 .94244 L .46905 .94087 L 0 .263 .068 r
F
.47751 .94119 m .47744 .94258 L .47381 .94244 L F
.48937 .94471 m .47744 .94258 L .47751 .94119 L 0 .298 .087 r
F
0 g
.47751 .94119 m
.48111 .94124 L
s
.47401 .93899 m
.47751 .94119 L
s
.5025 .93002 m .50273 .92988 L .49982 .92464 L 0 .433 .372 r
F
0 g
.5026 .92966 m
.50267 .92977 L
s
.50235 .92981 m
.5024 .92987 L
s
.50194 .92986 m
.50211 .93013 L
s
.2074 .81138 m .19591 .80958 L .19716 .81601 L 0 1 .536 r
F
0 g
.1925 .82169 m
.19716 .81601 L
s
.20178 .81667 m
.2066 .81213 L
s
.51316 .94817 m .51316 .94817 L .50968 .93662 L 0 .402 .275 r
F
.51316 .94818 m .51519 .95786 L .51534 .95805 L 0 .232 .278 r
F
.51316 .94818 m .5145 .95486 L .51519 .95786 L F
0 g
.51519 .95786 m
.51564 .95959 L
s
.49571 .91117 m .49592 .91113 L .49352 .90573 L 0 .593 .387 r
F
0 g
.49352 .90573 m
.49364 .906 L
s
.49291 .90592 m
.49563 .91102 L
s
.44184 .93212 m .43381 .93062 L .43015 .9286 L 0 .065 0 r
F
.44184 .93212 m .43853 .93255 L .43381 .93062 L F
.44184 .93212 m .44197 .93319 L .43853 .93255 L F
.45369 .9365 m .44197 .93319 L .44184 .93212 L 0 .164 .009 r
F
0 g
.43817 .9301 m
.44184 .93212 L
s
.44184 .93212 m
.44529 .93258 L
s
.58185 .64457 m .57922 .64188 L .57769 .64459 L 0 1 .363 r
F
.58185 .64457 m .58601 .63816 L .57922 .64188 L F
.58185 .64457 m .59351 .63592 L .58601 .63816 L F
0 g
.57815 .64696 m
.58185 .64457 L
s
.57812 .64698 m
.57815 .64696 L
s
.51316 .94818 m .50558 .93553 L .5022 .93027 L 0 .283 .316 r
F
0 g
.50211 .93013 m
.5022 .93027 L
s
.5014 .93185 m
.50488 .93691 L
s
.50131 .93237 m
.50488 .9369 L
s
.52163 .72039 m .53224 .70507 L .52829 .70355 L 0 1 .417 r
F
0 g
.53224 .70507 m
.53707 .69814 L
s
.52507 .94539 m .53694 .93622 L .53337 .94106 L 0 .277 .136 r
F
0 g
.53684 .93635 m
.53694 .93622 L
s
.53505 .93879 m
.53684 .93635 L
s
.53452 .93951 m
.53505 .93879 L
s
.53694 .93622 m
.53722 .93598 L
s
.52525 .94033 m
.52851 .93464 L
s
.2238 .87456 m .21463 .87687 L .21928 .8776 L 0 1 .523 r
F
0 g
.21928 .8776 m
.22268 .88183 L
s
.43874 .80789 m .43043 .79698 L .43029 .80293 L 0 1 .437 r
F
.43874 .80789 m .43404 .79329 L .43043 .79698 L F
.43874 .80789 m .43906 .79401 L .43404 .79329 L F
.43874 .80789 m .44213 .79867 L .43906 .79401 L F
.43874 .80789 m .44199 .80462 L .44213 .79867 L F
0 g
.43874 .80789 m
.43886 .81323 L
s
.43542 .80741 m
.43874 .80789 L
s
.51316 .94818 m .51534 .95805 L .51477 .95519 L 0 .232 .278 r
F
0 g
.51534 .95805 m
.51542 .95827 L
s
.50166 .94341 m .50154 .94419 L .49794 .94358 L 0 .299 .101 r
F
.51316 .94818 m .51316 .94818 L .51021 .94686 L 0 .343 .266 r
F
.51316 .94818 m .50166 .94341 L .50517 .94443 L 0 .326 .12 r
F
.51316 .94818 m .50154 .94419 L .50166 .94341 L F
0 g
.50163 .9434 m
.50166 .94341 L
s
.5014 .94536 m .49297 .94468 L .48951 .9429 L 0 .309 .102 r
F
0 g
.48585 .9427 m
.48951 .9429 L
s
.51316 .94817 m .51316 .94817 L .51254 .93231 L 0 .355 .263 r
F
.53952 .84139 m .54022 .81122 L .53864 .82677 L 0 .88 .289 r
F
.53245 .83427 m .53864 .82677 L .54022 .81122 L 0 .907 .304 r
F
0 g
.53892 .79947 m
.54022 .81122 L
s
.54022 .81122 m
.5438 .80016 L
s
.82935 .9893 m .83891 .99185 L .84067 .98284 L 0 1 .46 r
F
0 g
.83425 1.00036 m
.83891 .99185 L
s
.50295 .81876 m .50149 .82141 L .5001 .81988 L 0 .526 .094 r
F
.50294 .82727 m .50149 .82141 L .5001 .82102 L 0 .975 .36 r
F
.50149 .82141 m .50141 .82135 L .5001 .81988 L 0 .526 .094 r
F
.50148 .82143 m .50001 .82046 L .5001 .81988 L F
.50149 .82141 m .49927 .81243 L .50003 .82033 L 0 .975 .36 r
F
.50149 .82141 m .50003 .82033 L .5001 .82102 L F
.50149 .82141 m .50142 .82136 L .50141 .82135 L 0 .526 .094 r
F
.50149 .82141 m .50148 .82143 L .50142 .82136 L F
.50149 .82141 m .50124 .8052 L .49927 .81243 L 0 .975 .36 r
F
.50149 .82141 m .50118 .8339 L .49924 .82549 L 0 .526 .094 r
F
.50295 .81876 m .50255 .82221 L .50149 .82141 L F
.50294 .82727 m .50255 .82221 L .50149 .82141 L 0 .975 .36 r
F
.50255 .82221 m .50118 .8339 L .50149 .82141 L 0 .526 .094 r
F
.50255 .82221 m .50254 .82213 L .50149 .82141 L 0 .975 .36 r
F
.50254 .82213 m .50124 .8052 L .50149 .82141 L F
.50254 .82213 m .50469 .80414 L .50124 .8052 L F
.50294 .82727 m .50328 .82277 L .50255 .82221 L F
.50295 .81876 m .50401 .82332 L .50328 .82277 L 0 .526 .094 r
F
.50294 .82727 m .50504 .82407 L .50401 .82332 L 0 .975 .36 r
F
.50294 .82727 m .50589 .82701 L .50642 .82508 L F
.50295 .81876 m .5059 .82286 L .50642 .82508 L 0 .526 .094 r
F
.50295 .81876 m .50642 .82508 L .50504 .82407 L F
.50504 .82407 m .50642 .82508 L .50786 .81977 L 0 .975 .36 r
F
.50294 .82727 m .50642 .82508 L .50504 .82407 L F
.50504 .82407 m .50642 .82508 L .50785 .83124 L 0 .526 .094 r
F
.50464 .85073 m .50589 .82701 L .50294 .82727 L 0 .855 .352 r
F
.50464 .85073 m .50836 .83426 L .50589 .82701 L F
.50464 .85073 m .5087 .84419 L .50836 .83426 L F
.50401 .82332 m .50785 .83124 L .5075 .83834 L 0 .526 .094 r
F
.50295 .81876 m .50504 .82407 L .50401 .82332 L F
.50504 .82407 m .50785 .83124 L .50401 .82332 L F
.50401 .82332 m .50786 .81977 L .50752 .81038 L 0 .975 .36 r
F
.50504 .82407 m .50786 .81977 L .50401 .82332 L F
.50328 .82277 m .50752 .81038 L .50469 .80414 L F
.50294 .82727 m .50401 .82332 L .50328 .82277 L F
.50401 .82332 m .50752 .81038 L .50328 .82277 L F
.50328 .82277 m .5075 .83834 L .50464 .83949 L 0 .526 .094 r
F
.50401 .82332 m .5075 .83834 L .50328 .82277 L F
.50464 .85073 m .50294 .82727 L .50134 .83432 L 0 .855 .352 r
F
.50255 .82221 m .50464 .83949 L .50118 .8339 L 0 .526 .094 r
F
.50295 .81876 m .50328 .82277 L .50255 .82221 L F
.50328 .82277 m .50464 .83949 L .50255 .82221 L F
.50255 .82221 m .50329 .82263 L .50254 .82213 L 0 .975 .36 r
F
.50328 .82277 m .50329 .82263 L .50255 .82221 L F
.50329 .82263 m .50469 .80414 L .50254 .82213 L F
.50148 .82143 m .49924 .82549 L .50001 .82046 L 0 .526 .094 r
F
0 g
.50786 .81964 m
.50838 .81878 L
s
.48155 .85405 m .47531 .84296 L .47797 .84968 L 0 .914 .393 r
F
.48155 .85405 m .47523 .83683 L .47531 .84296 L F
0 g
.47154 .83917 m
.47531 .84296 L
s
.47797 .84968 m
.47848 .85558 L
s
.50941 .78064 m .51663 .76308 L .51341 .75861 L 0 1 .373 r
F
.50941 .78064 m .51648 .77142 L .51663 .76308 L F
0 g
.51663 .76308 m
.52009 .7549 L
s
.51809 .77972 m
.51932 .77638 L
s
.51316 .94818 m .51316 .94818 L .51601 .94203 L 0 .302 .125 r
F
.2238 .87456 m .21218 .87254 L .21463 .87687 L 0 1 .523 r
F
0 g
.21105 .88023 m
.21463 .87687 L
s
.51316 .94817 m .51316 .94817 L .50961 .93772 L 0 .406 .275 r
F
0 g
.36872 .76938 m
.36882 .7695 L
s
.37256 .7706 m
.37321 .77081 L
s
.37404 .77107 m
.37422 .77113 L
s
.36872 .76938 m
.37256 .7706 L
s
.60972 .67442 m
.60987 .67465 L
s
.61035 .67536 m
.61133 .6768 L
s
.60912 .67389 m
.60972 .67442 L
s
.46556 .94078 m .45716 .93677 L .46192 .93844 L 0 .235 .043 r
F
0 g
.46556 .93868 m
.46601 .93896 L
s
.46556 .94078 m .45369 .9365 L .45716 .93677 L 0 .235 .043 r
F
0 g
.4537 .93461 m
.45716 .93677 L
s
.46192 .93844 m
.46556 .93868 L
s
.6846 .6032 m .70144 .60481 L .70481 .60343 L 0 1 .457 r
F
.6846 .6032 m .69279 .60471 L .70144 .60481 L F
0 g
.70144 .60481 m
.7044 .60733 L
s
.30077 .5936 m
.3015 .59701 L
s
.52507 .94539 m .52508 .94403 L .52865 .93918 L 0 .277 .136 r
F
.55283 .87189 m .55517 .8237 L .55276 .84673 L 0 .814 .263 r
F
.54633 .85298 m .55276 .84673 L .55517 .8237 L 0 .85 .275 r
F
0 g
.55517 .8237 m
.5591 .81007 L
s
.55484 .81099 m
.55517 .8237 L
s
.51316 .94818 m .50488 .93691 L .50961 .94334 L 0 .298 .327 r
F
.51316 .94818 m .50961 .94334 L .50488 .93691 L 0 .306 .332 r
F
0 g
.50488 .93691 m
.50488 .93691 L
s
.50488 .9369 m
.50488 .93691 L
s
.50443 .92964 m .49571 .91117 L .49819 .91673 L 0 .408 .362 r
F
.50443 .92964 m .49592 .91113 L .49571 .91117 L F
0 g
.49909 .92523 m
.50235 .92981 L
s
.49563 .91102 m
.49571 .91117 L
s
.49571 .91117 m
.49581 .9114 L
s
.51316 .94818 m .51279 .95273 L .513 .95013 L 0 .234 .281 r
F
.51316 .94818 m .513 .95013 L .51279 .95273 L 0 .231 .278 r
F
0 g
.51279 .95273 m
.51279 .95274 L
s
.51226 .95421 m
.51279 .95273 L
s
.52518 .83003 m .52716 .79969 L .52412 .8086 L 0 .929 .319 r
F
0 g
.52615 .80266 m
.52716 .79969 L
s
.52509 .79193 m
.52716 .79969 L
s
.50941 .78064 m .51338 .77894 L .51648 .77142 L 0 1 .373 r
F
0 g
.51381 .77791 m
.51648 .77142 L
s
.51648 .77142 m
.51932 .77638 L
s
.49115 .8921 m .48858 .87846 L .48541 .87323 L 0 .704 .385 r
F
.47523 .83683 m .46867 .82702 L .47133 .83324 L 0 1 .401 r
F
0 g
.47133 .83324 m
.47154 .83917 L
s
.50257 .48465 m .51378 .48386 L .5223 .48387 L 0 0 0 r
F
0 g
.51378 .48386 m
.52205 .48238 L
s
.30766 .80857 m .29727 .79961 L .29399 .80624 L 0 1 .513 r
F
0 g
.29399 .80624 m
.29569 .8119 L
s
.30766 .80857 m .30374 .79533 L .29727 .79961 L 0 1 .513 r
F
.30766 .80857 m .30908 .79628 L .30374 .79533 L F
.30766 .80857 m .31076 .80196 L .30908 .79628 L F
0 g
.3012 .81283 m
.30766 .80857 L
s
.51316 .94817 m .51867 .92084 L .51679 .92775 L 0 .395 .269 r
F
.51316 .94817 m .51911 .9233 L .51867 .92084 L F
0 g
.51867 .92084 m
.51882 .91908 L
s
.51679 .92774 m
.51867 .92084 L
s
.61214 .51581 m .60741 .51247 L .60568 .51057 L 0 0 0 r
F
0 g
.60568 .51057 m
.60575 .51063 L
s
.60444 .5098 m
.60568 .51057 L
s
.61214 .51581 m .61685 .52073 L .60741 .51247 L 0 0 0 r
F
0 g
.60466 .50877 m
.61214 .51581 L
s
.60575 .51063 m
.61129 .51512 L
s
.61129 .51512 m
.61214 .51581 L
s
.73484 .68665 m
.73657 .68215 L
s
.73768 .67927 m
.73815 .67804 L
s
.27916 .93238 m .27095 .93125 L .2756 .93208 L 0 .486 .215 r
F
.27916 .93238 m .26751 .93006 L .27095 .93125 L F
0 g
.26818 .93123 m
.27095 .93125 L
s
.2756 .93208 m
.27977 .93302 L
s
.50894 .76099 m .51687 .7514 L .51703 .74414 L 0 1 .389 r
F
.50894 .76099 m .51341 .75861 L .51687 .7514 L F
0 g
.51687 .7514 m
.52009 .7549 L
s
.21218 .87254 m .20298 .87506 L .20764 .87578 L 0 1 .525 r
F
0 g
.20764 .87578 m
.21105 .88023 L
s
.48787 .87247 m .48195 .86013 L .4846 .86734 L 0 .809 .385 r
F
.48787 .87247 m .48155 .85405 L .48195 .86013 L F
0 g
.47848 .85558 m
.48195 .86013 L
s
.4846 .86734 m
.48541 .87323 L
s
.51317 .94818 m .52501 .94075 L .52505 .94204 L 0 .29 .119 r
F
.51317 .94818 m .52144 .9423 L .52501 .94075 L F
0 g
.52501 .94075 m
.52525 .94033 L
s
.52144 .9423 m
.52501 .94075 L
s
.53902 .6864 m .55185 .67335 L .54762 .67298 L 0 1 .44 r
F
0 g
.55185 .67335 m
.55754 .66773 L
s
.51479 1.05977 m .51217 1.05968 L .51512 1.06556 L 0 0 .154 r
F
.51479 1.05977 m .51012 1.05369 L .51217 1.05968 L F
0 g
.50981 1.05629 m
.51217 1.05968 L
s
.50866 1.04588 m .51012 1.05369 L .51033 1.05156 L 0 .081 .187 r
F
.51479 1.05977 m .51033 1.05156 L .51012 1.05369 L 0 0 .154 r
F
0 g
.51012 1.05369 m
.51217 1.05968 L
s
.50777 1.05104 m
.51012 1.05369 L
s
.58601 .63816 m .6006 .63259 L .60257 .63039 L 0 1 .407 r
F
.58601 .63816 m .59351 .63592 L .6006 .63259 L F
0 g
.6006 .63259 m
.60444 .63281 L
s
.59351 .63592 m
.59765 .63592 L
s
.59351 .63592 m
.6006 .63259 L
s
.50443 .92964 m .49863 .91667 L .49592 .91113 L 0 .408 .362 r
F
0 g
.49592 .91113 m
.49611 .91152 L
s
.49611 .91152 m
.49708 .9135 L
s
.49364 .906 m
.49592 .91113 L
s
.49581 .9114 m
.49672 .91345 L
s
.49672 .91345 m
.49777 .91578 L
s
.49982 .92464 m
.5026 .92966 L
s
.49753 .91559 m
.49819 .91673 L
s
.49602 .91298 m
.49753 .91559 L
s
.43435 .78853 m
.4391 .79016 L
s
.50422 .98505 m .49977 .99497 L .50201 .99484 L 0 .261 .267 r
F
0 g
.49954 1.0002 m
.49977 .99497 L
s
.50653 .96112 m .50613 .95925 L .50363 .95964 L 0 .301 .27 r
F
.51316 .94818 m .5025 .93002 L .50558 .93553 L 0 .276 .312 r
F
.51316 .94818 m .50273 .92988 L .5025 .93002 L F
0 g
.5024 .92987 m
.5025 .93002 L
s
.50149 .93153 m
.50502 .93634 L
s
.50165 .93109 m
.50503 .93635 L
s
.50387 .94707 m
.50676 .94837 L
s
.51316 .94818 m .51581 .95862 L .5163 .9592 L 0 .236 .28 r
F
.51316 .94818 m .51477 .95519 L .51581 .95862 L F
0 g
.51581 .95862 m
.51586 .95883 L
s
.51349 .95576 m
.51365 .95381 L
s
.81803 .99647 m .82308 1.00651 L .82768 .99801 L 0 1 .446 r
F
.81803 .99647 m .81861 1.00916 L .82308 1.00651 L F
0 g
.82308 1.00651 m
.82413 1.01 L
s
.51316 .94817 m .51316 .94817 L .50959 .93889 L 0 .406 .274 r
F
.39537 .9155 m .38659 .9129 L .39131 .9145 L 0 .452 .23 r
F
.39537 .9155 m .38362 .91121 L .38659 .9129 L F
0 g
.3829 .91222 m
.38659 .9129 L
s
.39131 .9145 m
.3947 .91593 L
s
.51316 .94817 m .51316 .94817 L .51291 .93297 L 0 .364 .264 r
F
0 g
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.21218 .87254 m .20056 .87052 L .20298 .87506 L 0 1 .525 r
F
0 g
.19942 .87865 m
.20298 .87506 L
s
.42589 .80183 m .41891 .79592 L .42245 .79981 L 0 1 .445 r
F
.42589 .80183 m .4171 .79201 L .41891 .79592 L F
.42589 .80183 m .41825 .79068 L .4171 .79201 L F
.42589 .80183 m .42169 .79271 L .41825 .79068 L F
.42589 .80183 m .42513 .79674 L .42169 .79271 L F
0 g
.42245 .79981 m
.42249 .80045 L
s
.42249 .80045 m
.4228 .80566 L
s
.42589 .80183 m .42693 .80065 L .42513 .79674 L 0 1 .445 r
F
0 g
.42589 .80183 m
.42777 .8058 L
s
.42245 .79981 m
.42589 .80183 L
s
.34382 .66583 m
.34815 .67929 L
s
.34249 .67163 m
.34381 .66584 L
s
.68027 1.11641 m .68526 1.1032 L .6896 1.10761 L 0 .174 .068 r
F
0 g
.67933 1.10181 m
.68526 1.1032 L
s
.68469 1.09812 m
.68526 1.1032 L
s
.51968 .96319 m .52534 .97371 L .52619 .97477 L 0 .091 .182 r
F
.51968 .96319 m .52298 .96975 L .52534 .97371 L F
0 g
.52307 .9699 m
.52534 .97371 L
s
.50257 .48465 m .49355 .48607 L .4939 .4856 L 0 0 0 r
F
0 g
.49314 .48502 m
.49444 .48465 L
s
.50257 .48465 m .50207 .48609 L .49355 .48607 L 0 0 0 r
F
.50257 .48465 m .51381 .48563 L .50207 .48609 L F
.50257 .48465 m .52248 .48468 L .51381 .48563 L F
.50257 .48465 m .5223 .48387 L .52248 .48468 L F
0 g
.49444 .48465 m
.50257 .48465 L
s
.5223 .48387 m
.53055 .48411 L
s
.51378 .48386 m
.5223 .48387 L
s
.47523 .83683 m .4689 .82087 L .46867 .82702 L 0 1 .401 r
F
0 g
.4646 .82398 m
.46867 .82702 L
s
.47523 .83683 m .47187 .8189 L .4689 .82087 L 0 1 .401 r
F
.47523 .83683 m .47578 .82249 L .47187 .8189 L F
.47523 .83683 m .47801 .82923 L .47578 .82249 L F
.47523 .83683 m .47778 .83538 L .47801 .82923 L F
.48155 .85405 m .47778 .83538 L .47523 .83683 L 0 .914 .393 r
F
0 g
.47133 .83324 m
.47523 .83683 L
s
.47523 .83683 m
.47531 .84296 L
s
.6989 1.09947 m .70894 1.09605 L .70517 1.09936 L 0 0 .024 r
F
.6896 1.10761 m .6989 1.09947 L .6995 1.10457 L 0 .093 .048 r
F
.50758 .96573 m .50115 .97404 L .50201 .97719 L 0 .288 .267 r
F
0 g
.49991 .96931 m
.50055 .96921 L
s
.50758 .96573 m .50241 .96893 L .50115 .97404 L 0 .288 .267 r
F
0 g
.49862 .97348 m
.50115 .97404 L
s
.42693 .80065 m
.43029 .80294 L
s
.43029 .80293 m
.4303 .80252 L
s
.53602 .98692 m
.53625 .98713 L
s
.53579 .98671 m
.53602 .98692 L
s
.53577 .98669 m
.53579 .98671 L
s
.53569 .98663 m
.53577 .98669 L
s
.53784 .98857 m
.53807 .98877 L
s
.53725 .98803 m
.53784 .98857 L
s
.53716 .98795 m
.53725 .98803 L
s
.5366 .98744 m
.53716 .98795 L
s
.53631 .98718 m
.5366 .98744 L
s
.53625 .98713 m
.53631 .98718 L
s
.53849 .99082 m .5374 .98912 L .53891 .98954 L 0 .296 0 r
F
0 g
.5374 .98912 m
.53745 .98914 L
s
.53745 .98914 m
.53753 .98916 L
s
.53753 .98916 m
.53778 .98923 L
s
.53778 .98923 m
.53784 .98924 L
s
.53784 .98924 m
.53816 .98933 L
s
.53816 .98933 m
.53831 .98937 L
s
.53831 .98937 m
.53883 .98952 L
s
.53883 .98952 m
.53891 .98954 L
s
.53807 .98877 m
.53881 .98944 L
s
.53881 .98944 m
.53891 .98954 L
s
.51316 .94818 m .50679 .94838 L .51043 .94826 L 0 .343 .266 r
F
.51316 .94818 m .51043 .94826 L .50679 .94838 L 0 .329 .264 r
F
0 g
.50432 .94988 m
.50679 .94838 L
s
.50676 .94837 m
.50679 .94838 L
s
.45447 .81255 m .44674 .80587 L .4498 .81082 L 0 1 .424 r
F
0 g
.4498 .81082 m
.44993 .81665 L
s
.44727 .49835 m .43666 .50124 L .43805 .50129 L 0 .777 .199 r
F
0 g
.43114 .50535 m
.43805 .50129 L
s
.44727 .49835 m .44418 .4984 L .43666 .50124 L 0 .777 .199 r
F
.44727 .49835 m .4556 .49467 L .44418 .4984 L F
.44727 .49835 m .46483 .49173 L .4556 .49467 L F
.44727 .49835 m .46571 .49155 L .46483 .49173 L F
.44727 .49835 m .45818 .49439 L .46571 .49155 L F
0 g
.44012 .50119 m
.44727 .49835 L
s
.43805 .50129 m
.44727 .49835 L
s
.45818 .49439 m
.46703 .49107 L
s
.47022 .80217 m
.4706 .80391 L
s
.46631 .80117 m
.47022 .80217 L
s
.64197 .76594 m .6449 .76089 L .64134 .755 L 0 .161 .225 r
F
0 g
.64134 .755 m
.64197 .76594 L
s
.63951 .75015 m
.64134 .755 L
s
.63768 .75075 m
.64197 .76594 L
s
.48155 .85405 m .48136 .83975 L .47778 .83538 L 0 .914 .393 r
F
.48155 .85405 m .48359 .84702 L .48136 .83975 L F
.48155 .85405 m .48367 .85314 L .48359 .84702 L F
.48787 .87247 m .48367 .85314 L .48155 .85405 L 0 .809 .385 r
F
0 g
.47797 .84968 m
.48155 .85405 L
s
.48155 .85405 m
.48195 .86013 L
s
.20056 .87052 m .19133 .87326 L .19599 .87398 L 0 1 .527 r
F
0 g
.19599 .87398 m
.19942 .87865 L
s
.45447 .81255 m .4471 .79986 L .44674 .80587 L 0 1 .424 r
F
.45447 .81255 m .45801 .8039 L .45534 .79852 L F
.45447 .81255 m .45764 .80991 L .45801 .8039 L F
0 g
.4544 .8185 m
.45447 .81255 L
s
.4498 .81082 m
.45447 .81255 L
s
.51316 .94818 m .51316 .94818 L .51622 .94256 L 0 .298 .124 r
F
.52075 .93381 m .52556 .91233 L .52265 .92341 L 0 .411 .261 r
F
.52075 .93381 m .52831 .90912 L .52556 .91233 L F
.51974 .92711 m .52265 .92341 L .52556 .91233 L 0 .443 .263 r
F
0 g
.52556 .91233 m
.52679 .91089 L
s
.52556 .91233 m
.52711 .89942 L
s
.51316 .94818 m .50503 .93635 L .50967 .9431 L 0 .29 .321 r
F
.51316 .94818 m .50967 .9431 L .50503 .93635 L 0 .298 .327 r
F
0 g
.50502 .93634 m
.50503 .93635 L
s
.50503 .93635 m
.50503 .93635 L
s
.28485 .59842 m
.28538 .59701 L
s
.28233 .60501 m
.28485 .59842 L
s
.28984 .60002 m
.29079 .59939 L
s
.28233 .60501 m
.28984 .60002 L
s
.25142 .71954 m .246 .70947 L .24076 .71517 L 0 1 .534 r
F
.25142 .71954 m .25304 .70671 L .246 .70947 L F
.25142 .71954 m .25717 .70875 L .25304 .70671 L F
.25142 .71954 m .25647 .71425 L .25717 .70875 L F
0 g
.24441 .72227 m
.25142 .71954 L
s
.25089 .72475 m
.25142 .71954 L
s
.7305 .59761 m .7477 .60222 L .75143 .60111 L 0 1 .489 r
F
.7305 .59761 m .73875 .60072 L .7477 .60222 L F
0 g
.7477 .60222 m
.75028 .60578 L
s
.51316 .94818 m .50597 .93529 L .50273 .92988 L 0 .276 .312 r
F
0 g
.50267 .92977 m
.50273 .92988 L
s
.50178 .93083 m
.50525 .93588 L
s
.50202 .93048 m
.50526 .93588 L
s
.51316 .94817 m .51316 .94817 L .5096 .94012 L 0 .402 .273 r
F
.50894 .76099 m .51703 .74414 L .51343 .74081 L 0 1 .389 r
F
0 g
.51703 .74414 m
.52086 .73638 L
s
.23035 .81483 m .22169 .80561 L .21888 .81313 L 0 1 .534 r
F
.23035 .81483 m .2272 .80056 L .22169 .80561 L F
.23035 .81483 m .23173 .80138 L .2272 .80056 L F
.23035 .81483 m .23308 .8075 L .23173 .80138 L F
0 g
.22485 .81983 m
.23035 .81483 L
s
.23035 .81483 m
.23177 .82075 L
s
.51316 .94818 m .50518 .95457 L .50555 .95645 L 0 .317 .263 r
F
.51316 .94818 m .50738 .95167 L .50518 .95457 L F
0 g
.50243 .95399 m
.50518 .95457 L
s
.47471 .48956 m .48583 .48709 L .4939 .4856 L 0 0 0 r
F
0 g
.48583 .48709 m
.49314 .48502 L
s
.20056 .87052 m .18893 .8685 L .19133 .87326 L 0 1 .527 r
F
0 g
.18779 .87708 m
.19133 .87326 L
s
.69434 .83921 m
.6944 .84042 L
s
.49848 .91108 m .49255 .89786 L .4956 .90537 L 0 .562 .373 r
F
.49848 .91108 m .49115 .8921 L .49255 .89786 L F
.49662 .91106 m .4956 .90537 L .49255 .89786 L 0 .576 .38 r
F
0 g
.4914 .89312 m
.49255 .89786 L
s
.49034 .89406 m
.49255 .89786 L
s
.51861 .96195 m .51816 .96142 L .51922 .9638 L 0 .099 .184 r
F
.34602 .7995 m .33607 .79639 L .33638 .80243 L 0 1 .483 r
F
0 g
.33123 .80637 m
.33638 .80243 L
s
.3462 .76097 m .34119 .75746 L .33681 .75609 L 0 .353 .212 r
F
.3462 .76097 m .34718 .76003 L .34119 .75746 L F
.3462 .76097 m .35078 .76209 L .34718 .76003 L F
.3462 .76097 m .35036 .76249 L .35078 .76209 L F
0 g
.34023 .75841 m
.3462 .76097 L
s
.34597 .76103 m
.3462 .76097 L
s
.32744 .75002 m .31524 .74378 L .32025 .74705 L 0 .383 .339 r
F
0 g
.32025 .74705 m
.32115 .75024 L
s
.49115 .8921 m .49124 .88607 L .48858 .87846 L 0 .704 .385 r
F
.49115 .8921 m .49234 .89192 L .49124 .88607 L F
.49848 .91108 m .49234 .89192 L .49115 .8921 L 0 .562 .373 r
F
0 g
.48798 .88687 m
.49115 .8921 L
s
.49115 .8921 m
.4914 .89312 L
s
.49352 .90573 m
.49658 .911 L
s
.51316 .94818 m .51365 .95381 L .51337 .9506 L 0 .231 .278 r
F
.51316 .94818 m .51337 .9506 L .51365 .95381 L 0 .231 .277 r
F
0 g
.51365 .95381 m
.51365 .95381 L
s
.51365 .95381 m
.51422 .95667 L
s
.4098 .78124 m
.41037 .78121 L
s
.53425 .98495 m
.53569 .98663 L
s
.51861 .96195 m .52298 .96975 L .52067 .96552 L 0 .099 .184 r
F
0 g
.51797 .96152 m
.51905 .96348 L
s
.51905 .96348 m
.51922 .9638 L
s
.51836 .96186 m
.51917 .96369 L
s
.51917 .96369 m
.51922 .9638 L
s
.51968 .96319 m .52067 .96552 L .52298 .96975 L 0 .091 .182 r
F
0 g
.52298 .96975 m
.52404 .97211 L
s
.52298 .96975 m
.52307 .9699 L
s
.51316 .94818 m .5163 .9592 L .51561 .95621 L 0 .236 .28 r
F
0 g
.5163 .9592 m
.51669 .96 L
s
.42513 .79674 m
.42693 .80065 L
s
.47471 .48956 m .46483 .49173 L .46571 .49155 L 0 0 0 r
F
.47471 .48956 m .4729 .49024 L .46483 .49173 L F
0 g
.45818 .49439 m
.4656 .49159 L
s
.47471 .48956 m .48454 .48806 L .4729 .49024 L 0 0 0 r
F
.47471 .48956 m .49355 .48607 L .48454 .48806 L F
.47471 .48956 m .4939 .4856 L .49355 .48607 L F
0 g
.48583 .48709 m
.4939 .4856 L
s
.46703 .49107 m
.47471 .48956 L
s
.4939 .4856 m
.50257 .48465 L
s
.69837 .69406 m
.69906 .69269 L
s
.50381 .92962 m .50171 .9241 L .49819 .91673 L 0 .411 .363 r
F
0 g
.49819 .91673 m
.49819 .91673 L
s
.50443 .92964 m .49819 .91673 L .50171 .9241 L 0 .408 .362 r
F
0 g
.49777 .91578 m
.49819 .91673 L
s
.51316 .94818 m .50496 .94579 L .50154 .94419 L 0 .326 .12 r
F
0 g
.50187 .94227 m
.50509 .94438 L
s
.50166 .94341 m
.50513 .94442 L
s
.49794 .94358 m
.50154 .94419 L
s
.5031 .92973 m .50337 .92966 L .5007 .92426 L 0 .422 .368 r
F
.77757 .81654 m .78587 .80303 L .79047 .80319 L 0 .056 .033 r
F
.77757 .81654 m .78035 .80873 L .78587 .80303 L F
0 g
.78365 .79839 m
.78587 .80303 L
s
.23007 .711 m .21841 .71292 L .22276 .71442 L 0 1 .537 r
F
0 g
.22276 .71442 m
.22292 .72003 L
s
.50941 .78064 m .51341 .75861 L .50894 .76099 L 0 1 .373 r
F
0 g
.51341 .75861 m
.51663 .76308 L
s
.51341 .75861 m
.51687 .7514 L
s
.50653 .96112 m .50241 .96893 L .50493 .96526 L 0 .301 .27 r
F
.50758 .96573 m .50493 .96526 L .50241 .96893 L 0 .288 .267 r
F
0 g
.50055 .96921 m
.50241 .96893 L
s
.50115 .97404 m
.50241 .96893 L
s
.29399 .80624 m .28367 .80996 L .28817 .81067 L 0 1 .521 r
F
0 g
.28817 .81067 m
.28982 .81618 L
s
.51316 .94817 m .51316 .94817 L .51328 .93385 L 0 .374 .265 r
F
0 g
.51316 .94817 m
.51316 .94816 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94811 m
.51316 .94817 L
s
.40823 .65672 m .39849 .65979 L .40106 .6596 L 0 1 .363 r
F
.40823 .65672 m .40213 .65687 L .39849 .65979 L F
0 g
.3981 .66227 m
.40106 .6596 L
s
.40823 .65672 m .40954 .65278 L .40213 .65687 L 0 1 .363 r
F
.40823 .65672 m .41673 .6499 L .40954 .65278 L F
.40823 .65672 m .41888 .65015 L .41673 .6499 L F
.40823 .65672 m .41524 .65307 L .41888 .65015 L F
0 g
.40489 .65925 m
.40823 .65672 L
s
.40106 .6596 m
.40823 .65672 L
s
.51855 .80087 m .51624 .78475 L .51608 .7942 L 0 1 .345 r
F
.50988 .80273 m .51624 .78475 L .51338 .77894 L 0 1 .359 r
F
.50988 .80273 m .51608 .7942 L .51624 .78475 L F
0 g
.51624 .78475 m
.51809 .77972 L
s
.70896 1.10653 m .70894 1.09605 L .71472 1.09463 L 0 0 .029 r
F
.70896 1.10653 m .70517 1.09936 L .70894 1.09605 L F
0 g
.70817 1.09203 m
.70894 1.09605 L
s
.34602 .7995 m .3397 .78949 L .33607 .79639 L 0 1 .483 r
F
.34602 .7995 m .34531 .78539 L .3397 .78949 L F
.34602 .7995 m .34915 .78682 L .34531 .78539 L F
.34602 .7995 m .34945 .79287 L .34915 .78682 L F
0 g
.34602 .7995 m
.34646 .80549 L
s
.34042 .80359 m
.34602 .7995 L
s
.5282 .97738 m .52741 .97634 L .52886 .97803 L 0 .136 0 r
F
0 g
.52867 .9778 m
.52886 .97803 L
s
.5284 .97749 m
.52867 .9778 L
s
.5286 .97771 m
.52886 .97803 L
s
.52731 .97614 m
.5286 .97771 L
s
.49662 .91106 m .49734 .91102 L .4956 .90537 L 0 .576 .38 r
F
.50488 .92976 m .49662 .91106 L .49864 .91667 L 0 .399 .357 r
F
.50488 .92976 m .49734 .91102 L .49662 .91106 L F
0 g
.49708 .9135 m
.49829 .91596 L
s
.49829 .91596 m
.49863 .91667 L
s
.50302 .92961 m
.50304 .92963 L
s
.49982 .92464 m
.50302 .92961 L
s
.50304 .92963 m
.50306 .92967 L
s
.49658 .911 m
.49662 .91106 L
s
.49704 .91223 m
.49767 .91399 L
s
.49703 .9122 m
.49704 .91223 L
s
.49662 .91106 m
.49703 .9122 L
s
.50988 .80273 m .51338 .77894 L .50941 .78064 L 0 1 .359 r
F
0 g
.51338 .77894 m
.51624 .78475 L
s
.51338 .77894 m
.51381 .77791 L
s
.44199 .80462 m
.44674 .80587 L
s
.52831 .90912 m .52907 .91592 L .53211 .9111 L 0 .474 .256 r
F
.52075 .93381 m .52907 .91592 L .52831 .90912 L 0 .411 .261 r
F
0 g
.52679 .91089 m
.52831 .90912 L
s
.52831 .90912 m
.52989 .88993 L
s
.51982 .92647 m
.52131 .91418 L
s
.51937 .9222 m
.52131 .91418 L
s
.4689 .82087 m .46201 .81225 L .46467 .81802 L 0 1 .41 r
F
0 g
.4646 .82398 m
.46467 .81802 L
s
.51316 .94817 m .51316 .94817 L .50965 .9414 L 0 .394 .272 r
F
.3739 .79258 m .36447 .79366 L .36828 .79562 L 0 1 .461 r
F
0 g
.36828 .79562 m
.36886 .80149 L
s
.4689 .82087 m .46256 .80609 L .46201 .81225 L 0 1 .41 r
F
.4689 .82087 m .47243 .81275 L .47019 .8065 L F
.4689 .82087 m .47187 .8189 L .47243 .81275 L F
0 g
.46867 .82702 m
.4689 .82087 L
s
.46467 .81802 m
.4689 .82087 L
s
.34023 .56652 m .32776 .57146 L .33091 .57261 L 0 1 .47 r
F
0 g
.32691 .5811 m
.33091 .57261 L
s
.34023 .56652 m .33263 .56391 L .32776 .57146 L 0 1 .47 r
F
.34023 .56652 m .3423 .55498 L .33263 .56391 L F
.34023 .56652 m .35164 .54888 L .3423 .55498 L F
.34023 .56652 m .35441 .54968 L .35164 .54888 L F
.34023 .56652 m .34951 .55725 L .35441 .54968 L F
0 g
.33563 .57423 m
.34023 .56652 L
s
.33091 .57261 m
.34023 .56652 L
s
.4391 .79016 m
.43937 .79117 L
s
.26515 .61023 m .25559 .60654 L .25237 .61446 L 0 1 .511 r
F
0 g
.24419 .62013 m
.25237 .61446 L
s
.53245 .83427 m .53228 .80919 L .53115 .82249 L 0 .907 .304 r
F
.52518 .83003 m .53115 .82249 L .53228 .80919 L 0 .929 .319 r
F
0 g
.53057 .79943 m
.53228 .80919 L
s
.53228 .80919 m
.5345 .8026 L
s
.6225 .52468 m
.62978 .53105 L
s
.63054 .53172 m
.6311 .53221 L
s
.6311 .53221 m
.63193 .53294 L
s
.51316 .94818 m .50517 .94443 L .50973 .94657 L 0 .326 .12 r
F
.51316 .94818 m .50973 .94657 L .50517 .94443 L 0 .316 .119 r
F
0 g
.50509 .94438 m
.50517 .94443 L
s
.50513 .94442 m
.50517 .94443 L
s
.34951 .55725 m
.35856 .55074 L
s
.50422 .98505 m .50332 .98191 L .50107 .98204 L 0 .261 .267 r
F
.49418 .89182 m .48858 .87846 L .49124 .88607 L 0 .688 .377 r
F
.49418 .89182 m .48787 .87247 L .48858 .87846 L F
0 g
.48541 .87323 m
.48858 .87846 L
s
.4184 .79596 m
.4189 .79592 L
s
.4137 .79629 m
.4184 .79596 L
s
.51316 .94818 m .50526 .93589 L .50977 .94291 L 0 .283 .316 r
F
.51316 .94818 m .50977 .94291 L .50526 .93589 L 0 .29 .321 r
F
0 g
.50525 .93588 m
.50526 .93589 L
s
.50526 .93588 m
.50526 .93589 L
s
.50955 1.03794 m .50622 1.04046 L .50866 1.04588 L 0 .104 .201 r
F
.50955 1.03794 m .50492 1.03427 L .50622 1.04046 L F
0 g
.50388 1.03783 m
.50622 1.04046 L
s
.60967 .62766 m .60751 .62491 L .60553 .6271 L 0 1 .365 r
F
.60967 .62766 m .61492 .62249 L .60751 .62491 L F
.60967 .62766 m .6228 .62145 L .61492 .62249 L F
.51316 .94817 m .51679 .92775 L .51472 .93941 L 0 .395 .269 r
F
.51316 .94817 m .51472 .93941 L .51679 .92775 L 0 .399 .268 r
F
0 g
.51679 .92775 m
.518 .91733 L
s
.51679 .92775 m
.51679 .92774 L
s
.51316 .94818 m .52144 .9423 L .51671 .94565 L 0 .29 .12 r
F
.51317 .94818 m .51671 .94565 L .52144 .9423 L 0 .29 .119 r
F
0 g
.52144 .9423 m
.52491 .93888 L
s
.52144 .9423 m
.52144 .9423 L
s
.51316 .94818 m .5031 .92973 L .50597 .93529 L 0 .272 .309 r
F
.51316 .94818 m .50337 .92966 L .5031 .92973 L F
0 g
.50306 .92967 m
.5031 .92973 L
s
.51316 .94818 m
.51316 .94818 L
s
.51779 .82776 m .52201 .80031 L .51855 .80087 L 0 .948 .334 r
F
.51779 .82776 m .52412 .8086 L .52201 .80031 L F
0 g
.52201 .80031 m
.52509 .79193 L
s
.50469 1.02564 m .50492 1.03427 L .50561 1.03142 L 0 .166 .237 r
F
.50955 1.03794 m .50561 1.03142 L .50492 1.03427 L 0 .104 .201 r
F
0 g
.50492 1.03427 m
.50622 1.04046 L
s
.5026 1.03243 m
.50492 1.03427 L
s
.74119 .68311 m
.74208 .67527 L
s
.67532 .76512 m
.67581 .76834 L
s
.67368 .75453 m
.67532 .76512 L
s
.50443 .92964 m .50205 .9241 L .49863 .91667 L 0 .408 .362 r
F
0 g
.49863 .91667 m
.49863 .91667 L
s
.50488 .92976 m .49864 .91667 L .50205 .9241 L 0 .399 .357 r
F
0 g
.50331 .92954 m
.50333 .92958 L
s
.5033 .92952 m
.50331 .92954 L
s
.5007 .92426 m
.5033 .92952 L
s
.50333 .92958 m
.50335 .92962 L
s
.49767 .91399 m
.49864 .91667 L
s
.51316 .94818 m .51316 .94818 L .5164 .9432 L 0 .294 .123 r
F
.48787 .87247 m .48694 .85827 L .48367 .85314 L 0 .809 .385 r
F
.40712 .92007 m .39839 .91697 L .40311 .91868 L 0 .332 .195 r
F
0 g
.40651 .91991 m
.40816 .92054 L
s
.40712 .92007 m .39537 .9155 L .39839 .91697 L 0 .332 .195 r
F
0 g
.3947 .91593 m
.39839 .91697 L
s
.40311 .91868 m
.40651 .91991 L
s
.26515 .61023 m .26382 .59741 L .25559 .60654 L 0 1 .511 r
F
0 g
.25237 .61446 m
.25559 .60654 L
s
.26515 .61023 m .27272 .59168 L .26382 .59741 L 0 1 .511 r
F
.26515 .61023 m .27635 .59317 L .27272 .59168 L F
.26515 .61023 m .27309 .60113 L .27635 .59317 L F
0 g
.26212 .6182 m
.26515 .61023 L
s
.25628 .61593 m
.26515 .61023 L
s
.40128 .79253 m .39202 .79099 L .39574 .79395 L 0 1 .452 r
F
0 g
.39574 .79395 m
.39614 .7999 L
s
.48787 .87247 m .48917 .86601 L .48694 .85827 L 0 .809 .385 r
F
.48787 .87247 m .48957 .87209 L .48917 .86601 L F
.49418 .89182 m .48957 .87209 L .48787 .87247 L 0 .688 .377 r
F
0 g
.48787 .87247 m
.48858 .87846 L
s
.4846 .86734 m
.48787 .87247 L
s
.51316 .94817 m .51756 .93204 L .51911 .9233 L 0 .395 .269 r
F
0 g
.51911 .9233 m
.51937 .9222 L
s
.45764 .80991 m
.45801 .8039 L
s
.45764 .80991 m
.46201 .81225 L
s
.76137 .64138 m .78072 .63079 L .77824 .63257 L 0 0 0 r
F
0 g
.78072 .63079 m
.78827 .62713 L
s
.51317 .94818 m .52505 .94204 L .52151 .94456 L 0 .29 .119 r
F
0 g
.52234 .94397 m
.52505 .94204 L
s
.52505 .94204 m
.52865 .93918 L
s
.51316 .94818 m .5145 .95486 L .51374 .95105 L 0 .231 .277 r
F
0 g
.5145 .95486 m
.51471 .95727 L
s
.51316 .94818 m .51374 .95105 L .5145 .95486 L 0 .232 .278 r
F
0 g
.5145 .95486 m
.51519 .95786 L
s
.51316 .94817 m .51316 .94817 L .51365 .93494 L 0 .384 .266 r
F
0 g
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94816 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94816 L
s
.53862 .89855 m .5397 .91266 L .54321 .91225 L 0 .475 .248 r
F
.53017 .92649 m .5397 .91266 L .53862 .89855 L 0 .407 .252 r
F
0 g
.53687 .89819 m
.53862 .89855 L
s
.53862 .89855 m
.53964 .87994 L
s
.51316 .94818 m .51316 .94818 L .51227 .94918 L 0 .24 .286 r
F
.51316 .94818 m .50555 .95645 L .50803 .95496 L 0 .317 .263 r
F
0 g
.50465 .95176 m
.50737 .95167 L
s
.50363 .95964 m
.50555 .95645 L
s
.56057 .65932 m .57539 .64875 L .571 .64871 L 0 1 .431 r
F
0 g
.57539 .64875 m
.57812 .64698 L
s
.51316 .94818 m .51701 .96006 L .51747 .96061 L 0 .242 .285 r
F
.51316 .94818 m .51561 .95621 L .51701 .96006 L F
0 g
.51701 .96006 m
.51707 .96024 L
s
.51477 .95519 m
.51581 .95862 L
s
.49848 .91108 m .49522 .89763 L .49234 .89192 L 0 .562 .373 r
F
0 g
.49124 .88607 m
.49234 .89192 L
s
.51968 .96319 m .52619 .97477 L .52477 .97196 L 0 .091 .182 r
F
0 g
.52619 .97477 m
.52731 .97614 L
s
.51316 .94818 m .50645 .93518 L .50337 .92966 L 0 .272 .309 r
F
0 g
.50335 .92962 m
.50337 .92966 L
s
.5022 .93027 m
.50557 .93552 L
s
.5025 .93002 m
.50557 .93553 L
s
.77984 1.04039 m .77727 1.04573 L .77862 1.04731 L 0 1 .277 r
F
0 g
.77256 1.05256 m
.77862 1.04731 L
s
.50488 .92976 m .50018 .91668 L .49734 .91102 L 0 .399 .357 r
F
0 g
.49734 .91102 m
.4974 .91114 L
s
.4974 .91114 m
.49764 .91162 L
s
.49764 .91162 m
.49795 .91223 L
s
.4956 .90537 m
.49734 .91102 L
s
.46201 .81225 m
.46256 .80609 L
s
.41524 .65307 m
.42211 .6504 L
s
.4171 .79201 m
.41891 .79592 L
s
.61492 .62249 m .63105 .61888 L .6342 .61649 L 0 1 .411 r
F
.61492 .62249 m .6228 .62145 L .63105 .61888 L F
0 g
.63105 .61888 m
.63419 .6203 L
s
.62281 .62146 m
.6269 .62202 L
s
.6228 .62145 m
.62281 .62146 L
s
.6228 .62145 m
.63105 .61888 L
s
.48695 .852 m .48136 .83975 L .48359 .84702 L 0 .902 .384 r
F
.48695 .852 m .48171 .83339 L .48136 .83975 L F
0 g
.47778 .83538 m
.48136 .83975 L
s
.48359 .84702 m
.48367 .85314 L
s
.51316 .94818 m .51477 .95519 L .51385 .95119 L 0 .232 .278 r
F
0 g
.51477 .95519 m
.51534 .95805 L
s
.51316 .94818 m .51385 .95119 L .51477 .95519 L 0 .236 .28 r
F
0 g
.51477 .95519 m
.51477 .95519 L
s
.50988 .80273 m .51335 .8019 L .51608 .7942 L 0 1 .359 r
F
.32744 .75002 m .31518 .74049 L .31524 .74378 L 0 .383 .339 r
F
0 g
.30845 .74282 m
.31524 .74378 L
s
.51316 .94818 m .50558 .93553 L .50991 .94275 L 0 .276 .312 r
F
.51316 .94818 m .50991 .94275 L .50558 .93553 L 0 .283 .316 r
F
0 g
.50557 .93552 m
.50558 .93553 L
s
.50557 .93553 m
.50558 .93553 L
s
.45369 .9365 m .44562 .93543 L .44197 .93319 L 0 .164 .009 r
F
.45369 .9365 m .45035 .93734 L .44562 .93543 L F
.45369 .9365 m .45381 .9378 L .45035 .93734 L F
.46556 .94078 m .45381 .9378 L .45369 .9365 L 0 .235 .043 r
F
0 g
.45369 .9365 m
.45716 .93677 L
s
.45004 .93426 m
.45369 .9365 L
s
.51316 .94818 m .50738 .95167 L .51068 .94968 L 0 .329 .264 r
F
.51316 .94818 m .51068 .94968 L .50738 .95167 L 0 .317 .263 r
F
0 g
.50518 .95457 m
.50738 .95167 L
s
.50737 .95167 m
.50738 .95167 L
s
.48171 .83339 m .47578 .82249 L .47801 .82923 L 0 .999 .392 r
F
0 g
.47778 .83538 m
.47801 .82923 L
s
.52163 .72039 m .51783 .71351 L .51767 .71888 L 0 1 .417 r
F
.52163 .72039 m .52238 .70694 L .51783 .71351 L F
.52163 .72039 m .52829 .70355 L .52238 .70694 L F
.43043 .79698 m .42169 .79271 L .42514 .79674 L 0 1 .441 r
F
0 g
.426 .79678 m
.43043 .79698 L
s
.42569 .79676 m
.426 .79678 L
s
.42514 .79674 m
.42569 .79676 L
s
.4303 .80252 m
.43043 .79698 L
s
.50758 .96573 m .50201 .97719 L .50422 .97582 L 0 .288 .267 r
F
0 g
.50107 .98204 m
.50201 .97719 L
s
.50847 .74363 m .51728 .73396 L .51744 .72764 L 0 1 .407 r
F
.50847 .74363 m .51343 .74081 L .51728 .73396 L F
0 g
.51728 .73396 m
.52086 .73638 L
s
.51779 .82776 m .51855 .80087 L .51584 .80907 L 0 .948 .334 r
F
0 g
.51765 .8036 m
.51855 .80087 L
s
.51608 .7942 m
.51855 .80087 L
s
.40128 .79253 m .39221 .78474 L .39202 .79099 L 0 1 .452 r
F
0 g
.38666 .79289 m
.39202 .79099 L
s
.40128 .79253 m .39619 .77937 L .39221 .78474 L 0 1 .452 r
F
.40128 .79253 m .40495 .78768 L .40515 .78143 L F
0 g
.40128 .79253 m
.4013 .7985 L
s
.39574 .79395 m
.40128 .79253 L
s
.3739 .79258 m .36454 .78724 L .36447 .79366 L 0 1 .461 r
F
0 g
.35917 .7969 m
.36447 .79366 L
s
.3739 .79258 m .36846 .78063 L .36454 .78724 L 0 1 .461 r
F
.3739 .79258 m .37408 .77758 L .36846 .78063 L F
.3739 .79258 m .37765 .78013 L .37408 .77758 L F
.3739 .79258 m .37757 .78656 L .37765 .78013 L F
0 g
.3739 .79258 m
.374 .79871 L
s
.36828 .79562 m
.3739 .79258 L
s
.50941 .78064 m .50584 .76851 L .50618 .77618 L 0 1 .373 r
F
.50941 .78064 m .50894 .76099 L .50584 .76851 L F
.50988 .80273 m .50941 .78064 L .50669 .78835 L 0 1 .359 r
F
.23007 .711 m .21935 .707 L .21841 .71292 L 0 1 .537 r
F
0 g
.21196 .71657 m
.21841 .71292 L
s
.29399 .80624 m .28284 .80445 L .28367 .80996 L 0 1 .521 r
F
0 g
.2785 .81447 m
.28367 .80996 L
s
.50381 .92962 m .50412 .92962 L .50171 .9241 L 0 .411 .363 r
F
0 g
.50171 .9241 m
.50197 .9247 L
s
.50379 .92959 m
.50379 .9296 L
s
.50378 .92958 m
.50379 .92959 L
s
.5007 .92426 m
.50378 .92958 L
s
.50126 .94735 m .49297 .94468 L .49771 .94586 L 0 .322 .102 r
F
.50126 .94735 m .48937 .94471 L .49297 .94468 L F
.5014 .94536 m .49771 .94586 L .49297 .94468 L 0 .309 .102 r
F
0 g
.48951 .9429 m
.49297 .94468 L
s
.73144 1.08395 m .74196 1.07743 L .73776 1.08116 L 0 0 0 r
F
.71869 1.09605 m .73144 1.08395 L .73073 1.0879 L F
.48937 .94471 m .48096 .94459 L .47744 .94258 L 0 .298 .087 r
F
.51316 .94818 m .51747 .96061 L .51643 .95718 L 0 .242 .285 r
F
0 g
.51561 .95621 m
.51701 .96006 L
s
.51747 .96061 m
.51797 .96152 L
s
.48171 .83339 m .47646 .81611 L .47578 .82249 L 0 .999 .392 r
F
0 g
.47187 .8189 m
.47578 .82249 L
s
.48171 .83339 m .47961 .81436 L .47646 .81611 L 0 .999 .392 r
F
.48171 .83339 m .48441 .8322 L .48509 .82582 L F
.48695 .852 m .48441 .8322 L .48171 .83339 L 0 .902 .384 r
F
0 g
.47801 .82923 m
.48171 .83339 L
s
.48136 .83975 m
.48171 .83339 L
s
.51316 .94818 m .51316 .94818 L .51654 .94393 L 0 .291 .122 r
F
.49219 .87174 m .48694 .85827 L .48917 .86601 L 0 .792 .376 r
F
.49219 .87174 m .48695 .852 L .48694 .85827 L F
0 g
.48367 .85314 m
.48694 .85827 L
s
.51316 .94818 m .50381 .92962 L .50645 .93518 L 0 .27 .308 r
F
.51316 .94818 m .50412 .92962 L .50381 .92962 L F
0 g
.50273 .92988 m
.50596 .93527 L
s
.5031 .92973 m
.50597 .93528 L
s
.50379 .9296 m
.50381 .92962 L
s
.50381 .92962 m
.50387 .92976 L
s
.49418 .89182 m .49251 .87784 L .48957 .87209 L 0 .688 .377 r
F
.51316 .94817 m .51316 .94817 L .51402 .93624 L 0 .392 .267 r
F
0 g
.51316 .94817 m
.51316 .94817 L
s
.74029 1.08188 m .74196 1.07743 L .74765 1.07301 L 0 0 0 r
F
.74029 1.08188 m .73776 1.08116 L .74196 1.07743 L F
0 g
.7418 1.07536 m
.74196 1.07743 L
s
.5068 1.01554 m .50277 1.02079 L .50469 1.02564 L 0 .185 .241 r
F
.5068 1.01554 m .50222 1.01451 L .50277 1.02079 L F
0 g
.50046 1.01898 m
.50277 1.02079 L
s
.50894 .76099 m .505 .75085 L .50534 .75766 L 0 1 .389 r
F
.50894 .76099 m .50847 .74363 L .505 .75085 L F
.50894 .76099 m .51343 .74081 L .50847 .74363 L F
0 g
.51343 .74081 m
.51728 .73396 L
s
.51343 .74081 m
.51703 .74414 L
s
.52238 .70694 m .53319 .69745 L .53383 .6927 L 0 1 .436 r
F
.52238 .70694 m .52829 .70355 L .53319 .69745 L F
0 g
.53319 .69745 m
.53707 .69814 L
s
.52829 .70355 m
.53224 .70507 L
s
.52829 .70355 m
.53319 .69745 L
s
.50323 1.00521 m .50222 1.01451 L .50339 1.01096 L 0 .223 .259 r
F
.5068 1.01554 m .50339 1.01096 L .50222 1.01451 L 0 .185 .241 r
F
0 g
.50222 1.01451 m
.50277 1.02079 L
s
.49994 1.01358 m
.50222 1.01451 L
s
.5014 .94536 m .50133 .94615 L .49771 .94586 L 0 .309 .102 r
F
.51316 .94818 m .5014 .94536 L .50496 .94579 L 0 .337 .12 r
F
.51316 .94818 m .50133 .94615 L .5014 .94536 L F
0 g
.49794 .94358 m
.5014 .94536 L
s
.47744 .94471 m .46905 .94087 L .47381 .94244 L 0 .283 .068 r
F
0 g
.47744 .94258 m
.4777 .94273 L
s
.47744 .94471 m .46556 .94078 L .46905 .94087 L 0 .283 .068 r
F
0 g
.46601 .93896 m
.46905 .94087 L
s
.47381 .94244 m
.47744 .94258 L
s
.45552 .79724 m
.45552 .79724 L
s
.45536 .7966 m
.45552 .79724 L
s
.45085 .79506 m
.45536 .7966 L
s
.77757 .81654 m .79047 .80319 L .79174 .80812 L 0 .056 .033 r
F
0 g
.79047 .80319 m
.79521 .79958 L
s
.4674 .63614 m .45951 .63688 L .46078 .63718 L 0 .803 .235 r
F
0 g
.45622 .63917 m
.46078 .63718 L
s
.4674 .63614 m .46458 .63543 L .45951 .63688 L 0 .803 .235 r
F
.4674 .63614 m .47262 .63382 L .46458 .63543 L F
.4674 .63614 m .47926 .63278 L .47262 .63382 L F
.4674 .63614 m .48006 .63302 L .47926 .63278 L F
.4674 .63614 m .47498 .63446 L .48006 .63302 L F
0 g
.46268 .63749 m
.4674 .63614 L
s
.46078 .63718 m
.4674 .63614 L
s
.47498 .63446 m
.48126 .63319 L
s
.50443 .92964 m .50453 .92966 L .50205 .9241 L 0 .408 .362 r
F
0 g
.50409 .92956 m
.50412 .92962 L
s
.50197 .9247 m
.50409 .92956 L
s
.50205 .9241 m
.50216 .92432 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.48695 .852 m .48776 .83718 L .48441 .8322 L 0 .902 .384 r
F
.48695 .852 m .48955 .84503 L .48776 .83718 L F
.48695 .852 m .4892 .85138 L .48955 .84503 L F
.49219 .87174 m .4892 .85138 L .48695 .852 L 0 .792 .376 r
F
0 g
.48694 .85827 m
.48695 .852 L
s
.48359 .84702 m
.48695 .852 L
s
.48917 .86601 m
.48957 .87209 L
s
.51316 .94818 m .50597 .93529 L .51008 .94265 L 0 .272 .309 r
F
.51316 .94818 m .51008 .94265 L .50597 .93529 L 0 .276 .312 r
F
0 g
.50597 .93528 m
.50597 .93529 L
s
.50596 .93527 m
.50597 .93529 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.52518 .83003 m .52412 .8086 L .52347 .82024 L 0 .929 .319 r
F
.51779 .82776 m .52347 .82024 L .52412 .8086 L 0 .948 .334 r
F
0 g
.52201 .80031 m
.52412 .8086 L
s
.52412 .8086 m
.52615 .80266 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.77984 1.04039 m .78822 1.03729 L .79091 1.03138 L 0 1 .277 r
F
0 g
.78296 1.04411 m
.78822 1.03729 L
s
.78822 1.03729 m
.78948 1.03957 L
s
.52844 1.0925 m .53081 1.09493 L .52991 1.09441 L 0 .326 0 r
F
0 g
.53057 1.09384 m
.53081 1.09493 L
s
.53519 1.10601 m .53081 1.09494 L .53439 1.10035 L 0 .369 0 r
F
.53519 1.10601 m .52991 1.09441 L .53081 1.09494 L F
0 g
.68659 .67686 m
.68841 .69385 L
s
.6867 .67717 m
.69262 .6937 L
s
.69262 .6937 m
.69388 .69719 L
s
.69388 .69719 m
.69425 .69823 L
s
.68659 .67686 m
.6867 .67717 L
s
.69425 .69823 m
.69454 .69906 L
s
.41888 .92487 m .41019 .92131 L .41491 .92312 L 0 0 0 r
F
0 g
.41833 .92415 m
.41975 .92482 L
s
.41888 .92487 m .40712 .92007 L .41019 .92131 L 0 0 0 r
F
0 g
.41491 .92312 m
.41833 .92415 L
s
.40816 .92054 m
.4099 .9212 L
s
.48937 .94471 m .48572 .94589 L .48096 .94459 L 0 .298 .087 r
F
.48937 .94471 m .48933 .94595 L .48572 .94589 L F
.50126 .94735 m .48933 .94595 L .48937 .94471 L 0 .322 .102 r
F
0 g
.48585 .9427 m
.48937 .94471 L
s
.48937 .94471 m
.49297 .94468 L
s
.51316 .94818 m .51316 .94818 L .51002 .94546 L 0 .314 .337 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51968 .96319 m .51926 .96271 L .52067 .96552 L 0 .091 .182 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.81803 .99647 m .81644 1.00487 L .81861 1.00916 L 0 1 .446 r
F
0 g
.81305 1.01632 m
.81861 1.00916 L
s
.4471 .79986 m .43906 .79401 L .44213 .79867 L 0 1 .431 r
F
0 g
.44213 .79867 m
.4471 .79986 L
s
.44674 .80587 m
.4471 .79986 L
s
.44199 .80462 m
.44213 .79867 L
s
.45801 .8039 m
.46256 .80609 L
s
.51316 .94818 m .51561 .95621 L .51421 .95162 L 0 .236 .28 r
F
.51316 .94818 m .51421 .95162 L .51561 .95621 L 0 .242 .285 r
F
0 g
.51561 .95621 m
.51561 .95621 L
s
.51561 .95621 m
.5163 .9592 L
s
.51316 .94818 m .51316 .94818 L .50986 .94504 L 0 .319 .34 r
F
.33941 .89765 m .32961 .89252 L .32859 .89491 L 0 1 .459 r
F
.33941 .89765 m .3336 .89169 L .32961 .89252 L F
.33941 .89765 m .33789 .893 L .3336 .89169 L F
.33941 .89765 m .34038 .89555 L .33789 .893 L F
.35023 .90059 m .34038 .89555 L .33941 .89765 L 0 .938 .432 r
F
0 g
.33542 .89846 m
.33941 .89765 L
s
.33941 .89765 m
.34194 .90002 L
s
.51316 .94818 m .50699 .93519 L .50412 .92962 L 0 .27 .308 r
F
0 g
.50412 .92962 m
.50415 .92969 L
s
.50415 .92969 m
.50421 .92981 L
s
.50412 .92962 m
.50412 .92962 L
s
.50154 .94419 m
.50495 .94578 L
s
.47646 .81611 m .47019 .8065 L .47243 .81275 L 0 1 .401 r
F
0 g
.47243 .81275 m
.47646 .81611 L
s
.47578 .82249 m
.47646 .81611 L
s
.47187 .8189 m
.47243 .81275 L
s
.33607 .79639 m .32627 .79983 L .33032 .80081 L 0 1 .489 r
F
0 g
.33032 .80081 m
.33123 .80637 L
s
.19767 .91746 m .18596 .91231 L .18603 .91552 L 0 .809 .352 r
F
0 g
.18603 .91552 m
.18957 .91842 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.32859 .89491 m .31882 .8897 L .31776 .89238 L 0 1 .477 r
F
.32859 .89491 m .32285 .88859 L .31882 .8897 L F
.32859 .89491 m .32715 .88981 L .32285 .88859 L F
.32859 .89491 m .32961 .89252 L .32715 .88981 L F
0 g
.32457 .89601 m
.32859 .89491 L
s
.32859 .89491 m
.33108 .89746 L
s
.49848 .91108 m .49788 .90544 L .49522 .89763 L 0 .562 .373 r
F
.49848 .91108 m .49927 .9112 L .49788 .90544 L F
.50582 .93011 m .49848 .91108 L .50018 .91668 L 0 .393 .353 r
F
.50582 .93011 m .49927 .9112 L .49848 .91108 L F
0 g
.4956 .90537 m
.49848 .91108 L
s
.49851 .91116 m
.49878 .91208 L
s
.49848 .91108 m
.49851 .91116 L
s
.50051 .91151 m .49522 .89763 L .49788 .90544 L 0 .548 .366 r
F
.50051 .91151 m .49418 .89182 L .49522 .89763 L F
0 g
.49234 .89192 m
.49522 .89763 L
s
.35023 .90059 m .34433 .89503 L .34038 .89555 L 0 .938 .432 r
F
.35023 .90059 m .34863 .89644 L .34433 .89503 L F
.35023 .90059 m .35115 .89882 L .34863 .89644 L F
.36104 .90377 m .35115 .89882 L .35023 .90059 L 0 .81 .394 r
F
0 g
.34628 .9011 m
.35023 .90059 L
s
.35023 .90059 m
.35279 .90279 L
s
.48441 .8322 m
.48509 .82582 L
s
.51316 .94818 m .51316 .94818 L .50973 .94465 L 0 .321 .341 r
F
0 g
.51028 .94568 m
.51033 .94573 L
s
.51002 .94546 m
.51028 .94568 L
s
.51035 .82695 m .51335 .8019 L .50988 .80273 L 0 .963 .348 r
F
.51035 .82695 m .51584 .80907 L .51335 .8019 L F
0 g
.51335 .8019 m
.51608 .7942 L
s
.21888 .81313 m .21029 .80365 L .2074 .81138 L 0 1 .535 r
F
.21888 .81313 m .21587 .79846 L .21029 .80365 L F
.21888 .81313 m .22041 .79931 L .21587 .79846 L F
.21888 .81313 m .22169 .80561 L .22041 .79931 L F
0 g
.21332 .81827 m
.21888 .81313 L
s
.21888 .81313 m
.22024 .81921 L
s
.51316 .94818 m .50613 .95925 L .50653 .96112 L 0 .306 .262 r
F
.51316 .94818 m .50803 .95496 L .50613 .95925 L F
0 g
.50363 .95964 m
.50613 .95925 L
s
.50555 .95645 m
.50802 .95496 L
s
.30998 .58752 m .29727 .59204 L .30077 .5936 L 0 1 .49 r
F
.50582 .93011 m .50018 .91668 L .50323 .92427 L 0 .393 .353 r
F
.50488 .92976 m .50323 .92427 L .50018 .91668 L 0 .399 .357 r
F
0 g
.49795 .91223 m
.50018 .91668 L
s
.50441 .92961 m
.50441 .92961 L
s
.50171 .9241 m
.50441 .92961 L
s
.50442 .92963 m
.50442 .92964 L
s
.50441 .92961 m
.50442 .92963 L
s
.49878 .91208 m
.50018 .91668 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.50758 .96573 m .50715 .96389 L .50493 .96526 L 0 .288 .267 r
F
.49418 .89182 m .49474 .88588 L .49251 .87784 L 0 .688 .377 r
F
.49418 .89182 m .49546 .89187 L .49474 .88588 L F
.50051 .91151 m .49546 .89187 L .49418 .89182 L 0 .548 .366 r
F
0 g
.49124 .88607 m
.49418 .89182 L
s
.49418 .89182 m
.49522 .89763 L
s
.4171 .79201 m .41028 .78673 L .41369 .79031 L 0 1 .447 r
F
.4171 .79201 m .40865 .78294 L .41028 .78673 L F
0 g
.41368 .79032 m
.41369 .7911 L
s
.41369 .7911 m
.4137 .79629 L
s
.4171 .79201 m .41825 .79068 L .41663 .7869 L 0 1 .447 r
F
0 g
.41369 .79031 m
.4171 .79201 L
s
.53902 .6864 m .53538 .68196 L .53477 .68606 L 0 1 .44 r
F
.53902 .6864 m .5409 .67636 L .53538 .68196 L F
.53902 .6864 m .54762 .67298 L .5409 .67636 L F
.31776 .89238 m .30803 .88706 L .30692 .89 L 0 1 .489 r
F
.31776 .89238 m .3121 .8857 L .30803 .88706 L F
.31776 .89238 m .3164 .88683 L .3121 .8857 L F
.31776 .89238 m .31882 .8897 L .3164 .88683 L F
0 g
.3137 .89372 m
.31776 .89238 L
s
.31776 .89238 m
.32022 .89508 L
s
.48062 .80932 m
.48247 .80999 L
s
.48247 .80999 m
.48252 .81001 L
s
.48252 .81001 m
.48257 .81003 L
s
.48257 .81003 m
.48263 .81005 L
s
.6846 .6032 m .70481 .60343 L .70095 .601 L 0 1 .457 r
F
0 g
.70481 .60343 m
.71307 .60417 L
s
.51316 .94818 m .51816 .96142 L .51861 .96195 L 0 .251 .291 r
F
.51316 .94818 m .51643 .95718 L .51816 .96142 L F
0 g
.51816 .96142 m
.51836 .96186 L
s
.50642 .82508 m
.50642 .82511 L
s
.51316 .94818 m .51316 .94818 L .50965 .94428 L 0 .321 .341 r
F
0 g
.51002 .94546 m
.51037 .94576 L
s
.64915 .60995 m .66573 .60924 L .66871 .60757 L 0 1 .44 r
F
.64915 .60995 m .65736 .61026 L .66573 .60924 L F
0 g
.66573 .60924 m
.6691 .6111 L
s
.51316 .94818 m .50496 .94579 L .50964 .94715 L 0 .337 .12 r
F
0 g
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m .50964 .94715 L .50496 .94579 L 0 .326 .12 r
F
0 g
.5014 .94536 m
.50496 .94579 L
s
.50495 .94578 m
.50496 .94579 L
s
.51037 .94576 m
.51044 .94582 L
s
.51316 .94817 m
.51316 .94818 L
s
.41825 .79068 m
.42169 .79271 L
s
.42169 .79271 m
.42172 .79225 L
s
.42172 .79225 m
.42202 .78771 L
s
.53519 1.10601 m .53439 1.10035 L .53827 1.10705 L 0 .369 0 r
F
0 g
.53081 1.09494 m
.53439 1.10035 L
s
.53215 1.09526 m
.53439 1.10035 L
s
.49953 .78502 m .50618 .77618 L .50584 .76851 L 0 1 .385 r
F
.49953 .78502 m .50348 .78325 L .50618 .77618 L F
0 g
.50618 .77618 m
.50941 .78064 L
s
.67575 .60655 m .6761 .59996 L .67298 .59719 L 0 .265 .301 r
F
.67684 .60719 m .67652 .60528 L .67575 .60655 L 0 1 .434 r
F
.67693 .61052 m .67652 .60528 L .67575 .60655 L 0 .265 .301 r
F
.67684 .60719 m .67788 .60665 L .67785 .60331 L 0 1 .434 r
F
.67788 .60665 m .6846 .6032 L .67873 .6033 L F
.67788 .60665 m .67873 .6033 L .67785 .60331 L F
.67956 .5993 m .68069 .60077 L .68369 .59904 L 0 1 .481 r
F
.67652 .60528 m .67785 .60331 L .6761 .59996 L 0 .265 .301 r
F
.67652 .60528 m .6761 .59996 L .67576 .6065 L F
.67926 .60074 m .68069 .60077 L .67956 .5993 L 0 1 .481 r
F
.67684 .60719 m .69279 .60471 L .6846 .6032 L 0 1 .434 r
F
.66269 .60036 m .6717 .60133 L .67893 .60088 L 0 1 .481 r
F
.67899 .60073 m .67893 .60088 L .68069 .60077 L F
.66203 .57399 m .6714 .59001 L .67893 .60088 L 0 .223 .268 r
F
.66203 .57399 m .67893 .60088 L .67899 .60073 L F
.66269 .60036 m .67893 .60088 L .67899 .60073 L 0 1 .481 r
F
.67899 .60073 m .67893 .60088 L .68077 .60353 L 0 .223 .268 r
F
.67956 .5993 m .68077 .60353 L .68388 .60553 L F
.66203 .57399 m .67899 .60073 L .67956 .5993 L F
.67899 .60073 m .67926 .60074 L .67956 .5993 L 0 1 .481 r
F
.67899 .60073 m .68077 .60353 L .67956 .5993 L 0 .223 .268 r
F
.66269 .60036 m .67899 .60073 L .67956 .5993 L 0 1 .481 r
F
.68132 .59311 m .69123 .59468 L .68615 .59215 L 0 1 .494 r
F
.66203 .57399 m .67952 .59923 L .67887 .59516 L 0 .223 .268 r
F
.66203 .57399 m .67887 .59516 L .66908 .57935 L F
.68104 .59505 m .69123 .59468 L .68132 .59311 L 0 1 .494 r
F
.68104 .59505 m .68821 .59643 L .69123 .59468 L F
.68101 .59521 m .68821 .59643 L .68104 .59505 L F
.68057 .59604 m .68821 .59643 L .68083 .59518 L F
.6846 .6032 m .68369 .59904 L .68069 .60077 L 0 1 .457 r
F
.6846 .6032 m .69239 .59914 L .68369 .59904 L F
.6846 .6032 m .70095 .601 L .69239 .59914 L F
.67952 .59923 m .67956 .5993 L .67954 .59913 L 0 .223 .268 r
F
.67952 .59923 m .67954 .59913 L .67887 .59516 L F
.66269 .60036 m .67956 .5993 L .67891 .59677 L 0 1 .481 r
F
.67956 .5993 m .68369 .59904 L .67986 .59722 L F
.67956 .5993 m .6796 .59902 L .67958 .59889 L 0 .223 .268 r
F
.67954 .59913 m .67958 .59889 L .67887 .59516 L F
.67956 .5993 m .67958 .59889 L .67954 .59913 L F
.67969 .59948 m .68013 .59777 L .67887 .59516 L F
.6695 .59547 m .67891 .59677 L .67995 .59673 L 0 1 .494 r
F
.66908 .57935 m .67887 .59516 L .68004 .59673 L 0 .288 .315 r
F
.68039 .59603 m .68004 .59673 L .68821 .59643 L 0 1 .494 r
F
.68039 .59603 m .68004 .59673 L .68855 .60806 L 0 .288 .315 r
F
.66908 .57935 m .68004 .59673 L .68039 .59603 L F
.68008 .59601 m .67995 .59673 L .68004 .59673 L 0 1 .494 r
F
.68008 .59601 m .68004 .59673 L .68039 .59603 L F
.6695 .59547 m .67995 .59673 L .68008 .59601 L F
.67956 .5993 m .67986 .59722 L .67891 .59677 L 0 1 .481 r
F
.67956 .5993 m .67961 .59907 L .6796 .59902 L 0 .223 .268 r
F
.68087 .59506 m .68855 .60806 L .69166 .60943 L 0 .288 .315 r
F
.66908 .57935 m .68039 .59603 L .68087 .59506 L F
.68039 .59603 m .68057 .59604 L .68049 .59582 L 0 1 .494 r
F
.68039 .59603 m .68855 .60806 L .68087 .59506 L 0 .288 .315 r
F
.68008 .59601 m .68039 .59603 L .68024 .59508 L 0 1 .494 r
F
.68039 .59603 m .68049 .59582 L .68024 .59508 L F
.68057 .59604 m .68083 .59518 L .68024 .59508 L F
.68087 .59506 m .68104 .59505 L .68132 .59311 L F
.68087 .59506 m .69166 .60943 L .68141 .59326 L 0 .288 .315 r
F
.68087 .59506 m .68141 .59326 L .68132 .59311 L F
.68132 .59311 m .69166 .60943 L .68634 .59876 L F
.68235 .58946 m .69879 .59025 L .69341 .58747 L 0 1 .504 r
F
.66908 .57935 m .68074 .59489 L .68124 .59302 L 0 .288 .315 r
F
.66908 .57935 m .68124 .59302 L .67613 .58316 L F
.68124 .59302 m .68132 .59311 L .68124 .59297 L F
.68124 .59302 m .68124 .59297 L .67613 .58316 L F
.68185 .59096 m .68615 .59215 L .69576 .59203 L 0 1 .504 r
F
.68184 .59101 m .68615 .59215 L .68185 .59096 L F
.68151 .59139 m .68615 .59215 L .68175 .59098 L F
.68175 .59098 m .68184 .59101 L .68176 .59095 L F
.68124 .59302 m .68087 .59506 L .68132 .59311 L 0 .288 .315 r
F
.68074 .59489 m .68087 .59506 L .68124 .59302 L F
.6695 .59547 m .68132 .59311 L .67633 .59054 L 0 1 .494 r
F
.68132 .59311 m .68615 .59215 L .68151 .59139 L F
.68132 .59311 m .68133 .59305 L .67613 .58316 L 0 .288 .315 r
F
.68142 .59323 m .68173 .59172 L .67613 .58316 L F
.68132 .59311 m .68151 .59139 L .67633 .59054 L 0 1 .494 r
F
.68132 .59311 m .68133 .59305 L .68133 .59305 L 0 .288 .315 r
F
.68176 .59095 m .68634 .59876 L .69634 .61111 L 0 .339 .352 r
F
.67613 .58316 m .68151 .59139 L .68176 .59095 L F
.68151 .59139 m .68634 .59876 L .68176 .59095 L F
.68176 .59095 m .68184 .59101 L .68185 .59096 L 0 1 .504 r
F
.68159 .59094 m .68175 .59098 L .68176 .59095 L F
.68151 .59139 m .68175 .59098 L .68159 .59094 L F
.68178 .59096 m .69576 .59203 L .68191 .59047 L F
.68204 .59046 m .69634 .61111 L .69946 .61196 L 0 .339 .352 r
F
.67613 .58316 m .68176 .59095 L .68204 .59046 L F
.68176 .59095 m .69634 .61111 L .68204 .59046 L F
.68213 .59046 m .69879 .59025 L .68235 .58946 L 0 1 .504 r
F
.68213 .59046 m .69576 .59203 L .69879 .59025 L F
.68212 .59049 m .69576 .59203 L .68213 .59046 L F
.69239 .59914 m .69123 .59468 L .68821 .59643 L 0 1 .475 r
F
.6824 .58951 m .69946 .61196 L .69382 .60106 L 0 .339 .352 r
F
.67613 .58316 m .68204 .59046 L .68235 .58946 L F
.67633 .59054 m .68204 .59046 L .68235 .58946 L 0 1 .504 r
F
.68204 .59046 m .68213 .59046 L .68235 .58946 L F
.68235 .58946 m .68204 .59046 L .6824 .58951 L 0 .339 .352 r
F
.68191 .59047 m .68212 .59049 L .68213 .59046 L 0 1 .504 r
F
.68204 .59046 m .69946 .61196 L .6824 .58951 L 0 .339 .352 r
F
.67633 .59054 m .68151 .59139 L .68159 .59094 L 0 1 .504 r
F
.68307 .58563 m .69341 .58747 L .68318 .58555 L F
.67613 .58316 m .68233 .58944 L .68307 .58563 L 0 .339 .352 r
F
.68233 .58944 m .68235 .58946 L .68307 .58563 L F
.67633 .59054 m .68307 .58563 L .67352 .58567 L 0 1 .504 r
F
.68307 .58563 m .68318 .58555 L .68309 .58555 L F
.68235 .58946 m .69341 .58747 L .68307 .58563 L F
.67613 .58316 m .68307 .58563 L .67319 .57335 L 0 .339 .352 r
F
.68307 .58563 m .68319 .58568 L .68309 .58555 L F
.68307 .58563 m .68309 .58555 L .67319 .57335 L F
.6831 .5855 m .68009 .58042 L .67746 .58253 L 0 1 .512 r
F
.68318 .58555 m .69007 .58051 L .68449 .58046 L F
.68318 .58555 m .70334 .58756 L .70637 .58575 L F
.68318 .58555 m .69341 .58747 L .70334 .58756 L F
.68318 .58555 m .70637 .58575 L .7007 .58273 L F
.68318 .58555 m .7007 .58273 L .69007 .58051 L F
.68319 .58568 m .69026 .58709 L .68449 .58046 L 0 .415 .38 r
F
.68311 .58543 m .68449 .58046 L .67995 .57524 L F
.68318 .58555 m .68449 .58046 L .68353 .5839 L 0 1 .512 r
F
.68319 .58568 m .68449 .58046 L .68311 .58543 L 0 .415 .38 r
F
.68353 .5839 m .68449 .58046 L .68427 .58046 L 0 1 .512 r
F
.68309 .5855 m .67995 .57524 L .67724 .57462 L 0 .415 .38 r
F
.68311 .58543 m .67995 .57524 L .6831 .5855 L F
.68311 .58543 m .68427 .58046 L .68009 .58042 L 0 1 .512 r
F
.68318 .58555 m .68427 .58046 L .68311 .58543 L F
.68318 .58555 m .68311 .58543 L .6831 .5855 L F
.68311 .58543 m .6831 .58549 L .6831 .5855 L F
.68319 .58568 m .68311 .58543 L .6831 .5855 L 0 .415 .38 r
F
.68311 .58543 m .68311 .58543 L .6831 .58549 L 0 1 .512 r
F
.68311 .58543 m .68009 .58042 L .6831 .5855 L F
.68307 .58563 m .68309 .58555 L .67352 .58567 L 0 1 .504 r
F
.67633 .59054 m .68235 .58946 L .68307 .58563 L F
.68307 .58563 m .68235 .58946 L .68318 .58567 L 0 .339 .352 r
F
.68318 .58567 m .6824 .58951 L .68319 .58568 L F
.68235 .58946 m .6824 .58951 L .68318 .58567 L F
.69239 .59914 m .70988 .60133 L .71326 .59992 L 0 1 .475 r
F
.69239 .59914 m .70095 .601 L .70988 .60133 L F
.69239 .59914 m .71326 .59992 L .70913 .59722 L F
.69239 .59914 m .70913 .59722 L .70021 .59502 L F
.69239 .59914 m .70021 .59502 L .69123 .59468 L F
.6824 .58951 m .69382 .60106 L .68341 .58599 L 0 .339 .352 r
F
.6824 .58951 m .68341 .58599 L .68319 .58568 L F
.67633 .59054 m .68178 .59096 L .68191 .59047 L 0 1 .504 r
F
.6695 .59547 m .68087 .59506 L .68132 .59311 L 0 1 .494 r
F
.68132 .59311 m .68142 .59323 L .68133 .59305 L 0 .288 .315 r
F
.68142 .59323 m .68634 .59876 L .68173 .59172 L F
.68024 .59508 m .68101 .59521 L .68104 .59505 L 0 1 .494 r
F
.6695 .59547 m .68008 .59601 L .68024 .59508 L F
.67956 .5993 m .67969 .59948 L .67961 .59907 L 0 .223 .268 r
F
.67969 .59948 m .68388 .60553 L .68013 .59777 L F
.67693 .61052 m .68499 .61697 L .67785 .60331 L 0 .265 .301 r
F
.67684 .60719 m .67785 .60331 L .67768 .60356 L 0 1 .434 r
F
.67684 .60719 m .67774 .60331 L .67652 .60528 L F
.67693 .61052 m .67785 .60331 L .67652 .60528 L 0 .265 .301 r
F
.67768 .60356 m .67785 .60331 L .67774 .60331 L 0 1 .434 r
F
.67652 .60528 m .67774 .60331 L .67619 .60334 L F
.67652 .60528 m .67576 .6065 L .67575 .60655 L 0 .265 .301 r
F
.67575 .60655 m .67619 .60334 L .67319 .60504 L 0 1 .434 r
F
.67652 .60528 m .67619 .60334 L .67575 .60655 L F
0 g
.66982 .59552 m
.67122 .59847 L
s
.67255 .60128 m
.67409 .60453 L
s
.67477 .60597 m
.67538 .60724 L
s
.69573 .60474 m
.70144 .60481 L
s
.67538 .60725 m
.67595 .60723 L
s
.36104 .90377 m .35506 .89862 L .35115 .89882 L 0 .81 .394 r
F
.36104 .90377 m .35935 .90014 L .35506 .89862 L F
.36104 .90377 m .36191 .90234 L .35935 .90014 L F
0 g
.35713 .90396 m
.36104 .90377 L
s
.37233 .90735 m .36191 .90234 L .36104 .90377 L 0 .651 .338 r
F
0 g
.36104 .90377 m
.36379 .90583 L
s
.50988 .80273 m .50669 .78835 L .50702 .79691 L 0 1 .359 r
F
.50124 .8052 m .50669 .78835 L .50348 .78325 L 0 1 .371 r
F
.50124 .8052 m .50702 .79691 L .50669 .78835 L F
0 g
.50669 .78835 m
.50941 .78064 L
s
.30998 .58752 m .30148 .58388 L .29727 .59204 L 0 1 .49 r
F
.30998 .58752 m .31062 .57454 L .30148 .58388 L F
.30998 .58752 m .31985 .56845 L .31062 .57454 L F
.30998 .58752 m .32302 .56968 L .31985 .56845 L F
.30998 .58752 m .31878 .57786 L .32302 .56968 L F
0 g
.30601 .596 m
.30998 .58752 L
s
.30077 .5936 m
.30998 .58752 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51665 .94475 L 0 .29 .12 r
F
.51316 .94818 m .50443 .92964 L .50699 .93519 L 0 .271 .309 r
F
.51316 .94818 m .50453 .92966 L .50443 .92964 L F
0 g
.50387 .92976 m
.50644 .93515 L
s
.50337 .92966 m
.50642 .93513 L
s
.50442 .92964 m
.50443 .92964 L
s
.50205 .9241 m
.50453 .92966 L
s
.50443 .92964 m
.50448 .92975 L
s
.50448 .92975 m
.5045 .92981 L
s
.50847 .74363 m .51744 .72764 L .51346 .72519 L 0 1 .407 r
F
0 g
.51744 .72764 m
.52163 .72039 L
s
.51624 .83276 m
.51626 .83287 L
s
.51544 .82846 m
.51624 .83276 L
s
.51438 .8312 m
.51544 .82846 L
s
.51316 .94818 m .51316 .94818 L .5096 .94393 L 0 .318 .34 r
F
.51316 .94817 m .51316 .94817 L .51438 .93773 L 0 .397 .267 r
F
0 g
.51316 .94817 m
.51316 .94816 L
s
.74221 .68422 m
.74454 .67901 L
s
.74707 .67338 m
.74739 .67265 L
s
.74739 .67265 m
.74798 .67134 L
s
.4805 .80879 m
.48063 .808 L
s
.30692 .89 m .29723 .88457 L .29608 .88776 L 0 1 .498 r
F
.30692 .89 m .30133 .88297 L .29723 .88457 L F
0 g
.29608 .88776 m
.29848 .89076 L
s
.30692 .89 m .30564 .88404 L .30133 .88297 L 0 1 .498 r
F
.30692 .89 m .30803 .88706 L .30564 .88404 L F
0 g
.30283 .89158 m
.30692 .89 L
s
.30692 .89 m
.30935 .89285 L
s
.53827 1.10705 m .54357 1.11136 L .54221 1.11177 L 0 .356 0 r
F
.54782 1.12486 m .54357 1.11136 L .54778 1.11623 L 0 .427 .024 r
F
.54782 1.12486 m .54221 1.11177 L .54357 1.11136 L F
0 g
.54132 1.10625 m
.54357 1.11136 L
s
.51316 .94818 m .50645 .93518 L .51028 .9426 L 0 .27 .308 r
F
.51316 .94818 m .51028 .9426 L .50645 .93518 L 0 .272 .309 r
F
0 g
.50642 .93513 m
.50645 .93518 L
s
.50644 .93515 m
.50645 .93518 L
s
.51316 .94818 m .50718 .93522 L .50453 .92966 L 0 .271 .309 r
F
0 g
.50456 .92971 m
.50461 .92981 L
s
.50453 .92966 m
.50456 .92971 L
s
.50453 .92966 m
.50453 .92966 L
s
.49953 .78502 m .50584 .76851 L .50226 .76451 L 0 1 .385 r
F
0 g
.50584 .76851 m
.50894 .76099 L
s
.49219 .87174 m .49222 .85711 L .4892 .85138 L 0 .792 .376 r
F
.50124 .8052 m .50348 .78325 L .49953 .78502 L 0 1 .371 r
F
0 g
.50348 .78325 m
.50618 .77618 L
s
.50348 .78325 m
.50669 .78835 L
s
.58601 .63816 m .60257 .63039 L .59812 .63011 L 0 1 .407 r
F
0 g
.60257 .63039 m
.60967 .62766 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51264 .94966 L 0 .234 .281 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51035 .82695 m .50988 .80273 L .50752 .81038 L 0 .963 .348 r
F
0 g
.50642 .82511 m
.50652 .82554 L
s
.51316 .94818 m .51316 .94818 L .50986 .94601 L 0 .307 .118 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.46673 .80417 m
.47019 .8065 L
s
.31518 .74049 m .30435 .73653 L .30843 .73927 L 0 .61 .428 r
F
0 g
.30843 .73927 m
.30845 .74282 L
s
.51316 .94818 m .51316 .94818 L .50958 .94362 L 0 .313 .337 r
F
0 g
.51068 .94603 m
.51079 .94613 L
s
.51044 .94582 m
.51068 .94603 L
s
.51033 .94573 m
.51073 .94607 L
s
.50422 .98505 m .50201 .99484 L .50366 .99059 L 0 .261 .267 r
F
.50653 .99287 m .50201 .99484 L .50183 1.00111 L 0 .238 .258 r
F
.50653 .99287 m .50366 .99059 L .50201 .99484 L F
0 g
.49977 .99497 m
.50201 .99484 L
s
.19767 .91746 m .18942 .91066 L .18596 .91231 L 0 .809 .352 r
F
.19767 .91746 m .19409 .91168 L .18942 .91066 L F
.19767 .91746 m .19762 .91461 L .19409 .91168 L F
.2093 .91945 m .19762 .91461 L .19767 .91746 L 0 .739 .325 r
F
0 g
.19422 .91909 m
.19767 .91746 L
s
.19767 .91746 m
.20119 .92011 L
s
.50653 .99287 m .50183 1.00111 L .50323 1.00521 L 0 .238 .258 r
F
0 g
.50183 1.00111 m
.50201 .99484 L
s
.49954 1.0002 m
.50183 1.00111 L
s
.53425 .98495 m
.53447 .98524 L
s
.53447 .98524 m
.53667 .98816 L
s
.53667 .98816 m
.53708 .9887 L
s
.53708 .98871 m
.5374 .98912 L
s
.47019 .8065 m
.4706 .80391 L
s
.49743 .89214 m .49251 .87784 L .49474 .88588 L 0 .67 .368 r
F
.49743 .89214 m .49219 .87174 L .49251 .87784 L F
0 g
.48957 .87209 m
.49251 .87784 L
s
.52507 .94539 m .53337 .94106 L .52863 .94412 L 0 .277 .136 r
F
0 g
.53451 .94122 m
.53518 .94131 L
s
.52495 .94887 m .52863 .94412 L .53337 .94106 L 0 .29 .138 r
F
0 g
.53337 .94106 m
.53451 .94122 L
s
.53337 .94106 m
.53452 .93951 L
s
.52519 .94388 m
.52865 .93918 L
s
.51316 .94818 m .50803 .95496 L .51096 .95109 L 0 .317 .263 r
F
.51316 .94818 m .51096 .95109 L .50803 .95496 L 0 .306 .262 r
F
0 g
.50802 .95496 m
.50803 .95496 L
s
.50613 .95925 m
.50803 .95496 L
s
.58192 .65007 m .58909 .65514 L .59599 .66037 L 0 0 0 r
F
0 g
.58909 .65514 m
.59295 .65693 L
s
.7305 .59761 m .75143 .60111 L .74782 .59768 L 0 1 .489 r
F
0 g
.75143 .60111 m
.75981 .60332 L
s
.50124 .8052 m .50469 .80414 L .50702 .79691 L 0 1 .371 r
F
0 g
.50469 .80414 m
.50702 .79691 L
s
.50702 .79691 m
.50988 .80273 L
s
.41663 .7869 m
.41825 .79068 L
s
.51316 .94818 m .50484 .94718 L .50133 .94615 L 0 .337 .12 r
F
0 g
.51073 .94607 m
.51084 .94617 L
s
.51002 .94546 m
.51085 .94618 L
s
.49771 .94586 m
.50133 .94615 L
s
.49264 .85068 m .48776 .83718 L .48955 .84503 L 0 .888 .374 r
F
.49264 .85068 m .48854 .8306 L .48776 .83718 L F
0 g
.48441 .8322 m
.48776 .83718 L
s
.51968 .96319 m .52477 .97196 L .52205 .96716 L 0 .091 .182 r
F
0 g
.5188 .96227 m
.52067 .96552 L
s
.52069 .96433 m .52477 .97196 L .52741 .97634 L 0 .088 .181 r
F
.52069 .96433 m .52205 .96716 L .52477 .97196 L F
0 g
.52477 .97196 m
.52619 .97477 L
s
.52477 .97196 m
.52513 .97255 L
s
.58192 .65007 m .5793 .64873 L .57772 .64732 L 0 0 0 r
F
.58192 .65007 m .5862 .65396 L .5793 .64873 L F
.58192 .65007 m .59383 .65953 L .5862 .65396 L F
.58192 .65007 m .59599 .66037 L .59802 .66227 L F
0 g
.58909 .65514 m
.59415 .65898 L
s
.57812 .64698 m
.58192 .65007 L
s
.59415 .65898 m
.59599 .66037 L
s
.37233 .90735 m .36593 .90254 L .36191 .90234 L 0 .651 .338 r
F
.37233 .90735 m .3704 .90424 L .36593 .90254 L F
.37233 .90735 m .37315 .9063 L .3704 .90424 L F
.38362 .9112 m .37315 .9063 L .37233 .90735 L 0 .54 .267 r
F
0 g
.36832 .90715 m
.37233 .90735 L
s
.37233 .90735 m
.37512 .90921 L
s
.51974 .92711 m .52015 .92975 L .52265 .92341 L 0 .443 .263 r
F
.51316 .94818 m .51974 .92711 L .51756 .93204 L 0 .386 .269 r
F
.51316 .94818 m .52015 .92975 L .51974 .92711 L F
0 g
.51974 .92711 m
.51982 .92647 L
s
.51756 .93204 m
.51974 .92711 L
s
.43404 .79329 m
.43426 .78994 L
s
.43404 .79329 m
.43906 .79401 L
s
.50582 .93011 m .50186 .91704 L .49927 .9112 L 0 .393 .353 r
F
0 g
.49927 .9112 m
.49931 .91128 L
s
.49931 .91128 m
.49937 .91143 L
s
.49788 .90544 m
.49927 .9112 L
s
.50482 .92964 m
.50487 .92974 L
s
.50487 .92974 m
.50488 .92974 L
s
.50488 .92974 m
.50488 .92975 L
s
.50216 .92432 m
.50482 .92964 L
s
.56858 .87295 m
.56883 .83892 L
s
.56858 .87318 m
.56858 .87295 L
s
.52844 1.0925 m .52737 1.09048 L .52714 1.08939 L 0 .326 0 r
F
0 g
.52714 1.08939 m
.52714 1.08939 L
s
.51316 .94818 m .51861 .96195 L .51721 .95809 L 0 .251 .291 r
F
0 g
.51861 .96195 m
.5188 .96227 L
s
.51643 .95718 m
.51816 .96142 L
s
.52069 .96433 m .52741 .97634 L .5282 .97738 L 0 .088 .181 r
F
0 g
.52798 .97701 m
.5284 .97749 L
s
.52513 .97255 m
.52741 .97634 L
s
.51316 .94818 m .51756 .93204 L .51505 .94126 L 0 .386 .269 r
F
.51316 .94817 m .51505 .94126 L .51756 .93204 L 0 .395 .269 r
F
0 g
.51756 .93204 m
.51911 .9233 L
s
.51756 .93204 m
.51756 .93204 L
s
.51316 .94818 m .51316 .94818 L .50961 .94334 L 0 .306 .332 r
F
.29608 .88776 m .28304 .88148 L .28184 .88498 L 0 1 .504 r
F
.29608 .88776 m .28819 .87984 L .28304 .88148 L F
0 g
.28184 .88498 m
.28523 .88836 L
s
.29608 .88776 m .29385 .88117 L .28819 .87984 L 0 1 .504 r
F
.29608 .88776 m .29723 .88457 L .29385 .88117 L F
0 g
.29094 .88938 m
.29608 .88776 L
s
.51316 .94818 m .51316 .94818 L .513 .95013 L 0 .231 .278 r
F
.52247 1.08075 m .51953 1.07458 L .51753 1.071 L 0 0 .116 r
F
.48854 .8306 m .49248 .82306 L .49117 .81516 L 0 .992 .382 r
F
.48854 .8306 m .49135 .82968 L .49248 .82306 L F
.49264 .85068 m .49135 .82968 L .48854 .8306 L 0 .888 .374 r
F
0 g
.48509 .82582 m
.48854 .8306 L
s
.48776 .83718 m
.48854 .8306 L
s
.4892 .85138 m
.48955 .84503 L
s
.6326 .53382 m
.63268 .53393 L
s
.63774 .53779 m .63751 .53786 L .63974 .53943 L 0 .137 .174 r
F
.61685 .52073 m .63688 .53734 L .63774 .53779 L F
.63688 .53734 m .63751 .53786 L .63774 .53779 L F
.63769 .54053 m .6436 .54593 L .63549 .53661 L 0 .106 .183 r
F
.63497 .53634 m .63549 .53661 L .63416 .53508 L F
.63769 .54053 m .63549 .53661 L .63497 .53634 L F
0 g
.63268 .53393 m
.6343 .53606 L
s
.6321 .53358 m
.63425 .53626 L
s
.63769 .54053 m .65396 .55826 L .6436 .54593 L 0 .106 .183 r
F
.63769 .54053 m .65972 .56586 L .65396 .55826 L F
.63769 .54053 m .65703 .56365 L .65972 .56586 L F
0 g
.653 .55979 m
.65437 .56194 L
s
.63769 .54053 m .64759 .55279 L .65703 .56365 L 0 .106 .183 r
F
0 g
.64759 .55279 m
.653 .55979 L
s
.6343 .53606 m
.63769 .54053 L
s
.63425 .53626 m
.63769 .54053 L
s
.49219 .87174 m .494 .86538 L .49222 .85711 L 0 .792 .376 r
F
.49219 .87174 m .49398 .87165 L .494 .86538 L F
.49743 .89214 m .49398 .87165 L .49219 .87174 L 0 .67 .368 r
F
0 g
.48917 .86601 m
.49219 .87174 L
s
.49219 .87174 m
.49251 .87784 L
s
.24076 .71517 m .23549 .70493 L .23007 .711 L 0 1 .536 r
F
.24076 .71517 m .24269 .70181 L .23549 .70493 L F
.24076 .71517 m .24683 .70374 L .24269 .70181 L F
.24076 .71517 m .246 .70947 L .24683 .70374 L F
0 g
.23359 .71826 m
.24076 .71517 L
s
.24009 .72064 m
.24076 .71517 L
s
.45122 .797 m
.45534 .79852 L
s
.51317 .94818 m .52508 .94403 L .52507 .94539 L 0 .293 .118 r
F
.51317 .94818 m .52151 .94456 L .52508 .94403 L F
0 g
.52508 .94403 m
.52519 .94388 L
s
.52151 .94456 m
.52261 .9444 L
s
.52261 .9444 m
.5244 .94413 L
s
.5244 .94413 m
.52465 .94409 L
s
.52465 .94409 m
.52505 .94403 L
s
.52505 .94403 m
.52508 .94403 L
s
.51316 .94818 m .51643 .95718 L .51456 .95204 L 0 .242 .285 r
F
.51316 .94818 m .51456 .95204 L .51643 .95718 L 0 .251 .291 r
F
0 g
.51643 .95718 m
.51643 .95718 L
s
.51643 .95718 m
.51747 .96061 L
s
.51779 .82776 m .51584 .80907 L .51568 .81945 L 0 .948 .334 r
F
.51035 .82695 m .51568 .81945 L .51584 .80907 L 0 .963 .348 r
F
0 g
.51335 .8019 m
.51584 .80907 L
s
.51584 .80907 m
.51765 .8036 L
s
.56351 .64034 m .57095 .64373 L .57532 .64605 L 0 0 0 r
F
.56351 .64034 m .57532 .64605 L .57492 .64595 L F
.5636 .65151 m .57468 .64606 L .57322 .64558 L 0 1 .453 r
F
.5636 .65151 m .571 .64871 L .57532 .64605 L F
.5636 .65151 m .57532 .64605 L .57492 .64595 L F
.57329 .64554 m .57772 .64732 L .5793 .64873 L 0 0 0 r
F
.56351 .64034 m .57492 .64595 L .57329 .64554 L F
.57322 .64558 m .57397 .64574 L .57329 .64554 L 0 1 .453 r
F
.57397 .64574 m .57492 .64595 L .57329 .64554 L F
.57468 .64606 m .57492 .64595 L .57322 .64558 L F
.57492 .64595 m .57772 .64732 L .57329 .64554 L 0 0 0 r
F
.57492 .64595 m .57532 .64605 L .57769 .64459 L 0 1 .453 r
F
.57076 .64465 m .57329 .64554 L .57102 .64481 L 0 0 0 r
F
.56351 .64034 m .57285 .64531 L .57076 .64465 L F
.57285 .64531 m .57329 .64554 L .57076 .64465 L F
.56351 .64034 m .57076 .64465 L .56664 .64305 L F
.5636 .65151 m .57069 .64511 L .56665 .6441 L 0 1 .453 r
F
.57069 .64511 m .57081 .645 L .57022 .64487 L F
.57069 .64511 m .57022 .64487 L .56665 .6441 L F
.57081 .645 m .57006 .64465 L .56981 .64461 L F
.57043 .64491 m .56981 .64461 L .56665 .6441 L F
.57081 .645 m .56981 .64461 L .57043 .64491 L F
.57006 .64465 m .56796 .6437 L .56665 .6441 L F
.57102 .64481 m .56796 .6437 L .57006 .64465 L F
.57076 .64465 m .56952 .64423 L .56664 .64305 L 0 0 0 r
F
.57121 .64492 m .56893 .64417 L .56796 .6437 L F
.56952 .64423 m .56796 .6437 L .56664 .64305 L F
.57121 .64492 m .56796 .6437 L .56952 .64423 L F
.56766 .64368 m .56778 .64363 L .56751 .64364 L 0 1 .471 r
F
.56777 .64361 m .5678 .64362 L .56762 .64354 L 0 0 0 r
F
.56764 .64359 m .56768 .64357 L .56762 .64358 L 0 1 .471 r
F
.56768 .64357 m .58153 .63789 L .56767 .64356 L F
.56768 .64357 m .56767 .64356 L .56762 .64358 L F
.56762 .64354 m .56766 .64356 L .56741 .64344 L 0 0 0 r
F
.5636 .65151 m .57329 .64554 L .57102 .64481 L 0 1 .453 r
F
.5678 .64362 m .5745 .64167 L .58153 .63789 L 0 1 .471 r
F
.56665 .6441 m .56796 .6437 L .5678 .64362 L F
.56796 .6437 m .5745 .64167 L .5678 .64362 L F
.5678 .64362 m .57455 .6469 L .58167 .65045 L 0 0 0 r
F
.56777 .64361 m .56781 .64363 L .5678 .64362 L F
.56781 .64363 m .57455 .6469 L .5678 .64362 L F
.56745 .64345 m .58307 .63527 L .57801 .63488 L 0 1 .471 r
F
.56766 .64356 m .56746 .64346 L .56741 .64344 L 0 0 0 r
F
.56762 .64354 m .56767 .64356 L .56766 .64356 L F
.56664 .64305 m .56796 .6437 L .56777 .64361 L F
.56766 .64356 m .58307 .63527 L .56745 .64346 L 0 1 .471 r
F
.5678 .64362 m .56767 .64356 L .56762 .64354 L 0 0 0 r
F
.5678 .64362 m .58153 .63789 L .56768 .64357 L 0 1 .471 r
F
.56766 .64356 m .58153 .63789 L .58307 .63527 L F
.56767 .64356 m .58153 .63789 L .56766 .64356 L F
.56351 .64034 m .56664 .64305 L .55987 .63946 L 0 0 0 r
F
.56665 .6441 m .56347 .64145 L .56157 .64373 L 0 1 .471 r
F
.56347 .64145 m .56266 .64078 L .56257 .64101 L F
.56664 .64305 m .56347 .64145 L .56154 .64054 L 0 0 0 r
F
.54658 .65042 m .56157 .64373 L .56257 .64101 L 0 1 .495 r
F
.56237 .64095 m .56257 .64101 L .56266 .64078 L F
.56347 .64145 m .56257 .64101 L .56154 .64054 L 0 0 0 r
F
.54658 .65042 m .56257 .64101 L .56237 .64095 L 0 1 .495 r
F
.5465 .63592 m .56237 .64095 L .55705 .63936 L 0 0 0 r
F
.54658 .65042 m .56237 .64095 L .55706 .6403 L 0 1 .495 r
F
.56237 .64095 m .56266 .64078 L .56142 .64067 L F
.56237 .64095 m .56142 .64067 L .55706 .6403 L F
.56238 .64096 m .56185 .6408 L .56142 .64067 L 0 0 0 r
F
.56231 .64093 m .56142 .64067 L .55705 .63936 L F
.56238 .64096 m .56142 .64067 L .56231 .64093 L F
.56237 .64095 m .56238 .64096 L .56232 .64094 L F
.56237 .64095 m .56232 .64094 L .55705 .63936 L F
.56238 .64096 m .56266 .64105 L .56185 .6408 L F
.56347 .64145 m .56261 .64102 L .56157 .64373 L 0 1 .471 r
F
.56261 .64102 m .56257 .64101 L .56257 .64101 L F
.56261 .64102 m .56257 .64101 L .56157 .64373 L F
.56347 .64145 m .56266 .64105 L .56257 .64101 L 0 0 0 r
F
.56347 .64145 m .56971 .63698 L .56266 .64078 L 0 1 .471 r
F
.56664 .64305 m .56702 .64324 L .56347 .64145 L 0 0 0 r
F
.56664 .64305 m .56777 .64361 L .56762 .64354 L F
.56664 .64305 m .56762 .64354 L .56741 .64344 L F
.56664 .64305 m .56741 .64344 L .56701 .64323 L F
.56665 .6441 m .56702 .64324 L .56347 .64145 L 0 1 .471 r
F
.56702 .64324 m .56971 .63698 L .56347 .64145 L F
.56347 .64145 m .56703 .64324 L .56281 .64112 L 0 0 0 r
F
.56702 .64324 m .56703 .64324 L .56347 .64145 L F
.56741 .64344 m .56746 .64346 L .56745 .64346 L F
.56745 .64346 m .57801 .63488 L .56703 .64324 L 0 1 .471 r
F
.56741 .64344 m .56745 .64346 L .56701 .64323 L 0 0 0 r
F
.56745 .64346 m .56704 .64325 L .56701 .64323 L F
.56745 .64346 m .56703 .64324 L .56702 .64325 L 0 1 .471 r
F
.5862 .65396 m .58325 .65132 L .58167 .65045 L 0 .187 .18 r
F
.56745 .64346 m .58325 .65132 L .57816 .64881 L 0 0 0 r
F
.56665 .6441 m .56766 .64356 L .56745 .64346 L 0 1 .471 r
F
.56766 .64356 m .56748 .64347 L .56746 .64346 L 0 0 0 r
F
.56745 .64346 m .57816 .64881 L .56704 .64325 L F
.56746 .64346 m .58325 .65132 L .56745 .64346 L F
.56766 .64356 m .58325 .65132 L .56748 .64347 L F
.56766 .64356 m .58167 .65045 L .58325 .65132 L F
.56702 .64324 m .57816 .64881 L .56978 .64459 L F
.56701 .64323 m .56704 .64325 L .56702 .64324 L F
.56704 .64325 m .57816 .64881 L .56702 .64324 L F
.56702 .64324 m .57801 .63488 L .56971 .63698 L 0 1 .471 r
F
.56702 .64325 m .56703 .64324 L .56702 .64324 L F
.56703 .64324 m .57801 .63488 L .56702 .64324 L F
.56665 .6441 m .56745 .64346 L .56702 .64325 L F
.56281 .64112 m .56978 .64459 L .56266 .64105 L 0 0 0 r
F
.56703 .64324 m .56978 .64459 L .56281 .64112 L F
.5678 .64362 m .58167 .65045 L .56767 .64356 L F
.56778 .64363 m .5678 .64362 L .56764 .64359 L 0 1 .471 r
F
.5678 .64362 m .56768 .64357 L .56764 .64359 L F
.56778 .64363 m .56764 .64359 L .56751 .64364 L F
.56762 .64358 m .56767 .64356 L .56766 .64356 L F
.56767 .64356 m .58167 .65045 L .56766 .64356 L 0 0 0 r
F
.56796 .6437 m .57455 .6469 L .56777 .64361 L F
.57081 .645 m .57102 .64481 L .57006 .64465 L 0 1 .453 r
F
.57076 .64465 m .57102 .64481 L .56952 .64423 L 0 0 0 r
F
.57102 .64481 m .57026 .64453 L .56952 .64423 L F
.57102 .64481 m .5745 .64167 L .56796 .6437 L 0 1 .453 r
F
.57102 .64481 m .57121 .64492 L .57026 .64453 L 0 0 0 r
F
.56751 .64364 m .56764 .64359 L .56762 .64358 L 0 1 .471 r
F
.56665 .6441 m .56766 .64368 L .56751 .64364 L F
.57102 .64481 m .57922 .64188 L .5745 .64167 L 0 1 .453 r
F
.57329 .64554 m .57922 .64188 L .57102 .64481 L F
.57102 .64481 m .57329 .64554 L .57121 .64492 L 0 0 0 r
F
.57121 .64492 m .5793 .64873 L .57455 .6469 L F
.57329 .64554 m .5793 .64873 L .57121 .64492 L F
.57121 .64492 m .57455 .6469 L .56893 .64417 L F
.57329 .64554 m .57769 .64459 L .57922 .64188 L 0 1 .453 r
F
.57492 .64595 m .57769 .64459 L .57329 .64554 L F
.57492 .64595 m .57532 .64605 L .57772 .64732 L 0 0 0 r
F
0 g
.57532 .64605 m
.57542 .6461 L
s
.57542 .6461 m
.57772 .64732 L
s
.57772 .64732 m
.57814 .64759 L
s
.57814 .64759 m
.58192 .65007 L
s
.55709 .63673 m
.56349 .64033 L
s
.57769 .64459 m
.58185 .64457 L
s
.51317 .94818 m .52151 .94456 L .51674 .94663 L 0 .29 .119 r
F
.51317 .94818 m .51674 .94663 L .52151 .94456 L 0 .293 .118 r
F
0 g
.52151 .94456 m
.52234 .94397 L
s
.52151 .94456 m
.52151 .94456 L
s
.50488 .92976 m .50525 .92987 L .50323 .92427 L 0 .399 .357 r
F
.51316 .94818 m .50488 .92976 L .50718 .93522 L 0 .271 .309 r
F
.51316 .94818 m .50525 .92987 L .50488 .92976 L F
0 g
.50694 .9351 m
.50699 .93519 L
s
.51085 .94618 m
.51098 .94629 L
s
.50421 .92981 m
.50694 .9351 L
s
.5045 .92981 m
.50679 .93476 L
s
.50488 .92975 m
.50488 .92976 L
s
.50488 .92976 m
.50493 .92986 L
s
.50493 .92986 m
.50528 .93071 L
s
.50528 .93071 m
.50538 .93095 L
s
.50538 .93095 m
.50554 .93132 L
s
.45534 .79852 m
.45552 .79724 L
s
.43906 .79401 m
.43937 .79117 L
s
.48063 .808 m
.48263 .81005 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51043 .94826 L 0 .329 .264 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50653 .96112 L .50873 .95821 L 0 .306 .262 r
F
0 g
.50493 .96526 m
.50653 .96112 L
s
.5409 .67636 m .55346 .66784 L .55453 .66435 L 0 1 .457 r
F
.5409 .67636 m .54762 .67298 L .55346 .66784 L F
0 g
.55346 .66784 m
.55754 .66773 L
s
.54762 .67298 m
.55185 .67335 L
s
.54762 .67298 m
.55346 .66784 L
s
.50051 .91151 m .49809 .89794 L .49546 .89187 L 0 .548 .366 r
F
0 g
.49474 .88588 m
.49546 .89187 L
s
.49788 .90544 m
.50039 .91125 L
s
.50039 .91125 m
.50045 .91139 L
s
.49937 .91143 m
.50185 .91701 L
s
.49125 .81481 m
.49125 .81481 L
s
.49125 .8148 m
.49125 .81481 L
s
.49117 .81443 m
.49125 .8148 L
s
.48778 .81476 m
.49068 .81448 L
s
.4877 .81477 m
.48778 .81476 L
s
.49068 .81448 m
.4908 .81447 L
s
.4908 .81447 m
.49117 .81443 L
s
.52247 1.08075 m .524 1.08429 L .52601 1.08789 L 0 0 .116 r
F
0 g
.52516 1.08618 m
.52713 1.08939 L
s
.50524 .92985 m
.50524 .92985 L
s
.50524 .92985 m
.50524 .92985 L
s
.50523 .92981 m
.50524 .92985 L
s
.50523 .92981 m
.50523 .92981 L
s
.50522 .92981 m
.50523 .92981 L
s
.50323 .92427 m
.50522 .92981 L
s
.51316 .94818 m .51316 .94818 L .50967 .9431 L 0 .298 .327 r
F
.5862 .65396 m .59947 .66331 L .59857 .66235 L 0 .187 .18 r
F
.59947 .66331 m .6031 .66587 L .59933 .66294 L F
.59947 .66331 m .59933 .66294 L .59857 .66235 L F
.5996 .66433 m .6 .66471 L .59802 .66227 L 0 .029 .153 r
F
.6 .66471 m .60499 .66941 L .59974 .66403 L F
.6 .66471 m .59974 .66403 L .59802 .66227 L F
.5996 .66433 m .61225 .67704 L .60499 .66941 L F
.5996 .66433 m .6134 .67866 L .61585 .681 L F
0 g
.61133 .6768 m
.61136 .67684 L
s
.5996 .66433 m .60643 .67152 L .6134 .67866 L 0 .029 .153 r
F
0 g
.59728 .66178 m
.5996 .66433 L
s
.40495 .78768 m
.40515 .78143 L
s
.4095 .78687 m
.41027 .78673 L
s
.40495 .78768 m
.4095 .78687 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51337 .9506 L 0 .231 .277 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.28284 .80445 m .27241 .80817 L .27691 .80888 L 0 1 .526 r
F
0 g
.27691 .80888 m
.2785 .81447 L
s
.54782 1.12486 m .54778 1.11623 L .55203 1.12317 L 0 .427 .024 r
F
0 g
.54357 1.11136 m
.54778 1.11623 L
s
.54561 1.11034 m
.54778 1.11623 L
s
.49953 .78502 m .49512 .7739 L .49595 .78101 L 0 1 .385 r
F
.49953 .78502 m .49783 .76683 L .49512 .7739 L F
.49953 .78502 m .50226 .76451 L .49783 .76683 L F
.50124 .8052 m .49953 .78502 L .4972 .79224 L 0 1 .371 r
F
.56351 .64034 m .55987 .63946 L .55876 .63851 L 0 0 0 r
F
.51479 1.05977 m .51512 1.06556 L .51712 1.06818 L 0 0 .154 r
F
0 g
.51512 1.06556 m
.51753 1.071 L
s
.43064 .92984 m .42199 .92588 L .42672 .92776 L 0 0 0 r
F
0 g
.43015 .9286 m
.43133 .92925 L
s
.43064 .92984 m .41888 .92487 L .42199 .92588 L 0 0 0 r
F
0 g
.42672 .92776 m
.43015 .9286 L
s
.41975 .92482 m
.42199 .92588 L
s
.64242 .61465 m .64105 .61121 L .63848 .6132 L 0 1 .409 r
F
.64242 .61465 m .64915 .60995 L .64105 .61121 L F
.64242 .61465 m .65736 .61026 L .64915 .60995 L F
0 g
.65736 .61026 m
.66126 .61171 L
s
.65736 .61026 m
.66573 .60924 L
s
.51316 .94818 m .51052 .94261 L .50699 .93519 L 0 .27 .308 r
F
0 g
.50699 .93519 m
.50699 .93519 L
s
.51316 .94818 m .50699 .93519 L .51052 .94261 L 0 .271 .309 r
F
0 g
.50679 .93476 m
.50699 .93519 L
s
.51479 1.05977 m .51233 1.05416 L .51033 1.05156 L 0 0 .154 r
F
0 g
.48772 .81038 m
.49068 .81448 L
s
.49068 .81448 m
.49117 .81516 L
s
.46556 .94078 m .45745 .94014 L .45381 .9378 L 0 .235 .043 r
F
.46556 .94078 m .46219 .94196 L .45745 .94014 L F
.46556 .94078 m .46566 .94224 L .46219 .94196 L F
.47744 .94471 m .46566 .94224 L .46556 .94078 L 0 .283 .068 r
F
0 g
.46556 .94078 m
.46905 .94087 L
s
.46192 .93844 m
.46556 .94078 L
s
.74383 .81897 m .75757 .80797 L .75508 .81892 L 0 .239 .087 r
F
0 g
.75596 .79885 m
.75757 .80797 L
s
.75757 .80797 m
.76287 .80043 L
s
.2093 .91945 m .2011 .91323 L .19762 .91461 L 0 .739 .325 r
F
.2093 .91945 m .20577 .91428 L .2011 .91323 L F
.2093 .91945 m .20928 .91694 L .20577 .91428 L F
.22094 .92147 m .20928 .91694 L .2093 .91945 L 0 .67 .295 r
F
0 g
.20583 .9208 m
.2093 .91945 L
s
.2093 .91945 m
.2128 .92184 L
s
.38362 .9112 m .37712 .90687 L .37315 .9063 L 0 .54 .267 r
F
.38362 .9112 m .38159 .90868 L .37712 .90687 L F
.38362 .9112 m .38438 .91054 L .38159 .90868 L F
0 g
.37965 .91063 m
.38362 .9112 L
s
.39537 .9155 m .38438 .91054 L .38362 .91121 L 0 .452 .23 r
F
0 g
.38362 .91121 m
.38659 .9129 L
s
.50124 .8052 m .4972 .79224 L .49803 .8001 L 0 1 .371 r
F
0 g
.49927 .81243 m
.50124 .8052 L
s
.51316 .94818 m .51316 .94818 L .50973 .94657 L 0 .316 .119 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.33681 .75609 m .33205 .75072 L .32744 .75002 L 0 .364 .235 r
F
0 g
.32687 .75117 m
.32744 .75002 L
s
.33681 .75609 m .33821 .75342 L .33205 .75072 L 0 .364 .235 r
F
.33681 .75609 m .34179 .75632 L .33821 .75342 L F
.33681 .75609 m .34119 .75746 L .34179 .75632 L F
0 g
.33069 .7534 m
.33681 .75609 L
s
.33641 .7565 m
.33681 .75609 L
s
.63849 .73615 m .64024 .73071 L .63702 .72669 L 0 .205 .26 r
F
0 g
.63702 .72669 m
.63728 .72839 L
s
.63688 .72642 m
.63702 .72669 L
s
.63849 .73615 m .6468 .74619 L .64024 .73071 L 0 .205 .26 r
F
.63849 .73615 m .65232 .76284 L .6468 .74619 L F
.63849 .73615 m .6538 .77233 L .65232 .76284 L F
.63849 .73615 m .64368 .7528 L .65024 .76832 L F
0 g
.63728 .72839 m
.63849 .73615 L
s
.63388 .72392 m
.63849 .73615 L
s
.49264 .85068 m .49445 .83534 L .49135 .82968 L 0 .888 .374 r
F
0 g
.49135 .82968 m
.49248 .82306 L
s
.51316 .94818 m .51316 .94818 L .50977 .94291 L 0 .29 .321 r
F
.49783 .76683 m .50534 .75766 L .505 .75085 L 0 1 .399 r
F
.49783 .76683 m .50226 .76451 L .50534 .75766 L F
0 g
.50534 .75766 m
.50894 .76099 L
s
.50226 .76451 m
.50584 .76851 L
s
.50226 .76451 m
.50534 .75766 L
s
.51316 .94817 m .51316 .94817 L .51472 .93941 L 0 .399 .268 r
F
0 g
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94815 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51317 .94818 m .51317 .94818 L .51671 .94565 L 0 .29 .119 r
F
.75602 .88154 m .76353 .87745 L .75891 .87878 L 0 1 .387 r
F
.75602 .88154 m .76759 .87855 L .76353 .87745 L F
.74446 .88461 m .75602 .88154 L .75198 .88079 L 0 1 .344 r
F
.74246 .6523 m .75869 .64093 L .7519 .64668 L 0 0 0 r
F
0 g
.75869 .64093 m
.76642 .63582 L
s
.75869 .64093 m
.76077 .63774 L
s
.80198 1.0234 m .81191 1.01338 L .80744 1.01635 L 0 1 .379 r
F
.79091 1.03138 m .80198 1.0234 L .80074 1.02108 L 0 1 .335 r
F
.47121 .80014 m .46458 .7917 L .46683 .79748 L 0 1 .411 r
F
.47121 .80014 m .46594 .78536 L .46458 .7917 L F
.47121 .80014 m .46999 .7827 L .46594 .78536 L F
0 g
.4662 .80194 m
.46683 .79748 L
s
.47121 .80014 m .47437 .78537 L .46999 .7827 L 0 1 .411 r
F
.47121 .80014 m .47616 .79157 L .47437 .78537 L F
.47121 .80014 m .47481 .7979 L .47616 .79157 L F
0 g
.4706 .80391 m
.47121 .80014 L
s
.46683 .79748 m
.47121 .80014 L
s
.33607 .79639 m .32609 .79383 L .32627 .79983 L 0 1 .489 r
F
0 g
.32101 .804 m
.32627 .79983 L
s
.76759 .87855 m .77508 .87417 L .77046 .87547 L 0 1 .422 r
F
.76759 .87855 m .77916 .87561 L .77508 .87417 L F
.51316 .94818 m .50781 .93542 L .50525 .92987 L 0 .271 .309 r
F
0 g
.50525 .92987 m
.50527 .92992 L
s
.50524 .92985 m
.50525 .92987 L
s
.50461 .92981 m
.50714 .93514 L
s
.74446 .88461 m .75198 .88079 L .74736 .88215 L 0 1 .344 r
F
.73026 .88851 m .74446 .88461 L .73964 .88445 L 0 1 .285 r
F
.39221 .78474 m .383 .78406 L .38656 .78675 L 0 1 .451 r
F
0 g
.39202 .79099 m
.39221 .78474 L
s
.38656 .78675 m
.38666 .79289 L
s
.28184 .88498 m .27148 .87906 L .27024 .88281 L 0 1 .509 r
F
.28184 .88498 m .27587 .87701 L .27148 .87906 L F
.28184 .88498 m .28049 .87806 L .27587 .87701 L F
.28184 .88498 m .28304 .88147 L .28049 .87806 L F
0 g
.27746 .887 m
.28184 .88498 L
s
.77916 .87561 m .78663 .87096 L .78201 .87224 L 0 1 .45 r
F
.77916 .87561 m .79073 .87274 L .78663 .87096 L F
.29399 .80624 m .28625 .79781 L .28284 .80445 L 0 1 .521 r
F
.29399 .80624 m .29209 .79336 L .28625 .79781 L F
.29399 .80624 m .29645 .79408 L .29209 .79336 L F
.29399 .80624 m .29726 .79961 L .29645 .79408 L F
0 g
.28817 .81067 m
.29399 .80624 L
s
.50758 .96573 m .50422 .97582 L .50632 .97084 L 0 .288 .267 r
F
.50869 .97026 m .50422 .97582 L .50332 .98191 L 0 .276 .263 r
F
.50869 .97026 m .50632 .97084 L .50422 .97582 L F
0 g
.50201 .97719 m
.50422 .97582 L
s
.50847 .74363 m .50415 .73511 L .50449 .74118 L 0 1 .407 r
F
.50847 .74363 m .508 .72825 L .50415 .73511 L F
.50847 .74363 m .51346 .72519 L .508 .72825 L F
.31518 .74049 m .30519 .7324 L .30435 .73653 L 0 .61 .428 r
F
0 g
.2981 .73658 m
.30435 .73653 L
s
.49272 .80826 m .48788 .79653 L .4892 .80379 L 0 1 .382 r
F
.49272 .80826 m .4898 .78966 L .48788 .79653 L F
0 g
.48772 .81038 m
.4892 .80379 L
s
.49272 .80826 m .49367 .78777 L .4898 .78966 L 0 1 .382 r
F
.49272 .80826 m .4972 .79224 L .49367 .78777 L F
.49272 .80826 m .49803 .8001 L .4972 .79224 L F
0 g
.4972 .79224 m
.49953 .78502 L
s
.49272 .80826 m .49611 .80697 L .49803 .8001 L 0 1 .382 r
F
0 g
.49803 .8001 m
.50124 .8052 L
s
.4892 .80379 m
.49272 .80826 L
s
.49126 .81475 m
.49272 .80826 L
s
.49126 .81477 m
.49126 .81475 L
s
.49125 .8148 m
.49126 .81477 L
s
.49117 .81516 m
.49125 .8148 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51374 .95105 L 0 .232 .278 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .5106 .94262 L .50718 .93522 L 0 .271 .309 r
F
0 g
.50714 .93514 m
.50718 .93522 L
s
.51316 .94818 m .50718 .93522 L .5106 .94262 L 0 .271 .309 r
F
0 g
.50554 .93132 m
.50718 .93522 L
s
.49611 .80697 m
.49803 .8001 L
s
.49611 .80697 m
.49927 .81243 L
s
.49674 .87177 m .49222 .85711 L .494 .86538 L 0 .775 .366 r
F
.49674 .87177 m .49264 .85068 L .49222 .85711 L F
0 g
.4892 .85138 m
.49222 .85711 L
s
.36454 .78724 m .3549 .78918 L .35873 .7909 L 0 1 .461 r
F
0 g
.35873 .7909 m
.35917 .7969 L
s
.73026 .88851 m .73964 .88445 L .73397 .88617 L 0 1 .285 r
F
.71945 .89164 m .73026 .88851 L .72648 .88848 L 0 .884 .252 r
F
.79073 .87274 m .7982 .86781 L .79357 .86906 L 0 1 .471 r
F
.79073 .87274 m .8023 .86994 L .7982 .86781 L F
.50869 .97026 m .50332 .98191 L .50422 .98505 L 0 .276 .263 r
F
0 g
.50332 .98191 m
.50422 .97582 L
s
.50107 .98204 m
.50332 .98191 L
s
.52238 .70694 m .53383 .6927 L .52952 .69161 L 0 1 .436 r
F
0 g
.53383 .6927 m
.53902 .68641 L
s
.33607 .79639 m .32991 .78681 L .32609 .79383 L 0 1 .489 r
F
.33607 .79639 m .33567 .78237 L .32991 .78681 L F
.33607 .79639 m .33953 .78348 L .33567 .78237 L F
.33607 .79639 m .3397 .78949 L .33953 .78348 L F
0 g
.33607 .79639 m
.33638 .80243 L
s
.33032 .80081 m
.33607 .79639 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51385 .95119 L 0 .236 .28 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.48645 .63249 m .47926 .63278 L .48006 .63302 L 0 .677 .209 r
F
0 g
.47498 .63446 m
.48006 .63302 L
s
.48645 .63249 m .4848 .63203 L .47926 .63278 L 0 .677 .209 r
F
.48645 .63249 m .493 .63125 L .4848 .63203 L F
.48645 .63249 m .4994 .63073 L .493 .63125 L F
.48645 .63249 m .49972 .63079 L .4994 .63073 L F
0 g
.49963 .63077 m
.50021 .63069 L
s
.48645 .63249 m .49417 .63155 L .49972 .63079 L 0 .677 .209 r
F
0 g
.48126 .63319 m
.48645 .63249 L
s
.48006 .63302 m
.48645 .63249 L
s
.51035 .82695 m .50752 .81038 L .50786 .81977 L 0 .963 .348 r
F
0 g
.50469 .80414 m
.50752 .81038 L
s
.51007 .8279 m
.51008 .82793 L
s
.50937 .82414 m
.51007 .8279 L
s
.50752 .81038 m
.50988 .80273 L
s
.51316 .94818 m .51316 .94818 L .50991 .94275 L 0 .283 .316 r
F
0 g
.51183 .93159 m
.51284 .94419 L
s
.51284 .94419 m
.51285 .94429 L
s
.51285 .94429 m
.51286 .94437 L
s
.49264 .85068 m .49576 .84381 L .49445 .83534 L 0 .888 .374 r
F
.49264 .85068 m .49498 .85038 L .49576 .84381 L F
.49674 .87177 m .49498 .85038 L .49264 .85068 L 0 .775 .366 r
F
0 g
.48955 .84503 m
.49264 .85068 L
s
.49222 .85711 m
.49264 .85068 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51068 .94968 L 0 .317 .263 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.71516 .82359 m
.71516 .82359 L
s
.54455 .63429 m .55219 .6363 L .55876 .63851 L 0 0 0 r
F
0 g
.55219 .6363 m
.55709 .63673 L
s
.8023 .86994 m .80976 .86473 L .80513 .86595 L 0 1 .488 r
F
.8023 .86994 m .81388 .86719 L .80976 .86473 L F
0 g
.60643 .67152 m
.6118 .67702 L
s
.6118 .67702 m
.61188 .67711 L
s
.61188 .67711 m
.61212 .67735 L
s
.50955 1.03794 m .50866 1.04588 L .51065 1.04747 L 0 .104 .201 r
F
0 g
.50866 1.04588 m
.51033 1.05156 L
s
.51316 .94818 m .51926 .96271 L .51968 .96319 L 0 .259 .298 r
F
.51316 .94818 m .51721 .95809 L .51926 .96271 L F
0 g
.51926 .96271 m
.52067 .96552 L
s
.51721 .9581 m
.51926 .96271 L
s
.47481 .7979 m
.47885 .80127 L
s
.40865 .78294 m
.41028 .78673 L
s
.50126 .94735 m .49288 .94744 L .48933 .94595 L 0 .322 .102 r
F
.71945 .89164 m .72648 .88848 L .72216 .88984 L 0 .884 .252 r
F
.70864 .89504 m .71945 .89164 L .71568 .89197 L 0 .834 .238 r
F
.49743 .89214 m .49667 .87791 L .49398 .87165 L 0 .67 .368 r
F
0 g
.49398 .87165 m
.49432 .87243 L
s
.49398 .87165 m
.494 .86538 L
s
.49474 .88588 m
.49733 .89191 L
s
.50683 .93067 m .50186 .91704 L .50452 .9247 L 0 .388 .349 r
F
0 g
.50527 .92992 m
.50532 .93003 L
s
.50683 .93067 m .50051 .91151 L .50186 .91704 L 0 .388 .349 r
F
.50582 .93011 m .50452 .9247 L .50186 .91704 L 0 .393 .353 r
F
0 g
.50185 .91701 m
.50186 .91704 L
s
.75132 .67298 m
.75192 .66887 L
s
.50955 1.03794 m .5076 1.03299 L .50561 1.03142 L 0 .104 .201 r
F
.48934 .94783 m .48096 .94459 L .48572 .94589 L 0 .313 .088 r
F
0 g
.48933 .94595 m
.48944 .94599 L
s
.48934 .94783 m .47744 .94471 L .48096 .94459 L 0 .313 .088 r
F
0 g
.4777 .94273 m
.48096 .94459 L
s
.48572 .94589 m
.48933 .94595 L
s
.40868 .7813 m .40989 .78191 L .40827 .78187 L 0 0 0 r
F
.4898 .78966 m .49367 .78777 L .49595 .78101 L 0 1 .394 r
F
0 g
.49367 .78777 m
.4972 .79224 L
s
.81388 .86719 m .82133 .86171 L .8167 .86291 L 0 1 .5 r
F
.81388 .86719 m .82546 .8645 L .82133 .86171 L F
.52069 .96433 m .52029 .96389 L .52205 .96716 L 0 .088 .181 r
F
.50051 .91151 m .50032 .90599 L .49809 .89794 L 0 .548 .366 r
F
.50051 .91151 m .50136 .91181 L .50032 .90599 L F
.50683 .93067 m .50136 .91181 L .50051 .91151 L 0 .388 .349 r
F
0 g
.50051 .91151 m
.50186 .91704 L
s
.50045 .91139 m
.50051 .91151 L
s
.50323 .92427 m
.50572 .92988 L
s
.50572 .92988 m
.50572 .92988 L
s
.50572 .92988 m
.50572 .92988 L
s
.50572 .92988 m
.50575 .92994 L
s
.50575 .92994 m
.50575 .92995 L
s
.50575 .92995 m
.50575 .92995 L
s
.50575 .92995 m
.50577 .93 L
s
.50577 .93 m
.50577 .93 L
s
.50577 .93 m
.50577 .93 L
s
.41663 .7869 m
.4175 .78685 L
s
.4175 .78685 m
.4195 .78674 L
s
.55203 1.12317 m .55839 1.12589 L .55659 1.12732 L 0 .392 .029 r
F
0 g
.5562 1.11998 m
.55839 1.12589 L
s
.55839 1.12589 m
.56087 1.12809 L
s
.51316 .94818 m .51316 .94818 L .51008 .94265 L 0 .276 .312 r
F
.51316 .94818 m .51721 .95809 L .5149 .95243 L 0 .251 .291 r
F
.51316 .94818 m .5149 .95243 L .51721 .95809 L 0 .259 .298 r
F
0 g
.51721 .95809 m
.51861 .96195 L
s
.51721 .95809 m
.51721 .9581 L
s
.49856 .85021 m .49564 .82853 L .49445 .83534 L 0 .873 .363 r
F
.49856 .85021 m .49854 .82792 L .49564 .82853 L F
0 g
.49248 .82306 m
.49564 .82853 L
s
.22094 .92147 m .21277 .91585 L .20928 .91694 L 0 .67 .295 r
F
.22094 .92147 m .21744 .9169 L .21277 .91585 L F
.22094 .92147 m .22095 .91932 L .21744 .9169 L F
.23258 .92354 m .22095 .91932 L .22094 .92147 L 0 .633 .266 r
F
0 g
.21745 .92255 m
.22094 .92147 L
s
.22094 .92147 m
.22443 .92362 L
s
.78881 .8146 m .79736 .80325 L .80196 .80318 L 0 0 .008 r
F
.78881 .8146 m .79174 .80812 L .79736 .80325 L F
0 g
.79521 .79958 m
.79736 .80325 L
s
.51316 .94818 m .51316 .94818 L .51421 .95162 L 0 .242 .285 r
F
.27024 .88281 m .25992 .8767 L .25864 .8807 L 0 1 .513 r
F
.27024 .88281 m .26434 .87445 L .25992 .8767 L F
.27024 .88281 m .26895 .87547 L .26434 .87445 L F
.27024 .88281 m .27148 .87906 L .26895 .87547 L F
0 g
.26583 .88504 m
.27024 .88281 L
s
.27024 .88281 m
.27281 .88621 L
s
.56057 .65932 m .55723 .65605 L .55615 .6593 L 0 1 .431 r
F
.56057 .65932 m .5636 .65151 L .55723 .65605 L F
.56057 .65932 m .571 .64871 L .5636 .65151 L F
0 g
.571 .64871 m
.57539 .64875 L
s
.54455 .63429 m .53993 .63371 L .53929 .63318 L 0 0 0 r
F
.54455 .63429 m .5465 .63592 L .53993 .63371 L F
.54455 .63429 m .55462 .63835 L .5465 .63592 L F
.54455 .63429 m .55987 .63946 L .55462 .63835 L F
.54455 .63429 m .55876 .63851 L .55987 .63946 L F
0 g
.55947 .63879 m
.56348 .64033 L
s
.55876 .63851 m
.55947 .63879 L
s
.53834 .63209 m
.54455 .63429 L
s
.55219 .6363 m
.55876 .63851 L
s
.39221 .78474 m .38352 .77757 L .383 .78406 L 0 1 .451 r
F
0 g
.37757 .78656 m
.383 .78406 L
s
.38656 .78675 m
.39221 .78474 L
s
.69055 .70111 m
.69058 .70122 L
s
.69058 .70122 m
.6909 .70231 L
s
.68841 .69385 m
.69055 .70111 L
s
.6909 .70231 m
.69093 .70242 L
s
.69093 .70242 m
.69103 .70276 L
s
.69685 .72252 m
.69685 .72253 L
s
.69622 .7204 m
.69685 .72252 L
s
.69533 .71737 m
.69622 .7204 L
s
.69391 .71255 m
.69533 .71737 L
s
.69232 .70713 m
.69391 .71255 L
s
.49856 .85021 m .49445 .83534 L .49576 .84381 L 0 .873 .363 r
F
0 g
.49445 .83534 m
.49564 .82853 L
s
.49135 .82968 m
.49445 .83534 L
s
.52075 .93381 m .52718 .92632 L .52907 .91592 L 0 .411 .261 r
F
0 g
.52907 .91592 m
.53211 .9111 L
s
.52518 .83003 m .52811 .83143 L .53115 .82249 L 0 .929 .319 r
F
0 g
.52811 .83143 m
.53115 .82249 L
s
.4898 .78966 m .49595 .78101 L .49512 .7739 L 0 1 .394 r
F
0 g
.49595 .78101 m
.49953 .78502 L
s
.49367 .78777 m
.49595 .78101 L
s
.82546 .8645 m .83291 .85876 L .82828 .85994 L 0 1 .509 r
F
.82546 .8645 m .83705 .86188 L .83291 .85876 L F
.51316 .94818 m .50484 .94718 L .50959 .94775 L 0 .345 .119 r
F
0 g
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50126 .94735 L .50484 .94718 L 0 .345 .119 r
F
0 g
.50358 .94724 m
.50364 .94724 L
s
.50364 .94724 m
.50369 .94723 L
s
.51316 .94818 m .50959 .94775 L .50484 .94718 L 0 .337 .12 r
F
0 g
.50369 .94723 m
.50484 .94718 L
s
.50133 .94615 m
.50484 .94718 L
s
.53849 .99082 m .54538 .99703 L .54191 .99421 L 0 .296 0 r
F
0 g
.54539 .99704 m
.54606 .99779 L
s
.54101 .99516 m .54191 .99421 L .54538 .99703 L 0 .329 0 r
F
0 g
.54538 .99703 m
.54539 .99704 L
s
.54538 .99703 m
.54596 .99719 L
s
.50582 .93011 m .50621 .9303 L .50452 .9247 L 0 .393 .353 r
F
.51316 .94818 m .50582 .93011 L .50781 .93542 L 0 .275 .311 r
F
.51316 .94818 m .50621 .9303 L .50582 .93011 L F
0 g
.51183 .93159 m
.51292 .94516 L
s
.50532 .93003 m
.50781 .93542 L
s
.50577 .93 m
.50582 .93011 L
s
.50582 .93011 m
.50585 .93019 L
s
.53005 .97992 m .52933 .97892 L .53113 .98107 L 0 .163 0 r
F
0 g
.53093 .98084 m
.53113 .98107 L
s
.53091 .9808 m
.53093 .98084 L
s
.53051 .98032 m
.53091 .9808 L
s
.52998 .97969 m
.53051 .98032 L
s
.53089 .98077 m
.53113 .98107 L
s
.53086 .98073 m
.53089 .98077 L
s
.53035 .98009 m
.53086 .98073 L
s
.52961 .97916 m
.53035 .98009 L
s
.52886 .97821 m
.52961 .97916 L
s
.4898 .78966 m .48459 .77947 L .48591 .78611 L 0 1 .394 r
F
.4898 .78966 m .48687 .77271 L .48459 .77947 L F
.4898 .78966 m .49123 .77034 L .48687 .77271 L F
.4898 .78966 m .49512 .7739 L .49123 .77034 L F
0 g
.48788 .79653 m
.4898 .78966 L
s
.51316 .94818 m .51316 .94818 L .50964 .94715 L 0 .326 .12 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.70864 .89504 m .71568 .89197 L .71137 .89344 L 0 .834 .238 r
F
0 g
.7049 .89581 m
.70562 .89566 L
s
.70562 .89566 m
.70864 .89504 L
s
.39537 .9155 m .38844 .91155 L .38438 .91054 L 0 .452 .23 r
F
.39537 .9155 m .3931 .91355 L .38844 .91155 L F
.39537 .9155 m .39607 .91525 L .3931 .91355 L F
.40712 .92007 m .39607 .91525 L .39537 .9155 L 0 .332 .195 r
F
0 g
.39131 .9145 m
.39537 .9155 L
s
.39537 .9155 m
.39839 .91697 L
s
.4562 .79235 m .44865 .78566 L .45133 .79071 L 0 1 .426 r
F
.4562 .79235 m .44983 .77946 L .44865 .78566 L F
.4562 .79235 m .45409 .77625 L .44983 .77946 L F
0 g
.45081 .79547 m
.45133 .79071 L
s
.4562 .79235 m .45896 .77789 L .45409 .77625 L 0 1 .426 r
F
.4562 .79235 m .46121 .7833 L .45896 .77789 L F
.4562 .79235 m .46003 .78949 L .46121 .7833 L F
0 g
.45552 .79724 m
.4562 .79235 L
s
.45133 .79071 m
.4562 .79235 L
s
.48032 .79468 m .47437 .78537 L .47616 .79157 L 0 1 .403 r
F
.48032 .79468 m .4762 .77884 L .47437 .78537 L F
0 g
.47481 .7979 m
.47616 .79157 L
s
.48032 .79468 m .48043 .77636 L .4762 .77884 L 0 1 .403 r
F
.48032 .79468 m .48459 .77947 L .48043 .77636 L F
.48032 .79468 m .48591 .78611 L .48459 .77947 L F
.48032 .79468 m .48408 .79262 L .48591 .78611 L F
0 g
.48591 .78611 m
.4898 .78966 L
s
.47885 .80127 m
.48032 .79468 L
s
.47616 .79157 m
.48032 .79468 L
s
.48408 .79262 m
.48788 .79653 L
s
.51316 .94818 m .51827 .93666 L .52015 .92975 L 0 .386 .269 r
F
0 g
.52015 .92975 m
.52265 .92341 L
s
.50267 .91239 m .49809 .89794 L .50032 .90599 L 0 .534 .359 r
F
.50267 .91239 m .49743 .89214 L .49809 .89794 L F
0 g
.49546 .89187 m
.49809 .89794 L
s
.52069 .96433 m .5282 .97738 L .52645 .97411 L 0 .088 .181 r
F
0 g
.5282 .97738 m
.52886 .97821 L
s
.49783 .76683 m .505 .75085 L .50105 .74777 L 0 1 .399 r
F
0 g
.505 .75085 m
.50847 .74363 L
s
.51779 .82776 m .52076 .82846 L .52347 .82024 L 0 .948 .334 r
F
0 g
.52076 .82846 m
.52347 .82024 L
s
.52347 .82024 m
.52518 .83003 L
s
.51316 .94818 m .51316 .94818 L .51028 .9426 L 0 .272 .309 r
F
0 g
.51292 .94516 m
.51293 .94524 L
s
.38453 .66814 m .37418 .67384 L .37715 .67259 L 0 1 .385 r
F
.38453 .66814 m .3774 .67034 L .37418 .67384 L F
.38453 .66814 m .38468 .66441 L .3774 .67034 L F
.38453 .66814 m .39207 .65996 L .38468 .66441 L F
.38453 .66814 m .39464 .65995 L .39207 .65996 L F
.38453 .66814 m .3914 .66346 L .39464 .65995 L F
0 g
.38159 .6708 m
.38453 .66814 L
s
.37715 .67259 m
.38453 .66814 L
s
.48408 .79262 m
.48591 .78611 L
s
.52495 .94887 m .52502 .94747 L .52863 .94412 L 0 .29 .138 r
F
0 g
.52537 .94714 m
.52863 .94412 L
s
.52507 .94539 m
.52863 .94412 L
s
.51316 .94818 m .50873 .95821 L .51126 .95248 L 0 .306 .262 r
F
.51316 .94818 m .50873 .95821 L .50715 .96389 L 0 .302 .261 r
F
.51316 .94818 m .51126 .95248 L .50873 .95821 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.50653 .96112 m
.50873 .95821 L
s
.50872 .95823 m
.50873 .95821 L
s
.50126 .94735 m .49765 .9482 L .49288 .94744 L 0 .322 .102 r
F
.50126 .94735 m .50124 .94816 L .49765 .9482 L F
.51316 .94818 m .50124 .94816 L .50126 .94735 L 0 .345 .119 r
F
0 g
.49771 .94586 m
.50126 .94735 L
s
.50126 .94735 m
.50358 .94724 L
s
.51316 .94818 m .50781 .93542 L .51087 .94271 L 0 .275 .311 r
F
.51316 .94818 m .51087 .94271 L .50781 .93542 L 0 .271 .309 r
F
0 g
.50781 .93542 m
.50781 .93542 L
s
.50585 .93019 m
.50781 .93542 L
s
.51098 .94629 m
.51216 .94731 L
s
.51293 .94524 m
.51293 .9453 L
s
.51216 .94731 m
.51229 .94743 L
s
.72177 .60093 m .73875 .60072 L .7305 .59761 L 0 1 .473 r
F
0 g
.73875 .60072 m
.74212 .60385 L
s
.73875 .60072 m
.7477 .60222 L
s
.5068 1.01554 m .50469 1.02564 L .50666 1.02609 L 0 .185 .241 r
F
0 g
.50469 1.02564 m
.50561 1.03142 L
s
.70896 1.10653 m .70516 1.10385 L .70517 1.09936 L 0 0 .029 r
F
0 g
.6989 1.09947 m
.70517 1.09936 L
s
.2074 .81138 m .19889 .80162 L .19591 .80958 L 0 1 .536 r
F
0 g
.19591 .80958 m
.19716 .81601 L
s
.2074 .81138 m .20453 .79628 L .19889 .80162 L 0 1 .536 r
F
.2074 .81138 m .20907 .79717 L .20453 .79628 L F
.2074 .81138 m .21029 .80365 L .20907 .79717 L F
0 g
.2066 .81213 m
.2074 .81138 L
s
.2074 .81138 m
.2087 .81763 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51096 .95109 L 0 .306 .262 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51968 .96319 L .51795 .95894 L 0 .259 .298 r
F
0 g
.51968 .96319 m
.52205 .96716 L
s
.36454 .78724 m .35515 .78247 L .3549 .78918 L 0 1 .461 r
F
0 g
.34945 .79287 m
.3549 .78918 L
s
.36454 .78724 m .35932 .77523 L .35515 .78247 L 0 1 .461 r
F
.36454 .78724 m .36513 .77156 L .35932 .77523 L F
.36454 .78724 m .36871 .77391 L .36513 .77156 L F
.36454 .78724 m .36846 .78063 L .36871 .77391 L F
0 g
.36447 .79366 m
.36454 .78724 L
s
.35873 .7909 m
.36454 .78724 L
s
.81803 .99647 m .82768 .99801 L .82935 .9893 L 0 1 .446 r
F
0 g
.82308 1.00651 m
.82768 .99801 L
s
.82768 .99801 m
.82978 1.00274 L
s
.49856 .85021 m .50134 .83432 L .49854 .82792 L 0 .873 .363 r
F
0 g
.49854 .82792 m
.49908 .82552 L
s
.51317 .94818 m .52507 .94539 L .52149 .94694 L 0 .293 .118 r
F
0 g
.52505 .9454 m
.52507 .94539 L
s
.52354 .94605 m
.52505 .9454 L
s
.52319 .94621 m
.52354 .94605 L
s
.52291 .94633 m
.52319 .94621 L
s
.52507 .94539 m
.52507 .94539 L
s
.52507 .94742 m
.52537 .94714 L
s
.49674 .87177 m .49773 .85677 L .49498 .85038 L 0 .775 .366 r
F
0 g
.49498 .85038 m
.49576 .84381 L
s
.49783 .76683 m .49304 .75732 L .49387 .76375 L 0 1 .399 r
F
.49783 .76683 m .49611 .75047 L .49304 .75732 L F
.49783 .76683 m .50105 .74777 L .49611 .75047 L F
0 g
.49512 .7739 m
.49783 .76683 L
s
.53245 .83427 m .53531 .83667 L .53864 .82677 L 0 .907 .304 r
F
0 g
.53531 .83667 m
.53864 .82677 L
s
.53115 .82249 m
.53245 .83427 L
s
.51316 .94817 m .51316 .94818 L .51505 .94126 L 0 .395 .269 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.52525 .63126 m .533 .63213 L .53929 .63318 L 0 0 0 r
F
0 g
.533 .63213 m
.53834 .63209 L
s
.5068 1.01554 m .50536 1.0114 L .50339 1.01096 L 0 .185 .241 r
F
.28284 .80445 m .27168 .80266 L .27241 .80817 L 0 1 .526 r
F
0 g
.26716 .81279 m
.27241 .80817 L
s
.49743 .89214 m .49845 .88635 L .49667 .87791 L 0 .67 .368 r
F
.49743 .89214 m .49877 .89245 L .49845 .88635 L F
.50267 .91239 m .49877 .89245 L .49743 .89214 L 0 .534 .359 r
F
0 g
.49733 .89191 m
.49743 .89214 L
s
.49743 .89214 m
.49809 .89794 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51456 .95204 L 0 .251 .291 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51377 .95018 m
.51382 .95035 L
s
.51382 .95035 m
.51421 .95162 L
s
.51352 .94972 m
.51385 .95119 L
s
.5135 .94965 m
.51352 .94972 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50715 .96389 L .50758 .96573 L 0 .302 .261 r
F
0 g
.50493 .96526 m
.50715 .96389 L
s
.50715 .96389 m
.50872 .95823 L
s
.51317 .94818 m .51317 .94818 L .51674 .94663 L 0 .293 .118 r
F
0 g
.50618 .93017 m
.50618 .93017 L
s
.50617 .93017 m
.50618 .93017 L
s
.50616 .93013 m
.50617 .93017 L
s
.50616 .93013 m
.50616 .93013 L
s
.50616 .93013 m
.50616 .93013 L
s
.50615 .93009 m
.50616 .93013 L
s
.50615 .93009 m
.50615 .93009 L
s
.50615 .93009 m
.50615 .93009 L
s
.50452 .9247 m
.50615 .93009 L
s
.51035 .82695 m .51333 .82711 L .51568 .81945 L 0 .963 .348 r
F
0 g
.51333 .82711 m
.51568 .81945 L
s
.51568 .81945 m
.51779 .82776 L
s
.508 .72825 m .51767 .71888 L .51783 .71351 L 0 1 .424 r
F
.508 .72825 m .51346 .72519 L .51767 .71888 L F
0 g
.51767 .71888 m
.52163 .72039 L
s
.51346 .72519 m
.51744 .72764 L
s
.51346 .72519 m
.51767 .71888 L
s
.50581 .63077 m .4994 .63073 L .49972 .63079 L 0 0 0 r
F
.50581 .63077 m .50535 .63079 L .4994 .63073 L F
0 g
.49417 .63155 m
.49972 .63079 L
s
.49972 .63079 m
.50398 .63078 L
s
.50581 .63077 m .51362 .63096 L .50535 .63079 L 0 0 0 r
F
.50581 .63077 m .5197 .63093 L .51362 .63096 L F
0 g
.51931 .63022 m
.52271 .63082 L
s
.50581 .63077 m .51954 .63075 L .5197 .63093 L 0 0 0 r
F
.50581 .63077 m .51359 .63068 L .51954 .63075 L F
0 g
.50021 .63069 m
.50581 .63077 L
s
.51359 .63068 m
.51931 .63022 L
s
.50786 .81977 m
.51035 .82695 L
s
.50642 .82508 m
.50786 .81977 L
s
.57966 .96798 m
.57967 .97616 L
s
.57967 .97616 m
.57967 .97718 L
s
.57967 .97718 m
.57967 .97818 L
s
.57967 .97818 m
.57967 .97966 L
s
.57967 .97966 m
.57967 .98252 L
s
.5796 .91689 m
.5796 .91802 L
s
.57953 .8546 m
.57958 .89934 L
s
.57284 .87073 m .5755 .90161 L .57953 .85118 L 0 .924 .229 r
F
0 g
.5755 .90161 m
.57953 .85118 L
s
.57953 .85118 m
.57953 .8546 L
s
.57284 .87073 m
.57298 .8062 L
s
.43972 .78792 m .43136 .78274 L .43444 .78718 L 0 1 .437 r
F
.43972 .78792 m .43231 .77655 L .43136 .78274 L F
.43972 .78792 m .43667 .77274 L .43231 .77655 L F
0 g
.4343 .7894 m
.43444 .78718 L
s
.43972 .78792 m .44195 .77348 L .43667 .77274 L 0 1 .437 r
F
.43972 .78792 m .44463 .77828 L .44195 .77348 L F
.43972 .78792 m .44367 .78446 L .44463 .77828 L F
0 g
.43937 .79117 m
.43972 .78792 L
s
.43444 .78718 m
.43972 .78792 L
s
.51316 .94818 m .50851 .93577 L .50621 .9303 L 0 .275 .311 r
F
0 g
.50621 .9303 m
.50623 .93034 L
s
.50618 .93017 m
.50621 .9303 L
s
.68845 .65855 m .68899 .64427 L .6855 .64122 L 0 .316 .303 r
F
0 g
.68217 .63417 m
.6855 .64122 L
s
.51316 .94818 m .51316 .94818 L .51052 .94261 L 0 .27 .308 r
F
.52525 .63126 m .5197 .63093 L .51954 .63075 L 0 0 0 r
F
0 g
.51954 .63075 m
.52087 .63087 L
s
.52525 .63126 m .52599 .63198 L .5197 .63093 L 0 0 0 r
F
.52525 .63126 m .53423 .6332 L .52599 .63198 L F
.52525 .63126 m .53993 .63371 L .53423 .6332 L F
0 g
.54034 .6334 m
.54455 .63429 L
s
.52525 .63126 m .53929 .63318 L .53993 .63371 L 0 0 0 r
F
0 g
.53929 .63318 m
.54034 .6334 L
s
.52087 .63087 m
.52525 .63126 L
s
.52271 .63082 m
.52525 .63126 L
s
.533 .63213 m
.53929 .63318 L
s
.67575 .60655 m
.67577 .6066 L
s
.67298 .59719 m
.67323 .59803 L
s
.67416 .60118 m
.675 .60401 L
s
.67094 .59397 m
.67114 .59429 L
s
.67212 .59583 m
.67298 .59719 L
s
.66447 .5838 m
.67094 .59397 L
s
.66394 .58296 m
.66447 .5838 L
s
.67693 .61052 m .69375 .63692 L .68499 .61697 L 0 .265 .301 r
F
.67693 .61052 m .69772 .65031 L .69375 .63692 L F
.67693 .61052 m .69423 .64817 L .69772 .65031 L F
0 g
.68493 .64877 m
.68731 .65537 L
s
.68172 .63983 m
.68493 .64877 L
s
.67693 .61052 m .68531 .63109 L .69423 .64817 L 0 .265 .301 r
F
0 g
.67577 .6066 m
.67693 .61052 L
s
.67538 .60725 m
.67693 .61052 L
s
.6855 .64122 m
.68655 .64739 L
s
.25864 .8807 m .24834 .87437 L .24703 .87863 L 0 1 .516 r
F
.25864 .8807 m .25279 .87192 L .24834 .87437 L F
.25864 .8807 m .25741 .87293 L .25279 .87192 L F
.25864 .8807 m .25992 .8767 L .25741 .87293 L F
0 g
.2542 .88313 m
.25864 .8807 L
s
.25864 .8807 m
.26118 .88427 L
s
.70896 1.10653 m .71472 1.09463 L .71869 1.09605 L 0 0 .029 r
F
0 g
.70894 1.09605 m
.71472 1.09463 L
s
.51359 .63068 m
.51954 .63075 L
s
.559 .90301 m .55941 .89449 L .55908 .89376 L 0 .763 .255 r
F
.55908 .89376 m .5633 .99894 L .5598 .93558 L 0 .867 .199 r
F
.55883 .87867 m .55941 .89449 L .55908 .89376 L F
.55941 .89449 m .5633 .99894 L .55908 .89376 L F
.55908 .89376 m .56206 .83978 L .5593 .86848 L 0 .763 .255 r
F
.55941 .89449 m .56206 .83978 L .55908 .89376 L F
0 g
.56046 .84533 m
.56068 .85408 L
s
.55283 .87189 m .5593 .86848 L .56206 .83978 L 0 .814 .263 r
F
0 g
.56203 .83216 m
.56206 .83978 L
s
.56206 .83978 m
.56613 .82717 L
s
.29005 .59598 m .28178 .59545 L .28539 .597 L 0 1 .501 r
F
.29005 .59598 m .2811 .59214 L .28178 .59545 L F
.29005 .59598 m .28381 .58927 L .2811 .59214 L F
.29005 .59598 m .28849 .58825 L .28381 .58927 L F
.29005 .59598 m .292 .58975 L .28849 .58825 L F
.29005 .59598 m .29267 .59306 L .292 .58975 L F
0 g
.29005 .59598 m
.29079 .59939 L
s
.28539 .597 m
.29005 .59598 L
s
.50683 .93067 m .50367 .91777 L .50136 .91181 L 0 .388 .349 r
F
0 g
.50136 .91181 m
.50144 .91202 L
s
.50032 .90599 m
.50136 .91181 L
s
.50679 .93056 m
.50679 .93056 L
s
.50679 .93056 m
.50679 .93056 L
s
.5067 .93031 m
.50679 .93056 L
s
.50669 .93031 m
.5067 .93031 L
s
.50669 .93031 m
.50669 .93031 L
s
.50667 .93026 m
.50669 .93031 L
s
.50452 .9247 m
.50665 .9302 L
s
.50665 .9302 m
.50665 .9302 L
s
.50665 .9302 m
.50665 .9302 L
s
.50665 .9302 m
.50667 .93025 L
s
.50667 .93025 m
.50667 .93026 L
s
.50667 .93026 m
.50667 .93026 L
s
.51316 .94818 m .51316 .94818 L .5106 .94262 L 0 .271 .309 r
F
0 g
.5106 .94262 m
.51062 .94267 L
s
.5131 .94666 m
.5131 .94668 L
s
.5131 .94664 m
.5131 .94666 L
s
.51254 .93231 m
.5131 .94664 L
s
.51311 .94681 m
.51311 .94683 L
s
.51311 .9468 m
.51311 .94681 L
s
.51254 .93231 m
.51311 .9468 L
s
.46003 .78949 m
.46458 .7917 L
s
.23258 .92354 m .22445 .9185 L .22095 .91932 L 0 .633 .266 r
F
.23258 .92354 m .22912 .91957 L .22445 .9185 L F
.23258 .92354 m .23261 .92173 L .22912 .91957 L F
.24422 .92565 m .23261 .92173 L .23258 .92354 L 0 .606 .25 r
F
0 g
.22908 .92434 m
.23258 .92354 L
s
.23258 .92354 m
.23605 .92544 L
s
.36397 .54435 m .35164 .54888 L .35441 .54968 L 0 1 .44 r
F
0 g
.34951 .55725 m
.35441 .54968 L
s
.36397 .54435 m .35737 .54249 L .35164 .54888 L 0 1 .44 r
F
.36397 .54435 m .36779 .53477 L .35737 .54249 L F
.36397 .54435 m .37737 .52943 L .36779 .53477 L F
.36397 .54435 m .37971 .53003 L .37737 .52943 L F
.36397 .54435 m .37397 .53643 L .37971 .53003 L F
0 g
.35856 .55074 m
.36397 .54435 L
s
.35441 .54968 m
.36397 .54435 L
s
.37397 .53643 m
.38322 .53079 L
s
.66746 .74486 m
.6675 .74405 L
s
.66716 .75048 m
.66731 .74757 L
s
.66744 .7451 m
.66746 .74486 L
s
.66602 .74683 m
.66677 .74322 L
s
.66571 .74836 m
.66602 .74683 L
s
.44241 .93489 m .43381 .93062 L .43853 .93255 L 0 .092 0 r
F
0 g
.44197 .93319 m
.44294 .93378 L
s
.44241 .93489 m .43064 .92984 L .43381 .93062 L 0 .092 0 r
F
0 g
.43853 .93255 m
.44197 .93319 L
s
.43133 .92925 m
.43381 .93062 L
s
.40989 .78191 m
.41161 .78233 L
s
.41161 .78233 m
.41163 .78233 L
s
.41163 .78233 m
.41332 .78275 L
s
.41336 .78282 m
.41336 .78282 L
s
.41336 .78282 m
.41336 .78282 L
s
.41336 .78282 m
.41336 .78282 L
s
.41332 .78275 m
.41336 .78282 L
s
.50653 .99287 m .5056 .98974 L .50366 .99059 L 0 .238 .258 r
F
.30519 .7324 m .29414 .72981 L .29823 .73247 L 0 .88 .476 r
F
0 g
.2981 .73658 m
.29823 .73247 L
s
.50653 .99287 m .50323 1.00521 L .50516 1.00437 L 0 .238 .258 r
F
0 g
.50323 1.00521 m
.50339 1.01096 L
s
.51316 .94818 m .51316 .94818 L .5149 .95243 L 0 .259 .298 r
F
0 g
.69976 .89794 m
.70059 .8975 L
s
.6709 1.12574 m .67036 1.10822 L .67614 1.1106 L 0 .241 .083 r
F
.6709 1.12574 m .66676 1.11086 L .67036 1.10822 L F
0 g
.66948 1.10208 m
.67036 1.10822 L
s
.50084 .89314 m .49667 .87791 L .49845 .88635 L 0 .653 .359 r
F
.50084 .89314 m .49674 .87177 L .49667 .87791 L F
0 g
.49432 .87243 m
.49667 .87791 L
s
.29267 .59306 m
.29726 .59205 L
s
.51316 .94818 m .51316 .94818 L .50959 .94775 L 0 .337 .12 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.50869 .97026 m .50824 .96846 L .50632 .97084 L 0 .276 .263 r
F
0 g
.40515 .78143 m
.40865 .78294 L
s
.51316 .94818 m .51316 .94818 L .51126 .95248 L 0 .302 .261 r
F
.51316 .94818 m .51795 .95894 L .51521 .95279 L 0 .259 .298 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51795 .95894 L .52029 .96389 L 0 .266 .304 r
F
.51316 .94818 m .51521 .95279 L .51795 .95894 L F
0 g
.51325 .94861 m
.51374 .95105 L
s
.51795 .95894 m
.51968 .96319 L
s
.51795 .95894 m
.51795 .95895 L
s
.51316 .94818 m .51316 .94818 L .51087 .94271 L 0 .271 .309 r
F
0 g
.4012 .77952 m
.4017 .77968 L
s
.39883 .77874 m
.4012 .77952 L
s
.3988 .77873 m
.39883 .77874 L
s
.39875 .77872 m
.3988 .77873 L
s
.39871 .7787 m
.39875 .77872 L
s
.3963 .77792 m
.39871 .7787 L
s
.40989 .78148 m
.41154 .7823 L
s
.41154 .7823 m
.41161 .78233 L
s
.41161 .78233 m
.41331 .78318 L
s
.41336 .78279 m
.4134 .78245 L
s
.41336 .78282 m
.41336 .78279 L
s
.41332 .78317 m
.41336 .78282 L
s
.31878 .57786 m
.32776 .57146 L
s
.64759 .55279 m
.65669 .56326 L
s
.49674 .87177 m .49904 .86559 L .49773 .85677 L 0 .775 .366 r
F
.49674 .87177 m .49861 .87202 L .49904 .86559 L F
.50084 .89314 m .49861 .87202 L .49674 .87177 L 0 .653 .359 r
F
0 g
.494 .86538 m
.49674 .87177 L
s
.49667 .87791 m
.49674 .87177 L
s
.51316 .94818 m .50851 .93577 L .51117 .94286 L 0 .28 .314 r
F
.51316 .94818 m .50683 .93067 L .50851 .93577 L F
.51316 .94818 m .51117 .94286 L .50851 .93577 L 0 .275 .311 r
F
0 g
.51062 .94267 m
.51227 .94625 L
s
.51227 .94625 m
.51231 .94634 L
s
.51231 .94634 m
.51233 .94637 L
s
.51305 .9474 m
.51305 .94741 L
s
.51305 .9474 m
.51305 .9474 L
s
.51087 .9319 m
.51305 .9474 L
s
.51307 .94753 m
.51308 .94757 L
s
.51307 .94753 m
.51307 .94753 L
s
.51307 .94752 m
.51307 .94753 L
s
.51087 .9319 m
.51307 .94752 L
s
.5121 .94588 m
.51212 .94591 L
s
.51205 .94578 m
.5121 .94588 L
s
.5106 .94262 m
.51205 .94578 L
s
.50623 .93034 m
.50851 .93577 L
s
.61492 .62249 m .6342 .61649 L .63026 .61511 L 0 1 .411 r
F
0 g
.6342 .61649 m
.64242 .61465 L
s
.40712 .92007 m .40009 .91663 L .39607 .91525 L 0 .332 .195 r
F
.40712 .92007 m .40475 .91874 L .40009 .91663 L F
.40712 .92007 m .40776 .92021 L .40475 .91874 L F
.41888 .92487 m .40776 .92021 L .40712 .92007 L 0 0 0 r
F
0 g
.40311 .91868 m
.40712 .92007 L
s
.57532 .64605 m
.57769 .64459 L
s
.571 .64871 m
.57405 .64683 L
s
.57405 .64683 m
.57412 .64679 L
s
.52238 .70694 m .51822 .70105 L .51806 .70587 L 0 1 .436 r
F
.52238 .70694 m .52313 .69494 L .51822 .70105 L F
.52238 .70694 m .52952 .69161 L .52313 .69494 L F
.50464 .85073 m .50134 .83432 L .50217 .84347 L 0 .855 .352 r
F
.49856 .85021 m .50217 .84347 L .50134 .83432 L 0 .873 .363 r
F
0 g
.49854 .82792 m
.50134 .83432 L
s
.50134 .83432 m
.50137 .8342 L
s
.50869 .97026 m .50422 .98505 L .50613 .98267 L 0 .276 .263 r
F
0 g
.50366 .99059 m
.50422 .98505 L
s
.24703 .87863 m .23676 .87206 L .23542 .87659 L 0 1 .518 r
F
.24703 .87863 m .24124 .86941 L .23676 .87206 L F
.24703 .87863 m .24586 .87041 L .24124 .86941 L F
.24703 .87863 m .24834 .87437 L .24586 .87041 L F
0 g
.24256 .88126 m
.24703 .87863 L
s
.24703 .87863 m
.24954 .88238 L
s
.76181 1.06111 m .7721 1.05245 L .76775 1.05609 L 0 .867 .181 r
F
.75105 1.07082 m .76181 1.06111 L .76123 1.06192 L 0 0 0 r
F
.47744 .94471 m .46929 .94451 L .46566 .94224 L 0 .283 .068 r
F
.47744 .94471 m .47403 .94609 L .46929 .94451 L F
.47744 .94471 m .47753 .94618 L .47403 .94609 L F
.48934 .94783 m .47753 .94618 L .47744 .94471 L 0 .313 .088 r
F
0 g
.47744 .94471 m
.48096 .94459 L
s
.47381 .94244 m
.47744 .94471 L
s
.51316 .94818 m .52029 .96389 L .52069 .96433 L 0 .266 .304 r
F
0 g
.52029 .96389 m
.52205 .96716 L
s
.51795 .95895 m
.52029 .96389 L
s
.50683 .93067 m .5059 .92542 L .50367 .91777 L 0 .388 .349 r
F
.50683 .93067 m .50726 .93095 L .5059 .92542 L F
.51316 .94818 m .50726 .93095 L .50683 .93067 L 0 .28 .314 r
F
0 g
.50683 .93067 m
.50851 .93577 L
s
.50679 .93056 m
.50683 .93067 L
s
.50986 .94601 m
.51291 .94801 L
s
.51291 .94801 m
.51291 .94801 L
s
.51291 .94801 m
.51292 .94802 L
s
.51308 .94776 m
.51308 .94776 L
s
.51308 .94775 m
.51308 .94776 L
s
.51029 .93309 m
.51308 .94775 L
s
.51311 .94772 m
.51311 .94772 L
s
.51311 .94772 m
.51311 .94772 L
s
.51117 .93162 m
.51311 .94772 L
s
.5106 .93233 m
.51309 .9477 L
s
.51309 .9477 m
.51309 .9477 L
s
.51309 .9477 m
.51309 .9477 L
s
.51305 .94741 m
.51309 .94763 L
s
.51029 .93309 m
.51308 .94772 L
s
.51308 .94772 m
.51308 .94772 L
s
.51308 .94772 m
.51308 .94772 L
s
.51311 .94765 m
.51311 .94765 L
s
.51311 .94764 m
.51311 .94765 L
s
.51149 .93152 m
.51311 .94764 L
s
.51149 .93152 m
.51311 .94766 L
s
.51311 .94766 m
.51311 .94766 L
s
.51311 .94766 m
.51311 .94767 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94812 m
.51316 .94817 L
s
.61639 .68425 m .61585 .681 L .6134 .67866 L 0 .109 .186 r
F
0 g
.61212 .67735 m
.6134 .67866 L
s
.61639 .68425 m .62283 .69032 L .61585 .681 L 0 .109 .186 r
F
0 g
.6134 .67866 m
.61608 .68366 L
s
.61639 .68425 m .62967 .70042 L .62283 .69032 L 0 .109 .186 r
F
0 g
.62441 .69668 m
.62552 .69855 L
s
.62552 .69855 m
.6259 .69926 L
s
.61639 .68425 m .63265 .70601 L .62967 .70042 L 0 .109 .186 r
F
0 g
.6259 .69926 m
.62644 .70029 L
s
.61639 .68425 m .6298 .70337 L .63265 .70601 L 0 .109 .186 r
F
0 g
.62644 .70029 m
.62716 .70164 L
s
.61639 .68425 m .62283 .69405 L .6298 .70337 L 0 .109 .186 r
F
0 g
.62283 .69405 m
.62346 .69509 L
s
.62346 .69509 m
.62441 .69668 L
s
.61136 .67684 m
.61639 .68425 L
s
.61608 .68366 m
.61639 .68425 L
s
.51316 .94818 m .51316 .94818 L .51521 .95279 L 0 .266 .304 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51319 .94823 L
s
.51319 .94823 m
.51521 .95279 L
s
.51316 .94818 m
.51316 .94818 L
s
.51318 .94822 m
.51521 .95279 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94819 L
s
.51317 .94819 m
.51319 .94826 L
s
.51319 .94826 m
.51456 .95204 L
s
.51316 .94818 m
.51317 .94819 L
s
.51318 .94823 m
.51456 .95204 L
s
.51316 .94818 m
.51377 .95018 L
s
.51316 .94818 m
.51421 .95162 L
s
.51316 .94818 m
.51374 .95105 L
s
.51316 .94818 m
.51325 .94861 L
s
.51316 .94818 m
.51337 .9506 L
s
.51316 .94818 m
.51337 .9506 L
s
.51323 .94846 m
.5135 .94965 L
s
.51316 .94818 m
.51323 .94846 L
s
.51316 .94818 m
.51385 .95119 L
s
.51317 .94819 m
.5149 .95243 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94819 m
.5149 .95243 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94818 m
.51317 .94819 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.50267 .91239 m .50112 .89885 L .49877 .89245 L 0 .534 .359 r
F
0 g
.49877 .89245 m
.49897 .89299 L
s
.49845 .88635 m
.49877 .89245 L
s
.50032 .90599 m
.50255 .91208 L
s
.51009 .82791 m
.51035 .82695 L
s
.51008 .82793 m
.51009 .82791 L
s
.51316 .94818 m .51827 .93666 L .51535 .94324 L 0 .373 .268 r
F
.51316 .94818 m .52075 .93381 L .51827 .93666 L F
.51316 .94818 m .51535 .94324 L .51827 .93666 L 0 .386 .269 r
F
0 g
.51827 .93666 m
.51828 .93666 L
s
.51827 .93666 m
.52015 .92975 L
s
.51316 .94818 m .51316 .94818 L .51117 .94286 L 0 .275 .311 r
F
0 g
.51117 .94286 m
.51306 .94791 L
s
.51306 .94791 m
.51306 .94791 L
s
.51306 .94791 m
.51306 .94791 L
s
.51306 .94791 m
.51314 .94813 L
s
.51314 .94813 m
.51314 .94813 L
s
.51314 .94813 m
.51314 .94813 L
s
.51314 .94813 m
.51315 .94815 L
s
.51315 .94815 m
.51315 .94815 L
s
.51315 .94815 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94818 m
.51316 .94818 L
s
.51117 .94286 m
.51305 .94787 L
s
.51305 .94787 m
.51305 .94787 L
s
.51305 .94787 m
.51305 .94788 L
s
.51305 .94788 m
.51314 .94812 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51293 .94768 m
.51293 .9477 L
s
.51292 .94767 m
.51293 .94768 L
s
.51052 .94261 m
.51292 .94767 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51283 .94754 m
.51284 .94755 L
s
.51283 .94753 m
.51283 .94754 L
s
.51028 .9426 m
.51283 .94753 L
s
.51293 .94772 m
.51293 .94773 L
s
.51292 .94772 m
.51293 .94772 L
s
.51028 .9426 m
.51292 .94772 L
s
.51316 .94818 m
.51316 .94818 L
s
.51314 .94774 m
.51314 .94774 L
s
.51314 .94774 m
.51314 .94774 L
s
.51218 .93185 m
.51314 .94774 L
s
.51316 .94808 m
.51316 .94812 L
s
.51316 .94807 m
.51316 .94807 L
s
.51316 .94807 m
.51316 .94807 L
s
.51316 .94807 m
.51316 .94811 L
s
.51316 .94815 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94808 m
.51316 .94808 L
s
.51316 .94808 m
.51316 .94808 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94813 m
.51316 .94813 L
s
.51316 .94813 m
.51316 .94814 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51052 .94261 m
.51277 .94735 L
s
.51277 .94735 m
.51277 .94736 L
s
.51277 .94736 m
.51279 .94739 L
s
.51316 .94814 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51234 .94808 m
.51237 .94808 L
s
.51231 .94808 m
.51234 .94808 L
s
.50959 .94775 m
.51231 .94808 L
s
.5122 .94806 m
.51222 .94807 L
s
.51216 .94806 m
.5122 .94806 L
s
.50959 .94775 m
.51216 .94806 L
s
.51212 .94591 m
.51307 .94799 L
s
.51307 .94799 m
.51308 .94799 L
s
.51308 .94799 m
.51308 .94799 L
s
.51313 .9481 m
.51313 .94811 L
s
.51313 .9481 m
.51313 .9481 L
s
.51313 .9481 m
.51313 .9481 L
s
.51308 .94799 m
.51313 .9481 L
s
.51279 .94739 m
.51309 .94802 L
s
.51309 .94802 m
.51309 .94802 L
s
.51309 .94802 m
.51309 .94802 L
s
.51311 .94807 m
.51314 .94812 L
s
.51311 .94807 m
.51311 .94807 L
s
.51311 .94807 m
.51311 .94807 L
s
.51309 .94802 m
.51311 .94807 L
s
.51314 .94812 m
.51314 .94812 L
s
.51314 .94812 m
.51314 .94812 L
s
.51315 .94815 m
.51315 .94815 L
s
.51314 .94814 m
.51315 .94815 L
s
.51314 .94814 m
.51314 .94814 L
s
.51314 .94812 m
.51314 .94814 L
s
.51315 .94815 m
.51315 .94815 L
s
.51315 .94815 m
.51315 .94815 L
s
.51315 .94815 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.5131 .94816 m
.5131 .94816 L
s
.5131 .94816 m
.5131 .94816 L
s
.51308 .94816 m
.51308 .94816 L
s
.51289 .9481 m
.51308 .94816 L
s
.51308 .94816 m
.5131 .94816 L
s
.51289 .9481 m
.51289 .9481 L
s
.51289 .9481 m
.51289 .9481 L
s
.50964 .94715 m
.51289 .9481 L
s
.51311 .94816 m
.51311 .94816 L
s
.51309 .94816 m
.51311 .94816 L
s
.51309 .94816 m
.51309 .94816 L
s
.51309 .94816 m
.51309 .94816 L
s
.51279 .94807 m
.51309 .94816 L
s
.51279 .94807 m
.51279 .94807 L
s
.51278 .94807 m
.51279 .94807 L
s
.50964 .94715 m
.51278 .94807 L
s
.51008 .94265 m
.51307 .94801 L
s
.5131 .94807 m
.5131 .94807 L
s
.51307 .94801 m
.5131 .94807 L
s
.5131 .94807 m
.51313 .94813 L
s
.5131 .94807 m
.5131 .94807 L
s
.51313 .94813 m
.51313 .94813 L
s
.51313 .94813 m
.51313 .94813 L
s
.51314 .94814 m
.51315 .94815 L
s
.51314 .94814 m
.51314 .94814 L
s
.51313 .94813 m
.51314 .94814 L
s
.51315 .94815 m
.51315 .94815 L
s
.51315 .94815 m
.51315 .94815 L
s
.51315 .94815 m
.51315 .94816 L
s
.51315 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94818 m
.51316 .94818 L
s
.51008 .94265 m
.51306 .948 L
s
.51311 .94809 m
.51311 .94809 L
s
.51306 .948 m
.51311 .94809 L
s
.51311 .94809 m
.51312 .94811 L
s
.51311 .94809 m
.51311 .94809 L
s
.51312 .94811 m
.51312 .94811 L
s
.51312 .94811 m
.51312 .94811 L
s
.51314 .94815 m
.51315 .94815 L
s
.51314 .94815 m
.51314 .94815 L
s
.51312 .94811 m
.51314 .94815 L
s
.51313 .94816 m
.51313 .94816 L
s
.51313 .94816 m
.51313 .94816 L
s
.51311 .94815 m
.51313 .94816 L
s
.51311 .94815 m
.51311 .94815 L
s
.51308 .94814 m
.51311 .94815 L
s
.51308 .94814 m
.51308 .94814 L
s
.51308 .94814 m
.51308 .94814 L
s
.50973 .94657 m
.51295 .94808 L
s
.51295 .94808 m
.51296 .94808 L
s
.51296 .94808 m
.51296 .94808 L
s
.51296 .94808 m
.51308 .94814 L
s
.51313 .94816 m
.51313 .94816 L
s
.51313 .94816 m
.51313 .94816 L
s
.51312 .94816 m
.51313 .94816 L
s
.51312 .94816 m
.51312 .94816 L
s
.51305 .94813 m
.51312 .94816 L
s
.51305 .94813 m
.51305 .94813 L
s
.51305 .94813 m
.51305 .94813 L
s
.50973 .94657 m
.51303 .94812 L
s
.51303 .94812 m
.51303 .94812 L
s
.51303 .94812 m
.51303 .94812 L
s
.51303 .94812 m
.51305 .94813 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51313 .94815 m
.51314 .94816 L
s
.51313 .94815 m
.51313 .94815 L
s
.51311 .94813 m
.51313 .94815 L
s
.51309 .94812 m
.51311 .94813 L
s
.51309 .94812 m
.51309 .94812 L
s
.51309 .94812 m
.51309 .94812 L
s
.51079 .94613 m
.51309 .94812 L
s
.51309 .94812 m
.5131 .94812 L
s
.51309 .94812 m
.51309 .94812 L
s
.51229 .94743 m
.51309 .94812 L
s
.5131 .94812 m
.5131 .94812 L
s
.5131 .94812 m
.5131 .94812 L
s
.51313 .94815 m
.51314 .94816 L
s
.5131 .94812 m
.51313 .94815 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51315 .94816 L
s
.51313 .94815 m
.51313 .94815 L
s
.51313 .94815 m
.51313 .94815 L
s
.51313 .94815 m
.51313 .94815 L
s
.51084 .94617 m
.51307 .94809 L
s
.51307 .94809 m
.51307 .94809 L
s
.51307 .94809 m
.51307 .94809 L
s
.51307 .94809 m
.5131 .94813 L
s
.5131 .94813 m
.5131 .94813 L
s
.5131 .94813 m
.5131 .94813 L
s
.51311 .94814 m
.51311 .94814 L
s
.51311 .94814 m
.51311 .94814 L
s
.5131 .94813 m
.51311 .94814 L
s
.51311 .94814 m
.51311 .94814 L
s
.51311 .94814 m
.51312 .94814 L
s
.51312 .94814 m
.51312 .94814 L
s
.51312 .94814 m
.51312 .94814 L
s
.51312 .94814 m
.51312 .94814 L
s
.51312 .94814 m
.51313 .94815 L
s
.51313 .94815 m
.51313 .94815 L
s
.51313 .94815 m
.51313 .94815 L
s
.51314 .94816 m
.51314 .94816 L
s
.51313 .94815 m
.51313 .94815 L
s
.51313 .94815 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.5131 .94806 m
.51311 .94808 L
s
.51304 .94794 m
.51305 .94797 L
s
.51315 .94816 m
.51315 .94816 L
s
.51291 .93297 m
.51316 .94795 L
s
.51316 .94795 m
.51316 .94795 L
s
.51316 .94795 m
.51316 .94795 L
s
.51316 .94795 m
.51316 .94808 L
s
.51291 .93297 m
.51316 .94793 L
s
.51316 .94793 m
.51316 .94793 L
s
.51316 .94793 m
.51316 .94793 L
s
.51316 .94793 m
.51316 .94807 L
s
.50961 .93772 m
.51314 .94813 L
s
.50961 .93772 m
.51315 .94815 L
s
.51218 .93185 m
.51314 .9478 L
s
.51314 .9478 m
.51314 .9478 L
s
.51314 .9478 m
.51314 .9478 L
s
.51316 .94805 m
.51316 .94805 L
s
.51316 .94805 m
.51316 .94805 L
s
.51316 .94805 m
.51316 .94805 L
s
.51314 .9478 m
.51316 .94805 L
s
.51316 .94805 m
.51316 .94805 L
s
.51316 .94805 m
.51316 .94805 L
s
.51316 .94805 m
.51316 .9481 L
s
.51316 .9481 m
.51316 .9481 L
s
.51316 .9481 m
.51316 .9481 L
s
.51316 .9481 m
.51316 .94812 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .94813 m
.51316 .94814 L
s
.51316 .94813 m
.51316 .94813 L
s
.51316 .94812 m
.51316 .94813 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94815 L
s
.51314 .94774 m
.51315 .94804 L
s
.51315 .94804 m
.51315 .94804 L
s
.51315 .94804 m
.51315 .94804 L
s
.51315 .94804 m
.51316 .94809 L
s
.51316 .94809 m
.51316 .94809 L
s
.51316 .94809 m
.51316 .94809 L
s
.51316 .9481 m
.51316 .94812 L
s
.51316 .9481 m
.51316 .9481 L
s
.51316 .9481 m
.51316 .9481 L
s
.51316 .94809 m
.51316 .9481 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94812 m
.51316 .94814 L
s
.51293 .9453 m
.51314 .94787 L
s
.51314 .94787 m
.51314 .94787 L
s
.51314 .94787 m
.51314 .94787 L
s
.51315 .94796 m
.51315 .94806 L
s
.51315 .94796 m
.51315 .94796 L
s
.51315 .94796 m
.51315 .94796 L
s
.51314 .94787 m
.51315 .94796 L
s
.51315 .94806 m
.51315 .94806 L
s
.51315 .94806 m
.51315 .94806 L
s
.51316 .9481 m
.51316 .9481 L
s
.51316 .9481 m
.51316 .9481 L
s
.51316 .9481 m
.51316 .9481 L
s
.51315 .94806 m
.51316 .9481 L
s
.51316 .9481 m
.51316 .9481 L
s
.51316 .9481 m
.51316 .9481 L
s
.51316 .9481 m
.51316 .94812 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94812 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94816 L
s
.51286 .94437 m
.51313 .9478 L
s
.51313 .9478 m
.51313 .9478 L
s
.51313 .9478 m
.51313 .9478 L
s
.51313 .9478 m
.51315 .94804 L
s
.51315 .94804 m
.51315 .94804 L
s
.51315 .94804 m
.51315 .94804 L
s
.51315 .94804 m
.51316 .94809 L
s
.51315 .94804 m
.51315 .94804 L
s
.51315 .94804 m
.51315 .94804 L
s
.51315 .94804 m
.51315 .94804 L
s
.51316 .94809 m
.51316 .94809 L
s
.51316 .94809 m
.51316 .94809 L
s
.51316 .94811 m
.51316 .94811 L
s
.51316 .94811 m
.51316 .94811 L
s
.51316 .94811 m
.51316 .94811 L
s
.51316 .94809 m
.51316 .94811 L
s
.51316 .94811 m
.51316 .94811 L
s
.51316 .94811 m
.51316 .94811 L
s
.51316 .94811 m
.51316 .94814 L
s
.51315 .94814 m
.51316 .94814 L
s
.51315 .94814 m
.51315 .94814 L
s
.51314 .94807 m
.51315 .94814 L
s
.51314 .94807 m
.51314 .94807 L
s
.51314 .94807 m
.51314 .94807 L
s
.51008 .93382 m
.51314 .94807 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51314 .94808 m
.51315 .94813 L
s
.51314 .94808 m
.51314 .94808 L
s
.51314 .94808 m
.51314 .94808 L
s
.51008 .93382 m
.51314 .94808 L
s
.51315 .94813 m
.51315 .94813 L
s
.51315 .94813 m
.51315 .94813 L
s
.51315 .94814 m
.51315 .94814 L
s
.51315 .94814 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51315 .94814 m
.51315 .94814 L
s
.51315 .94813 m
.51315 .94814 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51311 .94772 m
.51314 .94798 L
s
.51314 .94798 m
.51314 .94798 L
s
.51314 .94798 m
.51314 .94798 L
s
.51315 .94804 m
.51315 .94808 L
s
.51315 .94804 m
.51315 .94804 L
s
.51315 .94804 m
.51315 .94804 L
s
.51314 .94798 m
.51314 .948 L
s
.51314 .948 m
.51315 .94804 L
s
.51315 .94808 m
.51315 .94808 L
s
.51315 .94808 m
.51315 .94808 L
s
.51315 .94808 m
.51315 .9481 L
s
.51315 .9481 m
.51315 .9481 L
s
.51315 .9481 m
.51315 .9481 L
s
.51316 .94811 m
.51316 .94812 L
s
.51316 .94812 m
.51316 .94813 L
s
.51316 .94813 m
.51316 .94813 L
s
.51316 .94811 m
.51316 .94811 L
s
.51316 .94811 m
.51316 .94811 L
s
.51315 .9481 m
.51316 .94811 L
s
.51316 .94813 m
.51316 .94813 L
s
.51316 .94813 m
.51316 .94813 L
s
.51316 .94814 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94813 m
.51316 .94814 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51312 .94783 m
.51313 .94789 L
s
.51312 .94782 m
.51312 .94783 L
s
.51312 .94782 m
.51312 .94782 L
s
.51117 .93162 m
.51312 .94782 L
s
.51313 .94789 m
.51313 .94789 L
s
.51313 .94789 m
.51313 .94789 L
s
.51313 .94789 m
.51314 .94798 L
s
.51314 .94798 m
.51315 .94805 L
s
.51315 .94805 m
.51315 .94805 L
s
.51315 .94805 m
.51315 .94805 L
s
.51315 .94806 m
.51315 .94809 L
s
.51315 .94806 m
.51315 .94806 L
s
.51315 .94806 m
.51315 .94806 L
s
.51315 .94805 m
.51315 .94806 L
s
.51315 .94809 m
.51315 .94809 L
s
.51315 .94809 m
.51315 .94809 L
s
.51316 .94812 m
.51316 .94813 L
s
.51316 .94813 m
.51316 .94813 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .94812 m
.51316 .94812 L
s
.51315 .94809 m
.51316 .94812 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .94813 m
.51316 .94813 L
s
.51316 .94813 m
.51316 .94813 L
s
.51316 .94814 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94813 m
.51316 .94814 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.5106 .93233 m
.51311 .94784 L
s
.51311 .94784 m
.51311 .94784 L
s
.51311 .94784 m
.51311 .94784 L
s
.51314 .94801 m
.51315 .9481 L
s
.51314 .94801 m
.51314 .94801 L
s
.51314 .94801 m
.51314 .94801 L
s
.51311 .94784 m
.51314 .94801 L
s
.51315 .9481 m
.51315 .9481 L
s
.51315 .9481 m
.51315 .9481 L
s
.51315 .94811 m
.51315 .94813 L
s
.51315 .94813 m
.51316 .94814 L
s
.51315 .94811 m
.51315 .94811 L
s
.51315 .94811 m
.51315 .94811 L
s
.51315 .9481 m
.51315 .94811 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51314 .94802 m
.51315 .94808 L
s
.51314 .94802 m
.51314 .94802 L
s
.51314 .94802 m
.51314 .94802 L
s
.51309 .9477 m
.51312 .94793 L
s
.51312 .94793 m
.51314 .94802 L
s
.51315 .94808 m
.51315 .94808 L
s
.51315 .94808 m
.51315 .94808 L
s
.51315 .94812 m
.51315 .94812 L
s
.51315 .94812 m
.51316 .94813 L
s
.51315 .94812 m
.51315 .94812 L
s
.51315 .94812 m
.51315 .94812 L
s
.51315 .94808 m
.51315 .94812 L
s
.51316 .94813 m
.51316 .94813 L
s
.51316 .94813 m
.51316 .94813 L
s
.51316 .94814 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94813 m
.51316 .94814 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94815 m
.51316 .94816 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51315 .94812 m
.51315 .94812 L
s
.51315 .94812 m
.51315 .94812 L
s
.51315 .94812 m
.51315 .94812 L
s
.51315 .94812 m
.51316 .94814 L
s
.51315 .94812 m
.51315 .94812 L
s
.51315 .94812 m
.51315 .94812 L
s
.51314 .94804 m
.51315 .94805 L
s
.51315 .94805 m
.51315 .94805 L
s
.51315 .94805 m
.51315 .94805 L
s
.51315 .94811 m
.51315 .94812 L
s
.51315 .94805 m
.51315 .94811 L
s
.51314 .94804 m
.51314 .94804 L
s
.51314 .94804 m
.51314 .94804 L
s
.51313 .94794 m
.51314 .94804 L
s
.51313 .94794 m
.51313 .94794 L
s
.51313 .94794 m
.51313 .94794 L
s
.51308 .94757 m
.51313 .94794 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94815 m
.51316 .94816 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94813 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94815 L
s
.51316 .94813 m
.51316 .94813 L
s
.51316 .94813 m
.51316 .94813 L
s
.51315 .94808 m
.51315 .94811 L
s
.51315 .94811 m
.51315 .94811 L
s
.51315 .94811 m
.51315 .94811 L
s
.51315 .94812 m
.51316 .94813 L
s
.51315 .94811 m
.51315 .94812 L
s
.51315 .94808 m
.51315 .94808 L
s
.51315 .94808 m
.51315 .94808 L
s
.51314 .94803 m
.51314 .94803 L
s
.51314 .94803 m
.51314 .94803 L
s
.51314 .94803 m
.51314 .94803 L
s
.51314 .94803 m
.51315 .94808 L
s
.51314 .94803 m
.51314 .94803 L
s
.51314 .94803 m
.51314 .94803 L
s
.51309 .94763 m
.51314 .94803 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94815 m
.51316 .94816 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94813 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94815 L
s
.51316 .94813 m
.51316 .94813 L
s
.51316 .94813 m
.51316 .94813 L
s
.51315 .94809 m
.51315 .94811 L
s
.51315 .94808 m
.51315 .94809 L
s
.51315 .94807 m
.51315 .94808 L
s
.51315 .94811 m
.51315 .94811 L
s
.51315 .94811 m
.51315 .94811 L
s
.51315 .94811 m
.51316 .94813 L
s
.51315 .94807 m
.51315 .94807 L
s
.51315 .94807 m
.51315 .94807 L
s
.51052 .93249 m
.51313 .94799 L
s
.51313 .94799 m
.51313 .94799 L
s
.51313 .94799 m
.51313 .94799 L
s
.51313 .94799 m
.51315 .94807 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94815 m
.51316 .94816 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51315 .9481 m
.51315 .94811 L
s
.51315 .94809 m
.51315 .9481 L
s
.51315 .94811 m
.51315 .94811 L
s
.51315 .94811 m
.51315 .94811 L
s
.51315 .94811 m
.51316 .94814 L
s
.51315 .94809 m
.51315 .94809 L
s
.51315 .94809 m
.51315 .94809 L
s
.51052 .93249 m
.51313 .94798 L
s
.51313 .94798 m
.51313 .94798 L
s
.51313 .94798 m
.51313 .94798 L
s
.51313 .94798 m
.51315 .94809 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94814 m
.51316 .94816 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51315 .9481 m
.51315 .9481 L
s
.51315 .9481 m
.51315 .9481 L
s
.51315 .9481 m
.51315 .9481 L
s
.51316 .94814 m
.51316 .94814 L
s
.51315 .9481 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51315 .9481 m
.51315 .9481 L
s
.51315 .9481 m
.51315 .9481 L
s
.51308 .94776 m
.51315 .9481 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94815 m
.51316 .94816 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51315 .94812 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94814 L
s
.51315 .94812 m
.51315 .94812 L
s
.51315 .94812 m
.51315 .94812 L
s
.51308 .94772 m
.51315 .9481 L
s
.51315 .9481 m
.51315 .9481 L
s
.51315 .9481 m
.51315 .9481 L
s
.51315 .9481 m
.51315 .94812 L
s
.51316 .94811 m
.51316 .94812 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .94812 m
.51316 .94813 L
s
.51316 .94811 m
.51316 .94811 L
s
.51316 .94811 m
.51316 .94811 L
s
.51315 .94808 m
.51316 .94811 L
s
.51315 .94808 m
.51315 .94808 L
s
.51315 .94808 m
.51315 .94808 L
s
.51315 .94801 m
.51315 .94806 L
s
.51315 .94806 m
.51315 .94806 L
s
.51315 .94806 m
.51315 .94806 L
s
.51315 .94806 m
.51315 .94808 L
s
.51315 .94801 m
.51315 .94801 L
s
.51315 .948 m
.51315 .94801 L
s
.51311 .94765 m
.51313 .94785 L
s
.51313 .94785 m
.51313 .94785 L
s
.51313 .94785 m
.51313 .94785 L
s
.51313 .94785 m
.51315 .948 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94815 m
.51316 .94816 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94815 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94815 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94814 m
.51316 .94814 L
s
.51316 .94812 m
.51316 .94814 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .94812 m
.51316 .94812 L
s
.51315 .94809 m
.51316 .94811 L
s
.51316 .94811 m
.51316 .94811 L
s
.51316 .94811 m
.51316 .94811 L
s
.51316 .94811 m
.51316 .94812 L
s
.51315 .94809 m
.51315 .94809 L
s
.51315 .94809 m
.51315 .94809 L
s
.51315 .94804 m
.51315 .94809 L
s
.51315 .94804 m
.51315 .94804 L
s
.51315 .94804 m
.51315 .94804 L
s
.51312 .9478 m
.51315 .94803 L
s
.51315 .94803 m
.51315 .94803 L
s
.51315 .94803 m
.51315 .94803 L
s
.51315 .94803 m
.51315 .94804 L
s
.51312 .9478 m
.51312 .9478 L
s
.51312 .9478 m
.51312 .9478 L
s
.51311 .94767 m
.51312 .9478 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94815 m
.51316 .94816 L
s
.51316 .94815 m
.51316 .94815 L
s
.50991 .93466 m
.51312 .94798 L
s
.51312 .94798 m
.51312 .94798 L
s
.51312 .94798 m
.51312 .94798 L
s
.51315 .94813 m
.51315 .94813 L
s
.51312 .94798 m
.51315 .94813 L
s
.51315 .94813 m
.51315 .94813 L
s
.51315 .94813 m
.51316 .94815 L
s
.50991 .93466 m
.51311 .94797 L
s
.51311 .94797 m
.51311 .94797 L
s
.51311 .94797 m
.51311 .94797 L
s
.51311 .94797 m
.51315 .94813 L
s
.51315 .94813 m
.51315 .94813 L
s
.51315 .94814 m
.51316 .94816 L
s
.51315 .94813 m
.51315 .94814 L
s
.51315 .94811 m
.51315 .94812 L
s
.50978 .93559 m
.51315 .94811 L
s
.51315 .94812 m
.51315 .94812 L
s
.51315 .94812 m
.51316 .94816 L
s
.50978 .93559 m
.51315 .94811 L
s
.51315 .94811 m
.51315 .94811 L
s
.51315 .94811 m
.51315 .94815 L
s
.50968 .93662 m
.51313 .94807 L
s
.51313 .94807 m
.51313 .94807 L
s
.50968 .93662 m
.51313 .94807 L
s
.51313 .94807 m
.51313 .94807 L
s
.51316 .94812 m
.51316 .94813 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .94809 m
.51316 .94812 L
s
.51316 .94809 m
.51316 .94809 L
s
.51316 .94809 m
.51316 .94809 L
s
.51316 .94802 m
.51316 .94809 L
s
.51316 .94802 m
.51316 .94802 L
s
.51316 .94802 m
.51316 .94802 L
s
.5131 .94668 m
.51316 .94802 L
s
.51316 .94812 m
.51316 .94814 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .94812 m
.51316 .94812 L
s
.51316 .9481 m
.51316 .9481 L
s
.51316 .9481 m
.51316 .9481 L
s
.51316 .9481 m
.51316 .94812 L
s
.51316 .9481 m
.51316 .9481 L
s
.51316 .9481 m
.51316 .9481 L
s
.51316 .94803 m
.51316 .9481 L
s
.51316 .94803 m
.51316 .94803 L
s
.51316 .94803 m
.51316 .94803 L
s
.51311 .94683 m
.51316 .94803 L
s
.51314 .94813 m
.51315 .94813 L
s
.51315 .94814 m
.51315 .94815 L
s
.51315 .94816 m
.51315 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.50986 .94504 m
.51314 .94816 L
s
.50973 .94465 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.50973 .94465 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51314 .94816 m
.51314 .94816 L
s
.51297 .94805 m
.51297 .94805 L
s
.51297 .94805 m
.5131 .94814 L
s
.51297 .94805 m
.51297 .94805 L
s
.50986 .94601 m
.51297 .94805 L
s
.5131 .94814 m
.5131 .94814 L
s
.5131 .94814 m
.5131 .94814 L
s
.51312 .94815 m
.51314 .94816 L
s
.51312 .94815 m
.51312 .94815 L
s
.5131 .94814 m
.51312 .94815 L
s
.51311 .94815 m
.51312 .94815 L
s
.51311 .94815 m
.51311 .94815 L
s
.51292 .94802 m
.51311 .94815 L
s
.51312 .94815 m
.51312 .94815 L
s
.51312 .94815 m
.51312 .94815 L
s
.5131 .94809 m
.51313 .94813 L
s
.5131 .94809 m
.5131 .94809 L
s
.50967 .9431 m
.5131 .94809 L
s
.51315 .94816 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.51313 .94814 m
.51315 .94816 L
s
.5131 .94809 m
.51313 .94814 L
s
.5131 .94809 m
.5131 .94809 L
s
.50967 .9431 m
.5131 .94809 L
s
.51313 .94813 m
.51314 .94814 L
s
.51313 .94813 m
.51313 .94813 L
s
.50977 .94291 m
.51313 .94813 L
s
.51315 .94815 m
.51315 .94816 L
s
.51315 .94815 m
.51315 .94815 L
s
.51315 .94815 m
.51315 .94815 L
s
.51313 .94813 m
.51315 .94815 L
s
.51313 .94813 m
.51313 .94813 L
s
.50977 .94291 m
.51313 .94813 L
s
.5131 .94807 m
.51313 .94813 L
s
.51306 .94801 m
.51306 .94801 L
s
.50991 .94275 m
.51306 .94801 L
s
.51306 .94801 m
.5131 .94807 L
s
.51306 .94801 m
.51306 .94801 L
s
.51315 .94816 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.51314 .94814 m
.51315 .94816 L
s
.51314 .94814 m
.51314 .94814 L
s
.51314 .94814 m
.51314 .94814 L
s
.51314 .94814 m
.51314 .94814 L
s
.51314 .94814 m
.51314 .94814 L
s
.51311 .94809 m
.51314 .94814 L
s
.51305 .94799 m
.51305 .94799 L
s
.50991 .94275 m
.51305 .94799 L
s
.51305 .94799 m
.51311 .94809 L
s
.51305 .94799 m
.51305 .94799 L
s
.5131 .94807 m
.51312 .9481 L
s
.51312 .9481 m
.51312 .9481 L
s
.51313 .94811 m
.51314 .94813 L
s
.51312 .9481 m
.51313 .94811 L
s
.5131 .94807 m
.5131 .94807 L
s
.5131 .94807 m
.5131 .94807 L
s
.51293 .94773 m
.5131 .94807 L
s
.51315 .94816 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.51315 .94815 m
.51315 .94816 L
s
.51314 .94814 m
.51315 .94815 L
s
.51314 .94814 m
.51314 .94814 L
s
.51314 .94814 m
.51314 .94814 L
s
.51314 .94814 m
.51314 .94814 L
s
.51314 .94814 m
.51314 .94814 L
s
.51314 .94813 m
.51314 .94814 L
s
.51312 .9481 m
.51314 .94813 L
s
.51312 .9481 m
.51312 .9481 L
s
.51312 .9481 m
.51312 .9481 L
s
.51284 .94755 m
.51312 .94809 L
s
.51312 .94809 m
.51312 .94809 L
s
.51312 .94809 m
.51312 .9481 L
s
.51312 .94809 m
.51312 .94809 L
s
.51316 .94818 m
.51316 .94818 L
s
.51293 .9477 m
.51307 .94798 L
s
.51316 .94818 m
.51316 .94818 L
s
.51315 .94816 m
.51316 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.51315 .94815 m
.51315 .94816 L
s
.51315 .94815 m
.51315 .94815 L
s
.51315 .94815 m
.51315 .94815 L
s
.51314 .94814 m
.51315 .94815 L
s
.51314 .94814 m
.51314 .94814 L
s
.51314 .94812 m
.51314 .94814 L
s
.51314 .94812 m
.51314 .94812 L
s
.51314 .94812 m
.51314 .94812 L
s
.51309 .94802 m
.51311 .94807 L
s
.51311 .94807 m
.51311 .94807 L
s
.51311 .94807 m
.51311 .94807 L
s
.51311 .94807 m
.51314 .94812 L
s
.51309 .94802 m
.51309 .94802 L
s
.51309 .94802 m
.51309 .94802 L
s
.51233 .94637 m
.51309 .94802 L
s
.51309 .94801 m
.51314 .94812 L
s
.51309 .94801 m
.51309 .94801 L
s
.51309 .94801 m
.51309 .94801 L
s
.51087 .94271 m
.51309 .94801 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51315 .94815 m
.51316 .94816 L
s
.51315 .94815 m
.51315 .94815 L
s
.51315 .94815 m
.51315 .94815 L
s
.51314 .94813 m
.51315 .94815 L
s
.51314 .94813 m
.51314 .94813 L
s
.51314 .94813 m
.51314 .94813 L
s
.51314 .94812 m
.51314 .94813 L
s
.51314 .94812 m
.51314 .94812 L
s
.5131 .94804 m
.51314 .94812 L
s
.5131 .94804 m
.5131 .94804 L
s
.5131 .94804 m
.5131 .94804 L
s
.51087 .94271 m
.5131 .94804 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m .50758 .96573 L .50948 .96143 L 0 .302 .261 r
F
0 g
.50632 .97084 m
.50758 .96573 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50481 .94859 L .50124 .94816 L 0 .345 .119 r
F
0 g
.51126 .95248 m
.51316 .94818 L
s
.51315 .9482 m
.51316 .94818 L
s
.51315 .9482 m
.51315 .9482 L
s
.51315 .9482 m
.51315 .9482 L
s
.51096 .95109 m
.51315 .9482 L
s
.51314 .94821 m
.51316 .94818 L
s
.51314 .94821 m
.51314 .94821 L
s
.51314 .94821 m
.51314 .94821 L
s
.51096 .95109 m
.51314 .94821 L
s
.51315 .94819 m
.51315 .94819 L
s
.51315 .94819 m
.51315 .94819 L
s
.51313 .9482 m
.51315 .94819 L
s
.51315 .94819 m
.51316 .94818 L
s
.51313 .9482 m
.51313 .9482 L
s
.51313 .9482 m
.51313 .9482 L
s
.51068 .94968 m
.51313 .9482 L
s
.51315 .94819 m
.51315 .94819 L
s
.51315 .94819 m
.51315 .94819 L
s
.51312 .9482 m
.51315 .94819 L
s
.51315 .94819 m
.51316 .94818 L
s
.51312 .9482 m
.51312 .9482 L
s
.51312 .9482 m
.51312 .9482 L
s
.51068 .94968 m
.51312 .9482 L
s
.513 .95013 m
.51316 .94818 L
s
.513 .95013 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51315 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51315 .94816 m
.51315 .94816 L
s
.51315 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94818 L
s
.51315 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51315 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51315 .94817 m
.51316 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51314 .94817 m
.51315 .94817 L
s
.51314 .94817 m
.51314 .94817 L
s
.51314 .94817 m
.51314 .94817 L
s
.51314 .94817 m
.51314 .94817 L
s
.51312 .94815 m
.51314 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51314 .94816 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51315 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.5096 .94393 m
.51316 .94818 L
s
.5096 .94393 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51314 .94816 m
.51316 .94817 L
s
.51315 .94816 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51315 .94817 m
.51316 .94817 L
s
.50986 .94504 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51316 .94817 m
.51316 .94818 L
s
.51315 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51314 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94818 L
s
.51315 .94816 m
.51315 .94816 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51313 .94807 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51313 .94807 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51315 .94815 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94815 m
.51316 .94817 L
s
.51311 .94782 m
.51316 .94817 L
s
.51316 .94813 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51315 .94815 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51314 .94813 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51315 .94816 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94816 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94816 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51315 .94817 m
.51316 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94816 m
.51315 .94817 L
s
.51314 .94816 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94816 L
s
.51315 .94816 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.50965 .94428 m
.51316 .94818 L
s
.50965 .94428 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51314 .94817 m
.51315 .94817 L
s
.51314 .94817 m
.51314 .94817 L
s
.51314 .94817 m
.51314 .94817 L
s
.51314 .94817 m
.51314 .94817 L
s
.51314 .94817 m
.51314 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.50958 .94362 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.50958 .94362 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.50961 .94334 m
.51315 .94816 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.50961 .94334 m
.51316 .94817 L
s
.51313 .94816 m
.51314 .94817 L
s
.51314 .94817 m
.51314 .94817 L
s
.51314 .94817 m
.51314 .94817 L
s
.51314 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51313 .94816 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51311 .94816 m
.51313 .94817 L
s
.51311 .94816 m
.51311 .94816 L
s
.51313 .94817 m
.51313 .94817 L
s
.51313 .94817 m
.51313 .94817 L
s
.51313 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94818 L
s
.5131 .94816 m
.51314 .94817 L
s
.51314 .94817 m
.51314 .94817 L
s
.51314 .94817 m
.51314 .94817 L
s
.51314 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94817 L
s
.51315 .94817 m
.51315 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51315 .94816 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51222 .94807 m
.51309 .94817 L
s
.51309 .94817 m
.51309 .94817 L
s
.51309 .94817 m
.51309 .94817 L
s
.51309 .94817 m
.51313 .94818 L
s
.51313 .94818 m
.51313 .94818 L
s
.51313 .94818 m
.51313 .94818 L
s
.51313 .94818 m
.51315 .94818 L
s
.51237 .94808 m
.5131 .94817 L
s
.5131 .94817 m
.5131 .94817 L
s
.5131 .94817 m
.5131 .94817 L
s
.5131 .94817 m
.51314 .94818 L
s
.51314 .94818 m
.51314 .94818 L
s
.51314 .94818 m
.51314 .94818 L
s
.51314 .94818 m
.51315 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51315 .94818 m
.51316 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51315 .94818 m
.51316 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51315 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51315 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51314 .94818 m
.51316 .94818 L
s
.51315 .94818 m
.51316 .94818 L
s
.49856 .85021 m .50097 .85029 L .50217 .84347 L 0 .873 .363 r
F
.50147 .87268 m .49856 .85021 L .49773 .85677 L 0 .756 .356 r
F
.50147 .87268 m .50097 .85029 L .49856 .85021 L F
0 g
.49576 .84381 m
.49856 .85021 L
s
.50147 .87268 m .49773 .85677 L .49904 .86559 L 0 .756 .356 r
F
0 g
.49773 .85677 m
.49856 .85021 L
s
.49498 .85038 m
.49773 .85677 L
s
.48687 .77271 m .49123 .77034 L .49387 .76375 L 0 1 .407 r
F
0 g
.49123 .77034 m
.49512 .7739 L
s
.64915 .60995 m .66871 .60757 L .66451 .60583 L 0 1 .44 r
F
0 g
.66871 .60757 m
.67538 .60725 L
s
.51316 .94818 m .51316 .94818 L .51535 .94324 L 0 .386 .269 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94817 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94816 L
s
.51316 .94817 m
.51316 .94816 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51322 .9481 m
.5164 .9432 L
s
.51322 .9481 m
.51322 .9481 L
s
.51322 .94809 m
.5164 .9432 L
s
.51322 .94809 m
.51322 .94809 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.24422 .92565 m .23613 .92119 L .23261 .92173 L 0 .606 .25 r
F
.24422 .92565 m .2408 .92228 L .23613 .92119 L F
.24422 .92565 m .24427 .92419 L .2408 .92228 L F
.25587 .92782 m .24427 .92419 L .24422 .92565 L 0 .574 .241 r
F
0 g
.2407 .92618 m
.24422 .92565 L
s
.24422 .92565 m
.24768 .92731 L
s
.78881 .8146 m .80196 .80318 L .80312 .80706 L 0 0 .008 r
F
0 g
.80196 .80318 m
.80675 .80017 L
s
.50125 .94939 m .49288 .94744 L .49765 .9482 L 0 .339 .102 r
F
0 g
.50124 .94816 m
.50126 .94817 L
s
.50125 .94939 m .48934 .94783 L .49288 .94744 L 0 .339 .102 r
F
0 g
.48944 .94599 m
.49288 .94744 L
s
.49765 .9482 m
.50124 .94816 L
s
.51317 .94818 m .52149 .94694 L .51673 .94765 L 0 .293 .118 r
F
.51316 .94818 m .52149 .94694 L .52502 .94747 L 0 .298 .118 r
F
0 g
.52394 .94731 m
.52422 .94735 L
s
.52369 .94727 m
.52394 .94731 L
s
.51316 .94818 m .51673 .94765 L .52149 .94694 L 0 .298 .118 r
F
0 g
.51324 .94788 m
.51505 .94126 L
s
.51326 .94781 m
.51505 .94126 L
s
.51318 .94814 m
.51318 .94814 L
s
.51318 .94814 m
.51622 .94256 L
s
.51318 .94814 m
.51318 .94814 L
s
.51318 .94814 m
.51622 .94256 L
s
.52149 .94694 m
.52291 .94633 L
s
.52149 .94694 m
.52149 .94694 L
s
.74029 1.08188 m .74765 1.07301 L .75105 1.07082 L 0 0 0 r
F
0 g
.74196 1.07743 m
.74765 1.07301 L
s
.74765 1.07301 m
.74826 1.07217 L
s
.50791 .93144 m .50367 .91777 L .5059 .92542 L 0 .385 .346 r
F
.50791 .93144 m .50267 .91239 L .50367 .91777 L F
0 g
.50144 .91202 m
.50367 .91777 L
s
.40834 .77766 m
.40989 .78148 L
s
.54174 .99404 m
.54175 .99405 L
s
.54162 .99392 m
.54174 .99404 L
s
.54118 .99349 m
.54162 .99392 L
s
.54108 .99339 m
.54118 .99349 L
s
.54084 .99316 m
.54108 .99339 L
s
.5401 .99242 m
.54084 .99316 L
s
.54001 .99233 m
.5401 .99242 L
s
.53997 .99229 m
.54001 .99233 L
s
.53974 .99206 m
.53997 .99229 L
s
.53972 .99204 m
.53974 .99206 L
s
.53923 .99155 m
.53972 .99204 L
s
.5391 .99143 m
.53923 .99155 L
s
.53882 .99115 m
.5391 .99143 L
s
.53869 .99102 m
.53882 .99115 L
s
.53849 .99082 m
.53869 .99102 L
s
.53669 .98867 m
.53708 .98913 L
s
.53708 .98913 m
.5374 .98952 L
s
.53741 .98954 m
.53849 .99082 L
s
.51333 .82711 m
.51438 .8312 L
s
.51438 .8312 m
.51438 .83122 L
s
.51316 .94818 m .51317 .94818 L .51673 .94765 L 0 .298 .118 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51319 .94818 m
.51673 .94765 L
s
.51317 .94818 m
.51319 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51319 .94818 m
.51673 .94765 L
s
.51317 .94818 m
.51319 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94816 L
s
.51317 .94816 m
.51317 .94816 L
s
.51317 .94816 m
.51535 .94324 L
s
.51316 .94818 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94815 L
s
.51317 .94815 m
.51317 .94815 L
s
.51317 .94815 m
.51535 .94324 L
s
.51318 .94817 m
.51674 .94663 L
s
.51318 .94817 m
.51318 .94817 L
s
.51318 .94817 m
.51318 .94817 L
s
.51318 .94817 m
.51318 .94817 L
s
.51317 .94818 m
.51318 .94817 L
s
.51317 .94817 m
.51674 .94663 L
s
.51317 .94818 m
.51317 .94817 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94817 m
.51671 .94565 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94818 m
.51317 .94817 L
s
.51317 .94817 m
.51671 .94565 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94818 m
.51317 .94817 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51316 .94817 m
.51438 .93773 L
s
.51316 .94817 m
.51438 .93773 L
s
.51317 .94818 m
.51317 .94817 L
s
.51316 .94818 m
.51317 .94817 L
s
.51316 .94817 m
.51402 .93624 L
s
.51316 .94817 m
.51402 .93624 L
s
.51316 .94815 m
.51365 .93494 L
s
.51316 .94816 m
.51365 .93494 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51316 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51316 .94816 m
.51328 .93385 L
s
.51316 .94816 m
.51328 .93385 L
s
.51317 .94817 m
.51317 .94817 L
s
.51316 .94816 m
.51317 .94815 L
s
.51317 .94815 m
.51317 .94815 L
s
.51317 .94815 m
.51317 .94815 L
s
.51316 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94816 L
s
.51317 .94816 m
.51317 .94816 L
s
.51317 .94816 m
.51317 .94815 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94816 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94816 L
s
.51317 .94816 m
.51318 .94814 L
s
.51317 .94818 m
.51317 .94817 L
s
.51317 .94817 m
.51318 .94814 L
s
.51317 .94818 m
.51322 .9481 L
s
.51317 .94818 m
.51322 .94809 L
s
.51317 .94817 m
.51654 .94393 L
s
.51317 .94818 m
.51317 .94817 L
s
.51317 .94817 m
.51654 .94393 L
s
.51317 .94817 m
.51665 .94475 L
s
.51317 .94818 m
.51317 .94817 L
s
.51317 .94817 m
.51665 .94475 L
s
.51317 .94816 m
.51472 .93941 L
s
.51317 .94816 m
.51317 .94816 L
s
.51316 .94817 m
.51317 .94816 L
s
.51317 .94816 m
.51472 .93941 L
s
.51316 .94817 m
.51317 .94816 L
s
.51316 .94818 m
.51317 .94817 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94816 m
.51326 .94781 L
s
.51317 .94816 m
.51317 .94816 L
s
.51317 .94816 m
.51317 .94816 L
s
.51317 .94817 m
.51317 .94816 L
s
.51317 .94817 m
.51317 .94817 L
s
.51316 .94818 m
.51317 .94817 L
s
.51317 .94816 m
.51324 .94788 L
s
.51317 .94816 m
.51317 .94816 L
s
.51317 .94816 m
.51317 .94816 L
s
.51317 .94817 m
.51317 .94816 L
s
.51316 .94817 m
.51317 .94817 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.52069 .96433 m .52645 .97411 L .52332 .96871 L 0 .088 .181 r
F
.52161 .96534 m .52645 .97411 L .52933 .97892 L 0 .09 .181 r
F
.52161 .96534 m .52332 .96871 L .52645 .97411 L F
0 g
.52645 .97411 m
.5282 .97738 L
s
.52645 .97411 m
.52708 .97517 L
s
.51316 .94818 m .50958 .94836 L .50481 .94859 L 0 .345 .119 r
F
.51316 .94818 m .51316 .94818 L .50958 .94836 L F
0 g
.51126 .95248 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50925 .93627 L .50726 .93095 L 0 .28 .314 r
F
.51316 .94818 m .51149 .94307 L .50925 .93627 L F
.51316 .94818 m .51316 .94818 L .51149 .94307 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51863 .95972 L .51551 .95312 L 0 .266 .304 r
F
.51316 .94818 m .52069 .96433 L .51863 .95972 L F
.51316 .94818 m .50925 .93627 L .51149 .94307 L 0 .286 .318 r
F
.51316 .94818 m .50791 .93144 L .50925 .93627 L F
.51316 .94818 m .50836 .93182 L .50791 .93144 L F
.51316 .94818 m .51004 .93692 L .50836 .93182 L F
.51316 .94818 m .51182 .94335 L .51004 .93692 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51182 .94335 L 0 .286 .318 r
F
.51316 .94818 m .51316 .94818 L .51551 .95312 L 0 .272 .308 r
F
.51316 .94818 m .50948 .96143 L .51158 .95386 L 0 .302 .261 r
F
.51316 .94818 m .51926 .9604 L .51578 .95342 L 0 .272 .308 r
F
.51316 .94818 m .52161 .96534 L .51926 .9604 L F
.51316 .94818 m .52125 .96495 L .52161 .96534 L F
.51316 .94818 m .51863 .95972 L .52125 .96495 L F
.51316 .94818 m .51551 .95312 L .51863 .95972 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50481 .94859 L .50958 .94836 L 0 .352 .119 r
F
.51316 .94818 m .50125 .94939 L .50481 .94859 L F
.51316 .94818 m .50128 .95022 L .50125 .94939 L F
.51316 .94818 m .50486 .95004 L .50128 .95022 L F
.51316 .94818 m .50961 .94898 L .50486 .95004 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .50961 .94898 L 0 .352 .119 r
F
.51316 .94818 m .52113 .9366 L .52075 .93381 L 0 .373 .268 r
F
.51316 .94818 m .51894 .94153 L .52113 .9366 L F
.51316 .94818 m .51564 .94533 L .51894 .94153 L F
.51316 .94818 m .51316 .94818 L .51564 .94533 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51004 .93692 L .51182 .94335 L 0 .292 .321 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50905 .93244 L .51004 .93692 L 0 .292 .321 r
F
.51316 .94818 m .50952 .93291 L .50905 .93244 L F
.51316 .94818 m .51086 .93773 L .50952 .93291 L F
.51316 .94818 m .51218 .9437 L .51086 .93773 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51218 .9437 L 0 .292 .321 r
F
0 g
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51578 .95342 L 0 .275 .311 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .52138 .9494 L .51669 .9487 L 0 .298 .118 r
F
.51316 .94818 m .52495 .94887 L .52138 .9494 L F
.51316 .94818 m .52502 .94747 L .52495 .94887 L F
0 g
.52502 .94747 m
.52507 .94742 L
s
.52422 .94735 m
.52502 .94747 L
s
.51316 .94818 m .51983 .96097 L .51602 .95366 L 0 .275 .311 r
F
.51316 .94818 m .52244 .96621 L .51983 .96097 L F
.51316 .94818 m .52212 .96588 L .52244 .96621 L F
.51316 .94818 m .51926 .9604 L .52212 .96588 L F
.51316 .94818 m .51578 .95342 L .51926 .9604 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51158 .95386 L 0 .299 .261 r
F
.51316 .94818 m .51086 .93773 L .51218 .9437 L 0 .298 .325 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51024 .93366 L .51086 .93773 L 0 .298 .325 r
F
0 g
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m .51072 .93421 L .51024 .93366 L 0 .298 .325 r
F
0 g
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m .51171 .93869 L .51072 .93421 L 0 .298 .325 r
F
.51316 .94818 m .51254 .94411 L .51171 .93869 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51254 .94411 L 0 .298 .325 r
F
0 g
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94817 L
s
.51316 .94818 m .51316 .94818 L .51602 .95366 L 0 .274 .311 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .52032 .96142 L .51623 .95385 L 0 .274 .311 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .52318 .96691 L .52032 .96142 L 0 .274 .311 r
F
.51316 .94818 m .52289 .96665 L .52318 .96691 L F
.51316 .94818 m .51983 .96097 L .52289 .96665 L F
.51316 .94818 m .51602 .95366 L .51983 .96097 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51669 .9487 L 0 .305 .118 r
F
.51316 .94818 m .51027 .96458 L .51192 .95521 L 0 .299 .261 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50869 .97026 L .51027 .96458 L 0 .299 .261 r
F
.51316 .94818 m .50824 .96846 L .50869 .97026 L F
.51316 .94818 m .50948 .96143 L .50824 .96846 L F
.51316 .94818 m .51158 .95386 L .50948 .96143 L F
.51316 .94818 m .50486 .95004 L .50961 .94898 L 0 .356 .117 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50137 .95146 L .50486 .95004 L 0 .356 .117 r
F
.51316 .94818 m .50145 .9523 L .50137 .95146 L F
.51316 .94818 m .50501 .9515 L .50145 .9523 L F
.51316 .94818 m .50967 .9496 L .50501 .9515 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .50967 .9496 L 0 .356 .117 r
F
0 g
.51314 .94818 m
.51316 .94818 L
s
.51314 .94818 m
.51314 .94818 L
s
.51314 .94818 m
.51314 .94818 L
s
.51316 .94818 m .51171 .93869 L .51254 .94411 L 0 .303 .328 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51146 .9351 L .51171 .93869 L 0 .303 .328 r
F
0 g
.51316 .94817 m
.51316 .94818 L
s
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m .51195 .93573 L .51146 .9351 L 0 .303 .328 r
F
.51316 .94818 m .51257 .9398 L .51195 .93573 L F
.51316 .94818 m .51291 .94459 L .51257 .9398 L F
.51316 .94818 m .51316 .94818 L .51291 .94459 L F
0 g
.51316 .94817 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51623 .95385 L 0 .271 .309 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51894 .94153 L .51564 .94533 L 0 .355 .267 r
F
.51316 .94818 m .52167 .94084 L .51894 .94153 L F
.51316 .94818 m .52201 .94371 L .52167 .94084 L F
.51316 .94818 m .51954 .94656 L .52201 .94371 L F
.51316 .94818 m .51589 .94749 L .51954 .94656 L F
.51316 .94818 m .51316 .94818 L .51589 .94749 L F
.51316 .94818 m .52073 .96174 L .5164 .95399 L 0 .271 .309 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .5238 .96742 L .52073 .96174 L 0 .271 .309 r
F
.51316 .94818 m .52356 .96724 L .5238 .96742 L F
.51316 .94818 m .52032 .96142 L .52356 .96724 L F
.51316 .94818 m .51623 .95385 L .52032 .96142 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .52118 .95189 L .5166 .94977 L 0 .305 .118 r
F
.51316 .94818 m .52471 .95242 L .52118 .95189 L F
.51316 .94818 m .52482 .95099 L .52471 .95242 L F
.51316 .94818 m .52138 .9494 L .52482 .95099 L F
.51316 .94818 m .51669 .9487 L .52138 .9494 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51192 .95521 L 0 .297 .261 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51257 .9398 L .51291 .94459 L 0 .307 .33 r
F
0 g
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94818 m .51269 .93674 L .51257 .9398 L 0 .307 .33 r
F
.51316 .94818 m .51319 .93746 L .51269 .93674 L F
0 g
.51291 .94459 m
.51316 .94818 L
s
.51254 .94411 m
.51316 .94816 L
s
.51316 .94816 m
.51316 .94818 L
s
.51254 .94411 m
.51316 .94815 L
s
.51316 .94815 m
.51316 .94818 L
s
.51218 .9437 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94818 L
s
.51218 .9437 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51182 .94335 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51182 .94335 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51149 .94307 m
.51316 .94816 L
s
.51149 .94307 m
.51316 .94816 L
s
.51316 .94818 m .51344 .94105 L .51319 .93746 L 0 .307 .33 r
F
.51316 .94818 m .51328 .94513 L .51344 .94105 L F
.51316 .94818 m .51316 .94818 L .51328 .94513 L F
0 g
.51291 .94459 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .5164 .95399 L 0 .265 .305 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .52106 .9619 L .51655 .95406 L 0 .265 .305 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .52431 .96772 L .52106 .9619 L 0 .265 .305 r
F
.51316 .94818 m .52412 .96763 L .52431 .96772 L F
.51316 .94818 m .52073 .96174 L .52412 .96763 L F
.51316 .94818 m .5164 .95399 L .52073 .96174 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m .51109 .96765 L .51227 .95652 L 0 .297 .261 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50985 .97468 L .51109 .96765 L 0 .297 .261 r
F
0 g
.51316 .9482 m
.51316 .94818 L
s
.51316 .94821 m
.51316 .94818 L
s
.51316 .94818 m .50938 .97293 L .50985 .97468 L 0 .297 .261 r
F
0 g
.51316 .94821 m
.51316 .94821 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .94818 m .51027 .96458 L .50938 .97293 L 0 .297 .261 r
F
.51316 .94818 m .51192 .95521 L .51027 .96458 L F
.51316 .94818 m .51344 .94105 L .51328 .94513 L 0 .308 .331 r
F
.51316 .94818 m .51394 .93858 L .51344 .94105 L F
.51316 .94818 m .51443 .93937 L .51394 .93858 L F
.51316 .94818 m .51431 .94243 L .51443 .93937 L F
.51316 .94818 m .51365 .94571 L .51431 .94243 L F
.51316 .94818 m .51316 .94818 L .51365 .94571 L F
.51316 .94818 m .51316 .94818 L .51655 .95406 L 0 .256 .299 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .5166 .94977 L 0 .316 .119 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .52131 .9619 L .51665 .95406 L 0 .256 .299 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .5247 .96779 L .52131 .9619 L 0 .256 .299 r
F
.51316 .94818 m .52456 .96779 L .5247 .96779 L F
.51316 .94818 m .52106 .9619 L .52456 .96779 L F
.51316 .94818 m .51655 .95406 L .52106 .9619 L F
0 g
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m .51954 .94656 L .51589 .94749 L 0 .335 .265 r
F
.51316 .94818 m .5225 .94806 L .51954 .94656 L F
0 g
.52149 .94694 m
.52369 .94727 L
s
.51316 .94818 m .52281 .95097 L .5225 .94806 L 0 .335 .265 r
F
0 g
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m .52118 .95189 L .52451 .95454 L 0 .316 .119 r
F
.51316 .94818 m .5166 .94977 L .52118 .95189 L F
.51316 .94818 m .52007 .95166 L .52281 .95097 L 0 .335 .265 r
F
0 g
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m .51612 .94967 L .52007 .95166 L 0 .335 .265 r
F
.51316 .94818 m .51316 .94818 L .51612 .94967 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50501 .9515 L .50967 .9496 L 0 .357 .116 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50161 .95356 L .50501 .9515 L 0 .357 .116 r
F
0 g
.51315 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50174 .95441 L .50161 .95356 L 0 .357 .116 r
F
0 g
.51315 .94818 m
.51315 .94818 L
s
.51316 .94818 m .50524 .95298 L .50174 .95441 L 0 .357 .116 r
F
.51316 .94818 m .50977 .95024 L .50524 .95298 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .50977 .95024 L 0 .357 .116 r
F
0 g
.51313 .94818 m
.51315 .94818 L
s
.51313 .94818 m
.51313 .94818 L
s
.51313 .94818 m
.51313 .94818 L
s
.51316 .94818 m .51431 .94243 L .51365 .94571 L 0 .307 .331 r
F
.51316 .94818 m .51517 .94059 L .51431 .94243 L F
.51316 .94818 m .51566 .94144 L .51517 .94059 L F
.51316 .94818 m .51517 .94391 L .51566 .94144 L F
.51316 .94818 m .51402 .94635 L .51517 .94391 L F
.51316 .94818 m .51316 .94818 L .51402 .94635 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51665 .95406 L 0 .246 .293 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .5209 .95435 L .51648 .95082 L 0 .316 .119 r
F
.51316 .94818 m .52434 .95595 L .5209 .95435 L F
.51316 .94818 m .52451 .95454 L .52434 .95595 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .52147 .96172 L .51672 .95398 L 0 .246 .293 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .52496 .96761 L .52147 .96172 L 0 .246 .293 r
F
0 g
.51316 .94818 m
.51318 .94821 L
s
.51316 .94818 m
.51318 .94821 L
s
.51316 .94818 m .52487 .96772 L .52496 .96761 L 0 .246 .293 r
F
0 g
.51318 .94821 m
.51318 .94821 L
s
.51318 .94821 m
.51318 .94821 L
s
.51316 .94818 m .52131 .9619 L .52487 .96772 L 0 .246 .293 r
F
.51316 .94818 m .51665 .95406 L .52131 .9619 L F
0 g
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .51316 .94818 L .51227 .95652 L 0 .297 .262 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51517 .94391 L .51402 .94635 L 0 .302 .329 r
F
.51316 .94818 m .51638 .94275 L .51517 .94391 L F
.51316 .94818 m .51686 .94365 L .51638 .94275 L F
.51316 .94818 m .516 .94549 L .51686 .94365 L F
.51316 .94818 m .51438 .94703 L .516 .94549 L F
.51316 .94818 m .51316 .94818 L .51438 .94703 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m .51317 .94818 L .51672 .95398 L 0 .236 .286 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m .52153 .96136 L .51675 .95382 L 0 .236 .286 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m .5251 .96717 L .52153 .96136 L 0 .236 .286 r
F
.51317 .94818 m .52506 .96738 L .5251 .96717 L F
.51317 .94818 m .52147 .96172 L .52506 .96738 L F
.51317 .94818 m .51672 .95398 L .52147 .96172 L F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .51193 .97061 L .51264 .95779 L 0 .297 .262 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51104 .97896 L .51193 .97061 L 0 .297 .262 r
F
.51316 .94818 m .51056 .97727 L .51104 .97896 L F
.51316 .94818 m .51109 .96765 L .51056 .97727 L F
.51316 .94818 m .51227 .95652 L .51109 .96765 L F
.51316 .94818 m .516 .94549 L .51438 .94703 L 0 .294 .324 r
F
0 g
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m .51756 .94503 L .516 .94549 L 0 .294 .324 r
F
.51316 .94818 m .51802 .94597 L .51756 .94503 L F
.51316 .94818 m .5168 .94713 L .51802 .94597 L F
.51316 .94818 m .51472 .94773 L .5168 .94713 L F
.51316 .94818 m .51316 .94818 L .51472 .94773 L F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m .51317 .94818 L .51675 .95382 L 0 .225 .278 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m .51316 .94818 L .51648 .95082 L 0 .332 .12 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51316 .94818 m
.51317 .94819 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m .52151 .9608 L .51674 .95358 L 0 .225 .278 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m .52511 .96646 L .52151 .9608 L 0 .225 .278 r
F
0 g
.51316 .94818 m
.51317 .94819 L
s
.51317 .94818 m .52512 .96678 L .52511 .96646 L 0 .225 .278 r
F
0 g
.51317 .94819 m
.51317 .94819 L
s
.51317 .94818 m .52153 .96136 L .52512 .96678 L 0 .225 .278 r
F
.51317 .94818 m .51675 .95382 L .52153 .96136 L F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .52007 .95166 L .51612 .94967 L 0 .315 .262 r
F
.51316 .94818 m .52323 .95533 L .52007 .95166 L F
.5194 .95472 m .52406 .95802 L .52385 .95938 L 0 .332 .12 r
F
.51316 .94818 m .51726 .95188 L .5194 .95472 L F
.51726 .95188 m .52406 .95802 L .5194 .95472 L F
.51726 .95188 m .5209 .95435 L .52406 .95802 L F
.51316 .94818 m .51644 .95079 L .51726 .95188 L F
.51644 .95079 m .5209 .95435 L .51726 .95188 L F
.52385 .95938 m .52406 .95802 L .52755 .96017 L 0 .379 .144 r
F
.52385 .95938 m .53112 .97211 L .52687 .96541 L F
.52385 .95938 m .53462 .97428 L .53112 .97211 L F
.52658 .96315 m .53503 .97046 L .53462 .97428 L F
.52385 .95938 m .52527 .96078 L .52658 .96315 L F
.52527 .96078 m .53503 .97046 L .52658 .96315 L F
.53462 .97428 m .54182 .99366 L .53752 .98421 L 0 .408 .165 r
F
.53462 .97428 m .53481 .97463 L .54182 .99366 L F
.53481 .97463 m .5455 .99445 L .54239 .99378 L F
.53481 .97463 m .54239 .99378 L .54182 .99366 L F
.54356 .97329 m .54441 .98896 L .54755 1.00683 L 0 .258 .221 r
F
.54787 1.00764 m .54755 1.00683 L .54831 1.01117 L F
.54356 .97329 m .54755 1.00683 L .54787 1.00764 L F
.54012 .98766 m .53752 .98421 L .54182 .99366 L 0 .274 .233 r
F
.52527 .96078 m .532 .96441 L .53503 .97046 L 0 .379 .144 r
F
.52385 .95938 m .52481 .95997 L .52527 .96078 L F
.52481 .95997 m .532 .96441 L .52527 .96078 L F
.53976 .98639 m .53712 .98223 L .54012 .98766 L 0 .274 .233 r
F
.53462 .97428 m .53503 .97046 L .53869 .97124 L 0 .408 .165 r
F
.53462 .97428 m .53869 .97124 L .54317 .97612 L F
.53337 .96386 m .53696 .98144 L .53976 .98639 L 0 .274 .233 r
F
.53696 .98144 m .53712 .98223 L .53976 .98639 L F
.53712 .98223 m .53752 .98421 L .54012 .98766 L F
.52385 .95938 m .52755 .96017 L .532 .96441 L 0 .379 .144 r
F
.52323 .95533 m .5235 .95823 L .52587 .96328 L 0 .292 .247 r
F
.52632 .96387 m .52587 .96328 L .52687 .96541 L F
.52323 .95533 m .52587 .96328 L .52632 .96387 L F
.51316 .94818 m .51648 .95082 L .5209 .95435 L 0 .332 .12 r
F
.51316 .94818 m .5235 .95823 L .52323 .95533 L 0 .315 .262 r
F
.51316 .94818 m .52385 .95938 L .52053 .95673 L 0 .332 .12 r
F
.51316 .94818 m .52053 .95673 L .5235 .95823 L 0 .315 .262 r
F
.51316 .94818 m .51632 .95184 L .52053 .95673 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51632 .95184 L 0 .315 .262 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .5168 .94713 L .51472 .94773 L 0 .283 .317 r
F
.51316 .94818 m .5187 .9474 L .5168 .94713 L F
.51316 .94818 m .51913 .94836 L .5187 .9474 L F
0 g
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51318 .94818 L
s
.51318 .94818 m
.51318 .94818 L
s
.51318 .94818 m
.51318 .94818 L
s
.51318 .94818 m
.51472 .94773 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51472 .94773 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51438 .94703 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51438 .94703 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51402 .94635 L
s
.51316 .94818 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51317 .94817 L
s
.51317 .94817 m
.51402 .94635 L
s
.51316 .94818 m
.51316 .94817 L
s
.51316 .94817 m
.51316 .94817 L
s
.51316 .94817 m
.51365 .94571 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51328 .94513 L
s
.51316 .94818 m
.51328 .94513 L
s
.51316 .94818 m
.51365 .94571 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51757 .94881 L .51913 .94836 L 0 .283 .317 r
F
.51316 .94818 m .51505 .94845 L .51757 .94881 L F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .51316 .94818 L .51505 .94845 L 0 .283 .317 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50524 .95298 L .50977 .95024 L 0 .355 .115 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50197 .95568 L .50524 .95298 L 0 .355 .115 r
F
.51316 .94818 m .50215 .95653 L .50197 .95568 L F
.51316 .94818 m .50555 .95447 L .50215 .95653 L F
.51316 .94818 m .5099 .95087 L .50555 .95447 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .5099 .95087 L 0 .355 .115 r
F
0 g
.51315 .94818 m
.51316 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51317 .94818 L .51674 .95358 L 0 .216 .272 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m .5214 .96005 L .51669 .95326 L 0 .216 .272 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .52498 .96547 L .5214 .96005 L 0 .216 .272 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .52505 .9659 L .52498 .96547 L 0 .216 .272 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .52151 .9608 L .52505 .9659 L 0 .216 .272 r
F
.51316 .94818 m .51674 .95358 L .52151 .9608 L F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .51757 .94881 L .51505 .94845 L 0 .269 .307 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .51977 .9498 L .51757 .94881 L 0 .269 .307 r
F
.51316 .94818 m .52018 .95077 L .51977 .9498 L F
.51316 .94818 m .51828 .9505 L .52018 .95077 L F
.51316 .94818 m .51536 .94917 L .51828 .9505 L F
.51316 .94818 m .51316 .94818 L .51536 .94917 L F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94819 m .51316 .94819 L .51264 .95779 L 0 .299 .263 r
F
0 g
.51316 .94819 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51669 .95326 L 0 .209 .267 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .52053 .95673 L .51632 .95184 L 0 .332 .12 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .52119 .95911 L .5166 .95286 L 0 .209 .267 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .52473 .96422 L .52119 .95911 L 0 .209 .267 r
F
.51316 .94818 m .52485 .96475 L .52473 .96422 L F
.51316 .94818 m .5214 .96005 L .52485 .96475 L F
.51316 .94818 m .51669 .95326 L .5214 .96005 L F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m .51828 .9505 L .51536 .94917 L 0 .253 .296 r
F
.51316 .94818 m .52077 .95221 L .51828 .9505 L F
0 g
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m .52115 .95317 L .52077 .95221 L 0 .253 .296 r
F
.51316 .94818 m .51895 .95217 L .52115 .95317 L F
.51316 .94818 m .51564 .94989 L .51895 .95217 L F
.51316 .94818 m .51316 .94818 L .51564 .94989 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .5166 .95286 L 0 .206 .265 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .5209 .958 L .51648 .95238 L 0 .206 .265 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .52436 .9627 L .5209 .958 L 0 .206 .265 r
F
.51316 .94818 m .52452 .96334 L .52436 .9627 L F
.51316 .94818 m .52119 .95911 L .52452 .96334 L F
.51316 .94818 m .5166 .95286 L .52119 .95911 L F
0 g
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .51895 .95217 L .51564 .94989 L 0 .237 .285 r
F
.51316 .94818 m .52169 .95457 L .51895 .95217 L F
.51316 .94818 m .52203 .9555 L .52169 .95457 L F
.51316 .94818 m .51954 .95378 L .52203 .9555 L F
.51316 .94818 m .5159 .95058 L .51954 .95378 L F
.51316 .94818 m .51316 .94818 L .5159 .95058 L F
0 g
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51648 .95238 L 0 .207 .265 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .52053 .95673 L .51632 .95184 L 0 .207 .265 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .52386 .96095 L .52053 .95673 L 0 .207 .265 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .52407 .96168 L .52386 .96095 L 0 .207 .265 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .5209 .958 L .52407 .96168 L 0 .207 .265 r
F
.51316 .94818 m .51648 .95238 L .5209 .958 L F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51954 .95378 L .5159 .95058 L 0 .223 .276 r
F
.51316 .94818 m .52251 .95685 L .51954 .95378 L F
.51316 .94818 m .52282 .95772 L .52251 .95685 L F
.51316 .94818 m .52007 .95531 L .52282 .95772 L F
.51316 .94818 m .51612 .95123 L .52007 .95531 L F
.51316 .94818 m .51316 .94818 L .51612 .95123 L F
0 g
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51632 .95184 L 0 .213 .269 r
F
0 g
.51317 .94818 m
.51317 .94819 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .52007 .95531 L .51612 .95123 L 0 .213 .269 r
F
0 g
.51317 .94819 m
.51317 .94819 L
s
.51316 .94818 m .52324 .95898 L .52007 .95531 L 0 .213 .269 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .5235 .95979 L .52324 .95898 L 0 .213 .269 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .52053 .95673 L .5235 .95979 L 0 .213 .269 r
F
.51316 .94818 m .51632 .95184 L .52053 .95673 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51318 .94818 L
s
.51318 .94818 m
.51318 .94818 L
s
.51318 .94818 m
.51318 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m .51279 .97344 L .513 .959 L 0 .299 .263 r
F
.51316 .94819 m .51226 .98307 L .51279 .97344 L F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m .51177 .98145 L .51226 .98307 L 0 .299 .263 r
F
.51316 .94819 m .51193 .97061 L .51177 .98145 L F
.51316 .94819 m .51264 .95779 L .51193 .97061 L F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .52053 .95673 L .51632 .95184 L 0 .302 .259 r
F
.51316 .94818 m .52386 .96252 L .52053 .95673 L F
.51316 .94818 m .52408 .96534 L .52386 .96252 L F
.51316 .94818 m .52091 .96166 L .52408 .96534 L F
.51316 .94818 m .51648 .95395 L .52091 .96166 L F
.51316 .94818 m .51316 .94818 L .51648 .95395 L F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .51316 .94818 L .51632 .95184 L 0 .348 .122 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50555 .95447 L .5099 .95087 L 0 .35 .113 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50245 .95781 L .50555 .95447 L 0 .35 .113 r
F
.51316 .94818 m .50268 .95866 L .50245 .95781 L F
.51316 .94818 m .50595 .95596 L .50268 .95866 L F
.51316 .94818 m .51008 .95151 L .50595 .95596 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51008 .95151 L 0 .35 .113 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m .51316 .94819 L .513 .959 L 0 .303 .264 r
F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .52008 .95896 L .51612 .95279 L 0 .348 .122 r
F
.51316 .94818 m .52325 .96264 L .52008 .95896 L F
.51316 .94818 m .5235 .96136 L .52325 .96264 L F
.51316 .94818 m .52053 .95673 L .5235 .96136 L F
.51316 .94818 m .51632 .95184 L .52053 .95673 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94819 m .51365 .97612 L .51337 .96014 L 0 .303 .264 r
F
.51316 .94819 m .51349 .98698 L .51365 .97612 L F
.51316 .94819 m .513 .98544 L .51349 .98698 L F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51316 .94819 m .51279 .97344 L .513 .98544 L 0 .303 .264 r
F
.51316 .94819 m .513 .959 L .51279 .97344 L F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .9482 m
.51316 .94819 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .94818 m .52091 .96166 L .51648 .95395 L 0 .294 .257 r
F
.52318 .96691 m .53321 .98461 L .53056 .97981 L 0 .098 .183 r
F
.51316 .94818 m .52437 .96947 L .52091 .96166 L 0 .294 .257 r
F
0 g
.51317 .94819 m
.51317 .94819 L
s
.52161 .96534 m .52125 .96495 L .52332 .96871 L 0 .09 .181 r
F
.52161 .96534 m .52933 .97892 L .53005 .97992 L F
.52161 .96534 m .52798 .97616 L .52449 .97015 L F
.52161 .96534 m .53005 .97992 L .52798 .97616 L F
.52244 .96621 m .52449 .97015 L .52798 .97616 L 0 .093 .182 r
F
.52244 .96621 m .52212 .96588 L .52449 .97015 L F
.52244 .96621 m .52798 .97616 L .53108 .98139 L F
.52244 .96621 m .53173 .98235 L .52935 .97808 L F
.52244 .96621 m .53108 .98139 L .53173 .98235 L F
.51316 .94818 m .52454 .97216 L .52437 .96947 L 0 .294 .257 r
F
0 g
.51317 .94819 m
.51317 .94819 L
s
.51316 .94818 m .5212 .96635 L .52454 .97216 L 0 .294 .257 r
F
.51316 .94818 m .5166 .95595 L .5212 .96635 L F
.51316 .94818 m .51316 .94818 L .5166 .95595 L F
.51316 .94818 m .51316 .94818 L .51612 .95279 L 0 .363 .124 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94819 m .51316 .94819 L .51337 .96014 L 0 .307 .266 r
F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .50595 .95596 L .51008 .95151 L 0 .344 .112 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50305 .95994 L .50595 .95596 L 0 .344 .112 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50332 .96078 L .50305 .95994 L 0 .344 .112 r
F
.51316 .94818 m .50642 .95743 L .50332 .96078 L F
.51316 .94818 m .51028 .95214 L .50642 .95743 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51028 .95214 L 0 .344 .112 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51955 .96102 L .5159 .95367 L 0 .363 .124 r
F
.51316 .94818 m .52253 .96566 L .51955 .96102 L F
.51316 .94818 m .52283 .96449 L .52253 .96566 L F
.51316 .94818 m .52008 .95896 L .52283 .96449 L F
.51316 .94818 m .51612 .95279 L .52008 .95896 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94819 m .51451 .97862 L .51374 .96121 L 0 .307 .266 r
F
.51316 .94819 m .51472 .99064 L .51451 .97862 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m .51423 .9892 L .51472 .99064 L 0 .307 .266 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m .51365 .97612 L .51423 .9892 L 0 .307 .266 r
F
.51316 .94819 m .51337 .96014 L .51365 .97612 L F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .5212 .96635 L .5166 .95595 L 0 .289 .255 r
F
.51316 .94818 m .52475 .97606 L .5212 .96635 L F
.51316 .94818 m .52487 .97857 L .52475 .97606 L F
.51316 .94818 m .52141 .97073 L .52487 .97857 L F
.51316 .94818 m .51669 .95783 L .52141 .97073 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51669 .95783 L 0 .289 .255 r
F
.51316 .94819 m .51316 .94819 L .51374 .96121 L 0 .314 .266 r
F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m .51477 .97936 L .51385 .96153 L 0 .314 .266 r
F
.51316 .94819 m .51535 .99245 L .51477 .97936 L F
.51316 .94819 m .5152 .99203 L .51535 .99245 L F
.51316 .94819 m .51451 .97862 L .5152 .99203 L F
.51316 .94819 m .51374 .96121 L .51451 .97862 L F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .51316 .94818 L .5159 .95367 L 0 .374 .126 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50642 .95743 L .51028 .95214 L 0 .336 .112 r
F
.51316 .94818 m .50376 .96204 L .50642 .95743 L F
.51316 .94818 m .50407 .96287 L .50376 .96204 L F
.51316 .94818 m .50697 .95889 L .50407 .96287 L F
.51316 .94818 m .51051 .95276 L .50697 .95889 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51051 .95276 L 0 .336 .112 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m .51316 .94819 L .51385 .96153 L 0 .319 .267 r
F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .51896 .96284 L .51564 .95445 L 0 .374 .126 r
F
.51316 .94818 m .52171 .96837 L .51896 .96284 L F
.51316 .94818 m .52205 .96733 L .52171 .96837 L F
.51316 .94818 m .51955 .96102 L .52205 .96733 L F
.51316 .94818 m .5159 .95367 L .51955 .96102 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .52141 .97073 L .51669 .95783 L 0 .286 .253 r
F
.51316 .94818 m .52502 .98216 L .52141 .97073 L F
.51316 .94818 m .52508 .98445 L .52502 .98216 L F
.51316 .94818 m .52153 .97472 L .52508 .98445 L F
.51316 .94818 m .51674 .95953 L .52153 .97472 L F
0 g
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m .51317 .94818 L .51674 .95953 L 0 .286 .253 r
F
.51316 .94819 m .51562 .9816 L .51421 .96248 L 0 .319 .267 r
F
.51316 .94819 m .51631 .99502 L .51562 .9816 L F
.51316 .94819 m .51583 .99374 L .51631 .99502 L F
.51316 .94819 m .51477 .97936 L .51583 .99374 L F
.51316 .94819 m .51385 .96153 L .51477 .97936 L F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .50697 .95889 L .51051 .95276 L 0 .331 .111 r
F
.51316 .94818 m .50438 .96369 L .50697 .95889 L F
.51316 .94818 m .50449 .96394 L .50438 .96369 L F
.51316 .94818 m .50715 .95933 L .50449 .96394 L F
0 g
.50481 .94859 m
.50481 .94859 L
s
.50126 .94817 m
.50481 .94859 L
s
.51316 .94818 m .51059 .95295 L .50715 .95933 L 0 .331 .111 r
F
.51316 .94818 m .51316 .94818 L .51059 .95295 L F
0 g
.51316 .9482 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51564 .95445 L 0 .381 .128 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m .51316 .94819 L .51421 .96248 L 0 .328 .268 r
F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .5183 .96439 L .51536 .95511 L 0 .381 .128 r
F
.51316 .94818 m .52079 .97071 L .5183 .96439 L F
.51316 .94818 m .52117 .96982 L .52079 .97071 L F
.51316 .94818 m .51896 .96284 L .52117 .96982 L F
.51316 .94818 m .51564 .95445 L .51896 .96284 L F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m .52153 .97472 L .51674 .95953 L 0 .286 .252 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m .52515 .98767 L .52153 .97472 L 0 .286 .252 r
F
.51317 .94818 m .52516 .9897 L .52515 .98767 L F
.51317 .94818 m .52156 .97824 L .52516 .9897 L F
.51317 .94818 m .51675 .96103 L .52156 .97824 L F
.51317 .94818 m .51317 .94818 L .51675 .96103 L F
.51316 .94819 m .51644 .98358 L .51457 .96333 L 0 .328 .268 r
F
.51316 .94819 m .5175 .99797 L .51644 .98358 L F
.51316 .94819 m .51703 .99684 L .5175 .99797 L F
.51316 .94819 m .51562 .9816 L .51703 .99684 L F
.51316 .94819 m .51421 .96248 L .51562 .9816 L F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .50715 .95933 L .51059 .95295 L 0 .326 .111 r
F
0 g
.51315 .94818 m
.51316 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51316 .94818 m .50484 .96474 L .50715 .95933 L 0 .326 .111 r
F
.51316 .94818 m .5052 .96555 L .50484 .96474 L F
.51316 .94818 m .50779 .96075 L .5052 .96555 L F
.51316 .94818 m .51086 .95356 L .50779 .96075 L F
.51316 .94818 m .51316 .94818 L .51086 .95356 L F
0 g
.51315 .94818 m
.51315 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m .51316 .94819 L .51457 .96333 L 0 .335 .268 r
F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .51316 .94818 L .51536 .95511 L 0 .383 .13 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94819 m .52156 .97824 L .51675 .96103 L 0 .289 .253 r
F
.51317 .94819 m .52515 .99251 L .52156 .97824 L F
.51317 .94819 m .52511 .99424 L .52515 .99251 L F
.51317 .94819 m .52149 .98127 L .52511 .99424 L F
.51317 .94819 m .51672 .96232 L .52149 .98127 L F
.51317 .94819 m .51317 .94819 L .51672 .96232 L F
.51316 .94819 m .51723 .98527 L .5149 .96404 L 0 .335 .268 r
F
.51316 .94819 m .51864 1.00052 L .51723 .98527 L F
.51316 .94819 m .51819 .99955 L .51864 1.00052 L F
.51316 .94819 m .51644 .98358 L .51819 .99955 L F
.51316 .94819 m .51457 .96333 L .51644 .98358 L F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .51758 .96566 L .51505 .95565 L 0 .383 .13 r
F
.51316 .94818 m .51979 .97266 L .51758 .96566 L F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .5202 .97193 L .51979 .97266 L 0 .383 .13 r
F
.51316 .94818 m .5183 .96439 L .5202 .97193 L F
.51316 .94818 m .51536 .95511 L .5183 .96439 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .50779 .96075 L .51086 .95356 L 0 .32 .112 r
F
.51316 .94818 m .50578 .96674 L .50779 .96075 L F
.51316 .94818 m .50617 .96752 L .50578 .96674 L F
.51316 .94818 m .50849 .9621 L .50617 .96752 L F
.51316 .94818 m .51116 .95413 L .50849 .9621 L F
.51316 .94818 m .51316 .94818 L .51116 .95413 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m .51316 .94819 L .5149 .96404 L 0 .339 .267 r
F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m .52149 .98127 L .51672 .96232 L 0 .293 .254 r
F
.51316 .94819 m .52502 .99661 L .52149 .98127 L F
.51316 .94819 m .52493 .99804 L .52502 .99661 L F
.51316 .94819 m .52134 .98375 L .52493 .99804 L F
.51316 .94819 m .51666 .96339 L .52134 .98375 L F
.51316 .94819 m .51316 .94819 L .51666 .96339 L F
.51316 .94819 m .51797 .98662 L .51522 .96462 L 0 .339 .267 r
F
.51316 .94819 m .51972 1.00261 L .51797 .98662 L F
.51316 .94819 m .5193 1.00183 L .51972 1.00261 L F
.51316 .94819 m .51723 .98527 L .5193 1.00183 L F
.51316 .94819 m .5149 .96404 L .51723 .98527 L F
.51316 .94818 m .51316 .94818 L .51505 .95565 L 0 .381 .131 r
F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m .51316 .94819 L .51522 .96462 L 0 .34 .266 r
F
.51316 .94819 m .52076 .98709 L .52418 1.00329 L 0 .303 .257 r
F
.51316 .94818 m .51681 .96663 L .51472 .95606 L 0 .381 .131 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94819 m .52109 .9857 L .52462 1.00106 L 0 .298 .255 r
F
.51316 .94819 m .51655 .96422 L .52109 .9857 L F
.51316 .94819 m .51316 .94819 L .51655 .96422 L F
.51316 .94819 m .52109 .9857 L .51655 .96422 L 0 .303 .257 r
F
.51316 .94819 m .52437 1.00249 L .52109 .9857 L F
.51316 .94819 m .52418 1.00329 L .52437 1.00249 L F
.51316 .94818 m .51872 .97417 L .51681 .96663 L 0 .381 .131 r
F
.51316 .94819 m .52134 .98375 L .51666 .96339 L 0 .298 .255 r
F
.51316 .94819 m .52476 .99994 L .52134 .98375 L F
.51316 .94819 m .52462 1.00106 L .52476 .99994 L F
.51316 .94818 m .51916 .97362 L .51872 .97417 L 0 .381 .131 r
F
.51316 .94818 m .51758 .96566 L .51916 .97362 L F
.51316 .94818 m .51505 .95565 L .51758 .96566 L F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .50849 .9621 L .51116 .95413 L 0 .316 .113 r
F
.51316 .94818 m .50679 .96864 L .50849 .9621 L F
.51316 .94818 m .50722 .96936 L .50679 .96864 L F
.51316 .94818 m .50924 .96336 L .50722 .96936 L F
0 g
.51316 .9482 m
.51316 .9482 L
s
.51316 .94818 m .51148 .95467 L .50924 .96336 L 0 .316 .113 r
F
.51316 .94818 m .51316 .94818 L .51148 .95467 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .9482 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m .51866 .98761 L .51551 .96504 L 0 .34 .266 r
F
.51316 .94819 m .52073 1.00419 L .51866 .98761 L F
.51316 .94819 m .52034 1.00362 L .52073 1.00419 L F
.51316 .94819 m .51797 .98662 L .52034 1.00362 L F
.51316 .94819 m .51522 .96462 L .51797 .98662 L F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m .51316 .94819 L .51551 .96504 L 0 .337 .265 r
F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .51316 .94818 L .51472 .95606 L 0 .376 .131 r
F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m .51641 .96481 L .52076 .98709 L 0 .303 .257 r
F
.51316 .94819 m .51316 .94819 L .51641 .96481 L F
.51316 .94819 m .51929 .98818 L .51578 .96528 L 0 .337 .265 r
F
.51316 .94819 m .52166 1.00519 L .51929 .98818 L F
.51316 .94819 m .5213 1.00486 L .52166 1.00519 L F
.51316 .94819 m .51866 .98761 L .5213 1.00486 L F
.51316 .94819 m .51551 .96504 L .51866 .98761 L F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m .51316 .94819 L .51578 .96528 L 0 .331 .263 r
F
.51316 .94818 m .51601 .96728 L .51438 .95635 L 0 .376 .131 r
F
.51316 .94819 m .5225 1.00557 L .51985 .98831 L 0 .331 .263 r
F
.51316 .94819 m .52218 1.0055 L .5225 1.00557 L F
.51316 .94819 m .51929 .98818 L .52218 1.0055 L F
.51316 .94819 m .51578 .96528 L .51929 .98818 L F
.51316 .94818 m .51758 .97525 L .51601 .96728 L 0 .376 .131 r
F
.51316 .94819 m .52035 .98796 L .52362 1.00476 L 0 .312 .259 r
F
.51316 .94819 m .51623 .96518 L .52035 .98796 L F
.51316 .94819 m .51316 .94819 L .51623 .96518 L F
.51316 .94819 m .51985 .98831 L .51602 .96533 L 0 .331 .263 r
F
.51316 .94819 m .51316 .94819 L .51602 .96533 L 0 .322 .261 r
F
.51316 .94819 m .52035 .98796 L .51623 .96518 L F
.51316 .94819 m .52324 1.00528 L .52035 .98796 L F
.51316 .94819 m .52295 1.00548 L .52324 1.00528 L F
.51316 .94819 m .51985 .98831 L .52295 1.00548 L F
.51316 .94819 m .51602 .96533 L .51985 .98831 L F
.51316 .94818 m .51804 .97487 L .51758 .97525 L 0 .376 .131 r
F
.51316 .94819 m .52076 .98709 L .51641 .96481 L 0 .312 .259 r
F
.51316 .94819 m .52386 1.00426 L .52076 .98709 L F
.51316 .94819 m .52362 1.00476 L .52386 1.00426 L F
.51316 .94818 m .51681 .96663 L .51804 .97487 L 0 .376 .131 r
F
.51316 .94818 m .51472 .95606 L .51681 .96663 L F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .50924 .96336 L .51148 .95467 L 0 .315 .115 r
F
.51316 .94818 m .50788 .9704 L .50924 .96336 L F
.51316 .94818 m .50833 .97107 L .50788 .9704 L F
0 g
.50816 .96855 m
.50824 .96846 L
s
.50632 .97084 m
.50816 .96855 L
s
.51316 .94818 m .51003 .96452 L .50833 .97107 L 0 .315 .115 r
F
.51316 .94818 m .51182 .95516 L .51003 .96452 L F
.51316 .94818 m .51316 .94818 L .51182 .95516 L F
0 g
.51315 .94818 m
.51316 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51438 .95635 L 0 .367 .131 r
F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .51517 .96764 L .51402 .9565 L 0 .367 .131 r
F
.51316 .94818 m .5164 .97589 L .51517 .96764 L F
.51316 .94818 m .51688 .97569 L .5164 .97589 L F
.51316 .94818 m .51601 .96728 L .51688 .97569 L F
0 g
.51608 .95157 m
.51632 .95184 L
s
.51316 .94818 m .51438 .95635 L .51601 .96728 L 0 .367 .131 r
F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m
.51316 .94819 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .51003 .96452 L .51182 .95516 L 0 .316 .118 r
F
.51316 .94818 m .50903 .972 L .51003 .96452 L F
.51316 .94818 m .5095 .97259 L .50903 .972 L F
.51316 .94818 m .51085 .96554 L .5095 .97259 L F
.51316 .94818 m .51218 .9556 L .51085 .96554 L F
.51316 .94818 m .51316 .94818 L .51218 .9556 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51402 .9565 L 0 .357 .13 r
F
0 g
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .51432 .96771 L .51366 .95653 L 0 .357 .13 r
F
.51316 .94818 m .51518 .97611 L .51432 .96771 L F
.51316 .94818 m .51567 .97607 L .51518 .97611 L F
.51316 .94818 m .51517 .96764 L .51567 .97607 L F
.51316 .94818 m .51402 .9565 L .51517 .96764 L F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .51085 .96554 L .51218 .9556 L 0 .32 .121 r
F
.51316 .94818 m .51022 .97339 L .51085 .96554 L F
.51316 .94818 m .51071 .97389 L .51022 .97339 L F
.51316 .94818 m .5117 .96639 L .51071 .97389 L F
.51316 .94818 m .51254 .95597 L .5117 .96639 L F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51254 .95597 L 0 .32 .121 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51366 .95653 L 0 .346 .128 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .51344 .96751 L .51328 .95644 L 0 .346 .128 r
F
.51316 .94818 m .51394 .97594 L .51344 .96751 L F
.51316 .94818 m .51444 .97605 L .51394 .97594 L F
.51316 .94818 m .51432 .96771 L .51444 .97605 L F
.51316 .94818 m .51366 .95653 L .51432 .96771 L F
0 g
.51347 .94839 m
.51564 .94989 L
s
.51347 .94839 m
.51347 .94839 L
s
.51346 .94839 m
.51347 .94839 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m .5117 .96639 L .51254 .95597 L 0 .327 .123 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51145 .97454 L .5117 .96639 L 0 .327 .123 r
F
.51316 .94818 m .51194 .97492 L .51145 .97454 L F
.51316 .94818 m .51257 .96706 L .51194 .97492 L F
0 g
.51059 .95295 m
.51221 .94995 L
s
.51059 .95295 m
.51217 .95002 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .51291 .95625 L .51257 .96706 L 0 .327 .123 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51291 .95625 L 0 .327 .123 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51316 .94818 L .51328 .95644 L 0 .336 .126 r
F
0 g
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m .51257 .96706 L .51291 .95625 L 0 .336 .126 r
F
0 g
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m .51269 .9754 L .51257 .96706 L 0 .336 .126 r
F
.51316 .94818 m .51319 .97566 L .51269 .9754 L F
0 g
.51291 .95625 m
.51314 .94889 L
s
.51314 .94889 m
.51314 .94889 L
s
.51314 .94889 m
.51314 .94888 L
s
.51314 .94888 m
.51316 .94831 L
s
.51316 .94831 m
.51316 .94831 L
s
.51316 .94831 m
.51316 .94831 L
s
.51316 .94831 m
.51316 .94823 L
s
.51316 .94823 m
.51316 .94823 L
s
.51316 .94823 m
.51316 .94823 L
s
.51316 .94823 m
.51316 .94821 L
s
.51316 .94819 m
.51316 .94819 L
s
.51291 .95625 m
.51315 .94869 L
s
.51315 .94869 m
.51315 .94869 L
s
.51315 .94869 m
.51315 .94869 L
s
.51315 .94869 m
.51316 .94828 L
s
.51316 .94828 m
.51316 .94828 L
s
.51316 .94828 m
.51316 .94828 L
s
.51316 .94828 m
.51316 .94823 L
s
.51316 .94823 m
.51316 .94823 L
s
.51316 .94823 m
.51316 .94823 L
s
.51316 .94823 m
.51316 .94821 L
s
.51316 .94821 m
.51316 .94821 L
s
.51316 .94821 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94818 L
s
.51254 .95597 m
.51315 .94837 L
s
.51315 .94837 m
.51315 .94837 L
s
.51315 .94837 m
.51315 .94837 L
s
.51315 .94836 m
.51316 .94824 L
s
.51315 .94837 m
.51315 .94836 L
s
.51315 .94836 m
.51315 .94836 L
s
.51316 .94824 m
.51316 .94824 L
s
.51316 .94824 m
.51316 .94824 L
s
.51316 .94824 m
.51316 .94821 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51314 .94847 m
.51315 .94831 L
s
.51254 .95597 m
.51314 .94847 L
s
.51314 .94847 m
.51314 .94847 L
s
.51315 .94831 m
.51315 .94831 L
s
.51315 .94831 m
.51315 .94831 L
s
.51315 .94831 m
.51316 .94823 L
s
.51316 .94823 m
.51316 .94823 L
s
.51316 .94823 m
.51316 .94823 L
s
.51316 .94823 m
.51316 .94821 L
s
.51316 .94821 m
.51316 .94821 L
s
.51316 .94821 m
.51316 .94821 L
s
.51316 .94821 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51313 .94842 m
.51315 .94829 L
s
.51218 .9556 m
.51313 .94842 L
s
.51313 .94842 m
.51313 .94842 L
s
.51315 .94829 m
.51315 .94828 L
s
.51315 .94828 m
.51315 .94828 L
s
.51315 .94828 m
.51315 .94828 L
s
.51315 .94828 m
.51316 .94822 L
s
.51316 .94822 m
.51316 .94822 L
s
.51316 .94822 m
.51316 .94822 L
s
.51316 .94822 m
.51316 .94821 L
s
.51316 .94818 m
.51316 .94818 L
s
.51312 .94848 m
.51315 .94828 L
s
.51218 .9556 m
.51312 .94849 L
s
.51312 .94849 m
.51312 .94848 L
s
.51315 .94828 m
.51315 .94825 L
s
.51315 .94825 m
.51315 .94825 L
s
.51315 .94825 m
.51315 .94825 L
s
.51315 .94825 m
.51316 .94821 L
s
.51316 .94821 m
.51316 .94821 L
s
.51316 .94821 m
.51316 .94821 L
s
.51316 .94821 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51182 .95516 m
.51315 .94824 L
s
.51315 .94824 m
.51315 .94824 L
s
.51315 .94824 m
.51315 .94824 L
s
.51315 .94824 m
.51315 .94824 L
s
.51315 .94824 m
.51316 .94821 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51182 .95516 m
.51315 .94823 L
s
.51315 .94823 m
.51315 .94823 L
s
.51315 .94823 m
.51315 .94823 L
s
.51315 .94823 m
.51315 .94823 L
s
.51315 .94823 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51148 .95467 m
.51315 .94822 L
s
.51315 .94822 m
.51315 .94822 L
s
.51315 .94822 m
.51315 .94822 L
s
.51315 .94822 m
.51315 .94822 L
s
.51315 .94822 m
.51316 .9482 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51148 .95467 m
.51315 .94822 L
s
.51315 .94822 m
.51315 .94821 L
s
.51315 .94821 m
.51315 .94821 L
s
.51315 .94821 m
.51315 .94821 L
s
.51315 .94821 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51116 .95413 m
.51315 .94821 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51116 .95413 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51086 .95356 m
.51315 .9482 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51086 .95356 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51217 .95002 m
.51298 .94852 L
s
.51298 .94852 m
.51315 .94821 L
s
.51315 .94821 m
.51315 .94821 L
s
.51315 .94821 m
.51315 .94821 L
s
.51315 .94821 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51221 .94995 m
.51315 .9482 L
s
.51315 .9482 m
.51315 .9482 L
s
.51315 .9482 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51051 .95276 m
.51308 .94832 L
s
.51308 .94832 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51051 .95276 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94818 L
s
.51028 .95214 m
.51316 .94818 L
s
.51028 .95214 m
.51316 .94818 L
s
.51008 .95151 m
.51316 .94818 L
s
.5099 .95087 m
.51316 .94818 L
s
.50977 .95024 m
.51316 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51313 .94819 m
.51315 .94818 L
s
.50967 .9496 m
.51313 .94819 L
s
.50961 .94898 m
.51315 .94818 L
s
.50961 .94898 m
.51314 .94818 L
s
.51286 .94819 m
.51314 .94818 L
s
.51282 .9482 m
.51313 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51312 .9482 m
.51315 .94818 L
s
.50967 .9496 m
.51312 .9482 L
s
.50977 .95024 m
.51316 .94818 L
s
.5099 .95087 m
.51316 .94818 L
s
.51008 .95151 m
.51297 .94839 L
s
.51297 .94839 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51315 .94818 m
.51315 .94818 L
s
.51315 .94818 m
.51316 .94818 L
s
.51314 .94818 m
.51314 .94818 L
s
.51314 .94818 m
.51314 .94818 L
s
.51314 .94818 m
.51315 .94818 L
s
.50958 .94836 m
.51282 .9482 L
s
.50958 .94836 m
.51286 .94819 L
s
.51316 .94818 m .51344 .96751 L .51319 .97566 L 0 .336 .126 r
F
.51316 .94818 m .51328 .95644 L .51344 .96751 L F
0 g
.51335 .9484 m
.51632 .95184 L
s
.51334 .94839 m
.51608 .95157 L
s
.51341 .94847 m
.51632 .95184 L
s
.51338 .94843 m
.51341 .94847 L
s
.51339 .94833 m
.51564 .94989 L
s
.51338 .94833 m
.51339 .94833 L
s
.51338 .94833 m
.51338 .94833 L
s
.5132 .94818 m
.5132 .94818 L
s
.5132 .94818 m
.5132 .94818 L
s
.51321 .94819 m
.51321 .94819 L
s
.51321 .94819 m
.51321 .94819 L
s
.5132 .94822 m
.51321 .94823 L
s
.51321 .94823 m
.51323 .94825 L
s
.51323 .94825 m
.51323 .94825 L
s
.51323 .94826 m
.51324 .94827 L
s
.51324 .94827 m
.51338 .94843 L
s
.51323 .94825 m
.51323 .94826 L
s
.51323 .94825 m
.51323 .94825 L
s
.5132 .94822 m
.5132 .94822 L
s
.5132 .94822 m
.5132 .94822 L
s
.5132 .94822 m
.5132 .94822 L
s
.5132 .94822 m
.5132 .94822 L
s
.51319 .94821 m
.5132 .94822 L
s
.51322 .94824 m
.51322 .94824 L
s
.51322 .94824 m
.51334 .94839 L
s
.51322 .94824 m
.51322 .94824 L
s
.5132 .94823 m
.51321 .94823 L
s
.51321 .94823 m
.51321 .94823 L
s
.51321 .94824 m
.51322 .94824 L
s
.51321 .94823 m
.51321 .94824 L
s
.51321 .94823 m
.51321 .94823 L
s
.51321 .94822 m
.51321 .94822 L
s
.51323 .94824 m
.5159 .95058 L
s
.51321 .94822 m
.51323 .94824 L
s
.51323 .94824 m
.51323 .94824 L
s
.51323 .94824 m
.51323 .94824 L
s
.5132 .94821 m
.5132 .94821 L
s
.5132 .94821 m
.51346 .94839 L
s
.5132 .9482 m
.5132 .9482 L
s
.5132 .9482 m
.51321 .9482 L
s
.5132 .9482 m
.5132 .9482 L
s
.51321 .9482 m
.51321 .9482 L
s
.51321 .9482 m
.51536 .94917 L
s
.51321 .94819 m
.51505 .94845 L
s
.5132 .94818 m
.51505 .94845 L
s
.51322 .9482 m
.51322 .9482 L
s
.51322 .9482 m
.51536 .94917 L
s
.51322 .9482 m
.51322 .9482 L
s
.5132 .94819 m
.51322 .9482 L
s
.5132 .94819 m
.5132 .94819 L
s
.51319 .9482 m
.51338 .94833 L
s
.51319 .9482 m
.51319 .9482 L
s
.51327 .94828 m
.5159 .95058 L
s
.5132 .94821 m
.51327 .94828 L
s
.51327 .94828 m
.51327 .94828 L
s
.51327 .94828 m
.51327 .94828 L
s
.5132 .94821 m
.5132 .94821 L
s
.51321 .94823 m
.51321 .94823 L
s
.51322 .94824 m
.51324 .94827 L
s
.51321 .94823 m
.51322 .94824 L
s
.51324 .94827 m
.51335 .9484 L
s
.51321 .94823 m
.51321 .94823 L
s
.51326 .94828 m
.51612 .95123 L
s
.51326 .94828 m
.51326 .94828 L
s
.51327 .94829 m
.51612 .95123 L
s
.51327 .94829 m
.51327 .94829 L
s
.51321 .94825 m
.51321 .94825 L
s
.51321 .94825 m
.51321 .94826 L
s
.51321 .94825 m
.51321 .94825 L
s
.51321 .94826 m
.51321 .94826 L
s
.51321 .94826 m
.51612 .95279 L
s
.51322 .94827 m
.51322 .94827 L
s
.51322 .94827 m
.51612 .95279 L
s
.5132 .94832 m
.51323 .94843 L
s
.5132 .94832 m
.5132 .94832 L
s
.5132 .94832 m
.5132 .94832 L
s
.51316 .9482 m
.51316 .94822 L
s
.51316 .94822 m
.51316 .94822 L
s
.51316 .94822 m
.51316 .94822 L
s
.51316 .94822 m
.51317 .94893 L
s
.51317 .94893 m
.51328 .95644 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51366 .95653 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51402 .9565 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51438 .95635 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51316 .94819 m
.51317 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .9482 L
s
.51316 .94819 m
.51472 .95606 L
s
.51316 .94818 m
.51505 .95565 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51319 .94827 m
.5132 .94832 L
s
.51317 .94819 m
.51536 .95511 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51564 .95445 L
s
.51319 .94825 m
.51322 .94837 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51564 .95445 L
s
.51317 .94818 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94818 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.5159 .95367 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .9482 L
s
.51317 .94818 m
.51317 .94819 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.5159 .95367 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51322 .94827 L
s
.51318 .9482 m
.51318 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51318 .9482 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .94821 m
.51321 .94825 L
s
.51318 .9482 m
.51318 .94821 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51327 .94829 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51318 .9482 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51326 .94828 L
s
.51317 .94819 m
.51318 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94818 m
.51317 .94819 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51319 .94821 L
s
.51319 .94821 m
.51321 .94823 L
s
.51318 .9482 m
.51318 .9482 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51319 .9482 m
.5132 .94821 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51319 .9482 L
s
.51318 .94819 m
.51318 .94819 L
s
.51317 .94818 m
.51318 .94819 L
s
.51319 .94819 m
.51319 .9482 L
s
.51319 .9482 m
.51319 .9482 L
s
.51319 .9482 m
.51319 .9482 L
s
.51319 .9482 m
.51319 .9482 L
s
.51317 .94819 m
.51319 .94819 L
s
.51318 .94819 m
.5132 .94819 L
s
.51318 .94819 m
.5132 .9482 L
s
.51317 .94818 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.5132 .94821 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51318 .9482 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51318 .9482 m
.51321 .94822 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.5132 .94823 L
s
.51318 .9482 m
.51318 .9482 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .9482 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51318 .9482 L
s
.51318 .9482 m
.51319 .94821 L
s
.51319 .94821 m
.51319 .94821 L
s
.51319 .94821 m
.51319 .94821 L
s
.51319 .94821 m
.51319 .94821 L
s
.51318 .94824 m
.51319 .94826 L
s
.51318 .94824 m
.51318 .94824 L
s
.51318 .94824 m
.51318 .94824 L
s
.51317 .94821 m
.51318 .94824 L
s
.51317 .94821 m
.51317 .94821 L
s
.51317 .94821 m
.51317 .94821 L
s
.51317 .9482 m
.51317 .94821 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .94819 m
.51317 .9482 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51316 .94818 m
.51536 .95511 L
s
.51316 .94818 m
.51505 .95565 L
s
.51317 .94822 m
.5132 .94831 L
s
.51317 .94822 m
.51317 .94822 L
s
.51317 .94822 m
.51317 .94822 L
s
.51317 .94821 m
.51317 .94822 L
s
.51317 .94821 m
.51317 .94821 L
s
.51317 .94821 m
.51317 .94821 L
s
.51317 .9482 m
.51317 .94821 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .94819 m
.51317 .9482 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51316 .9482 m
.51316 .9482 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51472 .95606 L
s
.51316 .94818 m
.51317 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .94819 m
.51316 .94819 L
s
.51317 .94823 m
.51317 .94823 L
s
.51317 .94823 m
.51317 .94823 L
s
.51317 .94823 m
.51317 .94823 L
s
.51317 .94821 m
.51317 .94822 L
s
.51317 .94822 m
.51317 .94822 L
s
.51317 .94822 m
.51317 .94822 L
s
.51317 .94822 m
.51317 .94823 L
s
.51317 .94821 m
.51317 .94821 L
s
.51317 .94821 m
.51317 .94821 L
s
.51317 .94821 m
.51317 .94821 L
s
.51317 .94821 m
.51317 .94821 L
s
.51317 .94821 m
.51317 .94821 L
s
.51317 .9482 m
.51317 .94821 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .9482 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51316 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51316 .94819 m
.51317 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .9482 m
.51316 .94823 L
s
.51316 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94818 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51318 .94819 m
.51318 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94818 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51316 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94819 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94818 m
.51317 .94819 L
s
.51318 .94818 m
.51321 .94819 L
s
.51317 .94818 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51318 .94818 L
s
.51317 .94818 m
.5132 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51318 .94818 L
s
.51318 .94818 m
.51318 .94818 L
s
.51318 .94818 m
.51318 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94819 L
s
.51316 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51318 .94818 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94819 m
.51318 .94819 L
s
.51318 .94818 m
.51318 .94819 L
s
.51317 .94818 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94818 m
.51317 .94819 L
s
.51317 .94818 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94818 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51317 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51317 .94818 m
.51317 .94818 L
s
.51317 .94818 m
.51317 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .9482 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51317 .94819 m
.51317 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51317 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94819 m
.51438 .95635 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .9482 m
.51402 .9565 L
s
.51317 .9482 m
.51317 .9482 L
s
.51317 .9482 m
.51317 .9482 L
s
.51316 .94819 m
.51317 .9482 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94818 L
s
.51317 .94822 m
.51366 .95653 L
s
.51317 .94822 m
.51317 .94822 L
s
.51317 .94822 m
.51317 .94822 L
s
.51316 .94821 m
.51317 .94822 L
s
.51316 .94819 m
.51316 .94821 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94819 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94819 L
s
.51316 .94818 m
.51316 .94818 L
s
.51318 .94902 m
.51328 .95644 L
s
.51316 .94824 m
.51318 .94902 L
s
.51316 .94824 m
.51316 .94824 L
s
.51316 .94824 m
.51316 .94824 L
s
.51316 .9482 m
.51316 .94824 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .9482 m
.51316 .9482 L
s
.51316 .94818 m
.51316 .9482 L
s
.44367 .78446 m
.44865 .78566 L
s
.32609 .79383 m .31613 .79762 L .32019 .79846 L 0 1 .497 r
F
0 g
.32019 .79846 m
.32101 .804 L
s
.5409 .67636 m .55453 .66435 L .54996 .66405 L 0 1 .457 r
F
0 g
.55453 .66435 m
.56057 .65932 L
s
.80672 1.00448 m .81191 1.01338 L .81644 1.00487 L 0 1 .427 r
F
.80672 1.00448 m .80744 1.01635 L .81191 1.01338 L F
0 g
.81191 1.01338 m
.81305 1.01632 L
s
.72177 .60093 m .72174 .59635 L .71834 .59779 L 0 1 .473 r
F
.72177 .60093 m .7305 .59761 L .72174 .59635 L F
0 g
.71326 .59992 m
.72177 .60093 L
s
.42607 .78249 m
.43136 .78274 L
s
.46594 .78536 m .45896 .77789 L .46121 .7833 L 0 1 .42 r
F
.46594 .78536 m .46065 .77159 L .45896 .77789 L F
.46594 .78536 m .46516 .7686 L .46065 .77159 L F
0 g
.46003 .78949 m
.46121 .7833 L
s
.46594 .78536 m .46988 .77066 L .46516 .7686 L 0 1 .42 r
F
.46594 .78536 m .47168 .77641 L .46988 .77066 L F
.46594 .78536 m .46999 .7827 L .47168 .77641 L F
0 g
.46999 .7827 m
.47437 .78537 L
s
.46458 .7917 m
.46594 .78536 L
s
.46121 .7833 m
.46594 .78536 L
s
.74029 1.08188 m .73703 1.08307 L .73776 1.08116 L 0 0 0 r
F
0 g
.73703 1.08307 m
.73776 1.08116 L
s
.73144 1.08395 m
.73776 1.08116 L
s
.49611 .75047 m .50105 .74777 L .50449 .74118 L 0 1 .414 r
F
0 g
.50105 .74777 m
.50444 .74129 L
s
.50105 .74777 m
.505 .75085 L
s
.50726 .93095 m
.50727 .93098 L
s
.50925 .93627 m
.50925 .93627 L
s
.30519 .7324 m .29518 .72484 L .29414 .72981 L 0 .88 .476 r
F
0 g
.28773 .7305 m
.29414 .72981 L
s
.51628 .83265 m
.51779 .82776 L
s
.51624 .83276 m
.51628 .83265 L
s
.51611 .83319 m
.51624 .83276 L
s
.42607 .64802 m .41673 .6499 L .41888 .65015 L 0 1 .345 r
F
0 g
.41524 .65307 m
.41888 .65015 L
s
.42607 .64802 m .42101 .64724 L .41673 .6499 L 0 1 .345 r
F
.42607 .64802 m .42888 .64396 L .42101 .64724 L F
.42607 .64802 m .43608 .64183 L .42888 .64396 L F
.42607 .64802 m .43781 .64228 L .43608 .64183 L F
.42607 .64802 m .43351 .64494 L .43781 .64228 L F
0 g
.42211 .6504 m
.42607 .64802 L
s
.41888 .65015 m
.42607 .64802 L
s
.43351 .64494 m
.43401 .64478 L
s
.43401 .64478 m
.44039 .64282 L
s
.40827 .78187 m
.40989 .78191 L
s
.50267 .91239 m .5029 .90707 L .50112 .89885 L 0 .534 .359 r
F
.50267 .91239 m .50357 .91288 L .5029 .90707 L F
.50791 .93144 m .50357 .91288 L .50267 .91239 L 0 .385 .346 r
F
0 g
.50255 .91208 m
.50267 .91239 L
s
.50267 .91239 m
.50367 .91777 L
s
.50727 .93098 m
.50925 .93627 L
s
.5059 .92542 m
.50726 .93095 L
s
.5059 .92542 m
.50788 .93134 L
s
.43136 .78274 m
.43231 .77655 L
s
.49611 .75047 m .50449 .74118 L .50415 .73511 L 0 1 .414 r
F
0 g
.50449 .74118 m
.50847 .74363 L
s
.50444 .74129 m
.50449 .74118 L
s
.23542 .87659 m .22518 .86976 L .2238 .87456 L 0 1 .521 r
F
.23542 .87659 m .22968 .8669 L .22518 .86976 L F
.23542 .87659 m .23431 .8679 L .22968 .8669 L F
.23542 .87659 m .23676 .87206 L .23431 .8679 L F
0 g
.23092 .87942 m
.23542 .87659 L
s
.23542 .87659 m
.23791 .88052 L
s
.48687 .77271 m .49387 .76375 L .49304 .75732 L 0 1 .407 r
F
0 g
.49387 .76375 m
.49783 .76683 L
s
.49123 .77034 m
.49387 .76375 L
s
.54101 .99516 m .54003 .99341 L .54191 .99421 L 0 .329 0 r
F
0 g
.54003 .99341 m
.54005 .99341 L
s
.54005 .99341 m
.54007 .99342 L
s
.54007 .99342 m
.54021 .99348 L
s
.54021 .99348 m
.5403 .99352 L
s
.5403 .99352 m
.54042 .99357 L
s
.54042 .99357 m
.54052 .99362 L
s
.54052 .99362 m
.54055 .99363 L
s
.54055 .99363 m
.54103 .99384 L
s
.54103 .99384 m
.54123 .99392 L
s
.54123 .99392 m
.54131 .99395 L
s
.54131 .99395 m
.54166 .9941 L
s
.54166 .9941 m
.54176 .99415 L
s
.54176 .99415 m
.54177 .99415 L
s
.54177 .99415 m
.54191 .99421 L
s
.54175 .99405 m
.54191 .99421 L
s
.48687 .77271 m .48128 .76386 L .48261 .76993 L 0 1 .407 r
F
.48687 .77271 m .48393 .75726 L .48128 .76386 L F
.48687 .77271 m .48877 .75454 L .48393 .75726 L F
.48687 .77271 m .49304 .75732 L .48877 .75454 L F
0 g
.48459 .77947 m
.48687 .77271 L
s
.53952 .84139 m .54228 .8453 L .54586 .83417 L 0 .88 .289 r
F
0 g
.54228 .8453 m
.54586 .83417 L
s
.53864 .82677 m
.53952 .84139 L
s
.50824 .96846 m
.50903 .96398 L
s
.52076 .82846 m
.5225 .83787 L
s
.32744 .75002 m .32012 .73937 L .31518 .74049 L 0 .383 .339 r
F
0 g
.31518 .74049 m
.31524 .74378 L
s
.32744 .75002 m .32734 .74234 L .32012 .73937 L 0 .383 .339 r
F
.32744 .75002 m .33201 .74743 L .32734 .74234 L F
.32744 .75002 m .33205 .75072 L .33201 .74743 L F
0 g
.32025 .74705 m
.32744 .75002 L
s
.3914 .66346 m
.39849 .65979 L
s
.6817 .74017 m
.68272 .74464 L
s
.68312 .74636 m
.68757 .76569 L
s
.6817 .74017 m
.68181 .74203 L
s
.292 .58975 m
.29267 .59306 L
s
.50084 .89314 m .50101 .8788 L .49861 .87202 L 0 .653 .359 r
F
0 g
.49861 .87202 m
.49912 .87345 L
s
.49861 .87202 m
.49904 .86559 L
s
.49845 .88635 m
.50066 .89263 L
s
.75255 .67552 m
.75732 .66634 L
s
.75732 .66634 m
.75785 .66531 L
s
.76877 1.05063 m .7721 1.05245 L .77727 1.04573 L 0 1 .213 r
F
.76877 1.05063 m .76775 1.05609 L .7721 1.05245 L F
0 g
.7721 1.05245 m
.77256 1.05256 L
s
.39935 .77856 m
.40173 .77795 L
s
.39875 .77872 m
.39935 .77856 L
s
.39619 .77937 m
.39875 .77872 L
s
.39619 .77937 m
.39619 .77937 L
s
.39618 .77937 m
.39618 .77937 L
s
.39618 .77937 m
.39625 .77856 L
s
.23007 .711 m .22496 .70059 L .21935 .707 L 0 1 .537 r
F
0 g
.21841 .71292 m
.21935 .707 L
s
.23007 .711 m .23231 .69714 L .22496 .70059 L 0 1 .537 r
F
.23007 .711 m .23646 .69898 L .23231 .69714 L F
.23007 .711 m .23549 .70493 L .23646 .69898 L F
0 g
.22276 .71442 m
.23007 .711 L
s
.22926 .71671 m
.23007 .711 L
s
.50147 .87268 m .50341 .85737 L .50097 .85029 L 0 .756 .356 r
F
0 g
.50097 .85029 m
.50143 .85162 L
s
.50097 .85029 m
.50217 .84347 L
s
.27592 .59423 m
.27635 .59317 L
s
.27309 .60113 m
.27592 .59423 L
s
.28064 .5962 m
.28177 .59546 L
s
.27309 .60113 m
.28064 .5962 L
s
.49904 .86559 m
.50133 .87225 L
s
.508 .72825 m .51783 .71351 L .51349 .71185 L 0 1 .424 r
F
0 g
.51783 .71351 m
.52238 .70694 L
s
.51081 .85244 m .50836 .83426 L .5087 .84419 L 0 .836 .34 r
F
0 g
.50836 .83426 m
.51008 .82793 L
s
.50778 .83256 m
.50836 .83426 L
s
.72201 .66975 m
.72232 .66886 L
s
.72369 .66496 m .73306 .65835 L .72561 .66682 L 0 0 .011 r
F
0 g
.72232 .66886 m
.72369 .66496 L
s
.72124 .66831 m
.72369 .66496 L
s
.4762 .77884 m .48043 .77636 L .48261 .76993 L 0 1 .414 r
F
0 g
.48043 .77636 m
.48459 .77947 L
s
.27168 .80266 m .26113 .80637 L .26564 .8071 L 0 1 .531 r
F
0 g
.26564 .8071 m
.26716 .81279 L
s
.64959 .80921 m
.64968 .80967 L
s
.64968 .80967 m
.64982 .81035 L
s
.64982 .81035 m
.65009 .81178 L
s
.65171 .82018 m
.65253 .8244 L
s
.65087 .81581 m
.65171 .82018 L
s
.65046 .81371 m
.65087 .81581 L
s
.65034 .81309 m
.65046 .81371 L
s
.64751 .79842 m
.64759 .79883 L
s
.64675 .79446 m
.64683 .79489 L
s
.64683 .79489 m
.647 .79575 L
s
.647 .79575 m
.64722 .79689 L
s
.64722 .79689 m
.64745 .79808 L
s
.64745 .79808 m
.64751 .79842 L
s
.64638 .78646 m
.64645 .78798 L
s
.64645 .78798 m
.64669 .79316 L
s
.64669 .79316 m
.64675 .79446 L
s
.4762 .77884 m .46988 .77066 L .47168 .77641 L 0 1 .414 r
F
.4762 .77884 m .47206 .76424 L .46988 .77066 L F
0 g
.46999 .7827 m
.47168 .77641 L
s
.4762 .77884 m .47677 .76141 L .47206 .76424 L 0 1 .414 r
F
.4762 .77884 m .48128 .76386 L .47677 .76141 L F
.4762 .77884 m .48261 .76993 L .48128 .76386 L F
0 g
.48043 .77636 m
.48261 .76993 L
s
.47168 .77641 m
.4762 .77884 L
s
.47437 .78537 m
.4762 .77884 L
s
.48261 .76993 m
.48687 .77271 L
s
.25587 .92782 m .2478 .92393 L .24427 .92419 L 0 .574 .241 r
F
.25587 .92782 m .25247 .92504 L .2478 .92393 L F
.25587 .92782 m .25593 .92671 L .25247 .92504 L F
.26751 .93006 m .25593 .92671 L .25587 .92782 L 0 .534 .229 r
F
0 g
.25233 .92808 m
.25587 .92782 L
s
.25587 .92782 m
.25931 .92925 L
s
.68934 .90278 m
.68984 .90253 L
s
.52982 .97951 m
.52998 .97969 L
s
.52708 .97517 m
.52732 .97556 L
s
.52732 .97556 m
.52869 .97785 L
s
.52869 .97785 m
.52933 .97892 L
s
.42061 .92632 m .41173 .92197 L .41639 .92416 L 0 0 0 r
F
.42061 .92632 m .41376 .92289 L .41173 .92197 L F
.41888 .92487 m .41173 .92197 L .40929 .92086 L F
.41376 .92289 m .40905 .92054 L .41173 .92197 L F
.40929 .92086 m .41173 .92197 L .40776 .92021 L F
0 g
.41491 .92312 m
.41821 .92457 L
s
.41888 .92487 m .41639 .92416 L .41173 .92197 L 0 0 0 r
F
.41888 .92487 m .41945 .9254 L .41639 .92416 L F
.43064 .92984 m .41945 .9254 L .41888 .92487 L F
0 g
.41821 .92457 m
.41888 .92487 L
s
.41888 .92487 m
.42199 .92588 L
s
.5225 .83787 m
.52518 .83003 L
s
.45418 .93986 m .44562 .93543 L .45035 .93734 L 0 .19 .007 r
F
0 g
.45381 .9378 m
.45452 .93825 L
s
.45418 .93986 m .44241 .93489 L .44562 .93543 L 0 .19 .007 r
F
0 g
.45035 .93734 m
.45381 .9378 L
s
.44294 .93378 m
.44562 .93543 L
s
.52075 .93381 m .52388 .93339 L .52718 .92632 L 0 .411 .261 r
F
.52075 .93381 m .52113 .9366 L .52388 .93339 L F
0 g
.52075 .93381 m
.52265 .92341 L
s
.51828 .93666 m
.52075 .93381 L
s
.50495 .91376 m .50112 .89885 L .5029 .90707 L 0 .522 .353 r
F
.50495 .91376 m .50084 .89314 L .50112 .89885 L F
0 g
.49897 .89299 m
.50112 .89885 L
s
.58601 .63816 m .58307 .63527 L .58153 .63789 L 0 1 .407 r
F
.58601 .63816 m .59019 .63193 L .58307 .63527 L F
.58601 .63816 m .59812 .63011 L .59019 .63193 L F
0 g
.58153 .63789 m
.58601 .63816 L
s
.57922 .64188 m
.58079 .64102 L
s
.58079 .64102 m
.58601 .63816 L
s
.38352 .77757 m .37408 .77758 L .37765 .78013 L 0 1 .447 r
F
0 g
.37765 .78013 m
.38352 .77757 L
s
.383 .78406 m
.38352 .77757 L
s
.37757 .78656 m
.37765 .78013 L
s
.50791 .93144 m .50558 .9189 L .50357 .91288 L 0 .385 .346 r
F
.50791 .93144 m .50736 .92644 L .50558 .9189 L F
.50791 .93144 m .50836 .93182 L .50736 .92644 L F
0 g
.50791 .93144 m
.50925 .93627 L
s
.50788 .93134 m
.50791 .93144 L
s
.2238 .87456 m .21358 .86746 L .21218 .87254 L 0 1 .523 r
F
.2238 .87456 m .21811 .86439 L .21358 .86746 L F
.2238 .87456 m .22274 .8654 L .21811 .86439 L F
.2238 .87456 m .22518 .86976 L .22274 .8654 L F
0 g
.21928 .8776 m
.2238 .87456 L
s
.2238 .87456 m
.22627 .87869 L
s
.43967 .79232 m .43127 .78962 L .43441 .78995 L 0 .024 0 r
F
0 g
.4343 .7894 m
.43441 .78995 L
s
.6944 .84042 m
.69445 .84021 L
s
.53519 1.10601 m .53179 1.09915 L .52991 1.09441 L 0 .369 0 r
F
0 g
.52991 1.09441 m
.52991 1.09441 L
s
.52811 .83143 m
.52946 .84228 L
s
.40018 .77413 m
.40174 .77795 L
s
.50357 .91288 m
.50364 .91308 L
s
.48934 .94783 m .48114 .94811 L .47753 .94618 L 0 .313 .088 r
F
.48934 .94783 m .48589 .94923 L .48114 .94811 L F
.48934 .94783 m .4894 .94911 L .48589 .94923 L F
.50125 .94939 m .4894 .94911 L .48934 .94783 L 0 .339 .102 r
F
0 g
.48934 .94783 m
.49288 .94744 L
s
.48572 .94589 m
.48934 .94783 L
s
.49765 .9482 m
.50119 .94937 L
s
.50084 .89314 m .50232 .8876 L .50101 .8788 L 0 .653 .359 r
F
.50084 .89314 m .50225 .89375 L .50232 .8876 L F
.50495 .91376 m .50225 .89375 L .50084 .89314 L 0 .522 .353 r
F
0 g
.50066 .89263 m
.50084 .89314 L
s
.50084 .89314 m
.50112 .89885 L
s
.5029 .90707 m
.50357 .91288 L
s
.508 .72825 m .50332 .72133 L .50365 .7266 L 0 1 .424 r
F
.508 .72825 m .50754 .71501 L .50332 .72133 L F
.508 .72825 m .51349 .71185 L .50754 .71501 L F
0 g
.70095 .601 m
.70988 .60133 L
s
.70095 .601 m
.70481 .60343 L
s
.70988 .60133 m
.71307 .60417 L
s
.36846 .78063 m
.36871 .77391 L
s
.36846 .78063 m
.37408 .77758 L
s
.50836 .93182 m
.51004 .93692 L
s
.51004 .93692 m
.51004 .93692 L
s
.52313 .69493 m .53477 .68606 L .53538 .68196 L 0 1 .453 r
F
.52313 .69493 m .52952 .69161 L .53477 .68606 L F
0 g
.53477 .68606 m
.53902 .6864 L
s
.52952 .69161 m
.53383 .6927 L
s
.52952 .69161 m
.53477 .68606 L
s
.41407 .777 m .40503 .77402 L .40834 .77766 L 0 1 .446 r
F
.49611 .75047 m .49094 .74229 L .49178 .74813 L 0 1 .414 r
F
.49611 .75047 m .49439 .7357 L .49094 .74229 L F
.49611 .75047 m .49982 .73275 L .49439 .7357 L F
.49611 .75047 m .50415 .73511 L .49982 .73275 L F
0 g
.50415 .73511 m
.508 .72825 L
s
.49304 .75732 m
.49611 .75047 L
s
.73925 .5942 m .75703 .59942 L .76077 .59828 L 0 1 .501 r
F
.73925 .5942 m .74782 .59768 L .75703 .59942 L F
0 g
.75703 .59942 m
.75981 .60332 L
s
.62283 .69405 m
.62834 .70141 L
s
.62834 .70141 m
.62864 .70182 L
s
.62864 .70182 m
.62955 .70304 L
s
.28284 .80445 m .27522 .79599 L .27168 .80266 L 0 1 .526 r
F
.28284 .80445 m .28117 .79153 L .27522 .79599 L F
.28284 .80445 m .28554 .79227 L .28117 .79153 L F
.28284 .80445 m .28625 .79781 L .28554 .79227 L F
0 g
.27691 .80888 m
.28284 .80445 L
s
.28284 .80445 m
.28367 .80996 L
s
.51035 .82935 m .5075 .83834 L .50785 .83124 L 0 .608 .101 r
F
.51035 .82935 m .50986 .84862 L .5075 .83834 L F
0 g
.50652 .82554 m
.50785 .83124 L
s
.51081 .85244 m .51528 .84617 L .51544 .83535 L 0 .836 .34 r
F
.51081 .85244 m .5133 .8535 L .51528 .84617 L F
.51128 .87774 m .5133 .8535 L .51081 .85244 L 0 .714 .335 r
F
.51128 .87774 m .51504 .86218 L .5133 .8535 L F
.51035 .82935 m .51335 .85522 L .50986 .84862 L 0 .608 .101 r
F
.51035 .82935 m .51586 .85329 L .51335 .85522 L F
0 g
.5159 .83386 m
.51611 .83319 L
s
.51438 .83122 m
.51477 .83274 L
s
.51702 .8556 m .51544 .83535 L .51528 .84617 L 0 .814 .327 r
F
.51035 .82935 m .51569 .84416 L .51586 .85329 L 0 .608 .101 r
F
.51035 .82935 m .51333 .83391 L .51569 .84416 L F
0 g
.51333 .83391 m
.51438 .8312 L
s
.51008 .82793 m
.51035 .82935 L
s
.50785 .83124 m
.51035 .82935 L
s
.51544 .83535 m
.5159 .83386 L
s
.51477 .83274 m
.51544 .83535 L
s
.44983 .77946 m .44195 .77348 L .44463 .77828 L 0 1 .433 r
F
.44983 .77946 m .44344 .76725 L .44195 .77348 L F
.44983 .77946 m .44813 .76374 L .44344 .76725 L F
0 g
.44456 .77872 m
.44459 .77853 L
s
.44367 .78446 m
.44456 .77872 L
s
.44459 .77853 m
.44463 .77828 L
s
.44983 .77946 m .45333 .76493 L .44813 .76374 L 0 1 .433 r
F
.44983 .77946 m .45559 .77002 L .45333 .76493 L F
.44983 .77946 m .45409 .77625 L .45559 .77002 L F
0 g
.44865 .78566 m
.44983 .77946 L
s
.44463 .77828 m
.44983 .77946 L
s
.6465 .76619 m
.64779 .77046 L
s
.64625 .76534 m
.6465 .76619 L
s
.64499 .76116 m
.64625 .76534 L
s
.6449 .76089 m
.64499 .76116 L
s
.64368 .7528 m
.64476 .75991 L
s
.64476 .75991 m
.6449 .76089 L
s
.50125 .94939 m .493 .9503 L .4894 .94911 L 0 .339 .102 r
F
.50125 .94939 m .49775 .95061 L .493 .9503 L F
.50125 .94939 m .50128 .95022 L .49775 .95061 L F
0 g
.50119 .94937 m
.50125 .94939 L
s
.50125 .94939 m
.50481 .94859 L
s
.51626 .83287 m
.51629 .83299 L
s
.68845 .65855 m .69742 .6652 L .68899 .64427 L 0 .316 .303 r
F
0 g
.68655 .64739 m
.68845 .65855 L
s
.68731 .65537 m
.68845 .65855 L
s
.50869 .97026 m .50613 .98267 L .50779 .97635 L 0 .276 .263 r
F
.50985 .97468 m .50613 .98267 L .5056 .98974 L 0 .263 .258 r
F
.50985 .97468 m .50779 .97635 L .50613 .98267 L F
0 g
.50422 .98505 m
.50613 .98267 L
s
.64678 .79566 m
.64678 .80509 L
s
.41407 .777 m .40604 .76761 L .40503 .77402 L 0 1 .446 r
F
.41407 .777 m .41071 .76269 L .40604 .76761 L F
.41407 .777 m .41645 .76203 L .41071 .76269 L F
.41407 .777 m .41942 .76607 L .41645 .76203 L F
.41407 .777 m .4184 .77249 L .41942 .76607 L F
0 g
.4134 .78245 m
.41407 .777 L
s
.40834 .77766 m
.41407 .777 L
s
.26751 .93006 m .25948 .92673 L .25593 .92671 L 0 .534 .229 r
F
.26751 .93006 m .26415 .92787 L .25948 .92673 L F
.26751 .93006 m .26759 .9293 L .26415 .92787 L F
.27916 .93238 m .26759 .9293 L .26751 .93006 L 0 .486 .215 r
F
0 g
.26397 .93004 m
.26751 .93006 L
s
.26751 .93006 m
.27095 .93125 L
s
.50464 .85073 m .5071 .85125 L .5087 .84419 L 0 .855 .352 r
F
.50634 .87461 m .50464 .85073 L .50341 .85737 L 0 .736 .346 r
F
.50634 .87461 m .5071 .85125 L .50464 .85073 L F
0 g
.50217 .84347 m
.50464 .85073 L
s
.32609 .79383 m .31608 .79177 L .31613 .79762 L 0 1 .497 r
F
0 g
.31076 .80196 m
.31613 .79762 L
s
.35515 .78247 m .34531 .78539 L .34915 .78682 L 0 1 .462 r
F
0 g
.34915 .78682 m
.34945 .79287 L
s
.21218 .87254 m .20199 .86515 L .20056 .87052 L 0 1 .525 r
F
.21218 .87254 m .20654 .86187 L .20199 .86515 L F
.21218 .87254 m .21117 .86288 L .20654 .86187 L F
.21218 .87254 m .21358 .86746 L .21117 .86288 L F
0 g
.20764 .87578 m
.21218 .87254 L
s
.21218 .87254 m
.21463 .87687 L
s
.50439 .89491 m .50101 .8788 L .50232 .8876 L 0 .635 .351 r
F
.50439 .89491 m .50147 .87268 L .50101 .8788 L F
0 g
.49912 .87345 m
.50101 .8788 L
s
.49982 .73275 m
.50415 .73511 L
s
.59019 .63193 m .60553 .6271 L .60751 .62491 L 0 1 .441 r
F
.59019 .63193 m .59812 .63011 L .60553 .6271 L F
0 g
.60553 .6271 m
.60967 .62766 L
s
.59812 .63011 m
.60257 .63039 L
s
.59812 .63011 m
.60553 .6271 L
s
.50905 .93244 m .50558 .9189 L .50736 .92644 L 0 .383 .343 r
F
.50905 .93244 m .50495 .91376 L .50558 .9189 L F
0 g
.50364 .91308 m
.50558 .9189 L
s
.50736 .92644 m
.50836 .93182 L
s
.29518 .72484 m .28391 .72342 L .28801 .72593 L 0 1 .502 r
F
0 g
.28773 .7305 m
.28801 .72593 L
s
.52946 .84228 m
.53245 .83427 L
s
.50634 .87461 m .50341 .85737 L .50424 .86675 L 0 .736 .346 r
F
.50147 .87268 m .50424 .86675 L .50341 .85737 L 0 .756 .356 r
F
0 g
.50143 .85162 m
.50341 .85737 L
s
.50341 .85737 m
.50464 .85073 L
s
.34816 .67938 m
.35019 .67477 L
s
.34815 .67941 m
.34816 .67938 L
s
.50147 .87268 m .50341 .87331 L .50424 .86675 L 0 .756 .356 r
F
.50439 .89491 m .50341 .87331 L .50147 .87268 L 0 .635 .351 r
F
0 g
.50133 .87225 m
.50147 .87268 L
s
.50101 .8788 m
.50147 .87268 L
s
.45409 .77625 m
.45896 .77789 L
s
.32609 .79383 m .32008 .7848 L .31608 .79177 L 0 1 .497 r
F
0 g
.31608 .79177 m
.31613 .79762 L
s
.32609 .79383 m .32599 .78016 L .32008 .7848 L 0 1 .497 r
F
.32609 .79383 m .32987 .78095 L .32599 .78016 L F
.32609 .79383 m .32991 .78681 L .32987 .78095 L F
0 g
.32609 .79383 m
.32627 .79983 L
s
.32019 .79846 m
.32609 .79383 L
s
.5244 .96999 m
.52449 .97015 L
s
.27168 .80266 m .26049 .8008 L .26113 .80637 L 0 1 .531 r
F
0 g
.25581 .81108 m
.26113 .80637 L
s
.52629 1.08888 m .52737 1.09048 L .52844 1.0925 L 0 .306 0 r
F
.52629 1.08888 m .52601 1.08789 L .52737 1.09048 L F
0 g
.52714 1.08939 m
.52737 1.09048 L
s
.52167 .94084 m .52718 .92632 L .52388 .93339 L 0 .369 .258 r
F
.52167 .94084 m .53017 .92649 L .52718 .92632 L F
0 g
.52718 .92632 m
.52907 .91592 L
s
.75999 .67277 m
.76181 .66305 L
s
.43967 .79232 m .43212 .79141 L .43127 .78962 L 0 .024 0 r
F
.43967 .79232 m .4364 .79414 L .43212 .79141 L F
.43967 .79232 m .44168 .79651 L .4364 .79414 L F
.43967 .79232 m .44442 .79694 L .44168 .79651 L F
.43967 .79232 m .44355 .79514 L .44442 .79694 L F
0 g
.43937 .79117 m
.43967 .79232 L
s
.43441 .78995 m
.43967 .79232 L
s
.43064 .92984 m .42338 .92748 L .41945 .9254 L 0 0 0 r
F
.43064 .92984 m .42803 .92972 L .42338 .92748 L F
.43064 .92984 m .43115 .93073 L .42803 .92972 L F
.44241 .93489 m .43115 .93073 L .43064 .92984 L 0 .092 0 r
F
0 g
.42672 .92776 m
.43064 .92984 L
s
.43064 .92984 m
.43381 .93062 L
s
.80006 .81234 m .80885 .80295 L .81344 .80271 L 0 0 0 r
F
.80006 .81234 m .80312 .80706 L .80885 .80295 L F
0 g
.80675 .80017 m
.80885 .80295 L
s
.50869 .97026 m
.50979 .9663 L
s
.43231 .77655 m .42387 .7722 L .42683 .77632 L 0 1 .441 r
F
.43231 .77655 m .42519 .76602 L .42387 .7722 L F
0 g
.42607 .78249 m
.42678 .77674 L
s
.43231 .77655 m .42992 .7619 L .42519 .76602 L 0 1 .441 r
F
0 g
.42678 .77674 m
.42683 .77632 L
s
.43231 .77655 m .43541 .76213 L .42992 .7619 L 0 1 .441 r
F
.43231 .77655 m .438 .76656 L .43541 .76213 L F
.43231 .77655 m .43667 .77274 L .438 .76656 L F
0 g
.42683 .77632 m
.43231 .77655 L
s
.51086 .93773 m
.51086 .93773 L
s
.53519 1.10601 m .53827 1.10705 L .54016 1.11181 L 0 .369 0 r
F
0 g
.59305 1.02926 m
.59444 1.08653 L
s
.59539 1.12564 m
.59721 1.20049 L
s
.59721 1.20049 m
.5973 1.20435 L
s
.5973 1.20435 m
.59742 1.20926 L
s
.59742 1.20926 m
.59768 1.22018 L
s
.5906 .92853 m
.59082 .9376 L
s
.59142 .96234 m
.59152 .96627 L
s
.59768 1.22018 m
.59781 1.22557 L
s
.59821 1.24183 m
.59851 1.25438 L
s
.59781 1.22557 m
.59821 1.24183 L
s
.47117 .80643 m .46448 .80498 L .46678 .80415 L 0 .264 .016 r
F
0 g
.4662 .80194 m
.46678 .80415 L
s
.47117 .80643 m .46576 .80864 L .46448 .80498 L 0 .264 .016 r
F
.47117 .80643 m .46978 .8127 L .46576 .80864 L F
.47117 .80643 m .47419 .81498 L .46978 .8127 L F
.47117 .80643 m .47603 .81397 L .47419 .81498 L F
.47117 .80643 m .47473 .81031 L .47603 .81397 L F
0 g
.4706 .80391 m
.47117 .80643 L
s
.46678 .80415 m
.47117 .80643 L
s
.50905 .93244 m .50588 .91445 L .50495 .91376 L 0 .383 .343 r
F
.50905 .93244 m .50757 .92045 L .50588 .91445 L F
.50905 .93244 m .50889 .92777 L .50757 .92045 L F
.50905 .93244 m .50952 .93291 L .50889 .92777 L F
0 g
.50905 .93244 m
.51004 .93692 L
s
.50736 .92644 m
.50905 .93244 L
s
.50952 .93291 m
.51086 .93773 L
s
.53669 .98867 m
.53716 .98934 L
s
.53716 .98934 m
.53721 .98941 L
s
.53721 .98941 m
.53754 .98987 L
s
.53918 .9922 m
.54003 .99341 L
s
.53909 .99207 m
.53918 .9922 L
s
.53903 .99199 m
.53909 .99207 L
s
.53756 .9899 m
.53903 .99199 L
s
.64638 .78646 m
.64835 .79301 L
s
.65069 .80078 m
.65094 .80161 L
s
.6523 .80614 m
.65252 .80689 L
s
.65201 .80516 m
.6523 .80614 L
s
.50495 .91376 m .50429 .90043 L .50225 .89375 L 0 .522 .353 r
F
0 g
.50225 .89375 m
.50241 .89429 L
s
.50225 .89375 m
.50232 .8876 L
s
.53051 .98053 m
.53072 .9808 L
s
.53072 .9808 m
.53078 .98088 L
s
.53129 .98157 m
.53132 .9816 L
s
.53132 .9816 m
.53177 .9822 L
s
.53177 .9822 m
.53181 .98225 L
s
.53181 .98225 m
.53181 .98225 L
s
.53216 .98272 m
.53253 .9832 L
s
.53268 .98341 m
.53311 .98398 L
s
.53005 .97992 m
.53021 .98013 L
s
.53021 .98013 m
.53051 .98053 L
s
.52798 .97616 m
.52975 .97937 L
s
.52975 .97937 m
.53005 .97992 L
s
.50985 .97468 m .5056 .98974 L .50653 .99287 L 0 .263 .258 r
F
0 g
.5056 .98974 m
.50613 .98267 L
s
.50366 .99059 m
.5056 .98974 L
s
.54782 1.12486 m .54403 1.11755 L .54221 1.11177 L 0 .427 .024 r
F
0 g
.53827 1.10705 m
.54221 1.11177 L
s
.50653 .99287 m .50516 1.00437 L .50635 .99914 L 0 .238 .258 r
F
.50892 1.00063 m .50516 1.00437 L .50536 1.0114 L 0 .214 .247 r
F
.50892 1.00063 m .50635 .99914 L .50516 1.00437 L F
0 g
.50323 1.00521 m
.50516 1.00437 L
s
.40008 .77964 m
.4017 .77968 L
s
.35515 .78247 m .34573 .77843 L .34531 .78539 L 0 1 .462 r
F
0 g
.3397 .78949 m
.34531 .78539 L
s
.35515 .78247 m .35014 .77059 L .34573 .77843 L 0 1 .462 r
F
.35515 .78247 m .35615 .76623 L .35014 .77059 L F
.35515 .78247 m .35975 .76827 L .35615 .76623 L F
.35515 .78247 m .35932 .77523 L .35975 .76827 L F
0 g
.3549 .78918 m
.35515 .78247 L
s
.34915 .78682 m
.35515 .78247 L
s
.58707 1.10322 m
.58772 1.12672 L
s
.58656 1.08479 m
.58707 1.10322 L
s
.58512 1.03297 m
.58656 1.08479 L
s
.58502 1.02959 m
.58512 1.03297 L
s
.58808 1.13966 m
.58813 1.14136 L
s
.58772 1.12672 m
.58808 1.13966 L
s
.58813 1.14136 m
.58828 1.14686 L
s
.50634 .87461 m .5092 .8591 L .5071 .85125 L 0 .736 .346 r
F
0 g
.5071 .85125 m
.5087 .84419 L
s
.20056 .87052 m .19038 .86284 L .18893 .8685 L 0 1 .527 r
F
.20056 .87052 m .19496 .85934 L .19038 .86284 L F
0 g
.18893 .8685 m
.19133 .87326 L
s
.20056 .87052 m .19959 .86035 L .19496 .85934 L 0 1 .527 r
F
.20056 .87052 m .20199 .86515 L .19959 .86035 L F
0 g
.19599 .87398 m
.20056 .87052 L
s
.20056 .87052 m
.20298 .87506 L
s
.52113 .9366 m
.52388 .93339 L
s
.51894 .94153 m
.52113 .9366 L
s
.46597 .9445 m .45745 .94014 L .46219 .94196 L 0 .258 .042 r
F
0 g
.46566 .94224 m
.46613 .94253 L
s
.46597 .9445 m .45418 .93986 L .45745 .94014 L 0 .258 .042 r
F
0 g
.45452 .93825 m
.45745 .94014 L
s
.46219 .94196 m
.46566 .94224 L
s
.5409 .67636 m .53692 .6723 L .53631 .67607 L 0 1 .457 r
F
.5409 .67636 m .54278 .66715 L .53692 .6723 L F
.5409 .67636 m .54996 .66405 L .54278 .66715 L F
.50495 .91376 m .5056 .90873 L .50429 .90043 L 0 .522 .353 r
F
.50495 .91376 m .50588 .91445 L .5056 .90873 L F
0 g
.50495 .91376 m
.50558 .9189 L
s
.5029 .90707 m
.50495 .91376 L
s
.50985 .97468 m .50938 .97293 L .50779 .97635 L 0 .263 .258 r
F
0 g
.50779 .97635 m
.50938 .97293 L
s
.50779 .97635 m
.50869 .97026 L
s
.50938 .97293 m
.50942 .97249 L
s
.50486 .95004 m
.50486 .95004 L
s
.50128 .95022 m
.50486 .95004 L
s
.40018 .77412 m .39343 .7696 L .39671 .77288 L 0 1 .447 r
F
.40018 .77412 m .39206 .7658 L .39343 .7696 L F
.40018 .77412 m .3935 .76402 L .39206 .7658 L F
.40018 .77412 m .39697 .76526 L .3935 .76402 L F
0 g
.39629 .77804 m
.39671 .77288 L
s
.39671 .77288 m
.39671 .77288 L
s
.40018 .77412 m .40015 .76871 L .39697 .76526 L 0 1 .447 r
F
.40018 .77412 m .40152 .77251 L .40015 .76871 L F
0 g
.39671 .77288 m
.40018 .77412 L
s
.53531 .83667 m
.53625 .84929 L
s
.27916 .93238 m .27115 .9296 L .26759 .9293 L 0 .486 .215 r
F
.27916 .93238 m .27582 .93077 L .27115 .9296 L F
.27916 .93238 m .27925 .93197 L .27582 .93077 L F
0 g
.2756 .93208 m
.27916 .93238 L
s
.40153 .77251 m
.40502 .77402 L
s
.40503 .77402 m
.40539 .7717 L
s
.75508 .81892 m .76897 .80875 L .76633 .81803 L 0 .188 .072 r
F
0 g
.76747 .80123 m
.76897 .80875 L
s
.76897 .80875 m
.77438 .80216 L
s
.52262 .94922 m
.52494 .94887 L
s
.52494 .94887 m
.52495 .94887 L
s
.52271 .95002 m
.52274 .95003 L
s
.48393 .75726 m .48877 .75454 L .49178 .74813 L 0 1 .42 r
F
0 g
.48877 .75454 m
.49304 .75732 L
s
.5745 .64167 m
.57922 .64188 L
s
.5068 1.01554 m .50666 1.02609 L .50736 1.02184 L 0 .185 .241 r
F
.51045 1.02596 m .50666 1.02609 L .5076 1.03299 L 0 .141 .218 r
F
.51045 1.02596 m .50736 1.02184 L .50666 1.02609 L F
0 g
.50469 1.02564 m
.50666 1.02609 L
s
.5244 .96998 m
.52449 .97015 L
s
.82935 .9893 m .84067 .98284 L .83858 .97806 L 0 1 .46 r
F
.80672 1.00448 m .80522 1.01255 L .80744 1.01635 L 0 1 .427 r
F
0 g
.80198 1.0234 m
.80744 1.01635 L
s
.61492 .62249 m .61356 .61825 L .61095 .62112 L 0 1 .411 r
F
.61492 .62249 m .62185 .61568 L .61356 .61825 L F
.61492 .62249 m .63026 .61511 L .62185 .61568 L F
.50892 1.00063 m .50536 1.0114 L .5068 1.01554 L 0 .214 .247 r
F
0 g
.50516 1.00437 m
.50536 1.0114 L
s
.50339 1.01096 m
.50536 1.0114 L
s
.50439 .89491 m .50548 .88062 L .50341 .87331 L 0 .635 .351 r
F
0 g
.50341 .87331 m
.50371 .87437 L
s
.50341 .87331 m
.50424 .86675 L
s
.50424 .86675 m
.50611 .87375 L
s
.29518 .72484 m .28513 .71797 L .28391 .72342 L 0 1 .502 r
F
0 g
.27734 .72474 m
.28391 .72342 L
s
.53148 .9819 m
.53168 .98216 L
s
.53168 .98216 m
.53195 .9825 L
s
.53226 .9829 m
.53259 .98332 L
s
.53274 .9835 m
.53312 .98399 L
s
.35019 .67477 m .33899 .67102 L .34249 .67163 L 0 .319 .235 r
F
.31518 .74049 m .31041 .72964 L .30519 .7324 L 0 .61 .428 r
F
.31518 .74049 m .31719 .73085 L .31041 .72964 L F
.31518 .74049 m .32099 .73524 L .31719 .73085 L F
.31518 .74049 m .32012 .73937 L .32099 .73524 L F
0 g
.30843 .73927 m
.31518 .74049 L
s
.50955 1.03794 m .51065 1.04747 L .51086 1.04415 L 0 .104 .201 r
F
.51447 1.05055 m .51065 1.04747 L .51233 1.05416 L 0 .03 .161 r
F
.51447 1.05055 m .51086 1.04415 L .51065 1.04747 L F
0 g
.50866 1.04588 m
.51065 1.04747 L
s
.51171 .93869 m
.51171 .93869 L
s
.3894 .52558 m .37737 .52943 L .37971 .53003 L 0 1 .368 r
F
0 g
.37397 .53643 m
.37971 .53003 L
s
.3894 .52558 m .38389 .52419 L .37737 .52943 L 0 1 .368 r
F
.3894 .52558 m .39494 .5178 L .38389 .52419 L F
.3894 .52558 m .40465 .51334 L .39494 .5178 L F
.3894 .52558 m .40653 .51379 L .40465 .51334 L F
.3894 .52558 m .39999 .51904 L .40653 .51379 L F
0 g
.38322 .53079 m
.3894 .52558 L
s
.37971 .53003 m
.3894 .52558 L
s
.39999 .51904 m
.40935 .5143 L
s
.40015 .76871 m
.40152 .77251 L
s
.52974 .97913 m
.53108 .98139 L
s
.7519 .64668 m .76845 .63667 L .76137 .64138 L 0 0 0 r
F
0 g
.76845 .63667 m
.77073 .63421 L
s
.76845 .63667 m
.77646 .63229 L
s
.64766 .76221 m
.64879 .76489 L
s
.64368 .7528 m
.64766 .76221 L
s
.46065 .77159 m .45333 .76493 L .45559 .77002 L 0 1 .429 r
F
.46065 .77159 m .45535 .75866 L .45333 .76493 L F
.46065 .77159 m .46031 .7554 L .45535 .75866 L F
0 g
.45545 .7706 m
.45551 .77035 L
s
.45409 .77625 m
.45545 .7706 L
s
.45551 .77035 m
.45559 .77002 L
s
.46065 .77159 m .46538 .75698 L .46031 .7554 L 0 1 .429 r
F
.46065 .77159 m .46719 .76234 L .46538 .75698 L F
.46065 .77159 m .46516 .7686 L .46719 .76234 L F
0 g
.45896 .77789 m
.46065 .77159 L
s
.45559 .77002 m
.46065 .77159 L
s
.46551 .76875 m
.46988 .77066 L
s
.46516 .7686 m
.46551 .76875 L
s
.51045 1.02596 m .5076 1.03299 L .50955 1.03794 L 0 .141 .218 r
F
0 g
.50666 1.02609 m
.5076 1.03299 L
s
.50561 1.03142 m
.5076 1.03299 L
s
.50731 .91564 m .50429 .90043 L .5056 .90873 L 0 .51 .347 r
F
.50731 .91564 m .50439 .89491 L .50429 .90043 L F
0 g
.50241 .89429 m
.50429 .90043 L
s
.5056 .90873 m
.50588 .91445 L
s
.50588 .91445 m
.50594 .91465 L
s
.4184 .77249 m
.42387 .7722 L
s
.48393 .75726 m .47797 .7495 L .4793 .7551 L 0 1 .42 r
F
.48393 .75726 m .48098 .74308 L .47797 .7495 L F
.48393 .75726 m .48631 .74012 L .48098 .74308 L F
.48393 .75726 m .49094 .74229 L .48631 .74012 L F
.48393 .75726 m .49178 .74813 L .49094 .74229 L F
0 g
.48877 .75454 m
.49173 .74824 L
s
.48128 .76386 m
.48393 .75726 L
s
.49178 .74813 m
.49611 .75047 L
s
.49173 .74824 m
.49178 .74813 L
s
.44195 .77348 m
.44344 .76725 L
s
.43667 .77274 m
.44195 .77348 L
s
.51024 .93366 m .50757 .92045 L .50889 .92777 L 0 .382 .341 r
F
0 g
.50889 .92777 m
.50952 .93291 L
s
.45614 .79966 m .44853 .79722 L .45126 .79717 L 0 .15 0 r
F
0 g
.45081 .79547 m
.45126 .79717 L
s
.37212 .77091 m .36549 .76868 L .36521 .7683 L 0 0 0 r
F
.37481 .77066 m .36607 .76405 L .36549 .76868 L 0 1 .441 r
F
.37212 .77091 m .36549 .76868 L .36513 .77156 L F
.37481 .77066 m .36549 .76868 L .37212 .77091 L F
.37478 .77191 m .36595 .76928 L .36549 .76868 L 0 0 0 r
F
.37478 .77191 m .36549 .76868 L .37212 .77091 L F
0 g
.36521 .7683 m
.36549 .76868 L
s
.35954 .76632 m
.36521 .7683 L
s
.37468 .77187 m
.37468 .77181 L
s
.37408 .77758 m
.37468 .77188 L
s
.37468 .77181 m
.37469 .77178 L
s
.37469 .77178 m
.37469 .77177 L
s
.37422 .77113 m
.37469 .77178 L
s
.37469 .77178 m
.37469 .77178 L
s
.51479 1.05977 m .51712 1.06818 L .51685 1.06579 L 0 0 .154 r
F
.52094 1.07424 m .51712 1.06818 L .51953 1.07458 L 0 0 .129 r
F
.52094 1.07424 m .51685 1.06579 L .51712 1.06818 L F
0 g
.51512 1.06556 m
.51712 1.06818 L
s
.50754 .71501 m .51806 .70587 L .51822 .70105 L 0 1 .441 r
F
.50754 .71501 m .51349 .71185 L .51806 .70587 L F
0 g
.51806 .70587 m
.52238 .70694 L
s
.51349 .71185 m
.51783 .71351 L
s
.51349 .71185 m
.51806 .70587 L
s
.51024 .93366 m .50731 .91564 L .50757 .92045 L 0 .382 .341 r
F
.51024 .93366 m .50828 .91654 L .50731 .91564 L F
0 g
.50594 .91465 m
.50699 .91838 L
s
.50699 .91838 m
.50757 .92045 L
s
.51024 .93366 m .50963 .92244 L .50828 .91654 L 0 .382 .341 r
F
.51024 .93366 m .51046 .9294 L .50963 .92244 L F
.51024 .93366 m .51072 .93421 L .51046 .9294 L F
0 g
.51024 .93366 m
.51086 .93773 L
s
.50889 .92777 m
.51024 .93366 L
s
.51072 .93421 m
.51171 .93869 L
s
.44241 .93489 m .43502 .93308 L .43115 .93073 L 0 .092 0 r
F
.44241 .93489 m .43968 .93531 L .43502 .93308 L F
.44241 .93489 m .44285 .93609 L .43968 .93531 L F
.45418 .93986 m .44285 .93609 L .44241 .93489 L 0 .19 .007 r
F
0 g
.43853 .93255 m
.44241 .93489 L
s
.44241 .93489 m
.44562 .93543 L
s
.51447 1.05055 m .51233 1.05416 L .51479 1.05977 L 0 .03 .161 r
F
0 g
.51065 1.04747 m
.51233 1.05416 L
s
.51033 1.05156 m
.51233 1.05416 L
s
.51128 .87774 m .51081 .85244 L .5092 .8591 L 0 .714 .335 r
F
0 g
.5087 .84419 m
.51081 .85244 L
s
.33278 .66963 m .32484 .67091 L .3285 .66995 L 0 0 0 r
F
.33278 .66963 m .32372 .67116 L .32484 .67091 L F
.33278 .66963 m .32589 .67054 L .32372 .67116 L F
.33278 .66963 m .33018 .67022 L .32589 .67054 L F
.33278 .66963 m .33371 .67041 L .33018 .67022 L F
.33278 .66963 m .33482 .67016 L .33371 .67041 L F
0 g
.33278 .66963 m
.33412 .66384 L
s
.3285 .66995 m
.33278 .66963 L
s
.53017 .92649 m .53777 .92807 L .5397 .91266 L 0 .407 .252 r
F
0 g
.5397 .91266 m
.54321 .91225 L
s
.38778 .77161 m
.39343 .7696 L
s
.67274 .91531 m
.67331 .9146 L
s
.80006 .81234 m .81344 .80271 L .81451 .80565 L 0 0 0 r
F
0 g
.81344 .80271 m
.8183 .80027 L
s
.52313 .69493 m .53538 .68196 L .53071 .68128 L 0 1 .453 r
F
0 g
.53538 .68196 m
.5409 .67636 L
s
.52629 1.08888 m .52844 1.0925 L .52856 1.09293 L 0 .306 0 r
F
0 g
.52844 1.0925 m
.52991 1.09441 L
s
.6709 1.12574 m .66698 1.11835 L .66676 1.11086 L 0 .241 .083 r
F
0 g
.66676 1.11086 m
.66698 1.11835 L
s
.6644 1.10964 m
.66676 1.11086 L
s
.52244 .96621 m .52935 .97808 L .52554 .97144 L 0 .093 .182 r
F
0 g
.52798 .97616 m
.52974 .97913 L
s
.30148 .58388 m .28849 .58824 L .29201 .58975 L 0 1 .5 r
F
.47776 .94844 m .46929 .94451 L .47403 .94609 L 0 .302 .069 r
F
0 g
.47753 .94618 m
.4778 .94632 L
s
.47776 .94844 m .46597 .9445 L .46929 .94451 L 0 .302 .069 r
F
0 g
.46613 .94253 m
.46929 .94451 L
s
.47403 .94609 m
.47753 .94618 L
s
.45614 .79966 m .44962 .79979 L .44853 .79722 L 0 .15 0 r
F
.45614 .79966 m .45383 .80317 L .44962 .79979 L F
.45614 .79966 m .45872 .80568 L .45383 .80317 L F
.45614 .79966 m .46103 .80563 L .45872 .80568 L F
.45614 .79966 m .45991 .80305 L .46103 .80563 L F
0 g
.45552 .79724 m
.45614 .79966 L
s
.45126 .79717 m
.45614 .79966 L
s
.426 .78764 m
.43127 .78962 L
s
.50439 .89491 m .50631 .88972 L .50548 .88062 L 0 .635 .351 r
F
.50439 .89491 m .50584 .89585 L .50631 .88972 L F
.50731 .91564 m .50584 .89585 L .50439 .89491 L 0 .51 .347 r
F
0 g
.50232 .8876 m
.50439 .89491 L
s
.50429 .90043 m
.50439 .89491 L
s
.47206 .76424 m .47677 .76141 L .4793 .7551 L 0 1 .425 r
F
0 g
.47677 .76141 m
.48128 .76386 L
s
.49439 .7357 m .49982 .73275 L .50365 .7266 L 0 1 .429 r
F
0 g
.49982 .73275 m
.50326 .72723 L
s
.47206 .76424 m .46538 .75698 L .46719 .76234 L 0 1 .425 r
F
.47206 .76424 m .46791 .75066 L .46538 .75698 L F
0 g
.4671 .76261 m
.46719 .76234 L
s
.46516 .7686 m
.4671 .76261 L
s
.47206 .76424 m .47309 .7476 L .46791 .75066 L 0 1 .425 r
F
.47206 .76424 m .47797 .7495 L .47309 .7476 L F
.47206 .76424 m .4793 .7551 L .47797 .7495 L F
0 g
.47677 .76141 m
.47923 .75528 L
s
.46719 .76234 m
.47206 .76424 L
s
.46988 .77066 m
.47206 .76424 L
s
.4793 .7551 m
.48393 .75726 L
s
.47923 .75528 m
.4793 .7551 L
s
.50137 .95146 m .493 .9503 L .49775 .95061 L 0 .356 .102 r
F
0 g
.49775 .95061 m
.50128 .95022 L
s
.51128 .87774 m .5092 .8591 L .50954 .86905 L 0 .714 .335 r
F
.50634 .87461 m .50954 .86905 L .5092 .8591 L 0 .736 .346 r
F
0 g
.5092 .8591 m
.51081 .85244 L
s
.5071 .85125 m
.5092 .8591 L
s
.54782 1.12486 m .55203 1.12317 L .55387 1.12898 L 0 .427 .024 r
F
0 g
.55203 1.12317 m
.55659 1.12732 L
s
.26049 .8008 m .24983 .80451 L .25435 .80526 L 0 1 .534 r
F
0 g
.25435 .80526 m
.25581 .81108 L
s
.52094 1.07424 m .51953 1.07458 L .52247 1.08075 L 0 0 .129 r
F
0 g
.51712 1.06818 m
.51953 1.07458 L
s
.51753 1.071 m
.51953 1.07458 L
s
.3522 .68917 m
.35444 .69109 L
s
.35759 .6938 m
.3577 .69389 L
s
.35742 .69365 m
.35759 .6938 L
s
.53625 .84929 m
.53952 .84139 L
s
.50985 .97468 m .50653 .99287 L .50812 .98945 L 0 .263 .258 r
F
.50892 1.00063 m .50796 .99753 L .50635 .99914 L 0 .214 .247 r
F
0 g
.50635 .99914 m
.50653 .99287 L
s
.66203 .57399 m .65972 .56586 L .65703 .56365 L 0 .223 .268 r
F
0 g
.65669 .56326 m
.65703 .56365 L
s
.66203 .57399 m .66908 .57935 L .65972 .56586 L 0 .223 .268 r
F
0 g
.65437 .56194 m
.66203 .57399 L
s
.65703 .56365 m
.66203 .57399 L
s
.49439 .7357 m .50365 .7266 L .50332 .72133 L 0 1 .429 r
F
0 g
.50365 .7266 m
.508 .72825 L
s
.50326 .72723 m
.50365 .7266 L
s
.33263 .56391 m .31985 .56845 L .32302 .56968 L 0 1 .484 r
F
0 g
.31878 .57786 m
.32302 .56968 L
s
.33263 .56391 m .32501 .56104 L .31985 .56845 L 0 1 .484 r
F
.33263 .56391 m .33506 .55238 L .32501 .56104 L F
.33263 .56391 m .3447 .5466 L .33506 .55238 L F
.33263 .56391 m .34748 .54756 L .3447 .5466 L F
.33263 .56391 m .3423 .55498 L .34748 .54756 L F
0 g
.32776 .57146 m
.33263 .56391 L
s
.32302 .56968 m
.33263 .56391 L
s
.52471 .95242 m .52482 .95099 L .52843 .94936 L 0 .305 .14 r
F
0 g
.52482 .95099 m
.52843 .94936 L
s
.52274 .95003 m
.52482 .95099 L
s
.52495 .94887 m
.52843 .94936 L
s
.52247 1.08075 m .52601 1.08789 L .52525 1.08646 L 0 0 .116 r
F
0 g
.524 1.08429 m
.52601 1.08789 L
s
.50804 .89753 m .50548 .88062 L .50631 .88972 L 0 .616 .342 r
F
.50804 .89753 m .50634 .87461 L .50548 .88062 L F
0 g
.50371 .87437 m
.50548 .88062 L
s
.52629 1.08888 m .52525 1.08646 L .52601 1.08789 L 0 .306 0 r
F
0 g
.52601 1.08789 m
.52737 1.09048 L
s
.76877 1.05063 m .76632 1.05532 L .76775 1.05609 L 0 1 .213 r
F
0 g
.76181 1.06111 m
.76775 1.05609 L
s
.54278 .66715 m .55615 .6593 L .55723 .65605 L 0 1 .472 r
F
.54278 .66715 m .54996 .66405 L .55615 .6593 L F
0 g
.55615 .6593 m
.56057 .65932 L
s
.54996 .66405 m
.55453 .66435 L
s
.54996 .66405 m
.55615 .6593 L
s
.37346 .77138 m
.37348 .77136 L
s
.36871 .77391 m
.37329 .77147 L
s
.41396 .78402 m .4049 .7812 L .40827 .78187 L 0 0 0 r
F
.73925 .5942 m .76077 .59828 L .75693 .59455 L 0 1 .501 r
F
0 g
.76077 .59828 m
.76936 .60076 L
s
.50137 .95146 m .48956 .95107 L .493 .9503 L 0 .356 .102 r
F
0 g
.4894 .94911 m
.493 .9503 L
s
.50137 .95146 m .48972 .95241 L .48956 .95107 L 0 .356 .102 r
F
.50137 .95146 m .49334 .95326 L .48972 .95241 L F
.50137 .95146 m .49801 .95307 L .49334 .95326 L F
.50137 .95146 m .50145 .9523 L .49801 .95307 L F
0 g
.50137 .95146 m
.50486 .95004 L
s
.49775 .95061 m
.50137 .95146 L
s
.50634 .87461 m .50831 .8757 L .50954 .86905 L 0 .736 .346 r
F
.50804 .89753 m .50831 .8757 L .50634 .87461 L 0 .616 .342 r
F
0 g
.50548 .88062 m
.50634 .87461 L
s
.50611 .87375 m
.50634 .87461 L
s
.30148 .58388 m .29295 .58028 L .28849 .58824 L 0 1 .5 r
F
.30148 .58388 m .30242 .57116 L .29295 .58028 L F
.30148 .58388 m .31193 .56527 L .30242 .57116 L F
.30148 .58388 m .3151 .56656 L .31193 .56527 L F
.30148 .58388 m .31062 .57454 L .3151 .56656 L F
0 g
.29727 .59204 m
.30148 .58388 L
s
.29201 .58975 m
.30148 .58388 L
s
.40604 .76761 m .39697 .76526 L .40015 .76871 L 0 1 .445 r
F
0 g
.40539 .7717 m
.40604 .76761 L
s
.50501 .9515 m
.50501 .9515 L
s
.50145 .9523 m
.50501 .9515 L
s
.48956 .95107 m .48114 .94811 L .48589 .94923 L 0 .328 .088 r
F
.48956 .95107 m .47776 .94844 L .48114 .94811 L F
0 g
.48589 .94923 m
.4894 .94911 L
s
.4778 .94632 m
.48114 .94811 L
s
.76877 1.05063 m .77727 1.04573 L .77984 1.04039 L 0 1 .213 r
F
0 g
.7721 1.05245 m
.77727 1.04573 L
s
.77727 1.04573 m
.77862 1.04731 L
s
.31608 .79177 m .30374 .79533 L .30908 .79628 L 0 1 .505 r
F
0 g
.30908 .79628 m
.31076 .80196 L
s
.50731 .91564 m .50755 .90275 L .50584 .89585 L 0 .51 .347 r
F
.50731 .91564 m .50839 .91102 L .50755 .90275 L F
.50731 .91564 m .50828 .91654 L .50839 .91102 L F
0 g
.5056 .90873 m
.50731 .91564 L
s
.50731 .91564 m
.50757 .92045 L
s
.76728 .66059 m
.76776 .65979 L
s
.53017 .92649 m .53413 .93447 L .53777 .92807 L 0 .407 .252 r
F
.53017 .92649 m .53087 .93378 L .53413 .93447 L F
.52167 .94084 m .53087 .93378 L .53017 .92649 L 0 .369 .258 r
F
0 g
.52718 .92632 m
.53017 .92649 L
s
.53017 .92649 m
.53211 .9111 L
s
.64314 .81497 m
.64353 .81799 L
s
.64304 .8142 m
.64314 .81497 L
s
.28513 .71797 m .27365 .71746 L .27776 .71979 L 0 1 .516 r
F
0 g
.27734 .72474 m
.27776 .71979 L
s
.52318 .96691 m .52289 .96665 L .52554 .97144 L 0 .098 .183 r
F
.37481 .77066 m .37092 .75639 L .36607 .76405 L 0 1 .441 r
F
.37481 .77066 m .37702 .75314 L .37092 .75639 L F
.37481 .77066 m .3803 .75646 L .37702 .75314 L F
.37481 .77066 m .37935 .76397 L .3803 .75646 L F
0 g
.37469 .77177 m
.37481 .77066 L
s
.37348 .77136 m
.37481 .77066 L
s
.30519 .7324 m .30067 .72086 L .29518 .72484 L 0 .88 .476 r
F
.30519 .7324 m .30766 .72078 L .30067 .72086 L F
.30519 .7324 m .31148 .72466 L .30766 .72078 L F
.30519 .7324 m .31041 .72964 L .31148 .72466 L F
0 g
.29823 .73247 m
.30519 .7324 L
s
.30435 .73653 m
.30519 .7324 L
s
.52167 .94084 m .52866 .94125 L .53087 .93378 L 0 .369 .258 r
F
.52167 .94084 m .52501 .94389 L .52866 .94125 L F
.52167 .94084 m .52201 .94371 L .52501 .94389 L F
0 g
.51894 .94153 m
.52167 .94084 L
s
.52167 .94084 m
.52388 .93339 L
s
.80672 1.00448 m .81644 1.00487 L .81803 .99647 L 0 1 .427 r
F
0 g
.81191 1.01338 m
.81644 1.00487 L
s
.81644 1.00487 m
.81861 1.00916 L
s
.54633 .85298 m .54897 .85932 L .55276 .84673 L 0 .85 .275 r
F
0 g
.54897 .85932 m
.55276 .84673 L
s
.54586 .83417 m
.54633 .85298 L
s
.64192 .82493 m
.64304 .81445 L
s
.51146 .9351 m .50963 .92244 L .51046 .9294 L 0 .379 .339 r
F
.51146 .9351 m .50975 .91806 L .50963 .92244 L F
.51146 .9351 m .51074 .91919 L .50975 .91806 L F
0 g
.51046 .9294 m
.51072 .93421 L
s
.51146 .9351 m .51173 .92489 L .51074 .91919 L 0 .379 .339 r
F
.51146 .9351 m .51207 .93136 L .51173 .92489 L F
.51146 .9351 m .51195 .93573 L .51207 .93136 L F
0 g
.51146 .9351 m
.51171 .93869 L
s
.51046 .9294 m
.51146 .9351 L
s
.51195 .93573 m
.51257 .9398 L
s
.50584 .89585 m
.50631 .88972 L
s
.50584 .89585 m
.50598 .89639 L
s
.7319 .66075 m
.73306 .65835 L
s
.73154 .66151 m
.7319 .66075 L
s
.72965 .66223 m
.73306 .65835 L
s
.72828 .66379 m
.72965 .66223 L
s
.72668 .66561 m
.72828 .66379 L
s
.72561 .66682 m
.72668 .66561 L
s
.68196 .60156 m
.6846 .6032 L
s
.67785 .60331 m
.67796 .60331 L
s
.67796 .60331 m
.67873 .6033 L
s
.67873 .6033 m
.68058 .60327 L
s
.68277 .60323 m
.6846 .6032 L
s
.45418 .93986 m .44667 .9386 L .44285 .93609 L 0 .19 .007 r
F
.45418 .93986 m .45134 .94076 L .44667 .9386 L F
.45418 .93986 m .45455 .94129 L .45134 .94076 L F
.46597 .9445 m .45455 .94129 L .45418 .93986 L 0 .258 .042 r
F
0 g
.45035 .93734 m
.45418 .93986 L
s
.45418 .93986 m
.45745 .94014 L
s
.6709 1.12574 m .67614 1.1106 L .68027 1.11641 L 0 .241 .083 r
F
0 g
.67036 1.10822 m
.67614 1.1106 L
s
.67574 1.10435 m
.67614 1.1106 L
s
.40604 .76761 m .39834 .75868 L .39697 .76526 L 0 1 .445 r
F
.40604 .76761 m .40334 .75335 L .39834 .75868 L F
.40604 .76761 m .40923 .75224 L .40334 .75335 L F
.40604 .76761 m .41208 .7561 L .40923 .75224 L F
.40604 .76761 m .41071 .76269 L .41208 .7561 L F
0 g
.40015 .76871 m
.40604 .76761 L
s
.51344 .94105 m
.51344 .94105 L
s
.5647 .90987 m
.56562 .92086 L
s
.52313 .69493 m .5186 .69004 L .51845 .69426 L 0 1 .453 r
F
.52313 .69493 m .52386 .68447 L .5186 .69004 L F
.52313 .69493 m .53071 .68128 L .52386 .68447 L F
0 g
.49094 .74229 m
.49439 .7357 L
s
.48631 .74012 m
.49094 .74229 L
s
.50985 .97468 m .50812 .98945 L .50931 .98176 L 0 .263 .258 r
F
0 g
.50985 .97468 m
.51034 .97186 L
s
.65591 .60518 m .67319 .60504 L .67619 .60334 L 0 1 .463 r
F
.65591 .60518 m .66451 .60583 L .67319 .60504 L F
0 g
.67319 .60504 m
.67575 .60655 L
s
.35932 .77523 m
.36513 .77156 L
s
.44493 .64083 m .43608 .64183 L .43781 .64228 L 0 1 .297 r
F
0 g
.43351 .64494 m
.43781 .64228 L
s
.44493 .64083 m .44096 .63966 L .43608 .64183 L 0 1 .297 r
F
.44493 .64083 m .44919 .63722 L .44096 .63966 L F
.44493 .64083 m .45633 .63577 L .44919 .63722 L F
.44493 .64083 m .4576 .63627 L .45633 .63577 L F
.44493 .64083 m .45272 .63844 L .4576 .63627 L F
0 g
.44039 .64282 m
.44493 .64083 L
s
.43781 .64228 m
.44493 .64083 L
s
.45272 .63844 m
.45951 .63688 L
s
.63216 .71109 m .63265 .70601 L .6298 .70337 L 0 .21 .268 r
F
0 g
.6298 .70337 m
.63052 .70572 L
s
.62955 .70304 m
.6298 .70337 L
s
.63216 .71109 m .63957 .71773 L .63265 .70601 L 0 .21 .268 r
F
.63216 .71109 m .64593 .73073 L .63957 .71773 L F
.63216 .71109 m .64829 .73845 L .64593 .73073 L F
.63216 .71109 m .64507 .73575 L .64829 .73845 L F
.63216 .71109 m .63816 .72402 L .64507 .73575 L F
0 g
.62716 .70164 m
.63216 .71109 L
s
.63052 .70572 m
.63216 .71109 L
s
.6896 1.10761 m .6995 1.10457 L .69572 1.1082 L 0 .093 .048 r
F
.68027 1.11641 m .6896 1.10761 L .69003 1.11388 L 0 .174 .068 r
F
.44344 .76725 m .43541 .76213 L .438 .76656 L 0 1 .44 r
F
.44344 .76725 m .43729 .756 L .43541 .76213 L F
0 g
.43667 .77274 m
.43776 .76768 L
s
.44344 .76725 m .44239 .75226 L .43729 .756 L 0 1 .44 r
F
0 g
.43776 .76768 m
.438 .76656 L
s
.44344 .76725 m .44784 .75295 L .44239 .75226 L 0 1 .44 r
F
.44344 .76725 m .45001 .75761 L .44784 .75295 L F
.44344 .76725 m .44812 .76373 L .45001 .75761 L F
0 g
.438 .76656 m
.44344 .76725 L
s
.70472 .84268 m
.70472 .8427 L
s
.59019 .63193 m .60751 .62491 L .60274 .62436 L 0 1 .441 r
F
0 g
.60751 .62491 m
.61492 .62249 L
s
.49439 .7357 m .4889 .72891 L .48971 .73405 L 0 1 .429 r
F
.49439 .7357 m .49273 .72275 L .4889 .72891 L F
.49439 .7357 m .49864 .71968 L .49273 .72275 L F
.49439 .7357 m .50332 .72133 L .49864 .71968 L F
.27168 .80266 m .26417 .79408 L .26049 .8008 L 0 1 .531 r
F
.27168 .80266 m .27023 .78962 L .26417 .79408 L F
.27168 .80266 m .27461 .7904 L .27023 .78962 L F
.27168 .80266 m .27522 .79599 L .27461 .7904 L F
0 g
.26564 .8071 m
.27168 .80266 L
s
.27168 .80266 m
.27241 .80817 L
s
.52318 .96691 m .52554 .97144 L .52935 .97808 L 0 .098 .183 r
F
0 g
.52434 .9694 m
.52554 .97144 L
s
.52401 .96867 m
.52554 .97144 L
s
.37418 .67384 m
.3774 .67034 L
s
.36697 .68123 m
.37418 .67384 L
s
.7161 .88895 m .72648 .88848 L .72846 .88646 L 0 1 .288 r
F
.7161 .88895 m .72216 .88984 L .72648 .88848 L F
0 g
.72648 .88848 m
.73026 .88851 L
s
.7161 .88895 m .71771 .89005 L .72216 .88984 L 0 1 .288 r
F
0 g
.71945 .89164 m
.72216 .88984 L
s
.51954 .94656 m
.51955 .94657 L
s
.51954 .94656 m
.52201 .94371 L
s
.26049 .8008 m .24929 .79885 L .24983 .80451 L 0 1 .534 r
F
0 g
.24445 .80933 m
.24983 .80451 L
s
.72678 .88513 m .73397 .88617 L .73964 .88445 L 0 1 .311 r
F
.72678 .88513 m .72846 .88646 L .73397 .88617 L F
0 g
.73026 .88851 m
.73397 .88617 L
s
.72846 .88646 m
.73397 .88617 L
s
.70542 .89275 m .71568 .89197 L .71771 .89005 L 0 1 .289 r
F
.70542 .89275 m .71137 .89344 L .71568 .89197 L F
0 g
.71568 .89197 m
.71945 .89164 L
s
.67987 .77458 m
.6802 .78461 L
s
.67951 .76307 m
.67987 .77458 L
s
.72678 .88513 m .73964 .88445 L .74257 .88184 L 0 1 .311 r
F
0 g
.73964 .88445 m
.74446 .88461 L
s
.51045 1.02596 m .50898 1.02178 L .50736 1.02184 L 0 .141 .218 r
F
.51702 .8556 m .5195 .85734 L .52185 .84974 L 0 .814 .327 r
F
.79091 1.03138 m .80074 1.02108 L .79628 1.02442 L 0 1 .335 r
F
.77984 1.04039 m .79091 1.03138 L .78958 1.02975 L 0 1 .277 r
F
0 g
.47473 .81031 m
.47879 .81154 L
s
.52318 .96691 m .53056 .97981 L .52646 .97255 L 0 .098 .183 r
F
.52318 .96691 m .52935 .97808 L .53264 .98373 L F
0 g
.52353 .96718 m
.52356 .96723 L
s
.52267 .96564 m
.52353 .96718 L
s
.52118 .95189 m
.5212 .9519 L
s
.70542 .89275 m .70697 .89378 L .71137 .89344 L 0 1 .289 r
F
0 g
.70697 .89378 m
.71137 .89344 L
s
.70864 .89504 m
.71137 .89344 L
s
.50892 1.00063 m .5068 1.01554 L .50841 1.01394 L 0 .214 .247 r
F
0 g
.5068 1.01554 m
.50736 1.02184 L
s
.68899 .64427 m
.69038 .64772 L
s
.68531 .63109 m
.68899 .64427 L
s
.6404 .73109 m
.64185 .7345 L
s
.64024 .73071 m
.6404 .73109 L
s
.63816 .72402 m
.63979 .72925 L
s
.63979 .72925 m
.64024 .73071 L
s
.62185 .61568 m .63848 .6132 L .64105 .61121 L 0 1 .451 r
F
.62185 .61568 m .63026 .61511 L .63848 .6132 L F
0 g
.63848 .6132 m
.64242 .61465 L
s
.63027 .61511 m
.6342 .61649 L
s
.63026 .61511 m
.63027 .61511 L
s
.63026 .61511 m
.63848 .6132 L
s
.7408 .88007 m .74736 .88215 L .75198 .88079 L 0 1 .358 r
F
.7408 .88007 m .74257 .88184 L .74736 .88215 L F
0 g
.74446 .88461 m
.74736 .88215 L
s
.74257 .88184 m
.74736 .88215 L
s
.3423 .55498 m
.35164 .54888 L
s
.54228 .8453 m
.54282 .86012 L
s
.69921 1.11818 m .6995 1.10457 L .70516 1.10385 L 0 .043 .055 r
F
.69921 1.11818 m .69572 1.1082 L .6995 1.10457 L F
0 g
.6989 1.09947 m
.6995 1.10457 L
s
.50804 .89753 m .51004 .88351 L .50831 .8757 L 0 .616 .342 r
F
0 g
.50831 .8757 m
.50855 .8768 L
s
.50831 .8757 m
.50954 .86905 L
s
.45333 .76493 m
.45535 .75866 L
s
.44813 .76374 m
.45333 .76493 L
s
.7408 .88007 m .75198 .88079 L .75406 .87814 L 0 1 .358 r
F
0 g
.75198 .88079 m
.75602 .88154 L
s
.50828 .91654 m
.50963 .92244 L
s
.51104 .97896 m .50812 .98945 L .50796 .99753 L 0 .252 .254 r
F
.51104 .97896 m .50931 .98176 L .50812 .98945 L F
0 g
.50653 .99287 m
.50812 .98945 L
s
.42519 .76602 m .41645 .76203 L .41942 .76607 L 0 1 .445 r
F
0 g
.4184 .77249 m
.41942 .76607 L
s
.42519 .76602 m .41805 .75571 L .41645 .76203 L 0 1 .445 r
F
.42519 .76602 m .42317 .75132 L .41805 .75571 L F
.42519 .76602 m .42895 .75126 L .42317 .75132 L F
.42519 .76602 m .43154 .75558 L .42895 .75126 L F
.42519 .76602 m .42992 .7619 L .43154 .75558 L F
0 g
.42387 .7722 m
.42519 .76602 L
s
.41942 .76607 m
.42519 .76602 L
s
.39206 .7658 m .38523 .76141 L .38851 .76468 L 0 1 .444 r
F
.39206 .7658 m .38392 .75746 L .38523 .76141 L F
.39206 .7658 m .38546 .75547 L .38392 .75746 L F
.39206 .7658 m .38901 .75659 L .38546 .75547 L F
0 g
.38778 .77161 m
.38851 .76469 L
s
.38851 .76469 m
.38851 .76469 L
s
.39206 .7658 m .39219 .76007 L .38901 .75659 L 0 1 .444 r
F
.39206 .7658 m .3935 .76402 L .39219 .76007 L F
0 g
.39206 .7658 m
.39343 .7696 L
s
.38851 .76468 m
.39206 .7658 L
s
.75222 .87595 m .75891 .87878 L .76353 .87745 L 0 1 .396 r
F
.75222 .87595 m .75406 .87814 L .75891 .87878 L F
0 g
.75602 .88154 m
.75891 .87878 L
s
.7049 .89581 m
.70697 .89378 L
s
.50754 .71501 m .51822 .70105 L .51352 .6998 L 0 1 .441 r
F
0 g
.51822 .70105 m
.52313 .69494 L
s
.37478 .77191 m .37056 .77179 L .36595 .76928 L 0 0 0 r
F
.37478 .77191 m .37655 .77422 L .37056 .77179 L F
.37478 .77191 m .37991 .77494 L .37655 .77422 L F
.37478 .77191 m .37914 .77394 L .37991 .77494 L F
0 g
.37346 .77138 m
.37478 .77191 L
s
.37469 .77178 m
.37478 .77191 L
s
.51104 .97896 m .51056 .97727 L .50931 .98176 L 0 .252 .254 r
F
0 g
.50931 .98176 m
.51056 .97727 L
s
.50931 .98176 m
.50985 .97468 L
s
.51056 .97727 m
.51077 .97341 L
s
.50754 .71501 m .5025 .70895 L .50283 .71377 L 0 1 .441 r
F
.50754 .71501 m .50708 .70296 L .5025 .70895 L F
.50754 .71501 m .51352 .6998 L .50708 .70296 L F
0 g
.51352 .6998 m
.51822 .70105 L
s
.50332 .72133 m
.50754 .71501 L
s
.51625 .88229 m .51702 .8556 L .51504 .86218 L 0 .692 .325 r
F
.51625 .88229 m .5195 .85734 L .51702 .8556 L F
0 g
.51578 .84885 m
.51702 .8556 L
s
.81131 .80985 m .82034 .80225 L .82493 .80188 L 0 0 0 r
F
.81131 .80985 m .81451 .80565 L .82034 .80225 L F
0 g
.8183 .80027 m
.82034 .80225 L
s
.75222 .87595 m .76353 .87745 L .76556 .87449 L 0 1 .396 r
F
0 g
.76353 .87745 m
.76759 .87855 L
s
.5636 .65151 m .55994 .64824 L .55885 .65131 L 0 1 .453 r
F
.5636 .65151 m .56665 .6441 L .55994 .64824 L F
0 g
.3935 .76402 m
.39697 .76526 L
s
.51431 .94243 m
.51431 .94242 L
s
.51431 .94243 m
.51431 .94242 L
s
.41639 .92416 m
.41945 .9254 L
s
.41945 .9254 m
.42097 .9262 L
s
.50975 .91806 m .50755 .90275 L .50839 .91102 L 0 .497 .341 r
F
.50975 .91806 m .50804 .89753 L .50755 .90275 L F
0 g
.50598 .89639 m
.50755 .90275 L
s
.50828 .91654 m
.50839 .91102 L
s
.40213 .65687 m .39207 .65996 L .39464 .65995 L 0 1 .411 r
F
.40213 .65687 m .396 .65656 L .39207 .65996 L F
0 g
.3914 .66346 m
.39388 .66078 L
s
.39388 .66078 m
.39464 .65995 L
s
.40213 .65687 m .40383 .65201 L .396 .65656 L 0 1 .411 r
F
.40213 .65687 m .41133 .64893 L .40383 .65201 L F
.40213 .65687 m .41349 .64937 L .41133 .64893 L F
.40213 .65687 m .40954 .65278 L .41349 .64937 L F
0 g
.39849 .65979 m
.40213 .65687 L
s
.39464 .65995 m
.40213 .65687 L
s
.36513 .77156 m
.36549 .76868 L
s
.6809 .60914 m
.68469 .61638 L
s
.67785 .60331 m
.6809 .60914 L
s
.67785 .60331 m
.67785 .60331 L
s
.67665 .60102 m
.67785 .60331 L
s
.6714 .59001 m
.67284 .59306 L
s
.67429 .59613 m
.675 .59764 L
s
.76364 .87186 m .77046 .87547 L .77508 .87417 L 0 1 .429 r
F
.76364 .87186 m .76556 .87449 L .77046 .87547 L F
0 g
.76759 .87855 m
.77046 .87547 L
s
.69963 .89759 m
.70059 .8975 L
s
.28513 .71797 m .27505 .71174 L .27365 .71746 L 0 1 .516 r
F
0 g
.26692 .71933 m
.27365 .71746 L
s
.76364 .87186 m .77508 .87417 L .77706 .87089 L 0 1 .429 r
F
0 g
.77508 .87417 m
.77916 .87561 L
s
.65591 .81601 m
.65668 .82356 L
s
.65591 .81601 m
.65594 .82009 L
s
.46597 .9445 m .45833 .94384 L .45455 .94129 L 0 .258 .042 r
F
.46597 .9445 m .463 .94579 L .45833 .94384 L F
.46597 .9445 m .46627 .94607 L .463 .94579 L F
.47776 .94844 m .46627 .94607 L .46597 .9445 L 0 .302 .069 r
F
0 g
.46219 .94196 m
.46597 .9445 L
s
.46597 .9445 m
.46929 .94451 L
s
.34573 .77843 m .33567 .78237 L .33953 .78348 L 0 1 .466 r
F
0 g
.33953 .78348 m
.3397 .78949 L
s
.51269 .93674 m .51173 .92489 L .51207 .93136 L 0 .374 .337 r
F
.51269 .93674 m .51222 .92105 L .51173 .92489 L F
0 g
.51195 .93573 m
.51207 .93136 L
s
.51269 .93674 m .51322 .92241 L .51222 .92105 L 0 .374 .337 r
F
.51269 .93674 m .51384 .9278 L .51322 .92241 L F
.51269 .93674 m .51368 .93362 L .51384 .9278 L F
.51269 .93674 m .51319 .93746 L .51368 .93362 L F
0 g
.51257 .9398 m
.51269 .93674 L
s
.51207 .93136 m
.51269 .93674 L
s
.51319 .93746 m
.51344 .94105 L
s
.53173 .98235 m
.53189 .98257 L
s
.53189 .98257 m
.53233 .98321 L
s
.53233 .98321 m
.53236 .98324 L
s
.53279 .98385 m
.53324 .98449 L
s
.53465 .98648 m
.53507 .98709 L
s
.52935 .97808 m
.53173 .98235 L
s
.77507 .86781 m .78201 .87224 L .78663 .87096 L 0 1 .456 r
F
.77507 .86781 m .77706 .87089 L .78201 .87224 L F
0 g
.77916 .87561 m
.78201 .87224 L
s
.2811 .59214 m .27273 .59167 L .27635 .59317 L 0 1 .508 r
F
.2811 .59214 m .27211 .58842 L .27273 .59167 L F
.2811 .59214 m .27492 .58558 L .27211 .58842 L F
.2811 .59214 m .27968 .58455 L .27492 .58558 L F
.2811 .59214 m .28321 .58602 L .27968 .58455 L F
.2811 .59214 m .28381 .58927 L .28321 .58602 L F
0 g
.2811 .59214 m
.28178 .59545 L
s
.27635 .59317 m
.2811 .59214 L
s
.41624 .51025 m .40465 .51334 L .40653 .51379 L 0 1 .257 r
F
0 g
.39999 .51904 m
.40653 .51379 L
s
.41624 .51025 m .4119 .50926 L .40465 .51334 L 0 1 .257 r
F
.41624 .51025 m .42346 .50426 L .4119 .50926 L F
.41624 .51025 m .43318 .50072 L .42346 .50426 L F
.41624 .51025 m .43457 .50099 L .43318 .50072 L F
.41624 .51025 m .42731 .50508 L .43457 .50099 L F
0 g
.40935 .5143 m
.41624 .51025 L
s
.40653 .51379 m
.41624 .51025 L
s
.42731 .50508 m
.43666 .50124 L
s
.54376 .99822 m
.54428 .9988 L
s
.54248 .9968 m
.54376 .99822 L
s
.54247 .99678 m
.54248 .9968 L
s
.54245 .99676 m
.54247 .99678 L
s
.54198 .99623 m
.54245 .99676 L
s
.54198 .99623 m
.54198 .99623 L
s
.54164 .99586 m
.54198 .99623 L
s
.54135 .99554 m
.54164 .99586 L
s
.54129 .99546 m
.54135 .99554 L
s
.54101 .99516 m
.54129 .99546 L
s
.54097 .9951 m
.54101 .99516 L
s
.54077 .99485 m
.54097 .9951 L
s
.54046 .99446 m
.54077 .99485 L
s
.53989 .99373 m
.54046 .99446 L
s
.53946 .99319 m
.53989 .99373 L
s
.53933 .99302 m
.53946 .99319 L
s
.53889 .99245 m
.53933 .99302 L
s
.39219 .76007 m
.3935 .76402 L
s
.7305 .59761 m .74782 .59768 L .73925 .5942 L 0 1 .489 r
F
0 g
.74782 .59768 m
.75143 .60111 L
s
.74782 .59768 m
.75703 .59942 L
s
.51625 .88229 m .51504 .86218 L .51488 .8727 L 0 .692 .325 r
F
.51128 .87774 m .51488 .8727 L .51504 .86218 L 0 .714 .335 r
F
0 g
.51361 .85503 m
.51504 .86218 L
s
.51504 .86218 m
.51702 .8556 L
s
.77507 .86781 m .78663 .87096 L .78856 .86737 L 0 1 .456 r
F
0 g
.78663 .87096 m
.79073 .87274 L
s
.64915 .60995 m .6475 .60621 L .64492 .60822 L 0 1 .44 r
F
.64915 .60995 m .65591 .60518 L .6475 .60621 L F
.64915 .60995 m .66451 .60583 L .65591 .60518 L F
0 g
.66451 .60583 m
.66871 .60757 L
s
.66451 .60583 m
.67319 .60504 L
s
.48956 .95107 m .47799 .94999 L .47776 .94844 L 0 .328 .088 r
F
.48956 .95107 m .48167 .95184 L .47799 .94999 L F
.48956 .95107 m .48634 .95273 L .48167 .95184 L F
.48956 .95107 m .48972 .95241 L .48634 .95273 L F
0 g
.48956 .95107 m
.493 .9503 L
s
.48589 .94923 m
.48956 .95107 L
s
.51447 1.05055 m .5125 1.04547 L .51086 1.04415 L 0 .03 .161 r
F
.5238 .96742 m .52356 .96724 L .52646 .97255 L 0 .1 .183 r
F
0 g
.52263 .96526 m
.52377 .96737 L
s
.52377 .96737 m
.52379 .9674 L
s
.52356 .96723 m
.52356 .96724 L
s
.51045 1.02596 m .50955 1.03794 L .51118 1.03789 L 0 .141 .218 r
F
0 g
.50955 1.03794 m
.51086 1.04415 L
s
.31608 .79177 m .30289 .7896 L .30374 .79533 L 0 1 .505 r
F
0 g
.29727 .79961 m
.30374 .79533 L
s
.31608 .79177 m .30711 .78289 L .30289 .7896 L 0 1 .505 r
F
.31608 .79177 m .31413 .77836 L .30711 .78289 L F
.31608 .79177 m .31925 .77905 L .31413 .77836 L F
.31608 .79177 m .32007 .7848 L .31925 .77905 L F
0 g
.30908 .79628 m
.31608 .79177 L
s
.78651 .86384 m .79357 .86906 L .7982 .86781 L 0 1 .476 r
F
.78651 .86384 m .78856 .86737 L .79357 .86906 L F
0 g
.79073 .87274 m
.79357 .86906 L
s
.40008 .77964 m .39327 .77791 L .3966 .77864 L 0 0 0 r
F
.40008 .77964 m .39182 .77784 L .39327 .77791 L F
0 g
.39629 .77804 m
.39655 .77854 L
s
.40008 .77964 m .39322 .77846 L .39182 .77784 L 0 0 0 r
F
.40008 .77964 m .3967 .77946 L .39322 .77846 L F
0 g
.39655 .77854 m
.3966 .77864 L
s
.40008 .77964 m .39994 .78017 L .3967 .77946 L 0 0 0 r
F
.40008 .77964 m .40138 .78025 L .39994 .78017 L F
0 g
.3966 .77864 m
.40008 .77964 L
s
.47797 .7495 m
.48098 .74308 L
s
.47309 .7476 m
.47797 .7495 L
s
.50804 .89753 m .51038 .89283 L .51004 .88351 L 0 .616 .342 r
F
.50804 .89753 m .50952 .89884 L .51038 .89283 L F
.50975 .91806 m .50952 .89884 L .50804 .89753 L 0 .497 .341 r
F
0 g
.50631 .88972 m
.50804 .89753 L
s
.50755 .90275 m
.50804 .89753 L
s
.50524 .95298 m
.50524 .95298 L
s
.33482 .67016 m
.33898 .67102 L
s
.35019 .67477 m .34173 .67126 L .33899 .67102 L 0 .319 .235 r
F
.52471 .95242 m .53267 .95647 L .52807 .95476 L 0 .305 .14 r
F
0 g
.52118 .95189 m
.52471 .95242 L
s
.48098 .74308 m .48631 .74012 L .48971 .73405 L 0 1 .433 r
F
.47776 .94844 m .47 .94842 L .46627 .94607 L 0 .302 .069 r
F
.47776 .94844 m .47467 .94999 L .47 .94842 L F
.47776 .94844 m .47799 .94999 L .47467 .94999 L F
0 g
.47403 .94609 m
.47776 .94844 L
s
.47776 .94844 m
.48114 .94811 L
s
.34573 .77843 m .33626 .77537 L .33567 .78237 L 0 1 .466 r
F
0 g
.32991 .78681 m
.33567 .78237 L
s
.34573 .77843 m .34092 .76713 L .33626 .77537 L 0 1 .466 r
F
.34573 .77843 m .34713 .76207 L .34092 .76713 L F
.34573 .77843 m .35074 .76357 L .34713 .76207 L F
.34573 .77843 m .35014 .77059 L .35074 .76357 L F
0 g
.34531 .78539 m
.34573 .77843 L
s
.33953 .78348 m
.34573 .77843 L
s
.46538 .75698 m
.46791 .75066 L
s
.78651 .86384 m .7982 .86781 L .80008 .86391 L 0 1 .476 r
F
0 g
.7982 .86781 m
.8023 .86994 L
s
.51517 .94391 m
.51517 .94391 L
s
.51517 .94391 m
.51517 .94391 L
s
.41396 .78402 m .40578 .7823 L .4049 .7812 L 0 0 0 r
F
.41396 .78402 m .41035 .78443 L .40578 .7823 L F
.41396 .78402 m .41606 .78659 L .41035 .78443 L F
.41396 .78402 m .41909 .78734 L .41606 .78659 L F
.41396 .78402 m .41819 .78623 L .41909 .78734 L F
0 g
.41336 .78282 m
.41396 .78402 L
s
.40827 .78187 m
.41396 .78402 L
s
.41071 .76269 m
.41645 .76203 L
s
.41071 .76269 m
.41071 .76269 L
s
.41071 .76269 m
.41071 .76269 L
s
.51625 .88229 m .52087 .86693 L .5195 .85734 L 0 .692 .325 r
F
0 g
.5195 .85734 m
.52185 .84974 L
s
.3519 .7007 m
.35742 .69365 L
s
.28381 .58927 m
.28849 .58825 L
s
.39289 .77778 m
.39327 .77791 L
s
.38769 .77601 m
.39289 .77778 L
s
.37935 .76397 m
.38523 .76141 L
s
.33371 .67041 m
.33482 .67016 L
s
.30289 .7896 m
.30374 .79533 L
s
.36149 .7671 m .35615 .76623 L .35975 .76827 L 0 1 .431 r
F
.36149 .7671 m .35619 .76476 L .3598 .76627 L 0 0 0 r
F
.35833 .76575 m .35619 .76476 L .36149 .7671 L F
.36607 .76405 m .35833 .76575 L .36149 .7671 L 0 1 .431 r
F
.35833 .76575 m .35615 .76623 L .36149 .7671 L F
.36595 .76928 m .35833 .76575 L .36149 .7671 L 0 0 0 r
F
0 g
.35932 .77523 m
.35975 .76827 L
s
.40954 .65278 m
.41673 .6499 L
s
.79795 .85994 m .80513 .86595 L .80976 .86473 L 0 1 .492 r
F
.79795 .85994 m .80008 .86391 L .80513 .86595 L F
0 g
.8023 .86994 m
.80513 .86595 L
s
.50975 .91806 m .51089 .90588 L .50952 .89884 L 0 .497 .341 r
F
.50975 .91806 m .51122 .91397 L .51089 .90588 L F
.50975 .91806 m .51074 .91919 L .51122 .91397 L F
0 g
.50963 .92244 m
.50975 .91806 L
s
.50839 .91102 m
.50975 .91806 L
s
.42992 .7619 m
.43541 .76213 L
s
.51104 .97896 m .50796 .99753 L .50892 1.00063 L 0 .252 .254 r
F
0 g
.50796 .99753 m
.50812 .98945 L
s
.50635 .99914 m
.50796 .99753 L
s
.51175 .90111 m .51004 .88351 L .51038 .89283 L 0 .597 .334 r
F
.51175 .90111 m .51128 .87774 L .51004 .88351 L F
0 g
.50855 .8768 m
.51004 .88351 L
s
.45535 .75866 m .44784 .75295 L .45001 .75761 L 0 1 .438 r
F
.45535 .75866 m .45025 .74687 L .44784 .75295 L F
0 g
.44966 .75873 m
.45001 .75761 L
s
.44812 .76373 m
.44966 .75873 L
s
.45535 .75866 m .45564 .74343 L .45025 .74687 L 0 1 .438 r
F
.45535 .75866 m .46099 .74448 L .45564 .74343 L F
.45535 .75866 m .46273 .74933 L .46099 .74448 L F
.45535 .75866 m .46031 .7554 L .46273 .74933 L F
0 g
.45001 .75761 m
.45535 .75866 L
s
.46187 .75589 m
.46538 .75698 L
s
.46031 .7554 m
.46187 .75589 L
s
.29518 .72484 m .29088 .7132 L .28513 .71797 L 0 1 .502 r
F
.29518 .72484 m .29808 .71209 L .29088 .7132 L F
.29518 .72484 m .30192 .71539 L .29808 .71209 L F
.29518 .72484 m .30067 .72086 L .30192 .71539 L F
0 g
.28801 .72593 m
.29518 .72484 L
s
.29414 .72981 m
.29518 .72484 L
s
.68928 .90258 m
.68984 .90253 L
s
.79795 .85994 m .80976 .86473 L .81159 .86052 L 0 1 .492 r
F
0 g
.80976 .86473 m
.81388 .86719 L
s
.5238 .96742 m .53157 .9813 L .52723 .97344 L 0 .1 .183 r
F
0 g
.52276 .96476 m
.52397 .9668 L
s
.5238 .96742 m .53447 .98662 L .53157 .9813 L 0 .1 .183 r
F
0 g
.53404 .98563 m
.53448 .98625 L
s
.5238 .96742 m .53056 .97981 L .53399 .98585 L 0 .1 .183 r
F
0 g
.53353 .98491 m
.53389 .9854 L
s
.53254 .98356 m
.53264 .98373 L
s
.53062 .98026 m
.53254 .98356 L
s
.5238 .96742 m .52646 .97255 L .53056 .97981 L 0 .1 .183 r
F
0 g
.52935 .97808 m
.53062 .98026 L
s
.52356 .96724 m
.52646 .97255 L
s
.52273 .96488 m
.52415 .96744 L
s
.52341 .96732 m
.52646 .97255 L
s
.52267 .96511 m
.52405 .96751 L
s
.52379 .9674 m
.5238 .96742 L
s
.52391 .96761 m
.52391 .96761 L
s
.52391 .9676 m
.52391 .96761 L
s
.5238 .96742 m
.52391 .9676 L
s
.76633 .81803 m .78035 .80873 L .77757 .81654 L 0 .127 .054 r
F
0 g
.77898 .8026 m
.78035 .80873 L
s
.78035 .80873 m
.78587 .80303 L
s
.81131 .80985 m .82493 .80188 L .8259 .80398 L 0 0 0 r
F
0 g
.82493 .80188 m
.82984 .8 L
s
.79542 1.01348 m .80074 1.02108 L .80522 1.01255 L 0 1 .404 r
F
.79542 1.01348 m .79628 1.02442 L .80074 1.02108 L F
0 g
.80074 1.02108 m
.80198 1.0234 L
s
.49268 .82138 m .48778 .82265 L .48914 .81988 L 0 .409 .061 r
F
0 g
.4877 .81477 m
.48914 .81988 L
s
.49268 .82138 m .48965 .82885 L .48778 .82265 L 0 .409 .061 r
F
.49268 .82138 m .49353 .83435 L .48965 .82885 L F
.49268 .82138 m .49709 .83585 L .49353 .83435 L F
.49268 .82138 m .49795 .83234 L .49709 .83585 L F
.49268 .82138 m .49606 .82614 L .49795 .83234 L F
0 g
.49125 .81481 m
.49268 .82138 L
s
.48914 .81988 m
.49268 .82138 L
s
.51128 .87774 m .51327 .87937 L .51488 .8727 L 0 .714 .335 r
F
.51175 .90111 m .51327 .87937 L .51128 .87774 L 0 .597 .334 r
F
0 g
.51004 .88351 m
.51128 .87774 L
s
.50954 .86905 m
.51128 .87774 L
s
.54278 .66715 m .55723 .65605 L .55232 .65573 L 0 1 .472 r
F
0 g
.55723 .65605 m
.5636 .65151 L
s
.24929 .79885 m .23852 .80258 L .24305 .80336 L 0 1 .536 r
F
0 g
.24305 .80336 m
.24445 .80933 L
s
.48098 .74308 m .47473 .73654 L .47601 .74155 L 0 1 .433 r
F
.48098 .74308 m .47813 .73047 L .47473 .73654 L F
.48098 .74308 m .48394 .72737 L .47813 .73047 L F
.48098 .74308 m .4889 .72891 L .48394 .72737 L F
.48098 .74308 m .48971 .73405 L .4889 .72891 L F
0 g
.48631 .74012 m
.48937 .73466 L
s
.48971 .73405 m
.49439 .7357 L
s
.48937 .73466 m
.48971 .73405 L
s
.8094 .85612 m .8167 .86291 L .82133 .86171 L 0 1 .503 r
F
.8094 .85612 m .81159 .86052 L .8167 .86291 L F
0 g
.81388 .86719 m
.8167 .86291 L
s
.52282 .96452 m
.52351 .96572 L
s
.52254 .96392 m
.52293 .96455 L
s
.50161 .95356 m .49334 .95326 L .49801 .95307 L 0 .371 .102 r
F
0 g
.49801 .95307 m
.50145 .9523 L
s
.50161 .95356 m .49003 .95445 L .49334 .95326 L 0 .371 .102 r
F
.50161 .95356 m .49029 .95584 L .49003 .95445 L F
.50161 .95356 m .49389 .95633 L .49029 .95584 L F
.50161 .95356 m .49843 .9556 L .49389 .95633 L F
.50161 .95356 m .50174 .95441 L .49843 .9556 L F
0 g
.50161 .95356 m
.50501 .9515 L
s
.49801 .95307 m
.50161 .95356 L
s
.50174 .95441 m
.50524 .95298 L
s
.51394 .93858 m .51384 .9278 L .51368 .93362 L 0 .365 .335 r
F
0 g
.51319 .93746 m
.51368 .93362 L
s
.51394 .93858 m .51471 .92462 L .51384 .9278 L 0 .365 .335 r
F
.51394 .93858 m .5157 .9262 L .51471 .92462 L F
.51394 .93858 m .51595 .93117 L .5157 .9262 L F
.51394 .93858 m .5153 .93619 L .51595 .93117 L F
.51394 .93858 m .51443 .93937 L .5153 .93619 L F
0 g
.51344 .94105 m
.51394 .93858 L
s
.51368 .93362 m
.51394 .93858 L
s
.51431 .94242 m
.51443 .93937 L
s
.27132 .59258 m
.27272 .59168 L
s
.26382 .59741 m
.27132 .59258 L
s
.52094 1.07424 m .51848 1.06838 L .51685 1.06579 L 0 0 .129 r
F
0 g
.516 .94549 m
.516 .94549 L
s
.51447 1.05055 m .51479 1.05977 L .51643 1.06111 L 0 .03 .161 r
F
0 g
.51479 1.05977 m
.51685 1.06579 L
s
.52386 .68447 m .53631 .67607 L .53692 .6723 L 0 1 .468 r
F
.52386 .68447 m .53071 .68128 L .53631 .67607 L F
0 g
.53631 .67607 m
.5409 .67636 L
s
.53071 .68128 m
.53538 .68196 L
s
.53071 .68128 m
.53631 .67607 L
s
.54325 .9996 m .54239 .99781 L .5446 .99915 L 0 .357 .01 r
F
0 g
.54239 .99781 m
.54246 .99786 L
s
.54246 .99786 m
.54255 .99791 L
s
.54255 .99791 m
.54283 .99808 L
s
.54283 .99808 m
.54286 .9981 L
s
.54286 .9981 m
.54288 .99811 L
s
.54288 .99811 m
.54385 .9987 L
s
.54385 .9987 m
.54432 .99898 L
s
.54432 .99898 m
.5446 .99915 L
s
.54428 .9988 m
.5446 .99915 L
s
.8094 .85612 m .82133 .86171 L .82312 .85721 L 0 1 .503 r
F
0 g
.82133 .86171 m
.82546 .8645 L
s
.49606 .82614 m
.49924 .82549 L
s
.5745 .64167 m
.58153 .63789 L
s
.53298 .98419 m
.5331 .98436 L
s
.5331 .98436 m
.53313 .98441 L
s
.53313 .98441 m
.53331 .98465 L
s
.53365 .98513 m
.53398 .98557 L
s
.53412 .98577 m
.53452 .98633 L
s
.53468 .98654 m
.53507 .98709 L
s
.63418 .5351 m
.63549 .53661 L
s
.39834 .75868 m .38901 .75658 L .3922 .76006 L 0 1 .443 r
F
.51104 .97896 m .51017 .99614 L .51087 .98705 L 0 .252 .254 r
F
.51104 .97896 m .50892 1.00063 L .51017 .99614 L F
0 g
.51104 .97896 m
.51151 .97459 L
s
.50952 .89884 m
.51038 .89283 L
s
.50952 .89884 m
.50963 .89939 L
s
.51074 .91919 m
.51173 .92489 L
s
.67086 .78844 m .68617 .85402 L .68068 .79994 L 0 .45 .252 r
F
0 g
.67072 .78332 m
.67086 .78844 L
s
.67018 .78313 m
.67086 .78844 L
s
.46791 .75066 m .47309 .74759 L .47601 .74155 L 0 1 .436 r
F
.71869 1.09605 m .73073 1.0879 L .72556 1.09316 L 0 0 0 r
F
.72707 1.09763 m .73073 1.0879 L .73703 1.08307 L F
.72707 1.09763 m .72556 1.09316 L .73073 1.0879 L F
0 g
.73073 1.0879 m
.73144 1.08395 L
s
.73073 1.0879 m
.73178 1.08709 L
s
.82086 .85238 m .82828 .85994 L .83291 .85876 L 0 1 .512 r
F
.82086 .85238 m .82312 .85721 L .82828 .85994 L F
0 g
.82546 .8645 m
.82828 .85994 L
s
.44355 .79514 m
.44853 .79722 L
s
.46791 .75066 m .46099 .74448 L .46273 .74933 L 0 1 .436 r
F
.46791 .75066 m .46392 .73843 L .46099 .74448 L F
0 g
.46238 .7502 m
.46273 .74933 L
s
.46031 .7554 m
.46238 .7502 L
s
.46791 .75066 m .46955 .73521 L .46392 .73843 L 0 1 .436 r
F
.46791 .75066 m .47473 .73654 L .46955 .73521 L F
.46791 .75066 m .47601 .74155 L .47473 .73654 L F
0 g
.47309 .74759 m
.47568 .74223 L
s
.46273 .74933 m
.46791 .75066 L
s
.47601 .74155 m
.48098 .74308 L
s
.47568 .74223 m
.47601 .74155 L
s
.40139 .78025 m
.4049 .7812 L
s
.5793 .64873 m
.58085 .64991 L
s
.58085 .64991 m
.58135 .65029 L
s
.57455 .6469 m
.5793 .64873 L
s
.28321 .58602 m
.28381 .58927 L
s
.37482 .90475 m .36593 .90254 L .3704 .90424 L 0 .681 .378 r
F
0 g
.3704 .90424 m
.37315 .9063 L
s
.37482 .90475 m .36371 .9002 L .36593 .90254 L 0 .681 .378 r
F
0 g
.36191 .90234 m
.36593 .90254 L
s
.38593 .9096 m .37712 .90687 L .38159 .90868 L 0 .523 .307 r
F
.38593 .9096 m .37482 .90475 L .37712 .90687 L F
0 g
.37315 .9063 m
.37712 .90687 L
s
.38159 .90868 m
.38438 .91054 L
s
.27505 .71174 m .26336 .71191 L .26748 .71408 L 0 1 .523 r
F
0 g
.26692 .71933 m
.26748 .71408 L
s
.54204 .99728 m
.54239 .99781 L
s
.54158 .99657 m
.54204 .99728 L
s
.54102 .99572 m
.54158 .99657 L
s
.54082 .9954 m
.54102 .99572 L
s
.54059 .99506 m
.54082 .9954 L
s
.5401 .99431 m
.54059 .99506 L
s
.53956 .99349 m
.5401 .99431 L
s
.53941 .99326 m
.53956 .99349 L
s
.53889 .99245 m
.53941 .99326 L
s
.36371 .9002 m .35506 .89862 L .35935 .90014 L 0 .845 .429 r
F
0 g
.35935 .90014 m
.36191 .90234 L
s
.7305 .59761 m .73024 .59269 L .72683 .59416 L 0 1 .489 r
F
.7305 .59761 m .73925 .5942 L .73024 .59269 L F
.82086 .85238 m .83291 .85876 L .83465 .85397 L 0 1 .512 r
F
0 g
.83291 .85876 m
.83705 .86188 L
s
.59808 .66233 m
.59974 .66403 L
s
.52431 .96772 m .52412 .96763 L .52723 .97344 L 0 .101 .187 r
F
0 g
.52412 .96763 m
.52412 .96763 L
s
.52412 .96763 m
.52415 .96769 L
s
.52415 .96769 m
.52417 .96771 L
s
.52293 .96455 m
.52325 .96507 L
s
.52351 .96572 m
.52388 .96637 L
s
.52391 .96761 m
.52555 .97048 L
s
.52555 .97048 m
.52555 .97049 L
s
.52405 .96751 m
.52412 .96763 L
s
.52397 .9668 m
.52423 .96724 L
s
.6714 .59001 m
.67329 .59273 L
s
.67579 .59634 m
.67646 .59731 L
s
.36371 .9002 m .35306 .89614 L .35506 .89862 L 0 .845 .429 r
F
0 g
.35115 .89882 m
.35506 .89862 L
s
.52007 .95166 m
.52021 .95183 L
s
.52007 .95166 m
.52014 .95164 L
s
.39749 .91494 m .38844 .91155 L .3931 .91355 L 0 .436 .236 r
F
.39749 .91494 m .38593 .9096 L .38844 .91155 L F
0 g
.38438 .91054 m
.38844 .91155 L
s
.3931 .91355 m
.39607 .91525 L
s
.39834 .75868 m .39062 .74964 L .38901 .75658 L 0 1 .443 r
F
.39834 .75868 m .39596 .74387 L .39062 .74964 L F
.39834 .75868 m .40211 .74248 L .39596 .74387 L F
.39834 .75868 m .40496 .7464 L .40211 .74248 L F
.39834 .75868 m .40334 .75335 L .40496 .7464 L F
0 g
.39697 .76526 m
.39834 .75868 L
s
.3922 .76006 m
.39834 .75868 L
s
.82935 .9893 m .83858 .97806 L .83402 .98073 L 0 1 .46 r
F
.81803 .99647 m .82935 .9893 L .82719 .98496 L 0 1 .446 r
F
0 g
.68786 .71107 m
.68808 .71067 L
s
.69385 .7003 m
.69414 .69978 L
s
.69414 .69978 m
.69454 .69906 L
s
.68769 .71117 m
.68771 .71109 L
s
.5168 .94713 m
.51681 .94713 L
s
.63816 .72402 m
.64422 .7343 L
s
.50892 1.00063 m .50841 1.01394 L .50911 1.00767 L 0 .214 .247 r
F
.51136 1.00832 m .50841 1.01394 L .50898 1.02178 L 0 .188 .235 r
F
.51136 1.00832 m .50911 1.00767 L .50841 1.01394 L F
0 g
.5068 1.01554 m
.50841 1.01394 L
s
.35306 .89614 m .34433 .89503 L .34863 .89644 L 0 .973 .462 r
F
0 g
.34863 .89644 m
.35115 .89882 L
s
.52629 1.08888 m .52856 1.09293 L .52765 1.09147 L 0 .306 0 r
F
0 g
.52844 1.0925 m
.52856 1.09293 L
s
.53209 1.10222 m .52856 1.09293 L .53179 1.09915 L 0 .354 0 r
F
.53209 1.10222 m .52765 1.09148 L .52856 1.09293 L F
0 g
.65568 .7858 m
.65613 .78308 L
s
.6556 .78631 m
.65568 .7858 L
s
.65491 .79049 m
.6556 .78631 L
s
.65467 .79196 m
.65491 .79049 L
s
.65613 .78308 m
.65656 .78049 L
s
.65656 .78049 m
.65667 .77984 L
s
.65667 .77984 m
.65762 .77402 L
s
.36149 .7671 m
.36165 .767 L
s
.35975 .76827 m
.36139 .76717 L
s
.55987 .63946 m
.5623 .64075 L
s
.35833 .76575 m .35633 .76498 L .35615 .76623 L 0 1 .431 r
F
.36595 .76928 m .35711 .76619 L .35633 .76498 L 0 0 0 r
F
.35833 .76575 m .35633 .76498 L .35619 .76476 L F
.36595 .76928 m .35633 .76498 L .35833 .76575 L F
.36607 .76405 m .35732 .75789 L .35633 .76498 L 0 1 .431 r
F
.36607 .76405 m .35633 .76498 L .35833 .76575 L F
0 g
.36549 .76868 m
.36551 .76851 L
s
.35036 .76249 m
.35619 .76476 L
s
.36607 .76405 m .36247 .7488 L .35732 .75789 L 0 1 .431 r
F
.36607 .76405 m .3688 .74459 L .36247 .7488 L F
.36607 .76405 m .37209 .74805 L .3688 .74459 L F
.36607 .76405 m .37092 .75639 L .37209 .74805 L F
0 g
.36165 .767 m
.36607 .76405 L
s
.36551 .76851 m
.36607 .76405 L
s
.44418 .4984 m .43318 .50072 L .43457 .50099 L 0 .82 .221 r
F
0 g
.42731 .50508 m
.43457 .50099 L
s
.44418 .4984 m .44108 .49787 L .43318 .50072 L 0 .82 .221 r
F
.44418 .4984 m .45301 .49435 L .44108 .49787 L F
.44418 .4984 m .46262 .49175 L .45301 .49435 L F
.44418 .4984 m .46351 .49182 L .46262 .49175 L F
.44418 .4984 m .4556 .49467 L .46351 .49182 L F
0 g
.43666 .50124 m
.44418 .4984 L
s
.43457 .50099 m
.44418 .4984 L
s
.4556 .49467 m
.46483 .49173 L
s
.49273 .72275 m .49864 .71968 L .50283 .71377 L 0 1 .444 r
F
0 g
.49864 .71968 m
.50204 .71488 L
s
.49864 .71968 m
.50332 .72133 L
s
.31062 .57454 m
.31985 .56845 L
s
.35019 .67477 m .34893 .67221 L .34173 .67126 L 0 .319 .235 r
F
.35019 .67477 m .35667 .67536 L .34893 .67221 L F
.3495 .70027 m .35676 .68676 L .35914 .67855 L 0 1 .396 r
F
.35893 .67827 m .35914 .67855 L .35983 .67618 L F
.35019 .67477 m .35698 .67835 L .35914 .67855 L 0 .319 .235 r
F
.35893 .67827 m .35914 .67855 L .35977 .67861 L F
.35019 .67477 m .35914 .67855 L .35893 .67827 L F
.36804 .6713 m .36043 .66962 L .35779 .67379 L 0 1 .479 r
F
.35786 .67468 m .35779 .67379 L .35706 .67495 L F
.36804 .6713 m .35779 .67379 L .35786 .67468 L F
.35721 .6713 m .34877 .67267 L .35193 .67407 L 0 1 .494 r
F
.36043 .66962 m .35684 .67056 L .35721 .6713 L F
.3571 .67129 m .34888 .66854 L .35201 .67104 L 0 1 .526 r
F
.35721 .6713 m .35709 .67126 L .3571 .67129 L F
.35709 .67126 m .34888 .66854 L .3571 .67129 L F
.35715 .67118 m .34888 .66854 L .35721 .6713 L F
.35754 .67074 m .34888 .66854 L .35759 .67132 L F
.34173 .67126 m .35201 .67104 L .34888 .66854 L 0 .666 .39 r
F
.34173 .67126 m .34893 .67221 L .35201 .67104 L F
.36043 .66962 m .36141 .65913 L .35546 .66408 L 0 1 .494 r
F
.36043 .66962 m .35546 .66408 L .35549 .66423 L F
.36043 .66962 m .3554 .66413 L .35617 .66774 L F
.36043 .66962 m .35617 .66774 L .35684 .67056 L F
.36804 .6713 m .36862 .66228 L .36043 .66962 L 0 1 .479 r
F
.36043 .66962 m .36993 .65467 L .36141 .65913 L 0 1 .494 r
F
.36043 .66962 m .37269 .65587 L .36993 .65467 L F
.36043 .66962 m .36862 .66228 L .37269 .65587 L F
.36038 .67146 m .36133 .66238 L .35546 .66408 L 0 1 .526 r
F
.35526 .66266 m .36577 .65265 L .363 .65115 L 0 1 .507 r
F
.35287 .66483 m .35539 .66357 L .35526 .66266 L 0 1 .534 r
F
.35539 .66357 m .35539 .66357 L .35526 .66266 L 0 1 .507 r
F
.35539 .66357 m .36577 .65265 L .35526 .66266 L F
.35539 .66357 m .35526 .66266 L .35526 .66266 L F
.35597 .66757 m .35546 .66408 L .35287 .66483 L 0 1 .526 r
F
.35676 .67054 m .35287 .66483 L .34888 .66854 L F
.35674 .67041 m .35287 .66483 L .35676 .67054 L F
.35617 .66774 m .35287 .66483 L .35684 .67056 L F
.35539 .66357 m .36141 .65913 L .36577 .65265 L 0 1 .507 r
F
.35283 .66627 m .35546 .66408 L .35539 .66357 L F
.35546 .66408 m .36141 .65913 L .35539 .66357 L F
.35539 .66357 m .36133 .66238 L .36563 .65848 L 0 1 .534 r
F
.35287 .66483 m .35546 .66408 L .35539 .66357 L F
.35546 .66408 m .36133 .66238 L .35539 .66357 L F
.35526 .66266 m .36563 .65848 L .36289 .65573 L F
.35539 .66357 m .36563 .65848 L .35526 .66266 L F
.35369 .65921 m .363 .65115 L .35419 .65515 L 0 1 .507 r
F
.35287 .66483 m .35526 .66266 L .35369 .65921 L 0 1 .534 r
F
.35283 .66627 m .35526 .66266 L .35369 .65921 L 0 1 .507 r
F
.35526 .66266 m .363 .65115 L .35369 .65921 L F
.35369 .65921 m .35526 .66266 L .35392 .65766 L 0 1 .534 r
F
.35392 .65766 m .36289 .65573 L .35417 .65598 L F
.35526 .66266 m .36289 .65573 L .35392 .65766 L F
.35283 .66627 m .35539 .66357 L .35526 .66266 L 0 1 .507 r
F
.35617 .66774 m .35546 .66408 L .35597 .66757 L 0 1 .526 r
F
.36038 .67146 m .35546 .66408 L .35617 .66774 L F
.35549 .66423 m .35546 .66408 L .3554 .66413 L 0 1 .494 r
F
.35617 .66774 m .3554 .66413 L .35283 .66627 L F
.35684 .67056 m .35674 .67041 L .35676 .67054 L 0 1 .526 r
F
.36038 .67146 m .35617 .66774 L .35684 .67056 L F
.35617 .66774 m .35575 .66756 L .35684 .67056 L 0 1 .494 r
F
.35684 .67056 m .35283 .66627 L .34877 .67267 L F
.35575 .66756 m .35283 .66627 L .35684 .67056 L F
.35684 .67056 m .34877 .67267 L .35721 .6713 L F
.35759 .67132 m .35715 .67118 L .35721 .6713 L 0 1 .526 r
F
.36038 .67146 m .35754 .67074 L .35759 .67132 L F
.36804 .6713 m .35706 .67495 L .35699 .67531 L 0 1 .479 r
F
.35695 .67546 m .35667 .67536 L .35692 .67562 L 0 1 .516 r
F
.35695 .67546 m .35679 .67539 L .35685 .6755 L 0 1 .479 r
F
.36804 .6713 m .35699 .67531 L .35695 .67546 L F
.35695 .67546 m .35706 .67495 L .35667 .67536 L 0 1 .516 r
F
.35699 .67531 m .35679 .67539 L .35695 .67546 L 0 1 .479 r
F
.35893 .67827 m .35983 .67618 L .35693 .67562 L 0 1 .396 r
F
.36784 .67965 m .35695 .67546 L .35977 .67861 L 0 1 .516 r
F
.35695 .67546 m .35692 .67562 L .35977 .67861 L F
.36804 .6713 m .35685 .6755 L .35983 .67618 L 0 1 .479 r
F
.36784 .67965 m .36038 .67146 L .35706 .67495 L 0 1 .516 r
F
.35685 .6755 m .35693 .67562 L .35983 .67618 L 0 1 .479 r
F
.36784 .67965 m .35706 .67495 L .35695 .67546 L 0 1 .516 r
F
.35699 .67531 m .35706 .67495 L .35679 .67539 L 0 1 .479 r
F
.3584 .67806 m .35709 .6759 L .35667 .67536 L 0 .319 .235 r
F
.35685 .6755 m .35679 .67539 L .35667 .67557 L 0 1 .479 r
F
.35019 .67477 m .35835 .67804 L .35667 .67536 L 0 .319 .235 r
F
.35835 .67804 m .3584 .67806 L .35793 .67733 L F
.35835 .67804 m .35793 .67733 L .35667 .67536 L F
.3584 .67806 m .35893 .67827 L .35709 .6759 L F
.35685 .6755 m .35667 .67557 L .35693 .67562 L 0 1 .479 r
F
.3495 .70027 m .35893 .67827 L .35667 .67557 L 0 1 .396 r
F
.35893 .67827 m .35693 .67562 L .35667 .67536 L 0 .319 .235 r
F
.35893 .67827 m .35693 .67562 L .35667 .67557 L 0 1 .396 r
F
.3495 .70027 m .35914 .67855 L .35893 .67827 L F
.35893 .67827 m .35977 .67861 L .35693 .67562 L 0 .319 .235 r
F
.65591 .60518 m .67619 .60334 L .6717 .60133 L 0 1 .463 r
F
0 g
.67619 .60334 m
.67785 .60331 L
s
.48972 .95241 m
.49334 .95326 L
s
.35306 .89614 m .3424 .89236 L .34433 .89503 L 0 .973 .462 r
F
0 g
.34038 .89555 m
.34433 .89503 L
s
.51175 .90111 m .51465 .88765 L .51327 .87937 L 0 .597 .334 r
F
0 g
.51327 .87937 m
.51488 .8727 L
s
.5212 .88853 m .5232 .86061 L .52087 .86693 L 0 .668 .315 r
F
.5212 .88853 m .52564 .86323 L .5232 .86061 L F
0 g
.52185 .84974 m
.5232 .86061 L
s
.40905 .92054 m .40009 .91663 L .40475 .91874 L 0 .317 .204 r
F
0 g
.40953 .921 m
.41173 .92197 L
s
.40776 .92021 m
.40953 .921 L
s
.40905 .92054 m .39749 .91494 L .40009 .91663 L 0 .317 .204 r
F
0 g
.39607 .91525 m
.40009 .91663 L
s
.40475 .91874 m
.40776 .92021 L
s
.24929 .79885 m .23808 .7968 L .23852 .80258 L 0 1 .536 r
F
0 g
.23308 .8075 m
.23852 .80258 L
s
.51222 .92105 m .51089 .90588 L .51122 .91397 L 0 .484 .336 r
F
.51222 .92105 m .51175 .90111 L .51089 .90588 L F
0 g
.50963 .89939 m
.51089 .90588 L
s
.51074 .91919 m
.51122 .91397 L
s
.50555 .95447 m
.50555 .95447 L
s
.6966 .69829 m
.69757 .69599 L
s
.69757 .69599 m
.69761 .69589 L
s
.69761 .69589 m
.69768 .69572 L
s
.69768 .69572 m
.69837 .69406 L
s
.52431 .96772 m .53238 .98248 L .52785 .97408 L 0 .101 .187 r
F
0 g
.52388 .96637 m
.52464 .96769 L
s
.53447 .98662 m .53399 .98585 L .53671 .98997 L 0 .196 0 r
F
.52431 .96772 m .5355 .98831 L .53238 .98248 L 0 .101 .187 r
F
.52431 .96772 m .53157 .9813 L .53512 .98768 L F
.52431 .96772 m .52723 .97344 L .53157 .9813 L F
0 g
.52417 .96771 m
.52519 .96963 L
s
.52519 .96963 m
.52519 .96964 L
s
.52415 .96744 m
.52431 .96772 L
s
.52423 .96724 m
.52453 .96775 L
s
.52437 .96783 m
.52437 .96784 L
s
.52437 .96783 m
.52437 .96783 L
s
.52436 .96781 m
.52437 .96783 L
s
.52434 .96778 m
.52436 .96781 L
s
.52431 .96772 m
.52434 .96778 L
s
.54282 .86012 m
.54633 .85298 L
s
.45991 .80305 m
.46448 .80498 L
s
.51517 .94059 m .51595 .93117 L .5153 .93619 L 0 .35 .332 r
F
.51517 .94059 m .51718 .92875 L .51595 .93117 L F
.51517 .94059 m .51816 .93057 L .51718 .92875 L F
.51517 .94059 m .51803 .93498 L .51816 .93057 L F
.51517 .94059 m .51689 .93904 L .51803 .93498 L F
0 g
.51443 .93937 m
.5145 .93912 L
s
.51517 .94059 m .51566 .94144 L .51689 .93904 L 0 .35 .332 r
F
0 g
.51431 .94242 m
.51517 .94059 L
s
.5145 .93912 m
.5153 .93619 L
s
.51517 .94059 m
.5153 .93619 L
s
.51517 .94391 m
.51566 .94144 L
s
.52094 1.07424 m .52247 1.08075 L .52412 1.08336 L 0 0 .129 r
F
0 g
.52247 1.08075 m
.52525 1.08646 L
s
.46458 .63543 m .45633 .63577 L .4576 .63627 L 0 .837 .252 r
F
0 g
.45272 .63844 m
.4576 .63627 L
s
.46458 .63543 m .46175 .63421 L .45633 .63577 L 0 .837 .252 r
F
.46458 .63543 m .47026 .63264 L .46175 .63421 L F
.46458 .63543 m .47724 .63181 L .47026 .63264 L F
.46458 .63543 m .47805 .63226 L .47724 .63181 L F
.46458 .63543 m .47262 .63382 L .47805 .63226 L F
0 g
.45951 .63688 m
.46458 .63543 L
s
.4576 .63627 m
.46458 .63543 L
s
.47262 .63382 m
.47926 .63278 L
s
.39994 .78017 m
.40138 .78025 L
s
.3424 .89236 m .3336 .89169 L .33789 .893 L 0 1 .484 r
F
0 g
.33789 .893 m
.34038 .89555 L
s
.5225 .94806 m .52866 .94125 L .52501 .94389 L 0 .323 .253 r
F
.5225 .94806 m .53187 .94493 L .52866 .94125 L F
0 g
.52201 .94371 m
.52501 .94389 L
s
.5225 .94806 m .53249 .95249 L .53187 .94493 L 0 .323 .253 r
F
.52434 .95595 m .52807 .95476 L .53267 .95647 L 0 .338 .142 r
F
.5225 .94806 m .52998 .95667 L .53249 .95249 L 0 .323 .253 r
F
.52434 .95595 m .52451 .95454 L .52807 .95476 L 0 .338 .142 r
F
.5225 .94806 m .52601 .95466 L .52998 .95667 L 0 .323 .253 r
F
0 g
.52327 .95545 m
.52327 .95545 L
s
.52471 .95242 m
.52488 .95253 L
s
.5225 .94806 m .52281 .95097 L .52601 .95466 L 0 .323 .253 r
F
0 g
.5212 .9519 m
.52451 .95454 L
s
.52014 .95164 m
.52281 .95097 L
s
.51955 .94657 m
.5225 .94806 L
s
.5225 .94806 m
.52501 .94389 L
s
.52096 .95269 m
.52284 .95487 L
s
.52629 1.08888 m .52537 1.08688 L .52525 1.08646 L 0 .306 0 r
F
.38392 .75746 m .37702 .75313 L .38031 .75646 L 0 1 .437 r
F
.38392 .75746 m .37578 .74893 L .37702 .75313 L F
.38392 .75746 m .37742 .74665 L .37578 .74893 L F
.38392 .75746 m .38104 .74765 L .37742 .74665 L F
0 g
.37935 .76397 m
.3803 .75649 L
s
.3803 .75649 m
.3803 .75646 L
s
.38392 .75746 m .38423 .75126 L .38104 .74765 L 0 1 .437 r
F
.38392 .75746 m .38546 .75547 L .38423 .75126 L F
0 g
.38392 .75746 m
.38523 .76141 L
s
.38031 .75646 m
.38392 .75746 L
s
.36752 .71827 m .3575 .70463 L .36052 .71524 L 0 1 .423 r
F
.36752 .71827 m .3601 .69609 L .3575 .70463 L F
.76137 .64138 m .77824 .63257 L .77087 .63633 L 0 0 0 r
F
0 g
.77824 .63257 m
.78072 .63079 L
s
.43729 .756 m .42895 .75126 L .43154 .75558 L 0 1 .446 r
F
.43729 .756 m .43113 .74509 L .42895 .75126 L F
0 g
.42992 .7619 m
.43031 .7604 L
s
.43729 .756 m .43663 .74117 L .43113 .74509 L 0 1 .446 r
F
0 g
.43031 .7604 m
.43154 .75558 L
s
.43729 .756 m .4424 .7416 L .43663 .74117 L 0 1 .446 r
F
.43729 .756 m .44457 .74609 L .4424 .7416 L F
.43729 .756 m .44239 .75226 L .44457 .74609 L F
0 g
.43541 .76213 m
.43729 .756 L
s
.43154 .75558 m
.43729 .756 L
s
.26049 .8008 m .25311 .79204 L .24929 .79885 L 0 1 .534 r
F
.26049 .8008 m .25927 .78754 L .25311 .79204 L F
.26049 .8008 m .26366 .78839 L .25927 .78754 L F
.26049 .8008 m .26417 .79408 L .26366 .78839 L F
0 g
.25435 .80526 m
.26049 .8008 L
s
.26049 .8008 m
.26113 .80637 L
s
.38546 .75547 m
.38901 .75659 L
s
.38901 .75658 m
.38901 .75658 L
s
.51757 .94881 m
.51757 .94881 L
s
.50708 .70296 m .51352 .6998 L .51845 .69426 L 0 1 .456 r
F
0 g
.52451 .95454 m
.52598 .95463 L
s
.52866 .94125 m
.53087 .93378 L
s
.35952 .72992 m .35749 .70484 L .35362 .70549 L 0 .727 .319 r
F
.35952 .72992 m .36051 .71533 L .35749 .70484 L F
0 g
.35633 .76498 m
.35634 .76499 L
s
.35619 .76476 m
.35633 .76498 L
s
.49273 .72275 m .50283 .71377 L .5025 .70895 L 0 1 .444 r
F
0 g
.50283 .71377 m
.50754 .71501 L
s
.50204 .71488 m
.50283 .71377 L
s
.3424 .89236 m .33174 .88886 L .3336 .89169 L 0 1 .484 r
F
0 g
.32961 .89252 m
.3336 .89169 L
s
.62185 .61568 m .64105 .61121 L .63636 .60989 L 0 1 .451 r
F
0 g
.64105 .61121 m
.64915 .60995 L
s
.51226 .98307 m .51087 .98705 L .51017 .99614 L 0 .242 .251 r
F
.51226 .98307 m .51177 .98145 L .51087 .98705 L F
0 g
.51087 .98705 m
.51104 .97896 L
s
.51087 .98705 m
.51177 .98145 L
s
.51177 .98145 m
.51187 .97487 L
s
.59019 .63193 m .58693 .62884 L .58538 .63139 L 0 1 .441 r
F
.59019 .63193 m .59438 .62582 L .58693 .62884 L F
.59019 .63193 m .60274 .62436 L .59438 .62582 L F
0 g
.58307 .63527 m
.59019 .63193 L
s
.50708 .70296 m .51845 .69426 L .5186 .69004 L 0 1 .456 r
F
0 g
.51845 .69426 m
.52313 .69493 L
s
.51352 .6998 m
.51845 .69426 L
s
.69623 .71559 m
.69685 .72252 L
s
.6957 .70968 m
.69623 .71559 L
s
.69546 .70705 m
.6957 .70968 L
s
.69509 .70293 m
.69546 .70705 L
s
.41805 .75571 m .40923 .75224 L .41208 .7561 L 0 1 .448 r
F
0 g
.41208 .7561 m
.41805 .75571 L
s
.41645 .76203 m
.41805 .75571 L
s
.41805 .75571 m
.41805 .75571 L
s
.41071 .76269 m
.41208 .7561 L
s
.5212 .88853 m .52087 .86693 L .52022 .87797 L 0 .668 .315 r
F
.51625 .88229 m .52022 .87797 L .52087 .86693 L 0 .692 .325 r
F
0 g
.5195 .85734 m
.52087 .86693 L
s
.52087 .86693 m
.5232 .86061 L
s
.54278 .66715 m .53847 .66332 L .53785 .66684 L 0 1 .472 r
F
.54278 .66715 m .54468 .65856 L .53847 .66332 L F
.54278 .66715 m .55232 .65573 L .54468 .65856 L F
.76295 .67992 m .77771 .65464 L .78169 .65268 L 0 0 .03 r
F
.76295 .67992 m .7697 .66627 L .77771 .65464 L F
0 g
.77771 .65464 m
.77879 .64574 L
s
.77727 .65528 m
.77771 .65464 L
s
.53209 1.10222 m .53179 1.09915 L .53519 1.10601 L 0 .354 0 r
F
0 g
.52856 1.09293 m
.53179 1.09915 L
s
.52991 1.09441 m
.53179 1.09915 L
s
.41805 .75571 m .4112 .7459 L .40923 .75224 L 0 1 .448 r
F
.41805 .75571 m .41668 .7413 L .4112 .7459 L F
.41805 .75571 m .42266 .7409 L .41668 .7413 L F
.41805 .75571 m .42514 .74497 L .42266 .7409 L F
.41805 .75571 m .42317 .75132 L .42514 .74497 L F
0 g
.41805 .75571 m
.41805 .75571 L
s
.56047 .49181 m .57199 .49551 L .58155 .49912 L 0 0 0 r
F
0 g
.57199 .49551 m
.57971 .49712 L
s
.57971 .49712 m
.58102 .49795 L
s
.27505 .71174 m .26493 .70601 L .26336 .71191 L 0 1 .523 r
F
0 g
.25647 .71425 m
.26336 .71191 L
s
.56047 .49181 m .55305 .49041 L .55235 .48962 L 0 0 0 r
F
.56047 .49181 m .56262 .49402 L .55305 .49041 L F
.56047 .49181 m .57467 .49804 L .56262 .49402 L F
.56047 .49181 m .58278 .50023 L .57467 .49804 L F
0 g
.58102 .49795 m
.5817 .49838 L
s
.56047 .49181 m .58155 .49912 L .58278 .50023 L 0 0 0 r
F
0 g
.5513 .48814 m
.56047 .49181 L
s
.57199 .49551 m
.58015 .4986 L
s
.35014 .77059 m
.35615 .76623 L
s
.51222 .92105 m .51324 .90283 L .51175 .90111 L 0 .484 .336 r
F
.51222 .92105 m .51424 .90991 L .51324 .90283 L F
.51222 .92105 m .51408 .91763 L .51424 .90991 L F
.51222 .92105 m .51322 .92241 L .51408 .91763 L F
0 g
.51173 .92489 m
.51222 .92105 L
s
.51122 .91397 m
.51222 .92105 L
s
.70021 .59502 m .71834 .59779 L .72174 .59635 L 0 1 .49 r
F
.70021 .59502 m .70913 .59722 L .71834 .59779 L F
0 g
.71834 .59779 m
.72177 .60093 L
s
.70913 .59722 m
.71326 .59992 L
s
.70913 .59722 m
.71834 .59779 L
s
.38423 .75126 m
.38546 .75547 L
s
.53137 .48641 m .54306 .4879 L .55235 .48962 L 0 0 0 r
F
0 g
.54306 .4879 m
.5513 .48814 L
s
.51136 1.00832 m .50898 1.02178 L .51045 1.02596 L 0 .188 .235 r
F
0 g
.50841 1.01394 m
.50898 1.02178 L
s
.50736 1.02184 m
.50898 1.02178 L
s
.33174 .88886 m .32285 .88859 L .32715 .88981 L 0 1 .498 r
F
0 g
.32715 .88981 m
.33017 .88918 L
s
.32715 .88981 m
.32961 .89252 L
s
.44239 .75226 m
.44784 .75295 L
s
.51136 1.00832 m .51038 1.00525 L .50911 1.00767 L 0 .188 .235 r
F
0 g
.50892 1.00063 m
.50911 1.00767 L
s
.4729 .49024 m .46262 .49175 L .46351 .49182 L 0 0 0 r
F
0 g
.4556 .49467 m
.46351 .49182 L
s
.4729 .49024 m .47108 .49026 L .46262 .49175 L 0 0 0 r
F
.4729 .49024 m .48325 .48834 L .47108 .49026 L F
.4729 .49024 m .49301 .48657 L .49265 .48675 L F
.4729 .49024 m .49265 .48675 L .48325 .48834 L F
.4729 .49024 m .48454 .48806 L .49301 .48657 L F
0 g
.48454 .48806 m
.49355 .48607 L
s
.46351 .49182 m
.4729 .49024 L
s
.46483 .49173 m
.4729 .49024 L
s
.51175 .90111 m .51449 .89706 L .51465 .88765 L 0 .597 .334 r
F
.51175 .90111 m .51324 .90283 L .51449 .89706 L F
0 g
.51038 .89283 m
.51175 .90111 L
s
.51089 .90588 m
.51175 .90111 L
s
.58905 .50298 m .58278 .50023 L .58155 .49912 L 0 0 0 r
F
0 g
.58155 .49912 m
.58181 .49926 L
s
.58015 .4986 m
.58155 .49912 L
s
.58905 .50298 m .59251 .50595 L .58278 .50023 L 0 0 0 r
F
.58905 .50298 m .60426 .51247 L .59251 .50595 L F
.61685 .52073 m .61176 .51631 L .61002 .51493 L 0 .137 .174 r
F
.60346 .51196 m .6059 .51331 L .60501 .51285 L 0 0 0 r
F
.60385 .51221 m .60501 .51285 L .60426 .51247 L F
.60346 .51196 m .60501 .51285 L .60385 .51221 L F
.58905 .50298 m .61176 .51631 L .6059 .51331 L F
.58905 .50298 m .6059 .51331 L .60346 .51196 L F
.58905 .50298 m .61002 .51493 L .61176 .51631 L F
.5956 .50765 m .59946 .50892 L .58895 .50346 L 0 .333 .208 r
F
.59258 .50599 m .61375 .51767 L .60959 .51537 L 0 .234 .176 r
F
.59258 .50599 m .60959 .51537 L .60717 .51404 L F
.59265 .50602 m .61375 .51767 L .59258 .50599 L F
.61375 .51767 m .61438 .51805 L .61613 .51898 L F
.61685 .52073 m .61277 .51713 L .61261 .51704 L 0 .137 .174 r
F
.59251 .50595 m .61349 .51756 L .61375 .51767 L 0 .234 .176 r
F
.61349 .51756 m .61438 .51805 L .61375 .51767 L F
.61685 .52073 m .62157 .52433 L .61305 .51736 L 0 .137 .174 r
F
.61301 .51735 m .61305 .51736 L .61277 .51713 L F
.61685 .52073 m .61305 .51736 L .61301 .51735 L F
.59253 .50596 m .60824 .51463 L .59598 .50789 L 0 .234 .176 r
F
.59251 .50595 m .60426 .51247 L .61438 .51805 L F
.59598 .50789 m .5961 .50792 L .5956 .50765 L 0 .333 .208 r
F
.5961 .50792 m .59946 .50892 L .5956 .50765 L F
.60717 .51404 m .60959 .51537 L .60824 .51463 L 0 .234 .176 r
F
.59251 .50595 m .59265 .50602 L .59258 .50599 L F
.61375 .51767 m .61613 .51898 L .61392 .51777 L F
.61375 .51767 m .61392 .51777 L .60824 .51463 L F
.61261 .51704 m .61277 .51713 L .61176 .51631 L 0 .137 .174 r
F
.59251 .50595 m .59258 .50599 L .59253 .50596 L 0 .234 .176 r
F
.59258 .50599 m .60824 .51463 L .59253 .50596 L F
0 g
.60741 .51247 m
.6087 .5136 L
s
.6087 .5136 m
.60874 .51363 L
s
.60874 .51363 m
.61234 .51678 L
s
.58905 .50298 m .60029 .50922 L .61002 .51493 L 0 0 0 r
F
0 g
.58181 .49926 m
.58905 .50298 L
s
.5817 .49838 m
.58905 .50298 L
s
.60046 .50929 m
.60741 .51247 L
s
.60029 .50922 m
.60038 .50926 L
s
.60038 .50926 m
.60046 .50929 L
s
.51828 .9505 m
.51832 .95052 L
s
.51828 .9505 m
.51834 .95051 L
s
.5247 .96779 m .52456 .96779 L .52785 .97408 L 0 .097 .188 r
F
0 g
.52456 .96779 m
.52456 .96779 L
s
.52456 .96779 m
.52462 .96791 L
s
.52462 .96791 m
.52468 .96802 L
s
.52468 .96802 m
.5247 .96806 L
s
.5247 .96806 m
.52471 .96808 L
s
.52453 .96775 m
.52456 .96779 L
s
.52555 .97049 m
.52723 .97344 L
s
.52519 .96964 m
.52723 .97344 L
s
.53137 .48641 m .5229 .48613 L .52273 .48565 L 0 0 0 r
F
.53137 .48641 m .5322 .48784 L .5229 .48613 L F
.53137 .48641 m .54442 .48965 L .5322 .48784 L F
.53137 .48641 m .55305 .49041 L .54442 .48965 L F
.53137 .48641 m .55235 .48962 L .55305 .49041 L F
0 g
.55296 .48978 m
.56047 .49181 L
s
.55235 .48962 m
.55296 .48978 L
s
.52248 .48468 m
.53137 .48641 L
s
.54306 .4879 m
.55235 .48962 L
s
.741 .65451 m
.74246 .6523 L
s
.73761 .65692 m
.74246 .6523 L
s
.69684 .69817 m
.69959 .69401 L
s
.49273 .72275 m .48687 .7167 L .48769 .72147 L 0 1 .444 r
F
.49273 .72275 m .49106 .71078 L .48687 .7167 L F
.49273 .72275 m .49746 .70767 L .49106 .71078 L F
.49273 .72275 m .5025 .70895 L .49746 .70767 L F
0 g
.4889 .72891 m
.49273 .72275 L
s
.50207 .48609 m .51381 .48563 L .52273 .48565 L 0 0 0 r
F
0 g
.51381 .48563 m
.52248 .48468 L
s
.53056 .97981 m
.53107 .98074 L
s
.33174 .88886 m .32106 .88562 L .32285 .88859 L 0 1 .498 r
F
0 g
.31882 .8897 m
.32285 .88859 L
s
.28513 .71797 m .28104 .70643 L .27505 .71174 L 0 1 .516 r
F
.28513 .71797 m .28845 .70459 L .28104 .70643 L F
.28513 .71797 m .29231 .70746 L .28845 .70459 L F
.28513 .71797 m .29088 .7132 L .29231 .70746 L F
0 g
.27776 .71979 m
.28513 .71797 L
s
.28391 .72342 m
.28513 .71797 L
s
.5212 .88853 m .52663 .87378 L .52564 .86323 L 0 .668 .315 r
F
0 g
.52564 .86323 m
.52747 .85789 L
s
.50207 .48609 m .49265 .48675 L .49301 .48657 L 0 0 0 r
F
.50207 .48609 m .50157 .48677 L .49265 .48675 L F
0 g
.48454 .48806 m
.49301 .48657 L
s
.50207 .48609 m .51383 .48661 L .50157 .48677 L 0 0 0 r
F
.50207 .48609 m .5229 .48613 L .51383 .48661 L F
0 g
.52375 .48574 m
.53137 .48641 L
s
.50207 .48609 m .52273 .48565 L .5229 .48613 L 0 0 0 r
F
0 g
.52273 .48565 m
.52375 .48574 L
s
.49301 .48657 m
.50207 .48609 L
s
.49355 .48607 m
.50207 .48609 L
s
.51381 .48563 m
.52273 .48565 L
s
.5178 .84109 m .51586 .85329 L .51569 .84416 L 0 .685 .108 r
F
0 g
.51333 .83391 m
.51569 .84416 L
s
.5178 .84109 m .51861 .86603 L .51586 .85329 L 0 .685 .108 r
F
.5178 .84109 m .52212 .87385 L .51861 .86603 L F
.5178 .84109 m .52423 .87072 L .52212 .87385 L F
.5178 .84109 m .52354 .85876 L .52423 .87072 L F
.5178 .84109 m .52078 .84609 L .52354 .85876 L F
0 g
.52078 .84609 m
.5225 .83871 L
s
.51629 .83299 m
.5178 .84109 L
s
.51569 .84416 m
.5178 .84109 L
s
.5225 .83871 m
.52451 .84984 L
s
.51226 .98307 m .51017 .99614 L .51038 1.00525 L 0 .242 .251 r
F
0 g
.50892 1.00063 m
.51017 .99614 L
s
.43217 .93219 m .42338 .92748 L .42803 .92972 L 0 0 0 r
F
0 g
.43115 .93073 m
.43251 .93156 L
s
.43217 .93219 m .42061 .92632 L .42338 .92748 L 0 0 0 r
F
0 g
.42097 .9262 m
.42338 .92748 L
s
.42803 .92972 m
.43115 .93073 L
s
.51322 .92241 m
.51384 .9278 L
s
.70896 1.10653 m .71869 1.09605 L .71872 1.10054 L 0 0 .029 r
F
.51638 .94275 m .51803 .93498 L .51689 .93904 L 0 .328 .329 r
F
.51638 .94275 m .51961 .93344 L .51803 .93498 L F
.51638 .94275 m .52057 .93546 L .51961 .93344 L F
.51638 .94275 m .52007 .93919 L .52057 .93546 L F
.51638 .94275 m .51844 .94213 L .52007 .93919 L F
0 g
.51566 .94144 m
.51571 .94134 L
s
.51571 .94134 m
.51689 .93904 L
s
.51638 .94275 m .51686 .94365 L .51844 .94213 L 0 .328 .329 r
F
0 g
.51517 .94391 m
.51638 .94275 L
s
.51638 .94275 m
.51689 .93904 L
s
.516 .94549 m
.51686 .94365 L
s
.60896 .51431 m
.61002 .51493 L
s
.60029 .50922 m
.60896 .51431 L
s
.75105 1.07082 m .76123 1.06192 L .75688 1.06606 L 0 0 0 r
F
.74029 1.08188 m .75105 1.07082 L .75036 1.0727 L F
.30289 .7896 m .29209 .79336 L .29645 .79408 L 0 1 .517 r
F
0 g
.29645 .79408 m
.29726 .79961 L
s
.51895 .95217 m
.51971 .95284 L
s
.51971 .95284 m
.51971 .95284 L
s
.51971 .95284 m
.51971 .95284 L
s
.51971 .95284 m
.52008 .95317 L
s
.52008 .95317 m
.52009 .95317 L
s
.52009 .95317 m
.52009 .95317 L
s
.52009 .95317 m
.52034 .95339 L
s
.52034 .95339 m
.52034 .95339 L
s
.51895 .95217 m
.51895 .95217 L
s
.40334 .75335 m
.40923 .75224 L
s
.35615 .76623 m
.35633 .76498 L
s
.51548 .90575 m .51465 .88765 L .51449 .89706 L 0 .577 .327 r
F
.51548 .90575 m .51625 .88229 L .51465 .88765 L F
0 g
.51327 .87937 m
.51465 .88765 L
s
.27211 .58842 m
.27273 .59167 L
s
.37092 .75639 m
.37702 .75314 L
s
.5247 .96779 m .53299 .98327 L .52831 .97442 L 0 .097 .188 r
F
.5247 .96779 m .53629 .98958 L .53299 .98327 L F
.5247 .96779 m .53238 .98248 L .53601 .98913 L F
.5247 .96779 m .52785 .97408 L .53238 .98248 L F
0 g
.52464 .96769 m
.5247 .96779 L
s
.53107 .98074 m
.53321 .98461 L
s
.53056 .97981 m
.53112 .98081 L
s
.53112 .98081 m
.53127 .98108 L
s
.53127 .98108 m
.53233 .98293 L
s
.52478 .96795 m
.52483 .96802 L
s
.52477 .96793 m
.52478 .96795 L
s
.5247 .96779 m
.52477 .96793 L
s
.53321 .98461 m
.53336 .98485 L
s
.53336 .98485 m
.53368 .98533 L
s
.53368 .98533 m
.53371 .98538 L
s
.53371 .98538 m
.53381 .98553 L
s
.53419 .98612 m
.53456 .98668 L
s
.52386 .68447 m .53692 .6723 L .5319 .67175 L 0 1 .468 r
F
0 g
.53692 .6723 m
.54278 .66715 L
s
.69921 1.11818 m .69558 1.11403 L .69572 1.1082 L 0 .043 .055 r
F
0 g
.6896 1.10761 m
.69572 1.1082 L
s
.75772 1.06234 m .76123 1.06192 L .76632 1.05532 L 0 .955 .188 r
F
.75772 1.06234 m .75688 1.06606 L .76123 1.06192 L F
.79542 1.01348 m .79399 1.02118 L .79628 1.02442 L 0 1 .404 r
F
0 g
.79091 1.03138 m
.79628 1.02442 L
s
.32106 .88562 m .3121 .8857 L .3164 .88683 L 0 1 .507 r
F
0 g
.3164 .88683 m
.31856 .88627 L
s
.3164 .88683 m
.31882 .8897 L
s
.50197 .95568 m .49389 .95633 L .49843 .9556 L 0 .385 .102 r
F
0 g
.49843 .9556 m
.50174 .95441 L
s
.50197 .95568 m .49075 .95797 L .49389 .95633 L 0 .385 .102 r
F
.50197 .95568 m .4911 .95943 L .49075 .95797 L F
.50197 .95568 m .49465 .95951 L .4911 .95943 L F
.50197 .95568 m .49901 .95818 L .49465 .95951 L F
.50197 .95568 m .50215 .95653 L .49901 .95818 L F
0 g
.50197 .95568 m
.50524 .95298 L
s
.49843 .9556 m
.50197 .95568 L
s
.50215 .95653 m
.50555 .95447 L
s
.53519 1.10601 m .54016 1.11181 L .53879 1.11144 L 0 .369 0 r
F
.54357 1.1242 m .54016 1.11181 L .54403 1.11755 L 0 .449 .012 r
F
.54357 1.1242 m .53879 1.11144 L .54016 1.11181 L F
0 g
.53827 1.10705 m
.54016 1.11181 L
s
.35147 .71684 m .35362 .70547 L .35189 .70098 L 0 1 .232 r
F
0 g
.3522 .70178 m
.35362 .70547 L
s
.52326 .9515 m
.52336 .9516 L
s
.52323 .95146 m
.52326 .9515 L
s
.52281 .95097 m
.52323 .95146 L
s
.35952 .72992 m .35362 .70549 L .35147 .71685 L 0 .727 .319 r
F
0 g
.35362 .70549 m
.35749 .70484 L
s
.51226 .98307 m .51225 1.00271 L .51247 .99218 L 0 .242 .251 r
F
.51226 .98307 m .51136 1.00832 L .51225 1.00271 L F
.51226 .98307 m .51038 1.00525 L .51136 1.00832 L F
0 g
.51226 .98307 m
.51269 .97527 L
s
.50911 1.00767 m
.51038 1.00525 L
s
.51017 .99614 m
.51038 1.00525 L
s
.35737 .54249 m .3447 .5466 L .34748 .54756 L 0 1 .46 r
F
0 g
.3423 .55498 m
.34748 .54756 L
s
.35737 .54249 m .35074 .54022 L .3447 .5466 L 0 1 .46 r
F
.35737 .54249 m .36158 .53268 L .35074 .54022 L F
.35737 .54249 m .37149 .52761 L .36158 .53268 L F
.35737 .54249 m .37385 .52839 L .37149 .52761 L F
.35737 .54249 m .36779 .53477 L .37385 .52839 L F
0 g
.35164 .54888 m
.35737 .54249 L
s
.34748 .54756 m
.35737 .54249 L
s
.70481 .84339 m
.70482 .84339 L
s
.51954 .95378 m
.51955 .95378 L
s
.51967 .95387 m
.51967 .95387 L
s
.51967 .95387 m
.51967 .95387 L
s
.51955 .95378 m
.51967 .95387 L
s
.51625 .88229 m .51824 .88456 L .52022 .87797 L 0 .692 .325 r
F
.51548 .90575 m .51824 .88456 L .51625 .88229 L 0 .577 .327 r
F
0 g
.51465 .88765 m
.51625 .88229 L
s
.51488 .8727 m
.51625 .88229 L
s
.66443 1.11674 m
.66698 1.11835 L
s
.69921 1.11818 m .70516 1.10385 L .70896 1.10653 L 0 .043 .055 r
F
0 g
.6995 1.10457 m
.70516 1.10385 L
s
.70516 1.10385 m
.70517 1.09936 L
s
.23808 .7968 m .2272 .80056 L .23173 .80138 L 0 1 .537 r
F
0 g
.23173 .80138 m
.23308 .8075 L
s
.49003 .95445 m .48167 .95184 L .48634 .95273 L 0 .352 .088 r
F
0 g
.48634 .95273 m
.48972 .95241 L
s
.51045 1.02596 m .51118 1.03789 L .5114 1.03287 L 0 .141 .218 r
F
.51414 1.03648 m .51118 1.03789 L .5125 1.04547 L 0 .092 .191 r
F
.51414 1.03648 m .5114 1.03287 L .51118 1.03789 L F
0 g
.50955 1.03794 m
.51118 1.03789 L
s
.52434 .95595 m .532 .96441 L .52755 .96017 L 0 .338 .142 r
F
0 g
.52434 .95595 m
.52437 .95598 L
s
.52328 .95545 m
.52434 .95595 L
s
.50595 .95596 m
.50595 .95596 L
s
.36779 .53477 m
.37737 .52943 L
s
.44373 .93802 m .43502 .93308 L .43968 .93531 L 0 .118 0 r
F
0 g
.44285 .93609 m
.44384 .93674 L
s
.44373 .93802 m .43217 .93219 L .43502 .93308 L 0 .118 0 r
F
0 g
.43968 .93531 m
.44285 .93609 L
s
.43251 .93156 m
.43502 .93308 L
s
.32106 .88562 m .31036 .8826 L .3121 .8857 L 0 1 .507 r
F
0 g
.30803 .88706 m
.3121 .8857 L
s
.52007 .95531 m
.52013 .95537 L
s
.52013 .95537 m
.52019 .95544 L
s
.52019 .95544 m
.52077 .95611 L
s
.52077 .95611 m
.52083 .95618 L
s
.52083 .95618 m
.52092 .95629 L
s
.52092 .95629 m
.52111 .95651 L
s
.52111 .95651 m
.52167 .95716 L
s
.52167 .95716 m
.52212 .95768 L
s
.52212 .95768 m
.52212 .95768 L
s
.52212 .95768 m
.52212 .95768 L
s
.52007 .95531 m
.52007 .95531 L
s
.52137 .95645 m
.52137 .95645 L
s
.52137 .95645 m
.52137 .95645 L
s
.52007 .95531 m
.52137 .95645 L
s
.39062 .74964 m .38105 .74764 L .38423 .75126 L 0 1 .438 r
F
.53187 .94493 m .53777 .92807 L .53413 .93447 L 0 .326 .244 r
F
.53187 .94493 m .54123 .93473 L .53777 .92807 L F
0 g
.53777 .92807 m
.5397 .91266 L
s
.53087 .93378 m
.53413 .93447 L
s
.53777 .92807 m
.54123 .93473 L
s
.54123 .93473 m
.54321 .91225 L
s
.52277 .95904 m
.52277 .95904 L
s
.52277 .95904 m
.52277 .95904 L
s
.5213 .95752 m
.5213 .95752 L
s
.5213 .95752 m
.5213 .95752 L
s
.52071 .95691 m
.5213 .95752 L
s
.52071 .95691 m
.52071 .95691 L
s
.52071 .95691 m
.52071 .95691 L
s
.52053 .95673 m
.52071 .95691 L
s
.52053 .95673 m
.52069 .95693 L
s
.52069 .95693 m
.52069 .95693 L
s
.52069 .95693 m
.52069 .95693 L
s
.52069 .95693 m
.52115 .95751 L
s
.52115 .95751 m
.52115 .95751 L
s
.52115 .95751 m
.52115 .95751 L
s
.52115 .95751 m
.52205 .95866 L
s
.52244 .95971 m
.52244 .95971 L
s
.52244 .95971 m
.52244 .95971 L
s
.5219 .95886 m
.52244 .95971 L
s
.5219 .95886 m
.5219 .95886 L
s
.5219 .95886 m
.5219 .95886 L
s
.52143 .95813 m
.5219 .95886 L
s
.52143 .95813 m
.52143 .95813 L
s
.52143 .95813 m
.52143 .95813 L
s
.5213 .95793 m
.52143 .95813 L
s
.5213 .95793 m
.5213 .95793 L
s
.5213 .95793 m
.5213 .95793 L
s
.52088 .95728 m
.5213 .95793 L
s
.52088 .95728 m
.52088 .95728 L
s
.52088 .95728 m
.52088 .95728 L
s
.52088 .95727 m
.52088 .95728 L
s
.52088 .95727 m
.52088 .95727 L
s
.52088 .95727 m
.52088 .95727 L
s
.52064 .95689 m
.52088 .95727 L
s
.52064 .95689 m
.52064 .95689 L
s
.52064 .95689 m
.52064 .95689 L
s
.52062 .95686 m
.52064 .95689 L
s
.52062 .95686 m
.52062 .95686 L
s
.52062 .95686 m
.52062 .95686 L
s
.5206 .95683 m
.52062 .95686 L
s
.5206 .95683 m
.5206 .95683 L
s
.5206 .95683 m
.5206 .95683 L
s
.52054 .95674 m
.5206 .95683 L
s
.52053 .95673 m
.52054 .95674 L
s
.51324 .90283 m
.51449 .89706 L
s
.42317 .75132 m
.42895 .75126 L
s
.42895 .75126 m
.43113 .74509 L
s
.52386 .68447 m .51897 .68 L .51882 .68393 L 0 1 .468 r
F
.52386 .68447 m .52458 .67478 L .51897 .68 L F
.52386 .68447 m .5319 .67175 L .52458 .67478 L F
.52496 .96761 m .52487 .96772 L .52831 .97442 L 0 .091 .187 r
F
0 g
.52487 .96772 m
.52495 .96787 L
s
.52495 .96787 m
.52507 .96811 L
s
.52507 .96811 m
.52508 .96812 L
s
.52508 .96812 m
.52513 .96821 L
s
.52325 .96507 m
.52487 .96772 L
s
.59438 .62582 m .61095 .62112 L .61356 .61825 L 0 1 .465 r
F
.59438 .62582 m .60274 .62436 L .61095 .62112 L F
0 g
.61095 .62112 m
.61492 .62249 L
s
.60274 .62436 m
.60751 .62491 L
s
.60274 .62436 m
.61095 .62112 L
s
.61275 .51725 m
.61457 .51879 L
s
.61242 .51697 m
.61275 .51725 L
s
.61147 .51617 m
.61231 .51688 L
s
.61685 .52073 m .63974 .53943 L .63291 .53363 L 0 .137 .174 r
F
0 g
.63042 .53205 m
.63387 .53485 L
s
.61685 .52073 m .6277 .52985 L .63751 .53786 L 0 .137 .174 r
F
0 g
.61457 .51879 m
.61685 .52073 L
s
.3774 .67034 m .36513 .67608 L .36903 .67533 L 0 1 .452 r
F
0 g
.36694 .68132 m
.36753 .67961 L
s
.3774 .67034 m .36804 .6713 L .36513 .67608 L 0 1 .452 r
F
0 g
.36761 .6794 m
.36874 .67618 L
s
.36874 .67618 m
.36903 .67533 L
s
.3774 .67034 m .37583 .66419 L .36804 .6713 L 0 1 .452 r
F
.3774 .67034 m .38422 .65918 L .37583 .66419 L F
.3774 .67034 m .3876 .65963 L .38422 .65918 L F
.3774 .67034 m .38468 .66441 L .3876 .65963 L F
0 g
.36903 .67533 m
.3774 .67034 L
s
.72707 1.09763 m .73703 1.08307 L .74029 1.08188 L 0 0 0 r
F
0 g
.73178 1.08709 m
.73703 1.08307 L
s
.51756 .94503 m .52007 .93919 L .51844 .94213 L 0 .309 .323 r
F
.51756 .94503 m .52198 .93863 L .52007 .93919 L F
.51756 .94503 m .5229 .94083 L .52198 .93863 L F
.51756 .94503 m .52202 .94374 L .5229 .94083 L F
0 g
.51686 .94365 m
.51844 .94213 L
s
.51756 .94503 m .51993 .94542 L .52202 .94374 L 0 .309 .323 r
F
.51756 .94503 m .51802 .94597 L .51993 .94542 L F
0 g
.516 .94549 m
.51756 .94503 L
s
.51756 .94503 m
.51844 .94213 L
s
.5168 .94713 m
.51802 .94597 L
s
.76295 .67992 m .78169 .65268 L .77945 .66021 L 0 0 .03 r
F
0 g
.7697 .66627 m
.77727 .65528 L
s
.7697 .66627 m
.77174 .65769 L
s
.75999 .67277 m
.76728 .66059 L
s
.78169 .65268 m
.78895 .64206 L
s
.5025 .70895 m
.50708 .70296 L
s
.50708 .70296 m .5017 .69785 L .50202 .70212 L 0 1 .456 r
F
.50708 .70296 m .50664 .6923 L .5017 .69785 L F
.50708 .70296 m .51354 .6892 L .50664 .6923 L F
.50708 .70296 m .5186 .69004 L .51354 .6892 L F
0 g
.5186 .69004 m
.52386 .68447 L
s
.45025 .74687 m .4424 .7416 L .44457 .74609 L 0 1 .446 r
F
.45025 .74687 m .44513 .73557 L .4424 .7416 L F
0 g
.44359 .74885 m
.44457 .74609 L
s
.44239 .75226 m
.44359 .74885 L
s
.45025 .74687 m .45096 .73201 L .44513 .73557 L 0 1 .446 r
F
.45025 .74687 m .45664 .73279 L .45096 .73201 L F
.45025 .74687 m .45839 .7374 L .45664 .73279 L F
.45025 .74687 m .45564 .74343 L .45839 .7374 L F
0 g
.44784 .75295 m
.45025 .74687 L
s
.44457 .74609 m
.45025 .74687 L
s
.45564 .74343 m
.46099 .74448 L
s
.3601 .69595 m .36867 .69059 L .36491 .68514 L 0 .837 .463 r
F
.3601 .69595 m .3666 .69523 L .36867 .69059 L F
0 g
.3577 .69389 m
.3601 .69595 L
s
.33626 .77537 m .32599 .78016 L .32987 .78095 L 0 1 .47 r
F
0 g
.32987 .78095 m
.32991 .78681 L
s
.49746 .70767 m
.5025 .70895 L
s
.49003 .95445 m .47845 .95241 L .48167 .95184 L 0 .352 .088 r
F
0 g
.47799 .94999 m
.48167 .95184 L
s
.77757 .81654 m .79174 .80812 L .78881 .8146 L 0 .056 .033 r
F
0 g
.79047 .80319 m
.79174 .80812 L
s
.79174 .80812 m
.79736 .80325 L
s
.47813 .73047 m .48394 .72737 L .48769 .72147 L 0 1 .445 r
F
0 g
.48394 .72737 m
.4889 .72891 L
s
.4848 .63203 m .47724 .63181 L .47805 .63226 L 0 .733 .234 r
F
0 g
.47262 .63382 m
.47805 .63226 L
s
.4848 .63203 m .48314 .63099 L .47724 .63181 L 0 .733 .234 r
F
.4848 .63203 m .49182 .63035 L .48314 .63099 L F
.4848 .63203 m .49858 .63011 L .49182 .63035 L F
.4848 .63203 m .49891 .63043 L .49858 .63011 L F
.4848 .63203 m .493 .63125 L .49891 .63043 L F
0 g
.47926 .63278 m
.4848 .63203 L
s
.47805 .63226 m
.4848 .63203 L
s
.493 .63125 m
.4994 .63073 L
s
.36752 .71827 m .3666 .69529 L .3601 .69609 L 0 1 .423 r
F
0 g
.3575 .70463 m
.3601 .69609 L
s
.31036 .8826 m .30133 .88297 L .30564 .88404 L 0 1 .512 r
F
0 g
.30564 .88404 m
.30744 .88349 L
s
.30564 .88404 m
.30803 .88706 L
s
.51471 .92462 m .51424 .90991 L .51408 .91763 L 0 .467 .331 r
F
0 g
.51322 .92241 m
.51408 .91763 L
s
.39062 .74964 m .38291 .74026 L .38105 .74764 L 0 1 .438 r
F
.39062 .74964 m .38858 .73402 L .38291 .74026 L F
.39062 .74964 m .39498 .7324 L .38858 .73402 L F
.39062 .74964 m .39783 .73648 L .39498 .7324 L F
.39062 .74964 m .39596 .74387 L .39783 .73648 L F
0 g
.38901 .75658 m
.39062 .74964 L
s
.38423 .75126 m
.39062 .74964 L
s
.4553 .94357 m .44667 .9386 L .45134 .94076 L 0 .216 .005 r
F
0 g
.45455 .94129 m
.45528 .94178 L
s
.4553 .94357 m .44373 .93802 L .44667 .9386 L 0 .216 .005 r
F
0 g
.45134 .94076 m
.45455 .94129 L
s
.44384 .93674 m
.44667 .9386 L
s
.29295 .58028 m .27968 .58454 L .28321 .58601 L 0 1 .508 r
F
.43212 .79141 m .42363 .78834 L .42665 .78892 L 0 0 0 r
F
0 g
.43127 .78962 m
.43212 .79141 L
s
.42599 .78764 m
.42665 .78892 L
s
.26493 .70601 m .25304 .70671 L .25717 .70875 L 0 1 .528 r
F
0 g
.25647 .71425 m
.25717 .70875 L
s
.52496 .96761 m .53338 .98358 L .52861 .97441 L 0 .091 .187 r
F
.52496 .96761 m .53684 .99031 L .53338 .98358 L F
.52496 .96761 m .53665 .99009 L .53684 .99031 L F
.52496 .96761 m .53299 .98327 L .53665 .99009 L F
0 g
.53339 .9848 m
.53389 .98568 L
s
.53565 .98834 m
.53602 .98891 L
s
.53647 .98961 m
.53671 .98997 L
s
.53494 .98726 m
.53524 .98771 L
s
.53395 .98577 m
.53399 .98585 L
s
.53389 .98568 m
.53395 .98577 L
s
.52496 .96761 m .52831 .97442 L .53299 .98327 L 0 .091 .187 r
F
0 g
.52496 .96761 m
.52507 .96781 L
s
.52507 .96781 m
.52509 .96784 L
s
.52509 .96784 m
.52517 .96799 L
s
.52517 .96799 m
.52521 .96807 L
s
.52521 .96807 m
.52526 .96816 L
s
.52471 .96808 m
.52785 .97408 L
s
.52437 .96784 m
.52785 .97408 L
s
.52258 .9636 m
.52496 .96761 L
s
.53233 .98293 m
.53339 .9848 L
s
.54897 .85932 m
.54907 .87253 L
s
.54907 .87253 m
.54907 .87287 L
s
.54907 .87287 m
.54907 .87331 L
s
.54907 .87331 m
.54908 .87411 L
s
.54908 .87411 m
.54909 .87489 L
s
.54909 .87489 m
.5491 .87678 L
s
.54357 1.1242 m .54403 1.11755 L .54782 1.12486 L 0 .449 .012 r
F
0 g
.54016 1.11181 m
.54403 1.11755 L
s
.54221 1.11177 m
.54403 1.11755 L
s
.51471 .92462 m .51548 .90575 L .51424 .90991 L 0 .467 .331 r
F
0 g
.51324 .90283 m
.51424 .90991 L
s
.79542 1.01348 m .80522 1.01255 L .80672 1.00448 L 0 1 .404 r
F
0 g
.80074 1.02108 m
.80522 1.01255 L
s
.80522 1.01255 m
.80744 1.01635 L
s
.51414 1.03648 m .5125 1.04547 L .51447 1.05055 L 0 .092 .191 r
F
0 g
.51118 1.03789 m
.5125 1.04547 L
s
.51086 1.04415 m
.5125 1.04547 L
s
.68068 .79994 m .69042 .8059 L .68337 .76738 L 0 .494 .261 r
F
0 g
.68337 .76738 m
.68487 .77562 L
s
.68487 .77562 m
.68695 .78695 L
s
.68209 .74649 m
.68337 .76738 L
s
.51459 .98345 m
.51459 .9835 L
s
.51459 .98341 m
.51459 .98345 L
s
.51451 .97862 m
.51459 .98341 L
s
.49003 .95445 m .47883 .95407 L .47845 .95241 L 0 .352 .088 r
F
.49003 .95445 m .48253 .95579 L .47883 .95407 L F
.49003 .95445 m .48708 .95642 L .48253 .95579 L F
.49003 .95445 m .49029 .95584 L .48708 .95642 L F
0 g
.49003 .95445 m
.49334 .95326 L
s
.48634 .95273 m
.49003 .95445 L
s
.33626 .77537 m .32674 .77349 L .32599 .78016 L 0 1 .47 r
F
0 g
.32008 .7848 m
.32599 .78016 L
s
.33626 .77537 m .33162 .76539 L .32674 .77349 L 0 1 .47 r
F
.33626 .77537 m .33802 .7598 L .33162 .76539 L F
.33626 .77537 m .34167 .76046 L .33802 .7598 L F
.33626 .77537 m .34092 .76713 L .34167 .76046 L F
0 g
.33567 .78237 m
.33626 .77537 L
s
.32987 .78095 m
.33626 .77537 L
s
.69589 .6848 m
.69909 .69276 L
s
.69909 .69276 m
.69937 .69346 L
s
.69937 .69346 m
.69959 .69401 L
s
.70037 .69594 m
.70226 .70064 L
s
.70025 .69564 m
.70037 .69594 L
s
.69589 .6848 m
.69757 .69565 L
s
.69757 .69565 m
.69761 .69589 L
s
.69761 .69589 m
.69767 .69632 L
s
.69767 .69632 m
.69775 .6968 L
s
.31036 .8826 m .29966 .87976 L .30133 .88297 L 0 1 .512 r
F
0 g
.29723 .88457 m
.30133 .88297 L
s
.23808 .7968 m .22686 .79463 L .2272 .80056 L 0 1 .537 r
F
0 g
.22169 .80561 m
.2272 .80056 L
s
.47845 .95241 m .47 .94842 L .47467 .94999 L 0 .321 .069 r
F
0 g
.47467 .94999 m
.47799 .94999 L
s
.83102 .96487 m .83858 .97806 L .8422 .96828 L 0 1 .46 r
F
.83102 .96487 m .83402 .98073 L .83858 .97806 L F
0 g
.83858 .97806 m
.84067 .98284 L
s
.54468 .65856 m .55885 .65131 L .55994 .64824 L 0 1 .484 r
F
.54468 .65856 m .55232 .65573 L .55885 .65131 L F
0 g
.55885 .65131 m
.5636 .65151 L
s
.55232 .65573 m
.55723 .65605 L
s
.55232 .65573 m
.55885 .65131 L
s
.47813 .73047 m .47153 .72457 L .47281 .72927 L 0 1 .445 r
F
.47813 .73047 m .47528 .71867 L .47153 .72457 L F
.47813 .73047 m .48156 .7155 L .47528 .71867 L F
.47813 .73047 m .48687 .7167 L .48156 .7155 L F
.47813 .73047 m .48769 .72147 L .48687 .7167 L F
0 g
.48394 .72737 m
.48701 .72253 L
s
.47473 .73654 m
.47813 .73047 L
s
.48769 .72147 m
.49273 .72275 L
s
.48701 .72253 m
.48769 .72147 L
s
.37578 .74893 m .3688 .74458 L .37209 .74804 L 0 1 .424 r
F
.37578 .74893 m .36764 .73992 L .3688 .74458 L F
.37578 .74893 m .36939 .73716 L .36764 .73992 L F
.37578 .74893 m .37308 .73805 L .36939 .73716 L F
0 g
.37092 .75639 m
.37208 .74813 L
s
.37208 .74813 m
.37209 .74805 L
s
.37578 .74893 m .37627 .74198 L .37308 .73805 L 0 1 .424 r
F
.37578 .74893 m .37742 .74665 L .37627 .74198 L F
0 g
.37578 .74893 m
.37702 .75313 L
s
.37209 .74804 m
.37578 .74893 L
s
.51471 .92462 m .51697 .90792 L .51548 .90575 L 0 .467 .331 r
F
.51471 .92462 m .5176 .9149 L .51697 .90792 L F
.51471 .92462 m .51694 .92204 L .5176 .9149 L F
.51471 .92462 m .5157 .9262 L .51694 .92204 L F
0 g
.51384 .9278 m
.51471 .92462 L
s
.51408 .91763 m
.51471 .92462 L
s
.37742 .74665 m
.38104 .74765 L
s
.38105 .74764 m
.38105 .74764 L
s
.51548 .90575 m .51924 .89324 L .51824 .88456 L 0 .577 .327 r
F
0 g
.51824 .88456 m
.52022 .87797 L
s
.30289 .7896 m .29211 .78799 L .29209 .79336 L 0 1 .517 r
F
0 g
.28625 .79781 m
.29209 .79336 L
s
.46687 .94854 m .45833 .94384 L .463 .94579 L 0 .282 .042 r
F
0 g
.46627 .94607 m
.46675 .94638 L
s
.46687 .94854 m .4553 .94357 L .45833 .94384 L 0 .282 .042 r
F
0 g
.463 .94579 m
.46627 .94607 L
s
.45528 .94178 m
.45833 .94384 L
s
.35174 .76271 m .34713 .76207 L .35074 .76357 L 0 1 .415 r
F
.35174 .76271 m .34718 .76003 L .35078 .76209 L 0 0 0 r
F
.34914 .76125 m .34718 .76003 L .35174 .76271 L F
.35732 .75789 m .34914 .76125 L .35174 .76271 L 0 1 .415 r
F
.34914 .76125 m .34713 .76207 L .35174 .76271 L F
.35711 .76619 m .34914 .76125 L .35174 .76271 L 0 0 0 r
F
0 g
.35014 .77059 m
.35074 .76357 L
s
.47845 .95241 m .46687 .94854 L .47 .94842 L 0 .321 .069 r
F
0 g
.46675 .94638 m
.47 .94842 L
s
.39207 .65996 m
.396 .65656 L
s
.38468 .66441 m
.39207 .65996 L
s
.55027 .87525 m
.5503 .87543 L
s
.55018 .87462 m
.55027 .87525 L
s
.54905 .86703 m
.55018 .87462 L
s
.54907 .87287 m
.5491 .87936 L
s
.54907 .87273 m
.54907 .87287 L
s
.54907 .87204 m
.54907 .87273 L
s
.54905 .86703 m
.54907 .87204 L
s
.51349 .98698 m .513 .98544 L .51247 .99218 L 0 .234 .248 r
F
0 g
.51282 .97547 m
.513 .98544 L
s
.42101 .64724 m .41133 .64893 L .41349 .64937 L 0 1 .392 r
F
0 g
.40954 .65278 m
.41349 .64937 L
s
.42101 .64724 m .41593 .64599 L .41133 .64893 L 0 1 .392 r
F
.42101 .64724 m .42423 .64251 L .41593 .64599 L F
.42101 .64724 m .43176 .64038 L .42423 .64251 L F
.42101 .64724 m .43349 .64102 L .43176 .64038 L F
.42101 .64724 m .42888 .64396 L .43349 .64102 L F
0 g
.41673 .6499 m
.42101 .64724 L
s
.41349 .64937 m
.42101 .64724 L
s
.5157 .9262 m
.51595 .93117 L
s
.6277 .52985 m
.63685 .53732 L
s
.5187 .9474 m .52202 .94374 L .51993 .94542 L 0 .288 .313 r
F
.5187 .9474 m .52425 .94424 L .52202 .94374 L F
.5187 .9474 m .52513 .94658 L .52425 .94424 L F
0 g
.51802 .94597 m
.51993 .94542 L
s
.5187 .9474 m .52389 .94856 L .52513 .94658 L 0 .288 .313 r
F
.5187 .9474 m .52136 .94886 L .52389 .94856 L F
.5187 .9474 m .51913 .94836 L .52136 .94886 L F
0 g
.51757 .94881 m
.51976 .9498 L
s
.51681 .94713 m
.5187 .9474 L
s
.5187 .9474 m
.51993 .94542 L
s
.51757 .94881 m
.51913 .94836 L
s
.52607 .89679 m .52927 .86802 L .52663 .87378 L 0 .64 .307 r
F
.52607 .89679 m .53166 .8718 L .52927 .86802 L F
0 g
.52845 .85703 m
.52927 .86802 L
s
.52564 .86323 m
.52629 .87017 L
s
.36595 .76928 m .36196 .76962 L .35711 .76619 L 0 0 0 r
F
.36595 .76928 m .36814 .77265 L .36196 .76962 L F
.36595 .76928 m .37151 .77323 L .36814 .77265 L F
.36595 .76928 m .37056 .77179 L .37151 .77323 L F
0 g
.36549 .76868 m
.36595 .76928 L
s
.36149 .7671 m
.36595 .76928 L
s
.5251 .96717 m .52506 .96738 L .52861 .97441 L 0 .083 .185 r
F
0 g
.52506 .96738 m
.52516 .96758 L
s
.52516 .96758 m
.52531 .96788 L
s
.52531 .96788 m
.52537 .96799 L
s
.52537 .96799 m
.52543 .96812 L
s
.52288 .96395 m
.52506 .96738 L
s
.46392 .73843 m .45664 .73279 L .45839 .7374 L 0 1 .446 r
F
.46392 .73843 m .4599 .72685 L .45664 .73279 L F
0 g
.45764 .73904 m
.45839 .7374 L
s
.45564 .74343 m
.45764 .73904 L
s
.46392 .73843 m .466 .72353 L .4599 .72685 L 0 1 .446 r
F
.46392 .73843 m .47153 .72457 L .466 .72353 L F
0 g
.47325 .73616 m
.47473 .73654 L
s
.46392 .73843 m .47281 .72927 L .47153 .72457 L 0 1 .446 r
F
.46392 .73843 m .46955 .73521 L .47281 .72927 L F
0 g
.47281 .72927 m
.47813 .73047 L
s
.46099 .74448 m
.46392 .73843 L
s
.45839 .7374 m
.46392 .73843 L
s
.46955 .73521 m
.47325 .73616 L
s
.51136 1.00832 m .51045 1.02596 L .51172 1.02355 L 0 .188 .235 r
F
.65113 .78151 m .6538 .77233 L .65024 .76832 L 0 .285 .282 r
F
0 g
.65024 .76832 m
.65036 .76998 L
s
.65036 .76998 m
.65093 .77866 L
s
.65093 .77866 m
.65113 .78151 L
s
.64879 .76489 m
.65024 .76832 L
s
.64779 .77046 m
.65048 .77936 L
s
.65048 .77936 m
.65113 .78151 L
s
.47215 .73047 m
.47281 .72927 L
s
.46955 .73521 m
.47215 .73047 L
s
.35174 .76271 m
.35187 .7626 L
s
.35074 .76357 m
.35164 .7628 L
s
.34914 .76125 m .34737 .76042 L .34713 .76207 L 0 1 .415 r
F
.35711 .76619 m .34826 .7623 L .34737 .76042 L 0 0 0 r
F
.34914 .76125 m .34737 .76042 L .34718 .76003 L F
.35711 .76619 m .34737 .76042 L .34914 .76125 L F
.35732 .75789 m .34852 .7525 L .34737 .76042 L 0 1 .415 r
F
.35732 .75789 m .34737 .76042 L .34914 .76125 L F
0 g
.35187 .7626 m
.35198 .76251 L
s
.35633 .76498 m
.35639 .76452 L
s
.34119 .75746 m
.34718 .76003 L
s
.35732 .75789 m .35401 .74125 L .34852 .7525 L 0 1 .415 r
F
.35732 .75789 m .36058 .73556 L .35401 .74125 L F
.35732 .75789 m .36387 .73923 L .36058 .73556 L F
.35732 .75789 m .36247 .7488 L .36387 .73923 L F
0 g
.35198 .76251 m
.35732 .75789 L
s
.35639 .76452 m
.35732 .75789 L
s
.42888 .64396 m
.42921 .64386 L
s
.42921 .64386 m
.43608 .64183 L
s
.67274 .91531 m
.67285 .91506 L
s
.67294 .91486 m
.67331 .91397 L
s
.34173 .67126 m .33018 .67022 L .33371 .67041 L 0 .666 .39 r
F
0 g
.37627 .74198 m
.37742 .74665 L
s
.38593 .9096 m .37624 .90373 L .37482 .90475 L 0 .523 .307 r
F
.38593 .9096 m .38059 .90465 L .37624 .90373 L F
.38593 .9096 m .38495 .90688 L .38059 .90465 L F
.38593 .9096 m .38724 .90901 L .38495 .90688 L F
0 g
.38159 .90868 m
.38593 .9096 L
s
.39749 .91494 m .38724 .90901 L .38593 .9096 L 0 .436 .236 r
F
0 g
.38593 .9096 m
.38844 .91155 L
s
.70542 .89275 m .71771 .89005 L .7161 .88895 L 0 1 .289 r
F
0 g
.71568 .89197 m
.71771 .89005 L
s
.71771 .89005 m
.72216 .88984 L
s
.37482 .90475 m .36523 .89877 L .36371 .9002 L 0 .681 .378 r
F
.37482 .90475 m .36966 .89927 L .36523 .89877 L F
0 g
.36371 .9002 m
.36593 .90254 L
s
.37482 .90475 m .37403 .90138 L .36966 .89927 L 0 .681 .378 r
F
.37482 .90475 m .37624 .90373 L .37403 .90138 L F
0 g
.3704 .90424 m
.37482 .90475 L
s
.37482 .90475 m
.37712 .90687 L
s
.29966 .87976 m .28819 .87984 L .29385 .88117 L 0 1 .515 r
F
0 g
.29385 .88117 m
.2972 .88036 L
s
.29385 .88117 m
.29723 .88457 L
s
.4112 .7459 m .40211 .74248 L .40496 .7464 L 0 1 .45 r
F
0 g
.40334 .75335 m
.40496 .7464 L
s
.53431 .98634 m
.53468 .98689 L
s
.53501 .9874 m
.53531 .98784 L
s
.53569 .98842 m
.53605 .98897 L
s
.53648 .98962 m
.53671 .98997 L
s
.50642 .95743 m
.50642 .95743 L
s
.50642 .95744 m
.50642 .95743 L
s
.51913 .94836 m
.51916 .94836 L
s
.51916 .94836 m
.51916 .94836 L
s
.51916 .94836 m
.51916 .94836 L
s
.51916 .94836 m
.51919 .94837 L
s
.51919 .94837 m
.51919 .94837 L
s
.51919 .94837 m
.51919 .94837 L
s
.51349 .98698 m .51247 .99218 L .51225 1.00271 L 0 .234 .248 r
F
0 g
.51226 .98307 m
.51247 .99218 L
s
.51247 .99218 m
.513 .98544 L
s
.29295 .58028 m .28438 .57671 L .27968 .58454 L 0 1 .508 r
F
.29295 .58028 m .2942 .56772 L .28438 .57671 L F
.29295 .58028 m .30397 .56197 L .2942 .56772 L F
.29295 .58028 m .30715 .5633 L .30397 .56197 L F
.29295 .58028 m .30242 .57116 L .30715 .5633 L F
0 g
.28849 .58824 m
.29295 .58028 L
s
.28321 .58601 m
.29295 .58028 L
s
.24929 .79885 m .24203 .78984 L .23808 .7968 L 0 1 .536 r
F
.24929 .79885 m .2483 .7853 L .24203 .78984 L F
.24929 .79885 m .25269 .78622 L .2483 .7853 L F
.24929 .79885 m .25311 .79204 L .25269 .78622 L F
0 g
.24305 .80336 m
.24929 .79885 L
s
.24929 .79885 m
.24983 .80451 L
s
.39749 .91494 m .39164 .9104 L .38724 .90901 L 0 .436 .236 r
F
.39749 .91494 m .39619 .91284 L .39164 .9104 L F
.39749 .91494 m .39869 .91479 L .39619 .91284 L F
.40905 .92054 m .39869 .91479 L .39749 .91494 L 0 .317 .204 r
F
0 g
.3931 .91355 m
.39749 .91494 L
s
.39749 .91494 m
.40009 .91663 L
s
.70021 .59502 m .72174 .59635 L .71734 .59336 L 0 1 .49 r
F
0 g
.72174 .59635 m
.7305 .59761 L
s
.5862 .65396 m .5905 .65642 L .58325 .65132 L 0 .187 .18 r
F
.5862 .65396 m .59857 .66235 L .5905 .65642 L F
.5862 .65396 m .60106 .66463 L .6031 .66587 L F
.5862 .65396 m .59383 .65953 L .60106 .66463 L F
0 g
.58172 .65056 m
.5862 .65396 L
s
.582 .6507 m
.5862 .65396 L
s
.5251 .96717 m .53356 .98335 L .52874 .97401 L 0 .083 .185 r
F
.5251 .96717 m .53712 .9904 L .53356 .98335 L F
.5251 .96717 m .53704 .99045 L .53712 .9904 L F
.5251 .96717 m .53338 .98358 L .53704 .99045 L F
.5251 .96717 m .52861 .97441 L .53338 .98358 L F
0 g
.52372 .96493 m
.5251 .96717 L
s
.52547 .9682 m
.52553 .9683 L
s
.52543 .96812 m
.52547 .9682 L
s
.57455 .6469 m
.58167 .65045 L
s
.51447 1.05055 m .51643 1.06111 L .51616 1.05726 L 0 .03 .161 r
F
.51939 1.06354 m .51643 1.06111 L .51848 1.06838 L 0 0 .143 r
F
.51939 1.06354 m .51616 1.05726 L .51643 1.06111 L F
0 g
.51479 1.05977 m
.51643 1.06111 L
s
.51414 1.03648 m .51266 1.03226 L .5114 1.03287 L 0 .092 .191 r
F
0 g
.51045 1.02596 m
.5114 1.03287 L
s
.36371 .9002 m .35468 .89433 L .35306 .89614 L 0 .845 .429 r
F
.36371 .9002 m .35905 .89438 L .35468 .89433 L F
.36371 .9002 m .36324 .89627 L .35905 .89438 L F
.36371 .9002 m .36523 .89877 L .36324 .89627 L F
0 g
.35935 .90014 m
.36371 .9002 L
s
.7161 .88895 m .72846 .88646 L .72678 .88513 L 0 1 .288 r
F
0 g
.72648 .88848 m
.72846 .88646 L
s
.50535 .63079 m .49858 .63011 L .49891 .63043 L 0 .603 .211 r
F
.50535 .63079 m .50489 .63015 L .49858 .63011 L F
0 g
.493 .63125 m
.49891 .63043 L
s
.50535 .63079 m .51364 .63052 L .50489 .63015 L 0 .603 .211 r
F
.50535 .63079 m .52009 .63088 L .51364 .63052 L F
.50535 .63079 m .51993 .63099 L .52009 .63088 L F
0 g
.51995 .63098 m
.52111 .63117 L
s
.50535 .63079 m .51362 .63096 L .51993 .63099 L 0 .603 .211 r
F
0 g
.4994 .63073 m
.50535 .63079 L
s
.49891 .63043 m
.50535 .63079 L
s
.52607 .89679 m .52663 .87378 L .52549 .88524 L 0 .64 .307 r
F
.5212 .88853 m .52549 .88524 L .52663 .87378 L 0 .668 .315 r
F
0 g
.52629 .87017 m
.52663 .87378 L
s
.52663 .87378 m
.52927 .86802 L
s
.59383 .65953 m
.59954 .66355 L
s
.52323 .95533 m .52998 .95667 L .52601 .95466 L 0 .292 .247 r
F
.52323 .95533 m .53337 .96386 L .52998 .95667 L F
.52323 .95533 m .53391 .97145 L .53337 .96386 L F
.52323 .95533 m .53112 .97211 L .53391 .97145 L F
0 g
.53267 .95647 m
.53488 .95547 L
s
.52323 .95533 m .52687 .96541 L .53112 .97211 L 0 .292 .247 r
F
0 g
.52298 .95868 m
.52385 .95938 L
s
.52323 .95533 m
.52329 .95532 L
s
.52284 .95487 m
.52323 .95533 L
s
.52541 .96776 m
.52552 .96797 L
s
.5254 .96773 m
.52541 .96776 L
s
.52528 .96752 m
.5254 .96773 L
s
.52524 .96743 m
.52528 .96752 L
s
.5251 .96717 m
.52524 .96743 L
s
.35147 .71684 m .35189 .70098 L .34742 .70636 L 0 1 .232 r
F
0 g
.35189 .70098 m
.3522 .70178 L
s
.4112 .7459 m .40435 .73599 L .40211 .74248 L 0 1 .45 r
F
.4112 .7459 m .41019 .73127 L .40435 .73599 L F
.4112 .7459 m .41644 .73076 L .41019 .73127 L F
.4112 .7459 m .41893 .73481 L .41644 .73076 L F
.4112 .7459 m .41668 .7413 L .41893 .73481 L F
0 g
.40923 .75224 m
.4112 .7459 L
s
.40496 .7464 m
.4112 .7459 L
s
.51548 .90575 m .51858 .90256 L .51924 .89324 L 0 .577 .327 r
F
.51548 .90575 m .51697 .90792 L .51858 .90256 L F
0 g
.51424 .90991 m
.51548 .90575 L
s
.51449 .89706 m
.51548 .90575 L
s
.53209 1.10222 m .52916 1.09545 L .52765 1.09148 L 0 .354 0 r
F
0 g
.52765 1.09148 m
.52765 1.09148 L
s
.52414 .95807 m
.52414 .95807 L
s
.30289 .7896 m .29652 .78153 L .29211 .78799 L 0 1 .517 r
F
.30289 .7896 m .30297 .77703 L .29652 .78153 L F
.30289 .7896 m .30716 .77749 L .30297 .77703 L F
.30289 .7896 m .30711 .78289 L .30716 .77749 L F
0 g
.29645 .79408 m
.30289 .7896 L
s
.74383 .81897 m .75508 .81892 L .74986 .82764 L 0 .239 .087 r
F
0 g
.74383 .81897 m
.74415 .82086 L
s
.74342 .81974 m
.74383 .81897 L
s
.40578 .7823 m .3967 .77946 L .39994 .78017 L 0 0 0 r
F
0 g
.39994 .78017 m
.40578 .7823 L
s
.4049 .7812 m
.40578 .7823 L
s
.40578 .7823 m
.40578 .7823 L
s
.35952 .72992 m .36138 .72609 L .36051 .71533 L 0 .727 .319 r
F
0 g
.36052 .71524 m
.3607 .71532 L
s
.26493 .70601 m .25478 .70068 L .25304 .70671 L 0 1 .528 r
F
0 g
.246 .70947 m
.25304 .70671 L
s
.56529 .91694 m
.56542 .91037 L
s
.43113 .74509 m .42266 .7409 L .42514 .74497 L 0 1 .451 r
F
.43113 .74509 m .42521 .73484 L .42266 .7409 L F
0 g
.42317 .75132 m
.42514 .74497 L
s
.43113 .74509 m .43111 .73083 L .42521 .73484 L 0 1 .451 r
F
.43113 .74509 m .4371 .73095 L .43111 .73083 L F
.43113 .74509 m .43919 .73511 L .4371 .73095 L F
.43113 .74509 m .43663 .74117 L .43919 .73511 L F
0 g
.42514 .74497 m
.43113 .74509 L
s
.40905 .92054 m .403 .91659 L .39869 .91479 L 0 .317 .204 r
F
.40905 .92054 m .40755 .91913 L .403 .91659 L F
.40905 .92054 m .41014 .92082 L .40755 .91913 L F
.42061 .92632 m .41014 .92082 L .40905 .92054 L 0 0 0 r
F
0 g
.40905 .92054 m
.41173 .92197 L
s
.40475 .91874 m
.40905 .92054 L
s
.54543 1.00239 m
.54574 1.00279 L
s
.545 1.00183 m
.54543 1.00239 L
s
.54454 1.00125 m
.545 1.00183 L
s
.54359 1.00003 m
.54454 1.00125 L
s
.54339 .99979 m
.54359 1.00003 L
s
.54331 .99969 m
.54339 .99979 L
s
.54325 .9996 m
.54331 .99969 L
s
.54272 .99887 m
.54325 .9996 L
s
.54268 .99882 m
.54272 .99887 L
s
.54215 .99809 m
.54268 .99882 L
s
.54114 .99669 m
.54215 .99809 L
s
.54092 .99639 m
.54114 .99669 L
s
.54087 .99631 m
.54092 .99639 L
s
.54081 .99623 m
.54087 .99631 L
s
.43212 .79141 m .42485 .78983 L .42363 .78834 L 0 0 0 r
F
.43212 .79141 m .42951 .79242 L .42485 .78983 L F
.43212 .79141 m .435 .79491 L .42951 .79242 L F
.43212 .79141 m .43764 .79564 L .435 .79491 L F
.43212 .79141 m .4364 .79414 L .43764 .79564 L F
0 g
.42665 .78892 m
.43212 .79141 L
s
.27505 .71174 m .27116 .7003 L .26493 .70601 L 0 1 .523 r
F
.27505 .71174 m .27877 .69794 L .27116 .7003 L F
.27505 .71174 m .28264 .70051 L .27877 .69794 L F
.27505 .71174 m .28104 .70643 L .28264 .70051 L F
0 g
.26748 .71408 m
.27505 .71174 L
s
.27365 .71746 m
.27505 .71174 L
s
.5465 .63592 m .55462 .63835 L .56154 .64054 L 0 0 0 r
F
0 g
.55462 .63835 m
.55987 .63946 L
s
.51362 .63096 m
.51785 .63098 L
s
.53157 .9813 m
.5316 .98137 L
s
.5316 .98137 m
.53181 .98174 L
s
.53157 .9813 m
.53163 .9814 L
s
.53163 .9814 m
.5319 .9819 L
s
.29966 .87976 m .28559 .87624 L .28819 .87984 L 0 1 .515 r
F
0 g
.28304 .88148 m
.28819 .87984 L
s
.51977 .9498 m .52389 .94856 L .52136 .94886 L 0 .26 .298 r
F
.51977 .9498 m .52641 .95016 L .52389 .94856 L F
0 g
.51919 .94837 m
.52136 .94886 L
s
.51978 .9498 m
.51978 .9498 L
s
.51978 .9498 m
.51978 .9498 L
s
.51978 .9498 m
.52136 .94886 L
s
.51977 .9498 m .52723 .95258 L .52641 .95016 L 0 .26 .298 r
F
.51977 .9498 m .52564 .95353 L .52723 .95258 L F
.51977 .9498 m .52269 .95237 L .52564 .95353 L F
.51977 .9498 m .52018 .95077 L .52269 .95237 L F
0 g
.51834 .95051 m
.52018 .95077 L
s
.51976 .9498 m
.51977 .9498 L
s
.51977 .9498 m
.51978 .9498 L
s
.51349 .98698 m .51435 1.00914 L .51407 .99713 L 0 .234 .248 r
F
.51349 .98698 m .51382 1.0159 L .51435 1.00914 L F
0 g
.51422 .98894 m
.51422 .98913 L
s
.51382 .9928 m
.51382 .9928 L
s
.51382 .9928 m
.51382 .9928 L
s
.51382 .9928 m
.51391 .99429 L
s
.51391 .99429 m
.51391 .99429 L
s
.51391 .99429 m
.51391 .99429 L
s
.51391 .99429 m
.51392 .99451 L
s
.51392 .99451 m
.51392 .99452 L
s
.51392 .99452 m
.51392 .99452 L
s
.51392 .99452 m
.51395 .99503 L
s
.51395 .99503 m
.51395 .99503 L
s
.51395 .99503 m
.51395 .99503 L
s
.51349 .98698 m .51283 1.01288 L .51382 1.0159 L 0 .234 .248 r
F
0 g
.5138 .99248 m
.51382 .9928 L
s
.5138 .99248 m
.5138 .99248 L
s
.5138 .99248 m
.5138 .99248 L
s
.51372 .99106 m
.5138 .99248 L
s
.51372 .99106 m
.51372 .99106 L
s
.51372 .99106 m
.51372 .99106 L
s
.51363 .98943 m
.51372 .99106 L
s
.51363 .98943 m
.51363 .98943 L
s
.51363 .98943 m
.51363 .98943 L
s
.51361 .9891 m
.51363 .98943 L
s
.51361 .9891 m
.51361 .9891 L
s
.51361 .98909 m
.51361 .9891 L
s
.51356 .98814 m
.51361 .98909 L
s
.51356 .98814 m
.51356 .98814 L
s
.51356 .98814 m
.51356 .98814 L
s
.51352 .98759 m
.51356 .98814 L
s
.51352 .98759 m
.51352 .98759 L
s
.51352 .98759 m
.51352 .98759 L
s
.5135 .98714 m
.51352 .98759 L
s
.5135 .98714 m
.5135 .98714 L
s
.5135 .98714 m
.5135 .98714 L
s
.51421 .98891 m
.51422 .98894 L
s
.51365 .97612 m
.51421 .98891 L
s
.51349 .98698 m .51225 1.00271 L .51283 1.01288 L 0 .234 .248 r
F
0 g
.51349 .98698 m
.51365 .97612 L
s
.51349 .98698 m
.5135 .98714 L
s
.72678 .88513 m .74257 .88184 L .7408 .88007 L 0 1 .311 r
F
0 g
.73964 .88445 m
.74257 .88184 L
s
.35306 .89614 m .34413 .8902 L .3424 .89236 L 0 .973 .462 r
F
.35306 .89614 m .34857 .8899 L .34413 .8902 L F
.35306 .89614 m .35276 .89165 L .34857 .8899 L F
.35306 .89614 m .35468 .89433 L .35276 .89165 L F
0 g
.34863 .89644 m
.35306 .89614 L
s
.35306 .89614 m
.35506 .89862 L
s
.50245 .95781 m .49465 .95951 L .49901 .95818 L 0 .396 .102 r
F
.50245 .95781 m .49171 .96165 L .49465 .95951 L F
.50245 .95781 m .49215 .96317 L .49171 .96165 L F
.50245 .95781 m .4956 .9628 L .49215 .96317 L F
.50245 .95781 m .49975 .9608 L .4956 .9628 L F
.50245 .95781 m .50268 .95866 L .49975 .9608 L F
0 g
.50245 .95781 m
.50555 .95447 L
s
.49901 .95818 m
.50215 .95653 L
s
.49901 .95818 m
.50245 .95781 L
s
.50268 .95866 m
.50595 .95596 L
s
.54782 1.12486 m .55387 1.12898 L .55204 1.12976 L 0 .427 .024 r
F
.55709 1.14448 m .55387 1.12898 L .55831 1.13414 L 0 .524 .057 r
F
.55709 1.14448 m .55204 1.12976 L .55387 1.12898 L F
0 g
.55659 1.12732 m
.55831 1.13414 L
s
.55203 1.12317 m
.55387 1.12898 L
s
.55387 1.12898 m
.55831 1.13414 L
s
.5465 .63592 m .54153 .6344 L .54089 .63423 L 0 0 0 r
F
.5465 .63592 m .54846 .6366 L .54153 .6344 L F
.5465 .63592 m .55705 .63936 L .54846 .6366 L F
.5465 .63592 m .56154 .64054 L .56266 .64105 L F
0 g
.55462 .63835 m
.56154 .64054 L
s
.53993 .63371 m
.5465 .63592 L
s
.52511 .96646 m .52512 .96678 L .52874 .97401 L 0 .075 .181 r
F
0 g
.52512 .96678 m
.52524 .96702 L
s
.52406 .96518 m
.52512 .96678 L
s
.52552 .96797 m
.52566 .96822 L
s
.52599 .63198 m .52009 .63088 L .51993 .63099 L 0 0 0 r
F
0 g
.51785 .63098 m
.51993 .63099 L
s
.52599 .63198 m .52675 .63192 L .52009 .63088 L 0 0 0 r
F
.52599 .63198 m .53423 .6332 L .54089 .63423 L F
.52599 .63198 m .53547 .63341 L .52675 .63192 L F
.52599 .63198 m .54089 .63423 L .54153 .6344 L F
.52599 .63198 m .54153 .6344 L .53547 .63341 L F
0 g
.53423 .6332 m
.53993 .63371 L
s
.51993 .63099 m
.52599 .63198 L
s
.54163 .63445 m
.54308 .63489 L
s
.54136 .63437 m
.54163 .63445 L
s
.52008 .95897 m
.52018 .95909 L
s
.52018 .95909 m
.52018 .95909 L
s
.52018 .95909 m
.52018 .95909 L
s
.52018 .95909 m
.52147 .96058 L
s
.52147 .96058 m
.52147 .96058 L
s
.52147 .96058 m
.52147 .96058 L
s
.52008 .95896 m
.52008 .95897 L
s
.5215 .96182 m
.5215 .96182 L
s
.5215 .96181 m
.5215 .96182 L
s
.52133 .96148 m
.5215 .96181 L
s
.52133 .96148 m
.52133 .96148 L
s
.52133 .96148 m
.52133 .96148 L
s
.52122 .96126 m
.52133 .96148 L
s
.52122 .96126 m
.52122 .96126 L
s
.52077 .96034 m
.52122 .96126 L
s
.52076 .96034 m
.52077 .96034 L
s
.52076 .96034 m
.52076 .96034 L
s
.52008 .95897 m
.52076 .96034 L
s
.52008 .95896 m
.52008 .95897 L
s
.39596 .74387 m
.40211 .74248 L
s
.53423 .6332 m
.54089 .63423 L
s
.60499 .66941 m .6031 .66587 L .60106 .66463 L 0 .195 .2 r
F
0 g
.60106 .66463 m
.60111 .66468 L
s
.59954 .66355 m
.60106 .66463 L
s
.60499 .66941 m .61039 .67275 L .6031 .66587 L 0 .195 .2 r
F
0 g
.60111 .66468 m
.60495 .66937 L
s
.60499 .66941 m .61808 .68068 L .61039 .67275 L 0 .195 .2 r
F
0 g
.61338 .67827 m
.61585 .681 L
s
.60499 .66941 m .622 .68547 L .61808 .68068 L 0 .195 .2 r
F
0 g
.61585 .681 m
.61697 .68249 L
s
.60499 .66941 m .61954 .68392 L .622 .68547 L 0 .195 .2 r
F
0 g
.61697 .68249 m
.61743 .6831 L
s
.60499 .66941 m .61225 .67704 L .61954 .68392 L 0 .195 .2 r
F
0 g
.61225 .67704 m
.61275 .67759 L
s
.61275 .67759 m
.61338 .67827 L
s
.59974 .66403 m
.60499 .66941 L
s
.60495 .66937 m
.60499 .66941 L
s
.41819 .78623 m
.42363 .78834 L
s
.6865 .59907 m
.6866 .59907 L
s
.52018 .95077 m
.5202 .95078 L
s
.5202 .95078 m
.5202 .95078 L
s
.5202 .95078 m
.5202 .95078 L
s
.42061 .92632 m .41436 .92298 L .41182 .92171 L 0 0 0 r
F
.42061 .92632 m .4189 .92558 L .41436 .92298 L F
.42333 .92821 m .41436 .92298 L .4189 .92558 L 0 .156 .166 r
F
.42333 .92821 m .41643 .92403 L .41436 .92298 L F
.41643 .92403 m .4121 .92139 L .41436 .92298 L F
.41182 .92171 m .41436 .92298 L .41014 .92082 L 0 0 0 r
F
.42061 .92632 m .42158 .92701 L .4189 .92558 L F
.43217 .93219 m .42158 .92701 L .42061 .92632 L F
0 g
.42061 .92632 m
.42338 .92748 L
s
.52412 1.08196 m .52537 1.08688 L .52629 1.08888 L 0 0 .1 r
F
.52412 1.08196 m .52412 1.08337 L .52537 1.08688 L F
.38291 .74026 m .37309 .73804 L .37627 .74198 L 0 1 .431 r
F
0 g
.36247 .7488 m
.3688 .74459 L
s
.7408 .88007 m .75406 .87814 L .75222 .87595 L 0 1 .358 r
F
0 g
.75406 .87814 m
.75891 .87878 L
s
.75198 .88079 m
.75406 .87814 L
s
.49265 .95616 m
.49389 .95633 L
s
.49029 .95584 m
.49265 .95616 L
s
.56147 .6473 m
.56665 .6441 L
s
.22686 .79463 m .21587 .79846 L .22041 .79931 L 0 1 .538 r
F
0 g
.22041 .79931 m
.22169 .80561 L
s
.34718 .76003 m
.34737 .76042 L
s
.52511 .96646 m .53351 .98248 L .5287 .97318 L 0 .075 .181 r
F
.52511 .96646 m .53714 .98974 L .53351 .98248 L F
.52511 .96646 m .53716 .9901 L .53714 .98974 L F
.52511 .96646 m .53356 .98335 L .53716 .9901 L F
0 g
.5343 .98632 m
.53447 .98662 L
s
.53366 .98513 m
.5343 .98632 L
s
.52511 .96646 m .52874 .97401 L .53356 .98335 L 0 .075 .181 r
F
0 g
.52511 .96646 m
.52528 .96679 L
s
.52528 .96679 m
.5254 .967 L
s
.52403 .96477 m
.52511 .96646 L
s
.52564 .96781 m
.52576 .96805 L
s
.52563 .9678 m
.52564 .96781 L
s
.52555 .96765 m
.52563 .9678 L
s
.52543 .96741 m
.52555 .96765 L
s
.52524 .96702 m
.52543 .96741 L
s
.53181 .98174 m
.53366 .98513 L
s
.51919 .91154 m .51924 .89324 L .51858 .90256 L 0 .553 .32 r
F
.51919 .91154 m .5212 .88853 L .51924 .89324 L F
0 g
.51824 .88456 m
.51924 .89324 L
s
.72707 1.09763 m .72398 1.09733 L .72556 1.09316 L 0 0 0 r
F
0 g
.72398 1.09733 m
.72556 1.09316 L
s
.71869 1.09605 m
.72556 1.09316 L
s
.51939 1.06354 m .51848 1.06838 L .52094 1.07424 L 0 0 .143 r
F
0 g
.51643 1.06111 m
.51848 1.06838 L
s
.51685 1.06579 m
.51848 1.06838 L
s
.4424 .7416 m
.44513 .73557 L
s
.43663 .74117 m
.4424 .7416 L
s
.49106 .71078 m .49746 .70766 L .50202 .70212 L 0 1 .457 r
F
0 g
.49746 .70766 m
.50089 .7035 L
s
.3424 .89236 m .33355 .88639 L .33174 .88886 L 0 1 .484 r
F
.3424 .89236 m .33807 .88574 L .33355 .88639 L F
.3424 .89236 m .34227 .88736 L .33807 .88574 L F
.3424 .89236 m .34413 .8902 L .34227 .88736 L F
0 g
.33789 .893 m
.3424 .89236 L
s
.3424 .89236 m
.34433 .89503 L
s
.83102 .96487 m .83078 .9751 L .83402 .98073 L 0 1 .46 r
F
0 g
.82935 .9893 m
.83402 .98073 L
s
.47845 .95241 m .46737 .95025 L .46687 .94854 L 0 .321 .069 r
F
.47845 .95241 m .47116 .95268 L .46737 .95025 L F
.47845 .95241 m .47571 .95419 L .47116 .95268 L F
.47845 .95241 m .47883 .95407 L .47571 .95419 L F
0 g
.47845 .95241 m
.48167 .95184 L
s
.47467 .94999 m
.47845 .95241 L
s
.32501 .56104 m .31193 .56527 L .3151 .56656 L 0 1 .495 r
F
0 g
.31062 .57454 m
.3151 .56656 L
s
.32501 .56104 m .31736 .55797 L .31193 .56527 L 0 1 .495 r
F
.32501 .56104 m .3278 .54951 L .31736 .55797 L F
.32501 .56104 m .33773 .54398 L .3278 .54951 L F
.32501 .56104 m .34052 .54506 L .33773 .54398 L F
.32501 .56104 m .33506 .55238 L .34052 .54506 L F
0 g
.31985 .56845 m
.32501 .56104 L
s
.3151 .56656 m
.32501 .56104 L
s
.52077 .95221 m .52564 .95353 L .52269 .95237 L 0 .225 .277 r
F
.52077 .95221 m .52842 .95623 L .52564 .95353 L F
.52077 .95221 m .52918 .95868 L .52842 .95623 L F
0 g
.52329 .95532 m
.52445 .95504 L
s
.52077 .95221 m .52725 .95852 L .52918 .95868 L 0 .225 .277 r
F
.52077 .95221 m .52392 .95587 L .52725 .95852 L F
0 g
.5202 .95078 m
.5202 .95079 L
s
.52188 .95741 m
.5235 .95823 L
s
.52212 .95768 m
.5226 .95825 L
s
.5213 .95752 m
.52253 .9588 L
s
.52253 .9588 m
.52277 .95904 L
s
.52077 .95221 m .52115 .95317 L .52392 .95587 L 0 .225 .277 r
F
0 g
.52034 .95339 m
.52167 .95456 L
s
.51832 .95052 m
.52077 .95221 L
s
.51895 .95217 m
.52115 .95317 L
s
.5202 .95079 m
.52269 .95237 L
s
.52077 .95221 m
.52269 .95237 L
s
.28559 .87624 m .27587 .87701 L .28049 .87806 L 0 1 .516 r
F
0 g
.28049 .87806 m
.2834 .87702 L
s
.28049 .87806 m
.28304 .88147 L
s
.54345 1.00063 m
.54354 1.00078 L
s
.54292 .99975 m
.54345 1.00063 L
s
.54279 .99954 m
.54292 .99975 L
s
.54233 .99876 m
.54279 .99954 L
s
.54123 .99694 m
.54233 .99876 L
s
.54099 .99653 m
.54123 .99694 L
s
.54088 .99636 m
.54099 .99653 L
s
.54081 .99623 m
.54088 .99636 L
s
.77984 1.04039 m .78958 1.02975 L .78512 1.03353 L 0 1 .277 r
F
.76877 1.05063 m .77984 1.04039 L .77843 1.03958 L 0 1 .213 r
F
.75222 .87595 m .76556 .87449 L .76364 .87186 L 0 1 .396 r
F
0 g
.76556 .87449 m
.77046 .87547 L
s
.76353 .87745 m
.76556 .87449 L
s
.43217 .93219 m .42572 .92949 L .42158 .92701 L 0 0 0 r
F
.43217 .93219 m .43026 .9321 L .42572 .92949 L F
.43217 .93219 m .43302 .93326 L .43026 .9321 L F
.44373 .93802 m .43302 .93326 L .43217 .93219 L 0 .118 0 r
F
0 g
.42803 .92972 m
.43217 .93219 L
s
.43217 .93219 m
.43502 .93308 L
s
.62185 .61568 m .61926 .61202 L .61712 .61435 L 0 1 .451 r
F
.62185 .61568 m .62751 .61011 L .61926 .61202 L F
.62185 .61568 m .63636 .60989 L .62751 .61011 L F
.73925 .5942 m .75693 .59455 L .74803 .59072 L 0 1 .501 r
F
0 g
.75693 .59455 m
.76077 .59828 L
s
.61225 .67704 m
.61831 .68276 L
s
.51136 1.00832 m .51172 1.02355 L .51193 1.01616 L 0 .188 .235 r
F
0 g
.51136 1.00832 m
.51225 1.00271 L
s
.81803 .99647 m .82719 .98496 L .82264 .98792 L 0 1 .446 r
F
.80672 1.00448 m .81803 .99647 L .81582 .99263 L 0 1 .427 r
F
.52607 .89679 m .53225 .88334 L .53166 .8718 L 0 .64 .307 r
F
0 g
.53166 .8718 m
.53304 .86812 L
s
.51562 .9816 m
.51562 .9816 L
s
.75772 1.06234 m .76632 1.05532 L .76877 1.05063 L 0 .955 .188 r
F
0 g
.76123 1.06192 m
.76632 1.05532 L
s
.76632 1.05532 m
.76775 1.05609 L
s
.52498 .96547 m .52505 .9659 L .5287 .97318 L 0 .068 .178 r
F
0 g
.52505 .9659 m
.52521 .96622 L
s
.52483 .96802 m
.52831 .97442 L
s
.52513 .96821 m
.52831 .97442 L
s
.524 .96439 m
.52505 .9659 L
s
.51718 .92875 m .5176 .9149 L .51694 .92204 L 0 .446 .327 r
F
0 g
.5157 .9262 m
.51694 .92204 L
s
.52166 .95367 m
.52167 .95367 L
s
.52166 .95367 m
.52166 .95367 L
s
.5212 .95321 m
.52166 .95367 L
s
.5212 .95321 m
.5212 .95321 L
s
.5212 .95321 m
.5212 .95321 L
s
.52115 .95317 m
.5212 .95321 L
s
.52115 .95317 m
.52115 .95317 L
s
.53447 .98662 m
.53461 .98686 L
s
.53461 .98686 m
.53464 .98691 L
s
.51697 .90792 m
.51858 .90256 L
s
.5212 .88853 m .52316 .89156 L .52549 .88524 L 0 .668 .315 r
F
.51919 .91154 m .52316 .89156 L .5212 .88853 L 0 .553 .32 r
F
0 g
.51924 .89324 m
.5212 .88853 L
s
.52022 .87797 m
.5212 .88853 L
s
.38291 .74026 m .3752 .73011 L .37309 .73804 L 0 1 .431 r
F
.38291 .74026 m .38121 .72345 L .3752 .73011 L F
.38291 .74026 m .38786 .72173 L .38121 .72345 L F
.38291 .74026 m .39071 .72607 L .38786 .72173 L F
.38291 .74026 m .38858 .73402 L .39071 .72607 L F
0 g
.38105 .74764 m
.38291 .74026 L
s
.37627 .74198 m
.38291 .74026 L
s
.66937 .74639 m
.66941 .74624 L
s
.50214 .95906 m
.50268 .95866 L
s
.51803 .93498 m
.51844 .93458 L
s
.52355 .95833 m
.52355 .95834 L
s
.52355 .95833 m
.52355 .95833 L
s
.5235 .95823 m
.52355 .95833 L
s
.50697 .95889 m
.50697 .95889 L
s
.52385 .95938 m
.52388 .95943 L
s
.52458 .67478 m .53785 .66684 L .53847 .66332 L 0 1 .48 r
F
.52458 .67478 m .5319 .67175 L .53785 .66684 L F
0 g
.53785 .66684 m
.54278 .66715 L
s
.5319 .67175 m
.53692 .6723 L
s
.5319 .67175 m
.53785 .66684 L
s
.52498 .96547 m .53323 .98093 L .52849 .9719 L 0 .068 .178 r
F
.52498 .96547 m .5369 .98824 L .53323 .98093 L F
.52498 .96547 m .53703 .98895 L .5369 .98824 L F
.52498 .96547 m .53351 .98248 L .53703 .98895 L F
0 g
.53503 .98752 m
.53512 .98768 L
s
.52498 .96547 m .5287 .97318 L .53351 .98248 L 0 .068 .178 r
F
0 g
.52397 .96394 m
.52498 .96547 L
s
.5254 .967 m
.5257 .96758 L
s
.5257 .96758 m
.52574 .96765 L
s
.52553 .9683 m
.52718 .97157 L
s
.52526 .96816 m
.5273 .97197 L
s
.52521 .96622 m
.52545 .9667 L
s
.62751 .61011 m .64492 .60822 L .6475 .60621 L 0 1 .473 r
F
.62751 .61011 m .63636 .60989 L .64492 .60822 L F
0 g
.64492 .60822 m
.64915 .60995 L
s
.63636 .60989 m
.64105 .61121 L
s
.63636 .60989 m
.64492 .60822 L
s
.75772 1.06234 m .75537 1.06625 L .75688 1.06606 L 0 .955 .188 r
F
0 g
.75105 1.07082 m
.75688 1.06606 L
s
.76364 .87186 m .77706 .87089 L .77507 .86781 L 0 1 .429 r
F
0 g
.77508 .87417 m
.77706 .87089 L
s
.77706 .87089 m
.78201 .87224 L
s
.28559 .87624 m .27412 .87349 L .27587 .87701 L 0 1 .516 r
F
0 g
.27148 .87906 m
.27587 .87701 L
s
.48021 .81666 m .47419 .81498 L .47603 .81397 L 0 .311 .018 r
F
0 g
.47473 .81031 m
.47603 .81397 L
s
.48021 .81666 m .47596 .8194 L .47419 .81498 L 0 .311 .018 r
F
.48021 .81666 m .48017 .82427 L .47596 .8194 L F
.48021 .81666 m .48437 .82697 L .48017 .82427 L F
.48021 .81666 m .48573 .82569 L .48437 .82697 L F
.48021 .81666 m .48394 .82127 L .48573 .82569 L F
0 g
.47879 .81154 m
.48021 .81666 L
s
.47603 .81397 m
.48021 .81666 L
s
.27492 .58558 m
.27968 .58455 L
s
.27968 .58454 m
.28438 .57671 L
s
.39182 .77784 m .38493 .77604 L .38827 .7768 L 0 0 0 r
F
.39182 .77784 m .38354 .77599 L .38493 .77604 L F
.39182 .77784 m .38502 .77667 L .38354 .77599 L F
0 g
.37914 .77394 m
.38492 .77604 L
s
.38492 .77604 m
.38493 .77604 L
s
.39182 .77784 m .38858 .77771 L .38502 .77667 L 0 0 0 r
F
0 g
.38769 .77601 m
.38827 .7768 L
s
.38827 .7768 m
.38827 .7768 L
s
.39182 .77784 m .39183 .77841 L .38858 .77771 L 0 0 0 r
F
.39182 .77784 m .39322 .77846 L .39183 .77841 L F
0 g
.39182 .77784 m
.39327 .77791 L
s
.38827 .7768 m
.39182 .77784 L
s
.51718 .92875 m .51919 .91154 L .5176 .9149 L 0 .446 .327 r
F
.51718 .92875 m .52066 .9142 L .51919 .91154 L F
.51718 .92875 m .52091 .92092 L .52066 .9142 L F
0 g
.51757 .91461 m
.5176 .9149 L
s
.51697 .90792 m
.51757 .91461 L
s
.51718 .92875 m .51976 .92721 L .52091 .92092 L 0 .446 .327 r
F
.51718 .92875 m .51816 .93057 L .51976 .92721 L F
0 g
.51595 .93117 m
.51718 .92875 L
s
.51694 .92204 m
.51718 .92875 L
s
.51803 .93498 m
.51816 .93057 L
s
.44373 .93802 m .43707 .93597 L .43302 .93326 L 0 .118 0 r
F
.44373 .93802 m .44162 .93852 L .43707 .93597 L F
.44373 .93802 m .44447 .93939 L .44162 .93852 L F
.4553 .94357 m .44447 .93939 L .44373 .93802 L 0 .216 .005 r
F
0 g
.43968 .93531 m
.44373 .93802 L
s
.44373 .93802 m
.44667 .9386 L
s
.48687 .7167 m
.49106 .71078 L
s
.48156 .7155 m
.48687 .7167 L
s
.6436 .54593 m .63974 .53943 L .63751 .53786 L 0 .209 .208 r
F
0 g
.63685 .53732 m
.63751 .53786 L
s
.6436 .54593 m .64953 .54986 L .63974 .53943 L 0 .209 .208 r
F
.6436 .54593 m .66035 .56221 L .64953 .54986 L F
.6436 .54593 m .66645 .57029 L .66035 .56221 L F
.6436 .54593 m .66376 .5687 L .66645 .57029 L F
0 g
.65972 .56586 m
.66104 .56776 L
s
.6436 .54593 m .65396 .55826 L .66376 .5687 L 0 .209 .208 r
F
0 g
.65396 .55826 m
.65972 .56586 L
s
.63549 .53661 m
.6436 .54593 L
s
.63751 .53786 m
.6436 .54593 L
s
.6468 .74619 m .64829 .73845 L .64507 .73575 L 0 .289 .306 r
F
0 g
.64422 .7343 m
.64507 .73575 L
s
.6468 .74619 m .65508 .75274 L .64829 .73845 L 0 .289 .306 r
F
0 g
.64185 .7345 m
.6468 .74619 L
s
.64507 .73575 m
.6468 .74619 L
s
.36764 .73992 m .36059 .73555 L .36387 .73923 L 0 1 .398 r
F
.36764 .73992 m .35952 .72992 L .36059 .73555 L F
.36764 .73992 m .36138 .72609 L .35952 .72992 L F
.36764 .73992 m .36515 .72678 L .36138 .72609 L F
0 g
.36051 .71533 m
.36138 .72609 L
s
.36247 .7488 m
.36386 .73927 L
s
.36386 .73927 m
.36387 .73923 L
s
.36764 .73992 m .36832 .73153 L .36515 .72678 L 0 1 .398 r
F
.36764 .73992 m .36939 .73716 L .36832 .73153 L F
0 g
.36764 .73992 m
.3688 .74458 L
s
.36387 .73923 m
.36764 .73992 L
s
.36939 .73716 m
.37308 .73805 L
s
.65275 .82558 m .6565 .81418 L .65261 .80716 L 0 .284 .256 r
F
0 g
.65261 .80716 m
.65261 .80818 L
s
.65261 .80818 m
.65266 .81424 L
s
.65266 .81424 m
.65274 .82409 L
s
.65594 .82009 m
.65607 .83448 L
s
.65252 .80689 m
.65261 .80716 L
s
.49106 .71078 m .50202 .70212 L .5017 .69785 L 0 1 .457 r
F
0 g
.50202 .70212 m
.50708 .70296 L
s
.50089 .7035 m
.50202 .70212 L
s
.52169 .95457 m .52725 .95852 L .52392 .95587 L 0 .186 .253 r
F
.52169 .95457 m .53027 .9623 L .52725 .95852 L F
0 g
.51967 .95387 m
.52042 .95439 L
s
.51954 .95378 m
.52007 .95433 L
s
.52169 .95457 m .53096 .96468 L .53027 .9623 L 0 .186 .253 r
F
.52169 .95457 m .52871 .96338 L .53096 .96468 L F
0 g
.52042 .95439 m
.52093 .95474 L
s
.52007 .95433 m
.52053 .9548 L
s
.52169 .95457 m .52504 .95927 L .52871 .96338 L 0 .186 .253 r
F
0 g
.52267 .96007 m
.52267 .96007 L
s
.52244 .95971 m
.52267 .96007 L
s
.52347 .9615 m
.52354 .96159 L
s
.52264 .96002 m
.52355 .96108 L
s
.52169 .95457 m .52203 .9555 L .52504 .95927 L 0 .186 .253 r
F
0 g
.52243 .95676 m
.5225 .95683 L
s
.52235 .95667 m
.52243 .95676 L
s
.5226 .95825 m
.52274 .95841 L
s
.52137 .95645 m
.52253 .95747 L
s
.52253 .95747 m
.52263 .95756 L
s
.52167 .95456 m
.52169 .95457 L
s
.52199 .95547 m
.52203 .9555 L
s
.52093 .95474 m
.52199 .95547 L
s
.52053 .9548 m
.52235 .95667 L
s
.52301 .95498 m
.52392 .95587 L
s
.52301 .95498 m
.52301 .95498 L
s
.52167 .95367 m
.52301 .95498 L
s
.52298 .95532 m
.52392 .95587 L
s
.52298 .95532 m
.52298 .95532 L
s
.52248 .95503 m
.52298 .95532 L
s
.52248 .95503 m
.52248 .95503 L
s
.52248 .95503 m
.52248 .95503 L
s
.52191 .9547 m
.52248 .95503 L
s
.52191 .9547 m
.52191 .9547 L
s
.52191 .9547 m
.52191 .9547 L
s
.52169 .95457 m
.52191 .9547 L
s
.52169 .95457 m
.52169 .95457 L
s
.52205 .95866 m
.52349 .96049 L
s
.34092 .76713 m
.34713 .76207 L
s
.41668 .7413 m
.41849 .7361 L
s
.41668 .7413 m
.42266 .7409 L
s
.7519 .64668 m .76137 .64138 L .75324 .64676 L 0 0 0 r
F
0 g
.75084 .64781 m
.7519 .64668 L
s
.74399 .65296 m
.74448 .65258 L
s
.75004 .64816 m
.7519 .64668 L
s
.51382 1.0159 m .51172 1.02355 L .51266 1.03226 L 0 .162 .222 r
F
.51382 1.0159 m .51193 1.01616 L .51172 1.02355 L F
0 g
.51045 1.02596 m
.51172 1.02355 L
s
.33174 .88886 m .32297 .88287 L .32106 .88562 L 0 1 .498 r
F
.33174 .88886 m .32756 .88191 L .32297 .88287 L F
.33174 .88886 m .33176 .88341 L .32756 .88191 L F
.33174 .88886 m .33355 .88639 L .33176 .88341 L F
0 g
.33017 .88918 m
.33174 .88886 L
s
.33174 .88886 m
.3336 .89169 L
s
.46687 .94854 m .45592 .94518 L .4553 .94357 L 0 .282 .042 r
F
.46687 .94854 m .4598 .94793 L .45592 .94518 L F
.46687 .94854 m .46434 .95 L .4598 .94793 L F
.46687 .94854 m .46737 .95025 L .46434 .95 L F
0 g
.463 .94579 m
.46687 .94854 L
s
.46687 .94854 m
.47 .94842 L
s
.29211 .78799 m .28117 .79153 L .28554 .79227 L 0 1 .526 r
F
0 g
.28554 .79227 m
.28625 .79781 L
s
.51472 .99064 m .51423 .9892 L .51407 .99713 L 0 .228 .245 r
F
0 g
.51411 .99518 m
.51411 .99518 L
s
.51411 .99518 m
.51411 .99518 L
s
.51411 .99518 m
.51412 .99472 L
s
.51412 .99472 m
.51412 .99472 L
s
.51412 .99472 m
.51412 .99471 L
s
.51412 .99471 m
.51412 .99452 L
s
.51412 .99452 m
.51412 .99452 L
s
.51412 .99452 m
.51412 .99451 L
s
.51412 .99451 m
.51415 .99322 L
s
.51415 .99322 m
.51415 .99322 L
s
.51415 .99322 m
.51415 .99322 L
s
.51415 .99322 m
.51415 .99291 L
s
.51415 .99291 m
.51415 .99291 L
s
.51415 .99291 m
.51415 .99291 L
s
.51415 .99291 m
.51418 .99179 L
s
.51418 .99179 m
.51418 .99179 L
s
.51418 .99179 m
.51418 .99179 L
s
.51418 .99179 m
.5142 .99056 L
s
.5142 .99056 m
.5142 .99056 L
s
.5142 .99056 m
.5142 .99056 L
s
.5142 .99056 m
.51421 .99004 L
s
.51421 .99004 m
.51421 .99004 L
s
.51421 .99004 m
.51421 .99003 L
s
.51421 .99003 m
.51422 .98969 L
s
.51422 .98969 m
.51422 .98969 L
s
.51422 .98969 m
.51422 .98969 L
s
.51422 .98969 m
.51422 .9894 L
s
.51422 .9894 m
.51422 .9894 L
s
.51422 .9894 m
.51422 .9894 L
s
.51422 .9894 m
.51423 .9892 L
s
.51422 .98913 m
.51423 .9892 L
s
.32372 .67116 m .31571 .67145 L .31936 .67155 L 0 1 .362 r
F
.32372 .67116 m .31469 .67053 L .31571 .67145 L F
.32372 .67116 m .31697 .66939 L .31469 .67053 L F
.32372 .67116 m .32135 .66901 L .31697 .66939 L F
.32372 .67116 m .32488 .66962 L .32135 .66901 L F
.32372 .67116 m .32589 .67054 L .32488 .66962 L F
0 g
.31936 .67155 m
.32372 .67116 L
s
.64293 .82387 m
.64308 .82249 L
s
.64315 .82174 m
.64353 .81799 L
s
.64206 .83243 m
.64293 .82387 L
s
.6395 .85754 m
.64206 .83243 L
s
.63886 .8638 m
.6395 .85754 L
s
.52473 .96422 m .52485 .96475 L .52849 .9719 L 0 .066 .178 r
F
0 g
.52394 .96351 m
.52485 .96475 L
s
.52574 .96765 m
.52587 .9679 L
s
.52498 .96547 m
.52524 .96595 L
s
.52239 .95594 m
.52239 .95594 L
s
.52239 .95594 m
.52239 .95594 L
s
.52208 .95556 m
.52239 .95594 L
s
.52208 .95556 m
.52208 .95556 L
s
.52208 .95556 m
.52208 .95556 L
s
.52206 .95554 m
.52208 .95556 L
s
.52203 .9555 m
.52206 .95554 L
s
.69742 .6652 m .69772 .65031 L .69423 .64817 L 0 .384 .321 r
F
0 g
.68531 .63109 m
.69423 .64817 L
s
.4553 .94357 m .44843 .94222 L .44447 .93939 L 0 .216 .005 r
F
.4553 .94357 m .45298 .9446 L .44843 .94222 L F
.4553 .94357 m .45592 .94518 L .45298 .9446 L F
0 g
.45134 .94076 m
.4553 .94357 L
s
.4553 .94357 m
.45833 .94384 L
s
.36832 .73153 m
.36939 .73716 L
s
.22686 .79463 m .21562 .79235 L .21587 .79846 L 0 1 .538 r
F
0 g
.21029 .80365 m
.21587 .79846 L
s
.50664 .6923 m .51354 .6892 L .51882 .68393 L 0 1 .469 r
F
0 g
.51354 .6892 m
.5186 .69004 L
s
.50715 .95935 m
.50715 .95933 L
s
.50715 .95933 m
.50715 .95933 L
s
.54468 .65856 m .55994 .64824 L .55468 .64785 L 0 1 .484 r
F
0 g
.55994 .64824 m
.56147 .6473 L
s
.69685 .72253 m .70658 .72753 L .69863 .70252 L 0 .444 .294 r
F
0 g
.69863 .70252 m
.69916 .7042 L
s
.69916 .7042 m
.70006 .70701 L
s
.70006 .70701 m
.7025 .71469 L
s
.69803 .69864 m
.69863 .70252 L
s
.69685 .72252 m
.69685 .72253 L
s
.77507 .86781 m .78856 .86737 L .78651 .86384 L 0 1 .456 r
F
0 g
.78663 .87096 m
.78856 .86737 L
s
.78856 .86737 m
.79357 .86906 L
s
.78881 .8146 m .80312 .80706 L .80006 .81234 L 0 0 .008 r
F
0 g
.80196 .80318 m
.80312 .80706 L
s
.80312 .80706 m
.80885 .80295 L
s
.52473 .96422 m .53274 .97867 L .52811 .97017 L 0 .066 .178 r
F
.52473 .96422 m .5364 .98586 L .53274 .97867 L F
.52473 .96422 m .53663 .98692 L .5364 .98586 L F
.52473 .96422 m .53323 .98093 L .53663 .98692 L F
0 g
.53464 .98691 m
.5357 .98867 L
s
.53415 .98594 m
.53503 .98752 L
s
.53402 .98571 m
.53415 .98594 L
s
.52473 .96422 m .52849 .9719 L .53323 .98093 L 0 .066 .178 r
F
0 g
.52569 .96718 m
.5257 .96719 L
s
.52545 .9667 m
.52569 .96718 L
s
.5239 .96301 m
.52473 .96422 L
s
.53209 1.10222 m .53519 1.10601 L .53672 1.11001 L 0 .354 0 r
F
0 g
.69112 .74906 m
.6976 .77125 L
s
.52094 1.07424 m .52412 1.08336 L .52336 1.08067 L 0 0 .129 r
F
0 g
.52247 1.08075 m
.52412 1.08336 L
s
.52412 1.08196 m .52336 1.08067 L .52412 1.08337 L 0 0 .1 r
F
0 g
.52412 1.08337 m
.52537 1.08688 L
s
.52412 1.08196 m .52629 1.08888 L .52629 1.08828 L 0 0 .1 r
F
0 g
.52629 1.08888 m
.52765 1.09147 L
s
.55909 .8929 m
.5591 .89223 L
s
.55283 .87189 m .55534 .88231 L .5593 .86848 L 0 .814 .263 r
F
0 g
.55534 .88231 m
.55654 .87812 L
s
.55654 .87812 m
.5593 .86848 L
s
.5591 .89223 m
.5593 .86848 L
s
.5503 .87543 m
.55093 .87971 L
s
.55276 .84673 m
.55283 .87189 L
s
.5579 .87338 m
.55883 .87867 L
s
.52251 .95685 m .52871 .96338 L .52504 .95927 L 0 .147 .228 r
F
0 g
.52355 .96108 m
.52369 .96124 L
s
.52354 .96159 m
.5237 .9618 L
s
.52251 .95685 m .53194 .96815 L .52871 .96338 L 0 .147 .228 r
F
.52251 .95685 m .53255 .9704 L .53194 .96815 L F
.52251 .95685 m .53001 .96796 L .53255 .9704 L F
.52251 .95685 m .52602 .96248 L .53001 .96796 L F
0 g
.5257 .96719 m
.52578 .96735 L
s
.52485 .96475 m
.52511 .96526 L
s
.52382 .96244 m
.52413 .96284 L
s
.5237 .9618 m
.52407 .96231 L
s
.52251 .95685 m .52282 .95772 L .52602 .96248 L 0 .147 .228 r
F
0 g
.52369 .96124 m
.52392 .9615 L
s
.52332 .95961 m
.52341 .9597 L
s
.52267 .96007 m
.52279 .96026 L
s
.52361 .96064 m
.52376 .96083 L
s
.52349 .96049 m
.52361 .96064 L
s
.5225 .95683 m
.52251 .95685 L
s
.5232 .95894 m
.52323 .95897 L
s
.52313 .95886 m
.5232 .95894 L
s
.52274 .95841 m
.52313 .95886 L
s
.52278 .95769 m
.52282 .95772 L
s
.52263 .95756 m
.52278 .95769 L
s
.52277 .95904 m
.52332 .95961 L
s
.52445 .95853 m
.52445 .95853 L
s
.52311 .95685 m
.52445 .95853 L
s
.52311 .95685 m
.52311 .95685 L
s
.52239 .95594 m
.52311 .95685 L
s
.52442 .95867 m
.52442 .95867 L
s
.52424 .9585 m
.52442 .95867 L
s
.52424 .9585 m
.52424 .9585 L
s
.52423 .9585 m
.52424 .9585 L
s
.52319 .95749 m
.52423 .9585 L
s
.52319 .95749 m
.52319 .95749 L
s
.52266 .95699 m
.52319 .95749 L
s
.52266 .95699 m
.52266 .95699 L
s
.52266 .95699 m
.52266 .95699 L
s
.52261 .95694 m
.52266 .95699 L
s
.52256 .95689 m
.52261 .95694 L
s
.52252 .95685 m
.52256 .95689 L
s
.52251 .95685 m
.52252 .95685 L
s
.49106 .71078 m .4849 .70563 L .48568 .70991 L 0 1 .457 r
F
.49106 .71078 m .48946 .70008 L .4849 .70563 L F
.49106 .71078 m .49632 .69697 L .48946 .70008 L F
.49106 .71078 m .5017 .69785 L .49632 .69697 L F
.78414 1.02366 m .78958 1.02975 L .79399 1.02118 L 0 1 .373 r
F
.78414 1.02366 m .78512 1.03353 L .78958 1.02975 L F
0 g
.78958 1.02975 m
.79091 1.03138 L
s
.34713 .76207 m
.34737 .76042 L
s
.51382 1.0159 m .51283 1.01288 L .51193 1.01616 L 0 .162 .222 r
F
0 g
.51136 1.00832 m
.51193 1.01616 L
s
.51225 1.00271 m
.51283 1.01288 L
s
.51414 1.03648 m .51447 1.05055 L .51574 1.04995 L 0 .092 .191 r
F
.65591 .60518 m .65397 .60115 L .65138 .60318 L 0 1 .463 r
F
.65591 .60518 m .66269 .60036 L .65397 .60115 L F
.65591 .60518 m .6717 .60133 L .66269 .60036 L F
0 g
.6717 .60133 m
.67893 .60088 L
s
.6717 .60133 m
.67619 .60334 L
s
.52314 .95819 m
.52314 .95819 L
s
.52294 .9579 m
.52314 .95819 L
s
.5229 .95784 m
.52294 .9579 L
s
.52289 .95783 m
.5229 .95784 L
s
.52287 .95779 m
.52289 .95783 L
s
.52287 .95779 m
.52287 .95779 L
s
.52287 .95779 m
.52287 .95779 L
s
.52282 .95772 m
.52287 .95779 L
s
.25478 .70068 m .24269 .70181 L .24683 .70374 L 0 1 .532 r
F
0 g
.246 .70947 m
.24683 .70374 L
s
.52436 .9627 m .52452 .96334 L .52811 .97017 L 0 .072 .181 r
F
0 g
.52413 .96284 m
.52452 .96334 L
s
.52578 .96735 m
.52591 .96763 L
s
.52524 .96595 m
.52552 .96646 L
s
.27412 .87349 m .26434 .87445 L .26895 .87547 L 0 1 .517 r
F
0 g
.26895 .87547 m
.27148 .87906 L
s
.50664 .6923 m .51882 .68393 L .51897 .68 L 0 1 .469 r
F
0 g
.51882 .68393 m
.52386 .68447 L
s
.51354 .6892 m
.51882 .68393 L
s
.54516 1.00406 m .54443 1.00227 L .54696 1.00434 L 0 .381 .015 r
F
0 g
.54443 1.00227 m
.5449 1.00265 L
s
.5449 1.00265 m
.54525 1.00294 L
s
.54525 1.00294 m
.54557 1.0032 L
s
.54557 1.0032 m
.54585 1.00343 L
s
.54585 1.00343 m
.54696 1.00434 L
s
.54354 1.00078 m
.54443 1.00227 L
s
.54574 1.00279 m
.54696 1.00434 L
s
.68499 .61697 m .68388 .60553 L .68077 .60353 L 0 .311 .329 r
F
0 g
.68077 .60353 m
.6815 .60586 L
s
.6815 .60586 m
.68216 .60797 L
s
.67893 .60088 m
.68077 .60353 L
s
.68499 .61697 m .69306 .62154 L .68388 .60553 L 0 .311 .329 r
F
0 g
.68216 .60797 m
.68475 .6162 L
s
.68499 .61697 m .70219 .64092 L .69306 .62154 L 0 .311 .329 r
F
.68499 .61697 m .70644 .65442 L .70219 .64092 L F
.68499 .61697 m .70295 .65299 L .70644 .65442 L F
0 g
.69038 .64772 m
.69343 .65528 L
s
.68499 .61697 m .69375 .63692 L .70295 .65299 L 0 .311 .329 r
F
0 g
.68469 .61638 m
.68499 .61697 L
s
.68475 .6162 m
.68499 .61697 L
s
.69423 .64817 m
.69524 .65355 L
s
.3752 .73011 m .36516 .72677 L .36832 .73153 L 0 1 .422 r
F
.52436 .9627 m .53203 .97571 L .52757 .968 L 0 .072 .181 r
F
.52436 .9627 m .53564 .98258 L .53203 .97571 L F
.52436 .9627 m .53597 .984 L .53564 .98258 L F
.52436 .9627 m .53274 .97867 L .53597 .984 L F
0 g
.5319 .9819 m
.53402 .98571 L
s
.52436 .9627 m .52811 .97017 L .53274 .97867 L 0 .072 .181 r
F
0 g
.52407 .96231 m
.52436 .9627 L
s
.52324 .95898 m .53001 .96796 L .52602 .96248 L 0 .113 .206 r
F
0 g
.52392 .9615 m
.524 .9616 L
s
.52324 .95898 m .5334 .9736 L .53001 .96796 L 0 .113 .206 r
F
.52324 .95898 m .53392 .97563 L .5334 .9736 L F
.52324 .95898 m .53112 .97211 L .53392 .97563 L F
.52324 .95898 m .52687 .96541 L .53112 .97211 L F
0 g
.5273 .97197 m
.52798 .97324 L
s
.52718 .97157 m
.52789 .97299 L
s
.52591 .96763 m
.52594 .96768 L
s
.52552 .96646 m
.52557 .96656 L
s
.52324 .95898 m .5235 .95979 L .52687 .96541 L 0 .113 .206 r
F
0 g
.524 .9616 m
.52404 .96164 L
s
.52347 .95976 m
.5235 .95979 L
s
.52341 .9597 m
.52347 .95976 L
s
.52383 .96091 m
.52384 .96093 L
s
.52376 .96083 m
.52383 .96091 L
s
.52388 .95943 m
.52436 .96038 L
s
.52323 .95897 m
.52324 .95898 L
s
.52428 .95988 m
.52473 .96086 L
s
.52445 .95853 m
.52504 .95927 L
s
.52442 .95867 m
.52504 .95927 L
s
.52371 .95904 m
.52371 .95904 L
s
.52314 .95819 m
.52371 .95904 L
s
.52473 .96422 m
.52499 .96467 L
s
.52362 .95946 m
.52362 .95946 L
s
.52362 .95946 m
.52362 .95946 L
s
.52342 .9592 m
.52362 .95946 L
s
.52337 .95915 m
.52342 .9592 L
s
.52337 .95915 m
.52337 .95915 L
s
.52331 .95907 m
.52337 .95915 L
s
.52324 .95898 m
.52331 .95907 L
s
.52324 .95898 m
.52324 .95898 L
s
.54285 .86591 m
.54343 .86979 L
s
.52363 .96001 m
.52371 .96014 L
s
.52361 .95997 m
.52363 .96001 L
s
.52355 .95988 m
.52361 .95997 L
s
.52355 .95988 m
.52355 .95988 L
s
.5235 .95979 m
.52355 .95988 L
s
.52386 .96095 m .52407 .96168 L .52757 .968 L 0 .087 .19 r
F
0 g
.52404 .96164 m
.52407 .96168 L
s
.59438 .62582 m .61356 .61825 L .60884 .61688 L 0 1 .465 r
F
0 g
.61356 .61825 m
.62185 .61568 L
s
.52386 .96095 m .53112 .97211 L .52687 .96541 L 0 .087 .19 r
F
.52386 .96095 m .53464 .97846 L .53112 .97211 L F
.52386 .96095 m .53507 .98021 L .53464 .97846 L F
.52386 .96095 m .53203 .97571 L .53507 .98021 L F
.52386 .96095 m .52757 .968 L .53203 .97571 L F
0 g
.52798 .97324 m
.52861 .97441 L
s
.52789 .97299 m
.52861 .97441 L
s
.52386 .96095 m
.52395 .96108 L
s
.52395 .96108 m
.52408 .96128 L
s
.52408 .96128 m
.52415 .96138 L
s
.52415 .96138 m
.5242 .96146 L
s
.5242 .96146 m
.52421 .96147 L
s
.5257 .96643 m
.52577 .96656 L
s
.52593 .96688 m
.52599 .967 L
s
.52577 .96656 m
.52593 .96688 L
s
.52599 .967 m
.52603 .96707 L
s
.52594 .96768 m
.52608 .96796 L
s
.52607 .96747 m
.52613 .96757 L
s
.52572 .96683 m
.52607 .96747 L
s
.52557 .96656 m
.52572 .96683 L
s
.52384 .96093 m
.52386 .96095 L
s
.52449 .96292 m
.52468 .96323 L
s
.52436 .9627 m
.52449 .96292 L
s
.52468 .96323 m
.52486 .96354 L
s
.52486 .96354 m
.52487 .96354 L
s
.52487 .96354 m
.52491 .96361 L
s
.52491 .96361 m
.525 .96377 L
s
.52525 .96513 m
.52538 .96536 L
s
.52499 .96467 m
.52525 .96513 L
s
.52538 .96536 m
.52548 .96554 L
s
.52511 .96526 m
.5257 .96643 L
s
.5253 .96483 m
.52534 .96489 L
s
.52478 .96383 m
.52504 .96432 L
s
.52452 .96334 m
.52478 .96383 L
s
.52504 .96432 m
.52516 .96455 L
s
.52516 .96455 m
.52523 .96469 L
s
.52523 .96469 m
.5253 .96483 L
s
.52443 .96232 m
.52455 .96254 L
s
.52441 .96229 m
.52443 .96232 L
s
.52432 .96212 m
.52441 .96229 L
s
.52422 .96195 m
.52432 .96212 L
s
.52407 .96168 m
.52422 .96195 L
s
.54357 1.1242 m .54024 1.11674 L .53879 1.11144 L 0 .449 .012 r
F
0 g
.53519 1.10601 m
.53879 1.11144 L
s
.56858 .87318 m
.57284 .87073 L
s
.78651 .86384 m .80008 .86391 L .79795 .85994 L 0 1 .476 r
F
0 g
.7982 .86781 m
.80008 .86391 L
s
.80008 .86391 m
.80513 .86595 L
s
.45664 .73279 m
.4599 .72685 L
s
.53187 .94493 m .53249 .95249 L .53595 .9592 L 0 .326 .244 r
F
0 g
.53267 .95647 m
.53544 .96011 L
s
.53187 .94493 m
.53413 .93447 L
s
.52866 .94125 m
.53187 .94493 L
s
.44962 .79979 m .44168 .79651 L .44442 .79694 L 0 .057 0 r
F
0 g
.44355 .79514 m
.44442 .79694 L
s
.51955 .96102 m
.51955 .96102 L
s
.51955 .96102 m
.51955 .96102 L
s
.36138 .72609 m
.36515 .72678 L
s
.3752 .73011 m .36752 .71827 L .36516 .72677 L 0 1 .422 r
F
.38389 .52419 m .37149 .52761 L .37385 .52839 L 0 1 .4 r
F
0 g
.36779 .53477 m
.37385 .52839 L
s
.38389 .52419 m .37836 .52234 L .37149 .52761 L 0 1 .4 r
F
.38389 .52419 m .38987 .5161 L .37836 .52234 L F
.38389 .52419 m .39993 .51189 L .38987 .5161 L F
.38389 .52419 m .40182 .51253 L .39993 .51189 L F
.38389 .52419 m .39494 .5178 L .40182 .51253 L F
0 g
.37737 .52943 m
.38389 .52419 L
s
.37385 .52839 m
.38389 .52419 L
s
.39494 .5178 m
.40465 .51334 L
s
.51939 1.06354 m .51742 1.05829 L .51616 1.05726 L 0 0 .143 r
F
0 g
.51447 1.05055 m
.51616 1.05726 L
s
.44513 .73557 m .4371 .73095 L .43919 .73511 L 0 1 .454 r
F
.44513 .73557 m .44022 .72511 L .4371 .73095 L F
0 g
.43663 .74117 m
.43919 .73511 L
s
.44513 .73557 m .44647 .7215 L .44022 .72511 L 0 1 .454 r
F
.44513 .73557 m .45241 .72196 L .44647 .7215 L F
.44513 .73557 m .45408 .72617 L .45241 .72196 L F
.44513 .73557 m .45096 .73201 L .45408 .72617 L F
0 g
.43919 .73511 m
.44513 .73557 L
s
.45096 .73201 m
.45664 .73279 L
s
.40578 .7823 m .39793 .78048 L .3967 .77946 L 0 0 0 r
F
.40578 .7823 m .40282 .78255 L .39793 .78048 L F
.40578 .7823 m .40869 .78469 L .40282 .78255 L F
.40578 .7823 m .4116 .78546 L .40869 .78469 L F
.40578 .7823 m .41035 .78443 L .4116 .78546 L F
0 g
.40578 .7823 m
.40578 .7823 L
s
.62283 .69032 m .622 .68547 L .61954 .68392 L 0 .243 .267 r
F
0 g
.61954 .68392 m
.62149 .68772 L
s
.61831 .68276 m
.61954 .68392 L
s
.62283 .69032 m .62927 .69432 L .622 .68547 L 0 .243 .267 r
F
.62283 .69032 m .63651 .70458 L .62927 .69432 L F
.62283 .69032 m .63979 .71099 L .63651 .70458 L F
0 g
.63125 .70337 m
.63265 .70601 L
s
.63265 .70601 m
.63306 .7067 L
s
.62283 .69032 m .63694 .70928 L .63979 .71099 L 0 .243 .267 r
F
0 g
.63306 .7067 m
.63421 .70865 L
s
.62283 .69032 m .62967 .70042 L .63694 .70928 L 0 .243 .267 r
F
0 g
.62967 .70042 m
.63125 .70337 L
s
.61743 .6831 m
.62283 .69032 L
s
.62149 .68772 m
.62283 .69032 L
s
.40435 .73599 m .39498 .7324 L .39783 .73648 L 0 1 .452 r
F
0 g
.39596 .74387 m
.39783 .73648 L
s
.32106 .88562 m .31236 .8796 L .31036 .8826 L 0 1 .507 r
F
.32106 .88562 m .31703 .87838 L .31236 .8796 L F
.32106 .88562 m .32124 .87976 L .31703 .87838 L F
.32106 .88562 m .32297 .88287 L .32124 .87976 L F
0 g
.31856 .88627 m
.32106 .88562 L
s
.32106 .88562 m
.32285 .88859 L
s
.34371 .75809 m .33802 .7598 L .34167 .76046 L 0 1 .405 r
F
.34371 .75809 m .33821 .75342 L .34179 .75632 L 0 .086 0 r
F
.34217 .75692 m .33821 .75342 L .34371 .75809 L F
.34852 .7525 m .34217 .75692 L .34371 .75809 L 0 1 .405 r
F
.34217 .75692 m .33802 .7598 L .34371 .75809 L F
.34826 .7623 m .34217 .75692 L .34371 .75809 L 0 .086 0 r
F
0 g
.34179 .75632 m
.34232 .75681 L
s
.34737 .76042 m
.34741 .76053 L
s
.34119 .75746 m
.34169 .7565 L
s
.27412 .87349 m .26265 .87079 L .26434 .87445 L 0 1 .517 r
F
0 g
.25992 .8767 m
.26434 .87445 L
s
.51644 .98358 m
.51644 .98359 L
s
.56971 .63698 m .58538 .63139 L .58693 .62884 L 0 1 .486 r
F
.56971 .63698 m .57801 .63488 L .58538 .63139 L F
0 g
.58538 .63139 m
.59019 .63193 L
s
.57801 .63488 m
.58307 .63527 L
s
.57801 .63488 m
.58538 .63139 L
s
.51472 .99064 m .51644 1.01538 L .51566 1.00185 L 0 .228 .245 r
F
.51472 .99064 m .51628 1.02333 L .51644 1.01538 L F
.51472 .99064 m .51529 1.02037 L .51628 1.02333 L F
.51472 .99064 m .51435 1.00914 L .51529 1.02037 L F
0 g
.5152 .99201 m
.5152 .99202 L
s
.51473 .99075 m
.51473 .99075 L
s
.51473 .99075 m
.51473 .99075 L
s
.51473 .99075 m
.51474 .99092 L
s
.51474 .99092 m
.51474 .99092 L
s
.51474 .99092 m
.51474 .99092 L
s
.51474 .99092 m
.51475 .99099 L
s
.51475 .99099 m
.51475 .99099 L
s
.51475 .99099 m
.51475 .99099 L
s
.51475 .99099 m
.51482 .99186 L
s
.51482 .99186 m
.51482 .99186 L
s
.51482 .99186 m
.51482 .99186 L
s
.51482 .99186 m
.51493 .99312 L
s
.51493 .99312 m
.51493 .99312 L
s
.51493 .99312 m
.51493 .99312 L
s
.51493 .99312 m
.51501 .99412 L
s
.51501 .99412 m
.51501 .99413 L
s
.51501 .99413 m
.51501 .99413 L
s
.51501 .99413 m
.51505 .99455 L
s
.51505 .99455 m
.51505 .99455 L
s
.51505 .99455 m
.51505 .99455 L
s
.51505 .99455 m
.51515 .99581 L
s
.51515 .99581 m
.51515 .99581 L
s
.51515 .99581 m
.51515 .99582 L
s
.51515 .99582 m
.51517 .996 L
s
.51517 .996 m
.51517 .996 L
s
.51517 .996 m
.51517 .996 L
s
.51472 .99064 m .51407 .99713 L .51435 1.00914 L 0 .228 .245 r
F
0 g
.51472 .99064 m
.51473 .99075 L
s
.51459 .9835 m
.51472 .99064 L
s
.51451 .97862 m
.5152 .99201 L
s
.51395 .99503 m
.51407 .99713 L
s
.51407 .99713 m
.51411 .99518 L
s
.47153 .72457 m
.47528 .71867 L
s
.73925 .5942 m .73877 .58895 L .73535 .59046 L 0 1 .501 r
F
.73925 .5942 m .74803 .59072 L .73877 .58895 L F
.51919 .91154 m .52377 .90054 L .52316 .89156 L 0 .553 .32 r
F
0 g
.52316 .89156 m
.52549 .88524 L
s
.50305 .95994 m .4956 .9628 L .49975 .9608 L 0 .406 .102 r
F
.50305 .95994 m .49289 .96549 L .4956 .9628 L F
.50305 .95994 m .49343 .96707 L .49289 .96549 L F
.50305 .95994 m .49675 .9662 L .49343 .96707 L F
.50305 .95994 m .50062 .96346 L .49675 .9662 L F
.50305 .95994 m .50332 .96078 L .50062 .96346 L F
0 g
.50305 .95994 m
.50595 .95596 L
s
.49975 .9608 m
.50214 .95906 L
s
.49975 .9608 m
.50305 .95994 L
s
.50332 .96078 m
.50642 .95744 L
s
.36058 .73556 m
.36058 .73556 L
s
.23808 .7968 m .23094 .7875 L .22686 .79463 L 0 1 .537 r
F
.23808 .7968 m .23731 .78288 L .23094 .7875 L F
.23808 .7968 m .24171 .78387 L .23731 .78288 L F
.23808 .7968 m .24203 .78984 L .24171 .78387 L F
0 g
.23173 .80138 m
.23808 .7968 L
s
.23808 .7968 m
.23852 .80258 L
s
.79795 .85994 m .81159 .86052 L .8094 .85612 L 0 1 .492 r
F
0 g
.80976 .86473 m
.81159 .86052 L
s
.81159 .86052 m
.8167 .86291 L
s
.39322 .77846 m
.3967 .77946 L
s
.3967 .77946 m
.39713 .77981 L
s
.35147 .71684 m .34176 .73543 L .34639 .72968 L 0 1 .232 r
F
.35147 .71684 m .34002 .73093 L .34176 .73543 L F
.35147 .71684 m .34233 .71919 L .34002 .73093 L F
.35147 .71684 m .34742 .70636 L .34233 .71919 L F
.35952 .72992 m .35147 .71685 L .35233 .72761 L 0 .727 .319 r
F
0 g
.53537 .98806 m
.5355 .98831 L
s
.53238 .98248 m
.53278 .98322 L
s
.53525 .98774 m
.5358 .98875 L
s
.33506 .55238 m
.3447 .5466 L
s
.38858 .73402 m
.38915 .73189 L
s
.40435 .73599 m .39749 .72582 L .39498 .7324 L 0 1 .452 r
F
0 g
.38858 .73402 m
.39498 .7324 L
s
.40435 .73599 m .40369 .72112 L .39749 .72582 L 0 1 .452 r
F
.40435 .73599 m .41022 .72064 L .40369 .72112 L F
.40435 .73599 m .41271 .72469 L .41022 .72064 L F
.40435 .73599 m .41019 .73127 L .41271 .72469 L F
0 g
.40211 .74248 m
.40435 .73599 L
s
.39783 .73648 m
.40435 .73599 L
s
.32589 .67054 m
.33018 .67022 L
s
.34173 .67126 m .33321 .66906 L .33018 .67022 L 0 .666 .39 r
F
.44962 .79979 m .44309 .79864 L .44168 .79651 L 0 .057 0 r
F
.44962 .79979 m .44772 .8019 L .44309 .79864 L F
.44962 .79979 m .45294 .80477 L .44772 .8019 L F
.44962 .79979 m .45526 .80531 L .45294 .80477 L F
.44962 .79979 m .45383 .80317 L .45526 .80531 L F
0 g
.44853 .79722 m
.44962 .79979 L
s
.44442 .79694 m
.44962 .79979 L
s
.54468 .65856 m .54003 .65485 L .5394 .65818 L 0 1 .484 r
F
.54468 .65856 m .54658 .65042 L .54003 .65485 L F
.54468 .65856 m .55468 .64785 L .54658 .65042 L F
.49075 .95797 m .48253 .95579 L .48708 .95642 L 0 .377 .089 r
F
0 g
.48708 .95642 m
.49029 .95584 L
s
.51919 .91154 m .52263 .90949 L .52377 .90054 L 0 .553 .32 r
F
.51919 .91154 m .52066 .9142 L .52263 .90949 L F
0 g
.5176 .9149 m
.51919 .91154 L
s
.51858 .90256 m
.51919 .91154 L
s
.34173 .67126 m .34082 .66769 L .33321 .66906 L 0 .666 .39 r
F
.34173 .67126 m .34888 .66854 L .34082 .66769 L F
0 g
.33899 .67102 m
.34173 .67126 L
s
.47528 .71866 m .48156 .71549 L .48568 .70991 L 0 1 .457 r
F
.35952 .72992 m .35233 .72761 L .35564 .73057 L 0 .727 .319 r
F
0 g
.35564 .73057 m
.35952 .72992 L
s
.35952 .72992 m
.36059 .73555 L
s
.35147 .71685 m
.35233 .72761 L
s
.51382 1.0159 m .51266 1.03226 L .51414 1.03648 L 0 .162 .222 r
F
0 g
.51193 1.01616 m
.51283 1.01288 L
s
.51172 1.02355 m
.51266 1.03226 L
s
.5114 1.03287 m
.51266 1.03226 L
s
.52386 .96252 m .53112 .97211 L .52687 .96541 L 0 .27 .24 r
F
.52386 .96252 m .53465 .98265 L .53112 .97211 L F
.52386 .96252 m .5351 .98999 L .53465 .98265 L F
.52386 .96252 m .53207 .98706 L .5351 .98999 L F
.52386 .96252 m .52759 .97584 L .53207 .98706 L F
.52386 .96252 m .52408 .96534 L .52759 .97584 L F
.52325 .96264 m .5235 .96136 L .52687 .96541 L 0 .419 .147 r
F
0 g
.52361 .96149 m
.52407 .96205 L
s
.52356 .96143 m
.52361 .96149 L
s
.5235 .96136 m
.52356 .96143 L
s
.52455 .96254 m
.52468 .96278 L
s
.52371 .96014 m
.52481 .96198 L
s
.52362 .95946 m
.5258 .9622 L
s
.5258 .9622 m
.52581 .96221 L
s
.52581 .96221 m
.52581 .96221 L
s
.52581 .96221 m
.52602 .96248 L
s
.52371 .95904 m
.52586 .96223 L
s
.52586 .96223 m
.52602 .96248 L
s
.52212 .96307 m
.52269 .96372 L
s
.52269 .96372 m
.52308 .96418 L
s
.52421 .96147 m
.52482 .96237 L
s
.52279 .96026 m
.5235 .96136 L
s
.53512 .98768 m
.53514 .98771 L
s
.53514 .98771 m
.53557 .98844 L
s
.53493 .98714 m
.53525 .98774 L
s
.53493 .98725 m
.53537 .98806 L
s
.52007 .93919 m
.52084 .93896 L
s
.26265 .87079 m .25279 .87192 L .25741 .87293 L 0 1 .518 r
F
0 g
.25741 .87293 m
.25992 .8767 L
s
.29211 .78799 m .28132 .7863 L .28117 .79153 L 0 1 .526 r
F
0 g
.27522 .79599 m
.28117 .79153 L
s
.50779 .96075 m
.50779 .96075 L
s
.50779 .96075 m
.50779 .96075 L
s
.65396 .55826 m
.6636 .56854 L
s
.3752 .73011 m .37385 .71168 L .36752 .71827 L 0 1 .422 r
F
.3752 .73011 m .38074 .71026 L .37385 .71168 L F
.3752 .73011 m .38358 .71495 L .38074 .71026 L F
.3752 .73011 m .38121 .72345 L .38358 .71495 L F
0 g
.37309 .73804 m
.3752 .73011 L
s
.36832 .73153 m
.3752 .73011 L
s
.26493 .70601 m .26125 .69465 L .25478 .70068 L 0 1 .528 r
F
.26493 .70601 m .26904 .69189 L .26125 .69465 L F
.26493 .70601 m .27294 .69424 L .26904 .69189 L F
.26493 .70601 m .27116 .7003 L .27294 .69424 L F
0 g
.25717 .70875 m
.26493 .70601 L
s
.26336 .71191 m
.26493 .70601 L
s
.21562 .79235 m .20453 .79628 L .20907 .79717 L 0 1 .538 r
F
0 g
.20907 .79717 m
.21029 .80365 L
s
.34217 .75692 m .33879 .75481 L .33874 .75514 L 0 1 .405 r
F
.33613 .7524 m .32734 .74234 L .33201 .74743 L 0 .025 .162 r
F
.33609 .75237 m .32734 .74234 L .33613 .7524 L F
.33529 .75158 m .32734 .74234 L .33638 .7527 L F
.33529 .75158 m .32815 .73904 L .32734 .74234 L F
.33572 .75207 m .33308 .74662 L .33529 .75158 L F
.33638 .7527 m .33609 .75237 L .33613 .7524 L F
.33965 .74913 m .3358 .7508 L .33592 .75231 L 0 1 .182 r
F
.33592 .75231 m .3358 .7508 L .33572 .75207 L 0 .025 .162 r
F
.3358 .7508 m .33308 .74662 L .33572 .75207 L F
.33308 .74662 m .32815 .73904 L .33529 .75158 L F
.3358 .7508 m .33472 .75127 L .33592 .75231 L 0 1 .182 r
F
.34115 .75763 m .33874 .75514 L .33826 .75824 L 0 1 .405 r
F
.33667 .75305 m .33529 .75158 L .33638 .7527 L 0 .025 .162 r
F
.33667 .75305 m .3268 .76007 L .33165 .75963 L 0 1 .182 r
F
.33592 .75231 m .3268 .76007 L .33667 .75305 L F
.33945 .7564 m .33592 .75231 L .33667 .75305 L 0 .025 .162 r
F
.33592 .75231 m .33529 .75158 L .33667 .75305 L F
.33965 .74913 m .33592 .75231 L .33667 .75305 L 0 1 .182 r
F
.33945 .7564 m .3358 .7508 L .33592 .75231 L 0 .025 .162 r
F
.3358 .7508 m .33392 .73974 L .32815 .73904 L F
.33641 .74904 m .33653 .74761 L .33621 .74903 L 0 1 .182 r
F
.33965 .74913 m .33653 .74761 L .33641 .74904 L F
.33653 .74761 m .33392 .73974 L .3358 .7508 L 0 .025 .162 r
F
.33965 .74913 m .33174 .7489 L .33472 .75127 L 0 1 .182 r
F
.34217 .75692 m .33874 .75514 L .34115 .75763 L 0 1 .405 r
F
.34826 .7623 m .33945 .75641 L .33879 .75481 L 0 .086 0 r
F
.34217 .75692 m .33879 .75481 L .33821 .75342 L F
.34826 .7623 m .33879 .75481 L .34217 .75692 L F
.34852 .7525 m .33965 .74913 L .33879 .75481 L 0 1 .405 r
F
.34852 .7525 m .33879 .75481 L .34217 .75692 L F
.34852 .7525 m .34548 .73556 L .33965 .74913 L F
.33965 .74913 m .34548 .73556 L .34638 .72981 L 0 1 .182 r
F
.33965 .74913 m .34175 .73572 L .33641 .74273 L F
.33653 .74761 m .33641 .74273 L .33392 .73974 L 0 .025 .162 r
F
.33653 .74761 m .33641 .74273 L .33443 .74533 L 0 1 .182 r
F
.33653 .74761 m .33443 .74533 L .33378 .74627 L F
.33592 .74902 m .33373 .74625 L .33174 .7489 L F
.33603 .74736 m .33373 .74625 L .33592 .74902 L F
.33472 .75127 m .33174 .7489 L .32769 .75434 L F
.32858 .75381 m .33538 .7453 L .33152 .7519 L 0 0 0 r
F
.32768 .75439 m .33035 .75124 L .32858 .75381 L F
.33035 .75124 m .33538 .7453 L .32858 .75381 L F
.33378 .74627 m .33443 .74533 L .33373 .74625 L 0 1 .182 r
F
.33965 .74913 m .33641 .74273 L .33653 .74761 L F
.33653 .74761 m .33689 .74331 L .33641 .74273 L 0 .025 .162 r
F
.33965 .74913 m .34638 .72981 L .34175 .73572 L 0 1 .182 r
F
.33945 .7564 m .34139 .74873 L .33689 .74331 L 0 .025 .162 r
F
.33945 .7564 m .33689 .74331 L .33653 .74761 L F
.33945 .7564 m .33653 .74761 L .3358 .7508 L F
.33621 .74903 m .33603 .74736 L .33592 .74902 L 0 1 .182 r
F
.33653 .74761 m .33603 .74736 L .33621 .74903 L F
.33592 .75231 m .32769 .75434 L .3268 .76007 L F
.33472 .75127 m .32769 .75434 L .33592 .75231 L F
.33874 .7593 m .33826 .75824 L .33802 .7598 L 0 1 .405 r
F
.34115 .75763 m .33826 .75824 L .33874 .7593 L F
0 g
.34167 .76046 m
.34307 .75883 L
s
.34386 .75792 m
.34412 .75762 L
s
.34371 .75809 m
.34386 .75792 L
s
.34737 .76042 m
.34741 .76011 L
s
.34371 .75809 m
.34386 .75824 L
s
.34852 .7525 m .35233 .72762 L .34548 .73556 L 0 1 .405 r
F
0 g
.34883 .72351 m
.35147 .71684 L
s
.34852 .7525 m .35564 .73058 L .35233 .72762 L 0 1 .405 r
F
0 g
.34639 .72968 m
.34883 .72351 L
s
.34852 .7525 m .35401 .74125 L .35564 .73058 L 0 1 .405 r
F
0 g
.35401 .74125 m
.36058 .73556 L
s
.34741 .76011 m
.34852 .7525 L
s
.34412 .75762 m
.34852 .7525 L
s
.35401 .74125 m
.35564 .73058 L
s
.25478 .70068 m .24459 .69565 L .24269 .70181 L 0 1 .532 r
F
0 g
.23549 .70493 m
.24269 .70181 L
s
.8094 .85612 m .82312 .85721 L .82086 .85238 L 0 1 .503 r
F
0 g
.82133 .86171 m
.82312 .85721 L
s
.82312 .85721 m
.82828 .85994 L
s
.66096 .7705 m
.6612 .76971 L
s
.6612 .76971 m
.66122 .76967 L
s
.66709 .75069 m
.66716 .75048 L
s
.39183 .77841 m
.39322 .77846 L
s
.69742 .6652 m .70638 .66971 L .69772 .65031 L 0 .384 .321 r
F
0 g
.69343 .65528 m
.69742 .6652 L
s
.69524 .65355 m
.69742 .6652 L
s
.34092 .76713 m
.34167 .76046 L
s
.51535 .99245 m .5152 .99203 L .51566 1.00185 L 0 .226 .244 r
F
0 g
.51534 .99495 m
.51534 .99495 L
s
.51534 .99495 m
.51534 .99495 L
s
.51532 .99454 m
.51534 .99495 L
s
.51532 .99453 m
.51532 .99454 L
s
.51532 .99453 m
.51532 .99453 L
s
.51528 .99372 m
.51532 .99453 L
s
.51528 .99372 m
.51528 .99372 L
s
.51528 .99372 m
.51528 .99372 L
s
.51523 .99271 m
.51528 .99372 L
s
.51523 .99271 m
.51523 .99271 L
s
.51523 .99271 m
.51523 .99271 L
s
.5152 .9921 m
.51523 .99271 L
s
.5152 .9921 m
.5152 .9921 L
s
.5152 .9921 m
.5152 .9921 L
s
.5152 .99203 m
.5152 .9921 L
s
.51521 .99646 m
.51521 .99646 L
s
.51521 .99646 m
.51521 .99646 L
s
.51517 .996 m
.51521 .99646 L
s
.5152 .99202 m
.5152 .99203 L
s
.51477 .97936 m
.51535 .99242 L
s
.31036 .8826 m .30175 .87655 L .29966 .87976 L 0 1 .512 r
F
0 g
.29966 .87976 m
.30133 .88297 L
s
.31036 .8826 m .30648 .87509 L .30175 .87655 L 0 1 .512 r
F
.31036 .8826 m .3107 .87638 L .30648 .87509 L F
.31036 .8826 m .31236 .8796 L .3107 .87638 L F
0 g
.30744 .88349 m
.31036 .8826 L
s
.31036 .8826 m
.3121 .8857 L
s
.49075 .95797 m .47951 .95666 L .48253 .95579 L 0 .377 .089 r
F
0 g
.47883 .95407 m
.48253 .95579 L
s
.49075 .95797 m .48004 .95845 L .47951 .95666 L 0 .377 .089 r
F
.49075 .95797 m .48372 .96001 L .48004 .95845 L F
.49075 .95797 m .48809 .9603 L .48372 .96001 L F
.49075 .95797 m .4911 .95943 L .48809 .9603 L F
0 g
.49075 .95797 m
.49389 .95633 L
s
.48708 .95642 m
.49075 .95797 L
s
.46576 .80864 m .45872 .80568 L .46103 .80563 L 0 .192 0 r
F
0 g
.45991 .80305 m
.46103 .80563 L
s
.42521 .73484 m .41644 .73076 L .41893 .73481 L 0 1 .457 r
F
.42521 .73484 m .41929 .72471 L .41644 .73076 L F
0 g
.41849 .7361 m
.41893 .73481 L
s
.42521 .73484 m .42557 .72069 L .41929 .72471 L 0 1 .457 r
F
.42521 .73484 m .43187 .72072 L .42557 .72069 L F
.42521 .73484 m .43396 .72478 L .43187 .72072 L F
.42521 .73484 m .43111 .73083 L .43396 .72478 L F
0 g
.42266 .7409 m
.42521 .73484 L
s
.41893 .73481 m
.42521 .73484 L
s
.46576 .80864 m .46034 .80876 L .45872 .80568 L 0 .192 0 r
F
.46576 .80864 m .46481 .81283 L .46034 .80876 L F
.46576 .80864 m .46957 .81585 L .46481 .81283 L F
.46576 .80864 m .47142 .81579 L .46957 .81585 L F
.46576 .80864 m .46978 .8127 L .47142 .81579 L F
0 g
.46448 .80498 m
.46576 .80864 L
s
.46103 .80563 m
.46576 .80864 L
s
.81957 .97259 m .82719 .98496 L .83078 .9751 L 0 1 .449 r
F
.81957 .97259 m .82264 .98792 L .82719 .98496 L F
0 g
.82719 .98496 m
.82935 .9893 L
s
.47528 .71866 m .46841 .71359 L .46964 .71785 L 0 1 .457 r
F
.47528 .71866 m .47253 .708 L .46841 .71359 L F
.47528 .71866 m .47927 .70481 L .47253 .708 L F
.47528 .71866 m .4849 .70563 L .47927 .70481 L F
.47528 .71866 m .48568 .70991 L .4849 .70563 L F
0 g
.48156 .71549 m
.48472 .71121 L
s
.48472 .71121 m
.48568 .70991 L
s
.48568 .70991 m
.49106 .71078 L
s
.50664 .6923 m .50091 .68762 L .50123 .69163 L 0 1 .469 r
F
.50664 .6923 m .5062 .68234 L .50091 .68762 L F
.50664 .6923 m .51357 .67932 L .5062 .68234 L F
.50664 .6923 m .51897 .68 L .51357 .67932 L F
0 g
.5017 .69785 m
.50664 .6923 L
s
.68027 1.11641 m .69003 1.11388 L .68624 1.11783 L 0 .174 .068 r
F
.6709 1.12574 m .68027 1.11641 L .68053 1.12394 L 0 .241 .083 r
F
0 g
.67986 .59722 m
.68018 .59737 L
s
.68018 .59737 m
.68072 .59763 L
s
.50235 .96174 m
.50332 .96078 L
s
.83102 .96487 m .8422 .96828 L .84248 .95788 L 0 1 .46 r
F
0 g
.83858 .97806 m
.8422 .96828 L
s
.30242 .57116 m
.31193 .56527 L
s
.4599 .72685 m .45241 .72196 L .45408 .72617 L 0 1 .456 r
F
.4599 .72685 m .45605 .71627 L .45241 .72196 L F
0 g
.45286 .72846 m
.45408 .72617 L
s
.45096 .73201 m
.45286 .72846 L
s
.4599 .72685 m .46258 .71292 L .45605 .71627 L 0 1 .456 r
F
.4599 .72685 m .46841 .71359 L .46258 .71292 L F
.4599 .72685 m .46964 .71785 L .46841 .71359 L F
.4599 .72685 m .46599 .72353 L .46964 .71785 L F
0 g
.46964 .71785 m
.47528 .71866 L
s
.45408 .72617 m
.4599 .72685 L
s
.466 .72353 m
.47153 .72457 L
s
.26265 .87079 m .25116 .86811 L .25279 .87192 L 0 1 .518 r
F
0 g
.24834 .87437 m
.25279 .87192 L
s
.72426 .66839 m
.72561 .66682 L
s
.55883 .87867 m
.55905 .89206 L
s
.51961 .93344 m .52091 .92092 L .51976 .92721 L 0 .415 .322 r
F
.51961 .93344 m .52285 .91857 L .52091 .92092 L F
.51961 .93344 m .52428 .92174 L .52285 .91857 L F
.51961 .93344 m .52414 .92798 L .52428 .92174 L F
.51961 .93344 m .52251 .93313 L .52414 .92798 L F
0 g
.51816 .93057 m
.5187 .92943 L
s
.5187 .92943 m
.51976 .92721 L
s
.51961 .93344 m .52057 .93546 L .52251 .93313 L 0 .415 .322 r
F
0 g
.51844 .93458 m
.51961 .93344 L
s
.51961 .93344 m
.51976 .92721 L
s
.52007 .93919 m
.52057 .93546 L
s
.44096 .63966 m .43176 .64038 L .43349 .64102 L 0 1 .349 r
F
0 g
.42888 .64396 m
.43349 .64102 L
s
.44096 .63966 m .43697 .63802 L .43176 .64038 L 0 1 .349 r
F
.44096 .63966 m .44566 .63552 L .43697 .63802 L F
.44096 .63966 m .45314 .63417 L .44566 .63552 L F
.44096 .63966 m .45442 .63486 L .45314 .63417 L F
.44096 .63966 m .44919 .63722 L .45442 .63486 L F
0 g
.43608 .64183 m
.44096 .63966 L
s
.43349 .64102 m
.44096 .63966 L
s
.44919 .63722 m
.45633 .63577 L
s
.52458 .67478 m .53847 .66332 L .5331 .66282 L 0 1 .48 r
F
0 g
.53847 .66332 m
.54468 .65856 L
s
.51535 .99245 m .51708 1.01728 L .51616 1.00327 L 0 .226 .244 r
F
.51535 .99245 m .51755 1.02713 L .51708 1.01728 L F
.51535 .99245 m .51725 1.02623 L .51755 1.02713 L F
.51535 .99245 m .51644 1.01538 L .51725 1.02623 L F
0 g
.51644 .98358 m
.51715 .99324 L
s
.51715 .99324 m
.51716 .99335 L
s
.51716 .99335 m
.51717 .99348 L
s
.51535 .99245 m .51566 1.00185 L .51644 1.01538 L 0 .226 .244 r
F
0 g
.5157 .99707 m
.5157 .99708 L
s
.5157 .99707 m
.5157 .99707 L
s
.51566 .99665 m
.5157 .99707 L
s
.51566 .99664 m
.51566 .99665 L
s
.51566 .99664 m
.51566 .99664 L
s
.51565 .99648 m
.51566 .99664 L
s
.51565 .99648 m
.51565 .99648 L
s
.51565 .99647 m
.51565 .99648 L
s
.51557 .99534 m
.51565 .99647 L
s
.51557 .99534 m
.51557 .99534 L
s
.51557 .99534 m
.51557 .99534 L
s
.51553 .99488 m
.51557 .99534 L
s
.51553 .99488 m
.51553 .99488 L
s
.51553 .99488 m
.51553 .99488 L
s
.51547 .9941 m
.51553 .99488 L
s
.51547 .9941 m
.51547 .9941 L
s
.51547 .9941 m
.51547 .9941 L
s
.5154 .99308 m
.51547 .9941 L
s
.5154 .99308 m
.5154 .99308 L
s
.5154 .99308 m
.5154 .99308 L
s
.51535 .99249 m
.5154 .99308 L
s
.51535 .99249 m
.51535 .99249 L
s
.51535 .99249 m
.51535 .99249 L
s
.51535 .99245 m
.51535 .99249 L
s
.51535 .99242 m
.51535 .99245 L
s
.51477 .97936 m
.51582 .99358 L
s
.51566 1.00183 m
.51566 1.00185 L
s
.51521 .99646 m
.51566 1.00183 L
s
.51534 .99495 m
.51539 .99608 L
s
.51539 .99608 m
.51539 .99608 L
s
.51539 .99608 m
.51539 .99609 L
s
.51539 .99609 m
.5154 .99625 L
s
.5154 .99625 m
.5154 .99625 L
s
.5154 .99625 m
.5154 .99626 L
s
.5154 .99626 m
.51542 .99667 L
s
.51542 .99667 m
.51542 .99668 L
s
.51542 .99668 m
.51542 .99668 L
s
.51542 .99668 m
.51566 1.00185 L
s
.51583 .99369 m
.51583 .99369 L
s
.51582 .99358 m
.51583 .99369 L
s
.62967 .70042 m
.63608 .70823 L
s
.46868 .71935 m
.46964 .71785 L
s
.46599 .72353 m
.46868 .71935 L
s
.4846 .8215 m
.48778 .82265 L
s
.48394 .82127 m
.4846 .8215 L
s
.32673 .77349 m .31413 .77836 L .31925 .77905 L 0 1 .466 r
F
0 g
.31925 .77905 m
.3267 .77352 L
s
.32599 .78016 m
.32674 .7735 L
s
.32674 .7735 m
.32674 .77349 L
s
.31925 .77905 m
.32007 .7848 L
s
.32488 .66962 m
.32589 .67054 L
s
.396 .65656 m .38422 .65918 L .3876 .65963 L 0 1 .457 r
F
0 g
.38468 .66441 m
.3876 .65963 L
s
.396 .65656 m .38794 .65508 L .38422 .65918 L 0 1 .457 r
F
.396 .65656 m .3963 .65007 L .38794 .65508 L F
.396 .65656 m .40472 .64699 L .3963 .65007 L F
.396 .65656 m .40757 .64791 L .40472 .64699 L F
.396 .65656 m .40383 .65201 L .40757 .64791 L F
0 g
.3876 .65963 m
.396 .65656 L
s
.53081 .90742 m .53519 .87863 L .53225 .88334 L 0 .605 .298 r
F
.53081 .90742 m .5375 .88396 L .53519 .87863 L F
0 g
.53494 .87168 m
.53519 .87863 L
s
.53166 .8718 m
.53214 .88117 L
s
.59438 .62582 m .59166 .62116 L .58962 .62445 L 0 1 .465 r
F
.59438 .62582 m .59991 .61791 L .59166 .62116 L F
.59438 .62582 m .60884 .61688 L .59991 .61791 L F
0 g
.51723 .98527 m
.51723 .98528 L
s
.68943 1.13103 m .69003 1.11388 L .69558 1.11403 L 0 .134 .076 r
F
.68943 1.13103 m .68624 1.11783 L .69003 1.11388 L F
0 g
.6896 1.10761 m
.69003 1.11388 L
s
.70805 .59082 m .72683 .59416 L .73024 .59269 L 0 1 .501 r
F
.70805 .59082 m .71734 .59336 L .72683 .59416 L F
0 g
.72683 .59416 m
.7305 .59761 L
s
.52458 .67478 m .51935 .67059 L .5192 .67429 L 0 1 .48 r
F
.52458 .67478 m .52531 .66568 L .51935 .67059 L F
.52458 .67478 m .5331 .66282 L .52531 .66568 L F
0 g
.51897 .68 m
.52458 .67478 L
s
.53081 .90742 m .53225 .88334 L .53064 .89496 L 0 .605 .298 r
F
.52607 .89679 m .53064 .89496 L .53225 .88334 L 0 .64 .307 r
F
0 g
.53214 .88117 m
.53225 .88334 L
s
.53225 .88334 m
.53519 .87863 L
s
.82086 .85238 m .83465 .85397 L .83232 .84873 L 0 1 .512 r
F
0 g
.83291 .85876 m
.83465 .85397 L
s
.32673 .77349 m .31414 .77262 L .31413 .77836 L 0 1 .466 r
F
.32673 .77349 m .31929 .76564 L .31414 .77262 L F
.32673 .77349 m .3268 .76007 L .31929 .76564 L F
.32673 .77349 m .33165 .75963 L .3268 .76007 L F
.32673 .77349 m .33162 .76539 L .33165 .75963 L F
0 g
.3267 .77352 m
.32673 .77349 L
s
.51896 .96284 m
.51896 .96284 L
s
.51896 .96284 m
.51896 .96284 L
s
.5504 .87507 m
.55283 .87189 L
s
.55027 .87525 m
.5504 .87507 L
s
.54977 .8759 m
.55027 .87525 L
s
.5491 .87678 m
.54977 .8759 L
s
.36752 .71827 m .37363 .6983 L .3666 .69529 L 0 1 .423 r
F
.36752 .71827 m .37647 .70312 L .37363 .6983 L F
.36752 .71827 m .37385 .71168 L .37647 .70312 L F
0 g
.36516 .72677 m
.36752 .71827 L
s
.3607 .71532 m
.36752 .71827 L
s
.52141 .97073 m
.52141 .97073 L
s
.52285 .91857 m .52377 .90054 L .52263 .90949 L 0 .523 .314 r
F
.52285 .91857 m .52607 .89679 L .52377 .90054 L F
0 g
.52316 .89156 m
.52377 .90054 L
s
.75508 .81892 m .76099 .82569 L .75654 .82655 L 0 .188 .072 r
F
.75508 .81892 m .76633 .81803 L .76099 .82569 L F
0 g
.75508 .81892 m
.75654 .82655 L
s
.74986 .82764 m
.75074 .82616 L
s
.75074 .82616 m
.75508 .81892 L
s
.21562 .79235 m .20437 .78998 L .20453 .79628 L 0 1 .538 r
F
0 g
.19889 .80162 m
.20453 .79628 L
s
.52325 .96264 m .53004 .97929 L .52604 .97031 L 0 .419 .147 r
F
.52325 .96264 m .53343 .98337 L .53004 .97929 L F
.52325 .96264 m .53393 .97982 L .53343 .98337 L F
.52325 .96264 m .53112 .97211 L .53393 .97982 L F
.52325 .96264 m .52687 .96541 L .53112 .97211 L F
0 g
.52331 .96282 m
.52393 .96453 L
s
.52393 .96453 m
.52393 .96453 L
s
.52393 .96453 m
.52393 .96453 L
s
.5233 .96279 m
.52331 .96282 L
s
.52325 .96264 m
.5233 .96279 L
s
.52258 .96544 m
.52424 .96918 L
s
.52147 .96058 m
.52325 .96264 L
s
.52592 .96401 m
.52608 .96425 L
s
.52545 .96331 m
.52592 .96401 L
s
.52482 .96237 m
.52545 .96331 L
s
.5263 .96456 m
.5264 .96472 L
s
.5264 .96472 m
.52641 .96473 L
s
.52608 .96425 m
.52622 .96445 L
s
.52622 .96445 m
.5263 .96456 L
s
.52641 .96473 m
.52655 .96493 L
s
.52655 .96493 m
.52685 .96538 L
s
.52685 .96538 m
.52687 .96541 L
s
.52404 .9653 m
.52408 .96534 L
s
.52308 .96418 m
.52404 .9653 L
s
.52481 .96198 m
.52531 .96281 L
s
.52539 .96295 m
.52561 .96331 L
s
.52531 .96281 m
.52539 .96295 L
s
.52561 .96331 m
.52562 .96332 L
s
.52562 .96332 m
.52562 .96333 L
s
.52562 .96333 m
.52563 .96335 L
s
.52563 .96335 m
.52569 .96344 L
s
.52569 .96344 m
.52573 .96351 L
s
.52573 .96351 m
.52575 .96354 L
s
.52618 .96427 m
.52642 .96467 L
s
.52602 .96399 m
.52618 .96427 L
s
.52575 .96354 m
.52602 .96399 L
s
.52642 .96467 m
.52687 .96541 L
s
.52407 .96205 m
.52474 .96285 L
s
.52474 .96285 m
.52474 .96285 L
s
.52474 .96285 m
.52474 .96285 L
s
.52474 .96285 m
.52481 .96293 L
s
.52481 .96293 m
.52507 .96324 L
s
.52507 .96324 m
.52551 .96378 L
s
.52551 .96378 m
.52578 .9641 L
s
.52578 .9641 m
.52588 .96422 L
s
.52592 .96427 m
.52608 .96447 L
s
.52588 .96422 m
.52592 .96427 L
s
.52608 .96447 m
.52609 .96448 L
s
.52609 .96448 m
.5261 .96448 L
s
.5261 .96448 m
.52611 .9645 L
s
.52611 .9645 m
.52615 .96455 L
s
.52615 .96455 m
.52616 .96456 L
s
.52616 .96456 m
.52624 .96466 L
s
.52624 .96466 m
.52627 .96468 L
s
.52627 .96468 m
.52636 .9648 L
s
.52636 .9648 m
.52642 .96487 L
s
.52642 .96487 m
.52647 .96493 L
s
.52647 .96493 m
.52652 .96499 L
s
.52652 .96499 m
.52659 .96507 L
s
.52659 .96507 m
.52661 .9651 L
s
.52661 .9651 m
.52661 .9651 L
s
.52661 .9651 m
.52671 .96522 L
s
.52671 .96522 m
.52679 .96531 L
s
.52679 .96531 m
.52682 .96535 L
s
.52682 .96535 m
.52687 .96541 L
s
.25116 .86811 m .24124 .86941 L .24586 .87041 L 0 1 .519 r
F
0 g
.24586 .87041 m
.24834 .87437 L
s
.52523 .85384 m .52423 .87072 L .52354 .85876 L 0 .754 .12 r
F
0 g
.52078 .84609 m
.52354 .85876 L
s
.52523 .85384 m .52736 .88672 L .52423 .87072 L 0 .754 .12 r
F
.52607 .89679 m .52799 .90073 L .53064 .89496 L 0 .64 .307 r
F
.52523 .85384 m .53084 .89605 L .52736 .88672 L 0 .754 .12 r
F
.52523 .85384 m .53253 .89102 L .53084 .89605 L F
.52523 .85384 m .5313 .87507 L .53253 .89102 L F
.52523 .85384 m .52818 .85917 L .5313 .87507 L F
0 g
.52948 .84911 m
.53175 .86251 L
s
.52818 .85917 m
.52948 .84911 L
s
.52451 .84984 m
.52523 .85384 L
s
.52354 .85876 m
.52523 .85384 L
s
.52066 .9142 m
.52263 .90949 L
s
.52066 .9142 m
.52091 .92092 L
s
.62751 .61011 m .6475 .60621 L .64249 .60462 L 0 1 .473 r
F
0 g
.6475 .60621 m
.65591 .60518 L
s
.52444 .96644 m
.5246 .96691 L
s
.52444 .96644 m
.52444 .96644 L
s
.52444 .96644 m
.52444 .96644 L
s
.52413 .96549 m
.52444 .96644 L
s
.52413 .96549 m
.52413 .96549 L
s
.52413 .96549 m
.52413 .96549 L
s
.52412 .96546 m
.52413 .96549 L
s
.52408 .96534 m
.52412 .96546 L
s
.5355 .98831 m
.53554 .98839 L
s
.53554 .98839 m
.53557 .98844 L
s
.53557 .98844 m
.53727 .99153 L
s
.29211 .78799 m .28591 .78003 L .28132 .7863 L 0 1 .526 r
F
.29211 .78799 m .29251 .77573 L .28591 .78003 L F
.29211 .78799 m .2967 .77627 L .29251 .77573 L F
.29211 .78799 m .29652 .78153 L .2967 .77627 L F
0 g
.29209 .79336 m
.29211 .78799 L
s
.28554 .79227 m
.29211 .78799 L
s
.32012 .73937 m
.32734 .74234 L
s
.33201 .74777 m
.33202 .74853 L
s
.51939 1.06354 m .52094 1.07424 L .52221 1.0753 L 0 0 .143 r
F
0 g
.52094 1.07424 m
.52336 1.08067 L
s
.54357 1.1242 m .54782 1.12486 L .5493 1.13018 L 0 .449 .012 r
F
0 g
.71745 .83804 m
.71745 .83803 L
s
.50849 .9621 m
.50849 .9621 L
s
.50848 .96211 m
.50849 .9621 L
s
.49377 .95949 m
.49465 .95951 L
s
.4911 .95943 m
.49377 .95949 L
s
.43111 .73083 m
.4371 .73095 L
s
.29966 .87976 m .28779 .87277 L .28559 .87624 L 0 1 .515 r
F
.29966 .87976 m .29361 .87135 L .28779 .87277 L F
0 g
.28559 .87624 m
.28819 .87984 L
s
.29966 .87976 m .29916 .87294 L .29361 .87135 L 0 1 .515 r
F
.29966 .87976 m .30174 .87655 L .29916 .87294 L F
0 g
.2972 .88036 m
.29966 .87976 L
s
.51631 .99502 m .51583 .99374 L .51616 1.00327 L 0 .224 .243 r
F
0 g
.51596 .99739 m
.51606 1.00048 L
s
.51606 1.00048 m
.51615 1.00301 L
s
.51596 .99739 m
.51596 .99739 L
s
.51596 .99739 m
.51596 .99739 L
s
.51594 .99701 m
.51596 .99739 L
s
.51594 .997 m
.51594 .99701 L
s
.51594 .997 m
.51594 .997 L
s
.51594 .99686 m
.51594 .997 L
s
.51594 .99686 m
.51594 .99686 L
s
.51594 .99686 m
.51594 .99686 L
s
.5159 .99587 m
.51594 .99686 L
s
.5159 .99587 m
.5159 .99587 L
s
.5159 .99586 m
.5159 .99587 L
s
.51589 .99542 m
.5159 .99586 L
s
.51589 .99542 m
.51589 .99542 L
s
.51589 .99542 m
.51589 .99542 L
s
.51587 .99484 m
.51589 .99542 L
s
.51587 .99484 m
.51587 .99484 L
s
.51587 .99484 m
.51587 .99484 L
s
.51584 .99408 m
.51587 .99484 L
s
.51584 .99408 m
.51584 .99408 L
s
.51584 .99408 m
.51584 .99408 L
s
.51583 .99374 m
.51584 .99408 L
s
.5163 .99475 m
.51631 .99491 L
s
.51631 .99491 m
.51631 .99492 L
s
.51583 .99369 m
.51583 .99374 L
s
.51562 .9816 m
.5163 .99475 L
s
.51613 1.00291 m
.51615 1.00319 L
s
.51615 1.00319 m
.51616 1.00327 L
s
.5159 .99984 m
.51613 1.00291 L
s
.5157 .99708 m
.5159 .99984 L
s
.41014 .92082 m
.41436 .92298 L
s
.41019 .73127 m
.41266 .72482 L
s
.41019 .73127 m
.41644 .73076 L
s
.35711 .76619 m .35333 .76741 L .34826 .7623 L 0 0 0 r
F
.35711 .76619 m .35969 .77155 L .35333 .76741 L F
.35711 .76619 m .36308 .77192 L .35969 .77155 L F
.35711 .76619 m .36196 .76962 L .36308 .77192 L F
0 g
.35174 .76271 m
.35711 .76619 L
s
.35634 .76499 m
.35711 .76619 L
s
.50118 .8339 m .49709 .83585 L .49795 .83234 L 0 .494 .066 r
F
0 g
.49606 .82614 m
.49795 .83234 L
s
.50118 .8339 m .49941 .84344 L .49709 .83585 L 0 .494 .066 r
F
.50118 .8339 m .50337 .85006 L .49941 .84344 L F
.50118 .8339 m .50662 .85162 L .50337 .85006 L F
.50118 .8339 m .50697 .84708 L .50662 .85162 L F
.50118 .8339 m .50464 .83949 L .50697 .84708 L F
0 g
.49924 .82549 m
.50118 .8339 L
s
.49795 .83234 m
.50118 .8339 L
s
.50464 .83949 m
.5075 .83834 L
s
.41133 .64893 m
.41593 .64599 L
s
.40383 .65201 m
.40985 .64954 L
s
.40985 .64954 m
.41133 .64893 L
s
.78414 1.02366 m .78278 1.03093 L .78512 1.03353 L 0 1 .373 r
F
0 g
.77984 1.04039 m
.78512 1.03353 L
s
.80006 .81234 m .81451 .80565 L .81131 .80985 L 0 0 0 r
F
0 g
.81344 .80271 m
.81451 .80565 L
s
.81451 .80565 m
.82034 .80225 L
s
.41968 .926 m
.42158 .92701 L
s
.42158 .92701 m
.42311 .92793 L
s
.25116 .86811 m .23967 .86543 L .24124 .86941 L 0 1 .519 r
F
0 g
.23676 .87206 m
.24124 .86941 L
s
.30711 .78289 m
.31413 .77836 L
s
.39749 .72582 m .38786 .72173 L .39071 .72607 L 0 1 .456 r
F
0 g
.38915 .73189 m
.39071 .72607 L
s
.32734 .74234 m
.32815 .73904 L
s
.50376 .96204 m .49675 .9662 L .50062 .96346 L 0 .414 .103 r
F
.50376 .96204 m .4943 .96948 L .49675 .9662 L F
.50376 .96204 m .49492 .97112 L .4943 .96948 L F
.50376 .96204 m .49806 .96969 L .49492 .97112 L F
.50376 .96204 m .50163 .96615 L .49806 .96969 L F
.50376 .96204 m .50407 .96287 L .50163 .96615 L F
0 g
.50376 .96204 m
.50642 .95743 L
s
.50062 .96346 m
.50235 .96174 L
s
.50062 .96346 m
.50198 .96285 L
s
.50198 .96285 m
.50339 .96221 L
s
.50339 .96221 m
.50376 .96204 L
s
.50407 .96287 m
.50697 .95889 L
s
.65535 .77691 m
.65579 .77823 L
s
.65579 .77823 m
.65656 .78049 L
s
.65656 .78049 m
.65685 .78136 L
s
.65685 .78136 m
.65696 .78167 L
s
.65696 .78167 m
.65727 .78259 L
s
.65768 .7838 m
.65791 .78448 L
s
.65763 .78365 m
.65768 .7838 L
s
.6538 .77233 m
.65535 .77691 L
s
.65232 .76284 m
.6538 .77233 L
s
.52412 1.08196 m .52336 1.08007 L .52336 1.08067 L 0 0 .1 r
F
0 g
.38121 .72345 m
.38145 .72258 L
s
.52202 .94374 m
.52322 .94401 L
s
.52285 .91857 m .52799 .90073 L .52607 .89679 L 0 .523 .314 r
F
0 g
.52377 .90054 m
.52607 .89679 L
s
.52549 .88524 m
.52607 .89679 L
s
.52412 1.08196 m .52629 1.08828 L .52538 1.08548 L 0 0 .1 r
F
0 g
.52629 1.08888 m
.52629 1.08828 L
s
.52897 1.0945 m .52629 1.08829 L .52916 1.09545 L 0 0 .084 r
F
.52897 1.0945 m .52538 1.08549 L .52629 1.08829 L F
.55709 1.14448 m .55342 1.1364 L .55204 1.12976 L 0 .524 .057 r
F
0 g
.54782 1.12486 m
.55204 1.12976 L
s
.51831 .9897 m
.51832 .98984 L
s
.51829 .98956 m
.51831 .9897 L
s
.51797 .98662 m
.51829 .98956 L
s
.51797 .98662 m
.51797 .98664 L
s
.78414 1.02366 m .79399 1.02118 L .79542 1.01348 L 0 1 .373 r
F
0 g
.78958 1.02975 m
.79399 1.02118 L
s
.79399 1.02118 m
.79628 1.02442 L
s
.51414 1.03648 m .51574 1.04995 L .51546 1.04407 L 0 .092 .191 r
F
.51784 1.04712 m .51574 1.04995 L .51742 1.05829 L 0 .038 .163 r
F
.51784 1.04712 m .51546 1.04407 L .51574 1.04995 L F
0 g
.51447 1.05055 m
.51574 1.04995 L
s
.4364 .79414 m
.44168 .79651 L
s
.56971 .63698 m .58693 .62884 L .58154 .62827 L 0 1 .486 r
F
0 g
.58693 .62884 m
.59438 .62582 L
s
.24459 .69565 m .23231 .69714 L .23646 .69898 L 0 1 .534 r
F
0 g
.23549 .70493 m
.23646 .69898 L
s
.53616 .98932 m
.53629 .98958 L
s
.81957 .97259 m .81937 .98264 L .82264 .98792 L 0 1 .449 r
F
0 g
.81803 .99647 m
.82264 .98792 L
s
.32815 .73898 m .31719 .73085 L .32099 .73524 L 0 .266 .289 r
F
0 g
.32012 .73937 m
.32099 .73524 L
s
.51382 1.0159 m .51505 1.0332 L .51477 1.02461 L 0 .162 .222 r
F
.51382 1.0159 m .51414 1.03648 L .51505 1.0332 L F
0 g
.51382 1.0159 m
.51435 1.00914 L
s
.51518 1.01901 m
.51526 1.02002 L
s
.51435 1.00914 m
.51518 1.01901 L
s
.51382 1.0159 m
.51386 1.01624 L
s
.51386 1.01624 m
.51387 1.01634 L
s
.51631 .99502 m .51915 1.02326 L .51774 1.00766 L 0 .224 .243 r
F
.51631 .99502 m .51948 1.03283 L .51915 1.02326 L F
.51631 .99502 m .51851 1.02996 L .51948 1.03283 L F
.51631 .99502 m .51708 1.01728 L .51851 1.02996 L F
.51631 .99502 m .51616 1.00327 L .51708 1.01728 L F
0 g
.51672 .99863 m
.51672 .99864 L
s
.51672 .99863 m
.51672 .99863 L
s
.51667 .99822 m
.51672 .99863 L
s
.51667 .99821 m
.51667 .99822 L
s
.51667 .99821 m
.51667 .99821 L
s
.51666 .99807 m
.51667 .99821 L
s
.51666 .99807 m
.51666 .99807 L
s
.51666 .99807 m
.51666 .99807 L
s
.51654 .99703 m
.51666 .99807 L
s
.51654 .99703 m
.51654 .99703 L
s
.51654 .99703 m
.51654 .99703 L
s
.51647 .99642 m
.51654 .99703 L
s
.51647 .99642 m
.51647 .99642 L
s
.51647 .99642 m
.51647 .99642 L
s
.51642 .99597 m
.51647 .99642 L
s
.51642 .99597 m
.51642 .99597 L
s
.51642 .99597 m
.51642 .99597 L
s
.51634 .99522 m
.51642 .99597 L
s
.51634 .99522 m
.51634 .99522 L
s
.51634 .99522 m
.51634 .99522 L
s
.51631 .99502 m
.51634 .99522 L
s
.51562 .9816 m
.51698 .99626 L
s
.51631 .99492 m
.51631 .99502 L
s
.51702 .99676 m
.51702 .99677 L
s
.517 .99655 m
.51702 .99676 L
s
.51698 .99626 m
.517 .99655 L
s
.51615 1.00301 m
.51616 1.00327 L
s
.23967 .86543 m .22968 .8669 L .23431 .8679 L 0 1 .52 r
F
0 g
.23431 .8679 m
.23676 .87206 L
s
.28132 .7863 m .27023 .78962 L .27461 .7904 L 0 1 .533 r
F
0 g
.27461 .7904 m
.27522 .79599 L
s
.5183 .96439 m
.5183 .96439 L
s
.5183 .96439 m
.5183 .9644 L
s
.35064 .72958 m
.35233 .72762 L
s
.35049 .72976 m
.35064 .72958 L
s
.35043 .72982 m
.35049 .72976 L
s
.34548 .73556 m
.35043 .72982 L
s
.3599 .68085 m
.36079 .68162 L
s
.35876 .67987 m
.3599 .68085 L
s
.35977 .67861 m
.35977 .67861 L
s
.35914 .67855 m
.35977 .67861 L
s
.47951 .95666 m .47116 .95268 L .47571 .95419 L 0 .34 .069 r
F
0 g
.47571 .95419 m
.47883 .95407 L
s
.32815 .73898 m .31901 .72316 L .31719 .73085 L 0 .266 .289 r
F
0 g
.31041 .72964 m
.31719 .73085 L
s
.48946 .70008 m .49632 .69697 L .50123 .69163 L 0 1 .468 r
F
0 g
.49632 .69697 m
.49972 .69327 L
s
.49632 .69697 m
.5017 .69785 L
s
.64846 1.12347 m
.64864 1.12364 L
s
.39749 .72582 m .39063 .71517 L .38786 .72173 L 0 1 .456 r
F
0 g
.38121 .72345 m
.38786 .72173 L
s
.52153 .97472 m
.52153 .97472 L
s
.39749 .72582 m .39718 .71077 L .39063 .71517 L 0 1 .456 r
F
.39749 .72582 m .40398 .71051 L .39718 .71077 L F
.39749 .72582 m .40647 .71456 L .40398 .71051 L F
.39749 .72582 m .40369 .72112 L .40647 .71456 L F
0 g
.39498 .7324 m
.39749 .72582 L
s
.39071 .72607 m
.39749 .72582 L
s
.22686 .79463 m .21984 .78502 L .21562 .79235 L 0 1 .538 r
F
.22686 .79463 m .22631 .7803 L .21984 .78502 L F
.22686 .79463 m .23072 .78135 L .22631 .7803 L F
.22686 .79463 m .23094 .7875 L .23072 .78135 L F
0 g
.22041 .79931 m
.22686 .79463 L
s
.22686 .79463 m
.2272 .80056 L
s
.50923 .96337 m
.50924 .96336 L
s
.50923 .96337 m
.50924 .96336 L
s
.54658 .65042 m .55468 .64785 L .56157 .64373 L 0 1 .495 r
F
0 g
.55468 .64785 m
.56157 .64373 L
s
.55468 .64785 m
.55994 .64824 L
s
.56157 .64373 m
.56665 .6441 L
s
.65331 .76492 m
.65703 .77277 L
s
.65715 .77303 m
.65794 .77468 L
s
.65232 .76284 m
.65331 .76492 L
s
.65794 .77468 m
.65852 .7759 L
s
.65852 .7759 m
.65882 .77654 L
s
.4119 .50926 m .39993 .51189 L .40182 .51253 L 0 1 .3 r
F
0 g
.39494 .5178 m
.40182 .51253 L
s
.4119 .50926 m .40754 .50778 L .39993 .51189 L 0 1 .3 r
F
.4119 .50926 m .41959 .50294 L .40754 .50778 L F
.4119 .50926 m .42968 .49967 L .41959 .50294 L F
.4119 .50926 m .43108 .50015 L .42968 .49967 L F
.4119 .50926 m .42346 .50426 L .43108 .50015 L F
0 g
.40465 .51334 m
.4119 .50926 L
s
.40182 .51253 m
.4119 .50926 L
s
.42346 .50426 m
.43318 .50072 L
s
.52998 .95667 m
.53239 .9618 L
s
.53239 .9618 m
.5333 .96372 L
s
.52998 .95667 m
.53249 .95249 L
s
.36513 .67608 m
.36804 .6713 L
s
.35676 .68676 m
.35978 .68291 L
s
.35978 .68291 m
.36079 .68162 L
s
.36079 .68162 m
.36284 .679 L
s
.36488 .6764 m
.36513 .67608 L
s
.23967 .86543 m .22817 .86274 L .22968 .8669 L 0 1 .52 r
F
0 g
.22518 .86976 m
.22968 .8669 L
s
.52198 .93863 m .52414 .92798 L .52251 .93313 L 0 .372 .317 r
F
.52198 .93863 m .5264 .92689 L .52414 .92798 L F
.52198 .93863 m .52779 .93057 L .5264 .92689 L F
.52198 .93863 m .52726 .93609 L .52779 .93057 L F
0 g
.52057 .93546 m
.52251 .93313 L
s
.52198 .93863 m .52516 .93974 L .52726 .93609 L 0 .372 .317 r
F
.52198 .93863 m .5229 .94083 L .52516 .93974 L F
0 g
.52084 .93896 m
.52198 .93863 L
s
.52198 .93863 m
.52251 .93313 L
s
.52202 .94374 m
.5229 .94083 L
s
.76137 .64138 m .76253 .6409 L .75881 .64321 L 0 0 0 r
F
.76137 .64138 m .77087 .63633 L .76253 .6409 L F
0 g
.75324 .64676 m
.76137 .64138 L
s
.69042 .8059 m .69297 .77502 L .68914 .7725 L 0 .536 .27 r
F
0 g
.68914 .7725 m
.68952 .78246 L
s
.68757 .76569 m
.68914 .7725 L
s
.53249 .95249 m
.53261 .95273 L
s
.54649 1.00603 m
.54774 1.00788 L
s
.5462 1.0056 m
.54649 1.00603 L
s
.5458 1.005 m
.5462 1.0056 L
s
.54549 1.00454 m
.5458 1.005 L
s
.54516 1.00406 m
.54549 1.00454 L
s
.5435 1.00154 m
.54516 1.00406 L
s
.54342 1.00142 m
.5435 1.00154 L
s
.54326 1.00118 m
.54342 1.00142 L
s
.54266 1.00027 m
.54326 1.00118 L
s
.54244 .99993 m
.54266 1.00027 L
s
.52253 .96566 m .52283 .96449 L .52604 .97031 L 0 .454 .149 r
F
0 g
.52283 .96449 m
.52301 .96482 L
s
.5246 .96691 m
.52515 .96855 L
s
.52515 .96855 m
.52515 .96855 L
s
.52515 .96855 m
.52528 .96893 L
s
.52194 .96764 m
.52431 .97177 L
s
.52424 .96918 m
.52431 .96933 L
s
.52431 .96933 m
.52435 .96944 L
s
.5215 .96182 m
.52283 .96449 L
s
.53081 .90742 m .53769 .89642 L .5375 .88396 L 0 .605 .298 r
F
0 g
.5375 .88396 m
.53951 .8791 L
s
.54372 1.00225 m
.54589 1.0062 L
s
.54589 1.0062 m
.54615 1.00668 L
s
.54368 1.00219 m
.54372 1.00225 L
s
.54345 1.00177 m
.54368 1.00219 L
s
.54272 1.00044 m
.54345 1.00177 L
s
.54244 .99993 m
.54272 1.00044 L
s
.52437 .96947 m .53207 .98706 L .52759 .97584 L 0 .25 .233 r
F
.52437 .96947 m .5357 1.00063 L .53207 .98706 L F
0 g
.52153 .97472 m
.52154 .97477 L
s
.52153 .97472 m
.52155 .97477 L
s
.52437 .96947 m .53606 1.00747 L .5357 1.00063 L 0 .25 .233 r
F
.52437 .96947 m .53281 1.00102 L .53606 1.00747 L F
0 g
.5358 .98875 m
.53601 .98913 L
s
.53571 .98846 m
.53616 .98932 L
s
.52154 .97477 m
.52208 .97669 L
s
.52155 .97477 m
.52219 .97653 L
s
.53491 .98694 m
.53571 .98846 L
s
.52437 .96947 m .52815 .98565 L .53281 1.00102 L 0 .25 .233 r
F
.52437 .96947 m .52454 .97216 L .52815 .98565 L F
0 g
.52431 .97177 m
.5244 .97192 L
s
.52435 .96944 m
.52437 .96947 L
s
.52453 .9698 m
.52453 .9698 L
s
.52453 .9698 m
.52453 .9698 L
s
.5245 .96972 m
.52453 .9698 L
s
.52443 .96959 m
.5245 .96972 L
s
.52437 .96947 m
.52443 .96959 L
s
.52437 .96947 m
.52437 .96947 L
s
.28559 .87624 m .27641 .86982 L .27412 .87349 L 0 1 .516 r
F
.28559 .87624 m .28153 .86799 L .27641 .86982 L F
.28559 .87624 m .28605 .86923 L .28153 .86799 L F
.28559 .87624 m .28779 .87277 L .28605 .86923 L F
0 g
.2834 .87702 m
.28559 .87624 L
s
.31901 .72316 m .30766 .72078 L .31148 .72466 L 0 1 .456 r
F
0 g
.31041 .72964 m
.31148 .72466 L
s
.65275 .82558 m .66267 .84259 L .6565 .81418 L 0 .284 .256 r
F
.65275 .82558 m .66702 .87361 L .66267 .84259 L F
.65275 .82558 m .66719 .89228 L .66702 .87361 L F
.65275 .82558 m .66305 .886 L .66719 .89228 L F
0 g
.65963 .88673 m
.65964 .88674 L
s
.65274 .82409 m
.65275 .82558 L
s
.65253 .8244 m
.65275 .82558 L
s
.47951 .95666 m .46827 .95296 L .47116 .95268 L 0 .34 .069 r
F
0 g
.46737 .95025 m
.47116 .95268 L
s
.44022 .72511 m .43187 .72072 L .43396 .72478 L 0 1 .462 r
F
.44022 .72511 m .43529 .71497 L .43187 .72072 L F
0 g
.43111 .73083 m
.43396 .72478 L
s
.44022 .72511 m .44196 .71136 L .43529 .71497 L 0 1 .462 r
F
.44022 .72511 m .44822 .71169 L .44196 .71136 L F
.44022 .72511 m .4499 .71575 L .44822 .71169 L F
.44022 .72511 m .44647 .7215 L .4499 .71575 L F
0 g
.4371 .73095 m
.44022 .72511 L
s
.43396 .72478 m
.44022 .72511 L
s
.51866 .98761 m
.51867 .98765 L
s
.53601 .98913 m
.53684 .99068 L
s
.52897 1.0945 m .52916 1.09545 L .53209 1.10222 L 0 0 .084 r
F
0 g
.52629 1.08829 m
.52916 1.09545 L
s
.80672 1.00448 m .81582 .99263 L .81127 .99593 L 0 1 .427 r
F
.79542 1.01348 m .80672 1.00448 L .80445 1.0012 L 0 1 .404 r
F
.52285 .91857 m .52821 .90981 L .52799 .90073 L 0 .523 .314 r
F
0 g
.52799 .90073 m
.53052 .8952 L
s
.52285 .91857 m .52658 .91799 L .52821 .90981 L 0 .523 .314 r
F
.52285 .91857 m .52428 .92174 L .52658 .91799 L F
0 g
.52091 .92092 m
.52285 .91857 L
s
.52263 .90949 m
.52285 .91857 L
s
.44647 .7215 m
.45241 .72196 L
s
.48946 .70008 m .50123 .69163 L .50091 .68762 L 0 1 .468 r
F
0 g
.50123 .69163 m
.50664 .6923 L
s
.49972 .69327 m
.50123 .69163 L
s
.25478 .70068 m .2513 .68934 L .24459 .69565 L 0 1 .532 r
F
.25478 .70068 m .25928 .68626 L .2513 .68934 L F
.25478 .70068 m .26319 .68846 L .25928 .68626 L F
.25478 .70068 m .26125 .69465 L .26319 .68846 L F
0 g
.24683 .70374 m
.25478 .70068 L
s
.25304 .70671 m
.25478 .70068 L
s
.63957 .71773 m .63979 .71099 L .63694 .70928 L 0 .298 .326 r
F
0 g
.63608 .70823 m
.63694 .70928 L
s
.63957 .71773 m .64697 .72198 L .63979 .71099 L 0 .298 .326 r
F
.63957 .71773 m .6537 .73491 L .64697 .72198 L F
.63957 .71773 m .65633 .74338 L .6537 .73491 L F
.63957 .71773 m .65311 .74172 L .65633 .74338 L F
.63957 .71773 m .64593 .73073 L .65311 .74172 L F
0 g
.63421 .70865 m
.63957 .71773 L
s
.63694 .70928 m
.63957 .71773 L
s
.51784 1.04712 m .51636 1.04285 L .51546 1.04407 L 0 .038 .163 r
F
0 g
.51414 1.03648 m
.51546 1.04407 L
s
.67986 .90204 m
.68053 .90192 L
s
.19857 .91044 m .18942 .91066 L .19409 .91168 L 0 .776 .36 r
F
0 g
.19409 .91168 m
.19762 .91461 L
s
.19857 .91044 m .18691 .9076 L .18942 .91066 L 0 .776 .36 r
F
0 g
.18596 .91231 m
.18942 .91066 L
s
.69772 .65031 m
.69904 .65328 L
s
.69375 .63692 m
.69772 .65031 L
s
.70805 .59082 m .73024 .59269 L .72558 .58943 L 0 1 .501 r
F
0 g
.73024 .59269 m
.73925 .5942 L
s
.66908 .57935 m .66645 .57029 L .66376 .5687 L 0 .288 .315 r
F
0 g
.6636 .56854 m
.66376 .5687 L
s
.66908 .57935 m .67613 .58316 L .66645 .57029 L 0 .288 .315 r
F
0 g
.66104 .56776 m
.66908 .57935 L
s
.66376 .5687 m
.66908 .57935 L
s
.69064 .89707 m
.69331 .89683 L
s
.22817 .86274 m .21811 .86439 L .22274 .8654 L 0 1 .522 r
F
0 g
.22274 .8654 m
.22518 .86976 L
s
.50438 .96369 m .49806 .96969 L .50163 .96615 L 0 .419 .103 r
F
.50438 .96369 m .49554 .97274 L .49806 .96969 L F
.50438 .96369 m .49575 .97326 L .49554 .97274 L F
.50438 .96369 m .49851 .97079 L .49575 .97326 L F
.50438 .96369 m .50197 .96699 L .49851 .97079 L F
.50438 .96369 m .50449 .96394 L .50197 .96699 L F
0 g
.50438 .96369 m
.50697 .95889 L
s
.50273 .96467 m
.50407 .96287 L
s
.50416 .96389 m
.50438 .96369 L
s
.50449 .96394 m
.50715 .95935 L
s
.51784 1.04712 m .51742 1.05829 L .51939 1.06354 L 0 .038 .163 r
F
0 g
.51574 1.04995 m
.51742 1.05829 L
s
.51616 1.05726 m
.51742 1.05829 L
s
.48946 .70008 m .48295 .69533 L .48373 .69938 L 0 1 .468 r
F
.48946 .70008 m .48785 .68999 L .48295 .69533 L F
.48946 .70008 m .49518 .68691 L .48785 .68999 L F
.48946 .70008 m .50091 .68762 L .49518 .68691 L F
0 g
.4849 .70563 m
.48946 .70008 L
s
.31901 .72316 m .30969 .71308 L .30766 .72078 L 0 1 .456 r
F
0 g
.30067 .72086 m
.30766 .72078 L
s
.24459 .69565 m .23438 .69086 L .23231 .69714 L 0 1 .534 r
F
0 g
.22496 .70059 m
.23231 .69714 L
s
.21023 .9133 m .2011 .91323 L .20577 .91428 L 0 .712 .334 r
F
0 g
.20577 .91428 m
.20928 .91694 L
s
.21023 .9133 m .19857 .91044 L .2011 .91323 L 0 .712 .334 r
F
0 g
.19762 .91461 m
.2011 .91323 L
s
.53341 .9645 m
.5335 .9645 L
s
.53369 .96452 m
.5341 .96454 L
s
.53355 .96451 m
.53369 .96452 L
s
.53391 .96822 m
.53449 .96938 L
s
.53364 .96767 m
.53391 .96822 L
s
.5175 .99797 m .51703 .99684 L .51774 1.00766 L 0 .223 .242 r
F
0 g
.51718 .9992 m
.51718 .9992 L
s
.51718 .9992 m
.51718 .9992 L
s
.51716 .99884 m
.51718 .9992 L
s
.51716 .99884 m
.51716 .99884 L
s
.51716 .99884 m
.51716 .99884 L
s
.51715 .99873 m
.51716 .99884 L
s
.51715 .99873 m
.51715 .99873 L
s
.51715 .99873 m
.51715 .99873 L
s
.5171 .99793 m
.51715 .99873 L
s
.5171 .99793 m
.5171 .99793 L
s
.5171 .99792 m
.5171 .99793 L
s
.51706 .99733 m
.5171 .99792 L
s
.51706 .99732 m
.51706 .99733 L
s
.51706 .99732 m
.51706 .99732 L
s
.51705 .9972 m
.51706 .99732 L
s
.51705 .9972 m
.51705 .9972 L
s
.51705 .9972 m
.51705 .9972 L
s
.51703 .99684 m
.51705 .9972 L
s
.51702 .99677 m
.51703 .99684 L
s
.51672 .99864 m
.51712 1.00215 L
s
.51717 .99348 m
.51749 .99779 L
s
.51003 .96453 m
.51003 .96452 L
s
.51002 .96454 m
.51003 .96452 L
s
.39063 .71517 m .38074 .71026 L .38358 .71495 L 0 1 .464 r
F
0 g
.38145 .72258 m
.38358 .71495 L
s
.51758 .96566 m
.51758 .96566 L
s
.22188 .9162 m .21277 .91585 L .21744 .9169 L 0 .647 .307 r
F
0 g
.21744 .9169 m
.22095 .91932 L
s
.22188 .9162 m .21023 .9133 L .21277 .91585 L 0 .647 .307 r
F
0 g
.20928 .91694 m
.21277 .91585 L
s
.74029 1.08188 m .75036 1.0727 L .74601 1.07743 L 0 0 0 r
F
.74667 1.07578 m .75036 1.0727 L .75537 1.06625 L 0 .867 .15 r
F
0 g
.75095 1.07109 m
.75105 1.07082 L
s
.74667 1.07578 m .74601 1.07743 L .75036 1.0727 L 0 .867 .15 r
F
0 g
.75036 1.0727 m
.7508 1.07213 L
s
.41929 .72471 m .41022 .72064 L .41271 .72469 L 0 1 .464 r
F
0 g
.41266 .72482 m
.41271 .72469 L
s
.52156 .97824 m
.52156 .97824 L
s
.33703 .76067 m
.33802 .7598 L
s
.33162 .76539 m
.33703 .76067 L
s
.33162 .76539 m
.33165 .75963 L
s
.64982 .74167 m
.65331 .74902 L
s
.64829 .73845 m
.64982 .74167 L
s
.64593 .73073 m
.64829 .73845 L
s
.47951 .95666 m .46897 .95485 L .46827 .95296 L 0 .34 .069 r
F
.47951 .95666 m .47278 .95733 L .46897 .95485 L F
.47951 .95666 m .47715 .95874 L .47278 .95733 L F
.47951 .95666 m .48004 .95845 L .47715 .95874 L F
0 g
.47951 .95666 m
.48253 .95579 L
s
.47571 .95419 m
.47951 .95666 L
s
.39793 .78048 m .38859 .77771 L .39184 .77841 L 0 0 0 r
F
.51628 1.02333 m .51477 1.02461 L .51505 1.0332 L 0 .137 .21 r
F
.51628 1.02333 m .51529 1.02037 L .51477 1.02461 L F
0 g
.51387 1.01634 m
.51477 1.02461 L
s
.51526 1.02002 m
.51529 1.02037 L
s
.46827 .95296 m .4598 .94793 L .46434 .95 L 0 .305 .041 r
F
0 g
.46434 .95 m
.46737 .95025 L
s
.23354 .91913 m .22445 .9185 L .22912 .91957 L 0 .607 .278 r
F
0 g
.22912 .91957 m
.23261 .92173 L
s
.23354 .91913 m .22188 .9162 L .22445 .9185 L 0 .607 .278 r
F
0 g
.22095 .91932 m
.22445 .9185 L
s
.41929 .72471 m .41335 .71465 L .41022 .72064 L 0 1 .464 r
F
.41929 .72471 m .42003 .71072 L .41335 .71465 L F
.41929 .72471 m .42662 .71074 L .42003 .71072 L F
.41929 .72471 m .42872 .71471 L .42662 .71074 L F
.41929 .72471 m .42557 .72069 L .42872 .71471 L F
0 g
.41644 .73076 m
.41929 .72471 L
s
.41271 .72469 m
.41929 .72471 L
s
.52818 .85917 m
.52892 .86296 L
s
.42485 .78983 m .41606 .78659 L .41909 .78734 L 0 0 0 r
F
0 g
.41819 .78623 m
.41909 .78734 L
s
.28132 .7863 m .27051 .78441 L .27023 .78962 L 0 1 .533 r
F
0 g
.26417 .79408 m
.27023 .78962 L
s
.22817 .86274 m .21666 .86003 L .21811 .86439 L 0 1 .522 r
F
0 g
.21358 .86746 m
.21811 .86439 L
s
.70542 .89275 m .7117 .88928 L .70745 .89082 L 0 1 .289 r
F
.70542 .89275 m .7161 .88895 L .7117 .88928 L F
0 g
.70542 .89275 m
.70709 .89117 L
s
.70107 .89313 m
.70542 .89275 L
s
.72707 1.09763 m .74029 1.08188 L .73875 1.08603 L 0 0 0 r
F
.46175 .63421 m .45314 .63417 L .45442 .63486 L 0 .987 .292 r
F
0 g
.44919 .63722 m
.45442 .63486 L
s
.46175 .63421 m .45891 .63249 L .45314 .63417 L 0 .987 .292 r
F
.46175 .63421 m .46788 .63096 L .45891 .63249 L F
.46175 .63421 m .47522 .6303 L .46788 .63096 L F
.46175 .63421 m .47603 .63097 L .47522 .6303 L F
.46175 .63421 m .47026 .63264 L .47603 .63097 L F
0 g
.45633 .63577 m
.46175 .63421 L
s
.45442 .63486 m
.46175 .63421 L
s
.47026 .63264 m
.47724 .63181 L
s
.52253 .96566 m .52877 .98567 L .52507 .97472 L 0 .454 .149 r
F
.52253 .96566 m .532 .99155 L .52877 .98567 L F
.52253 .96566 m .5326 .9884 L .532 .99155 L F
.52253 .96566 m .53004 .97929 L .5326 .9884 L F
.52253 .96566 m .52604 .97031 L .53004 .97929 L F
0 g
.52253 .96566 m
.52268 .96619 L
s
.52416 .97695 m
.52471 .9782 L
s
.52465 .97579 m
.52472 .97596 L
s
.52472 .97596 m
.52474 .97602 L
s
.52428 .97478 m
.52465 .97579 L
s
.51955 .96102 m
.52253 .96566 L
s
.52393 .96453 m
.52495 .96731 L
s
.52182 .96803 m
.52428 .97478 L
s
.52141 .97073 m
.52416 .97695 L
s
.24519 .9221 m .23613 .92119 L .2408 .92228 L 0 .583 .252 r
F
0 g
.2408 .92228 m
.24427 .92419 L
s
.24519 .9221 m .23354 .91913 L .23613 .92119 L 0 .583 .252 r
F
0 g
.23261 .92173 m
.23613 .92119 L
s
.5062 .68234 m .51357 .67932 L .5192 .67429 L 0 1 .481 r
F
0 g
.51357 .67932 m
.51897 .68 L
s
.37056 .77179 m
.37655 .77422 L
s
.51929 .98818 m
.51931 .98833 L
s
.51929 .98818 m
.51934 .98849 L
s
.51628 1.02333 m .51505 1.0332 L .51636 1.04285 L 0 .137 .21 r
F
0 g
.51477 1.02461 m
.51529 1.02037 L
s
.51414 1.03648 m
.51505 1.0332 L
s
.66066 .87496 m
.66107 .87747 L
s
.66107 .87747 m
.66205 .8835 L
s
.34638 .72985 m
.34638 .72981 L
s
.34637 .7299 m
.34638 .72985 L
s
.34636 .72994 m
.34637 .7299 L
s
.34548 .73556 m
.34636 .72994 L
s
.35074 .54022 m .33773 .54398 L .34052 .54506 L 0 1 .476 r
F
0 g
.33506 .55238 m
.34052 .54506 L
s
.35074 .54022 m .34409 .53763 L .33773 .54398 L 0 1 .476 r
F
.35074 .54022 m .35536 .53023 L .34409 .53763 L F
.35074 .54022 m .3656 .52539 L .35536 .53023 L F
.35074 .54022 m .36796 .52632 L .3656 .52539 L F
.35074 .54022 m .36158 .53268 L .36796 .52632 L F
0 g
.3447 .5466 m
.35074 .54022 L
s
.34052 .54506 m
.35074 .54022 L
s
.59991 .61791 m .61712 .61435 L .61926 .61202 L 0 1 .487 r
F
.59991 .61791 m .60884 .61688 L .61712 .61435 L F
0 g
.61712 .61435 m
.62185 .61568 L
s
.60884 .61688 m
.61356 .61825 L
s
.60884 .61688 m
.61712 .61435 L
s
.65661 .86081 m
.65666 .86263 L
s
.65649 .8572 m
.65661 .86081 L
s
.65642 .85491 m
.65649 .8572 L
s
.65679 .86658 m
.65685 .86867 L
s
.65673 .86482 m
.65679 .86658 L
s
.65666 .86263 m
.65673 .86482 L
s
.65719 .8589 m
.6575 .86242 L
s
.65919 .8817 m
.65923 .88216 L
s
.65966 .88705 m
.66018 .89299 L
s
.65923 .88216 m
.65966 .88705 L
s
.66302 .92527 m
.66305 .92564 L
s
.6575 .86242 m
.65919 .8817 L
s
.46827 .95296 m .45703 .94775 L .4598 .94793 L 0 .305 .041 r
F
0 g
.45592 .94518 m
.4598 .94793 L
s
.70021 .59502 m .71734 .59336 L .70805 .59082 L 0 1 .49 r
F
0 g
.71734 .59336 m
.72683 .59416 L
s
.71734 .59336 m
.72174 .59635 L
s
.25684 .92513 m .2478 .92393 L .25247 .92504 L 0 .553 .244 r
F
.25684 .92513 m .24519 .9221 L .2478 .92393 L F
0 g
.24427 .92419 m
.2478 .92393 L
s
.25247 .92504 m
.25593 .92671 L
s
.33802 .7598 m
.33826 .75824 L
s
.33826 .75824 m
.33829 .75806 L
s
.33829 .75806 m
.33868 .75551 L
s
.46978 .8127 m
.47419 .81498 L
s
.52531 .66568 m .5331 .66282 L .5394 .65818 L 0 1 .491 r
F
0 g
.5331 .66282 m
.53847 .66332 L
s
.52531 .66568 m .5394 .65818 L .54003 .65485 L 0 1 .491 r
F
0 g
.5394 .65818 m
.54468 .65856 L
s
.5331 .66282 m
.5394 .65818 L
s
.39063 .71517 m .38377 .70397 L .38074 .71026 L 0 1 .464 r
F
0 g
.37385 .71168 m
.38074 .71026 L
s
.56971 .63698 m .56539 .63357 L .5643 .63642 L 0 1 .486 r
F
.56971 .63698 m .57279 .63007 L .56539 .63357 L F
.56971 .63698 m .58154 .62827 L .57279 .63007 L F
0 g
.56266 .64078 m
.56971 .63698 L
s
.34744 .7062 m
.3495 .70027 L
s
.34743 .70623 m
.34744 .7062 L
s
.27412 .87349 m .26502 .86691 L .26265 .87079 L 0 1 .517 r
F
.27412 .87349 m .27021 .86492 L .26502 .86691 L F
.27412 .87349 m .27474 .86614 L .27021 .86492 L F
.27412 .87349 m .27641 .86982 L .27474 .86614 L F
0 g
.26895 .87547 m
.27412 .87349 L
s
.27412 .87349 m
.27587 .87701 L
s
.70896 1.10653 m .71872 1.10054 L .71478 1.10511 L 0 0 .029 r
F
.71699 1.1115 m .71872 1.10054 L .72398 1.09734 L 0 0 .016 r
F
.71699 1.1115 m .71478 1.10511 L .71872 1.10054 L F
0 g
.71869 1.09605 m
.71872 1.10054 L
s
.81957 .97259 m .83078 .9751 L .83102 .96487 L 0 1 .449 r
F
0 g
.82719 .98496 m
.83078 .9751 L
s
.83078 .9751 m
.83402 .98073 L
s
.69921 1.11818 m .70896 1.10653 L .70886 1.11237 L 0 .043 .055 r
F
.81131 .80985 m .8259 .80398 L .82257 .80717 L 0 0 0 r
F
0 g
.82493 .80188 m
.8259 .80398 L
s
.70021 .59502 m .69879 .59025 L .69576 .59203 L 0 1 .49 r
F
.70021 .59502 m .70805 .59082 L .69879 .59025 L F
0 g
.69576 .59203 m
.70021 .59502 L
s
.69123 .59468 m
.70021 .59502 L
s
.53842 .99379 m
.53858 .9941 L
s
.53632 .98963 m
.53656 .99011 L
s
.53858 .9941 m
.53867 .99428 L
s
.53629 .98958 m
.53632 .98963 L
s
.26849 .92822 m .25948 .92673 L .26415 .92787 L 0 .518 .234 r
F
.26849 .92822 m .25684 .92513 L .25948 .92673 L F
0 g
.25593 .92671 m
.25948 .92673 L
s
.26415 .92787 m
.26759 .9293 L
s
.5175 .99797 m .52115 1.02891 L .51927 1.0117 L 0 .223 .242 r
F
.5175 .99797 m .52187 1.03979 L .52115 1.02891 L F
.5175 .99797 m .52092 1.03704 L .52187 1.03979 L F
.5175 .99797 m .51915 1.02326 L .52092 1.03704 L F
.5175 .99797 m .51774 1.00766 L .51915 1.02326 L F
0 g
.5178 1.0003 m
.5178 1.00031 L
s
.5178 1.0003 m
.5178 1.0003 L
s
.51775 .9999 m
.5178 1.0003 L
s
.51775 .99989 m
.51775 .9999 L
s
.51775 .99989 m
.51775 .99989 L
s
.51773 .99979 m
.51775 .99989 L
s
.51773 .99979 m
.51773 .99979 L
s
.51773 .99978 m
.51773 .99979 L
s
.51762 .99892 m
.51773 .99978 L
s
.51762 .99892 m
.51762 .99892 L
s
.51762 .99892 m
.51762 .99892 L
s
.51753 .99819 m
.51762 .99892 L
s
.51753 .99819 m
.51753 .99819 L
s
.51753 .99819 m
.51753 .99819 L
s
.51751 .99808 m
.51753 .99819 L
s
.51751 .99807 m
.51751 .99808 L
s
.51751 .99807 m
.51751 .99807 L
s
.5175 .99797 m
.51751 .99807 L
s
.51749 .99779 m
.5175 .99797 L
s
.51756 1.00612 m
.51774 1.00766 L
s
.51712 1.00215 m
.51756 1.00612 L
s
.51644 .98359 m
.51811 .99882 L
s
.51768 1.00681 m
.51774 1.00766 L
s
.5175 1.00411 m
.51768 1.00681 L
s
.51718 .9992 m
.5175 1.00411 L
s
.51818 .99947 m
.51818 .9995 L
s
.51814 .99914 m
.51818 .99947 L
s
.51811 .99882 m
.51814 .99914 L
s
.5062 .68234 m .5192 .67429 L .51935 .67059 L 0 1 .481 r
F
0 g
.5192 .67429 m
.52458 .67478 L
s
.51357 .67932 m
.5192 .67429 L
s
.45703 .94775 m .44843 .94222 L .45298 .9446 L 0 .242 .003 r
F
0 g
.45298 .9446 m
.45592 .94518 L
s
.68518 .60779 m
.68848 .61355 L
s
.68389 .60556 m
.68518 .60779 L
s
.68388 .60553 m
.68389 .60556 L
s
.67996 .59743 m
.68388 .60553 L
s
.67986 .59722 m
.67996 .59743 L
s
.67963 .59675 m
.67986 .59722 L
s
.51085 .96556 m
.51085 .96554 L
s
.51085 .96557 m
.51085 .96554 L
s
.45383 .80317 m
.45872 .80568 L
s
.7161 .88895 m .72233 .88532 L .71807 .88692 L 0 1 .288 r
F
.7161 .88895 m .72678 .88513 L .72233 .88532 L F
0 g
.40369 .72112 m
.40639 .71475 L
s
.40369 .72112 m
.41022 .72064 L
s
.66096 .7705 m
.66107 .77001 L
s
.66107 .77001 m
.66117 .76959 L
s
.50484 .96474 m .49851 .97079 L .50197 .96699 L 0 .422 .104 r
F
.50484 .96474 m .49645 .97495 L .49851 .97079 L F
.50484 .96474 m .49718 .97667 L .49645 .97495 L F
.50484 .96474 m .50006 .97441 L .49718 .97667 L F
.50484 .96474 m .50316 .96969 L .50006 .97441 L F
0 g
.5044 .96404 m
.50449 .96394 L
s
.50163 .96615 m
.50273 .96467 L
s
.50163 .96615 m
.50163 .96615 L
s
.50484 .96474 m .5052 .96555 L .50316 .96969 L 0 .422 .104 r
F
0 g
.50484 .96474 m
.50715 .95933 L
s
.50163 .96615 m
.50416 .96389 L
s
.50364 .96496 m
.5044 .96404 L
s
.5029 .96626 m
.50484 .96474 L
s
.5052 .96555 m
.50779 .96075 L
s
.47253 .708 m .47927 .70481 L .48373 .69938 L 0 1 .467 r
F
0 g
.47927 .70481 m
.4849 .70563 L
s
.33321 .66906 m .32135 .669 L .32488 .66962 L 0 1 .502 r
F
0 g
.61287 .51722 m
.61305 .51736 L
s
.61176 .51631 m
.61275 .51712 L
s
.6059 .51331 m
.61176 .51631 L
s
.60511 .5129 m
.6059 .51331 L
s
.30969 .71308 m .29808 .71209 L .30192 .71539 L 0 1 .486 r
F
0 g
.30067 .72086 m
.30192 .71539 L
s
.45703 .94775 m .4458 .94163 L .44843 .94222 L 0 .242 .003 r
F
0 g
.44447 .93939 m
.44843 .94222 L
s
.21666 .86003 m .20654 .86187 L .21117 .86288 L 0 1 .524 r
F
0 g
.21117 .86288 m
.21358 .86746 L
s
.51681 .96663 m
.51681 .96663 L
s
.52149 .98127 m
.52149 .98127 L
s
.67017 .91008 m
.67332 .90825 L
s
.28013 .9314 m .27115 .9296 L .27582 .93077 L 0 .474 .222 r
F
.28013 .9314 m .26849 .92822 L .27115 .9296 L F
0 g
.26759 .9293 m
.27115 .9296 L
s
.27582 .93077 m
.27925 .93197 L
s
.52414 .92798 m
.52451 .9278 L
s
.52414 .92798 m
.52428 .92174 L
s
.67995 .59673 m
.68004 .59673 L
s
.45605 .71627 m .44822 .71169 L .4499 .71575 L 0 1 .465 r
F
.45605 .71627 m .45219 .70613 L .44822 .71169 L F
0 g
.44815 .71868 m
.4499 .71575 L
s
.44647 .7215 m
.44815 .71868 L
s
.45605 .71627 m .45915 .70277 L .45219 .70613 L 0 1 .465 r
F
.45605 .71627 m .46531 .7033 L .45915 .70277 L F
.45605 .71627 m .46655 .70736 L .46531 .7033 L F
.45605 .71627 m .46258 .71292 L .46655 .70736 L F
0 g
.45241 .72196 m
.45605 .71627 L
s
.4499 .71575 m
.45605 .71627 L
s
.46258 .71292 m
.46841 .71359 L
s
.4458 .94163 m .43707 .93597 L .44162 .93852 L 0 .142 0 r
F
0 g
.44162 .93852 m
.44447 .93939 L
s
.4458 .94163 m .43456 .93502 L .43707 .93597 L 0 .142 0 r
F
0 g
.43302 .93326 m
.43707 .93597 L
s
.49171 .96165 m .48372 .96001 L .48809 .9603 L 0 .402 .089 r
F
.49171 .96165 m .48093 .96124 L .48372 .96001 L F
0 g
.48809 .9603 m
.4911 .95943 L
s
.49171 .96165 m .4816 .96317 L .48093 .96124 L 0 .402 .089 r
F
.49171 .96165 m .48522 .96452 L .4816 .96317 L F
.49171 .96165 m .48938 .9644 L .48522 .96452 L F
.49171 .96165 m .49215 .96317 L .48938 .9644 L F
0 g
.49171 .96165 m
.49465 .95951 L
s
.48809 .9603 m
.49171 .96165 L
s
.43456 .93502 m .42572 .92949 L .43026 .9321 L 0 .003 0 r
F
.43456 .93502 m .42333 .92821 L .42572 .92949 L F
0 g
.42311 .92793 m
.42572 .92949 L
s
.43026 .9321 m
.43302 .93326 L
s
.51985 .98831 m
.51986 .98835 L
s
.51985 .98831 m
.51987 .98839 L
s
.4121 .92139 m .403 .91659 L .40755 .91913 L 0 .304 .211 r
F
0 g
.40755 .91913 m
.41014 .92082 L
s
.76633 .81803 m .77212 .82322 L .76767 .82426 L 0 .127 .054 r
F
.76633 .81803 m .77757 .81654 L .77212 .82322 L F
0 g
.76099 .82569 m
.76633 .81803 L
s
.38354 .77599 m .37655 .77422 L .37991 .77494 L 0 0 0 r
F
.38354 .77599 m .37522 .77429 L .37655 .77422 L F
.38354 .77599 m .3768 .77511 L .37522 .77429 L F
0 g
.3799 .77493 m
.37991 .77494 L
s
.37914 .77394 m
.3799 .77493 L
s
.38354 .77599 m .38043 .77616 L .3768 .77511 L 0 0 0 r
F
.38354 .77599 m .3837 .77674 L .38043 .77616 L F
.38354 .77599 m .38502 .77667 L .3837 .77674 L F
0 g
.38354 .77599 m
.38493 .77604 L
s
.37991 .77494 m
.38354 .77599 L
s
.65586 .80317 m
.65649 .80503 L
s
.65649 .80503 m
.65903 .81256 L
s
.65586 .80317 m
.6563 .81068 L
s
.6563 .81068 m
.6565 .81418 L
s
.4121 .92139 m .40086 .91469 L .403 .91659 L 0 .304 .211 r
F
0 g
.39869 .91479 m
.403 .91659 L
s
.68943 1.13103 m .68597 1.12517 L .68624 1.11783 L 0 .134 .076 r
F
0 g
.68027 1.11641 m
.68624 1.11783 L
s
.47253 .708 m .46531 .7033 L .46655 .70736 L 0 1 .467 r
F
.47253 .708 m .46978 .69787 L .46531 .7033 L F
.47253 .708 m .47697 .69468 L .46978 .69787 L F
.47253 .708 m .48295 .69533 L .47697 .69468 L F
.47253 .708 m .48373 .69938 L .48295 .69533 L F
0 g
.47927 .70481 m
.48247 .70091 L
s
.48247 .70091 m
.48373 .69938 L
s
.46655 .70736 m
.47253 .708 L
s
.46841 .71359 m
.47253 .708 L
s
.48373 .69938 m
.48946 .70008 L
s
.52897 1.0945 m .52652 1.08814 L .52538 1.08549 L 0 0 .084 r
F
0 g
.52538 1.08549 m
.52538 1.08549 L
s
.40086 .91469 m .39164 .9104 L .39619 .91284 L 0 .42 .256 r
F
0 g
.39619 .91284 m
.39869 .91479 L
s
.4653 .70911 m
.46655 .70736 L
s
.46258 .71292 m
.4653 .70911 L
s
.53209 1.10222 m .53672 1.11001 L .53533 1.10846 L 0 .354 0 r
F
.53929 1.12008 m .53672 1.11001 L .54024 1.11674 L 0 .449 0 r
F
.53929 1.12008 m .53533 1.10846 L .53672 1.11001 L F
0 g
.53519 1.10601 m
.53672 1.11001 L
s
.39063 .71517 m .39067 .70027 L .38377 .70397 L 0 1 .464 r
F
.39063 .71517 m .39772 .70049 L .39067 .70027 L F
.39063 .71517 m .40023 .70448 L .39772 .70049 L F
.39063 .71517 m .39718 .71077 L .40023 .70448 L F
0 g
.38786 .72173 m
.39063 .71517 L
s
.38358 .71495 m
.39063 .71517 L
s
.52194 1.07041 m .52336 1.08007 L .52412 1.08196 L 0 0 .127 r
F
0 g
.52094 1.07424 m
.52187 1.07502 L
s
.52194 1.07041 m .52221 1.0753 L .52336 1.08007 L 0 0 .127 r
F
0 g
.52336 1.08067 m
.52336 1.08007 L
s
.72678 .88513 m .73528 .88035 L .7297 .88251 L 0 1 .311 r
F
.72678 .88513 m .7408 .88007 L .73528 .88035 L F
0 g
.36158 .53268 m
.37149 .52761 L
s
.52425 .94424 m .52726 .93609 L .52516 .93974 L 0 .316 .308 r
F
.52425 .94424 m .52982 .93646 L .52726 .93609 L F
.52425 .94424 m .53115 .94063 L .52982 .93646 L F
.52425 .94424 m .53023 .94513 L .53115 .94063 L F
0 g
.5229 .94083 m
.52516 .93974 L
s
.52425 .94424 m .52769 .94696 L .53023 .94513 L 0 .316 .308 r
F
.52425 .94424 m .52513 .94658 L .52769 .94696 L F
0 g
.52389 .94856 m
.52513 .94658 L
s
.52322 .94401 m
.52425 .94424 L
s
.52425 .94424 m
.52516 .93974 L
s
.40086 .91469 m .38962 .90821 L .39164 .9104 L 0 .42 .256 r
F
0 g
.38724 .90901 m
.39164 .9104 L
s
.21666 .86003 m .20514 .85729 L .20654 .86187 L 0 1 .524 r
F
0 g
.20199 .86515 m
.20654 .86187 L
s
.68943 1.13103 m .69558 1.11403 L .69921 1.11818 L 0 .134 .076 r
F
0 g
.69003 1.11388 m
.69558 1.11403 L
s
.69558 1.11403 m
.69572 1.1082 L
s
.65674 .81531 m
.65809 .8215 L
s
.6565 .81418 m
.65674 .81531 L
s
.33165 .75963 m
.33607 .75383 L
s
.33607 .75383 m
.33634 .75347 L
s
.33634 .75347 m
.33661 .75311 L
s
.44108 .49787 m .42968 .49967 L .43108 .50015 L 0 .85 .239 r
F
0 g
.42346 .50426 m
.43108 .50015 L
s
.44108 .49787 m .43796 .49681 L .42968 .49967 L 0 .85 .239 r
F
.44108 .49787 m .4504 .49347 L .43796 .49681 L F
.44108 .49787 m .46041 .49119 L .4504 .49347 L F
.44108 .49787 m .4613 .49148 L .46041 .49119 L F
.44108 .49787 m .45301 .49435 L .4613 .49148 L F
0 g
.43318 .50072 m
.44108 .49787 L
s
.43108 .50015 m
.44108 .49787 L
s
.45301 .49435 m
.46262 .49175 L
s
.38377 .70397 m .37363 .6983 L .37647 .70312 L 0 1 .479 r
F
0 g
.37385 .71168 m
.37647 .70312 L
s
.49508 .96286 m
.4956 .9628 L
s
.49215 .96317 m
.49508 .96286 L
s
.80814 .98118 m .81582 .99263 L .81937 .98264 L 0 1 .436 r
F
.80814 .98118 m .81127 .99593 L .81582 .99263 L F
0 g
.81582 .99263 m
.81803 .99647 L
s
.5117 .96647 m
.5117 .96639 L
s
.42557 .72069 m
.43187 .72072 L
s
.5264 .92689 m .52821 .90981 L .52658 .91799 L 0 .482 .308 r
F
.5264 .92689 m .53081 .90742 L .52821 .90981 L F
0 g
.52799 .90073 m
.52821 .90981 L
s
.52428 .92174 m
.52658 .91799 L
s
.56142 .64067 m
.56266 .64078 L
s
.52134 .98375 m
.52134 .98376 L
s
.52134 .98375 m
.52134 .98376 L
s
.38962 .90821 m .38059 .90465 L .38495 .90688 L 0 .52 .347 r
F
0 g
.38495 .90688 m
.38724 .90901 L
s
.52035 .98796 m
.52035 .98798 L
s
.52035 .98796 m
.52035 .988 L
s
.51601 .96728 m
.51601 .96729 L
s
.50498 .96601 m
.5052 .96555 L
s
.50481 .96636 m
.50498 .96601 L
s
.62751 .61011 m .62461 .60619 L .62246 .60852 L 0 1 .473 r
F
.62751 .61011 m .6332 .60452 L .62461 .60619 L F
.62751 .61011 m .64249 .60462 L .6332 .60452 L F
.42485 .78983 m .41756 .78782 L .41606 .78659 L 0 0 0 r
F
0 g
.41035 .78443 m
.41606 .78659 L
s
.42485 .78983 m .4226 .79022 L .41756 .78782 L 0 0 0 r
F
.42485 .78983 m .42838 .79272 L .4226 .79022 L F
.42485 .78983 m .43103 .79366 L .42838 .79272 L F
.42485 .78983 m .42951 .79242 L .43103 .79366 L F
0 g
.42363 .78834 m
.42485 .78983 L
s
.41909 .78734 m
.42485 .78983 L
s
.21562 .79235 m .20872 .78243 L .20437 .78998 L 0 1 .538 r
F
0 g
.20437 .78998 m
.20453 .79628 L
s
.21562 .79235 m .2153 .77757 L .20872 .78243 L 0 1 .538 r
F
.21562 .79235 m .21971 .77868 L .2153 .77757 L F
.21562 .79235 m .21984 .78502 L .21971 .77868 L F
0 g
.20907 .79717 m
.21562 .79235 L
s
.21562 .79235 m
.21587 .79846 L
s
.56166 .64074 m
.56266 .64105 L
s
.56142 .64067 m
.56166 .64074 L
s
.38962 .90821 m .37882 .90226 L .38059 .90465 L 0 .52 .347 r
F
0 g
.37624 .90373 m
.38059 .90465 L
s
.5553 .88541 m
.55534 .88231 L
s
.55519 .8932 m
.55522 .89101 L
s
.30969 .71308 m .3003 .70478 L .29808 .71209 L 0 1 .486 r
F
0 g
.29088 .7132 m
.29808 .71209 L
s
.70658 .72753 m .70816 .7076 L .70435 .70586 L 0 .5 .307 r
F
0 g
.70435 .70586 m
.70498 .71195 L
s
.70226 .70064 m
.70435 .70586 L
s
.52171 .96837 m .52205 .96733 L .52507 .97472 L 0 .481 .15 r
F
0 g
.52205 .96733 m
.52237 .96813 L
s
.52141 .97073 m
.52392 .97869 L
s
.51955 .96102 m
.52205 .96733 L
s
.52109 .9857 m
.52109 .9857 L
s
.52109 .9857 m
.52159 .98826 L
s
.52109 .9857 m
.52109 .98571 L
s
.52076 .98709 m
.52076 .9871 L
s
.52076 .98709 m
.52077 .98712 L
s
.31736 .55797 m .30397 .56197 L .30715 .5633 L 0 1 .504 r
F
0 g
.30242 .57116 m
.30715 .5633 L
s
.51864 1.00052 m .51819 .99955 L .51927 1.0117 L 0 .224 .241 r
F
0 g
.51831 1.00093 m
.51831 1.00093 L
s
.51831 1.00093 m
.51831 1.00093 L
s
.51828 1.0006 m
.51831 1.00093 L
s
.51828 1.00059 m
.51828 1.0006 L
s
.51828 1.00059 m
.51828 1.00059 L
s
.51828 1.00053 m
.51828 1.00059 L
s
.51828 1.00052 m
.51828 1.00053 L
s
.51828 1.00052 m
.51828 1.00052 L
s
.51822 .99992 m
.51828 1.00052 L
s
.51822 .99992 m
.51822 .99992 L
s
.51822 .99991 m
.51822 .99992 L
s
.51819 .99955 m
.51822 .99991 L
s
.51859 .99996 m
.51862 1.00034 L
s
.51862 1.00034 m
.51863 1.00041 L
s
.51818 .9995 m
.51819 .99955 L
s
.51723 .98527 m
.51859 .99996 L
s
.51939 1.06354 m .52221 1.0753 L .52145 1.07083 L 0 0 .143 r
F
0 g
.52187 1.07502 m
.52221 1.0753 L
s
.52194 1.07041 m .52145 1.07083 L .52221 1.0753 L 0 0 .127 r
F
0 g
.52221 1.0753 m
.52336 1.08007 L
s
.28132 .7863 m .27528 .77823 L .27051 .78441 L 0 1 .533 r
F
.28132 .7863 m .28202 .7741 L .27528 .77823 L F
.28132 .7863 m .28621 .7748 L .28202 .7741 L F
.28132 .7863 m .28591 .78003 L .28621 .7748 L F
0 g
.28117 .79153 m
.28132 .7863 L
s
.27461 .7904 m
.28132 .7863 L
s
.76877 1.05063 m .77843 1.03958 L .77397 1.04388 L 0 1 .213 r
F
.75772 1.06234 m .76877 1.05063 L .76728 1.05079 L 0 .955 .188 r
F
0 g
.54674 1.00732 m
.54785 1.0085 L
s
.54652 1.00707 m
.54674 1.00732 L
s
.54624 1.00678 m
.54652 1.00707 L
s
.54615 1.00668 m
.54624 1.00678 L
s
.6332 .60452 m .65138 .60318 L .65397 .60115 L 0 1 .489 r
F
.6332 .60452 m .64249 .60462 L .65138 .60318 L F
0 g
.65138 .60318 m
.65591 .60518 L
s
.64249 .60462 m
.65138 .60318 L
s
.64249 .60462 m
.6475 .60621 L
s
.52475 .97606 m .53281 1.00102 L .52815 .98565 L 0 .235 .228 r
F
.52475 .97606 m .53651 1.01719 L .53281 1.00102 L F
.52475 .97606 m .53676 1.0233 L .53651 1.01719 L F
.52475 .97606 m .53334 1.01358 L .53676 1.0233 L F
0 g
.53656 .99011 m
.53842 .99379 L
s
.53488 .98639 m
.53571 .98795 L
s
.53629 .98926 m
.53684 .99031 L
s
.53562 .98795 m
.53629 .98926 L
s
.53489 .98651 m
.53562 .98795 L
s
.53491 .98684 m
.53651 .98982 L
s
.53651 .98982 m
.53665 .99009 L
s
.52475 .97606 m .52854 .99461 L .53334 1.01358 L 0 .235 .228 r
F
.52475 .97606 m .52487 .97857 L .52854 .99461 L F
0 g
.52474 .97602 m
.52475 .97606 L
s
.52491 .97649 m
.52499 .97672 L
s
.5249 .97649 m
.52491 .97649 L
s
.5249 .97649 m
.5249 .97649 L
s
.52484 .9763 m
.5249 .97649 L
s
.52475 .97606 m
.52484 .9763 L
s
.52475 .97606 m
.52475 .97606 L
s
.31736 .55797 m .30968 .55474 L .30397 .56197 L 0 1 .504 r
F
.31736 .55797 m .32051 .54643 L .30968 .55474 L F
.31736 .55797 m .33075 .54108 L .32051 .54643 L F
.31736 .55797 m .33354 .54227 L .33075 .54108 L F
.31736 .55797 m .3278 .54951 L .33354 .54227 L F
0 g
.31193 .56527 m
.31736 .55797 L
s
.30715 .5633 m
.31736 .55797 L
s
.64593 .73073 m
.65265 .74102 L
s
.38377 .70397 m .3769 .69265 L .37363 .6983 L 0 1 .479 r
F
0 g
.3666 .69529 m
.37363 .6983 L
s
.37882 .90226 m .36966 .89927 L .37403 .90138 L 0 .705 .413 r
F
0 g
.37403 .90138 m
.37624 .90373 L
s
.5062 .68234 m .50011 .67797 L .50043 .68177 L 0 1 .481 r
F
.5062 .68234 m .50575 .67293 L .50011 .67797 L F
.5062 .68234 m .51359 .67001 L .50575 .67293 L F
.5062 .68234 m .51935 .67059 L .51359 .67001 L F
0 g
.50091 .68762 m
.5062 .68234 L
s
.7408 .88007 m .74742 .87563 L .74288 .87741 L 0 1 .358 r
F
.7408 .88007 m .75222 .87595 L .74742 .87563 L F
0 g
.51644 1.01538 m
.51685 1.02097 L
s
.51685 1.02097 m
.51698 1.02264 L
s
.68068 .79994 m .69601 .85341 L .69042 .8059 L 0 .494 .261 r
F
0 g
.68021 .78512 m
.68068 .79994 L
s
.67837 .78493 m
.68068 .79994 L
s
.26265 .87079 m .25362 .86402 L .25116 .86811 L 0 1 .518 r
F
.26265 .87079 m .25888 .86186 L .25362 .86402 L F
.26265 .87079 m .26341 .86308 L .25888 .86186 L F
.26265 .87079 m .26502 .86691 L .26341 .86308 L F
0 g
.25741 .87293 m
.26265 .87079 L
s
.26265 .87079 m
.26434 .87445 L
s
.20514 .85729 m .19496 .85934 L .19959 .86035 L 0 1 .525 r
F
0 g
.19959 .86035 m
.20199 .86515 L
s
.46827 .95296 m .4579 .94956 L .45703 .94775 L 0 .305 .041 r
F
.46827 .95296 m .46183 .95253 L .4579 .94956 L F
.46827 .95296 m .46621 .95467 L .46183 .95253 L F
.46827 .95296 m .46897 .95485 L .46621 .95467 L F
0 g
.46827 .95296 m
.47116 .95268 L
s
.46434 .95 m
.46827 .95296 L
s
.51517 .96764 m
.51517 .96764 L
s
.41592 .64599 m .40472 .64699 L .40757 .64791 L 0 1 .439 r
F
0 g
.40383 .65201 m
.40757 .64791 L
s
.41592 .64599 m .40923 .64354 L .40472 .64699 L 0 1 .439 r
F
.41592 .64599 m .4181 .63985 L .40923 .64354 L F
.41592 .64599 m .42647 .63793 L .4181 .63985 L F
.41592 .64599 m .42875 .63905 L .42647 .63793 L F
.41592 .64599 m .42423 .64251 L .42875 .63905 L F
0 g
.40757 .64791 m
.41592 .64599 L
s
.65134 .7992 m
.65143 .79505 L
s
.65116 .80712 m
.65125 .80334 L
s
.65116 .80721 m
.65116 .80712 L
s
.65131 .80066 m
.65134 .7992 L
s
.65066 .80096 m
.65143 .79505 L
s
.64865 .81651 m
.64991 .80681 L
s
.6485 .81767 m
.64865 .81651 L
s
.6504 .80301 m
.65066 .80096 L
s
.64815 .82034 m
.6485 .81767 L
s
.64645 .83348 m
.64651 .83302 L
s
.64651 .83302 m
.64708 .82864 L
s
.37882 .90226 m .368 .89663 L .36966 .89927 L 0 .705 .413 r
F
0 g
.36523 .89877 m
.36966 .89927 L
s
.51344 .96751 m
.51344 .96751 L
s
.51432 .96771 m
.51432 .96771 L
s
.77287 1.03526 m .77843 1.03958 L .78278 1.03093 L 0 1 .332 r
F
.77287 1.03526 m .77397 1.04388 L .77843 1.03958 L F
0 g
.77843 1.03958 m
.77984 1.04039 L
s
.31901 .72316 m .31622 .70667 L .30969 .71308 L 0 1 .456 r
F
.31901 .72316 m .32378 .70516 L .31622 .70667 L F
.31901 .72316 m .3273 .70957 L .32378 .70516 L F
.31901 .72316 m .32525 .71729 L .3273 .70957 L F
.32815 .73898 m .32525 .71729 L .31901 .72316 L 0 .266 .289 r
F
0 g
.31148 .72466 m
.31901 .72316 L
s
.31719 .73085 m
.31901 .72316 L
s
.53684 .99048 m
.53804 .99293 L
s
.53681 .99041 m
.53684 .99048 L
s
.53665 .99009 m
.53681 .99041 L
s
.34826 .7623 m .34472 .76332 L .33945 .75641 L 0 .086 0 r
F
0 g
.33945 .7564 m
.33945 .75641 L
s
.34826 .7623 m .35062 .7679 L .34472 .76332 L 0 .086 0 r
F
.35062 .7679 m .34962 .76786 L .34946 .76771 L F
.35034 .76768 m .34946 .76771 L .34472 .76332 L F
.35062 .7679 m .34946 .76771 L .35034 .76768 L F
.33945 .7564 m .34556 .76004 L .34139 .74873 L 0 .025 .162 r
F
.33945 .7564 m .34472 .76332 L .34556 .76004 L F
.34736 .76776 m .33954 .74791 L .34139 .74902 L 0 .709 .063 r
F
.34991 .77576 m .34693 .76777 L .34736 .76776 L F
.34693 .76777 m .33954 .74791 L .34736 .76776 L F
.34768 .76777 m .34139 .74902 L .34556 .76017 L F
.34991 .77576 m .34736 .76776 L .34768 .76777 L F
.34736 .76776 m .34139 .74902 L .34768 .76777 L F
.35062 .7679 m .35123 .76935 L .34962 .76786 L 0 .086 0 r
F
.34826 .7623 m .35461 .77044 L .35123 .76935 L F
.34826 .7623 m .35333 .76741 L .35461 .77044 L F
0 g
.34741 .76053 m
.34826 .7623 L
s
.34543 .75969 m
.34826 .7623 L
s
.27051 .78441 m .25927 .78754 L .26366 .78839 L 0 1 .537 r
F
0 g
.26366 .78839 m
.26417 .79408 L
s
.48004 .95845 m
.48372 .96001 L
s
.54658 .65042 m .54159 .64676 L .54096 .64995 L 0 1 .495 r
F
.54658 .65042 m .54849 .64262 L .54159 .64676 L F
.54658 .65042 m .55706 .6403 L .54849 .64262 L F
.20514 .85729 m .19362 .85454 L .19496 .85934 L 0 1 .525 r
F
0 g
.19038 .86284 m
.19496 .85934 L
s
.66269 .60036 m .66046 .59603 L .65786 .59808 L 0 1 .481 r
F
.66269 .60036 m .6695 .59547 L .66046 .59603 L F
.66269 .60036 m .67891 .59677 L .6695 .59547 L F
0 g
.67891 .59677 m
.67995 .59673 L
s
.67891 .59677 m
.67986 .59722 L
s
.52194 1.07041 m .52412 1.08196 L .52401 1.07987 L 0 0 .127 r
F
0 g
.52412 1.08196 m
.52538 1.08548 L
s
.68004 .59673 m
.68298 .60064 L
s
.43176 .64038 m
.43697 .63802 L
s
.42423 .64251 m
.43176 .64038 L
s
.39793 .78048 m .39005 .7787 L .38859 .77771 L 0 0 0 r
F
.39793 .78048 m .39526 .78074 L .39005 .7787 L F
.39793 .78048 m .40138 .78282 L .39526 .78074 L F
.39793 .78048 m .40431 .78356 L .40138 .78282 L F
.39793 .78048 m .40282 .78255 L .40431 .78356 L F
0 g
.39713 .77981 m
.39793 .78048 L
s
.39184 .77841 m
.39793 .78048 L
s
.51628 1.02333 m .51636 1.04285 L .51784 1.04712 L 0 .137 .21 r
F
0 g
.51546 1.04407 m
.51636 1.04285 L
s
.51505 1.0332 m
.51636 1.04285 L
s
.75222 .87595 m .75879 .8712 L .75424 .87297 L 0 1 .396 r
F
.75222 .87595 m .76364 .87186 L .75879 .8712 L F
.53538 .92078 m .53769 .89642 L .53561 .90769 L 0 .555 .291 r
F
.53538 .92078 m .5409 .89353 L .53769 .89642 L F
.53081 .90742 m .53561 .90769 L .53769 .89642 L 0 .605 .298 r
F
0 g
.5375 .88396 m
.53769 .89642 L
s
.368 .89663 m .35905 .89438 L .36324 .89627 L 0 .869 .458 r
F
0 g
.36324 .89627 m
.36523 .89877 L
s
.53929 1.12008 m .54024 1.11674 L .54357 1.1242 L 0 .449 0 r
F
0 g
.53672 1.11001 m
.54024 1.11674 L
s
.53879 1.11144 m
.54024 1.11674 L
s
.48314 .63099 m .47522 .6303 L .47603 .63097 L 0 .772 .253 r
F
.48314 .63099 m .48148 .62941 L .47522 .6303 L F
0 g
.47026 .63264 m
.47603 .63097 L
s
.48314 .63099 m .49064 .62888 L .48148 .62941 L 0 .772 .253 r
F
.48314 .63099 m .49776 .6289 L .49064 .62888 L F
.48314 .63099 m .49809 .62945 L .49776 .6289 L F
.48314 .63099 m .49182 .63035 L .49809 .62945 L F
0 g
.47724 .63181 m
.48314 .63099 L
s
.47603 .63097 m
.48314 .63099 L
s
.49182 .63035 m
.49858 .63011 L
s
.51864 1.00052 m .52308 1.03414 L .52073 1.01532 L 0 .224 .241 r
F
.51864 1.00052 m .52416 1.04636 L .52308 1.03414 L F
.51864 1.00052 m .52326 1.04378 L .52416 1.04636 L F
.51864 1.00052 m .52115 1.02891 L .52326 1.04378 L F
.51864 1.00052 m .51927 1.0117 L .52115 1.02891 L F
0 g
.51883 1.00186 m
.51883 1.00187 L
s
.51883 1.00186 m
.51883 1.00186 L
s
.51877 1.00145 m
.51883 1.00186 L
s
.51877 1.00145 m
.51877 1.00145 L
s
.51877 1.00145 m
.51877 1.00145 L
s
.51876 1.00139 m
.51877 1.00145 L
s
.51876 1.00139 m
.51876 1.00139 L
s
.51876 1.00139 m
.51876 1.00139 L
s
.51867 1.00075 m
.51876 1.00139 L
s
.51867 1.00075 m
.51867 1.00075 L
s
.51867 1.00074 m
.51867 1.00075 L
s
.51864 1.00052 m
.51867 1.00074 L
s
.51919 1.00095 m
.51925 1.00145 L
s
.51929 1.00175 m
.51929 1.0018 L
s
.51925 1.00145 m
.51929 1.00175 L
s
.5178 1.00031 m
.51869 1.00723 L
s
.51869 1.00723 m
.51927 1.0117 L
s
.51723 .98528 m
.51919 1.00095 L
s
.51832 .98984 m
.51961 1.00158 L
s
.51863 1.00041 m
.51864 1.00052 L
s
.51901 1.00876 m
.51927 1.0117 L
s
.51831 1.00093 m
.51901 1.00876 L
s
.53485 .98591 m
.53524 .98669 L
s
.52502 .98216 m .53334 1.01358 L .52854 .99461 L 0 .225 .224 r
F
.52502 .98216 m .53706 1.03182 L .53334 1.01358 L F
.52502 .98216 m .53721 1.03706 L .53706 1.03182 L F
.52502 .98216 m .53364 1.02444 L .53721 1.03706 L F
.52502 .98216 m .52877 1.00251 L .53364 1.02444 L F
.52502 .98216 m .52508 .98445 L .52877 1.00251 L F
.52171 .96837 m .52732 .99104 L .52396 .97851 L 0 .481 .15 r
F
.52171 .96837 m .53037 .99851 L .52732 .99104 L F
.52171 .96837 m .53105 .99589 L .53037 .99851 L F
.52171 .96837 m .52877 .98567 L .53105 .99589 L F
0 g
.52109 .98571 m
.52171 .98841 L
s
.52171 .96837 m .52507 .97472 L .52877 .98567 L 0 .481 .15 r
F
0 g
.52171 .96837 m
.52201 .96971 L
s
.52463 .9832 m
.52476 .98355 L
s
.52476 .98355 m
.52494 .98405 L
s
.51896 .96284 m
.52171 .96837 L
s
.52495 .96731 m
.52604 .97031 L
s
.52134 .98376 m
.5227 .98916 L
s
.52134 .98376 m
.52246 .98908 L
s
.52392 .97869 m
.52452 .9806 L
s
.31469 .67053 m .30659 .67031 L .31024 .67092 L 0 1 .5 r
F
.31469 .67053 m .30565 .66876 L .30659 .67031 L F
.31469 .67053 m .30805 .66732 L .30565 .66876 L F
.31469 .67053 m .3125 .66693 L .30805 .66732 L F
.31469 .67053 m .31604 .66785 L .3125 .66693 L F
.31469 .67053 m .31697 .66939 L .31604 .66785 L F
0 g
.31469 .67053 m
.31571 .67145 L
s
.31024 .67092 m
.31469 .67053 L
s
.38502 .77667 m
.38858 .77771 L
s
.50578 .96674 m .50006 .97441 L .50316 .96969 L 0 .428 .105 r
F
0 g
.50295 .96581 m
.50364 .96496 L
s
.50578 .96674 m .49832 .97929 L .50006 .97441 L 0 .428 .105 r
F
.50578 .96674 m .49912 .98105 L .49832 .97929 L F
.50578 .96674 m .50175 .97807 L .49912 .98105 L F
.50578 .96674 m .50445 .97236 L .50175 .97807 L F
0 g
.50198 .96698 m
.50295 .96581 L
s
.50197 .96699 m
.50198 .96698 L
s
.50197 .96699 m
.5029 .96626 L
s
.50578 .96674 m .50617 .96752 L .50445 .97236 L 0 .428 .105 r
F
0 g
.50578 .96674 m
.50779 .96075 L
s
.50542 .96715 m
.50578 .96674 L
s
.50617 .96752 m
.50848 .96211 L
s
.74667 1.07578 m .75537 1.06625 L .75772 1.06234 L 0 .867 .15 r
F
0 g
.75537 1.06625 m
.75688 1.06606 L
s
.7508 1.07213 m
.75537 1.06625 L
s
.53081 .90742 m .53267 .91241 L .53561 .90769 L 0 .605 .298 r
F
.5264 .92689 m .53267 .91241 L .53081 .90742 L 0 .482 .308 r
F
0 g
.53064 .89553 m
.53081 .90742 L
s
.52821 .90981 m
.53081 .90742 L
s
.368 .89663 m .35764 .89158 L .35905 .89438 L 0 .869 .458 r
F
0 g
.35468 .89433 m
.35905 .89438 L
s
.52531 .66568 m .51973 .66168 L .51958 .66519 L 0 1 .491 r
F
.52531 .66568 m .52605 .65703 L .51973 .66168 L F
.52531 .66568 m .53431 .65435 L .52605 .65703 L F
.52531 .66568 m .54003 .65485 L .53431 .65435 L F
0 g
.54003 .65485 m
.54658 .65042 L
s
.51935 .67059 m
.52531 .66568 L
s
.47108 .49026 m .46041 .49119 L .4613 .49148 L 0 .699 .209 r
F
0 g
.45301 .49435 m
.4613 .49148 L
s
.47108 .49026 m .46926 .48969 L .46041 .49119 L 0 .699 .209 r
F
.47108 .49026 m .48195 .48798 L .46926 .48969 L F
.47108 .49026 m .49174 .48676 L .48195 .48798 L F
.47108 .49026 m .49211 .48683 L .49174 .48676 L F
.47108 .49026 m .48325 .48834 L .49211 .48683 L F
0 g
.46262 .49175 m
.47108 .49026 L
s
.4613 .49148 m
.47108 .49026 L
s
.48325 .48834 m
.49265 .48675 L
s
.24459 .69565 m .24132 .6843 L .23438 .69086 L 0 1 .534 r
F
0 g
.23231 .69714 m
.23438 .69086 L
s
.24459 .69565 m .24949 .68093 L .24132 .6843 L 0 1 .534 r
F
.24459 .69565 m .25341 .68303 L .24949 .68093 L F
.24459 .69565 m .2513 .68934 L .25341 .68303 L F
0 g
.23646 .69898 m
.24459 .69565 L
s
.24269 .70181 m
.24459 .69565 L
s
.51784 1.04712 m .51939 1.06354 L .52029 1.06233 L 0 .038 .163 r
F
0 g
.51939 1.06354 m
.52145 1.07083 L
s
.51628 1.02333 m .51837 1.04289 L .51759 1.03297 L 0 .137 .21 r
F
.51628 1.02333 m .51784 1.04712 L .51837 1.04289 L F
0 g
.51721 1.02579 m
.51724 1.02615 L
s
.51721 1.02569 m
.51721 1.02579 L
s
.51698 1.02264 m
.51721 1.02569 L
s
.51628 1.02333 m
.51644 1.01538 L
s
.51628 1.02333 m
.5163 1.02347 L
s
.5163 1.02347 m
.5163 1.02352 L
s
.5163 1.02352 m
.51632 1.02363 L
s
.51632 1.02363 m
.51632 1.02365 L
s
.51632 1.02365 m
.51634 1.02379 L
s
.51634 1.02379 m
.51641 1.02429 L
s
.51641 1.02429 m
.51657 1.02544 L
s
.51657 1.02544 m
.51675 1.02678 L
s
.31414 .77262 m .30297 .77703 L .30716 .77749 L 0 1 .469 r
F
0 g
.30716 .77749 m
.31414 .77262 L
s
.31413 .77836 m
.31414 .77263 L
s
.31414 .77263 m
.31414 .77262 L
s
.30711 .78289 m
.30716 .77749 L
s
.76364 .87186 m .77016 .86681 L .76561 .86856 L 0 1 .429 r
F
.76364 .87186 m .77507 .86781 L .77016 .86681 L F
.45703 .94775 m .44683 .94323 L .4458 .94163 L 0 .242 .003 r
F
.45703 .94775 m .45089 .94639 L .44683 .94323 L F
.45703 .94775 m .45526 .94898 L .45089 .94639 L F
.45703 .94775 m .4579 .94956 L .45526 .94898 L F
0 g
.45298 .9446 m
.45703 .94775 L
s
.45703 .94775 m
.4598 .94793 L
s
.69042 .8059 m .7001 .80842 L .69297 .77502 L 0 .536 .27 r
F
0 g
.69297 .77502 m
.6945 .78221 L
s
.6945 .78221 m
.6952 .78549 L
s
.68952 .78246 m
.69042 .8059 L
s
.68695 .78695 m
.69042 .8059 L
s
.69111 .74906 m
.69297 .77502 L
s
.51708 1.01728 m
.51708 1.01729 L
s
.51708 1.01729 m
.51708 1.01729 L
s
.51708 1.01728 m
.51716 1.01798 L
s
.3837 .77674 m
.38502 .77667 L
s
.5409 .89353 m .54311 .90095 L .54663 .89376 L 0 .698 .282 r
F
.53538 .92078 m .54311 .90095 L .5409 .89353 L 0 .555 .291 r
F
0 g
.54082 .88215 m
.5409 .89353 L
s
.53769 .89642 m
.5409 .89353 L
s
.3003 .70478 m .28845 .70459 L .29231 .70746 L 0 1 .503 r
F
0 g
.29088 .7132 m
.29231 .70746 L
s
.41335 .71465 m .40398 .71051 L .40647 .71456 L 0 1 .471 r
F
0 g
.40639 .71475 m
.40647 .71456 L
s
.5264 .92689 m .53249 .92132 L .53267 .91241 L 0 .482 .308 r
F
.5264 .92689 m .5304 .92819 L .53249 .92132 L F
.5264 .92689 m .52779 .93057 L .5304 .92819 L F
0 g
.52451 .9278 m
.5264 .92689 L
s
.5264 .92689 m
.52658 .91799 L
s
.52725 .95852 m
.52817 .95859 L
s
.57279 .63007 m .58962 .62445 L .59166 .62116 L 0 1 .497 r
F
.57279 .63007 m .58154 .62827 L .58962 .62445 L F
0 g
.58962 .62445 m
.59438 .62582 L
s
.58154 .62827 m
.58693 .62884 L
s
.58154 .62827 m
.58962 .62445 L
s
.3769 .69265 m .36491 .68514 L .36867 .69059 L 0 1 .499 r
F
0 g
.3666 .69523 m
.36867 .69059 L
s
.38377 .70397 m .38414 .68994 L .3769 .69265 L 0 1 .479 r
F
0 g
.37363 .6983 m
.3769 .69265 L
s
.38377 .70397 m .39146 .69078 L .38414 .68994 L 0 1 .479 r
F
.38377 .70397 m .39397 .69462 L .39146 .69078 L F
.38377 .70397 m .39067 .70027 L .39397 .69462 L F
0 g
.38074 .71026 m
.38377 .70397 L
s
.37647 .70312 m
.38377 .70397 L
s
.43529 .71497 m .42662 .71074 L .42872 .71471 L 0 1 .47 r
F
.43529 .71497 m .43035 .7051 L .42662 .71074 L F
0 g
.42557 .72069 m
.42872 .71471 L
s
.43529 .71497 m .43743 .70155 L .43035 .7051 L 0 1 .47 r
F
.43529 .71497 m .44401 .70181 L .43743 .70155 L F
.43529 .71497 m .4457 .70572 L .44401 .70181 L F
.43529 .71497 m .44196 .71136 L .4457 .70572 L F
0 g
.43187 .72072 m
.43529 .71497 L
s
.42872 .71471 m
.43529 .71497 L
s
.59991 .61791 m .61926 .61202 L .61383 .61081 L 0 1 .487 r
F
0 g
.61926 .61202 m
.62751 .61011 L
s
.25116 .86811 m .24221 .86111 L .23967 .86543 L 0 1 .519 r
F
.25116 .86811 m .24753 .85878 L .24221 .86111 L F
.25116 .86811 m .25207 .86002 L .24753 .85878 L F
.25116 .86811 m .25362 .86402 L .25207 .86002 L F
0 g
.24586 .87041 m
.25116 .86811 L
s
.25116 .86811 m
.25279 .87192 L
s
.35764 .89158 m .34857 .8899 L .35276 .89165 L 0 1 .486 r
F
0 g
.35276 .89165 m
.35468 .89433 L
s
.80814 .98118 m .80798 .99104 L .81127 .99593 L 0 1 .436 r
F
0 g
.80672 1.00448 m
.81127 .99593 L
s
.53705 .99076 m
.53706 .99079 L
s
.53684 .99031 m
.53705 .99076 L
s
.52641 .95016 m .53023 .94513 L .52769 .94696 L 0 .278 .293 r
F
.52641 .95016 m .53307 .94717 L .53023 .94513 L F
0 g
.52513 .94658 m
.52769 .94696 L
s
.52641 .95016 m .53432 .95173 L .53307 .94717 L 0 .278 .293 r
F
.52641 .95016 m .53303 .95493 L .53432 .95173 L F
0 g
.53334 .95415 m
.53595 .9592 L
s
.52641 .95016 m .53007 .95463 L .53303 .95493 L 0 .278 .293 r
F
0 g
.52835 .95617 m
.52838 .95619 L
s
.52641 .95016 m .52723 .95258 L .53007 .95463 L 0 .278 .293 r
F
0 g
.52389 .94856 m
.52641 .95016 L
s
.52641 .95016 m
.52769 .94696 L
s
.52564 .95353 m
.52723 .95258 L
s
.52564 .95353 m
.52835 .95617 L
s
.41335 .71465 m .4074 .70467 L .40398 .71051 L 0 1 .471 r
F
.41335 .71465 m .41446 .70094 L .4074 .70467 L F
.41335 .71465 m .42135 .70103 L .41446 .70094 L F
.41335 .71465 m .42346 .70488 L .42135 .70103 L F
.41335 .71465 m .42003 .71072 L .42346 .70488 L F
0 g
.41022 .72064 m
.41335 .71465 L
s
.40647 .71456 m
.41335 .71465 L
s
.33321 .66906 m .32467 .66639 L .32135 .669 L 0 1 .502 r
F
.33321 .66906 m .33266 .66351 L .32467 .66639 L F
.33321 .66906 m .34104 .66295 L .33266 .66351 L F
.33321 .66906 m .34418 .66507 L .34104 .66295 L F
.33321 .66906 m .34082 .66769 L .34418 .66507 L F
0 g
.33018 .67022 m
.33321 .66906 L
s
.32488 .66962 m
.33321 .66906 L
s
.30969 .71308 m .30712 .69832 L .3003 .70478 L 0 1 .486 r
F
.30969 .71308 m .31491 .69599 L .30712 .69832 L F
.30969 .71308 m .31847 .69934 L .31491 .69599 L F
.30969 .71308 m .31622 .70667 L .31847 .69934 L F
0 g
.30192 .71539 m
.30969 .71308 L
s
.30766 .72078 m
.30969 .71308 L
s
.38422 .65918 m
.38794 .65508 L
s
.39718 .71077 m
.39993 .7051 L
s
.39718 .71077 m
.40398 .71051 L
s
.70518 .69014 m
.71198 .70539 L
s
.4458 .94163 m .43576 .93632 L .43456 .93502 L 0 .142 0 r
F
.4458 .94163 m .43994 .93943 L .43576 .93632 L F
.4458 .94163 m .44432 .94229 L .43994 .93943 L F
.4458 .94163 m .44683 .94323 L .44432 .94229 L F
0 g
.44162 .93852 m
.4458 .94163 L
s
.4458 .94163 m
.44843 .94222 L
s
.71592 .58656 m .73535 .59046 L .73877 .58895 L 0 1 .51 r
F
.71592 .58656 m .72558 .58943 L .73535 .59046 L F
0 g
.73535 .59046 m
.73925 .5942 L
s
.74667 1.07578 m .74442 1.07875 L .74601 1.07743 L 0 .867 .15 r
F
0 g
.74442 1.07875 m
.74601 1.07743 L
s
.74029 1.08188 m
.74459 1.07853 L
s
.77507 .86781 m .78154 .86248 L .77699 .8642 L 0 1 .456 r
F
.77507 .86781 m .78651 .86384 L .78154 .86248 L F
.50157 .48677 m .49174 .48676 L .49211 .48683 L 0 0 0 r
F
0 g
.48325 .48834 m
.49211 .48683 L
s
.50157 .48677 m .50107 .48677 L .49174 .48676 L 0 0 0 r
F
.50157 .48677 m .51386 .48686 L .50107 .48677 L F
0 g
.49211 .48683 m
.50137 .48677 L
s
.50157 .48677 m .52333 .48679 L .51386 .48686 L 0 0 0 r
F
0 g
.5229 .48613 m
.52585 .48667 L
s
.50157 .48677 m .52316 .48662 L .52333 .48679 L 0 0 0 r
F
.50157 .48677 m .51383 .48661 L .52316 .48662 L F
0 g
.49265 .48675 m
.50157 .48677 L
s
.51383 .48661 m
.5229 .48613 L
s
.51972 1.00261 m .5193 1.00183 L .52073 1.01532 L 0 .227 .24 r
F
0 g
.51937 1.0025 m
.51937 1.0025 L
s
.51937 1.00249 m
.51937 1.0025 L
s
.51933 1.00217 m
.51937 1.00249 L
s
.51933 1.00217 m
.51933 1.00217 L
s
.51933 1.00217 m
.51933 1.00217 L
s
.51933 1.00216 m
.51933 1.00217 L
s
.51933 1.00216 m
.51933 1.00216 L
s
.51933 1.00216 m
.51933 1.00216 L
s
.5193 1.00183 m
.51933 1.00216 L
s
.51961 1.00158 m
.51966 1.00209 L
s
.51966 1.00209 m
.5197 1.00244 L
s
.5197 1.00244 m
.51971 1.00255 L
s
.51797 .98664 m
.52016 1.00232 L
s
.51929 1.0018 m
.5193 1.00183 L
s
.53255 .86721 m .53253 .89102 L .5313 .87507 L 0 .811 .137 r
F
0 g
.52892 .86296 m
.5313 .87507 L
s
.53255 .86721 m .53601 .91143 L .53253 .89102 L 0 .811 .137 r
F
.53538 .92078 m .54289 .91404 L .54311 .90095 L 0 .555 .291 r
F
.53538 .92078 m .54037 .92406 L .54289 .91404 L F
.53255 .86721 m .53943 .92262 L .53601 .91143 L 0 .811 .137 r
F
.53255 .86721 m .54067 .91458 L .53943 .92262 L F
.53255 .86721 m .53891 .89282 L .54067 .91458 L F
.53255 .86721 m .53543 .8726 L .53891 .89282 L F
0 g
.53629 .85877 m
.53886 .87503 L
s
.53175 .86251 m
.53255 .86721 L
s
.5313 .87507 m
.53255 .86721 L
s
.53543 .8726 m
.53629 .85877 L
s
.68846 .5933 m
.69123 .59468 L
s
.35764 .89158 m .34726 .88689 L .34857 .8899 L 0 1 .486 r
F
0 g
.34413 .8902 m
.34857 .8899 L
s
.44196 .71136 m
.44822 .71169 L
s
.35676 .68676 m
.35863 .68031 L
s
.35863 .68031 m
.35864 .68029 L
s
.35864 .68029 m
.35914 .67855 L
s
.31697 .66939 m
.32135 .66901 L
s
.51383 .48661 m
.52144 .48662 L
s
.2942 .56772 m
.30397 .56197 L
s
.27051 .78441 m .25968 .78227 L .25927 .78754 L 0 1 .537 r
F
0 g
.25311 .79204 m
.25927 .78754 L
s
.52194 1.07041 m .52133 1.06873 L .52145 1.07083 L 0 0 .127 r
F
.48785 .68999 m .49518 .68691 L .50043 .68177 L 0 1 .479 r
F
0 g
.49518 .68691 m
.49858 .68358 L
s
.49518 .68691 m
.50091 .68762 L
s
.55144 .94184 m
.55154 .94059 L
s
.5322 .48784 m .52333 .48679 L .52316 .48662 L 0 0 0 r
F
0 g
.52316 .48662 m
.52404 .48674 L
s
.52144 .48662 m
.52316 .48662 L
s
.5322 .48784 m .53303 .48848 L .52333 .48679 L 0 0 0 r
F
.5322 .48784 m .54578 .49056 L .53303 .48848 L F
.5322 .48784 m .55482 .49178 L .54578 .49056 L F
0 g
.55305 .49041 m
.55543 .49131 L
s
.5322 .48784 m .55411 .49134 L .55482 .49178 L 0 0 0 r
F
.5322 .48784 m .54442 .48965 L .55411 .49134 L F
0 g
.54442 .48965 m
.55305 .49041 L
s
.52585 .48667 m
.5322 .48784 L
s
.52404 .48674 m
.5322 .48784 L
s
.43456 .93502 m .42469 .92913 L .42333 .92821 L 0 .003 0 r
F
.43456 .93502 m .429 .93205 L .42469 .92913 L F
.43456 .93502 m .43338 .93504 L .429 .93205 L F
.43456 .93502 m .43576 .93632 L .43338 .93504 L F
0 g
.43026 .9321 m
.43456 .93502 L
s
.43456 .93502 m
.43707 .93597 L
s
.52897 1.0945 m .53209 1.10222 L .53325 1.1049 L 0 0 .084 r
F
0 g
.54442 .48965 m
.5526 .49107 L
s
.64863 1.12444 m
.64864 1.12364 L
s
.34893 .67221 m
.34911 .67214 L
s
.34893 .67221 m
.34904 .67225 L
s
.35262 .67371 m
.35667 .67536 L
s
.52079 .97071 m .52117 .96982 L .52396 .97851 L 0 .499 .151 r
F
0 g
.52117 .96982 m
.52129 .9702 L
s
.52219 .97653 m
.52463 .9832 L
s
.52208 .97669 m
.52446 .98522 L
s
.52301 .96482 m
.52604 .97031 L
s
.51896 .96284 m
.52117 .96982 L
s
.56262 .49402 m .55482 .49178 L .55411 .49134 L 0 0 0 r
F
0 g
.55411 .49134 m
.55461 .49149 L
s
.5526 .49107 m
.55411 .49134 L
s
.56262 .49402 m .56478 .49533 L .55696 .49255 L 0 0 0 r
F
.56478 .49533 m .55659 .49235 L .55588 .49222 L 0 .378 .194 r
F
.53303 .48848 m .55588 .49222 L .55659 .49235 L 0 0 0 r
F
.53303 .48848 m .54578 .49056 L .55588 .49222 L F
.53303 .48848 m .55348 .49184 L .54715 .49072 L F
.55348 .49184 m .55659 .49235 L .55259 .49166 L F
.55348 .49184 m .55259 .49166 L .54715 .49072 L F
.55872 .4929 m .55696 .49255 L .55482 .49178 L F
.56262 .49402 m .55696 .49255 L .55872 .4929 L F
0 g
.55543 .49131 m
.55901 .49266 L
s
.55461 .49149 m
.55763 .49245 L
s
.56262 .49402 m .57735 .49962 L .56478 .49533 L 0 0 0 r
F
.56262 .49402 m .58586 .5023 L .57735 .49962 L F
0 g
.58278 .50023 m
.58451 .50125 L
s
.56262 .49402 m .58462 .50159 L .58586 .5023 L 0 0 0 r
F
.56262 .49402 m .57467 .49804 L .58462 .50159 L F
0 g
.57467 .49804 m
.58278 .50023 L
s
.55901 .49266 m
.56262 .49402 L
s
.55763 .49245 m
.56262 .49402 L
s
.74173 .65441 m
.74399 .65296 L
s
.36804 .6713 m .37684 .6574 L .36862 .66228 L 0 1 .479 r
F
.36804 .6713 m .3796 .65822 L .37684 .6574 L F
.36804 .6713 m .37582 .66419 L .3796 .65822 L F
0 g
.36298 .67431 m
.36804 .6713 L
s
.37583 .66419 m
.38422 .65918 L
s
.71699 1.1115 m .72398 1.09734 L .72707 1.09763 L 0 0 .016 r
F
0 g
.71872 1.10054 m
.72398 1.09734 L
s
.57467 .49804 m
.58338 .50115 L
s
.42333 .92821 m .41363 .92187 L .4121 .92139 L 0 .156 .166 r
F
.42333 .92821 m .41806 .92451 L .41363 .92187 L F
.42333 .92821 m .42244 .92754 L .41806 .92451 L F
.42333 .92821 m .42469 .92913 L .42244 .92754 L F
0 g
.42361 .92836 m
.42572 .92949 L
s
.83102 .96487 m .84248 .95788 L .83924 .95218 L 0 1 .46 r
F
.50489 .63015 m .49776 .6289 L .49809 .62945 L 0 .669 .238 r
F
.50489 .63015 m .50443 .62889 L .49776 .6289 L F
0 g
.49182 .63035 m
.49809 .62945 L
s
.50489 .63015 m .51367 .62943 L .50443 .62889 L 0 .669 .238 r
F
.50489 .63015 m .52048 .63013 L .51367 .62943 L F
.50489 .63015 m .52032 .63051 L .52048 .63013 L F
.50489 .63015 m .51364 .63052 L .52032 .63051 L F
0 g
.49858 .63011 m
.50489 .63015 L
s
.49809 .62945 m
.50489 .63015 L
s
.51364 .63052 m
.52009 .63088 L
s
.53571 .98795 m
.53647 .98938 L
s
.54311 .90095 m
.54663 .89376 L
s
.54655 1.00807 m
.54674 1.00839 L
s
.54406 1.00391 m
.54655 1.00807 L
s
.544 1.00381 m
.54406 1.00391 L
s
.54376 1.0034 m
.544 1.00381 L
s
.54417 1.00422 m
.54595 1.00775 L
s
.54412 1.00413 m
.54417 1.00422 L
s
.54694 1.00972 m
.54726 1.01036 L
s
.54726 1.01036 m
.54751 1.01085 L
s
.54595 1.00775 m
.54694 1.00972 L
s
.54376 1.0034 m
.54412 1.00413 L
s
.4121 .92139 m .40255 .91471 L .40086 .91469 L 0 .304 .211 r
F
.4121 .92139 m .40711 .91697 L .40255 .91471 L F
.4121 .92139 m .41149 .91998 L .40711 .91697 L F
.4121 .92139 m .41363 .92187 L .41149 .91998 L F
0 g
.40755 .91913 m
.4121 .92139 L
s
.4121 .92139 m
.41436 .92298 L
s
.3003 .70478 m .29086 .69761 L .28845 .70459 L 0 1 .503 r
F
0 g
.28104 .70643 m
.28845 .70459 L
s
.65313 .79877 m
.65335 .79789 L
s
.65527 .79042 m
.65583 .78823 L
s
.65703 .78353 m
.65806 .77949 L
s
.65583 .78823 m
.65703 .78353 L
s
.65833 .77847 m
.65873 .77688 L
s
.65806 .77949 m
.65833 .77847 L
s
.65873 .77688 m
.65882 .77654 L
s
.78651 .86384 m .79293 .85822 L .78837 .85991 L 0 1 .476 r
F
.78651 .86384 m .79795 .85994 L .79293 .85822 L F
0 g
.52723 .95258 m
.52735 .95267 L
s
.52726 .93609 m
.52813 .93621 L
s
.52726 .93609 m
.52779 .93057 L
s
.32815 .73898 m .33243 .72101 L .32525 .71729 L 0 .266 .289 r
F
.32815 .73898 m .33577 .73189 L .33243 .72101 L F
.32815 .73898 m .33392 .7396 L .33577 .73189 L F
0 g
.32099 .73524 m
.32815 .73898 L
s
.77757 .81654 m .78326 .82038 L .7788 .82155 L 0 .056 .033 r
F
.77757 .81654 m .78881 .8146 L .78326 .82038 L F
.34726 .88689 m .33807 .88574 L .34227 .88736 L 0 1 .505 r
F
0 g
.34227 .88736 m
.34546 .88706 L
s
.34227 .88736 m
.34413 .8902 L
s
.59251 .50595 m .58586 .5023 L .58462 .50159 L 0 .234 .176 r
F
0 g
.58462 .50159 m
.5848 .50169 L
s
.58338 .50115 m
.58462 .50159 L
s
.56478 .49533 m .58629 .50256 L .58005 .50035 L 0 .378 .194 r
F
.58629 .50256 m .58895 .50346 L .58608 .50246 L F
.58629 .50256 m .58608 .50246 L .58005 .50035 L F
.59251 .50595 m .59598 .50789 L .58734 .50312 L 0 .234 .176 r
F
.58762 .50327 m .58734 .50312 L .58586 .5023 L F
.59251 .50595 m .58734 .50312 L .58762 .50327 L F
0 g
.58899 .50388 m
.59251 .50595 L
s
.58451 .50125 m
.58728 .50287 L
s
.58737 .50293 m
.58899 .50388 L
s
.58809 .50351 m
.59239 .50588 L
s
.5848 .50169 m
.58637 .50256 L
s
.58653 .50265 m
.58809 .50351 L
s
.59239 .50588 m
.59251 .50595 L
s
.68136 .89784 m
.68297 .89816 L
s
.51972 1.00261 m .5249 1.03887 L .52212 1.01845 L 0 .227 .24 r
F
.51972 1.00261 m .52634 1.05246 L .5249 1.03887 L F
.51972 1.00261 m .52549 1.05008 L .52634 1.05246 L F
.51972 1.00261 m .52308 1.03414 L .52549 1.05008 L F
.51972 1.00261 m .52073 1.01532 L .52308 1.03414 L F
0 g
.51982 1.00324 m
.51982 1.00324 L
s
.51982 1.00324 m
.51982 1.00324 L
s
.51976 1.00284 m
.51982 1.00324 L
s
.51976 1.00284 m
.51976 1.00284 L
s
.51976 1.00284 m
.51976 1.00284 L
s
.51975 1.00281 m
.51976 1.00284 L
s
.51975 1.00281 m
.51975 1.00281 L
s
.51975 1.0028 m
.51975 1.00281 L
s
.51972 1.00261 m
.51975 1.0028 L
s
.51883 1.00187 m
.52016 1.01131 L
s
.51866 .98761 m
.52056 1.00281 L
s
.52056 1.00281 m
.52063 1.00339 L
s
.51971 1.00255 m
.51972 1.00261 L
s
.52033 1.00354 m
.52033 1.00355 L
s
.52029 1.00329 m
.52033 1.00354 L
s
.52024 1.0029 m
.52029 1.00329 L
s
.52016 1.00232 m
.52024 1.0029 L
s
.31414 .77262 m .30384 .77226 L .30297 .77703 L 0 1 .469 r
F
0 g
.29652 .78153 m
.30297 .77703 L
s
.31414 .77262 m .3092 .76636 L .30384 .77226 L 0 1 .469 r
F
.31414 .77262 m .31621 .76147 L .3092 .76636 L F
.31414 .77262 m .32018 .76085 L .31621 .76147 L F
.31414 .77262 m .31929 .76564 L .32018 .76085 L F
0 g
.31414 .77262 m
.31414 .77262 L
s
.68059 .89998 m
.68136 .89784 L
s
.67986 .90204 m
.68059 .89998 L
s
.53337 .96386 m .54441 .98896 L .54356 .97329 L 0 .274 .233 r
F
.53337 .96386 m .54182 .99366 L .54441 .98896 L F
0 g
.53524 .98669 m
.53606 .9883 L
s
.53606 .9883 m
.53677 .98972 L
s
.53691 .99022 m
.53704 .99045 L
s
.53647 .98938 m
.53691 .99022 L
s
.53677 .98972 m
.53712 .9904 L
s
.53337 .96386 m .53391 .97145 L .53752 .98421 L 0 .274 .233 r
F
0 g
.53337 .96386 m
.53595 .9592 L
s
.5333 .96372 m
.53337 .96386 L
s
.52871 .96338 m
.52908 .96393 L
s
.52871 .96338 m
.52885 .96346 L
s
.3769 .69265 m .36784 .67965 L .36491 .68514 L 0 1 .499 r
F
0 g
.36079 .68162 m
.36491 .68514 L
s
.40086 .91469 m .39147 .90774 L .38962 .90821 L 0 .42 .256 r
F
.40086 .91469 m .39616 .90959 L .39147 .90774 L F
0 g
.38962 .90821 m
.39164 .9104 L
s
.40086 .91469 m .40054 .91252 L .39616 .90959 L 0 .42 .256 r
F
.40086 .91469 m .40255 .91471 L .40054 .91252 L F
0 g
.39619 .91284 m
.40086 .91469 L
s
.40086 .91469 m
.403 .91659 L
s
.50679 .96864 m .50175 .97807 L .50445 .97236 L 0 .433 .107 r
F
0 g
.50536 .96721 m
.50542 .96715 L
s
.50456 .96685 m
.50481 .96636 L
s
.50679 .96864 m .50036 .9837 L .50175 .97807 L 0 .433 .107 r
F
.50679 .96864 m .50122 .98548 L .50036 .9837 L F
.50679 .96864 m .50357 .98173 L .50122 .98548 L F
.50679 .96864 m .50584 .97496 L .50357 .98173 L F
0 g
.50609 .96774 m
.50617 .96752 L
s
.50316 .96969 m
.50536 .96721 L
s
.50316 .96969 m
.50456 .96685 L
s
.50679 .96864 m .50722 .96936 L .50584 .97496 L 0 .433 .107 r
F
0 g
.50679 .96864 m
.50849 .9621 L
s
.50722 .96936 m
.50923 .96337 L
s
.71699 1.1115 m .71403 1.10981 L .71478 1.10511 L 0 0 .016 r
F
0 g
.70896 1.10653 m
.71478 1.10511 L
s
.31604 .66785 m
.31697 .66939 L
s
.44309 .79864 m .435 .79491 L .43764 .79564 L 0 0 0 r
F
0 g
.44168 .79651 m
.44309 .79864 L
s
.4364 .79414 m
.43764 .79564 L
s
.5422 .95004 m
.54395 .95504 L
s
.54154 .95312 m
.54171 .95232 L
s
.54183 .95176 m
.5422 .95004 L
s
.23967 .86543 m .23079 .85817 L .22817 .86274 L 0 1 .52 r
F
.23967 .86543 m .23618 .85567 L .23079 .85817 L F
.23967 .86543 m .24072 .85692 L .23618 .85567 L F
.23967 .86543 m .24221 .86111 L .24072 .85692 L F
0 g
.23431 .8679 m
.23967 .86543 L
s
.23967 .86543 m
.24124 .86941 L
s
.3278 .54951 m
.33773 .54398 L
s
.60426 .51247 m
.61348 .51755 L
s
.53929 1.12008 m .53643 1.11277 L .53533 1.10846 L 0 .449 0 r
F
0 g
.53234 1.1027 m
.53533 1.10846 L
s
.67082 .90119 m
.67332 .90297 L
s
.30397 .56197 m
.30968 .55474 L
s
.48965 .82885 m .48437 .82697 L .48573 .82569 L 0 .356 .017 r
F
0 g
.48394 .82127 m
.48573 .82569 L
s
.48965 .82885 m .48662 .83235 L .48437 .82697 L 0 .356 .017 r
F
.48965 .82885 m .49099 .83824 L .48662 .83235 L F
.48965 .82885 m .49492 .84141 L .49099 .83824 L F
.48965 .82885 m .49579 .83974 L .49492 .84141 L F
.48965 .82885 m .49353 .83435 L .49579 .83974 L F
0 g
.48778 .82265 m
.48965 .82885 L
s
.48573 .82569 m
.48965 .82885 L
s
.52194 1.07041 m .52401 1.07987 L .52309 1.07518 L 0 0 .127 r
F
0 g
.52401 1.07987 m
.52412 1.08196 L
s
.52582 1.0814 m .52401 1.07987 L .52652 1.08814 L 0 0 .116 r
F
.52582 1.0814 m .52309 1.07519 L .52401 1.07987 L F
.51755 1.02713 m .51725 1.02623 L .5176 1.03298 L 0 .119 .201 r
F
0 g
.51729 1.02703 m
.51734 1.02796 L
s
.51725 1.0264 m
.51729 1.02703 L
s
.51725 1.02623 m
.51725 1.0264 L
s
.51708 1.01729 m
.51752 1.02641 L
s
.51752 1.02641 m
.51752 1.02654 L
s
.51752 1.02654 m
.51754 1.02698 L
s
.51675 1.02678 m
.51759 1.03297 L
s
.51724 1.02615 m
.51725 1.02623 L
s
.54357 1.1242 m .5493 1.13018 L .54746 1.12997 L 0 .449 .012 r
F
.5517 1.14418 m .5493 1.13018 L .55342 1.1364 L 0 .538 .048 r
F
.5517 1.14418 m .54746 1.12997 L .5493 1.13018 L F
0 g
.54782 1.12486 m
.5493 1.13018 L
s
.6332 .60452 m .65397 .60115 L .64864 .59931 L 0 1 .489 r
F
0 g
.65397 .60115 m
.66269 .60036 L
s
.34726 .88689 m .33687 .88256 L .33807 .88574 L 0 1 .505 r
F
0 g
.33355 .88639 m
.33807 .88574 L
s
.48785 .68999 m .48098 .68556 L .48177 .68941 L 0 1 .479 r
F
.48785 .68999 m .48624 .6804 L .48098 .68556 L F
.48785 .68999 m .49403 .67738 L .48624 .6804 L F
.48785 .68999 m .50011 .67797 L .49403 .67738 L F
.48785 .68999 m .50043 .68177 L .50011 .67797 L F
0 g
.49858 .68358 m
.50043 .68177 L
s
.48295 .69533 m
.48785 .68999 L
s
.50043 .68177 m
.5062 .68234 L
s
.53267 .91241 m
.53506 .90858 L
s
.53506 .90858 m
.53543 .90799 L
s
.52515 .99251 m .53729 1.05731 L .53736 1.05406 L 0 .219 .223 r
F
.52515 .99251 m .53356 1.04035 L .53729 1.05731 L F
.52515 .99251 m .52871 1.01467 L .53356 1.04035 L F
.52515 .99251 m .52511 .99424 L .52871 1.01467 L F
.52079 .97071 m .52572 .99527 L .52273 .98159 L 0 .499 .151 r
F
0 g
.52156 .97824 m
.52301 .98287 L
s
.52515 .98767 m .53738 1.04843 L .53735 1.04418 L 0 .22 .223 r
F
.52515 .98767 m .53372 1.03338 L .53738 1.04843 L F
.52515 .98767 m .52882 1.00922 L .53372 1.03338 L F
.52515 .98767 m .52516 .9897 L .52882 1.00922 L F
.52515 .99251 m .53372 1.03338 L .52882 1.00922 L 0 .219 .223 r
F
.52515 .99251 m .53736 1.05406 L .53372 1.03338 L F
.52079 .97071 m .52854 1.00405 L .52572 .99527 L 0 .499 .151 r
F
.52515 .98767 m .53364 1.02444 L .52877 1.00251 L 0 .22 .223 r
F
.52515 .98767 m .53735 1.04418 L .53364 1.02444 L F
.52079 .97071 m .52929 1.00202 L .52854 1.00405 L 0 .499 .151 r
F
.52079 .97071 m .52732 .99104 L .52929 1.00202 L F
0 g
.528 .99271 m
.52854 .99461 L
s
.52824 .99329 m
.52854 .99461 L
s
.52079 .97071 m .52396 .97851 L .52732 .99104 L 0 .499 .151 r
F
0 g
.51867 .98765 m
.52108 1.00341 L
s
.5183 .96439 m
.52079 .97071 L
s
.52268 .96619 m
.52435 .97218 L
s
.52237 .96813 m
.52403 .97218 L
s
.52156 .97824 m
.52397 .98782 L
s
.52129 .9702 m
.52172 .97154 L
s
.52149 .98127 m
.52328 .98903 L
s
.52149 .98127 m
.52357 .98871 L
s
.52171 .98841 m
.52312 .99453 L
s
.52159 .98826 m
.52282 .99457 L
s
.52397 .98782 m
.52463 .99044 L
s
.80814 .98118 m .81937 .98264 L .81957 .97259 L 0 1 .436 r
F
0 g
.81582 .99263 m
.81937 .98264 L
s
.81937 .98264 m
.82264 .98792 L
s
.38962 .90821 m .38083 .90131 L .37882 .90226 L 0 .52 .347 r
F
.38962 .90821 m .3855 .90264 L .38083 .90131 L F
.38962 .90821 m .38971 .90535 L .3855 .90264 L F
.38962 .90821 m .39147 .90774 L .38971 .90535 L F
0 g
.38495 .90688 m
.38962 .90821 L
s
.53727 .99096 m
.53761 .99173 L
s
.53704 .99045 m
.53727 .99096 L
s
.5473 1.00938 m
.54831 1.01114 L
s
.54704 1.00892 m
.5473 1.00938 L
s
.54674 1.00839 m
.54704 1.00892 L
s
.52675 .63192 m .52048 .63013 L .52032 .63051 L 0 .554 .223 r
F
0 g
.51364 .63052 m
.52032 .63051 L
s
.52675 .63192 m .5275 .63113 L .52048 .63013 L 0 .554 .223 r
F
.52675 .63192 m .53671 .63285 L .5275 .63113 L F
.52675 .63192 m .54313 .63426 L .53671 .63285 L F
.52675 .63192 m .54249 .63441 L .54313 .63426 L F
0 g
.54153 .6344 m
.54296 .63485 L
s
.52675 .63192 m .53547 .63341 L .54249 .63441 L 0 .554 .223 r
F
0 g
.52009 .63088 m
.52675 .63192 L
s
.52032 .63051 m
.52675 .63192 L
s
.53547 .63341 m
.54153 .6344 L
s
.79795 .85994 m .80432 .85405 L .79976 .85571 L 0 1 .492 r
F
.79795 .85994 m .8094 .85612 L .80432 .85405 L F
.77287 1.03526 m .78278 1.03093 L .78414 1.02366 L 0 1 .332 r
F
0 g
.77843 1.03958 m
.78278 1.03093 L
s
.78278 1.03093 m
.78512 1.03353 L
s
.48093 .96124 m .47278 .95733 L .47715 .95874 L 0 .365 .069 r
F
0 g
.47715 .95874 m
.48004 .95845 L
s
.4966 .96624 m
.49675 .9662 L
s
.51784 1.04712 m .52029 1.06233 L .51952 1.05547 L 0 .038 .163 r
F
0 g
.51939 1.06354 m
.52029 1.06233 L
s
.56978 .64459 m .57816 .64881 L .58563 .65229 L 0 .366 .213 r
F
0 g
.57816 .64881 m
.58325 .65132 L
s
.58325 .65132 m
.58475 .65237 L
s
.53547 .63341 m
.54063 .63415 L
s
.69317 .89487 m
.69331 .89486 L
s
.56978 .64459 m .56546 .64163 L .56434 .64151 L 0 .366 .213 r
F
.56978 .64459 m .57294 .64511 L .56546 .64163 L F
.56978 .64459 m .58178 .64962 L .57294 .64511 L F
.56978 .64459 m .58722 .6527 L .58178 .64962 L F
0 g
.58475 .65237 m
.58505 .65259 L
s
.56978 .64459 m .58563 .65229 L .58722 .6527 L 0 .366 .213 r
F
0 g
.56266 .64105 m
.56978 .64459 L
s
.57816 .64881 m
.58408 .65156 L
s
.3495 .70027 m .338 .70532 L .34146 .70822 L 0 1 .396 r
F
0 g
.34146 .70822 m
.34316 .70655 L
s
.34233 .71919 m
.34463 .71339 L
s
.34463 .71339 m
.34742 .70636 L
s
.3495 .70027 m .34107 .69473 L .338 .70532 L 0 1 .396 r
F
.3495 .70027 m .34863 .68352 L .34107 .69473 L F
.3495 .70027 m .35667 .67557 L .34863 .68352 L F
0 g
.34316 .70655 m
.3495 .70027 L
s
.51755 1.02713 m .5176 1.03298 L .51837 1.04289 L 0 .119 .201 r
F
0 g
.51734 1.02796 m
.5176 1.03298 L
s
.5905 .65642 m .58722 .6527 L .58563 .65229 L 0 .322 .22 r
F
0 g
.58563 .65229 m
.58574 .65237 L
s
.58408 .65156 m
.58563 .65229 L
s
.5905 .65642 m .59481 .65766 L .58722 .6527 L 0 .322 .22 r
F
.5905 .65642 m .60333 .66387 L .59481 .65766 L F
0 g
.59921 .66285 m
.6031 .66587 L
s
.5905 .65642 m .60819 .66801 L .60333 .66387 L 0 .322 .22 r
F
0 g
.59888 .66259 m
.59921 .66285 L
s
.6031 .66587 m
.60437 .66707 L
s
.5905 .65642 m .60615 .66732 L .60819 .66801 L 0 .322 .22 r
F
0 g
.60437 .66707 m
.60461 .66729 L
s
.5905 .65642 m .59857 .66235 L .60615 .66732 L 0 .322 .22 r
F
0 g
.59857 .66235 m
.59888 .66259 L
s
.58505 .65259 m
.5905 .65642 L
s
.58574 .65237 m
.5905 .65642 L
s
.55572 .63875 m .5643 .63642 L .56539 .63357 L 0 1 .504 r
F
.54846 .6366 m .55705 .63936 L .55819 .63969 L 0 .447 .213 r
F
.54846 .6366 m .55819 .63969 L .55706 .63926 L F
.55706 .63926 m .5643 .63642 L .55572 .63875 L 0 1 .504 r
F
.55706 .63926 m .55819 .63969 L .5643 .63642 L F
.55572 .63875 m .56434 .64151 L .56546 .64163 L 0 .447 .213 r
F
.54846 .6366 m .55706 .63926 L .55572 .63875 L F
.55706 .63926 m .56434 .64151 L .55572 .63875 L F
.54849 .64262 m .55706 .6403 L .55819 .63969 L 0 1 .504 r
F
.54849 .64262 m .55819 .63969 L .55706 .63926 L F
.54849 .64262 m .55706 .63926 L .55572 .63875 L F
.55706 .63926 m .55819 .63969 L .56434 .64151 L 0 .447 .213 r
F
0 g
.56058 .6406 m
.56142 .64067 L
s
.56116 .64059 m
.56142 .64067 L
s
.55819 .6397 m
.56116 .64059 L
s
.54846 .6366 m .54313 .63426 L .54249 .63441 L 0 .447 .213 r
F
0 g
.54063 .63415 m
.54249 .63441 L
s
.55378 .63797 m .56539 .63357 L .55945 .63299 L 0 1 .504 r
F
.55374 .63796 m .55572 .63875 L .55378 .63797 L 0 .447 .213 r
F
.54846 .6366 m .55572 .63875 L .55374 .63796 L F
.55378 .63797 m .55945 .63299 L .55006 .63645 L 0 1 .504 r
F
.55006 .63645 m .55378 .63797 L .5501 .63645 L 0 .447 .213 r
F
.54846 .6366 m .55378 .63797 L .55006 .63645 L F
.55006 .63645 m .55945 .63299 L .55041 .63508 L 0 1 .504 r
F
.54849 .64262 m .55378 .63797 L .55006 .63645 L F
.54849 .64262 m .55005 .6365 L .54316 .63896 L F
.55005 .6365 m .55006 .63645 L .54999 .63648 L F
.55005 .6365 m .54999 .63648 L .54316 .63896 L F
.55569 .63876 m .55572 .63875 L .55378 .63797 L F
.55572 .63875 m .56539 .63357 L .55378 .63797 L F
.55378 .63797 m .56546 .64163 L .5595 .63945 L 0 .447 .213 r
F
.55572 .63875 m .56546 .64163 L .55378 .63797 L F
.5501 .63645 m .5595 .63945 L .55042 .63642 L F
.55378 .63797 m .5595 .63945 L .5501 .63645 L F
.54849 .64262 m .55569 .63876 L .55378 .63797 L 0 1 .504 r
F
.55006 .63645 m .55041 .63508 L .5488 .63594 L F
.54846 .6366 m .55006 .63645 L .54313 .63426 L 0 .447 .213 r
F
.55006 .63645 m .5488 .63594 L .54313 .63426 L F
.55006 .63645 m .5488 .63594 L .54316 .63896 L 0 1 .504 r
F
.55006 .63645 m .55042 .63642 L .5488 .63594 L 0 .447 .213 r
F
0 g
.54296 .63485 m
.5479 .63642 L
s
.54249 .63441 m
.54793 .6364 L
s
.5643 .63642 m
.56971 .63698 L
s
.55706 .6403 m
.56019 .64057 L
s
.56019 .64057 m
.56058 .6406 L
s
.56465 .64169 m
.56978 .64459 L
s
.56434 .64151 m
.56465 .64169 L
s
.55819 .63969 m
.56434 .64151 L
s
.42003 .71072 m
.42662 .71074 L
s
.77287 1.03526 m .77158 1.04204 L .77397 1.04388 L 0 1 .332 r
F
0 g
.76877 1.05063 m
.77397 1.04388 L
s
.59857 .66235 m
.60486 .66647 L
s
.65923 .77864 m
.65925 .77882 L
s
.65923 .77862 m
.65923 .77864 L
s
.79542 1.01348 m .80445 1.0012 L .79991 1.00491 L 0 1 .404 r
F
.78414 1.02366 m .79542 1.01348 L .7931 1.01084 L 0 1 .373 r
F
.49289 .96549 m .48522 .96452 L .48938 .9644 L 0 .426 .09 r
F
0 g
.48938 .9644 m
.49215 .96317 L
s
.49289 .96549 m .4827 .96618 L .48522 .96452 L 0 .426 .09 r
F
.49289 .96549 m .4835 .96826 L .4827 .96618 L F
.49289 .96549 m .48703 .96935 L .4835 .96826 L F
.49289 .96549 m .49092 .96872 L .48703 .96935 L F
.49289 .96549 m .49343 .96707 L .49092 .96872 L F
0 g
.49289 .96549 m
.4956 .9628 L
s
.48938 .9644 m
.49289 .96549 L
s
.49343 .96707 m
.4966 .96624 L
s
.3769 .69265 m .37552 .67778 L .36784 .67965 L 0 1 .499 r
F
0 g
.36491 .68514 m
.36784 .67965 L
s
.3769 .69265 m .38378 .67984 L .37552 .67778 L 0 1 .499 r
F
.3769 .69265 m .38709 .68445 L .38378 .67984 L F
.3769 .69265 m .38414 .68994 L .38709 .68445 L F
0 g
.36867 .69059 m
.3769 .69265 L
s
.51755 1.02713 m .5194 1.04592 L .51847 1.03557 L 0 .119 .201 r
F
.51755 1.02713 m .51975 1.05268 L .5194 1.04592 L F
0 g
.51784 1.04712 m
.51797 1.04775 L
s
.51755 1.02713 m .51929 1.05133 L .51975 1.05268 L 0 .119 .201 r
F
.51755 1.02713 m .51837 1.04289 L .51929 1.05133 L F
0 g
.51834 1.04309 m
.51837 1.04289 L
s
.51784 1.04712 m
.51834 1.04309 L
s
.51754 1.02698 m
.51755 1.02713 L
s
.51716 1.01798 m
.51829 1.02802 L
s
.51848 1.02969 m
.51848 1.02969 L
s
.51848 1.02969 m
.5185 1.02992 L
s
.51846 1.02956 m
.51848 1.02969 L
s
.51846 1.02952 m
.51846 1.02956 L
s
.51829 1.02802 m
.51845 1.02947 L
s
.51845 1.02947 m
.51846 1.02952 L
s
.51755 1.02713 m
.51756 1.02722 L
s
.51756 1.02722 m
.51758 1.02739 L
s
.51758 1.02739 m
.51763 1.02785 L
s
.51763 1.02785 m
.51774 1.02884 L
s
.51774 1.02884 m
.51847 1.03557 L
s
.51797 1.04775 m
.51797 1.04778 L
s
.51797 1.04778 m
.51952 1.05547 L
s
.45219 .70613 m .44401 .70181 L .4457 .70572 L 0 1 .474 r
F
.45219 .70613 m .44831 .69638 L .44401 .70181 L F
0 g
.44371 .70872 m
.4457 .70572 L
s
.44196 .71136 m
.44371 .70872 L
s
.45219 .70613 m .45572 .69305 L .44831 .69638 L 0 1 .474 r
F
.45219 .70613 m .46221 .69347 L .45572 .69305 L F
.45219 .70613 m .46345 .69735 L .46221 .69347 L F
.45219 .70613 m .45915 .70277 L .46345 .69735 L F
0 g
.44822 .71169 m
.45219 .70613 L
s
.4457 .70572 m
.45219 .70613 L
s
.45915 .70277 m
.46531 .7033 L
s
.53473 .98391 m
.5351 .98466 L
s
.37882 .90226 m .37017 .89521 L .368 .89663 L 0 .705 .413 r
F
0 g
.368 .89663 m
.36966 .89927 L
s
.37882 .90226 m .37496 .89608 L .37017 .89521 L 0 .705 .413 r
F
.37882 .90226 m .37918 .89866 L .37496 .89608 L F
.37882 .90226 m .38083 .90131 L .37918 .89866 L F
0 g
.37403 .90138 m
.37882 .90226 L
s
.37882 .90226 m
.38059 .90465 L
s
.55706 .6403 m
.55812 .63973 L
s
.55812 .63973 m
.55819 .63969 L
s
.55897 .63928 m
.5643 .63642 L
s
.52073 1.00419 m .52034 1.00362 L .52212 1.01845 L 0 .229 .24 r
F
0 g
.52036 1.00383 m
.52036 1.00383 L
s
.52036 1.00383 m
.52036 1.00383 L
s
.52034 1.00362 m
.52034 1.00364 L
s
.52034 1.00364 m
.52036 1.00383 L
s
.52108 1.00341 m
.52117 1.00402 L
s
.52041 1.01226 m
.52066 1.01463 L
s
.52066 1.01463 m
.52073 1.01532 L
s
.52033 1.00355 m
.52034 1.00362 L
s
.52063 1.00339 m
.52068 1.00377 L
s
.52068 1.00377 m
.52071 1.00403 L
s
.52071 1.00403 m
.52072 1.00412 L
s
.52057 1.01416 m
.52073 1.01532 L
s
.52016 1.01131 m
.52057 1.01416 L
s
.53001 .96796 m
.53098 .96889 L
s
.37836 .52234 m .3656 .52539 L .36796 .52632 L 0 1 .426 r
F
0 g
.36158 .53268 m
.36796 .52632 L
s
.37836 .52234 m .3728 .5201 L .3656 .52539 L 0 1 .426 r
F
.37836 .52234 m .38478 .51399 L .3728 .5201 L F
.37836 .52234 m .3952 .51001 L .38478 .51399 L F
.37836 .52234 m .39709 .51081 L .3952 .51001 L F
.37836 .52234 m .38987 .5161 L .39709 .51081 L F
0 g
.37149 .52761 m
.37836 .52234 L
s
.36796 .52632 m
.37836 .52234 L
s
.38987 .5161 m
.39993 .51189 L
s
.52842 .95623 m .53303 .95493 L .53007 .95463 L 0 .226 .269 r
F
0 g
.52735 .95267 m
.53007 .95463 L
s
.52842 .95623 m .53612 .95875 L .53303 .95493 L 0 .226 .269 r
F
.52842 .95623 m .53727 .96355 L .53612 .95875 L F
.52842 .95623 m .53561 .96516 L .53727 .96355 L F
.52842 .95623 m .53226 .9625 L .53561 .96516 L F
0 g
.52885 .96346 m
.53004 .96415 L
s
.52842 .95623 m .52918 .95868 L .53226 .9625 L 0 .226 .269 r
F
0 g
.52838 .95619 m
.52842 .95623 L
s
.52842 .95623 m
.53007 .95463 L
s
.52913 .95867 m
.52918 .95868 L
s
.52817 .95859 m
.52913 .95867 L
s
.52725 .95852 m
.52913 .96087 L
s
.62157 .52433 m .61613 .51898 L .61438 .51805 L 0 .245 .205 r
F
0 g
.61348 .51755 m
.61438 .51805 L
s
.62157 .52433 m .62631 .52676 L .61613 .51898 L 0 .245 .205 r
F
0 g
.61438 .51805 m
.61679 .52015 L
s
.62157 .52433 m .63814 .5362 L .62631 .52676 L 0 .245 .205 r
F
.62157 .52433 m .64533 .54248 L .63814 .5362 L F
0 g
.63791 .53787 m
.63974 .53943 L
s
.63974 .53943 m
.6399 .5396 L
s
.62157 .52433 m .64309 .5414 L .64533 .54248 L 0 .245 .205 r
F
0 g
.6399 .5396 m
.64103 .5408 L
s
.62157 .52433 m .63291 .53363 L .64309 .5414 L 0 .245 .205 r
F
0 g
.63291 .53363 m
.63791 .53787 L
s
.61305 .51736 m
.62157 .52433 L
s
.61679 .52015 m
.62157 .52433 L
s
.33687 .88256 m .32756 .88191 L .33176 .88341 L 0 1 .517 r
F
0 g
.33176 .88341 m
.33355 .88639 L
s
.6627 .92165 m
.66305 .92096 L
s
.44309 .79864 m .43679 .79666 L .435 .79491 L 0 0 0 r
F
.44309 .79864 m .44184 .79973 L .43679 .79666 L F
.44309 .79864 m .44731 .80274 L .44184 .79973 L F
.44309 .79864 m .44954 .80366 L .44731 .80274 L F
.44309 .79864 m .44772 .8019 L .44954 .80366 L F
0 g
.43764 .79564 m
.44309 .79864 L
s
.46978 .69787 m .47697 .69468 L .48177 .68941 L 0 1 .477 r
F
0 g
.47697 .69468 m
.48295 .69533 L
s
.61039 .67275 m .60819 .66801 L .60615 .66732 L 0 .315 .27 r
F
0 g
.60486 .66647 m
.60615 .66732 L
s
.61039 .67275 m .6158 .67463 L .60819 .66801 L 0 .315 .27 r
F
0 g
.60615 .66732 m
.60946 .67156 L
s
.61039 .67275 m .62392 .68277 L .6158 .67463 L 0 .315 .27 r
F
.61039 .67275 m .62815 .6882 L .62392 .68277 L F
0 g
.61944 .68233 m
.622 .68547 L
s
.622 .68547 m
.62264 .68625 L
s
.61039 .67275 m .62569 .6873 L .62815 .6882 L 0 .315 .27 r
F
0 g
.62264 .68625 m
.62351 .6873 L
s
.61039 .67275 m .61808 .68068 L .62569 .6873 L 0 .315 .27 r
F
0 g
.61808 .68068 m
.61944 .68233 L
s
.60461 .66729 m
.61039 .67275 L
s
.60946 .67156 m
.61039 .67275 L
s
.8094 .85612 m .81573 .84996 L .81117 .85159 L 0 1 .503 r
F
.8094 .85612 m .82086 .85238 L .81573 .84996 L F
.70658 .72753 m .7163 .73037 L .70816 .7076 L 0 .5 .307 r
F
0 g
.70923 .71058 m
.70951 .71137 L
s
.70951 .71137 m
.71178 .71773 L
s
.70816 .7076 m
.70923 .71058 L
s
.70518 .69014 m
.70816 .7076 L
s
.7025 .71469 m
.70658 .72753 L
s
.70498 .71195 m
.70658 .72753 L
s
.51975 1.05268 m .52029 1.06233 L .52133 1.06873 L 0 0 .148 r
F
.51975 1.05268 m .51952 1.05547 L .52029 1.06233 L F
.50575 .67293 m .51359 .67001 L .51958 .66519 L 0 1 .49 r
F
0 g
.51359 .67001 m
.51935 .67059 L
s
.53758 .99145 m
.53773 .9918 L
s
.53744 .99114 m
.53758 .99145 L
s
.53712 .9904 m
.53744 .99114 L
s
.46978 .69787 m .46221 .69347 L .46345 .69735 L 0 1 .477 r
F
.46978 .69787 m .46701 .68819 L .46221 .69347 L F
0 g
.46202 .69915 m
.46345 .69735 L
s
.45915 .70277 m
.46202 .69915 L
s
.46978 .69787 m .47466 .68503 L .46701 .68819 L 0 1 .477 r
F
.46978 .69787 m .48098 .68556 L .47466 .68503 L F
.46978 .69787 m .48177 .68941 L .48098 .68556 L F
0 g
.47697 .69468 m
.48029 .69104 L
s
.48029 .69104 m
.48177 .68941 L
s
.46345 .69735 m
.46978 .69787 L
s
.46531 .7033 m
.46978 .69787 L
s
.48177 .68941 m
.48785 .68999 L
s
.70007 .89105 m .70745 .89082 L .7117 .88928 L 0 1 .259 r
F
.70007 .89105 m .70247 .89158 L .70745 .89082 L F
0 g
.70709 .89117 m
.70745 .89082 L
s
.70107 .89313 m
.70247 .89158 L
s
.48093 .96124 m .47015 .95785 L .47278 .95733 L 0 .365 .069 r
F
0 g
.46897 .95485 m
.47278 .95733 L
s
.48093 .96124 m .47104 .95995 L .47015 .95785 L 0 .365 .069 r
F
.48093 .96124 m .47482 .96246 L .47104 .95995 L F
.48093 .96124 m .47898 .96369 L .47482 .96246 L F
.48093 .96124 m .4816 .96317 L .47898 .96369 L F
0 g
.48093 .96124 m
.48372 .96001 L
s
.47715 .95874 m
.48093 .96124 L
s
.27051 .78441 m .26464 .77607 L .25968 .78227 L 0 1 .537 r
F
.27051 .78441 m .27152 .77206 L .26464 .77607 L F
.27051 .78441 m .27572 .77293 L .27152 .77206 L F
.27051 .78441 m .27528 .77823 L .27572 .77293 L F
0 g
.27023 .78962 m
.27051 .78441 L
s
.26366 .78839 m
.27051 .78441 L
s
.51979 .97266 m .5202 .97193 L .52273 .98159 L 0 .509 .151 r
F
0 g
.5183 .9644 m
.5202 .97193 L
s
.3003 .70478 m .29795 .69115 L .29086 .69761 L 0 1 .503 r
F
.3003 .70478 m .30597 .68845 L .29795 .69115 L F
.3003 .70478 m .30956 .69132 L .30597 .68845 L F
.3003 .70478 m .30712 .69832 L .30956 .69132 L F
0 g
.29231 .70746 m
.3003 .70478 L
s
.29808 .71209 m
.3003 .70478 L
s
.53543 .8726 m
.53613 .87667 L
s
.25968 .78227 m .2483 .7853 L .25269 .78622 L 0 1 .54 r
F
0 g
.25269 .78622 m
.25311 .79204 L
s
.52073 1.00419 m .52659 1.04297 L .52341 1.02101 L 0 .229 .24 r
F
.52073 1.00419 m .52839 1.05793 L .52659 1.04297 L F
.52073 1.00419 m .52759 1.05582 L .52839 1.05793 L F
.52073 1.00419 m .5249 1.03887 L .52759 1.05582 L F
.52073 1.00419 m .52212 1.01845 L .5249 1.03887 L F
0 g
.52076 1.00439 m
.52076 1.00439 L
s
.52076 1.00439 m
.52076 1.00439 L
s
.52073 1.00419 m
.52074 1.00422 L
s
.52074 1.00422 m
.52076 1.00439 L
s
.52072 1.00412 m
.52073 1.00419 L
s
.22817 .86274 m .21936 .85519 L .21666 .86003 L 0 1 .522 r
F
.22817 .86274 m .22481 .85251 L .21936 .85519 L F
.22817 .86274 m .22936 .85378 L .22481 .85251 L F
.22817 .86274 m .23079 .85817 L .22936 .85378 L F
0 g
.22274 .8654 m
.22817 .86274 L
s
.22817 .86274 m
.22968 .8669 L
s
.33687 .88256 m .32646 .87861 L .32756 .88191 L 0 1 .517 r
F
0 g
.32297 .88287 m
.32756 .88191 L
s
.368 .89663 m .35995 .88972 L .35764 .89158 L 0 .869 .458 r
F
.368 .89663 m .36473 .89007 L .35995 .88972 L F
.368 .89663 m .36877 .8924 L .36473 .89007 L F
.368 .89663 m .37017 .89521 L .36877 .8924 L F
0 g
.36324 .89627 m
.368 .89663 L
s
.59991 .61791 m .59611 .61406 L .59444 .6167 L 0 1 .487 r
F
.59991 .61791 m .60443 .61153 L .59611 .61406 L F
.59991 .61791 m .61383 .61081 L .60443 .61153 L F
0 g
.53233 .97182 m
.53294 .97168 L
s
.53164 .97277 m
.53178 .97295 L
s
.53159 .9727 m
.53164 .97277 L
s
.53128 .97231 m
.53159 .9727 L
s
.53118 .97219 m
.53128 .97231 L
s
.53112 .97211 m
.53118 .97219 L
s
.53112 .97212 m
.53122 .97229 L
s
.53112 .97211 m
.53112 .97212 L
s
.53122 .97229 m
.53124 .97234 L
s
.53124 .97234 m
.53127 .97238 L
s
.53127 .97238 m
.53156 .9729 L
s
.53156 .9729 m
.53187 .97347 L
s
.29086 .69761 m .27877 .69794 L .28264 .70051 L 0 1 .515 r
F
0 g
.28104 .70643 m
.28264 .70051 L
s
.53112 .97211 m
.53112 .97211 L
s
.53141 .9729 m
.53153 .97324 L
s
.53133 .9727 m
.53141 .9729 L
s
.53133 .97268 m
.53133 .9727 L
s
.53132 .97267 m
.53133 .97268 L
s
.53128 .97256 m
.53132 .97267 L
s
.53119 .9723 m
.53128 .97256 L
s
.53118 .9723 m
.53119 .9723 L
s
.53112 .97211 m
.53118 .9723 L
s
.52982 .93646 m .53249 .92132 L .5304 .92819 L 0 .42 .301 r
F
0 g
.52779 .93057 m
.5304 .92819 L
s
.50788 .9704 m .50357 .98173 L .50584 .97496 L 0 .438 .11 r
F
0 g
.50661 .96893 m
.50679 .96864 L
s
.50587 .96836 m
.50609 .96774 L
s
.50788 .9704 m .50254 .98815 L .50357 .98173 L 0 .438 .11 r
F
.50788 .9704 m .50345 .98992 L .50254 .98815 L F
.50788 .9704 m .5055 .98532 L .50345 .98992 L F
0 g
.50445 .97236 m
.50484 .97128 L
s
.50788 .9704 m .50732 .97745 L .5055 .98532 L 0 .438 .11 r
F
0 g
.50718 .96955 m
.50722 .96936 L
s
.50489 .97167 m
.50661 .96893 L
s
.50484 .97128 m
.50587 .96836 L
s
.50788 .9704 m .50833 .97107 L .50732 .97745 L 0 .438 .11 r
F
0 g
.50788 .9704 m
.50923 .96337 L
s
.50833 .97107 m
.51002 .96454 L
s
.51975 1.05268 m .52133 1.06873 L .52194 1.07041 L 0 0 .148 r
F
0 g
.52029 1.06233 m
.52133 1.06873 L
s
.52133 1.06873 m
.52145 1.07083 L
s
.53706 .99079 m
.53957 .99619 L
s
.61808 .68068 m
.62474 .68647 L
s
.36196 .76962 m
.36814 .77265 L
s
.65963 .88674 m
.65964 .88674 L
s
.71592 .58656 m .73877 .58895 L .73385 .58543 L 0 1 .51 r
F
0 g
.73877 .58895 m
.74803 .59072 L
s
.45314 .63417 m
.45891 .63249 L
s
.70007 .89105 m .7117 .88928 L .71302 .88773 L 0 1 .259 r
F
0 g
.70247 .89158 m
.70745 .89082 L
s
.7117 .88928 m
.7161 .88895 L
s
.66979 .9078 m
.67082 .90119 L
s
.63291 .53363 m
.6426 .54103 L
s
.5517 1.14418 m .55342 1.1364 L .55709 1.14448 L 0 .538 .048 r
F
0 g
.5493 1.13018 m
.55342 1.1364 L
s
.55204 1.12976 m
.55342 1.1364 L
s
.52982 .93646 m .53538 .92078 L .53249 .92132 L 0 .42 .301 r
F
0 g
.53249 .92132 m
.53267 .91241 L
s
.65508 .75274 m .65633 .74338 L .65311 .74172 L 0 .384 .336 r
F
0 g
.65311 .74172 m
.65418 .74769 L
s
.65265 .74102 m
.65311 .74172 L
s
.65508 .75274 m .66335 .75657 L .65633 .74338 L 0 .384 .336 r
F
0 g
.65331 .74902 m
.65508 .75274 L
s
.65418 .74769 m
.65508 .75274 L
s
.4074 .70467 m .39772 .70049 L .40023 .70448 L 0 1 .481 r
F
0 g
.39993 .7051 m
.40023 .70448 L
s
.50575 .67293 m .51958 .66519 L .51973 .66168 L 0 1 .49 r
F
0 g
.51958 .66519 m
.52531 .66568 L
s
.51359 .67001 m
.51958 .66519 L
s
.52582 1.0814 m .52652 1.08814 L .52897 1.0945 L 0 0 .116 r
F
0 g
.52401 1.07987 m
.52652 1.08814 L
s
.52538 1.08549 m
.52652 1.08814 L
s
.82086 .85238 m .82715 .84597 L .82258 .84756 L 0 1 .512 r
F
.82086 .85238 m .83232 .84873 L .82715 .84597 L F
.43697 .63802 m .42647 .63793 L .42875 .63905 L 0 1 .404 r
F
0 g
.42423 .64251 m
.42875 .63905 L
s
.43697 .63802 m .43171 .63515 L .42647 .63793 L 0 1 .404 r
F
.43697 .63802 m .441 .63258 L .43171 .63515 L F
.43697 .63802 m .44923 .63155 L .441 .63258 L F
.43697 .63802 m .45092 .63274 L .44923 .63155 L F
.43697 .63802 m .44566 .63552 L .45092 .63274 L F
0 g
.42875 .63905 m
.43697 .63802 L
s
.44566 .63552 m
.45314 .63417 L
s
.51975 1.05268 m .51929 1.05133 L .51952 1.05547 L 0 0 .148 r
F
0 g
.51929 1.05134 m
.51952 1.05547 L
s
.51929 1.05133 m
.51929 1.05134 L
s
.51928 1.0512 m
.51929 1.05133 L
s
.52605 .65703 m .53431 .65435 L .54096 .64995 L 0 1 .5 r
F
0 g
.53431 .65435 m
.54003 .65485 L
s
.79672 .99079 m .80445 1.0012 L .80798 .99104 L 0 1 .42 r
F
.79672 .99079 m .79991 1.00491 L .80445 1.0012 L F
0 g
.80445 1.0012 m
.80672 1.00448 L
s
.70638 .66971 m .70644 .65442 L .70295 .65299 L 0 .454 .337 r
F
0 g
.69375 .63692 m
.70295 .65299 L
s
.52582 1.0814 m .52386 1.07584 L .52309 1.07519 L 0 0 .116 r
F
0 g
.52309 1.07519 m
.52309 1.07519 L
s
.55296 .89334 m .55539 .89083 L .5598 .93558 L 0 .881 .187 r
F
0 g
.55905 .89206 m
.55908 .89376 L
s
.55908 .89376 m
.55909 .89413 L
s
.55909 .89413 m
.55911 .89557 L
s
.55911 .89557 m
.55912 .89605 L
s
.55907 .89536 m
.55908 .89376 L
s
.55907 .89553 m
.55907 .89536 L
s
.55908 .89376 m
.55909 .8929 L
s
.5553 .88541 m
.55539 .89083 L
s
.51979 .97266 m .52397 .99829 L .5214 .98392 L 0 .509 .151 r
F
.52476 .99994 m .53319 1.04537 L .52842 1.01886 L 0 .224 .227 r
F
.52476 .99994 m .53657 1.06638 L .53319 1.04537 L F
.52476 .99994 m .53629 1.06772 L .53657 1.06638 L F
.52476 .99994 m .53258 1.04854 L .53629 1.06772 L F
.52476 .99994 m .52796 1.02181 L .53258 1.04854 L F
.52476 .99994 m .52462 1.00106 L .52796 1.02181 L F
.51979 .97266 m .52653 1.00807 L .52397 .99829 L 0 .509 .151 r
F
.52502 .99661 m .53356 1.04035 L .52871 1.01467 L 0 .221 .224 r
F
.52502 .99661 m .5371 1.06143 L .53356 1.04035 L F
.52502 .99661 m .53692 1.06369 L .5371 1.06143 L F
.52502 .99661 m .53319 1.04537 L .53692 1.06369 L F
.52502 .99661 m .52842 1.01886 L .53319 1.04537 L F
.52502 .99661 m .52493 .99804 L .52842 1.01886 L F
.51979 .97266 m .52735 1.00665 L .52653 1.00807 L 0 .509 .151 r
F
.51979 .97266 m .52572 .99527 L .52735 1.00665 L F
0 g
.52117 1.00402 m
.52123 1.00441 L
s
.52156 1.00445 m
.52161 1.00481 L
s
.52123 1.00441 m
.52127 1.00465 L
s
.52127 1.00465 m
.5213 1.00483 L
s
.51937 1.0025 m
.52041 1.01226 L
s
.51979 .97266 m .52273 .98159 L .52572 .99527 L 0 .509 .151 r
F
0 g
.52435 .97218 m
.52481 .97379 L
s
.52481 .97379 m
.52507 .97472 L
s
.52403 .97218 m
.52466 .97372 L
s
.52466 .97372 m
.52507 .97472 L
s
.51931 .98833 m
.52156 1.00445 L
s
.51758 .96566 m
.51979 .97266 L
s
.52122 .97309 m
.52127 .97339 L
s
.52121 .97307 m
.52122 .97309 L
s
.52079 .97071 m
.52121 .97307 L
s
.5202 .97193 m
.52042 .97278 L
s
.52605 .65703 m .54096 .64995 L .54159 .64676 L 0 1 .5 r
F
0 g
.54096 .64995 m
.54658 .65042 L
s
.53431 .65435 m
.54096 .64995 L
s
.6709 1.12574 m .68053 1.12394 L .67672 1.12815 L 0 .241 .083 r
F
0 g
.42951 .79242 m
.435 .79491 L
s
.51948 1.03283 m .51847 1.03557 L .5194 1.04592 L 0 .106 .194 r
F
0 g
.51837 1.04289 m
.51928 1.0512 L
s
.51948 1.03283 m .51851 1.02996 L .51847 1.03557 L 0 .106 .194 r
F
0 g
.51847 1.03557 m
.5185 1.03071 L
s
.5185 1.03071 m
.51851 1.03015 L
s
.51851 1.03015 m
.51851 1.02996 L
s
.5185 1.02992 m
.51851 1.02996 L
s
.39005 .7787 m .38043 .77616 L .3837 .77675 L 0 0 0 r
F
.71051 .8872 m .71807 .88692 L .72233 .88532 L 0 1 .255 r
F
.71051 .8872 m .71302 .88773 L .71807 .88692 L F
0 g
.7161 .88895 m
.71807 .88692 L
s
.57279 .63007 m .59166 .62116 L .58619 .61977 L 0 1 .497 r
F
0 g
.59166 .62116 m
.59991 .61791 L
s
.66022 .79131 m .66927 .7967 L .66266 .7796 L 0 .406 .308 r
F
.66022 .79131 m .67457 .81712 L .66927 .7967 L F
.66022 .79131 m .67569 .83135 L .67457 .81712 L F
0 g
.65809 .8215 m
.6586 .82385 L
s
.66022 .79131 m .67188 .82985 L .67569 .83135 L 0 .406 .308 r
F
.66022 .79131 m .66525 .81267 L .67188 .82985 L F
0 g
.65903 .81256 m
.66152 .81993 L
s
.65925 .77882 m
.66022 .79131 L
s
.65791 .78448 m
.66022 .79131 L
s
.6586 .82385 m
.66135 .83652 L
s
.52691 .99901 m
.52722 1.00068 L
s
.5269 .99895 m
.52691 .99901 L
s
.76295 .67992 m .77945 .66021 L .77241 .67233 L 0 0 .03 r
F
0 g
.77945 .66021 m
.78169 .65268 L
s
.52166 1.00519 m .5213 1.00486 L .52341 1.02101 L 0 .231 .239 r
F
0 g
.5213 1.00486 m
.52132 1.00501 L
s
.52132 1.00501 m
.52133 1.00507 L
s
.51934 .98849 m
.52211 1.00507 L
s
.5213 1.00483 m
.5213 1.00486 L
s
.52164 1.00501 m
.52165 1.00513 L
s
.52161 1.00481 m
.52164 1.00501 L
s
.494 .83455 m
.49709 .83585 L
s
.49353 .83435 m
.494 .83455 L
s
.32646 .87861 m .31703 .87838 L .32124 .87976 L 0 1 .523 r
F
0 g
.32124 .87976 m
.32297 .88287 L
s
.62253 1.12113 m
.62264 1.1326 L
s
.62291 1.16065 m
.62301 1.17175 L
s
.62283 1.1524 m
.62291 1.16065 L
s
.6225 1.11827 m
.62253 1.12113 L
s
.6233 1.20241 m
.6234 1.21253 L
s
.62301 1.17175 m
.6233 1.20241 L
s
.6249 1.36975 m
.62493 1.37285 L
s
.35764 .89158 m .34972 .88462 L .34726 .88689 L 0 1 .486 r
F
.35764 .89158 m .35461 .88454 L .34972 .88462 L F
.35764 .89158 m .35866 .8867 L .35461 .88454 L F
.35764 .89158 m .35995 .88972 L .35866 .8867 L F
0 g
.35276 .89165 m
.35764 .89158 L
s
.35764 .89158 m
.35905 .89438 L
s
.4074 .70467 m .40143 .69489 L .39772 .70049 L 0 1 .481 r
F
0 g
.39067 .70027 m
.39772 .70049 L
s
.4074 .70467 m .40888 .69143 L .40143 .69489 L 0 1 .481 r
F
.4074 .70467 m .41607 .69162 L .40888 .69143 L F
.4074 .70467 m .41818 .69535 L .41607 .69162 L F
.4074 .70467 m .41446 .70094 L .41818 .69535 L F
0 g
.40398 .71051 m
.4074 .70467 L
s
.40023 .70448 m
.4074 .70467 L
s
.51946 1.03208 m
.51947 1.03235 L
s
.51945 1.032 m
.51946 1.03208 L
s
.51915 1.02326 m
.51945 1.032 L
s
.51944 1.02555 m
.52011 1.03074 L
s
.51915 1.02326 m
.51944 1.02555 L
s
.71051 .8872 m .72233 .88532 L .72356 .88353 L 0 1 .255 r
F
0 g
.72233 .88532 m
.72678 .88513 L
s
.70805 .59082 m .72558 .58943 L .71592 .58656 L 0 1 .501 r
F
0 g
.72558 .58943 m
.73535 .59046 L
s
.72558 .58943 m
.73024 .59269 L
s
.46034 .80876 m .45294 .80477 L .45526 .80531 L 0 .083 0 r
F
0 g
.45383 .80317 m
.45526 .80531 L
s
.53714 .98974 m .53716 .9901 L .54082 .99892 L 0 0 .125 r
F
0 g
.53716 .9901 m
.53748 .99085 L
s
.53484 .98575 m
.53716 .9901 L
s
.53952 .996 m
.53955 .99606 L
s
.53761 .99173 m
.53952 .996 L
s
.53957 .99619 m
.54003 .99719 L
s
.52982 .93646 m .53716 .92695 L .53538 .92078 L 0 .42 .301 r
F
.52982 .93646 m .53658 .93524 L .53716 .92695 L F
.52982 .93646 m .53404 .94011 L .53658 .93524 L F
.52982 .93646 m .53115 .94063 L .53404 .94011 L F
0 g
.52813 .93621 m
.52982 .93646 L
s
.52982 .93646 m
.5304 .92819 L
s
.56539 .63357 m
.57279 .63007 L
s
.57279 .63007 m .56874 .62504 L .56729 .62869 L 0 1 .497 r
F
.57279 .63007 m .57685 .62121 L .56874 .62504 L F
.57279 .63007 m .58619 .61977 L .57685 .62121 L F
.51975 1.05268 m .52194 1.07041 L .52171 1.06627 L 0 0 .148 r
F
0 g
.52194 1.07041 m
.52309 1.07518 L
s
.67963 1.14502 m .68053 1.12394 L .68597 1.12517 L 0 .21 .093 r
F
.67963 1.14502 m .67672 1.12815 L .68053 1.12394 L F
0 g
.68027 1.11641 m
.68053 1.12394 L
s
.50986 .84862 m .50662 .85162 L .50697 .84708 L 0 .58 .071 r
F
0 g
.50464 .83949 m
.50697 .84708 L
s
.50986 .84862 m .50936 .86105 L .50662 .85162 L 0 .58 .071 r
F
.50986 .84862 m .51338 .86908 L .50936 .86105 L F
.50986 .84862 m .51628 .87062 L .51338 .86908 L F
.50986 .84862 m .51611 .86464 L .51628 .87062 L F
0 g
.51769 .86176 m
.51808 .86356 L
s
.50986 .84862 m .51335 .85522 L .51611 .86464 L 0 .58 .071 r
F
0 g
.51335 .85522 m
.51586 .85329 L
s
.5075 .83834 m
.50986 .84862 L
s
.50697 .84708 m
.50986 .84862 L
s
.51586 .85329 m
.51769 .86176 L
s
.34002 .73091 m .34146 .70823 L .338 .70532 L 0 1 .282 r
F
.34002 .73091 m .34233 .71919 L .34146 .70823 L F
0 g
.34146 .70823 m
.34218 .7174 L
s
.34218 .7174 m
.34231 .71893 L
s
.34231 .71893 m
.34233 .71919 L
s
.78881 .8146 m .7944 .81728 L .78994 .81855 L 0 0 .008 r
F
.78881 .8146 m .80006 .81234 L .7944 .81728 L F
.53027 .9623 m .53561 .96516 L .53226 .9625 L 0 .158 .232 r
F
.53027 .9623 m .53892 .97077 L .53561 .96516 L F
.53027 .9623 m .53996 .97559 L .53892 .97077 L F
.53027 .9623 m .53796 .97538 L .53996 .97559 L F
.53027 .9623 m .53425 .97028 L .53796 .97538 L F
0 g
.52918 .95868 m
.52924 .95875 L
s
.53153 .97324 m
.5317 .9737 L
s
.5317 .9737 m
.53173 .9738 L
s
.53173 .9738 m
.53182 .97405 L
s
.53182 .97405 m
.53183 .97407 L
s
.53183 .97407 m
.53184 .9741 L
s
.53184 .9741 m
.53213 .97488 L
s
.53187 .97347 m
.53224 .97415 L
s
.53178 .97295 m
.53284 .97428 L
s
.53284 .97428 m
.53289 .97434 L
s
.53332 .97347 m
.53365 .97368 L
s
.53365 .97368 m
.53462 .97428 L
s
.53294 .97168 m
.53391 .97145 L
s
.53027 .9623 m .53096 .96468 L .53425 .97028 L 0 .158 .232 r
F
0 g
.52908 .96393 m
.53183 .968 L
s
.53004 .96415 m
.53096 .96468 L
s
.52913 .96087 m
.53027 .9623 L
s
.52924 .95875 m
.53226 .9625 L
s
.53027 .9623 m
.53226 .9625 L
s
.53001 .96796 m
.5325 .97212 L
s
.62927 .69432 m .62815 .6882 L .62569 .6873 L 0 .332 .341 r
F
0 g
.62474 .68647 m
.62569 .6873 L
s
.62927 .69432 m .63572 .69663 L .62815 .6882 L 0 .332 .341 r
F
.62927 .69432 m .64335 .70697 L .63572 .69663 L F
.62927 .69432 m .64693 .714 L .64335 .70697 L F
.62927 .69432 m .64407 .71302 L .64693 .714 L F
0 g
.63979 .71099 m
.64128 .71327 L
s
.62927 .69432 m .63651 .70458 L .64407 .71302 L 0 .332 .341 r
F
0 g
.63651 .70458 m
.63979 .71099 L
s
.62351 .6873 m
.62927 .69432 L
s
.62569 .6873 m
.62927 .69432 L
s
.73981 .8394 m
.74033 .83836 L
s
.29086 .69761 m .28137 .69117 L .27877 .69794 L 0 1 .515 r
F
0 g
.27116 .7003 m
.27877 .69794 L
s
.52166 1.00519 m .52814 1.04631 L .52459 1.0229 L 0 .231 .239 r
F
0 g
.52036 1.00383 m
.52036 1.00384 L
s
.51987 .98839 m
.52232 1.00195 L
s
.51986 .98835 m
.52234 1.00452 L
s
.52166 1.00519 m .53027 1.06261 L .52814 1.04631 L 0 .231 .239 r
F
.52166 1.00519 m .52954 1.06084 L .53027 1.06261 L F
.52166 1.00519 m .52659 1.04297 L .52954 1.06084 L F
.52166 1.00519 m .52341 1.02101 L .52659 1.04297 L F
0 g
.52166 1.00519 m
.52169 1.00537 L
s
.52169 1.00537 m
.52171 1.0055 L
s
.52171 1.0055 m
.52177 1.00582 L
s
.52177 1.00582 m
.52177 1.00583 L
s
.52156 1.01476 m
.52212 1.01845 L
s
.52178 1.01564 m
.52212 1.01845 L
s
.52211 1.00507 m
.52216 1.00543 L
s
.52165 1.00513 m
.52166 1.00519 L
s
.21666 .86003 m .20793 .85218 L .20514 .85729 L 0 1 .524 r
F
.21666 .86003 m .21344 .8493 L .20793 .85218 L F
.21666 .86003 m .21799 .85059 L .21344 .8493 L F
.21666 .86003 m .21936 .85519 L .21799 .85059 L F
0 g
.21117 .86288 m
.21666 .86003 L
s
.21666 .86003 m
.21811 .86439 L
s
.69306 .62154 m .69166 .60943 L .68855 .60806 L 0 .373 .352 r
F
0 g
.68855 .60806 m
.68989 .61206 L
s
.68298 .60064 m
.68855 .60806 L
s
.69306 .62154 m .70113 .62459 L .69166 .60943 L 0 .373 .352 r
F
.69306 .62154 m .71064 .64345 L .70113 .62459 L F
.69306 .62154 m .71516 .65698 L .71064 .64345 L F
.69306 .62154 m .71167 .65613 L .71516 .65698 L F
0 g
.70295 .65299 m
.70392 .65772 L
s
.69904 .65328 m
.70193 .65974 L
s
.69306 .62154 m .70219 .64092 L .71167 .65613 L 0 .373 .352 r
F
0 g
.68848 .61355 m
.69306 .62154 L
s
.68989 .61206 m
.69306 .62154 L
s
.43035 .7051 m .42135 .70103 L .42346 .70488 L 0 1 .479 r
F
.43035 .7051 m .42539 .69554 L .42135 .70103 L F
0 g
.42003 .71072 m
.42346 .70488 L
s
.43035 .7051 m .43289 .69207 L .42539 .69554 L 0 1 .479 r
F
.43035 .7051 m .43979 .69229 L .43289 .69207 L F
.43035 .7051 m .44148 .69605 L .43979 .69229 L F
.43035 .7051 m .43743 .70155 L .44148 .69605 L F
0 g
.42662 .71074 m
.43035 .7051 L
s
.42346 .70488 m
.43035 .7051 L
s
.47596 .8194 m .46957 .81585 L .47142 .81579 L 0 .23 0 r
F
0 g
.46978 .8127 m
.47142 .81579 L
s
.47596 .8194 m .47169 .81957 L .46957 .81585 L 0 .23 0 r
F
.47596 .8194 m .47639 .8245 L .47169 .81957 L F
.47596 .8194 m .48095 .82812 L .47639 .8245 L F
.47596 .8194 m .48232 .82802 L .48095 .82812 L F
.47596 .8194 m .48017 .82427 L .48232 .82802 L F
0 g
.47419 .81498 m
.47596 .8194 L
s
.47142 .81579 m
.47596 .8194 L
s
.25968 .78227 m .24884 .7799 L .2483 .7853 L 0 1 .54 r
F
0 g
.24203 .78984 m
.2483 .7853 L
s
.70805 .59082 m .70637 .58575 L .70334 .58756 L 0 1 .501 r
F
.70805 .59082 m .71592 .58656 L .70637 .58575 L F
0 g
.70334 .58756 m
.70805 .59082 L
s
.69879 .59025 m
.70805 .59082 L
s
.50575 .67293 m .49931 .66879 L .49963 .67241 L 0 1 .49 r
F
.50575 .67293 m .50531 .66396 L .49931 .66879 L F
.50575 .67293 m .51362 .66115 L .50531 .66396 L F
.50575 .67293 m .51973 .66168 L .51362 .66115 L F
0 g
.50011 .67797 m
.50575 .67293 L
s
.32646 .87861 m .31603 .875 L .31703 .87838 L 0 1 .523 r
F
0 g
.31236 .8796 m
.31703 .87838 L
s
.46034 .80876 m .4549 .80731 L .45294 .80477 L 0 .083 0 r
F
.46034 .80876 m .45983 .81125 L .4549 .80731 L F
.46034 .80876 m .46494 .81472 L .45983 .81125 L F
.46034 .80876 m .46679 .81539 L .46494 .81472 L F
.46034 .80876 m .46481 .81283 L .46679 .81539 L F
0 g
.45872 .80568 m
.46034 .80876 L
s
.45526 .80531 m
.46034 .80876 L
s
.50903 .972 m .5055 .98532 L .50732 .97745 L 0 .445 .115 r
F
0 g
.5078 .97058 m
.50788 .9704 L
s
.50708 .96992 m
.50718 .96955 L
s
.50903 .972 m .50484 .99255 L .5055 .98532 L 0 .445 .115 r
F
.50903 .972 m .50579 .99428 L .50484 .99255 L F
0 g
.50445 .97236 m
.50489 .97167 L
s
.50903 .972 m .50751 .98879 L .50579 .99428 L 0 .445 .115 r
F
0 g
.50584 .97496 m
.50708 .96992 L
s
.50903 .972 m .50885 .97976 L .50751 .98879 L 0 .445 .115 r
F
0 g
.50831 .97121 m
.50833 .97107 L
s
.50903 .972 m .5095 .97259 L .50885 .97976 L 0 .445 .115 r
F
0 g
.50903 .972 m
.51003 .96453 L
s
.5095 .97259 m
.51085 .96557 L
s
.47015 .95785 m .46183 .95253 L .46621 .95467 L 0 .328 .04 r
F
0 g
.46621 .95467 m
.46897 .95485 L
s
.72094 .88273 m .7297 .88251 L .73528 .88035 L 0 1 .288 r
F
.72094 .88273 m .72356 .88353 L .7297 .88251 L F
0 g
.72678 .88513 m
.7297 .88251 L
s
.83102 .96487 m .83924 .95218 L .83465 .95504 L 0 1 .46 r
F
.81957 .97259 m .83102 .96487 L .82776 .95953 L 0 1 .449 r
F
.37522 .77429 m .36814 .77265 L .37151 .77324 L 0 0 0 r
F
.37522 .77429 m .36686 .77306 L .36814 .77265 L F
.37522 .77429 m .36852 .77421 L .36686 .77306 L F
0 g
.3715 .77322 m
.37151 .77323 L
s
.37056 .77179 m
.3715 .77322 L
s
.37522 .77429 m .37223 .77527 L .36852 .77421 L 0 0 0 r
F
.37522 .77429 m .37552 .77553 L .37223 .77527 L F
.37522 .77429 m .3768 .77511 L .37552 .77553 L F
0 g
.37522 .77429 m
.37655 .77422 L
s
.37151 .77324 m
.37522 .77429 L
s
.51872 .97417 m .51916 .97362 L .5214 .98392 L 0 .511 .15 r
F
0 g
.51758 .96566 m
.51916 .97362 L
s
.52671 .9996 m
.52698 1.00083 L
s
.52646 .99847 m
.52671 .9996 L
s
.52622 .9974 m
.52646 .99847 L
s
.52603 .99653 m
.52622 .9974 L
s
.52584 .99563 m
.52603 .99653 L
s
.41755 .78782 m .40869 .78469 L .4116 .78546 L 0 0 0 r
F
0 g
.4116 .78546 m
.41755 .78782 L
s
.41606 .78659 m
.41755 .78782 L
s
.41755 .78782 m
.41756 .78782 L
s
.41035 .78443 m
.4116 .78546 L
s
.60443 .61153 m .62246 .60852 L .62461 .60619 L 0 1 .5 r
F
.60443 .61153 m .61383 .61081 L .62246 .60852 L F
0 g
.62246 .60852 m
.62751 .61011 L
s
.61383 .61081 m
.61926 .61202 L
s
.61383 .61081 m
.62246 .60852 L
s
.70638 .66971 m .71534 .67254 L .70644 .65442 L 0 .454 .337 r
F
0 g
.70193 .65974 m
.70638 .66971 L
s
.70392 .65772 m
.70638 .66971 L
s
.24519 .9221 m .23476 .91747 L .23354 .91913 L 0 .583 .252 r
F
.24519 .9221 m .23917 .91728 L .23476 .91747 L F
.24519 .9221 m .24381 .9187 L .23917 .91728 L F
.24519 .9221 m .24639 .92077 L .24381 .9187 L F
.25684 .92513 m .24639 .92077 L .24519 .9221 L 0 .553 .244 r
F
0 g
.2408 .92228 m
.24519 .9221 L
s
.24519 .9221 m
.2478 .92393 L
s
.25684 .92513 m .25076 .92085 L .24639 .92077 L 0 .553 .244 r
F
.25684 .92513 m .2554 .9223 L .25076 .92085 L F
.25684 .92513 m .258 .92413 L .2554 .9223 L F
.26849 .92822 m .258 .92413 L .25684 .92513 L 0 .518 .234 r
F
0 g
.25247 .92504 m
.25684 .92513 L
s
.25684 .92513 m
.25948 .92673 L
s
.23354 .91913 m .22314 .91419 L .22188 .9162 L 0 .607 .278 r
F
.23354 .91913 m .22756 .91374 L .22314 .91419 L F
.23354 .91913 m .23221 .91515 L .22756 .91374 L F
.23354 .91913 m .23476 .91747 L .23221 .91515 L F
0 g
.22912 .91957 m
.23354 .91913 L
s
.23354 .91913 m
.23613 .92119 L
s
.68765 .59213 m
.69576 .59203 L
s
.26849 .92822 m .26236 .92448 L .258 .92413 L 0 .518 .234 r
F
.26849 .92822 m .26699 .92595 L .26236 .92448 L F
.26849 .92822 m .26962 .92755 L .26699 .92595 L F
.28013 .9314 m .26962 .92755 L .26849 .92822 L 0 .474 .222 r
F
0 g
.26415 .92787 m
.26849 .92822 L
s
.26849 .92822 m
.27115 .9296 L
s
.53929 1.12008 m .54357 1.1242 L .54469 1.12854 L 0 .449 0 r
F
.53714 .98974 m .54562 1.01054 L .54076 .99848 L 0 0 .125 r
F
0 g
.53714 .98974 m
.5376 .99085 L
s
.5348 .98506 m
.53714 .98974 L
s
.53816 .9925 m
.5382 .99259 L
s
.53788 .99181 m
.53816 .9925 L
s
.53748 .99085 m
.53788 .99181 L
s
.22188 .9162 m .21151 .91095 L .21023 .9133 L 0 .647 .307 r
F
.22188 .9162 m .21596 .91023 L .21151 .91095 L F
.22188 .9162 m .2206 .91163 L .21596 .91023 L F
.22188 .9162 m .22314 .91419 L .2206 .91163 L F
0 g
.21744 .9169 m
.22188 .9162 L
s
.22188 .9162 m
.22445 .9185 L
s
.72094 .88273 m .73528 .88035 L .73739 .87774 L 0 1 .288 r
F
0 g
.72356 .88353 m
.7297 .88251 L
s
.73528 .88035 m
.7408 .88007 L
s
.53023 .94513 m
.53115 .94063 L
s
.64953 .54986 m .64533 .54248 L .64309 .5414 L 0 .29 .271 r
F
0 g
.6426 .54103 m
.64309 .5414 L
s
.64953 .54986 m .65547 .55254 L .64533 .54248 L 0 .29 .271 r
F
.64953 .54986 m .66675 .56488 L .65547 .55254 L F
.64953 .54986 m .67319 .57335 L .66675 .56488 L F
.64953 .54986 m .67049 .57228 L .67319 .57335 L F
0 g
.66645 .57029 m
.66772 .57198 L
s
.64953 .54986 m .66035 .56221 L .67049 .57228 L 0 .29 .271 r
F
0 g
.66035 .56221 m
.66645 .57029 L
s
.64103 .5408 m
.64953 .54986 L
s
.64309 .5414 m
.64953 .54986 L
s
.28013 .9314 m .27394 .92817 L .26962 .92755 L 0 .474 .222 r
F
.28013 .9314 m .27858 .92967 L .27394 .92817 L F
.28013 .9314 m .28123 .93106 L .27858 .92967 L F
0 g
.27582 .93077 m
.28013 .9314 L
s
.21023 .9133 m .19987 .90773 L .19857 .91044 L 0 .712 .334 r
F
.21023 .9133 m .20434 .90674 L .19987 .90773 L F
.21023 .9133 m .20899 .90813 L .20434 .90674 L F
.21023 .9133 m .21151 .91095 L .20899 .90813 L F
0 g
.20577 .91428 m
.21023 .9133 L
s
.21023 .9133 m
.21277 .91585 L
s
.53391 .97145 m
.53409 .97211 L
s
.66623 .84101 m
.66643 .85179 L
s
.34726 .88689 m .33947 .87994 L .33687 .88256 L 0 1 .505 r
F
.34726 .88689 m .34448 .87946 L .33947 .87994 L F
.34726 .88689 m .34853 .88144 L .34448 .87946 L F
.34726 .88689 m .34972 .88462 L .34853 .88144 L F
0 g
.34546 .88706 m
.34726 .88689 L
s
.34726 .88689 m
.34857 .8899 L
s
.53169 .96593 m
.53291 .968 L
s
.53114 .96499 m
.53169 .96593 L
s
.53099 .96473 m
.53114 .96499 L
s
.53096 .96468 m
.53099 .96473 L
s
.55945 .63299 m
.56539 .63357 L
s
.51948 1.03283 m .5194 1.04592 L .52119 1.05696 L 0 .106 .194 r
F
0 g
.66294 .91291 m
.66305 .91305 L
s
.19857 .91044 m .18824 .90454 L .18691 .9076 L 0 .776 .36 r
F
.19857 .91044 m .19273 .90327 L .18824 .90454 L F
0 g
.18691 .9076 m
.18942 .91066 L
s
.19857 .91044 m .19738 .90465 L .19273 .90327 L 0 .776 .36 r
F
.19857 .91044 m .19987 .90773 L .19738 .90465 L F
0 g
.19409 .91168 m
.19857 .91044 L
s
.19857 .91044 m
.2011 .91323 L
s
.5225 1.00557 m .52218 1.0055 L .52459 1.0229 L 0 .233 .237 r
F
0 g
.52218 1.0055 m
.52218 1.0055 L
s
.52218 1.0055 m
.52219 1.00559 L
s
.52216 1.00543 m
.52218 1.0055 L
s
.32467 .66639 m .31251 .66693 L .31605 .66785 L 0 1 .534 r
F
.51872 .97417 m .5221 1.00012 L .51998 .98549 L 0 .511 .15 r
F
0 g
.51979 .97266 m
.5199 .97343 L
s
.52127 .97339 m
.52139 .97407 L
s
.52042 .97278 m
.52062 .97351 L
s
.51872 .97417 m .52437 1.01055 L .5221 1.00012 L 0 .511 .15 r
F
.52386 1.00426 m .52362 1.00476 L .52656 1.0243 L 0 .231 .232 r
F
.52386 1.00426 m .53177 1.05003 L .52734 1.02359 L F
.52386 1.00426 m .53475 1.06981 L .53177 1.05003 L F
.52386 1.00426 m .53426 1.06959 L .53475 1.06981 L F
.52386 1.00426 m .53075 1.05002 L .53426 1.06959 L F
.52386 1.00426 m .52656 1.0243 L .53075 1.05002 L F
.52437 1.00249 m .52418 1.00329 L .52734 1.02359 L 0 .228 .23 r
F
.51872 .97417 m .52525 1.00974 L .52437 1.01055 L 0 .511 .15 r
F
.52437 1.00249 m .53258 1.04854 L .52796 1.02181 L 0 .228 .23 r
F
.52437 1.00249 m .53578 1.0691 L .53258 1.04854 L F
.52437 1.00249 m .5354 1.0696 L .53578 1.0691 L F
.52437 1.00249 m .53177 1.05003 L .5354 1.0696 L F
.52437 1.00249 m .52734 1.02359 L .53177 1.05003 L F
.51872 .97417 m .52397 .99829 L .52525 1.00974 L 0 .511 .15 r
F
0 g
.52234 1.00452 m
.52249 1.00554 L
s
.52225 1.00605 m
.52228 1.00623 L
s
.52221 1.00576 m
.52225 1.00605 L
s
.5222 1.00566 m
.52221 1.00576 L
s
.52219 1.00559 m
.5222 1.00566 L
s
.52407 .99866 m
.52462 1.00106 L
s
.51872 .97417 m .5214 .98392 L .52397 .99829 L 0 .511 .15 r
F
0 g
.51681 .96663 m
.51872 .97417 L
s
.52062 .97351 m
.52102 .97507 L
s
.52102 .97507 m
.52121 .97579 L
s
.43743 .70155 m
.44401 .70181 L
s
.47015 .95785 m .45937 .95248 L .46183 .95253 L 0 .328 .04 r
F
0 g
.4579 .94956 m
.46183 .95253 L
s
.30384 .77226 m .29251 .77573 L .2967 .77627 L 0 1 .496 r
F
0 g
.29652 .78153 m
.2967 .77627 L
s
.4816 .96317 m
.48522 .96452 L
s
.51975 1.05268 m .52171 1.06627 L .52078 1.05908 L 0 0 .148 r
F
0 g
.5194 1.04592 m
.51975 1.05268 L
s
.52171 1.06627 m
.52194 1.07041 L
s
.52265 1.06133 m .52171 1.06628 L .52386 1.07584 L 0 0 .143 r
F
.52265 1.06133 m .52079 1.05908 L .52171 1.06628 L F
0 g
.53462 .97428 m
.53468 .97448 L
s
.54767 1.01106 m
.54876 1.01258 L
s
.54751 1.01085 m
.54767 1.01106 L
s
.31929 .76564 m
.3268 .76007 L
s
.31603 .875 m .30648 .87509 L .3107 .87638 L 0 1 .526 r
F
0 g
.3107 .87638 m
.31236 .8796 L
s
.73462 .87639 m .74288 .87741 L .74742 .87563 L 0 1 .351 r
F
.73462 .87639 m .7374 .87773 L .74288 .87741 L F
0 g
.7408 .88007 m
.74288 .87741 L
s
.7374 .87773 m
.74288 .87741 L
s
.35706 .67495 m
.3578 .67418 L
s
.35704 .67497 m
.35706 .67495 L
s
.35667 .67536 m
.35704 .67497 L
s
.63651 .70458 m
.64352 .7124 L
s
.51975 1.05268 m
.51977 1.05278 L
s
.51977 1.05278 m
.52078 1.05908 L
s
.53538 .92078 m .53716 .92695 L .54037 .92406 L 0 .555 .291 r
F
0 g
.53249 .92132 m
.53538 .92078 L
s
.53538 .92078 m
.53559 .90896 L
s
.5225 1.00557 m .52953 1.04871 L .52564 1.02404 L 0 .233 .237 r
F
0 g
.52076 1.00439 m
.5208 1.00463 L
s
.5225 1.00557 m .53197 1.06631 L .52953 1.04871 L 0 .233 .237 r
F
.5225 1.00557 m .53132 1.06495 L .53197 1.06631 L F
.5225 1.00557 m .52814 1.04631 L .53132 1.06495 L F
.5225 1.00557 m .52459 1.0229 L .52814 1.04631 L F
0 g
.5225 1.00557 m
.52253 1.00575 L
s
.52253 1.00575 m
.52254 1.00579 L
s
.52254 1.00579 m
.52254 1.00582 L
s
.52254 1.00582 m
.52255 1.00586 L
s
.52255 1.00586 m
.52255 1.00589 L
s
.52255 1.00589 m
.52261 1.00623 L
s
.52261 1.00623 m
.52266 1.00649 L
s
.52249 1.00554 m
.5225 1.00557 L
s
.35667 .67557 m
.35706 .67495 L
s
.35706 .67495 m
.35779 .67379 L
s
.35779 .67379 m
.3593 .6714 L
s
.32768 .75439 m
.32769 .75434 L
s
.3268 .76007 m
.32768 .75439 L
s
.4979 .96976 m
.49806 .96969 L
s
.4974 .97049 m
.49806 .96969 L
s
.38794 .65508 m .37684 .6574 L .3796 .65822 L 0 1 .489 r
F
0 g
.37582 .66419 m
.3796 .65822 L
s
.38794 .65508 m .38136 .65286 L .37684 .6574 L 0 1 .489 r
F
.38794 .65508 m .39015 .64764 L .38136 .65286 L F
.38794 .65508 m .39851 .6445 L .39015 .64764 L F
.38794 .65508 m .40084 .64553 L .39851 .6445 L F
.38794 .65508 m .3963 .65007 L .40084 .64553 L F
0 g
.3796 .65822 m
.38794 .65508 L
s
.51022 .97339 m .50751 .98879 L .50885 .97976 L 0 .452 .121 r
F
0 g
.509 .97209 m
.50903 .972 L
s
.50777 .97065 m
.5078 .97058 L
s
.50828 .97139 m
.50831 .97121 L
s
.51022 .97339 m .50724 .99682 L .50751 .98879 L 0 .452 .121 r
F
.51022 .97339 m .50822 .99847 L .50724 .99682 L F
0 g
.50584 .97496 m
.50777 .97065 L
s
.51022 .97339 m .50959 .99203 L .50822 .99847 L 0 .452 .121 r
F
0 g
.50732 .97745 m
.50828 .97139 L
s
.50732 .97745 m
.509 .97209 L
s
.50885 .97976 m
.5095 .97259 L
s
.51022 .97339 m .51044 .98185 L .50959 .99203 L 0 .452 .121 r
F
.51022 .97339 m .51071 .97389 L .51044 .98185 L F
0 g
.51022 .97339 m
.51085 .96556 L
s
.51021 .97342 m
.51022 .97339 L
s
.51071 .97389 m
.5117 .96639 L
s
.73462 .87639 m .74742 .87563 L .74866 .87293 L 0 1 .351 r
F
0 g
.74742 .87563 m
.75222 .87595 L
s
.20514 .85729 m .19648 .84914 L .19362 .85454 L 0 1 .525 r
F
0 g
.19362 .85454 m
.19496 .85934 L
s
.20514 .85729 m .20205 .84604 L .19648 .84914 L 0 1 .525 r
F
.20514 .85729 m .20661 .84735 L .20205 .84604 L F
.20514 .85729 m .20793 .85218 L .20661 .84735 L F
0 g
.19959 .86035 m
.20514 .85729 L
s
.20514 .85729 m
.20654 .86187 L
s
.52265 1.06133 m .52119 1.05696 L .52079 1.05908 L 0 0 .143 r
F
0 g
.66666 .89148 m
.66669 .89152 L
s
.66737 .8924 m
.66861 .894 L
s
.66403 .8875 m
.66403 .8875 L
s
.79672 .99079 m .79659 1.00046 L .79991 1.00491 L 0 1 .42 r
F
0 g
.79542 1.01348 m
.79991 1.00491 L
s
.54849 .64262 m .54316 .63896 L .54253 .64205 L 0 1 .504 r
F
0 g
.66861 .894 m
.66884 .89334 L
s
.74986 .82764 m
.75003 .82995 L
s
.75013 .83118 m
.75054 .83667 L
s
.5517 1.14418 m .54848 1.13595 L .54746 1.12997 L 0 .538 .048 r
F
0 g
.54357 1.1242 m
.54746 1.12997 L
s
.40472 .64699 m
.40923 .64354 L
s
.3963 .65007 m
.40472 .64699 L
s
.52605 .65703 m .52011 .65316 L .51996 .65653 L 0 1 .5 r
F
.52605 .65703 m .52678 .64875 L .52011 .65316 L F
.52605 .65703 m .53552 .64624 L .52678 .64875 L F
.52605 .65703 m .54159 .64676 L .53552 .64624 L F
0 g
.51973 .66168 m
.52605 .65703 L
s
.54159 .64676 m
.54849 .64262 L
s
.51758 .97525 m .51804 .97487 L .51998 .98549 L 0 .508 .149 r
F
0 g
.51916 .97362 m
.51952 .97529 L
s
.51681 .96663 m
.51804 .97487 L
s
.5369 .98824 m .53703 .98895 L .54076 .99848 L 0 0 .127 r
F
0 g
.5376 .99085 m
.53794 .99168 L
s
.53478 .98482 m
.53703 .98895 L
s
.34002 .73091 m .338 .70532 L .33376 .70606 L 0 1 .282 r
F
.53194 .96815 m .53796 .97538 L .53425 .97028 L 0 .08 .188 r
F
0 g
.53224 .97415 m
.53237 .97438 L
s
.53194 .96815 m .54144 .98264 L .53796 .97538 L 0 .08 .188 r
F
.53194 .96815 m .54237 .98722 L .54144 .98264 L F
.53194 .96815 m .54004 .98506 L .54237 .98722 L F
.53194 .96815 m .53601 .97763 L .54004 .98506 L F
0 g
.53335 .97822 m
.53378 .97904 L
s
.53194 .96815 m .53255 .9704 L .53601 .97763 L 0 .08 .188 r
F
0 g
.5325 .97212 m
.53264 .97235 L
s
.53213 .97488 m
.53244 .97573 L
s
.53237 .97438 m
.53398 .97728 L
s
.53289 .97434 m
.53325 .97479 L
s
.53325 .97479 m
.53369 .97535 L
s
.53304 .97301 m
.5333 .97344 L
s
.53264 .97235 m
.53304 .97301 L
s
.53183 .968 m
.53194 .96815 L
s
.53227 .97014 m
.53255 .9704 L
s
.53098 .96889 m
.53227 .97014 L
s
.53291 .968 m
.53425 .97028 L
s
.53298 .96912 m
.53425 .97028 L
s
.53274 .96889 m
.53298 .96912 L
s
.53194 .96815 m
.53274 .96889 L
s
.53291 .97701 m
.53394 .97853 L
s
.53245 .97576 m
.5326 .97616 L
s
.53244 .97573 m
.53245 .97576 L
s
.5326 .97616 m
.53263 .97626 L
s
.53263 .97626 m
.53293 .97707 L
s
.53968 .88021 m .54067 .91458 L .53891 .89282 L 0 .852 .155 r
F
0 g
.53613 .87667 m
.53891 .89282 L
s
.53974 .93711 m .54289 .91404 L .54037 .92406 L 0 .475 .283 r
F
.53974 .93711 m .54635 .91413 L .54289 .91404 L F
.53974 .93711 m .54845 .92428 L .54635 .91413 L F
.53974 .93711 m .54782 .93735 L .54845 .92428 L F
.53968 .88021 m .5445 .94106 L .54067 .91458 L 0 .852 .155 r
F
.53968 .88021 m .54783 .95447 L .5445 .94106 L F
0 g
.54296 .91009 m
.54311 .90095 L
s
.53968 .88021 m .54858 .94152 L .54783 .95447 L 0 .852 .155 r
F
.54635 .91413 m .54845 .92428 L .55219 .91935 L 0 .645 .274 r
F
.53968 .88021 m .54627 .91111 L .54858 .94152 L 0 .852 .155 r
F
0 g
.54637 .91252 m
.54663 .89376 L
s
.53968 .88021 m .54246 .88497 L .54627 .91111 L 0 .852 .155 r
F
0 g
.53886 .87503 m
.53968 .88021 L
s
.53891 .89282 m
.53968 .88021 L
s
.54246 .88497 m
.54285 .86591 L
s
.6332 .60452 m .62998 .60035 L .62783 .60269 L 0 1 .489 r
F
.6332 .60452 m .63891 .5989 L .62998 .60035 L F
.6332 .60452 m .64864 .59931 L .63891 .5989 L F
.51948 1.03283 m .52269 1.05572 L .52127 1.04386 L 0 .106 .194 r
F
.51948 1.03283 m .52265 1.06133 L .52269 1.05572 L F
.51948 1.03283 m .52119 1.05696 L .52265 1.06133 L F
0 g
.52079 1.05908 m
.52119 1.05696 L
s
.52109 1.05638 m
.52119 1.05696 L
s
.52045 1.03882 m
.52108 1.04266 L
s
.51995 1.03574 m
.52045 1.03882 L
s
.51992 1.03554 m
.51995 1.03574 L
s
.51964 1.03381 m
.51992 1.03554 L
s
.51957 1.03339 m
.51964 1.03381 L
s
.51949 1.0329 m
.51957 1.03339 L
s
.51948 1.03283 m
.51949 1.0329 L
s
.5194 1.04592 m
.52091 1.05526 L
s
.52091 1.05526 m
.52099 1.0557 L
s
.52099 1.0557 m
.52109 1.05638 L
s
.51947 1.03235 m
.51948 1.03283 L
s
.52011 1.03074 m
.52071 1.03538 L
s
.52086 1.0366 m
.52087 1.03661 L
s
.52071 1.03538 m
.52086 1.0366 L
s
.52087 1.03661 m
.52088 1.03672 L
s
.52088 1.03672 m
.52088 1.03676 L
s
.52088 1.03676 m
.52089 1.0368 L
s
.52324 1.00528 m .52295 1.00548 L .52564 1.02404 L 0 .232 .235 r
F
0 g
.52295 1.00548 m
.52301 1.00585 L
s
.52305 1.00616 m
.52307 1.00625 L
s
.52307 1.00625 m
.52308 1.00632 L
s
.52308 1.00632 m
.52308 1.00634 L
s
.52308 1.00634 m
.52308 1.00634 L
s
.52308 1.00634 m
.52314 1.00678 L
s
.52232 1.00195 m
.52295 1.00548 L
s
.41446 .70094 m
.42135 .70103 L
s
.29086 .69761 m .28874 .6847 L .28137 .69117 L 0 1 .515 r
F
.29086 .69761 m .29699 .68177 L .28874 .6847 L F
.29086 .69761 m .30059 .68436 L .29699 .68177 L F
.29086 .69761 m .29795 .69115 L .30059 .68436 L F
0 g
.28845 .70459 m
.29086 .69761 L
s
.28264 .70051 m
.29086 .69761 L
s
.31603 .875 m .30557 .87167 L .30648 .87509 L 0 1 .526 r
F
0 g
.30175 .87655 m
.30648 .87509 L
s
.36784 .67965 m .36845 .66951 L .36038 .67146 L 0 1 .516 r
F
.36784 .67965 m .37654 .67054 L .36845 .66951 L F
.36784 .67965 m .37926 .67388 L .37654 .67054 L F
.36784 .67965 m .37552 .67778 L .37926 .67388 L F
0 g
.35977 .67861 m
.36784 .67965 L
s
.54708 1.01079 m
.54724 1.01108 L
s
.54475 1.00647 m
.54506 1.00704 L
s
.63891 .5989 m .65786 .59808 L .66046 .59603 L 0 1 .501 r
F
.63891 .5989 m .64864 .59931 L .65786 .59808 L F
0 g
.65786 .59808 m
.66269 .60036 L
s
.64864 .59931 m
.65786 .59808 L
s
.64864 .59931 m
.65397 .60115 L
s
.34409 .53763 m .33075 .54108 L .33354 .54227 L 0 1 .488 r
F
0 g
.3278 .54951 m
.33354 .54227 L
s
.34409 .53763 m .33741 .53474 L .33075 .54108 L 0 1 .488 r
F
.34409 .53763 m .34911 .52747 L .33741 .53474 L F
.34409 .53763 m .35968 .52282 L .34911 .52747 L F
.34409 .53763 m .36205 .52388 L .35968 .52282 L F
.34409 .53763 m .35536 .53023 L .36205 .52388 L F
0 g
.33773 .54398 m
.34409 .53763 L
s
.33354 .54227 m
.34409 .53763 L
s
.74576 .87109 m .75424 .87297 L .75879 .8712 L 0 1 .399 r
F
.74576 .87109 m .74866 .87293 L .75424 .87297 L F
0 g
.75222 .87595 m
.75424 .87297 L
s
.45937 .95248 m .45089 .94639 L .45526 .94898 L 0 .267 0 r
F
0 g
.45526 .94898 m
.4579 .94956 L
s
.47522 .6303 m
.48148 .62941 L
s
.47015 .95785 m .46047 .95455 L .45937 .95248 L 0 .328 .04 r
F
.47015 .95785 m .46442 .95773 L .46047 .95455 L F
.47015 .95785 m .46858 .9599 L .46442 .95773 L F
.47015 .95785 m .47104 .95995 L .46858 .9599 L F
0 g
.47015 .95785 m
.47278 .95733 L
s
.46621 .95467 m
.47015 .95785 L
s
.52897 1.0945 m .53325 1.1049 L .53185 1.10169 L 0 0 .084 r
F
.53497 1.11112 m .53325 1.1049 L .53643 1.11277 L 0 .404 0 r
F
.53497 1.11112 m .53185 1.10169 L .53325 1.1049 L F
.7001 .80842 m .7046 .77961 L .69959 .77807 L 0 .575 .28 r
F
0 g
.69959 .77807 m
.7001 .80842 L
s
.6976 .77125 m
.69959 .77807 L
s
.70009 .8084 m
.7001 .80842 L
s
.6952 .78549 m
.70009 .8084 L
s
.51758 .97525 m .52013 1.00082 L .51847 .98633 L 0 .508 .149 r
F
0 g
.51872 .97417 m
.51878 .97468 L
s
.5199 .97343 m
.52004 .97443 L
s
.51758 .97525 m .52208 1.01157 L .52013 1.00082 L 0 .508 .149 r
F
.51758 .97525 m .52301 1.01133 L .52208 1.01157 L F
.51758 .97525 m .5221 1.00012 L .52301 1.01133 L F
0 g
.52301 1.00585 m
.52305 1.00616 L
s
.5208 1.00463 m
.52255 1.01562 L
s
.51982 1.00324 m
.52156 1.01476 L
s
.52036 1.00384 m
.52178 1.01564 L
s
.51758 .97525 m .51998 .98549 L .5221 1.00012 L 0 .508 .149 r
F
0 g
.52139 .97407 m
.52217 .97845 L
s
.52217 .97845 m
.52273 .98159 L
s
.52121 .97579 m
.52172 .9777 L
s
.52172 .9777 m
.52273 .98159 L
s
.52172 .97154 m
.52396 .97851 L
s
.52201 .96971 m
.52396 .97851 L
s
.51601 .96728 m
.51758 .97525 L
s
.51878 .97468 m
.51887 .9755 L
s
.51887 .9755 m
.51895 .97622 L
s
.52004 .97443 m
.5203 .97619 L
s
.48624 .6804 m .49403 .67738 L .49963 .67241 L 0 1 .488 r
F
0 g
.49403 .67738 m
.49751 .67429 L
s
.49403 .67738 m
.50011 .67797 L
s
.33687 .88256 m .3292 .8757 L .32646 .87861 L 0 1 .517 r
F
.33687 .88256 m .33432 .87485 L .3292 .8757 L F
.33687 .88256 m .33839 .87663 L .33432 .87485 L F
.33687 .88256 m .33947 .87994 L .33839 .87663 L F
0 g
.33176 .88341 m
.33687 .88256 L
s
.33687 .88256 m
.33807 .88574 L
s
.52324 1.00528 m .53075 1.05002 L .52656 1.0243 L 0 .232 .235 r
F
.52324 1.00528 m .53347 1.06879 L .53075 1.05002 L F
.52324 1.00528 m .5329 1.06795 L .53347 1.06879 L F
.52324 1.00528 m .52953 1.04871 L .5329 1.06795 L F
.52324 1.00528 m .52564 1.02404 L .52953 1.04871 L F
0 g
.52329 1.00557 m
.52331 1.00569 L
s
.52331 1.00569 m
.52331 1.00573 L
s
.52331 1.00573 m
.52335 1.00595 L
s
.52335 1.00595 m
.5234 1.0062 L
s
.5234 1.0062 m
.52341 1.00627 L
s
.52341 1.00627 m
.52343 1.00639 L
s
.52579 1.01987 m
.52635 1.02306 L
s
.52457 1.01292 m
.52579 1.01987 L
s
.52343 1.00639 m
.5235 1.00679 L
s
.5235 1.00679 m
.52457 1.01292 L
s
.52656 1.02427 m
.52656 1.0243 L
s
.52635 1.02306 m
.52656 1.02427 L
s
.52266 1.00649 m
.52369 1.01257 L
s
.52299 1.01134 m
.52442 1.02171 L
s
.52217 1.01155 m
.52331 1.02027 L
s
.52269 1.01142 m
.52418 1.02043 L
s
.52759 1.01394 m
.52842 1.01886 L
s
.52693 1.00996 m
.52759 1.01394 L
s
.52659 1.00796 m
.52693 1.00996 L
s
.52476 1.01884 m
.52534 1.02224 L
s
.52369 1.01257 m
.52476 1.01884 L
s
.52545 1.0229 m
.52564 1.02404 L
s
.52534 1.02224 m
.52545 1.0229 L
s
.52418 1.02043 m
.52459 1.0229 L
s
.52255 1.01562 m
.52326 1.02009 L
s
.52326 1.02009 m
.52341 1.02101 L
s
.52331 1.02027 m
.52341 1.02101 L
s
.52442 1.02171 m
.52459 1.0229 L
s
.52542 1.0225 m
.52546 1.02274 L
s
.52546 1.02274 m
.52564 1.02404 L
s
.52314 1.00678 m
.52389 1.01194 L
s
.52389 1.01194 m
.52481 1.01827 L
s
.52481 1.01827 m
.52542 1.0225 L
s
.52714 1.00701 m
.52759 1.00919 L
s
.52759 1.00919 m
.52845 1.01344 L
s
.52845 1.01344 m
.52856 1.01399 L
s
.52856 1.01399 m
.52871 1.01467 L
s
.52779 1.0037 m
.52882 1.00922 L
s
.52761 1.00369 m
.52823 1.00652 L
s
.52732 1.0068 m
.52838 1.01281 L
s
.52731 1.00672 m
.52732 1.0068 L
s
.52838 1.01281 m
.52849 1.01344 L
s
.52849 1.01344 m
.52871 1.01467 L
s
.52823 1.00652 m
.52882 1.00922 L
s
.39005 .7787 m .38212 .77724 L .38043 .77616 L 0 0 0 r
F
.39005 .7787 m .38767 .77927 L .38212 .77724 L F
.39005 .7787 m .39404 .78124 L .38767 .77927 L F
.39005 .7787 m .39698 .78183 L .39404 .78124 L F
.39005 .7787 m .39526 .78074 L .39698 .78183 L F
0 g
.38859 .77771 m
.39005 .7787 L
s
.3837 .77675 m
.39005 .7787 L
s
.53296 .97127 m
.53349 .97238 L
s
.53277 .97087 m
.53296 .97127 L
s
.53272 .97076 m
.53277 .97087 L
s
.53255 .9704 m
.53272 .97076 L
s
.74576 .87109 m .75879 .8712 L .75993 .86812 L 0 1 .399 r
F
0 g
.75879 .8712 m
.76364 .87186 L
s
.28137 .69117 m .26904 .69189 L .27294 .69424 L 0 1 .522 r
F
0 g
.27116 .7003 m
.27294 .69424 L
s
.5369 .98824 m .5452 1.00914 L .54039 .99688 L 0 0 .127 r
F
.5369 .98824 m .54076 .99848 L .54562 1.01054 L F
0 g
.53703 .98895 m
.53745 .99002 L
s
.53808 .99202 m
.53824 .99239 L
s
.53794 .99168 m
.53808 .99202 L
s
.5351 .98466 m
.5369 .98824 L
s
.54506 1.00704 m
.54708 1.01079 L
s
.54475 1.00647 m
.54522 1.00748 L
s
.41755 .78782 m .41054 .78571 L .40869 .78469 L 0 0 0 r
F
0 g
.40282 .78255 m
.40869 .78469 L
s
.41755 .78782 m .41595 .78786 L .41054 .78571 L 0 0 0 r
F
.41755 .78782 m .42193 .79024 L .41595 .78786 L F
.41755 .78782 m .42448 .79125 L .42193 .79024 L F
.41755 .78782 m .4226 .79022 L .42448 .79125 L F
0 g
.41755 .78782 m
.41755 .78782 L
s
.3768 .77511 m
.38043 .77616 L
s
.24884 .7799 m .23731 .78288 L .24171 .78387 L 0 1 .541 r
F
0 g
.24171 .78387 m
.24376 .78273 L
s
.24171 .78387 m
.24203 .78984 L
s
.4943 .96948 m .48703 .96935 L .49092 .96872 L 0 .449 .09 r
F
0 g
.49092 .96872 m
.49343 .96707 L
s
.4943 .96948 m .4848 .97151 L .48703 .96935 L 0 .449 .09 r
F
.4943 .96948 m .48572 .97377 L .4848 .97151 L F
.4943 .96948 m .48911 .97452 L .48572 .97377 L F
.4943 .96948 m .4927 .97328 L .48911 .97452 L F
.4943 .96948 m .49492 .97112 L .4927 .97328 L F
0 g
.4943 .96948 m
.49675 .9662 L
s
.49092 .96872 m
.4943 .96948 L
s
.49492 .97112 m
.4979 .96976 L
s
.66266 .7796 m
.663 .78048 L
s
.66415 .78345 m
.66715 .79122 L
s
.663 .78048 m
.66415 .78345 L
s
.66093 .76912 m
.66106 .76992 L
s
.66106 .76992 m
.66107 .77001 L
s
.66107 .77001 m
.66109 .77009 L
s
.66196 .77538 m
.66266 .7796 L
s
.66139 .77196 m
.66196 .77538 L
s
.66138 .77188 m
.66139 .77196 L
s
.6695 .59547 m .66698 .59088 L .66437 .59295 L 0 1 .494 r
F
.6695 .59547 m .67633 .59054 L .66698 .59088 L F
.51145 .97454 m .50959 .99203 L .51044 .98185 L 0 .461 .127 r
F
.51145 .97454 m .5097 1.00084 L .50959 .99203 L F
.51145 .97454 m .5107 1.00235 L .5097 1.00084 L F
0 g
.50885 .97976 m
.51021 .97342 L
s
.51145 .97454 m .51171 .99496 L .5107 1.00235 L 0 .461 .127 r
F
0 g
.51044 .98185 m
.51071 .97389 L
s
.51145 .97454 m .51206 .98365 L .51171 .99496 L 0 .461 .127 r
F
.51145 .97454 m .51194 .97492 L .51206 .98365 L F
0 g
.51194 .97492 m
.51257 .96706 L
s
.51145 .97454 m
.5117 .96647 L
s
.51044 .98185 m
.51145 .97454 L
s
.79672 .99079 m .80798 .99104 L .80814 .98118 L 0 1 .42 r
F
0 g
.80445 1.0012 m
.80798 .99104 L
s
.80798 .99104 m
.81127 .99593 L
s
.52601 1.00642 m
.52707 1.01187 L
s
.52707 1.01187 m
.52772 1.01524 L
s
.52772 1.01524 m
.52842 1.01886 L
s
.52588 1.00574 m
.52601 1.00642 L
s
.52586 1.00565 m
.52588 1.00574 L
s
.52576 1.00515 m
.52586 1.00565 L
s
.40754 .50778 m .3952 .51001 L .39709 .51081 L 0 1 .342 r
F
0 g
.38987 .5161 m
.39709 .51081 L
s
.40754 .50778 m .40317 .50587 L .3952 .51001 L 0 1 .342 r
F
.40754 .50778 m .41571 .50117 L .40317 .50587 L F
.40754 .50778 m .42618 .49814 L .41571 .50117 L F
.40754 .50778 m .42758 .49881 L .42618 .49814 L F
.40754 .50778 m .41959 .50294 L .42758 .49881 L F
0 g
.39993 .51189 m
.40754 .50778 L
s
.39709 .51081 m
.40754 .50778 L
s
.41959 .50294 m
.42968 .49967 L
s
.45937 .95248 m .44859 .94585 L .45089 .94639 L 0 .267 0 r
F
0 g
.44683 .94323 m
.45089 .94639 L
s
.52448 1.01044 m
.52472 1.01206 L
s
.52472 1.01206 m
.5258 1.01919 L
s
.5258 1.01919 m
.52656 1.02426 L
s
.52656 1.02426 m
.52656 1.0243 L
s
.49845 .97092 m
.49851 .97079 L
s
.52554 1.00681 m
.5257 1.00779 L
s
.5257 1.00779 m
.52612 1.0104 L
s
.52612 1.0104 m
.52667 1.01381 L
s
.52667 1.01381 m
.52796 1.02181 L
s
.52546 1.00628 m
.52554 1.00681 L
s
.52544 1.00619 m
.52546 1.00628 L
s
.52533 1.00547 m
.52544 1.00619 L
s
.5251 1.00404 m
.52533 1.00547 L
s
.52509 1.00401 m
.5251 1.00404 L
s
.52502 1.00354 m
.52509 1.00401 L
s
.52491 1.00287 m
.52502 1.00354 L
s
.52473 1.00176 m
.52491 1.00287 L
s
.52462 1.00106 m
.52473 1.00176 L
s
.55296 .89334 m .55616 .97099 L .55327 .92744 L 0 .881 .187 r
F
.55296 .89334 m .56063 1.01705 L .55616 .97099 L F
.55296 .89334 m .5598 .93558 L .5633 .99894 L F
0 g
.55912 .89605 m
.5598 .93558 L
s
.559 .90301 m
.55907 .89553 L
s
.55862 .90297 m
.559 .90301 L
s
.55697 .90282 m
.55784 .9029 L
s
.55784 .9029 m
.55862 .90297 L
s
.55657 .90278 m
.55697 .90282 L
s
.55093 .87971 m
.55296 .89334 L
s
.5164 .97589 m .51688 .97569 L .51847 .98633 L 0 .501 .146 r
F
0 g
.51804 .97487 m
.51821 .97577 L
s
.51821 .97577 m
.51824 .97596 L
s
.51601 .96729 m
.51688 .97569 L
s
.5249 1.01005 m
.52508 1.01105 L
s
.52508 1.01105 m
.52553 1.01352 L
s
.52553 1.01352 m
.52696 1.02146 L
s
.52696 1.02146 m
.52734 1.02359 L
s
.40143 .69489 m .39146 .69078 L .39397 .69462 L 0 1 .491 r
F
0 g
.39067 .70027 m
.39397 .69462 L
s
.66267 .84259 m .66614 .82595 L .6623 .82224 L 0 .475 .282 r
F
0 g
.6623 .82224 m
.6623 .82236 L
s
.6623 .82236 m
.66252 .83436 L
s
.66252 .83436 m
.66265 .84121 L
s
.66152 .81993 m
.6623 .82224 L
s
.30565 .66876 m .29747 .66825 L .30112 .66916 L 0 1 .531 r
F
.30565 .66876 m .29661 .66631 L .29747 .66825 L F
.30565 .66876 m .29911 .66464 L .29661 .66631 L F
.30565 .66876 m .30365 .66424 L .29911 .66464 L F
.30565 .66876 m .30719 .66538 L .30365 .66424 L F
.30565 .66876 m .30805 .66732 L .30719 .66538 L F
0 g
.30565 .66876 m
.30659 .67031 L
s
.30112 .66916 m
.30565 .66876 L
s
.37552 .77553 m
.3768 .77511 L
s
.52514 1.00662 m
.52563 1.00928 L
s
.52563 1.00928 m
.52612 1.01189 L
s
.52612 1.01189 m
.52671 1.01509 L
s
.52671 1.01509 m
.52796 1.02181 L
s
.52505 1.00614 m
.52514 1.00662 L
s
.52503 1.00606 m
.52505 1.00614 L
s
.52491 1.00541 m
.52503 1.00606 L
s
.52468 1.00414 m
.52491 1.00541 L
s
.52455 1.00345 m
.52468 1.00414 L
s
.52454 1.00342 m
.52455 1.00345 L
s
.52698 1.00083 m
.52761 1.00369 L
s
.52769 1.00315 m
.52779 1.0037 L
s
.52722 1.00068 m
.52769 1.00315 L
s
.52519 1.00979 m
.52521 1.0099 L
s
.52521 1.0099 m
.5256 1.0124 L
s
.5256 1.0124 m
.52692 1.02093 L
s
.52692 1.02093 m
.52734 1.02359 L
s
.7569 .86578 m .76561 .86856 L .77016 .86681 L 0 1 .436 r
F
.7569 .86578 m .75993 .86812 L .76561 .86856 L F
0 g
.76364 .87186 m
.76561 .86856 L
s
.25968 .78227 m .25398 .77359 L .24884 .7799 L 0 1 .54 r
F
.25968 .78227 m .26101 .76962 L .25398 .77359 L F
.25968 .78227 m .26521 .77064 L .26101 .76962 L F
.25968 .78227 m .26464 .77607 L .26521 .77064 L F
0 g
.25927 .78754 m
.25968 .78227 L
s
.25269 .78622 m
.25968 .78227 L
s
.44831 .69638 m .43979 .69229 L .44148 .69605 L 0 1 .483 r
F
.44831 .69638 m .44441 .687 L .43979 .69229 L F
0 g
.43969 .69849 m
.44148 .69605 L
s
.43743 .70155 m
.43969 .69849 L
s
.44831 .69638 m .45226 .68371 L .44441 .687 L 0 1 .483 r
F
.44831 .69638 m .45909 .68404 L .45226 .68371 L F
.44831 .69638 m .46034 .68777 L .45909 .68404 L F
.44831 .69638 m .45572 .69305 L .46034 .68777 L F
0 g
.44401 .70181 m
.44831 .69638 L
s
.44148 .69605 m
.44831 .69638 L
s
.45572 .69305 m
.46221 .69347 L
s
.75772 1.06234 m .76728 1.05079 L .76283 1.0557 L 0 .955 .188 r
F
.76162 1.04858 m .76728 1.05079 L .77158 1.04204 L 0 1 .279 r
F
.76162 1.04858 m .76283 1.0557 L .76728 1.05079 L F
0 g
.76728 1.05079 m
.76877 1.05063 L
s
.76728 1.05079 m
.7675 1.05035 L
s
.5164 .97589 m .51809 1.00052 L .51691 .9865 L 0 .501 .146 r
F
0 g
.51758 .97525 m
.51762 .97564 L
s
.5164 .97589 m .51969 1.01129 L .51809 1.00052 L 0 .501 .146 r
F
.5164 .97589 m .52066 1.01156 L .51969 1.01129 L F
.5164 .97589 m .52013 1.00082 L .52066 1.01156 L F
0 g
.52047 .97742 m
.5214 .98392 L
s
.52056 .98006 m
.5214 .98392 L
s
.5203 .97619 m
.52047 .97742 L
s
.5164 .97589 m .51847 .98633 L .52013 1.00082 L 0 .501 .146 r
F
0 g
.51895 .97622 m
.51895 .97627 L
s
.51895 .97627 m
.51998 .98549 L
s
.51952 .97529 m
.51964 .97583 L
s
.51964 .97583 m
.52056 .98006 L
s
.51824 .97596 m
.51842 .97694 L
s
.51842 .97694 m
.51998 .98549 L
s
.51517 .96764 m
.5164 .97589 L
s
.66093 .76912 m
.66119 .76961 L
s
.66119 .76961 m
.66122 .76967 L
s
.66283 .7727 m
.66456 .77595 L
s
.66178 .77073 m
.66283 .7727 L
s
.66176 .77069 m
.66178 .77073 L
s
.33158 .70995 m .32378 .70516 L .3273 .70956 L 0 1 .41 r
F
.33158 .70995 m .32283 .69972 L .32378 .70516 L F
0 g
.32525 .71729 m
.32706 .71047 L
s
.33158 .70995 m .32508 .69687 L .32283 .69972 L 0 1 .41 r
F
0 g
.32304 .70531 m
.32378 .70516 L
s
.31622 .70667 m
.32304 .70531 L
s
.33158 .70995 m .32936 .69726 L .32508 .69687 L 0 1 .41 r
F
0 g
.32706 .71047 m
.3273 .70957 L
s
.33158 .70995 m .33282 .70062 L .32936 .69726 L 0 1 .41 r
F
.33158 .70995 m .33376 .70606 L .33282 .70062 L F
.34002 .73091 m .33158 .70995 L .33244 .72091 L 0 1 .282 r
F
.34002 .73091 m .33376 .70606 L .33158 .70995 L F
0 g
.33066 .7201 m
.33238 .72099 L
s
.32525 .71729 m
.33066 .7201 L
s
.33238 .72099 m
.33243 .72101 L
s
.3273 .70956 m
.33158 .70995 L
s
.33376 .70606 m
.338 .70532 L
s
.5334 .9736 m .54004 .98506 L .53601 .97763 L 0 .006 .154 r
F
0 g
.53378 .97904 m
.53453 .98047 L
s
.5334 .9736 m .54366 .99368 L .54004 .98506 L 0 .006 .154 r
F
.5334 .9736 m .54446 .99773 L .54366 .99368 L F
.5334 .9736 m .54182 .99366 L .54446 .99773 L F
.5334 .9736 m .53752 .98421 L .54182 .99366 L F
0 g
.53403 .98079 m
.53504 .98246 L
s
.53443 .98198 m
.53491 .98293 L
s
.5334 .9736 m .53392 .97563 L .53752 .98421 L 0 .006 .154 r
F
0 g
.53453 .98047 m
.53505 .98146 L
s
.53459 .97951 m
.53484 .97988 L
s
.53394 .97853 m
.53459 .97951 L
s
.53444 .97811 m
.53454 .97828 L
s
.53398 .97728 m
.53444 .97811 L
s
.53369 .97535 m
.53392 .97563 L
s
.5333 .97344 m
.5334 .9736 L
s
.53515 .97583 m
.53539 .97667 L
s
.53496 .97544 m
.53527 .97649 L
s
.53349 .97238 m
.53601 .97763 L
s
.53432 .97503 m
.53601 .97763 L
s
.53397 .97449 m
.53432 .97503 L
s
.53384 .97429 m
.53397 .97449 L
s
.53368 .97405 m
.53384 .97429 L
s
.53357 .97387 m
.53368 .97405 L
s
.5334 .9736 m
.53357 .97387 L
s
.33282 .70062 m
.33376 .70606 L
s
.45891 .63249 m .44923 .63155 L .45092 .63274 L 0 1 .356 r
F
0 g
.44566 .63552 m
.45092 .63274 L
s
.45891 .63249 m .45516 .62952 L .44923 .63155 L 0 1 .356 r
F
.45891 .63249 m .46475 .62801 L .45516 .62952 L F
.45891 .63249 m .47275 .62776 L .46475 .62801 L F
.45891 .63249 m .47382 .62893 L .47275 .62776 L F
.45891 .63249 m .46788 .63096 L .47382 .62893 L F
0 g
.45092 .63274 m
.45891 .63249 L
s
.46788 .63096 m
.47522 .6303 L
s
.5364 .98586 m .53663 .98692 L .54039 .99688 L 0 0 .131 r
F
0 g
.5347 .98352 m
.53663 .98692 L
s
.53745 .99002 m
.53801 .99145 L
s
.48624 .6804 m .47901 .67622 L .4798 .67991 L 0 1 .488 r
F
.48624 .6804 m .48462 .67124 L .47901 .67622 L F
.48624 .6804 m .49288 .66829 L .48462 .67124 L F
.48624 .6804 m .49931 .66879 L .49288 .66829 L F
.48624 .6804 m .49963 .67241 L .49931 .66879 L F
0 g
.49751 .67429 m
.49963 .67241 L
s
.48098 .68556 m
.48624 .6804 L
s
.49963 .67241 m
.50575 .67293 L
s
.80006 .81234 m .80555 .81401 L .80108 .81534 L 0 0 0 r
F
.80006 .81234 m .81131 .80985 L .80555 .81401 L F
.51269 .9754 m .51171 .99496 L .51206 .98365 L 0 .471 .132 r
F
.51269 .9754 m .51221 1.00447 L .51171 .99496 L F
0 g
.51194 .97492 m
.51206 .98365 L
s
.51269 .9754 m .51322 1.00578 L .51221 1.00447 L 0 .471 .132 r
F
.51269 .9754 m .51385 .99744 L .51322 1.00578 L F
0 g
.51334 .97087 m
.51344 .96751 L
s
.51344 .96751 m
.51355 .96934 L
s
.51269 .9754 m .51369 .98507 L .51385 .99744 L 0 .471 .132 r
F
.51269 .9754 m .51319 .97566 L .51369 .98507 L F
0 g
.51319 .97566 m
.51334 .97087 L
s
.51257 .96706 m
.51269 .9754 L
s
.51206 .98365 m
.51269 .9754 L
s
.51355 .96934 m
.51394 .97588 L
s
.63416 .86471 m .63859 .85593 L .63524 .88423 L 0 .283 .182 r
F
0 g
.63416 .86471 m
.63524 .88423 L
s
.63859 .85593 m
.64191 .825 L
s
.6322 .89998 m
.63416 .86471 L
s
.63037 .93276 m
.6322 .89998 L
s
.44859 .94585 m .43994 .93943 L .44432 .94229 L 0 .164 0 r
F
0 g
.44432 .94229 m
.44683 .94323 L
s
.7569 .86578 m .77016 .86681 L .77121 .86337 L 0 1 .436 r
F
0 g
.77016 .86681 m
.77507 .86781 L
s
.34082 .66769 m
.34888 .66854 L
s
.72707 1.09763 m .73875 1.08603 L .73341 1.09278 L 0 0 0 r
F
.73312 1.0952 m .73875 1.08603 L .74442 1.07876 L F
.73312 1.0952 m .73341 1.09278 L .73875 1.08603 L F
0 g
.73875 1.08603 m
.74029 1.08188 L
s
.73875 1.08603 m
.73946 1.08511 L
s
.30557 .87167 m .29361 .87135 L .29916 .87294 L 0 1 .526 r
F
0 g
.29916 .87294 m
.29971 .87283 L
s
.29916 .87294 m
.30174 .87655 L
s
.74667 1.07578 m .75772 1.06234 L .75615 1.06363 L 0 .867 .15 r
F
.51518 .97611 m .51567 .97607 L .51691 .9865 L 0 .492 .142 r
F
0 g
.51688 .97569 m
.51697 .97627 L
s
.51517 .96764 m
.51567 .97607 L
s
.51319 .97566 m
.5132 .97583 L
s
.5132 .97583 m
.5132 .97583 L
s
.5132 .97583 m
.5132 .97583 L
s
.5132 .97583 m
.51326 .977 L
s
.51326 .977 m
.51326 .977 L
s
.44772 .8019 m
.45294 .80477 L
s
.30384 .77226 m .29353 .7714 L .29251 .77573 L 0 1 .496 r
F
0 g
.28591 .78003 m
.29251 .77573 L
s
.34107 .69473 m .32937 .69726 L .33282 .70062 L 0 1 .442 r
F
.34107 .69473 m .33266 .68781 L .32937 .69726 L F
.34107 .69473 m .34051 .67856 L .33266 .68781 L F
.34107 .69473 m .34877 .67267 L .34051 .67856 L F
.34107 .69473 m .35193 .67407 L .34877 .67267 L F
.34107 .69473 m .34863 .68352 L .35193 .67407 L F
0 g
.338 .70532 m
.34107 .69473 L
s
.33282 .70062 m
.34107 .69473 L
s
.34863 .68352 m
.35667 .67557 L
s
.53502 .97825 m
.53506 .97834 L
s
.53446 .97692 m
.53495 .97807 L
s
.53422 .97635 m
.53446 .97692 L
s
.53495 .97807 m
.53495 .9781 L
s
.53495 .9781 m
.53502 .97825 L
s
.5341 .97605 m
.53422 .97635 L
s
.53392 .97563 m
.5341 .97605 L
s
.51518 .97611 m .51598 .99934 L .51531 .98605 L 0 .492 .142 r
F
.51518 .97611 m .51723 1.00988 L .51598 .99934 L F
.51518 .97611 m .51822 1.01058 L .51723 1.00988 L F
.51518 .97611 m .51809 1.00052 L .51822 1.01058 L F
.51518 .97611 m .51691 .9865 L .51809 1.00052 L F
0 g
.51697 .97627 m
.51847 .98633 L
s
.5164 .97589 m
.51691 .9865 L
s
.51432 .96771 m
.51518 .97611 L
s
.51762 .97564 m
.5177 .97669 L
s
.5177 .97669 m
.51847 .98633 L
s
.5364 .98586 m .54442 1.0059 L .53973 .99397 L 0 0 .131 r
F
.5364 .98586 m .54821 1.01592 L .54442 1.0059 L F
0 g
.53824 .99239 m
.53841 .99281 L
s
.5364 .98586 m .54855 1.01732 L .54821 1.01592 L 0 0 .131 r
F
0 g
.53773 .9918 m
.53781 .992 L
s
.5364 .98586 m .5452 1.00914 L .54855 1.01732 L 0 0 .131 r
F
0 g
.54835 1.01422 m
.5485 1.01455 L
s
.54805 1.01358 m
.54835 1.01422 L
s
.54789 1.01322 m
.54805 1.01358 L
s
.5476 1.01175 m
.54795 1.01241 L
s
.54724 1.01108 m
.5476 1.01175 L
s
.5364 .98586 m .54039 .99688 L .5452 1.00914 L 0 0 .131 r
F
0 g
.5369 .98824 m
.53759 .98994 L
s
.53491 .98293 m
.5364 .98586 L
s
.51394 .97594 m .51385 .99744 L .51369 .98507 L 0 .482 .138 r
F
0 g
.51326 .977 m
.51369 .98507 L
s
.51394 .97594 m .51473 1.00754 L .51385 .99744 L 0 .482 .138 r
F
0 g
.51369 .98507 m
.51394 .97594 L
s
.51432 .96771 m
.5144 .97314 L
s
.51394 .97594 m .51574 1.00858 L .51473 1.00754 L 0 .482 .138 r
F
.51394 .97594 m .51598 .99934 L .51574 1.00858 L F
0 g
.5144 .97314 m
.51441 .97391 L
s
.51394 .97594 m .51531 .98605 L .51598 .99934 L 0 .482 .138 r
F
0 g
.51567 .97607 m
.51572 .97647 L
s
.51572 .97647 m
.51691 .9865 L
s
.51394 .97594 m .51444 .97605 L .51531 .98605 L 0 .482 .138 r
F
0 g
.51518 .97611 m
.51531 .98605 L
s
.51394 .97588 m
.51394 .97594 L
s
.51394 .97594 m
.51394 .97594 L
s
.51441 .97391 m
.51444 .97605 L
s
.51444 .97605 m
.51531 .98605 L
s
.44859 .94585 m .4378 .93847 L .43994 .93943 L 0 .164 0 r
F
0 g
.43576 .93632 m
.43994 .93943 L
s
.30384 .77226 m .2991 .76615 L .29353 .7714 L 0 1 .496 r
F
.30384 .77226 m .30627 .76212 L .2991 .76615 L F
.30384 .77226 m .31025 .76201 L .30627 .76212 L F
.30384 .77226 m .3092 .76636 L .31025 .76201 L F
0 g
.30297 .77703 m
.30384 .77226 L
s
.2967 .77627 m
.30384 .77226 L
s
.54246 .88497 m
.54248 .88507 L
s
.40143 .69489 m .39544 .68551 L .39146 .69078 L 0 1 .491 r
F
0 g
.38414 .68994 m
.39146 .69078 L
s
.40143 .69489 m .40328 .68232 L .39544 .68551 L 0 1 .491 r
F
.40143 .69489 m .41076 .68259 L .40328 .68232 L F
.40143 .69489 m .41289 .68616 L .41076 .68259 L F
.40143 .69489 m .40888 .69143 L .41289 .68616 L F
0 g
.39772 .70049 m
.40143 .69489 L
s
.39397 .69462 m
.40143 .69489 L
s
.32467 .66639 m .31611 .6633 L .31251 .66693 L 0 1 .534 r
F
.32467 .66639 m .32448 .65938 L .31611 .6633 L F
.32467 .66639 m .33315 .6579 L .32448 .65938 L F
.32467 .66639 m .33631 .65987 L .33315 .6579 L F
.32467 .66639 m .33266 .66351 L .33631 .65987 L F
0 g
.32135 .669 m
.32467 .66639 L
s
.31605 .66785 m
.32467 .66639 L
s
.82906 .93676 m .83924 .95218 L .84177 .94127 L 0 1 .45 r
F
.82906 .93676 m .83465 .95504 L .83924 .95218 L F
0 g
.83924 .95218 m
.84248 .95788 L
s
.52582 1.0814 m .52897 1.0945 L .52975 1.09517 L 0 0 .116 r
F
0 g
.69341 .58747 m
.69879 .59025 L
s
.74145 .65272 m .75881 .64321 L .76253 .6409 L 0 .845 .188 r
F
0 g
.76027 .64217 m
.76137 .64138 L
s
.74145 .65272 m .7498 .64826 L .75881 .64321 L 0 .845 .188 r
F
0 g
.75782 .64376 m
.75881 .64321 L
s
.54911 1.01479 m
.55008 1.01679 L
s
.54815 1.01281 m
.54911 1.01479 L
s
.54795 1.01241 m
.54815 1.01281 L
s
.76805 .86052 m .77699 .8642 L .78154 .86248 L 0 1 .464 r
F
.76805 .86052 m .77121 .86337 L .77699 .8642 L F
0 g
.77507 .86781 m
.77699 .8642 L
s
.52265 1.06133 m .52386 1.07584 L .52582 1.0814 L 0 0 .143 r
F
0 g
.52171 1.06628 m
.52386 1.07584 L
s
.52309 1.07519 m
.52386 1.07584 L
s
.60443 .61153 m .62461 .60619 L .61883 .60476 L 0 1 .5 r
F
0 g
.62461 .60619 m
.6332 .60452 L
s
.69921 1.11818 m .70886 1.11237 L .70491 1.11747 L 0 .043 .055 r
F
.7069 1.12719 m .70886 1.11237 L .71403 1.10981 L 0 0 .049 r
F
.7069 1.12719 m .70491 1.11747 L .70886 1.11237 L F
0 g
.70886 1.11237 m
.70896 1.10653 L
s
.70886 1.11237 m
.70986 1.11187 L
s
.64697 .72198 m .64693 .714 L .64407 .71302 L 0 .391 .364 r
F
0 g
.64352 .7124 m
.64407 .71302 L
s
.64697 .72198 m .65438 .72432 L .64693 .714 L 0 .391 .364 r
F
.64697 .72198 m .66146 .73711 L .65438 .72432 L F
.64697 .72198 m .66436 .74609 L .66146 .73711 L F
.64697 .72198 m .66115 .74525 L .66436 .74609 L F
.64697 .72198 m .6537 .73491 L .66115 .74525 L F
0 g
.64128 .71327 m
.64697 .72198 L
s
.64407 .71302 m
.64697 .72198 L
s
.53464 .97846 m .54182 .99366 L .53752 .98421 L 0 0 .144 r
F
0 g
.53505 .98146 m
.53549 .9823 L
s
.53504 .98246 m
.53564 .98345 L
s
.53464 .97846 m .54554 1.00323 L .54182 .99366 L 0 0 .144 r
F
.53464 .97846 m .5462 1.00651 L .54554 1.00323 L F
.53464 .97846 m .54329 1.0007 L .5462 1.00651 L F
.53464 .97846 m .53877 .98972 L .54329 1.0007 L F
0 g
.53564 .98345 m
.53574 .98362 L
s
.53464 .97846 m .53507 .98021 L .53877 .98972 L 0 0 .144 r
F
0 g
.53549 .9823 m
.53554 .98239 L
s
.53484 .97988 m
.53507 .98021 L
s
.53454 .97828 m
.53464 .97846 L
s
.53506 .97834 m
.53519 .97865 L
s
.53523 .97964 m
.53554 .98027 L
s
.53511 .97942 m
.53523 .97964 L
s
.5349 .979 m
.53511 .97942 L
s
.53478 .97875 m
.5349 .979 L
s
.53464 .97846 m
.53478 .97875 L
s
.35536 .53023 m
.3656 .52539 L
s
.34863 .68352 m
.35193 .67407 L
s
.53564 .98258 m .53597 .984 L .53973 .99397 L 0 0 .136 r
F
0 g
.53574 .98362 m
.53597 .984 L
s
.32646 .87861 m .31891 .87186 L .31603 .875 L 0 1 .523 r
F
.32646 .87861 m .32414 .8707 L .31891 .87186 L F
.32646 .87861 m .32821 .87231 L .32414 .8707 L F
.32646 .87861 m .3292 .8757 L .32821 .87231 L F
0 g
.32124 .87976 m
.32646 .87861 L
s
.32646 .87861 m
.32756 .88191 L
s
.46701 .68819 m .47466 .68503 L .4798 .67991 L 0 1 .485 r
F
0 g
.47466 .68503 m
.48098 .68556 L
s
.5353 .98081 m
.53565 .98172 L
s
.53525 .98067 m
.5353 .98081 L
s
.53507 .98021 m
.53525 .98067 L
s
.75054 .83667 m
.75654 .82655 L
s
.28137 .69117 m .27184 .68524 L .26904 .69189 L 0 1 .522 r
F
0 g
.26125 .69465 m
.26904 .69189 L
s
.53564 .98258 m .54329 1.0007 L .53877 .98972 L 0 0 .136 r
F
.53564 .98258 m .54707 1.01074 L .54329 1.0007 L F
.53564 .98258 m .54757 1.0131 L .54707 1.01074 L F
.53564 .98258 m .54442 1.0059 L .54757 1.0131 L F
0 g
.54756 1.01251 m
.54789 1.01322 L
s
.54735 1.01206 m
.54751 1.01241 L
s
.53564 .98258 m .53973 .99397 L .54442 1.0059 L 0 0 .136 r
F
0 g
.53564 .98258 m
.53609 .9836 L
s
.53609 .9836 m
.53662 .98481 L
s
.53802 .99059 m
.53864 .99225 L
s
.53759 .98994 m
.5383 .9917 L
s
.5383 .9917 m
.53851 .99221 L
s
.53851 .99221 m
.5389 .99318 L
s
.53841 .99281 m
.53959 .99565 L
s
.53781 .992 m
.54082 .99892 L
s
.5382 .99259 m
.54082 .99892 L
s
.53869 .99318 m
.53954 .99537 L
s
.53858 .99292 m
.53869 .99318 L
s
.53801 .99145 m
.53854 .9928 L
s
.53854 .9928 m
.53858 .99292 L
s
.53554 .98239 m
.53564 .98258 L
s
.5364 .98586 m
.53745 .98843 L
s
.53724 .98854 m
.53802 .99059 L
s
.53663 .98692 m
.53724 .98854 L
s
.53726 .98743 m
.53731 .98754 L
s
.4378 .93847 m .429 .93205 L .43338 .93504 L 0 .019 0 r
F
0 g
.43338 .93504 m
.43576 .93632 L
s
.70644 .65442 m
.7077 .65699 L
s
.70219 .64092 m
.70644 .65442 L
s
.30805 .66732 m
.3125 .66693 L
s
.68943 1.13103 m .69921 1.11818 L .69898 1.12554 L 0 .134 .076 r
F
.24884 .7799 m .23799 .7773 L .23731 .78288 L 0 1 .541 r
F
0 g
.23094 .7875 m
.23731 .78288 L
s
.46701 .68819 m .45909 .68404 L .46034 .68777 L 0 1 .485 r
F
.46701 .68819 m .46423 .67891 L .45909 .68404 L F
0 g
.45888 .68943 m
.46034 .68777 L
s
.45572 .69305 m
.45888 .68943 L
s
.46701 .68819 m .47234 .6758 L .46423 .67891 L 0 1 .485 r
F
.46701 .68819 m .47901 .67622 L .47234 .6758 L F
.46701 .68819 m .4798 .67991 L .47901 .67622 L F
0 g
.47466 .68503 m
.47819 .68152 L
s
.47819 .68152 m
.4798 .67991 L
s
.46034 .68777 m
.46701 .68819 L
s
.46221 .69347 m
.46701 .68819 L
s
.4798 .67991 m
.48624 .6804 L
s
.52115 1.02891 m
.52136 1.03208 L
s
.52136 1.03208 m
.52165 1.03656 L
s
.52167 1.03257 m
.52214 1.03586 L
s
.52214 1.03586 m
.52243 1.03792 L
s
.52243 1.03792 m
.52249 1.03838 L
s
.52249 1.03838 m
.52269 1.03975 L
s
.52115 1.02891 m
.52166 1.0325 L
s
.52166 1.0325 m
.52167 1.03257 L
s
.57498 .94423 m
.5752 .92659 L
s
.57532 .91672 m
.5755 .90161 L
s
.76805 .86052 m .78154 .86248 L .7825 .85869 L 0 1 .464 r
F
0 g
.78154 .86248 m
.78651 .86384 L
s
.48212 .82553 m
.48437 .82697 L
s
.48017 .82427 m
.48212 .82553 L
s
.65778 .74611 m
.66147 .75304 L
s
.65742 .74543 m
.65778 .74611 L
s
.65633 .74338 m
.65742 .74543 L
s
.6537 .73491 m
.65633 .74338 L
s
.53307 .94717 m .53658 .93524 L .53404 .94011 L 0 .33 .29 r
F
0 g
.53115 .94063 m
.53404 .94011 L
s
.53497 1.11112 m .53643 1.11277 L .53929 1.12008 L 0 .404 0 r
F
0 g
.53325 1.1049 m
.53643 1.11277 L
s
.53533 1.10846 m
.53643 1.11277 L
s
.4378 .93847 m .42702 .93071 L .429 .93205 L 0 .019 0 r
F
0 g
.42469 .92913 m
.42704 .93072 L
s
.53716 .92695 m
.54037 .92406 L
s
.30557 .87167 m .29183 .8676 L .29361 .87135 L 0 1 .526 r
F
0 g
.28779 .87277 m
.29361 .87135 L
s
.49776 .6289 m
.50443 .62889 L
s
.51335 .85522 m
.51383 .85684 L
s
.39146 .69078 m
.39544 .68551 L
s
.55553 1.02319 m
.55577 1.02368 L
s
.45937 .95248 m .4499 .94774 L .44859 .94585 L 0 .267 0 r
F
.45937 .95248 m .45401 .95124 L .4499 .94774 L F
.45937 .95248 m .45817 .95402 L .45401 .95124 L F
.45937 .95248 m .46047 .95455 L .45817 .95402 L F
0 g
.45526 .94898 m
.45937 .95248 L
s
.45937 .95248 m
.46183 .95253 L
s
.67963 1.14502 m .67632 1.13717 L .67672 1.12815 L 0 .21 .093 r
F
0 g
.6709 1.12574 m
.67672 1.12815 L
s
.4827 .96618 m .47482 .96246 L .47898 .96369 L 0 .396 .07 r
F
0 g
.47898 .96369 m
.4816 .96317 L
s
.35721 .6713 m
.35759 .67132 L
s
.81957 .97259 m .82776 .95953 L .82316 .96268 L 0 1 .449 r
F
.80814 .98118 m .81957 .97259 L .81628 .96765 L 0 1 .436 r
F
.42702 .93071 m .41806 .92451 L .42244 .92754 L 0 .145 .175 r
F
0 g
.42244 .92754 m
.42469 .92913 L
s
.77922 .85535 m .78837 .85991 L .79293 .85822 L 0 1 .484 r
F
.77922 .85535 m .7825 .85869 L .78837 .85991 L F
0 g
.78651 .86384 m
.78837 .85991 L
s
.53307 .94717 m .53974 .93711 L .53658 .93524 L 0 .33 .29 r
F
0 g
.53658 .93524 m
.53716 .92695 L
s
.53307 .94717 m .53747 .95362 L .54044 .95157 L 0 .33 .29 r
F
.53307 .94717 m .53432 .95173 L .53747 .95362 L F
0 g
.53023 .94513 m
.53307 .94717 L
s
.53307 .94717 m
.53404 .94011 L
s
.30719 .66538 m
.30805 .66732 L
s
.7163 .73037 m .71768 .71064 L .71388 .70964 L 0 .554 .319 r
F
0 g
.71388 .70964 m
.71448 .71481 L
s
.71448 .71481 m
.7163 .73037 L
s
.71198 .70539 m
.71388 .70964 L
s
.71178 .71773 m
.71595 .7294 L
s
.71595 .7294 m
.7163 .73037 L
s
.42702 .93071 m .41624 .9228 L .41806 .92451 L 0 .145 .175 r
F
0 g
.41363 .92187 m
.41806 .92451 L
s
.78414 1.02366 m .7931 1.01084 L .78856 1.01504 L 0 1 .373 r
F
.77287 1.03526 m .78414 1.02366 L .78177 1.02178 L 0 1 .332 r
F
.57685 .62121 m .59444 .6167 L .59611 .61406 L 0 1 .509 r
F
.57685 .62121 m .58619 .61977 L .59444 .6167 L F
0 g
.59444 .6167 m
.59991 .61791 L
s
.58619 .61977 m
.59166 .62116 L
s
.58619 .61977 m
.59444 .6167 L
s
.67963 1.14502 m .68597 1.12517 L .68943 1.13103 L 0 .21 .093 r
F
0 g
.68053 1.12394 m
.68597 1.12517 L
s
.68597 1.12517 m
.68624 1.11783 L
s
.53303 .95493 m
.53432 .95173 L
s
.42539 .69554 m .41607 .69162 L .41818 .69535 L 0 1 .487 r
F
.42539 .69554 m .42041 .6863 L .41607 .69162 L F
0 g
.41532 .69966 m
.41818 .69535 L
s
.41446 .70094 m
.41532 .69966 L
s
.42539 .69554 m .42834 .68293 L .42041 .6863 L 0 1 .487 r
F
.42539 .69554 m .43556 .68312 L .42834 .68293 L F
.42539 .69554 m .43725 .68675 L .43556 .68312 L F
.42539 .69554 m .43289 .69207 L .43725 .68675 L F
0 g
.42135 .70103 m
.42539 .69554 L
s
.41818 .69535 m
.42539 .69554 L
s
.53974 .93711 m
.54037 .92406 L
s
.50531 .66396 m .51362 .66115 L .51996 .65653 L 0 1 .499 r
F
0 g
.51362 .66115 m
.51973 .66168 L
s
.52187 1.03979 m .52092 1.03704 L .52127 1.04386 L 0 .086 .183 r
F
0 g
.52122 1.04285 m
.52123 1.04293 L
s
.52119 1.0423 m
.52122 1.04285 L
s
.52107 1.0399 m
.52119 1.0423 L
s
.52104 1.03932 m
.52107 1.0399 L
s
.52097 1.03791 m
.52104 1.03932 L
s
.52096 1.03789 m
.52097 1.03791 L
s
.52093 1.03731 m
.52096 1.03789 L
s
.52092 1.03704 m
.52093 1.03731 L
s
.52165 1.03656 m
.52181 1.03898 L
s
.52181 1.03898 m
.52183 1.03919 L
s
.52183 1.03919 m
.52183 1.03925 L
s
.52183 1.03925 m
.52183 1.03927 L
s
.52089 1.0368 m
.52092 1.03704 L
s
.77922 .85535 m .79293 .85822 L .7938 .8541 L 0 1 .484 r
F
0 g
.79293 .85822 m
.79795 .85994 L
s
.53497 1.11112 m .53258 1.10435 L .53185 1.10169 L 0 .404 0 r
F
0 g
.52897 1.0945 m
.53185 1.10169 L
s
.54652 .89055 m .54858 .94152 L .54627 .91111 L 0 .876 .172 r
F
0 g
.54248 .88507 m
.54627 .91111 L
s
.54652 .89055 m .55273 .97639 L .54858 .94152 L 0 .876 .172 r
F
.54652 .89055 m .55594 .99221 L .55273 .97639 L F
.54652 .89055 m .55616 .97099 L .55594 .99221 L F
.54652 .89055 m .55327 .92744 L .55616 .97099 L F
0 g
.55539 .89083 m
.55686 .90578 L
s
.55686 .90578 m
.5598 .93558 L
s
.54652 .89055 m .54916 .89322 L .55327 .92744 L 0 .876 .172 r
F
0 g
.55296 .89334 m
.55327 .92744 L
s
.54343 .86979 m
.54652 .89055 L
s
.54627 .91111 m
.54652 .89055 L
s
.5491 .87936 m
.54916 .89322 L
s
.82906 .93676 m .83028 .94844 L .83465 .95504 L 0 1 .45 r
F
0 g
.83102 .96487 m
.83465 .95504 L
s
.4827 .96618 m .4725 .96328 L .47482 .96246 L 0 .396 .07 r
F
.4827 .96618 m .47356 .96562 L .4725 .96328 L F
.4827 .96618 m .47729 .96812 L .47356 .96562 L F
.4827 .96618 m .48118 .96909 L .47729 .96812 L F
.4827 .96618 m .4835 .96826 L .48118 .96909 L F
0 g
.4827 .96618 m
.48522 .96452 L
s
.47898 .96369 m
.4827 .96618 L
s
.53004 .97929 m
.5319 .98154 L
s
.63891 .5989 m .66046 .59603 L .65481 .59397 L 0 1 .501 r
F
0 g
.66046 .59603 m
.6695 .59547 L
s
.46481 .81283 m
.46557 .81381 L
s
.46481 .81283 m
.46957 .81585 L
s
.54916 .89322 m
.55327 .92744 L
s
.41624 .9228 m .40711 .91697 L .41149 .91998 L 0 .29 .216 r
F
0 g
.41149 .91998 m
.41363 .92187 L
s
.32283 .69972 m .31491 .69598 L .31847 .69934 L 0 1 .46 r
F
.32283 .69972 m .314 .69163 L .31491 .69598 L F
0 g
.31622 .70667 m
.31822 .70015 L
s
.32283 .69972 m .31633 .68917 L .314 .69163 L 0 1 .46 r
F
0 g
.31432 .69616 m
.31491 .69599 L
s
.30712 .69832 m
.31432 .69616 L
s
.32283 .69972 m .3207 .68956 L .31633 .68917 L 0 1 .46 r
F
0 g
.31822 .70015 m
.31847 .69934 L
s
.32283 .69972 m .32417 .69252 L .3207 .68956 L 0 1 .46 r
F
.32283 .69972 m .32508 .69687 L .32417 .69252 L F
0 g
.32283 .69972 m
.32378 .70516 L
s
.31847 .69934 m
.32283 .69972 L
s
.6582 .86356 m
.66069 .87509 L
s
.66069 .87509 m
.66215 .88186 L
s
.65685 .85734 m
.6582 .86356 L
s
.35333 .76741 m
.35461 .77044 L
s
.35333 .76741 m
.35969 .77155 L
s
.73312 1.0952 m .74442 1.07876 L .74667 1.07578 L 0 0 0 r
F
0 g
.73946 1.08511 m
.74442 1.07876 L
s
.47104 .95995 m
.47482 .96246 L
s
.52187 1.03979 m .52127 1.04386 L .52269 1.05572 L 0 .086 .183 r
F
0 g
.52108 1.04266 m
.52127 1.04386 L
s
.52123 1.04293 m
.52127 1.04386 L
s
.67613 .58316 m .67319 .57335 L .67049 .57228 L 0 .339 .352 r
F
0 g
.67049 .57228 m
.67613 .58316 L
s
.66035 .56221 m
.67049 .57228 L
s
.66772 .57198 m
.67613 .58316 L
s
.53658 .93524 m
.53974 .93711 L
s
.41624 .9228 m .40545 .91491 L .40711 .91697 L 0 .29 .216 r
F
0 g
.40255 .91471 m
.40711 .91697 L
s
.33392 .7396 m
.33577 .73189 L
s
.3413 .74862 m
.34139 .74873 L
s
.33641 .74273 m
.3413 .74862 L
s
.33392 .73974 m
.33641 .74273 L
s
.78532 1.00164 m .7931 1.01084 L .79659 1.00046 L 0 1 .402 r
F
.78532 1.00164 m .78856 1.01504 L .7931 1.01084 L F
0 g
.7931 1.01084 m
.79542 1.01348 L
s
.79039 .8503 m .79976 .85571 L .80432 .85405 L 0 1 .498 r
F
.79039 .8503 m .7938 .8541 L .79976 .85571 L F
0 g
.79795 .85994 m
.79976 .85571 L
s
.55041 .63507 m .55945 .63299 L .56729 .62869 L 0 1 .511 r
F
0 g
.52048 .63013 m
.5275 .63113 L
s
.51367 .62943 m
.52048 .63013 L
s
.76162 1.04858 m .77158 1.04204 L .77287 1.03526 L 0 1 .279 r
F
0 g
.77158 1.04204 m
.77397 1.04388 L
s
.7675 1.05035 m
.77158 1.04204 L
s
.74145 .65272 m .76253 .6409 L .75885 .64188 L 0 .845 .188 r
F
0 g
.76253 .6409 m
.77087 .63633 L
s
.70007 .89105 m .71302 .88773 L .71051 .8872 L 0 1 .259 r
F
0 g
.71302 .88773 m
.71807 .88692 L
s
.7117 .88928 m
.71302 .88773 L
s
.32508 .69687 m
.32936 .69726 L
s
.34002 .73091 m .33244 .72091 L .33578 .73166 L 0 1 .282 r
F
0 g
.33158 .70995 m
.33244 .72091 L
s
.29183 .8676 m .28153 .86799 L .28605 .86923 L 0 1 .523 r
F
0 g
.28605 .86923 m
.28779 .87277 L
s
.50531 .66396 m .51996 .65653 L .52011 .65316 L 0 1 .499 r
F
0 g
.51996 .65653 m
.52605 .65703 L
s
.51362 .66115 m
.51996 .65653 L
s
.34002 .73093 m
.34176 .73543 L
s
.35193 .67407 m
.35708 .67137 L
s
.35708 .67137 m
.35714 .67134 L
s
.35714 .67134 m
.35721 .6713 L
s
.5517 1.14418 m .55709 1.14448 L .55813 1.15051 L 0 .538 .048 r
F
0 g
.55709 1.14448 m
.56155 1.14967 L
s
.31603 .875 m .30859 .86838 L .30557 .87167 L 0 1 .526 r
F
0 g
.30557 .87167 m
.30648 .87509 L
s
.31603 .875 m .31393 .86698 L .30859 .86838 L 0 1 .526 r
F
.31603 .875 m .31802 .86842 L .31393 .86698 L F
.31603 .875 m .31891 .87186 L .31802 .86842 L F
0 g
.3107 .87638 m
.31603 .875 L
s
.31603 .875 m
.31703 .87838 L
s
.40545 .91491 m .39616 .90959 L .40054 .91252 L 0 .4 .292 r
F
0 g
.40054 .91252 m
.40255 .91471 L
s
.28137 .69117 m .2795 .67872 L .27184 .68524 L 0 1 .522 r
F
.28137 .69117 m .28797 .67562 L .2795 .67872 L F
.28137 .69117 m .29158 .67803 L .28797 .67562 L F
.28137 .69117 m .28874 .6847 L .29158 .67803 L F
0 g
.27877 .69794 m
.28137 .69117 L
s
.27294 .69424 m
.28137 .69117 L
s
.71699 1.1115 m .72707 1.09763 L .72635 1.10232 L 0 0 .016 r
F
0 g
.33641 .74273 m
.34175 .73572 L
s
.43796 .49681 m .42618 .49814 L .42758 .49881 L 0 .913 .252 r
F
0 g
.41959 .50294 m
.42758 .49881 L
s
.43796 .49681 m .43483 .49526 L .42618 .49814 L 0 .913 .252 r
F
.43796 .49681 m .44779 .49208 L .43483 .49526 L F
.43796 .49681 m .45818 .49008 L .44779 .49208 L F
.43796 .49681 m .45907 .49059 L .45818 .49008 L F
.43796 .49681 m .4504 .49347 L .45907 .49059 L F
0 g
.42968 .49967 m
.43796 .49681 L
s
.42758 .49881 m
.43796 .49681 L
s
.4504 .49347 m
.46041 .49119 L
s
.65857 .74168 m
.66109 .74517 L
s
.6537 .73491 m
.65857 .74168 L
s
.79039 .8503 m .80432 .85405 L .80511 .84962 L 0 1 .498 r
F
0 g
.80432 .85405 m
.8094 .85612 L
s
.69166 .60943 m
.69291 .61143 L
s
.68634 .59876 m
.69166 .60943 L
s
.44859 .94585 m .43933 .94006 L .4378 .93847 L 0 .164 0 r
F
.44859 .94585 m .4436 .94362 L .43933 .94006 L F
.44859 .94585 m .44777 .94678 L .4436 .94362 L F
.44859 .94585 m .4499 .94774 L .44777 .94678 L F
0 g
.44432 .94229 m
.44859 .94585 L
s
.44859 .94585 m
.45089 .94639 L
s
.5655 .90754 m
.5655 .90736 L
s
.56548 .90937 m
.5655 .90754 L
s
.56544 .91183 m
.56548 .90937 L
s
.56544 .91224 m
.56544 .91183 L
s
.56537 .91744 m
.56544 .91224 L
s
.56536 .91782 m
.56537 .91744 L
s
.56548 .90744 m
.5655 .90736 L
s
.5652 .90831 m
.56548 .90744 L
s
.56479 .90958 m
.5652 .90831 L
s
.5647 .90987 m
.56479 .90958 L
s
.55041 .63507 m .56729 .62869 L .56874 .62504 L 0 1 .511 r
F
0 g
.56729 .62869 m
.57279 .63007 L
s
.55945 .63299 m
.56729 .62869 L
s
.53228 .98727 m
.53335 .9883 L
s
.53465 .98265 m .54182 .99366 L .53752 .98421 L 0 .231 .219 r
F
.53465 .98265 m .54559 1.01203 L .54182 .99366 L F
.53465 .98265 m .5463 1.02709 L .54559 1.01203 L F
.53465 .98265 m .5434 1.02548 L .5463 1.02709 L F
.53465 .98265 m .53884 1.00831 L .5434 1.02548 L F
.53465 .98265 m .5351 .98999 L .53884 1.00831 L F
.53343 .98337 m .53393 .97982 L .53752 .98421 L 0 .482 .168 r
F
0 g
.53654 .98301 m
.5366 .98308 L
s
.5366 .98308 m
.5368 .98333 L
s
.5364 .98284 m
.53654 .98301 L
s
.53627 .98268 m
.5364 .98284 L
s
.53615 .98253 m
.53627 .98268 L
s
.53583 .98214 m
.53615 .98253 L
s
.53576 .98205 m
.53583 .98214 L
s
.53517 .98133 m
.53576 .98205 L
s
.5351 .98125 m
.53517 .98133 L
s
.53393 .97982 m
.5351 .98125 L
s
.53682 .9828 m
.53701 .98319 L
s
.53598 .98114 m
.53682 .9828 L
s
.53701 .98319 m
.53703 .98323 L
s
.53565 .98172 m
.53581 .98211 L
s
.53554 .98027 m
.53598 .98114 L
s
.5364 .98153 m
.53643 .98162 L
s
.53607 .98075 m
.5364 .98153 L
s
.53519 .97865 m
.53607 .98075 L
s
.53293 .97707 m
.53393 .97982 L
s
.32417 .69252 m
.32508 .69687 L
s
.52678 .64875 m .53552 .64624 L .54253 .64205 L 0 1 .507 r
F
0 g
.53552 .64624 m
.54159 .64676 L
s
.48148 .62941 m .47275 .62776 L .47382 .62893 L 0 .916 .304 r
F
.48148 .62941 m .47929 .62657 L .47275 .62776 L F
0 g
.46788 .63096 m
.47382 .62893 L
s
.48148 .62941 m .48908 .62615 L .47929 .62657 L 0 .916 .304 r
F
.48148 .62941 m .49675 .62663 L .48908 .62615 L F
.48148 .62941 m .49718 .62769 L .49675 .62663 L F
.48148 .62941 m .49064 .62888 L .49718 .62769 L F
0 g
.47382 .62893 m
.48148 .62941 L
s
.49064 .62888 m
.49776 .6289 L
s
.81131 .80985 m .8167 .81061 L .81224 .81199 L 0 0 0 r
F
.81131 .80985 m .82257 .80717 L .8167 .81061 L F
0 g
.5488 .63594 m
.55042 .63642 L
s
.54878 .63593 m
.5488 .63594 L
s
.40545 .91491 m .39465 .90718 L .39616 .90959 L 0 .4 .292 r
F
0 g
.39147 .90774 m
.39616 .90959 L
s
.43289 .69207 m
.43979 .69229 L
s
.49554 .97274 m .48911 .97452 L .4927 .97328 L 0 .463 .092 r
F
.49554 .97274 m .48666 .97601 L .48911 .97452 L F
.49554 .97274 m .48697 .97675 L .48666 .97601 L F
.49554 .97274 m .48982 .97621 L .48697 .97675 L F
.49554 .97274 m .4933 .97475 L .48982 .97621 L F
0 g
.4927 .97328 m
.4927 .97328 L
s
.49554 .97274 m .49575 .97326 L .4933 .97475 L 0 .463 .092 r
F
0 g
.49554 .97274 m
.4974 .97049 L
s
.4927 .97328 m
.49492 .97112 L
s
.4927 .97328 m
.49554 .97274 L
s
.49575 .97326 m
.49851 .97079 L
s
.58178 .64962 m
.58722 .6527 L
s
.56546 .64163 m
.57294 .64511 L
s
.23799 .7773 m .22631 .7803 L .23072 .78135 L 0 1 .541 r
F
0 g
.23072 .78135 m
.23094 .7875 L
s
.43679 .79666 m .42838 .79272 L .43103 .79366 L 0 0 0 r
F
0 g
.42951 .79242 m
.43103 .79366 L
s
.32051 .54643 m
.33075 .54108 L
s
.55482 .49178 m
.55603 .49222 L
s
.55603 .49222 m
.55622 .49228 L
s
.54777 .49083 m
.55482 .49178 L
s
.40888 .69143 m
.41607 .69162 L
s
.52678 .64875 m .54253 .64205 L .54316 .63896 L 0 1 .507 r
F
0 g
.54253 .64205 m
.54849 .64262 L
s
.53552 .64624 m
.54253 .64205 L
s
.27184 .68524 m .25928 .68626 L .26319 .68846 L 0 1 .527 r
F
0 g
.26125 .69465 m
.26319 .68846 L
s
.33075 .54108 m
.33741 .53474 L
s
.66525 .81267 m
.66817 .82024 L
s
.66525 .81267 m
.66562 .81814 L
s
.66562 .81814 m
.66607 .82484 L
s
.36862 .66228 m
.37684 .6574 L
s
.49972 .97536 m
.50006 .97441 L
s
.29183 .8676 m .28062 .86442 L .28153 .86799 L 0 1 .523 r
F
0 g
.27641 .86982 m
.28153 .86799 L
s
.80158 .84535 m .81117 .85159 L .81573 .84996 L 0 1 .508 r
F
.80158 .84535 m .80511 .84962 L .81117 .85159 L F
0 g
.8094 .85612 m
.81117 .85159 L
s
.50531 .66396 m .49851 .65999 L .49883 .66347 L 0 1 .499 r
F
.50531 .66396 m .50486 .65536 L .49851 .65999 L F
.50531 .66396 m .51364 .65266 L .50486 .65536 L F
.50531 .66396 m .52011 .65316 L .51364 .65266 L F
0 g
.49931 .66879 m
.50531 .66396 L
s
.39465 .90718 m .3855 .90264 L .38971 .90535 L 0 .525 .379 r
F
0 g
.38971 .90535 m
.39147 .90774 L
s
.58586 .5023 m
.58623 .50251 L
s
.5864 .5026 m
.58734 .50312 L
s
.58368 .50161 m
.58586 .5023 L
s
.63859 .85593 m
.63886 .86381 L
s
.71051 .8872 m .72356 .88353 L .72094 .88273 L 0 1 .255 r
F
0 g
.72233 .88532 m
.72356 .88353 L
s
.76162 1.04858 m .7604 1.05477 L .76283 1.0557 L 0 1 .279 r
F
0 g
.75772 1.06234 m
.76283 1.0557 L
s
.4933 .97475 m
.49575 .97326 L
s
.29353 .7714 m .28202 .7741 L .28621 .7748 L 0 1 .521 r
F
0 g
.28591 .78003 m
.28621 .7748 L
s
.7001 .80842 m .71276 .80848 L .7046 .77961 L 0 .575 .28 r
F
0 g
.7046 .77961 m
.7067 .78705 L
s
.7067 .78705 m
.7076 .79023 L
s
.70341 .75573 m
.7046 .77961 L
s
.7001 .80842 m
.7001 .80842 L
s
.60443 .61153 m .6003 .60748 L .59862 .6101 L 0 1 .5 r
F
.60443 .61153 m .60897 .60519 L .6003 .60748 L F
.60443 .61153 m .61883 .60476 L .60897 .60519 L F
.32768 .75439 m .31621 .76147 L .32018 .76085 L 0 0 0 r
F
.32768 .75439 m .31783 .76041 L .31621 .76147 L F
0 g
.31929 .76564 m
.32018 .76085 L
s
.32768 .75439 m .32399 .75839 L .31783 .76041 L 0 0 0 r
F
0 g
.32018 .76085 m
.32246 .75889 L
s
.32768 .75439 m .33152 .7519 L .32399 .75839 L 0 0 0 r
F
.32768 .75439 m .33372 .74638 L .33538 .7453 L F
0 g
.33443 .74533 m
.33641 .74273 L
s
.33373 .74625 m
.33443 .74533 L
s
.36038 .67146 m .36973 .66279 L .36133 .66238 L 0 1 .526 r
F
.36038 .67146 m .37246 .66579 L .36973 .66279 L F
.36038 .67146 m .36845 .66951 L .37246 .66579 L F
0 g
.35759 .67132 m
.36038 .67146 L
s
.3578 .67418 m
.36038 .67146 L
s
.39465 .90718 m .38428 .89999 L .3855 .90264 L 0 .525 .379 r
F
0 g
.38083 .90131 m
.3855 .90264 L
s
.80158 .84535 m .81573 .84996 L .81643 .84523 L 0 1 .508 r
F
0 g
.81573 .84996 m
.82086 .85238 L
s
.4378 .93847 m .42876 .93191 L .42702 .93071 L 0 .019 0 r
F
.4378 .93847 m .4332 .93534 L .42876 .93191 L F
.4378 .93847 m .43736 .93872 L .4332 .93534 L F
.4378 .93847 m .43933 .94006 L .43736 .93872 L F
0 g
.43338 .93504 m
.4378 .93847 L
s
.4378 .93847 m
.43994 .93943 L
s
.71446 .69349 m
.72166 .70818 L
s
.72166 .70818 m
.72339 .7117 L
s
.71446 .69349 m
.71768 .71064 L
s
.71592 .58656 m .73385 .58543 L .72382 .58223 L 0 1 .51 r
F
0 g
.73385 .58543 m
.73877 .58895 L
s
.54831 1.01485 m
.54866 1.01557 L
s
.54866 1.01557 m
.5488 1.01583 L
s
.5463 1.01073 m
.54798 1.01417 L
s
.54807 1.01435 m
.54831 1.01485 L
s
.54607 1.01026 m
.5463 1.01073 L
s
.54693 1.01243 m
.54844 1.0159 L
s
.5486 1.01626 m
.54875 1.01661 L
s
.54657 1.01159 m
.54693 1.01243 L
s
.52187 1.03979 m .52589 1.06548 L .52399 1.05196 L 0 .086 .183 r
F
.52187 1.03979 m .52624 1.07232 L .52589 1.06548 L F
.52187 1.03979 m .52482 1.06792 L .52624 1.07232 L F
.52187 1.03979 m .52269 1.05572 L .52482 1.06792 L F
0 g
.52183 1.03927 m
.52187 1.03979 L
s
.52269 1.03975 m
.52319 1.04331 L
s
.52319 1.04331 m
.5232 1.04336 L
s
.52187 1.03979 m
.52194 1.04021 L
s
.52194 1.04021 m
.52197 1.04039 L
s
.52197 1.04039 m
.52221 1.04177 L
s
.52221 1.04177 m
.52236 1.04259 L
s
.52236 1.04259 m
.5225 1.04343 L
s
.5225 1.04343 m
.52271 1.04459 L
s
.52271 1.04459 m
.5229 1.04568 L
s
.38212 .77724 m .37224 .77527 L .37552 .77553 L 0 0 0 r
F
0 g
.42647 .63793 m
.43171 .63515 L
s
.4835 .96826 m
.48703 .96935 L
s
.24884 .7799 m .24332 .77083 L .23799 .7773 L 0 1 .541 r
F
.24884 .7799 m .25048 .76683 L .24332 .77083 L F
.24884 .7799 m .25469 .76799 L .25048 .76683 L F
.24884 .7799 m .25398 .77359 L .25469 .76799 L F
0 g
.24376 .78273 m
.24884 .7799 L
s
.2483 .7853 m
.24884 .7799 L
s
.40923 .64354 m .39851 .6445 L .40084 .64553 L 0 1 .474 r
F
0 g
.3963 .65007 m
.40084 .64553 L
s
.40923 .64354 m .40375 .64087 L .39851 .6445 L 0 1 .474 r
F
.40923 .64354 m .41309 .63706 L .40375 .64087 L F
.40923 .64354 m .4215 .63507 L .41309 .63706 L F
.40923 .64354 m .42336 .63622 L .4215 .63507 L F
.40923 .64354 m .4181 .63985 L .42336 .63622 L F
0 g
.40084 .64553 m
.40923 .64354 L
s
.4181 .63985 m
.42647 .63793 L
s
.39544 .68551 m .38378 .67984 L .38709 .68445 L 0 1 .504 r
F
0 g
.38414 .68994 m
.38709 .68445 L
s
.8176 .94467 m .82776 .95953 L .83028 .94844 L 0 1 .439 r
F
.8176 .94467 m .82316 .96268 L .82776 .95953 L F
0 g
.82776 .95953 m
.83102 .96487 L
s
.37552 .67778 m
.37577 .67785 L
s
.54936 1.01605 m
.55045 1.01797 L
s
.5485 1.01455 m
.54936 1.01605 L
s
.75774 .8438 m .76767 .82426 L .77212 .82322 L 0 .03 .052 r
F
.75774 .8438 m .76152 .83305 L .76767 .82426 L F
0 g
.76633 .81803 m
.76767 .82426 L
s
.52265 1.06133 m .52623 1.07929 L .52481 1.0709 L 0 0 .143 r
F
.52265 1.06133 m .52582 1.0814 L .52623 1.07929 L F
0 g
.52265 1.06133 m
.52276 1.06182 L
s
.52276 1.06182 m
.52277 1.06185 L
s
.52277 1.06185 m
.52287 1.0623 L
s
.52265 1.06133 m
.52269 1.05572 L
s
.38428 .89999 m .37496 .89608 L .37918 .89866 L 0 .707 .436 r
F
0 g
.37918 .89866 m
.38083 .90131 L
s
.43679 .79666 m .43048 .7941 L .42838 .79272 L 0 0 0 r
F
.43679 .79666 m .43594 .7969 L .43048 .7941 L F
.43679 .79666 m .44173 .79991 L .43594 .7969 L F
.43679 .79666 m .44396 .80113 L .44173 .79991 L F
.43679 .79666 m .44184 .79973 L .44396 .80113 L F
0 g
.435 .79491 m
.43679 .79666 L
s
.43103 .79366 m
.43679 .79666 L
s
.81278 .84052 m .82258 .84756 L .82715 .84597 L 0 1 .516 r
F
.81278 .84052 m .81643 .84523 L .82258 .84756 L F
0 g
.82086 .85238 m
.82258 .84756 L
s
.7069 1.12719 m .71403 1.10981 L .71699 1.1115 L 0 0 .049 r
F
0 g
.71403 1.10981 m
.71478 1.10511 L
s
.70986 1.11187 m
.71403 1.10981 L
s
.71592 .58656 m .71399 .5812 L .71094 .58303 L 0 1 .51 r
F
.71592 .58656 m .72382 .58223 L .71399 .5812 L F
0 g
.70637 .58575 m
.71592 .58656 L
s
.52582 1.0814 m .52975 1.09517 L .52834 1.08969 L 0 0 .116 r
F
.53929 1.12008 m .54469 1.12854 L .54283 1.12685 L 0 .449 0 r
F
.54626 1.13955 m .54469 1.12854 L .54848 1.13595 L 0 .507 .029 r
F
.54626 1.13955 m .54283 1.12685 L .54469 1.12854 L F
0 g
.54357 1.1242 m
.54469 1.12854 L
s
.23799 .7773 m .22713 .77451 L .22631 .7803 L 0 1 .541 r
F
0 g
.21984 .78502 m
.22631 .7803 L
s
.23072 .78135 m
.2335 .7798 L
s
.29795 .69115 m
.2993 .68767 L
s
.28062 .86442 m .27021 .86492 L .27474 .86614 L 0 1 .52 r
F
0 g
.27474 .86614 m
.27641 .86982 L
s
.30557 .87167 m .29502 .86417 L .29183 .8676 L 0 1 .526 r
F
0 g
.29183 .8676 m
.29361 .87135 L
s
.30557 .87167 m .30146 .86288 L .29502 .86417 L 0 1 .526 r
F
.30557 .87167 m .30683 .86461 L .30146 .86288 L F
.30557 .87167 m .30859 .86838 L .30683 .86461 L F
0 g
.29971 .87283 m
.30557 .87167 L
s
.42702 .93071 m .41819 .92355 L .41624 .9228 L 0 .145 .175 r
F
.42702 .93071 m .42279 .92672 L .41819 .92355 L F
.42702 .93071 m .42695 .9302 L .42279 .92672 L F
.42702 .93071 m .42876 .93191 L .42695 .9302 L F
0 g
.42244 .92754 m
.42702 .93071 L
s
.42871 .93186 m
.429 .93205 L
s
.36686 .77306 m .35969 .77155 L .36308 .77192 L 0 .025 0 r
F
.36686 .77306 m .35844 .77283 L .35969 .77155 L F
0 g
.36196 .76962 m
.36307 .77191 L
s
.36307 .77191 m
.36308 .77192 L
s
.36686 .77306 m .36017 .77493 L .35844 .77283 L 0 .025 0 r
F
.36686 .77306 m .36396 .77607 L .36017 .77493 L F
.36686 .77306 m .36728 .7755 L .36396 .77607 L F
.36686 .77306 m .36852 .77421 L .36728 .7755 L F
0 g
.36686 .77306 m
.36814 .77265 L
s
.36308 .77192 m
.36686 .77306 L
s
.52448 1.06598 m
.52466 1.06699 L
s
.33578 .73166 m
.34002 .73091 L
s
.66267 .84259 m .67242 .8496 L .66614 .82595 L 0 .475 .282 r
F
0 g
.66614 .82595 m
.66772 .83191 L
s
.66607 .82484 m
.66614 .82595 L
s
.39544 .68551 m .38754 .67414 L .38378 .67984 L 0 1 .504 r
F
0 g
.37577 .67785 m
.38378 .67984 L
s
.39544 .68551 m .39589 .67115 L .38754 .67414 L 0 1 .504 r
F
.39544 .68551 m .40427 .67221 L .39589 .67115 L F
.39544 .68551 m .40707 .67661 L .40427 .67221 L F
.39544 .68551 m .40328 .68232 L .40707 .67661 L F
0 g
.38709 .68445 m
.39544 .68551 L
s
.72094 .88273 m .73739 .87774 L .73462 .87639 L 0 1 .288 r
F
0 g
.73528 .88035 m
.73739 .87774 L
s
.38428 .89999 m .37389 .89312 L .37496 .89608 L 0 .707 .436 r
F
0 g
.37017 .89521 m
.37496 .89608 L
s
.33266 .68781 m .3207 .68955 L .32417 .69251 L 0 1 .479 r
F
.82906 .93676 m .84177 .94127 L .84055 .92954 L 0 1 .45 r
F
0 g
.83924 .95218 m
.84177 .94127 L
s
.81278 .84052 m .82715 .84597 L .82776 .84094 L 0 1 .516 r
F
0 g
.82715 .84597 m
.83232 .84873 L
s
.27184 .68524 m .26228 .67966 L .25928 .68626 L 0 1 .527 r
F
0 g
.2513 .68934 m
.25928 .68626 L
s
.57685 .62121 m .59611 .61406 L .59 .61295 L 0 1 .509 r
F
0 g
.59611 .61406 m
.60443 .61153 L
s
.50443 .62889 m .49675 .62663 L .49718 .62769 L 0 .721 .262 r
F
.50443 .62889 m .50383 .62639 L .49675 .62663 L F
0 g
.49064 .62888 m
.49718 .62769 L
s
.50443 .62889 m .5137 .62712 L .50383 .62639 L 0 .721 .262 r
F
.50443 .62889 m .52096 .62832 L .5137 .62712 L F
.50443 .62889 m .52075 .62919 L .52096 .62832 L F
.50443 .62889 m .51367 .62943 L .52075 .62919 L F
0 g
.49718 .62769 m
.50443 .62889 L
s
.53062 1.09572 m .52975 1.09517 L .53258 1.10435 L 0 0 .09 r
F
.53062 1.09572 m .52834 1.08969 L .52975 1.09517 L F
0 g
.52897 1.0945 m
.52975 1.09517 L
s
.4226 .79022 m
.42838 .79272 L
s
.46926 .48969 m .45818 .49008 L .45907 .49059 L 0 .747 .231 r
F
0 g
.4504 .49347 m
.45907 .49059 L
s
.46926 .48969 m .46742 .48857 L .45818 .49008 L 0 .747 .231 r
F
.46926 .48969 m .48064 .48705 L .46742 .48857 L F
.46926 .48969 m .49084 .48615 L .48064 .48705 L F
.46926 .48969 m .4912 .48647 L .49084 .48615 L F
.46926 .48969 m .48195 .48798 L .4912 .48647 L F
0 g
.46041 .49119 m
.46926 .48969 L
s
.45907 .49059 m
.46926 .48969 L
s
.48195 .48798 m
.49174 .48676 L
s
.69341 .58747 m
.70334 .58756 L
s
.52308 1.03414 m
.52309 1.03426 L
s
.52309 1.03426 m
.52323 1.03589 L
s
.52323 1.03589 m
.52326 1.03616 L
s
.52326 1.03616 m
.52332 1.0369 L
s
.52332 1.0369 m
.52392 1.04367 L
s
.52386 1.03933 m
.52439 1.04284 L
s
.52439 1.04284 m
.52471 1.04497 L
s
.52308 1.03414 m
.5231 1.0343 L
s
.5231 1.0343 m
.52336 1.036 L
s
.52336 1.036 m
.52342 1.03642 L
s
.52342 1.03642 m
.52352 1.03708 L
s
.52352 1.03708 m
.52386 1.03933 L
s
.78532 1.00164 m .78523 1.01111 L .78856 1.01504 L 0 1 .402 r
F
0 g
.78414 1.02366 m
.78856 1.01504 L
s
.33266 .68781 m .32421 .68127 L .3207 .68955 L 0 1 .479 r
F
.33266 .68781 m .33238 .67318 L .32421 .68127 L F
.33266 .68781 m .34088 .66846 L .33238 .67318 L F
.33266 .68781 m .34404 .67027 L .34088 .66846 L F
.33266 .68781 m .34051 .67856 L .34404 .67027 L F
0 g
.32937 .69726 m
.33266 .68781 L
s
.32417 .69251 m
.33266 .68781 L
s
.78532 1.00164 m .79659 1.00046 L .79672 .99079 L 0 1 .402 r
F
0 g
.7931 1.01084 m
.79659 1.00046 L
s
.79659 1.00046 m
.79991 1.00491 L
s
.44441 .687 m .43556 .68312 L .43725 .68675 L 0 1 .491 r
F
.44441 .687 m .4405 .67797 L .43556 .68312 L F
0 g
.43585 .68845 m
.43725 .68675 L
s
.43289 .69207 m
.43585 .68845 L
s
.44441 .687 m .4488 .67473 L .4405 .67797 L 0 1 .491 r
F
.44441 .687 m .45596 .67499 L .4488 .67473 L F
.44441 .687 m .45722 .67857 L .45596 .67499 L F
.44441 .687 m .45226 .68371 L .45722 .67857 L F
0 g
.43979 .69229 m
.44441 .687 L
s
.43725 .68675 m
.44441 .687 L
s
.45226 .68371 m
.45909 .68404 L
s
.7069 1.12719 m .70406 1.12382 L .70491 1.11747 L 0 0 .049 r
F
0 g
.69921 1.11818 m
.70491 1.11747 L
s
.48462 .67124 m .49288 .66829 L .49883 .66347 L 0 1 .496 r
F
0 g
.49288 .66829 m
.49931 .66879 L
s
.31611 .6633 m .30365 .66424 L .3072 .66538 L 0 1 .541 r
F
.49645 .97495 m .48982 .97621 L .4933 .97475 L 0 .478 .092 r
F
0 g
.4933 .97475 m
.4933 .97475 L
s
.49645 .97495 m .48802 .97919 L .48982 .97621 L 0 .478 .092 r
F
.49645 .97495 m .48911 .98171 L .48802 .97919 L F
.49645 .97495 m .49228 .9819 L .48911 .98171 L F
.49645 .97495 m .49539 .97965 L .49228 .9819 L F
.49645 .97495 m .49718 .97667 L .49539 .97965 L F
0 g
.49645 .97495 m
.49845 .97092 L
s
.4933 .97475 m
.49645 .97495 L
s
.49718 .97667 m
.50006 .97441 L
s
.41624 .9228 m .40762 .91517 L .40545 .91491 L 0 .29 .216 r
F
.41624 .9228 m .41237 .91798 L .40762 .91517 L F
.41624 .9228 m .41654 .92148 L .41237 .91798 L F
.41624 .9228 m .41819 .92355 L .41654 .92148 L F
0 g
.41149 .91998 m
.41624 .9228 L
s
.41624 .9228 m
.41806 .92451 L
s
.41054 .78571 m .40138 .78282 L .40431 .78356 L 0 .331 .188 r
F
0 g
.40282 .78255 m
.40431 .78356 L
s
.52678 .64875 m .5205 .64495 L .52034 .6482 L 0 1 .507 r
F
.52678 .64875 m .52752 .64075 L .5205 .64495 L F
.52678 .64875 m .53673 .6384 L .52752 .64075 L F
.52678 .64875 m .54316 .63896 L .53673 .6384 L F
0 g
.52011 .65316 m
.52678 .64875 L
s
.60897 .60519 m .62783 .60269 L .62998 .60035 L 0 1 .509 r
F
.60897 .60519 m .61883 .60476 L .62783 .60269 L F
0 g
.62783 .60269 m
.6332 .60452 L
s
.61883 .60476 m
.62461 .60619 L
s
.61883 .60476 m
.62783 .60269 L
s
.4725 .96328 m .46442 .95773 L .46858 .9599 L 0 .35 .04 r
F
0 g
.46858 .9599 m
.47104 .95995 L
s
.28062 .86442 m .2694 .86129 L .27021 .86492 L 0 1 .52 r
F
0 g
.26502 .86691 m
.27021 .86492 L
s
.3728 .5201 m .35968 .52282 L .36205 .52388 L 0 1 .448 r
F
0 g
.35536 .53023 m
.36205 .52388 L
s
.3728 .5201 m .36722 .51752 L .35968 .52282 L 0 1 .448 r
F
.3728 .5201 m .37967 .51151 L .36722 .51752 L F
.3728 .5201 m .39044 .50773 L .37967 .51151 L F
.3728 .5201 m .39234 .50868 L .39044 .50773 L F
.3728 .5201 m .38478 .51399 L .39234 .50868 L F
0 g
.3656 .52539 m
.3728 .5201 L
s
.36205 .52388 m
.3728 .5201 L
s
.66267 .84259 m .67696 .87755 L .67242 .8496 L 0 .475 .282 r
F
.66267 .84259 m .67333 .89748 L .67735 .89813 L F
.66267 .84259 m .66702 .87361 L .67333 .89748 L F
0 g
.66719 .89227 m
.66799 .88699 L
s
.66799 .88699 m
.66835 .88463 L
s
.66835 .88463 m
.66839 .88436 L
s
.66215 .88186 m
.66269 .88435 L
s
.66269 .88435 m
.66305 .886 L
s
.66265 .84121 m
.66267 .84259 L
s
.66135 .83652 m
.66267 .84259 L
s
.66839 .88436 m
.66893 .88081 L
s
.37389 .89312 m .36473 .89007 L .36877 .8924 L 0 .866 .473 r
F
0 g
.36877 .8924 m
.37017 .89521 L
s
.75774 .8438 m .77212 .82322 L .7725 .82916 L 0 .03 .052 r
F
0 g
.76152 .83305 m
.76767 .82426 L
s
.76099 .82569 m
.76152 .83305 L
s
.77212 .82322 m
.77757 .81654 L
s
.49941 .84344 m .49492 .84141 L .49579 .83974 L 0 .399 .015 r
F
0 g
.49353 .83435 m
.49579 .83974 L
s
.49941 .84344 m .49762 .84803 L .49492 .84141 L 0 .399 .015 r
F
.49941 .84344 m .5021 .85519 L .49762 .84803 L F
.49941 .84344 m .50574 .85891 L .5021 .85519 L F
.49941 .84344 m .50609 .8567 L .50574 .85891 L F
.49941 .84344 m .50337 .85006 L .50609 .8567 L F
0 g
.49709 .83585 m
.49941 .84344 L
s
.49579 .83974 m
.49941 .84344 L
s
.68268 .72322 m
.68368 .72143 L
s
.68564 .71791 m
.68675 .7159 L
s
.68675 .7159 m
.68707 .71532 L
s
.73312 1.0952 m .73099 1.09672 L .73341 1.09278 L 0 0 0 r
F
0 g
.72707 1.09763 m
.73341 1.09278 L
s
.67398 .74073 m
.67412 .74043 L
s
.73462 .87639 m .74866 .87293 L .74576 .87109 L 0 1 .351 r
F
0 g
.74866 .87293 m
.75424 .87297 L
s
.74742 .87563 m
.74866 .87293 L
s
.8176 .94467 m .81881 .95632 L .82316 .96268 L 0 1 .439 r
F
0 g
.81957 .97259 m
.82316 .96268 L
s
.314 .69163 m .30598 .68845 L .30956 .69131 L 0 1 .488 r
F
.314 .69163 m .30511 .6846 L .30598 .68845 L F
0 g
.30712 .69832 m
.30928 .6921 L
s
.314 .69163 m .30754 .68234 L .30511 .6846 L 0 1 .488 r
F
0 g
.30544 .68863 m
.30597 .68845 L
s
.29795 .69115 m
.30544 .68863 L
s
.314 .69163 m .31199 .68265 L .30754 .68234 L 0 1 .488 r
F
0 g
.30928 .6921 m
.30956 .69132 L
s
.314 .69163 m .31548 .68533 L .31199 .68265 L 0 1 .488 r
F
.314 .69163 m .31633 .68917 L .31548 .68533 L F
0 g
.314 .69163 m
.31491 .69598 L
s
.30956 .69131 m
.314 .69163 L
s
.71896 .71386 m
.72331 .72482 L
s
.71768 .71064 m
.71896 .71386 L
s
.72331 .72482 m
.72333 .72487 L
s
.72333 .72487 m
.72337 .72496 L
s
.72337 .72496 m
.72444 .72766 L
s
.72514 .72941 m
.72601 .7316 L
s
.54316 .63896 m
.5488 .63594 L
s
.5488 .63594 m
.54881 .63594 L
s
.54881 .63594 m
.55041 .63508 L
s
.5275 .63113 m .54425 .63367 L .54426 .63367 L 0 .631 .251 r
F
.55041 .63507 m .54508 .62978 L .54426 .63367 L 0 1 .511 r
F
.52752 .64075 m .54425 .6337 L .54426 .63367 L 0 1 .513 r
F
.54063 .63256 m .54426 .63367 L .54508 .62978 L F
.5275 .63113 m .54426 .63367 L .54063 .63256 L 0 .631 .251 r
F
.5275 .63113 m .53671 .63285 L .54425 .63367 L F
.52752 .64075 m .54426 .63367 L .54063 .63256 L 0 1 .513 r
F
.54063 .63256 m .54426 .63367 L .54086 .63258 L 0 .631 .251 r
F
.54086 .63258 m .54426 .63367 L .54509 .63304 L F
.54464 .63379 m .54426 .63367 L .54438 .63373 L 0 1 .511 r
F
.55041 .63507 m .54426 .63367 L .54464 .63379 L F
.55042 .63642 m .54509 .63304 L .54426 .63367 L 0 .544 .246 r
F
.54438 .63373 m .54426 .63367 L .54425 .63367 L F
.55042 .63642 m .54426 .63367 L .54438 .63373 L F
.54438 .63373 m .54426 .63367 L .54425 .6337 L 0 1 .511 r
F
0 g
.54878 .63593 m
.54878 .63593 L
s
.55041 .63507 m .55295 .62547 L .54508 .62978 L 0 1 .511 r
F
0 g
.5487 .63591 m
.54878 .63593 L
s
.54313 .63426 m
.5487 .63591 L
s
.55041 .63507 m .5626 .62366 L .55295 .62547 L 0 1 .511 r
F
.55041 .63507 m .56874 .62504 L .5626 .62366 L F
.29353 .7714 m .2832 .76983 L .28202 .7741 L 0 1 .521 r
F
0 g
.27528 .77823 m
.28202 .7741 L
s
.72322 .72542 m
.72333 .72506 L
s
.72333 .72506 m
.72337 .72496 L
s
.72337 .72496 m
.72463 .72111 L
s
.66927 .7967 m .67149 .78358 L .66796 .78235 L 0 .525 .326 r
F
0 g
.66796 .78235 m
.66857 .78902 L
s
.66456 .77595 m
.66796 .78235 L
s
.3092 .76636 m
.31621 .76147 L
s
.37389 .89312 m .36393 .8869 L .36473 .89007 L 0 .866 .473 r
F
0 g
.35995 .88972 m
.36473 .89007 L
s
.53343 .98337 m .54014 1.00976 L .53608 .99618 L 0 .482 .168 r
F
.53343 .98337 m .54376 1.01421 L .54014 1.00976 L F
0 g
.53643 .98162 m
.53651 .98181 L
s
.53343 .98337 m .5445 1.00652 L .54376 1.01421 L 0 .482 .168 r
F
.53343 .98337 m .54182 .99366 L .5445 1.00652 L F
0 g
.53651 .98181 m
.53675 .98236 L
s
.53527 .99902 m
.5356 1.00025 L
s
.53343 .98337 m .53752 .98421 L .54182 .99366 L 0 .482 .168 r
F
0 g
.53343 .98337 m
.53365 .98447 L
s
.53335 .9883 m
.53472 .98963 L
s
.53675 .98236 m
.53752 .98421 L
s
.53752 .98421 m
.53752 .98421 L
s
.53752 .9842 m
.53752 .98421 L
s
.53717 .98352 m
.53752 .9842 L
s
.53703 .98323 m
.53717 .98352 L
s
.5319 .98154 m
.53343 .98337 L
s
.5368 .98333 m
.53684 .98338 L
s
.53684 .98338 m
.53686 .9834 L
s
.53686 .9834 m
.53694 .9835 L
s
.53694 .9835 m
.53709 .98368 L
s
.53709 .98368 m
.53715 .98376 L
s
.53715 .98376 m
.53715 .98376 L
s
.53715 .98376 m
.53719 .9838 L
s
.53719 .9838 m
.53724 .98387 L
s
.53724 .98387 m
.53726 .98389 L
s
.53726 .98389 m
.53734 .98399 L
s
.53734 .98399 m
.5375 .98419 L
s
.5375 .98419 m
.53752 .98421 L
s
.71632 .73117 m .71864 .73943 L .71505 .74545 L 0 .053 .092 r
F
.70717 .74622 m .71632 .73117 L .70968 .75525 L 0 .074 .1 r
F
0 g
.71614 .73185 m
.71632 .73117 L
s
.53673 .6384 m
.54316 .63896 L
s
.40545 .91491 m .39703 .9069 L .39465 .90718 L 0 .4 .292 r
F
0 g
.39465 .90718 m
.39616 .90959 L
s
.40545 .91491 m .40195 .9093 L .39703 .9069 L 0 .4 .292 r
F
.40545 .91491 m .40612 .91276 L .40195 .9093 L F
.40545 .91491 m .40762 .91517 L .40612 .91276 L F
0 g
.40054 .91252 m
.40545 .91491 L
s
.40545 .91491 m
.40711 .91697 L
s
.38478 .51399 m
.3952 .51001 L
s
.5275 .63113 m .52096 .62832 L .52075 .62919 L 0 .631 .251 r
F
0 g
.51367 .62943 m
.52075 .62919 L
s
.5275 .63113 m .5285 .62913 L .52096 .62832 L 0 .631 .251 r
F
.5275 .63113 m .53581 .6311 L .5285 .62913 L F
.53581 .6311 m .53599 .6311 L .53514 .63088 L F
.53581 .6311 m .53514 .63088 L .5285 .62913 L F
.53139 .62959 m .53833 .62844 L .54621 .62449 L 0 1 .519 r
F
.53139 .62959 m .53833 .62844 L .53139 .62959 L F
.53138 .6296 m .53833 .62844 L .53138 .62959 L F
.5285 .62913 m .53198 .62983 L .53139 .62959 L 0 .735 .317 r
F
.53138 .6296 m .53141 .6296 L .53137 .6296 L 0 1 .519 r
F
.53141 .6296 m .53833 .62844 L .5314 .62959 L F
.53141 .6296 m .5314 .62959 L .53137 .6296 L F
.53198 .62983 m .53833 .62844 L .53133 .62961 L F
.53599 .6311 m .53833 .62844 L .53198 .62983 L 0 1 .513 r
F
.53599 .6311 m .54508 .62978 L .53833 .62844 L F
.54063 .63256 m .54508 .62978 L .53599 .6311 L F
.53599 .6311 m .54509 .63304 L .53834 .6311 L 0 .631 .251 r
F
.5275 .63113 m .54063 .63256 L .53599 .6311 L F
.54063 .63256 m .54509 .63304 L .53599 .6311 L F
.54057 .6326 m .54063 .63256 L .53599 .6311 L 0 1 .513 r
F
.52752 .64075 m .54057 .6326 L .53599 .6311 L F
.53599 .6311 m .53834 .6311 L .53223 .62988 L 0 .631 .251 r
F
.53599 .6311 m .53223 .62988 L .53198 .62983 L F
.53139 .62959 m .53834 .6311 L .54625 .63195 L 0 .735 .317 r
F
.53198 .62983 m .53834 .6311 L .53139 .62959 L F
.5285 .62913 m .53139 .62959 L .53089 .62939 L F
.5308 .62943 m .54621 .62449 L .54689 .62137 L 0 1 .519 r
F
.53514 .63088 m .53198 .62983 L .5285 .62913 L 0 .631 .251 r
F
.5285 .63059 m .53133 .62961 L .5308 .62943 L 0 1 .519 r
F
.53133 .62961 m .54621 .62449 L .5308 .62943 L F
.53599 .6311 m .53198 .62983 L .53198 .62983 L 0 .631 .251 r
F
.53599 .6311 m .53198 .62983 L .53514 .63088 L F
.53089 .62939 m .54625 .63195 L .54694 .63112 L 0 .735 .317 r
F
.53139 .62959 m .54625 .63195 L .53089 .62939 L F
.53138 .62959 m .53139 .62959 L .53139 .62959 L 0 1 .519 r
F
.53137 .6296 m .53138 .6296 L .53138 .62959 L F
.53015 .6291 m .54689 .62137 L .53964 .62053 L F
.5285 .63059 m .53089 .62939 L .53015 .6291 L F
.53089 .62939 m .54689 .62137 L .53015 .6291 L F
.53015 .6291 m .53089 .62939 L .53018 .6291 L 0 .735 .317 r
F
.5285 .62913 m .52141 .62594 L .52124 .62692 L F
.5285 .62913 m .5287 .62854 L .52141 .62594 L F
.5287 .62854 m .5293 .62253 L .52231 .62603 L 0 1 .519 r
F
.5285 .62913 m .53089 .62939 L .53014 .6291 L 0 .735 .317 r
F
.5287 .62854 m .53964 .62053 L .5293 .62253 L 0 1 .519 r
F
.5285 .62913 m .53015 .6291 L .5287 .62854 L 0 .735 .317 r
F
.5285 .63059 m .53015 .6291 L .5287 .62854 L 0 1 .519 r
F
.53015 .6291 m .53964 .62053 L .5287 .62854 L F
.5287 .62854 m .53018 .6291 L .52872 .62848 L 0 .735 .317 r
F
.53015 .6291 m .53018 .6291 L .5287 .62854 L F
.5287 .62854 m .52931 .62678 L .52231 .62603 L F
.5287 .62854 m .52231 .62603 L .52141 .62594 L F
.5287 .62854 m .5287 .62854 L .52227 .62605 L 0 1 .519 r
F
.5287 .62854 m .52231 .62603 L .52227 .62605 L F
.5285 .63059 m .5287 .62854 L .52141 .62649 L F
.5287 .62854 m .52227 .62605 L .52141 .62649 L F
.53014 .6291 m .53089 .62939 L .53015 .6291 L 0 .735 .317 r
F
.53018 .6291 m .54694 .63112 L .53968 .6289 L F
.53089 .62939 m .54694 .63112 L .53018 .6291 L F
.52872 .62848 m .53968 .6289 L .52931 .62678 L F
.53018 .6291 m .53968 .6289 L .52872 .62848 L F
.53133 .62961 m .53138 .6296 L .53137 .6296 L 0 1 .519 r
F
.5285 .63059 m .53198 .62983 L .53133 .62961 L F
.52752 .64075 m .53599 .6311 L .5285 .63059 L 0 1 .513 r
F
.53599 .6311 m .53198 .62983 L .5285 .63059 L F
0 g
.52075 .62919 m
.5275 .63113 L
s
.543 .63423 m
.54313 .63426 L
s
.48462 .67124 m .47703 .66727 L .47783 .67081 L 0 1 .496 r
F
.48462 .67124 m .48299 .66244 L .47703 .66727 L F
.48462 .67124 m .49172 .65955 L .48299 .66244 L F
.48462 .67124 m .49851 .65999 L .49172 .65955 L F
.48462 .67124 m .49883 .66347 L .49851 .65999 L F
0 g
.49288 .66829 m
.49652 .66534 L
s
.49652 .66534 m
.49883 .66347 L
s
.47901 .67622 m
.48462 .67124 L
s
.49883 .66347 m
.50531 .66396 L
s
.80814 .98118 m .81628 .96765 L .8117 .97114 L 0 1 .436 r
F
.79672 .99079 m .80814 .98118 L .80483 .97668 L 0 1 .42 r
F
.53612 .95875 m .54044 .95157 L .53747 .95362 L 0 .26 .268 r
F
0 g
.53432 .95173 m
.53747 .95362 L
s
.53612 .95875 m .54065 .96835 L .54402 .96994 L 0 .26 .268 r
F
0 g
.53827 .96968 m
.53874 .97047 L
s
.54356 .97329 m
.54458 .96782 L
s
.54239 .96917 m
.54356 .97329 L
s
.53612 .95875 m .53727 .96355 L .54065 .96835 L 0 .26 .268 r
F
0 g
.53561 .96516 m
.53827 .96968 L
s
.53561 .96516 m
.53727 .96355 L
s
.53612 .95875 m
.53747 .95362 L
s
.53303 .95493 m
.53612 .95875 L
s
.38378 .67984 m
.38754 .67414 L
s
.53062 1.09572 m .52871 1.08992 L .52834 1.08969 L 0 0 .09 r
F
0 g
.52582 1.0814 m
.52834 1.08969 L
s
.50107 .48677 m .49084 .48615 L .4912 .48647 L 0 .602 .208 r
F
.50107 .48677 m .50056 .48615 L .49084 .48615 L F
0 g
.48195 .48798 m
.4912 .48647 L
s
.50107 .48677 m .51389 .48645 L .50056 .48615 L 0 .602 .208 r
F
.50107 .48677 m .52376 .48676 L .51389 .48645 L F
.50107 .48677 m .52359 .48685 L .52376 .48676 L F
0 g
.52361 .48684 m
.52452 .487 L
s
.50107 .48677 m .51386 .48686 L .52359 .48685 L 0 .602 .208 r
F
0 g
.49174 .48676 m
.50107 .48677 L
s
.4912 .48647 m
.50107 .48677 L
s
.34051 .67856 m
.34877 .67267 L
s
.56874 .62504 m
.57685 .62121 L
s
.5488 1.01584 m
.54992 1.01857 L
s
.5488 1.01583 m
.5488 1.01584 L
s
.54992 1.01857 m
.54994 1.01861 L
s
.57685 .62121 m .57189 .61721 L .57071 .62012 L 0 1 .509 r
F
.57685 .62121 m .58017 .61413 L .57189 .61721 L F
.57685 .62121 m .59 .61295 L .58017 .61413 L F
0 g
.31633 .68917 m
.3207 .68956 L
s
.3207 .68955 m
.3207 .68955 L
s
.71339 .7583 m
.72057 .77849 L
s
.74576 .87109 m .75993 .86812 L .7569 .86578 L 0 1 .399 r
F
0 g
.75993 .86812 m
.76561 .86856 L
s
.75879 .8712 m
.75993 .86812 L
s
.73023 .71906 m
.73033 .7188 L
s
.73043 .71853 m
.73081 .71756 L
s
.73081 .71756 m
.73283 .71228 L
s
.73033 .7188 m
.73043 .71853 L
s
.53497 1.11112 m .53929 1.12008 L .54004 1.12277 L 0 .404 0 r
F
.55042 .63642 m .55301 .63505 L .54509 .63304 L 0 .544 .246 r
F
0 g
.54438 .63373 m
.54549 .63423 L
s
.55042 .63642 m .56272 .63837 L .55301 .63505 L 0 .544 .246 r
F
.55042 .63642 m .56889 .64111 L .56272 .63837 L F
.55042 .63642 m .56741 .64146 L .56889 .64111 L F
.55042 .63642 m .5595 .63945 L .56741 .64146 L F
0 g
.54549 .63423 m
.55042 .63642 L
s
.5595 .63945 m
.56546 .64163 L
s
.42041 .6863 m .41076 .68259 L .41289 .68616 L 0 1 .496 r
F
.42041 .6863 m .41542 .67745 L .41076 .68259 L F
0 g
.41172 .68769 m
.41289 .68616 L
s
.40888 .69143 m
.41172 .68769 L
s
.42041 .6863 m .42376 .67416 L .41542 .67745 L 0 1 .496 r
F
.42041 .6863 m .4313 .67431 L .42376 .67416 L F
.42041 .6863 m .43301 .67779 L .4313 .67431 L F
.42041 .6863 m .42834 .68293 L .43301 .67779 L F
0 g
.41607 .69162 m
.42041 .6863 L
s
.41289 .68616 m
.42041 .6863 L
s
.46423 .67891 m .45596 .67499 L .45722 .67857 L 0 1 .493 r
F
.46423 .67891 m .46145 .66999 L .45596 .67499 L F
0 g
.45585 .67998 m
.45722 .67857 L
s
.45226 .68371 m
.45585 .67998 L
s
.46423 .67891 m .47001 .66692 L .46145 .66999 L 0 1 .493 r
F
.46423 .67891 m .47703 .66727 L .47001 .66692 L F
.46423 .67891 m .47783 .67081 L .47703 .66727 L F
.46423 .67891 m .47234 .6758 L .47783 .67081 L F
0 g
.47783 .67081 m
.48462 .67124 L
s
.45909 .68404 m
.46423 .67891 L
s
.45722 .67857 m
.46423 .67891 L
s
.47234 .6758 m
.47901 .67622 L
s
.69088 .7093 m
.69213 .70741 L
s
.69213 .70741 m
.6963 .7011 L
s
.4725 .96328 m .46229 .95789 L .46442 .95773 L 0 .35 .04 r
F
0 g
.46047 .95455 m
.46442 .95773 L
s
.57294 .64511 m .58178 .64962 L .58998 .65297 L 0 .474 .249 r
F
0 g
.58883 .65375 m
.59481 .65766 L
s
.58722 .6527 m
.58883 .65375 L
s
.47617 .67232 m
.47783 .67081 L
s
.47234 .6758 m
.47617 .67232 L
s
.33372 .74638 m
.33538 .7453 L
s
.57294 .64511 m .56889 .64111 L .56741 .64146 L 0 .474 .249 r
F
0 g
.5595 .63945 m
.56741 .64146 L
s
.57294 .64511 m .57709 .64446 L .56889 .64111 L 0 .474 .249 r
F
.57294 .64511 m .58655 .64927 L .57709 .64446 L F
.57294 .64511 m .59207 .65291 L .58655 .64927 L F
.57294 .64511 m .58998 .65297 L .59207 .65291 L F
0 g
.58178 .64962 m
.58804 .65218 L
s
.56741 .64146 m
.57294 .64511 L
s
.63891 .5989 m .63537 .59449 L .63321 .59683 L 0 1 .501 r
F
.63891 .5989 m .64464 .59326 L .63537 .59449 L F
.63891 .5989 m .65481 .59397 L .64464 .59326 L F
.29353 .7714 m .289 .76483 L .2832 .76983 L 0 1 .521 r
F
.29353 .7714 m .29635 .76141 L .289 .76483 L F
.29353 .7714 m .30032 .76186 L .29635 .76141 L F
.29353 .7714 m .2991 .76615 L .30032 .76186 L F
0 g
.29251 .77573 m
.29353 .7714 L
s
.28621 .7748 m
.29353 .7714 L
s
.22713 .77451 m .2153 .77757 L .21971 .77868 L 0 1 .541 r
F
0 g
.21971 .77868 m
.21984 .78502 L
s
.64464 .59326 m .66437 .59295 L .66698 .59088 L 0 1 .51 r
F
.64464 .59326 m .65481 .59397 L .66437 .59295 L F
0 g
.66437 .59295 m
.6695 .59547 L
s
.65481 .59397 m
.66437 .59295 L
s
.65481 .59397 m
.66046 .59603 L
s
.51386 .48686 m
.52199 .48685 L
s
.2694 .86129 m .25888 .86186 L .26341 .86308 L 0 1 .518 r
F
0 g
.26341 .86308 m
.26502 .86691 L
s
.59481 .65766 m .59207 .65291 L .58998 .65297 L 0 .428 .299 r
F
0 g
.58804 .65218 m
.58998 .65297 L
s
.59481 .65766 m .60048 .65773 L .59207 .65291 L 0 .428 .299 r
F
0 g
.58998 .65297 m
.5945 .65736 L
s
.59481 .65766 m .60959 .6642 L .60048 .65773 L 0 .428 .299 r
F
0 g
.60676 .66679 m
.60819 .66801 L
s
.59481 .65766 m .61441 .66889 L .60959 .6642 L 0 .428 .299 r
F
0 g
.60466 .665 m
.60676 .66679 L
s
.60819 .66801 m
.60904 .66874 L
s
.59481 .65766 m .61173 .66868 L .61441 .66889 L 0 .428 .299 r
F
0 g
.6098 .66941 m
.6158 .67463 L
s
.60904 .66874 m
.6098 .66941 L
s
.59481 .65766 m .60333 .66387 L .61173 .66868 L 0 .428 .299 r
F
0 g
.60333 .66387 m
.60466 .665 L
s
.5945 .65736 m
.59481 .65766 L
s
.68786 .89345 m
.68817 .89351 L
s
.52624 1.07232 m .52481 1.0709 L .52623 1.07929 L 0 0 .132 r
F
.52624 1.07232 m .52482 1.06792 L .52481 1.0709 L F
0 g
.52287 1.0623 m
.52481 1.0709 L
s
.52481 1.0709 m
.52482 1.06792 L
s
.52466 1.06699 m
.52482 1.06792 L
s
.54626 1.13955 m .54848 1.13595 L .5517 1.14418 L 0 .507 .029 r
F
0 g
.54469 1.12854 m
.54848 1.13595 L
s
.54746 1.12997 m
.54848 1.13595 L
s
.36393 .8869 m .35461 .88454 L .35866 .8867 L 0 .998 .497 r
F
0 g
.35866 .8867 m
.35995 .88972 L
s
.66335 .75657 m .66436 .74609 L .66115 .74525 L 0 .502 .357 r
F
0 g
.66115 .74525 m
.66234 .75134 L
s
.66234 .75134 m
.66335 .75657 L
s
.66109 .74517 m
.66115 .74525 L
s
.66147 .75304 m
.66335 .75657 L
s
.60333 .66387 m
.61007 .66773 L
s
.38212 .77724 m .37416 .77654 L .37224 .77527 L 0 0 0 r
F
.38212 .77724 m .38002 .77851 L .37416 .77654 L F
.38212 .77724 m .38666 .78023 L .38002 .77851 L F
.38212 .77724 m .38962 .78055 L .38666 .78023 L F
.38212 .77724 m .38767 .77927 L .38962 .78055 L F
0 g
.38043 .77616 m
.38212 .77724 L
s
.37552 .77553 m
.38212 .77724 L
s
.27184 .68524 m .27022 .67306 L .26228 .67966 L 0 1 .527 r
F
.27184 .68524 m .27891 .66981 L .27022 .67306 L F
.27184 .68524 m .28254 .67209 L .27891 .66981 L F
.27184 .68524 m .2795 .67872 L .28254 .67209 L F
0 g
.26904 .69189 m
.27184 .68524 L
s
.26319 .68846 m
.27184 .68524 L
s
.31548 .68533 m
.31633 .68917 L
s
.39465 .90718 m .38686 .89918 L .38428 .89999 L 0 .525 .379 r
F
.39465 .90718 m .39181 .90101 L .38686 .89918 L F
.39465 .90718 m .39582 .90426 L .39181 .90101 L F
.39465 .90718 m .39703 .9069 L .39582 .90426 L F
0 g
.38971 .90535 m
.39465 .90718 L
s
.4725 .96328 m .46361 .96026 L .46229 .95789 L 0 .35 .04 r
F
.4725 .96328 m .46753 .96365 L .46361 .96026 L F
.4725 .96328 m .47144 .96578 L .46753 .96365 L F
.4725 .96328 m .47356 .96562 L .47144 .96578 L F
0 g
.4725 .96328 m
.47482 .96246 L
s
.46858 .9599 m
.4725 .96328 L
s
.29661 .66631 m .28834 .6656 L .292 .66672 L 0 1 .538 r
F
.29661 .66631 m .28755 .66338 L .28834 .6656 L F
.29661 .66631 m .29016 .66153 L .28755 .66338 L F
.29661 .66631 m .29478 .66112 L .29016 .66153 L F
.29661 .66631 m .29833 .66241 L .29478 .66112 L F
.29661 .66631 m .29911 .66464 L .29833 .66241 L F
0 g
.29661 .66631 m
.29747 .66825 L
s
.292 .66672 m
.29661 .66631 L
s
.52416 1.04636 m .52326 1.04378 L .52399 1.05196 L 0 .071 .175 r
F
0 g
.52391 1.05097 m
.52395 1.05148 L
s
.52375 1.04927 m
.52391 1.05097 L
s
.52352 1.04673 m
.52375 1.04927 L
s
.52344 1.04584 m
.52352 1.04673 L
s
.52344 1.04584 m
.52344 1.04584 L
s
.52337 1.04507 m
.52344 1.04584 L
s
.52334 1.04472 m
.52337 1.04507 L
s
.52328 1.0441 m
.52334 1.04472 L
s
.52326 1.04378 m
.52328 1.0441 L
s
.52392 1.04367 m
.52408 1.04549 L
s
.52408 1.04549 m
.52409 1.04559 L
s
.5238 1.05086 m
.5239 1.05143 L
s
.52346 1.0489 m
.5238 1.05086 L
s
.5229 1.04568 m
.52346 1.0489 L
s
.5232 1.04336 m
.52326 1.04378 L
s
.50128 .97998 m
.50175 .97807 L
s
.4549 .80731 m .44731 .80274 L .44954 .80366 L 0 0 0 r
F
0 g
.45294 .80477 m
.4549 .80731 L
s
.44772 .8019 m
.44954 .80366 L
s
.36852 .77421 m
.37223 .77527 L
s
.53303 .48848 m .52376 .48676 L .52359 .48685 L 0 0 0 r
F
0 g
.52199 .48685 m
.52359 .48685 L
s
.53303 .48848 m .53386 .48841 L .52376 .48676 L 0 0 0 r
F
.53303 .48848 m .54715 .49072 L .53386 .48841 L F
0 g
.52359 .48685 m
.53303 .48848 L
s
.67633 .59054 m .67352 .58567 L .6709 .58776 L 0 1 .504 r
F
.52624 1.07232 m .52623 1.07929 L .52871 1.08992 L 0 0 .132 r
F
0 g
.52582 1.0814 m
.52623 1.07929 L
s
.6158 .67463 m .61441 .66889 L .61173 .66868 L 0 .405 .36 r
F
0 g
.61007 .66773 m
.61173 .66868 L
s
.6158 .67463 m .62293 .67529 L .61441 .66889 L 0 .405 .36 r
F
0 g
.61173 .66868 m
.61442 .6726 L
s
.6158 .67463 m .63159 .68361 L .62293 .67529 L 0 .405 .36 r
F
.6158 .67463 m .63566 .68956 L .63159 .68361 L F
0 g
.6277 .68763 m
.62815 .6882 L
s
.62815 .6882 m
.62823 .68829 L
s
.6158 .67463 m .63243 .68917 L .63566 .68956 L 0 .405 .36 r
F
0 g
.62976 .68999 m
.63572 .69663 L
s
.62823 .68829 m
.62976 .68999 L
s
.6158 .67463 m .62392 .68277 L .63243 .68917 L 0 .405 .36 r
F
0 g
.62392 .68277 m
.6277 .68763 L
s
.61442 .6726 m
.6158 .67463 L
s
.55449 .49199 m
.55588 .49222 L
s
.66927 .7967 m .67829 .79896 L .67149 .78358 L 0 .525 .326 r
F
.66927 .7967 m .68384 .81828 L .67829 .79896 L F
.66927 .7967 m .68517 .8327 L .68384 .81828 L F
.66927 .7967 m .68138 .83257 L .68517 .8327 L F
.66927 .7967 m .67457 .81712 L .68138 .83257 L F
0 g
.66715 .79122 m
.66927 .7967 L
s
.66857 .78902 m
.66927 .7967 L
s
.66772 .83191 m
.67036 .84186 L
s
.34962 .76786 m
.35123 .76935 L
s
.34946 .76771 m
.34962 .76786 L
s
.34472 .76332 m
.34557 .7641 L
s
.34704 .76546 m
.34946 .76771 L
s
.34556 .76006 m
.34556 .76004 L
s
.34555 .76009 m
.34556 .76006 L
s
.34472 .76332 m
.34495 .76243 L
s
.34554 .76011 m
.34555 .76009 L
s
.76851 .8382 m .7788 .82155 L .78326 .82038 L 0 0 .029 r
F
.76851 .8382 m .7725 .82916 L .7788 .82155 L F
0 g
.77757 .81654 m
.7788 .82155 L
s
.41054 .78571 m .40351 .78363 L .40138 .78282 L 0 .331 .188 r
F
0 g
.39526 .78074 m
.40138 .78282 L
s
.41054 .78571 m .40928 .78544 L .40351 .78363 L 0 .331 .188 r
F
.41054 .78571 m .41555 .78761 L .40928 .78544 L F
.41054 .78571 m .4181 .78867 L .41555 .78761 L F
.41054 .78571 m .41595 .78786 L .4181 .78867 L F
0 g
.40869 .78469 m
.41054 .78571 L
s
.40431 .78356 m
.41054 .78571 L
s
.36728 .7755 m
.36852 .77421 L
s
.26228 .67966 m .24949 .68093 L .25341 .68303 L 0 1 .531 r
F
0 g
.2513 .68934 m
.25341 .68303 L
s
.36393 .8869 m .35396 .8811 L .35461 .88454 L 0 .998 .497 r
F
0 g
.34972 .88462 m
.35461 .88454 L
s
.55598 .49225 m
.55628 .49236 L
s
.56478 .49533 m .56695 .49584 L .55659 .49235 L 0 .378 .194 r
F
.56478 .49533 m .58005 .50035 L .56695 .49584 L F
.56478 .49533 m .58771 .5031 L .58895 .50346 L F
.56478 .49533 m .57735 .49962 L .58771 .5031 L F
0 g
.55628 .49236 m
.56478 .49533 L
s
.29183 .8676 m .28395 .8609 L .28062 .86442 L 0 1 .523 r
F
.29183 .8676 m .28974 .85926 L .28395 .8609 L F
.29183 .8676 m .29413 .86059 L .28974 .85926 L F
.29183 .8676 m .29502 .86417 L .29413 .86059 L F
0 g
.28605 .86923 m
.29183 .8676 L
s
.35287 .66483 m .34104 .66295 L .34418 .66507 L 0 1 .534 r
F
0 g
.34082 .66769 m
.34418 .66507 L
s
.7569 .86578 m .77121 .86337 L .76805 .86052 L 0 1 .436 r
F
0 g
.77121 .86337 m
.77699 .8642 L
s
.77016 .86681 m
.77121 .86337 L
s
.2694 .86129 m .25816 .85813 L .25888 .86186 L 0 1 .518 r
F
0 g
.25362 .86402 m
.25888 .86186 L
s
.62392 .68277 m
.63114 .68821 L
s
.71534 .67254 m .71516 .65698 L .71167 .65613 L 0 .52 .351 r
F
0 g
.71167 .65613 m
.71534 .67254 L
s
.70219 .64092 m
.71167 .65613 L
s
.7077 .65699 m
.71534 .67254 L
s
.53062 1.09572 m .53258 1.10435 L .53497 1.11112 L 0 0 .09 r
F
0 g
.52975 1.09517 m
.53258 1.10435 L
s
.70717 .74622 m .70968 .75525 L .70612 .76229 L 0 .074 .1 r
F
.6981 .76424 m .70717 .74622 L .7008 .77389 L 0 .09 .106 r
F
0 g
.70432 .7586 m
.71034 .77761 L
s
.52877 .98567 m
.53001 .98793 L
s
.50369 .85022 m
.50662 .85162 L
s
.50337 .85006 m
.50369 .85022 L
s
.51861 .86603 m .51628 .87062 L .51611 .86464 L 0 .664 .076 r
F
0 g
.51611 .86464 m
.51667 .86495 L
s
.51383 .85684 m
.51611 .86464 L
s
.51861 .86603 m .51942 .88251 L .51628 .87062 L 0 .664 .076 r
F
.51861 .86603 m .52346 .89237 L .51942 .88251 L F
.51861 .86603 m .52597 .89375 L .52346 .89237 L F
.51861 .86603 m .52527 .88572 L .52597 .89375 L F
0 g
.52631 .88134 m
.52699 .88484 L
s
.51861 .86603 m .52212 .87385 L .52527 .88572 L 0 .664 .076 r
F
0 g
.52212 .87385 m
.52423 .87072 L
s
.51808 .86356 m
.51861 .86603 L
s
.51667 .86495 m
.51861 .86603 L
s
.52423 .87072 m
.52631 .88134 L
s
.40328 .68232 m
.41076 .68259 L
s
.38428 .89999 m .37668 .89175 L .37389 .89312 L 0 .707 .436 r
F
0 g
.37389 .89312 m
.37496 .89608 L
s
.38428 .89999 m .38179 .89308 L .37668 .89175 L 0 .707 .436 r
F
.38428 .89999 m .3858 .89622 L .38179 .89308 L F
.38428 .89999 m .38686 .89918 L .3858 .89622 L F
0 g
.37918 .89866 m
.38428 .89999 L
s
.38428 .89999 m
.3855 .90264 L
s
.31611 .6633 m .30753 .65987 L .30365 .66424 L 0 1 .541 r
F
.31611 .6633 m .31627 .65517 L .30753 .65987 L F
.31611 .6633 m .32522 .65307 L .31627 .65517 L F
.31611 .6633 m .3284 .65499 L .32522 .65307 L F
.31611 .6633 m .32448 .65938 L .3284 .65499 L F
0 g
.31251 .66693 m
.31611 .6633 L
s
.3072 .66538 m
.31611 .6633 L
s
.4549 .80731 m .44966 .80482 L .44731 .80274 L 0 0 0 r
F
.4549 .80731 m .45504 .80853 L .44966 .80482 L F
.4549 .80731 m .46042 .81219 L .45504 .80853 L F
.4549 .80731 m .4622 .81335 L .46042 .81219 L F
.4549 .80731 m .45983 .81125 L .4622 .81335 L F
0 g
.44954 .80366 m
.4549 .80731 L
s
.8176 .94467 m .83028 .94844 L .82906 .93676 L 0 1 .439 r
F
0 g
.82776 .95953 m
.83028 .94844 L
s
.83028 .94844 m
.83465 .95504 L
s
.59598 .50789 m .58895 .50346 L .58771 .5031 L 0 .333 .208 r
F
0 g
.58771 .5031 m
.5878 .50316 L
s
.5878 .50316 m
.59487 .50725 L
s
.57735 .49962 m
.58771 .5031 L
s
.59598 .50789 m .61224 .51585 L .59946 .50892 L 0 .333 .208 r
F
0 g
.61251 .51699 m
.61613 .51898 L
s
.59598 .50789 m .62051 .52063 L .61224 .51585 L 0 .333 .208 r
F
0 g
.60995 .51557 m
.61251 .51699 L
s
.61613 .51898 m
.61686 .51955 L
s
.59598 .50789 m .61875 .52009 L .62051 .52063 L 0 .333 .208 r
F
0 g
.61686 .51955 m
.61737 .51994 L
s
.59598 .50789 m .60824 .51463 L .61875 .52009 L 0 .333 .208 r
F
0 g
.60824 .51463 m
.60995 .51557 L
s
.59487 .50725 m
.59598 .50789 L
s
.58734 .50312 m
.59598 .50789 L
s
.38136 .65286 m .36993 .65467 L .37269 .65587 L 0 1 .506 r
F
0 g
.36862 .66228 m
.37269 .65587 L
s
.38136 .65286 m .37476 .6498 L .36993 .65467 L 0 1 .506 r
F
.38136 .65286 m .38399 .64451 L .37476 .6498 L F
.38136 .65286 m .39268 .64149 L .38399 .64451 L F
.38136 .65286 m .39501 .64277 L .39268 .64149 L F
.38136 .65286 m .39015 .64764 L .39501 .64277 L F
0 g
.37684 .6574 m
.38136 .65286 L
s
.37269 .65587 m
.38136 .65286 L
s
.23799 .7773 m .23263 .76783 L .22713 .77451 L 0 1 .541 r
F
.23799 .7773 m .23995 .76375 L .23263 .76783 L F
.23799 .7773 m .24416 .76502 L .23995 .76375 L F
.23799 .7773 m .24332 .77083 L .24416 .76502 L F
0 g
.2335 .7798 m
.23799 .7773 L
s
.23731 .78288 m
.23799 .7773 L
s
.66616 .75909 m
.66841 .75303 L
s
.66841 .75303 m
.66844 .75296 L
s
.66844 .75296 m
.66865 .75238 L
s
.66865 .75238 m
.66885 .75185 L
s
.54626 1.13955 m .5435 1.13156 L .54283 1.12685 L 0 .507 .029 r
F
0 g
.53929 1.12008 m
.54283 1.12685 L
s
.66978 1.1599 m .671 1.13457 L .67632 1.13717 L 0 .273 .105 r
F
.66978 1.1599 m .66717 1.13893 L .671 1.13457 L F
0 g
.6709 1.12574 m
.671 1.13457 L
s
.22713 .77451 m .21625 .77157 L .2153 .77757 L 0 1 .541 r
F
0 g
.20872 .78243 m
.2153 .77757 L
s
.21971 .77868 m
.22349 .77655 L
s
.52416 1.04636 m .52399 1.05196 L .52589 1.06548 L 0 .071 .175 r
F
0 g
.5239 1.05143 m
.52399 1.05196 L
s
.52395 1.05148 m
.52399 1.05196 L
s
.52269 1.05572 m
.52448 1.06598 L
s
.80615 .95338 m .81628 .96765 L .81881 .95632 L 0 1 .427 r
F
.80615 .95338 m .8117 .97114 L .81628 .96765 L F
0 g
.81628 .96765 m
.81957 .97259 L
s
.29911 .66464 m
.30365 .66424 L
s
.7435 .70051 m
.74394 .69822 L
s
.73703 .71308 m
.73745 .71212 L
s
.7394 .70776 m
.73961 .70729 L
s
.73774 .71147 m
.7394 .70776 L
s
.73745 .71212 m
.73774 .71147 L
s
.7432 .69926 m
.74378 .69795 L
s
.46229 .95789 m .45401 .95124 L .45817 .95402 L 0 .291 0 r
F
0 g
.45817 .95402 m
.46047 .95455 L
s
.60824 .51463 m
.61799 .5197 L
s
.54825 1.01609 m
.54884 1.0174 L
s
.54569 1.01035 m
.54578 1.01057 L
s
.54569 1.01035 m
.54664 1.01266 L
s
.54899 1.01833 m
.54903 1.01844 L
s
.5487 1.01764 m
.54899 1.01833 L
s
.54868 1.0176 m
.5487 1.01764 L
s
.53727 .96355 m
.53752 .9639 L
s
.42834 .68293 m
.43556 .68312 L
s
.4848 .97151 m .47729 .96812 L .48118 .96909 L 0 .429 .07 r
F
0 g
.48118 .96909 m
.4835 .96826 L
s
.35396 .8811 m .34448 .87946 L .34853 .88144 L 0 1 .513 r
F
0 g
.34853 .88144 m
.34972 .88462 L
s
.50486 .65536 m .51364 .65266 L .52034 .6482 L 0 1 .506 r
F
0 g
.51364 .65266 m
.52011 .65316 L
s
.4848 .97151 m .47528 .96934 L .47729 .96812 L 0 .429 .07 r
F
.4848 .97151 m .47651 .97195 L .47528 .96934 L F
.4848 .97151 m .48014 .97438 L .47651 .97195 L F
.4848 .97151 m .48373 .975 L .48014 .97438 L F
.4848 .97151 m .48572 .97377 L .48373 .975 L F
0 g
.4848 .97151 m
.48703 .96935 L
s
.48118 .96909 m
.4848 .97151 L
s
.44923 .63155 m
.45516 .62952 L
s
.76805 .86052 m .7825 .85869 L .77922 .85535 L 0 1 .464 r
F
0 g
.7825 .85869 m
.78837 .85991 L
s
.78154 .86248 m
.7825 .85869 L
s
.76851 .8382 m .78326 .82038 L .78348 .82511 L 0 0 .029 r
F
0 g
.78326 .82038 m
.78881 .8146 L
s
.63572 .69663 m .63566 .68956 L .63243 .68917 L 0 .456 .392 r
F
0 g
.63114 .68821 m
.63243 .68917 L
s
.63572 .69663 m .6442 .69762 L .63566 .68956 L 0 .456 .392 r
F
.63572 .69663 m .65235 .70798 L .6442 .69762 L F
.63572 .69663 m .65564 .71544 L .65235 .70798 L F
.63572 .69663 m .65188 .71504 L .65564 .71544 L F
0 g
.64851 .71618 m
.65438 .72432 L
s
.64693 .714 m
.64851 .71618 L
s
.63572 .69663 m .64335 .70697 L .65188 .71504 L 0 .456 .392 r
F
0 g
.64335 .70697 m
.64693 .714 L
s
.63243 .68917 m
.63572 .69663 L
s
.60897 .60519 m .62998 .60035 L .62386 .59871 L 0 1 .509 r
F
0 g
.62998 .60035 m
.63891 .5989 L
s
.41076 .68259 m
.41542 .67745 L
s
.70694 .68709 m .70745 .68612 L .70412 .69035 L 0 0 0 r
F
.70694 .68709 m .7155 .67738 L .70745 .68612 L F
0 g
.69914 .69706 m
.70694 .68709 L
s
.67816 .89323 m
.67906 .89303 L
s
.67906 .89303 m
.68058 .89268 L
s
.28874 .6847 m
.29043 .68074 L
s
.66301 .88591 m
.66305 .88601 L
s
.66297 .88581 m
.66301 .88591 L
s
.66286 .88553 m
.66297 .88581 L
s
.66264 .88498 m
.66286 .88553 L
s
.66216 .88377 m
.66264 .88498 L
s
.66205 .8835 m
.66216 .88377 L
s
.25816 .85813 m .24753 .85878 L .25207 .86002 L 0 1 .517 r
F
0 g
.25207 .86002 m
.25362 .86402 L
s
.29833 .66241 m
.29911 .66464 L
s
.48662 .83235 m .48095 .82812 L .48232 .82802 L 0 .261 0 r
F
0 g
.48017 .82427 m
.48232 .82802 L
s
.48662 .83235 m .48357 .83267 L .48095 .82812 L 0 .261 0 r
F
.48662 .83235 m .48844 .83865 L .48357 .83267 L F
.48662 .83235 m .49276 .843 L .48844 .83865 L F
.48662 .83235 m .49362 .84281 L .49276 .843 L F
.48662 .83235 m .49099 .83824 L .49362 .84281 L F
0 g
.48437 .82697 m
.48662 .83235 L
s
.48232 .82802 m
.48662 .83235 L
s
.2832 .76983 m .27152 .77206 L .27572 .77293 L 0 1 .533 r
F
0 g
.27528 .77823 m
.27572 .77293 L
s
.52416 1.04636 m .52897 1.07513 L .52661 1.05979 L 0 .071 .175 r
F
.52416 1.04636 m .52971 1.08335 L .52897 1.07513 L F
.52416 1.04636 m .52834 1.07893 L .52971 1.08335 L F
.52416 1.04636 m .52589 1.06548 L .52834 1.07893 L F
0 g
.52409 1.04559 m
.52416 1.04636 L
s
.52538 1.04937 m
.52541 1.04959 L
s
.52541 1.04959 m
.52543 1.04968 L
s
.52528 1.04873 m
.52538 1.04937 L
s
.52506 1.04726 m
.52513 1.04776 L
s
.52513 1.04776 m
.52528 1.04873 L
s
.52471 1.04497 m
.52506 1.04726 L
s
.52416 1.04636 m
.52428 1.04702 L
s
.52428 1.04702 m
.52429 1.04705 L
s
.52429 1.04705 m
.52441 1.04772 L
s
.52441 1.04772 m
.52443 1.04785 L
s
.52443 1.04785 m
.52468 1.04921 L
s
.52468 1.04921 m
.52472 1.04942 L
s
.52485 1.05015 m
.52518 1.05193 L
s
.52472 1.04942 m
.52485 1.05015 L
s
.52518 1.05193 m
.5255 1.0537 L
s
.47169 .81957 m .46494 .81472 L .46679 .81539 L 0 .099 0 r
F
0 g
.46557 .81381 m
.46679 .81539 L
s
.37389 .89312 m .36692 .88499 L .36393 .8869 L 0 .866 .473 r
F
.37389 .89312 m .37205 .8857 L .36692 .88499 L F
.37389 .89312 m .3759 .88857 L .37205 .8857 L F
.37389 .89312 m .37668 .89175 L .3759 .88857 L F
0 g
.36877 .8924 m
.37389 .89312 L
s
.62631 .52676 m .62051 .52063 L .61875 .52009 L 0 .332 .226 r
F
0 g
.61799 .5197 m
.61875 .52009 L
s
.62631 .52676 m .63106 .5282 L .62051 .52063 L 0 .332 .226 r
F
.62631 .52676 m .64338 .53774 L .63106 .5282 L F
.62631 .52676 m .65094 .54441 L .64338 .53774 L F
.62631 .52676 m .64869 .54376 L .65094 .54441 L F
0 g
.64533 .54248 m
.64657 .54371 L
s
.62631 .52676 m .63814 .5362 L .64869 .54376 L 0 .332 .226 r
F
0 g
.63814 .5362 m
.64533 .54248 L
s
.61737 .51994 m
.62631 .52676 L
s
.61875 .52009 m
.62631 .52676 L
s
.46229 .95789 m .45208 .95082 L .45401 .95124 L 0 .291 0 r
F
0 g
.4499 .94774 m
.45401 .95124 L
s
.35396 .8811 m .34396 .8758 L .34448 .87946 L 0 1 .513 r
F
0 g
.33947 .87994 m
.34448 .87946 L
s
.26228 .67966 m .25269 .67434 L .24949 .68093 L 0 1 .531 r
F
0 g
.24132 .6843 m
.24949 .68093 L
s
.5249 1.03887 m
.52546 1.04411 L
s
.52546 1.04411 m
.52553 1.04482 L
s
.52553 1.04482 m
.52583 1.04759 L
s
.52583 1.04759 m
.52585 1.04786 L
s
.526 1.04584 m
.5263 1.04769 L
s
.5263 1.04769 m
.52633 1.04791 L
s
.5249 1.03887 m
.52578 1.04441 L
s
.52578 1.04441 m
.52594 1.04543 L
s
.52594 1.04543 m
.526 1.04584 L
s
.54182 .94451 m
.54462 .94459 L
s
.5417 .9445 m
.54182 .94451 L
s
.54164 .9445 m
.5417 .9445 L
s
.54141 .94449 m
.54164 .9445 L
s
.54044 .95157 m
.54086 .94853 L
s
.54091 .94811 m
.54141 .94449 L
s
.70113 .62459 m .69946 .61196 L .69634 .61111 L 0 .454 .371 r
F
0 g
.68634 .59876 m
.69634 .61111 L
s
.70113 .62459 m .70921 .62639 L .69946 .61196 L 0 .454 .371 r
F
.70113 .62459 m .71909 .64479 L .70921 .62639 L F
.70113 .62459 m .72389 .65831 L .71909 .64479 L F
.70113 .62459 m .7204 .65792 L .72389 .65831 L F
.70113 .62459 m .71064 .64345 L .7204 .65792 L F
0 g
.69291 .61143 m
.70113 .62459 L
s
.69634 .61111 m
.70113 .62459 L
s
.70007 .89105 m .71051 .8872 L .70552 .88796 L 0 1 .259 r
F
0 g
.70076 .89023 m
.70092 .89004 L
s
.70015 .89095 m
.70076 .89023 L
s
.70007 .89105 m
.70015 .89095 L
s
.69705 .89123 m
.69707 .89123 L
s
.69998 .89106 m
.70007 .89105 L
s
.69893 .89112 m
.69998 .89106 L
s
.69848 .89114 m
.69893 .89112 L
s
.32421 .68127 m .31199 .68265 L .31548 .68532 L 0 1 .501 r
F
.43171 .63515 m .4215 .63507 L .42336 .63622 L 0 1 .447 r
F
0 g
.4181 .63985 m
.42336 .63622 L
s
.43171 .63515 m .42742 .63224 L .4215 .63507 L 0 1 .447 r
F
.43171 .63515 m .43719 .62962 L .42742 .63224 L F
.43171 .63515 m .44556 .62855 L .43719 .62962 L F
.43171 .63515 m .44693 .62975 L .44556 .62855 L F
.43171 .63515 m .441 .63258 L .44693 .62975 L F
0 g
.42336 .63622 m
.43171 .63515 L
s
.441 .63258 m
.44923 .63155 L
s
.74667 1.07578 m .75615 1.06363 L .7517 1.06929 L 0 .867 .15 r
F
.75039 1.06402 m .75615 1.06363 L .7604 1.05477 L 0 1 .212 r
F
.75039 1.06402 m .7517 1.06929 L .75615 1.06363 L F
0 g
.75615 1.06363 m
.75772 1.06234 L
s
.75615 1.06363 m
.75641 1.0631 L
s
.71276 .80848 m .71547 .78128 L .71141 .78099 L 0 .626 .293 r
F
0 g
.71141 .78099 m
.71168 .78651 L
s
.71168 .78651 m
.71276 .80848 L
s
.71034 .77761 m
.71141 .78099 L
s
.71275 .80847 m
.71276 .80848 L
s
.7076 .79023 m
.71275 .80847 L
s
.50486 .65536 m .52034 .6482 L .5205 .64495 L 0 1 .506 r
F
0 g
.52034 .6482 m
.52678 .64875 L
s
.51364 .65266 m
.52034 .6482 L
s
.47169 .81957 m .46742 .8178 L .46494 .81472 L 0 .099 0 r
F
.47169 .81957 m .4726 .82259 L .46742 .8178 L F
.47246 .82212 m .47753 .82679 L .4726 .82259 L F
.46742 .8178 m .47551 .82513 L .47419 .82372 L 0 .06 .157 r
F
.46764 .81801 m .47419 .82372 L .46895 .81925 L F
.46742 .8178 m .46837 .81863 L .46764 .81801 L F
.46837 .81863 m .47419 .82372 L .46764 .81801 L F
.47169 .81957 m .47661 .82565 L .47246 .82212 L 0 .099 0 r
F
.47661 .82565 m .47753 .82679 L .47246 .82212 L F
.47169 .81957 m .4789 .82759 L .47753 .82679 L F
.47169 .81957 m .47639 .8245 L .4789 .82759 L F
0 g
.46957 .81585 m
.47169 .81957 L
s
.46679 .81539 m
.47169 .81957 L
s
.39015 .64764 m
.39851 .6445 L
s
.73277 .66036 m .7498 .64826 L .74145 .65272 L 0 0 0 r
F
0 g
.7498 .64826 m
.75324 .64676 L
s
.7498 .64826 m
.75782 .64376 L
s
.53281 1.00102 m
.53371 1.0028 L
s
.77287 1.03526 m .78177 1.02178 L .77724 1.02657 L 0 1 .332 r
F
.77395 1.014 m .78177 1.02178 L .78523 1.01111 L 0 1 .38 r
F
.77395 1.014 m .77724 1.02657 L .78177 1.02178 L F
0 g
.78177 1.02178 m
.78414 1.02366 L
s
.76162 1.04858 m .77287 1.03526 L .77045 1.03429 L 0 1 .279 r
F
0 g
.68309 .58555 m
.68309 .58555 L
s
.68301 .58546 m
.68309 .58555 L
s
.53796 .97538 m
.53854 .97659 L
s
.53796 .97538 m
.53815 .9754 L
s
.64335 .70697 m
.6511 .7143 L
s
.77922 .85535 m .7938 .8541 L .79039 .8503 L 0 1 .484 r
F
0 g
.7938 .8541 m
.79976 .85571 L
s
.79293 .85822 m
.7938 .8541 L
s
.54044 .95157 m
.54205 .95385 L
s
.54252 .95451 m
.54383 .95636 L
s
.67291 .78679 m
.67585 .79345 L
s
.67149 .78358 m
.67291 .78679 L
s
.66951 .77252 m
.67149 .78358 L
s
.44184 .79973 m
.44318 .80061 L
s
.44184 .79973 m
.44731 .80274 L
s
.25816 .85813 m .24691 .85491 L .24753 .85878 L 0 1 .517 r
F
0 g
.24221 .86111 m
.24753 .85878 L
s
.35287 .66483 m .3453 .65905 L .34104 .66295 L 0 1 .534 r
F
0 g
.33266 .66351 m
.34104 .66295 L
s
.35287 .66483 m .35369 .65921 L .3453 .65905 L 0 1 .534 r
F
.35283 .66627 m .35369 .65921 L .34522 .66199 L 0 1 .507 r
F
.35369 .65921 m .35419 .65515 L .35222 .65665 L F
.35314 .6592 m .35222 .65665 L .3453 .65905 L 0 1 .534 r
F
.35369 .65921 m .35222 .65665 L .35314 .6592 L F
.3453 .65905 m .35097 .65382 L .34697 .65 L 0 1 .538 r
F
.35097 .65382 m .3504 .65254 L .34697 .65 L F
.35149 .65334 m .35606 .64702 L .34909 .6498 L 0 1 .517 r
F
.35149 .65334 m .35005 .64971 L .34909 .6498 L 0 1 .538 r
F
.35149 .65334 m .34909 .6498 L .34697 .65 L F
.35097 .65382 m .35149 .65334 L .3504 .65254 L F
.35149 .65334 m .35884 .64874 L .35606 .64702 L 0 1 .517 r
F
.35156 .65352 m .35884 .64874 L .35149 .65334 L F
.3453 .65905 m .35195 .65544 L .35149 .65334 L 0 1 .538 r
F
.35182 .65557 m .35195 .65544 L .35117 .65377 L 0 1 .517 r
F
.35195 .65544 m .35884 .64874 L .35153 .65354 L F
.35195 .65544 m .35153 .65354 L .35117 .65377 L F
.3453 .65905 m .35222 .65665 L .35195 .65544 L 0 1 .538 r
F
.34522 .66199 m .35419 .65515 L .35884 .64874 L 0 1 .517 r
F
.35195 .65544 m .35417 .65598 L .35876 .65174 L 0 1 .538 r
F
.35222 .65665 m .35417 .65598 L .35195 .65544 L F
.35149 .65334 m .35876 .65174 L .356 .64916 L F
.35153 .65354 m .35156 .65352 L .35149 .65334 L 0 1 .517 r
F
.35195 .65544 m .35876 .65174 L .35149 .65334 L 0 1 .538 r
F
.35117 .65377 m .35153 .65354 L .35149 .65334 L 0 1 .517 r
F
.34522 .66199 m .35149 .65334 L .34695 .65065 L F
.35149 .65334 m .34909 .6498 L .34695 .65065 L F
.3453 .65905 m .33771 .65367 L .33315 .6579 L 0 1 .538 r
F
.3453 .65905 m .34697 .65 L .33771 .65367 L F
.33771 .65367 m .34697 .65 L .34886 .64822 L 0 1 .54 r
F
.34862 .64728 m .34886 .64822 L .35189 .64434 L 0 1 .525 r
F
.34862 .64728 m .34886 .64822 L .35186 .64538 L 0 1 .54 r
F
.33771 .65367 m .34886 .64822 L .34862 .64728 L F
.34822 .64764 m .34861 .64853 L .34886 .64822 L 0 1 .525 r
F
.34822 .64764 m .34886 .64822 L .34862 .64728 L F
.3376 .6572 m .34695 .65065 L .34861 .64853 L F
.3376 .6572 m .34861 .64853 L .34822 .64764 L F
.35149 .65334 m .356 .64916 L .35005 .64971 L 0 1 .538 r
F
.34522 .66199 m .35182 .65557 L .35117 .65377 L 0 1 .517 r
F
.35369 .65921 m .35222 .65665 L .34522 .66199 L 0 1 .507 r
F
.35369 .65921 m .35417 .65598 L .35222 .65665 L 0 1 .534 r
F
0 g
.34418 .66507 m
.35039 .6649 L
s
.34888 .66854 m
.35189 .66574 L
s
.49832 .97929 m .49228 .9819 L .49539 .97965 L 0 .499 .094 r
F
.49832 .97929 m .49083 .98562 L .49228 .9819 L F
.49832 .97929 m .49202 .98832 L .49083 .98562 L F
.49832 .97929 m .49496 .98795 L .49202 .98832 L F
.49832 .97929 m .49768 .98476 L .49496 .98795 L F
0 g
.49539 .97965 m
.49602 .9786 L
s
.49602 .9786 m
.49718 .97667 L
s
.49832 .97929 m .49912 .98105 L .49768 .98476 L 0 .499 .094 r
F
0 g
.49832 .97929 m
.49972 .97536 L
s
.49539 .97965 m
.49832 .97929 L
s
.49912 .98105 m
.50175 .97807 L
s
.38754 .67414 m .37654 .67054 L .37926 .67388 L 0 1 .515 r
F
0 g
.37552 .67778 m
.37926 .67388 L
s
.63814 .5362 m
.64836 .54352 L
s
.58017 .61413 m .59862 .6101 L .6003 .60748 L 0 1 .516 r
F
.58017 .61413 m .59 .61295 L .59862 .6101 L F
0 g
.59862 .6101 m
.60443 .61153 L
s
.59 .61295 m
.59611 .61406 L
s
.59 .61295 m
.59862 .6101 L
s
.54925 1.01831 m .54911 1.01745 L .55265 1.02519 L 0 .435 0 r
F
0 g
.54921 1.01765 m
.54925 1.01774 L
s
.54911 1.01745 m
.54921 1.01765 L
s
.54935 1.01797 m
.55014 1.01971 L
s
.54925 1.01774 m
.54935 1.01797 L
s
.55014 1.01971 m
.55139 1.02244 L
s
.55139 1.02244 m
.55265 1.02519 L
s
.54903 1.01844 m
.54927 1.01902 L
s
.54904 1.01784 m
.54925 1.01831 L
s
.54994 1.01861 m
.55136 1.02206 L
s
.55136 1.02206 m
.55265 1.02519 L
s
.54875 1.01661 m
.54911 1.01745 L
s
.64464 .59326 m .66698 .59088 L .661 .58858 L 0 1 .51 r
F
0 g
.66698 .59088 m
.67633 .59054 L
s
.48889 .97447 m
.48911 .97452 L
s
.48572 .97377 m
.48889 .97447 L
s
.28062 .86442 m .27286 .85766 L .2694 .86129 L 0 1 .52 r
F
.28062 .86442 m .27876 .85593 L .27286 .85766 L F
.28062 .86442 m .28316 .85726 L .27876 .85593 L F
.28062 .86442 m .28395 .8609 L .28316 .85726 L F
0 g
.27474 .86614 m
.28062 .86442 L
s
.28062 .86442 m
.28153 .86799 L
s
.80615 .95338 m .80735 .96504 L .8117 .97114 L 0 1 .427 r
F
0 g
.80814 .98118 m
.8117 .97114 L
s
.30511 .6846 m .29699 .68177 L .30059 .68436 L 0 1 .505 r
F
.30511 .6846 m .29618 .67821 L .29699 .68177 L F
0 g
.2993 .68767 m
.30029 .68513 L
s
.30511 .6846 m .29871 .67604 L .29618 .67821 L 0 1 .505 r
F
0 g
.29648 .68196 m
.29699 .68177 L
s
.28874 .6847 m
.29648 .68196 L
s
.30511 .6846 m .30323 .67629 L .29871 .67604 L 0 1 .505 r
F
0 g
.30029 .68513 m
.30059 .68436 L
s
.30511 .6846 m .30674 .67878 L .30323 .67629 L 0 1 .505 r
F
.30511 .6846 m .30754 .68234 L .30674 .67878 L F
0 g
.30511 .6846 m
.30598 .68845 L
s
.30059 .68436 m
.30511 .6846 L
s
.52752 .64075 m .53673 .6384 L .54425 .6337 L 0 1 .513 r
F
0 g
.53673 .6384 m
.54425 .6337 L
s
.54425 .6337 m
.54438 .63373 L
s
.67626 .851 m
.67748 .85899 L
s
.67626 .851 m
.6764 .85699 L
s
.50486 .65536 m .4977 .65152 L .49802 .65487 L 0 1 .506 r
F
.50486 .65536 m .50441 .64705 L .4977 .65152 L F
.50486 .65536 m .51367 .64446 L .50441 .64705 L F
.50486 .65536 m .5205 .64495 L .51367 .64446 L F
0 g
.49851 .65999 m
.50486 .65536 L
s
.47356 .96562 m
.47729 .96812 L
s
.45208 .95082 m .4436 .94362 L .44777 .94678 L 0 .184 0 r
F
0 g
.44777 .94678 m
.4499 .94774 L
s
.32421 .68127 m .31573 .67509 L .31199 .68265 L 0 1 .501 r
F
.32421 .68127 m .32422 .66767 L .31573 .67509 L F
.32421 .68127 m .33298 .6636 L .32422 .66767 L F
.32421 .68127 m .33614 .6656 L .33298 .6636 L F
.32421 .68127 m .33238 .67318 L .33614 .6656 L F
0 g
.3207 .68955 m
.32421 .68127 L
s
.31548 .68532 m
.32421 .68127 L
s
.7793 .83264 m .78994 .81855 L .7944 .81728 L 0 0 .001 r
F
.7793 .83264 m .78348 .82511 L .78994 .81855 L F
0 g
.78881 .8146 m
.78994 .81855 L
s
.34396 .8758 m .33432 .87485 L .33839 .87663 L 0 1 .526 r
F
0 g
.33839 .87663 m
.33947 .87994 L
s
.73312 1.0952 m .74667 1.07578 L .74428 1.07968 L 0 0 0 r
F
0 g
.73099 1.09672 m
.73341 1.09278 L
s
.36393 .8869 m .35714 .87867 L .35396 .8811 L 0 .998 .497 r
F
.36393 .8869 m .36242 .87885 L .35714 .87867 L F
.36393 .8869 m .36628 .88154 L .36242 .87885 L F
.36393 .8869 m .36692 .88499 L .36628 .88154 L F
0 g
.35866 .8867 m
.36393 .8869 L
s
.36393 .8869 m
.36473 .89007 L
s
.46229 .95789 m .45366 .95306 L .45208 .95082 L 0 .291 0 r
F
.46229 .95789 m .45778 .95693 L .45366 .95306 L F
.46229 .95789 m .46168 .95985 L .45778 .95693 L F
.46229 .95789 m .46361 .96026 L .46168 .95985 L F
0 g
.46229 .95789 m
.46442 .95773 L
s
.45817 .95402 m
.46229 .95789 L
s
.50311 .98464 m
.50357 .98173 L
s
.532 .99155 m .5326 .9884 L .53608 .99618 L 0 .544 .169 r
F
0 g
.5326 .9884 m
.53333 .99003 L
s
.53382 .99362 m
.53527 .99902 L
s
.53004 .97929 m
.5326 .9884 L
s
.7518 .69525 m
.75188 .69492 L
s
.7459 .70289 m
.74633 .70204 L
s
.75073 .69355 m
.75096 .6931 L
s
.52624 1.07232 m .52871 1.08992 L .53062 1.09572 L 0 0 .132 r
F
0 g
.52623 1.07929 m
.52871 1.08992 L
s
.52834 1.08969 m
.52871 1.08992 L
s
.35283 .66627 m .34088 .66846 L .34404 .67027 L 0 1 .507 r
F
0 g
.34051 .67856 m
.34404 .67027 L
s
.35283 .66627 m .34522 .66199 L .34088 .66846 L 0 1 .507 r
F
0 g
.34877 .67267 m
.35283 .66627 L
s
.34404 .67027 m
.35283 .66627 L
s
.4405 .67797 m .4313 .67431 L .43301 .67779 L 0 1 .498 r
F
.4405 .67797 m .43658 .66929 L .4313 .67431 L F
0 g
.43197 .67893 m
.43301 .67779 L
s
.42834 .68293 m
.43197 .67893 L
s
.4405 .67797 m .44532 .66608 L .43658 .66929 L 0 1 .498 r
F
.4405 .67797 m .45282 .66626 L .44532 .66608 L F
.4405 .67797 m .45408 .66971 L .45282 .66626 L F
.4405 .67797 m .4488 .67473 L .45408 .66971 L F
0 g
.43556 .68312 m
.4405 .67797 L
s
.43301 .67779 m
.4405 .67797 L
s
.40317 .50587 m .39044 .50773 L .39234 .50868 L 0 1 .378 r
F
0 g
.38478 .51399 m
.39234 .50868 L
s
.40317 .50587 m .39877 .50357 L .39044 .50773 L 0 1 .378 r
F
.40317 .50587 m .41181 .49898 L .39877 .50357 L F
.40317 .50587 m .42265 .49617 L .41181 .49898 L F
.40317 .50587 m .42406 .49701 L .42265 .49617 L F
.40317 .50587 m .41571 .50117 L .42406 .49701 L F
0 g
.3952 .51001 m
.40317 .50587 L
s
.39234 .50868 m
.40317 .50587 L
s
.41571 .50117 m
.42618 .49814 L
s
.4488 .67473 m
.45596 .67499 L
s
.79039 .8503 m .80511 .84962 L .80158 .84535 L 0 1 .498 r
F
0 g
.80432 .85405 m
.80511 .84962 L
s
.80511 .84962 m
.81117 .85159 L
s
.45208 .95082 m .44186 .94271 L .4436 .94362 L 0 .184 0 r
F
0 g
.43933 .94006 m
.4436 .94362 L
s
.35968 .52282 m
.36722 .51752 L
s
.34911 .52747 m
.35968 .52282 L
s
.5517 1.14418 m .55813 1.15051 L .55584 1.15043 L 0 .538 .048 r
F
.5595 1.16648 m .55813 1.15051 L .56247 1.15737 L 0 .657 .074 r
F
0 g
.56155 1.14967 m
.56247 1.15737 L
s
.5595 1.16648 m .55584 1.15043 L .55813 1.15051 L 0 .657 .074 r
F
0 g
.55709 1.14448 m
.55813 1.15051 L
s
.55813 1.15051 m
.56247 1.15737 L
s
.38754 .67414 m .38108 .66578 L .37654 .67054 L 0 1 .515 r
F
0 g
.36845 .66951 m
.37654 .67054 L
s
.38754 .67414 m .38985 .66277 L .38108 .66578 L 0 1 .515 r
F
.38754 .67414 m .39816 .66303 L .38985 .66277 L F
.38754 .67414 m .40045 .66638 L .39816 .66303 L F
.38754 .67414 m .39589 .67114 L .40045 .66638 L F
0 g
.37926 .67388 m
.38754 .67414 L
s
.71051 .8872 m .71586 .88353 L .71173 .8854 L 0 1 .255 r
F
.71051 .8872 m .72094 .88273 L .71586 .88353 L F
0 g
.70714 .88772 m
.71051 .8872 L
s
.70552 .88796 m
.70714 .88772 L
s
.2832 .76983 m .27287 .76765 L .27152 .77206 L 0 1 .533 r
F
0 g
.26464 .77607 m
.27152 .77206 L
s
.24691 .85491 m .23618 .85567 L .24072 .85692 L 0 1 .517 r
F
0 g
.24072 .85692 m
.24221 .86111 L
s
.30754 .68234 m
.31199 .68265 L
s
.31199 .68265 m
.31199 .68264 L
s
.53892 .97077 m .54402 .96994 L .54065 .96835 L 0 .166 .226 r
F
0 g
.53752 .9639 m
.54065 .96835 L
s
.53892 .97077 m .54762 .97793 L .54402 .96994 L 0 .166 .226 r
F
.53892 .97077 m .54904 .98699 L .54762 .97793 L F
.53892 .97077 m .54729 .98941 L .54904 .98699 L F
.53892 .97077 m .54354 .98358 L .54729 .98941 L F
.53892 .97077 m .53996 .97559 L .54354 .98358 L F
0 g
.53874 .97047 m
.53892 .97077 L
s
.53892 .97077 m
.54065 .96835 L
s
.53944 .97554 m
.53996 .97559 L
s
.53815 .9754 m
.53944 .97554 L
s
.53854 .97659 m
.54113 .98199 L
s
.34396 .8758 m .33394 .87104 L .33432 .87485 L 0 1 .526 r
F
0 g
.3292 .8757 m
.33432 .87485 L
s
.67242 .8496 m .67569 .83135 L .67188 .82985 L 0 .591 .297 r
F
0 g
.67188 .82985 m
.67212 .83866 L
s
.66817 .82024 m
.67188 .82985 L
s
.65547 .55254 m .65094 .54441 L .64869 .54376 L 0 .353 .326 r
F
0 g
.64836 .54352 m
.64869 .54376 L
s
.65547 .55254 m .66143 .55414 L .65094 .54441 L 0 .353 .326 r
F
.65547 .55254 m .67317 .56646 L .66143 .55414 L F
.65547 .55254 m .67995 .57524 L .67317 .56646 L F
.65547 .55254 m .67724 .57462 L .67995 .57524 L F
0 g
.67442 .57486 m
.67939 .58098 L
s
.67319 .57335 m
.67442 .57486 L
s
.65547 .55254 m .66675 .56488 L .67724 .57462 L 0 .353 .326 r
F
0 g
.66675 .56488 m
.67319 .57335 L
s
.64657 .54371 m
.65547 .55254 L
s
.64869 .54376 m
.65547 .55254 L
s
.6981 .76424 m .7008 .77389 L .69727 .78232 L 0 .09 .106 r
F
.26228 .67966 m .2609 .66763 L .25269 .67434 L 0 1 .531 r
F
0 g
.24949 .68093 m
.25269 .67434 L
s
.26228 .67966 m .26982 .66423 L .2609 .66763 L 0 1 .531 r
F
.26228 .67966 m .27346 .66643 L .26982 .66423 L F
.26228 .67966 m .27022 .67306 L .27346 .66643 L F
0 g
.25928 .68626 m
.26228 .67966 L
s
.25341 .68303 m
.26228 .67966 L
s
.54409 .95345 m
.54469 .94667 L
s
.54405 .95383 m
.54409 .95345 L
s
.54404 .95403 m
.54405 .95383 L
s
.54383 .95636 m
.54404 .95403 L
s
.66619 .74916 m
.66724 .75094 L
s
.66834 .75278 m
.66844 .75296 L
s
.66436 .74609 m
.66588 .74864 L
s
.67162 .75831 m
.67162 .75831 L
s
.66966 .75501 m
.67162 .75831 L
s
.66899 .75388 m
.66966 .75501 L
s
.66844 .75296 m
.66899 .75388 L
s
.66146 .73711 m
.66436 .74609 L
s
.72397 .71613 m
.72494 .72346 L
s
.72339 .7117 m
.72397 .71613 L
s
.72562 .7287 m
.72601 .7316 L
s
.30674 .67878 m
.30754 .68234 L
s
.80615 .95338 m .81881 .95632 L .8176 .94467 L 0 1 .427 r
F
0 g
.81628 .96765 m
.81881 .95632 L
s
.81881 .95632 m
.82316 .96268 L
s
.75039 1.06402 m .7604 1.05477 L .76162 1.04858 L 0 1 .212 r
F
0 g
.7604 1.05477 m
.76283 1.0557 L
s
.75641 1.0631 m
.7604 1.05477 L
s
.7793 .83264 m .7944 .81728 L .79448 .82095 L 0 0 .001 r
F
0 g
.7944 .81728 m
.80006 .81234 L
s
.65438 .72432 m .65564 .71544 L .65188 .71504 L 0 .528 .39 r
F
0 g
.6511 .7143 m
.65188 .71504 L
s
.65438 .72432 m .66411 .72516 L .65564 .71544 L 0 .528 .39 r
F
0 g
.65188 .71504 m
.65438 .72432 L
s
.79672 .99079 m .80483 .97668 L .80025 .98058 L 0 1 .42 r
F
.78532 1.00164 m .79672 .99079 L .79339 .98681 L 0 1 .402 r
F
.7155 .67738 m .7158 .67619 L .71245 .68005 L 0 0 0 r
F
.44186 .94271 m .4332 .93534 L .43736 .93872 L 0 .031 0 r
F
0 g
.43736 .93872 m
.43933 .94006 L
s
.77395 1.014 m .78523 1.01111 L .78532 1.00164 L 0 1 .38 r
F
0 g
.78177 1.02178 m
.78523 1.01111 L
s
.78523 1.01111 m
.78856 1.01504 L
s
.60897 .60519 m .6045 .60094 L .60281 .60355 L 0 1 .509 r
F
.60897 .60519 m .61353 .59886 L .6045 .60094 L F
.60897 .60519 m .62386 .59871 L .61353 .59886 L F
0 g
.48908 .97635 m
.48982 .97621 L
s
.48299 .66244 m .49172 .65955 L .49802 .65487 L 0 1 .503 r
F
0 g
.49172 .65955 m
.49851 .65999 L
s
.24691 .85491 m .23565 .85162 L .23618 .85567 L 0 1 .517 r
F
0 g
.23079 .85817 m
.23618 .85567 L
s
.41542 .67745 m .40427 .67221 L .40707 .67661 L 0 1 .505 r
F
.41542 .67745 m .40883 .66647 L .40427 .67221 L F
0 g
.40633 .67772 m
.40707 .67661 L
s
.40328 .68232 m
.40633 .67772 L
s
.41542 .67745 m .41773 .66322 L .40883 .66647 L 0 1 .505 r
F
.41542 .67745 m .4261 .66406 L .41773 .66322 L F
.41542 .67745 m .42834 .66843 L .4261 .66406 L F
.41542 .67745 m .42376 .67416 L .42834 .66843 L F
0 g
.40707 .67661 m
.41542 .67745 L
s
.43048 .7941 m .42193 .79024 L .42448 .79125 L 0 .289 .195 r
F
0 g
.42448 .79125 m
.43047 .7941 L
s
.42838 .79272 m
.43048 .7941 L
s
.43048 .7941 m
.43048 .7941 L
s
.4226 .79022 m
.42448 .79125 L
s
.52589 1.06548 m
.52615 1.0669 L
s
.35396 .8811 m .34734 .87288 L .34396 .8758 L 0 1 .513 r
F
.35396 .8811 m .35278 .87254 L .34734 .87288 L F
.35396 .8811 m .35664 .875 L .35278 .87254 L F
.35396 .8811 m .35714 .87867 L .35664 .875 L F
0 g
.34853 .88144 m
.35396 .8811 L
s
.35396 .8811 m
.35461 .88454 L
s
.22713 .77451 m .22194 .76465 L .21625 .77157 L 0 1 .541 r
F
0 g
.2153 .77757 m
.21625 .77157 L
s
.22713 .77451 m .2294 .76045 L .22194 .76465 L 0 1 .541 r
F
.22713 .77451 m .23362 .7618 L .2294 .76045 L F
.22713 .77451 m .23263 .76783 L .23362 .7618 L F
0 g
.22349 .77655 m
.22713 .77451 L
s
.22631 .7803 m
.22713 .77451 L
s
.54971 1.01961 m
.54972 1.01963 L
s
.54925 1.01831 m
.54957 1.01922 L
s
.54957 1.01922 m
.54971 1.01961 L
s
.55095 1.0231 m
.55251 1.02752 L
s
.54972 1.01963 m
.55095 1.0231 L
s
.82906 .93676 m .84055 .92954 L .83618 .92289 L 0 1 .45 r
F
0 g
.54816 1.01666 m
.54882 1.01826 L
s
.54915 1.01905 m
.5493 1.01942 L
s
.54902 1.01875 m
.54915 1.01905 L
s
.54899 1.01866 m
.54902 1.01875 L
s
.54852 1.01771 m
.54899 1.01887 L
s
.80158 .84535 m .81643 .84523 L .81278 .84052 L 0 1 .508 r
F
0 g
.81573 .84996 m
.81643 .84523 L
s
.81643 .84523 m
.82258 .84756 L
s
.35844 .77283 m .35124 .76936 L .35462 .77045 L 0 .203 .093 r
F
0 g
.71516 .65698 m
.71637 .65923 L
s
.71064 .64345 m
.71516 .65698 L
s
.5357 1.00063 m .5434 1.02548 L .53884 1.00831 L 0 .192 .205 r
F
.5357 1.00063 m .54727 1.04854 L .5434 1.02548 L F
0 g
.53281 1.00102 m
.53406 1.00647 L
s
.53371 1.0028 m
.53467 1.00471 L
s
.5357 1.00063 m .54783 1.06207 L .54727 1.04854 L 0 .192 .205 r
F
.5357 1.00063 m .54465 1.05422 L .54783 1.06207 L F
0 g
.54782 1.01585 m
.54816 1.01666 L
s
.5468 1.01345 m
.54852 1.01771 L
s
.5465 1.01272 m
.5468 1.01345 L
s
.54562 1.01054 m
.5465 1.01272 L
s
.5357 1.00063 m .53988 1.03037 L .54465 1.05422 L 0 .192 .205 r
F
.5357 1.00063 m .53606 1.00747 L .53988 1.03037 L F
0 g
.5356 1.00025 m
.5357 1.00063 L
s
.5357 1.00063 m
.53611 1.00162 L
s
.55295 .62547 m .57071 .62012 L .57189 .61721 L 0 1 .518 r
F
.55295 .62547 m .5626 .62365 L .57071 .62012 L F
0 g
.57071 .62012 m
.57685 .62121 L
s
.5626 .62366 m
.56874 .62504 L
s
.5626 .62365 m
.57071 .62012 L
s
.52634 1.05246 m .52549 1.05008 L .52661 1.05979 L 0 .062 .17 r
F
0 g
.52603 1.05478 m
.52612 1.05555 L
s
.52598 1.05437 m
.52603 1.05478 L
s
.52582 1.05294 m
.52598 1.05437 L
s
.5256 1.05108 m
.52582 1.05294 L
s
.52558 1.05092 m
.5256 1.05108 L
s
.52549 1.05008 m
.52558 1.05092 L
s
.52633 1.04791 m
.527 1.05212 L
s
.52585 1.04786 m
.52625 1.05152 L
s
.52625 1.05152 m
.52631 1.05215 L
s
.52559 1.05422 m
.52576 1.05511 L
s
.5255 1.0537 m
.52558 1.05415 L
s
.52558 1.05415 m
.52559 1.05422 L
s
.52543 1.04968 m
.52549 1.05008 L
s
.47275 .62776 m
.47929 .62657 L
s
.44186 .94271 m .43165 .93398 L .4332 .93534 L 0 .031 0 r
F
0 g
.42876 .93191 m
.4332 .93534 L
s
.5205 .64495 m
.52752 .64075 L
s
.51367 .64446 m
.5205 .64495 L
s
.52624 1.07232 m .53063 1.09274 L .52873 1.08296 L 0 0 .132 r
F
.52624 1.07232 m .53062 1.09572 L .53063 1.09274 L F
0 g
.52589 1.06548 m
.52624 1.07232 L
s
.52624 1.07232 m
.52627 1.07242 L
s
.52627 1.07242 m
.52628 1.07249 L
s
.52628 1.07249 m
.52649 1.07337 L
s
.66356 .76495 m .66477 .76283 L .66177 .77123 L 0 0 .006 r
F
.66361 .76539 m .66177 .77123 L .66477 .76283 L 0 1 .138 r
F
.65592 .78901 m .66356 .76495 L .65861 .78092 L 0 0 .006 r
F
.64864 .79844 m .66166 .77147 L .66361 .76539 L 0 1 .138 r
F
.66166 .77147 m .66177 .77123 L .66361 .76539 L F
.6568 .78657 m .65861 .78092 L .6573 .78516 L 0 0 .006 r
F
.65592 .78901 m .65861 .78092 L .6568 .78657 L F
0 g
.66301 .76673 m
.66356 .76495 L
s
.66313 .76646 m
.66356 .76495 L
s
.37416 .77654 m .36397 .77607 L .36729 .7755 L 0 0 0 r
F
.72094 .88273 m .72846 .87741 L .72303 .88011 L 0 1 .288 r
F
.72094 .88273 m .73462 .87639 L .72846 .87741 L F
.31783 .76041 m .30627 .76212 L .31025 .76201 L 0 .838 .254 r
F
0 g
.3092 .76636 m
.31025 .76201 L
s
.2694 .86129 m .26175 .85436 L .25816 .85813 L 0 1 .518 r
F
.2694 .86129 m .26776 .85254 L .26175 .85436 L F
.2694 .86129 m .27216 .85391 L .26776 .85254 L F
.2694 .86129 m .27286 .85766 L .27216 .85391 L F
0 g
.26341 .86308 m
.2694 .86129 L
s
.2694 .86129 m
.27021 .86492 L
s
.68943 1.13103 m .69898 1.12554 L .69502 1.1312 L 0 .134 .076 r
F
.69681 1.1449 m .69898 1.12554 L .70406 1.12382 L 0 .053 .075 r
F
.69681 1.1449 m .69502 1.1312 L .69898 1.12554 L F
0 g
.69898 1.12554 m
.69921 1.11818 L
s
.69898 1.12554 m
.70019 1.12513 L
s
.36461 .65746 m
.36993 .65467 L
s
.52752 .64075 m .52097 .6353 L .52076 .63942 L 0 1 .513 r
F
.52752 .64075 m .5285 .63059 L .52097 .6353 L F
.71276 .80848 m .72305 .80681 L .71547 .78128 L 0 .626 .293 r
F
0 g
.71339 .7583 m
.71547 .78128 L
s
.71276 .80848 m
.71276 .80848 L
s
.52251 .87533 m
.52317 .8778 L
s
.52212 .87385 m
.52251 .87533 L
s
.53497 1.11112 m .54004 1.12277 L .53816 1.11903 L 0 .404 0 r
F
.54078 1.12895 m .54004 1.12277 L .5435 1.13156 L 0 .484 0 r
F
.54078 1.12895 m .53816 1.11903 L .54004 1.12277 L F
0 g
.53929 1.12008 m
.54004 1.12277 L
s
.48299 .66244 m .47505 .65864 L .47584 .66205 L 0 1 .503 r
F
.48299 .66244 m .48135 .65395 L .47505 .65864 L F
.48299 .66244 m .49056 .65112 L .48135 .65395 L F
.48299 .66244 m .4977 .65152 L .49056 .65112 L F
.48299 .66244 m .49802 .65487 L .4977 .65152 L F
0 g
.49172 .65955 m
.4956 .65667 L
s
.4956 .65667 m
.49802 .65487 L
s
.47703 .66727 m
.48299 .66244 L
s
.49802 .65487 m
.50486 .65536 L
s
.30753 .65987 m .29478 .66112 L .29833 .66241 L 0 1 .542 r
F
0 g
.66675 .56488 m
.67724 .57462 L
s
.77395 1.014 m .77389 1.02325 L .77724 1.02657 L 0 1 .38 r
F
0 g
.77287 1.03526 m
.77724 1.02657 L
s
.33394 .87104 m .32414 .8707 L .32821 .87231 L 0 1 .535 r
F
0 g
.32821 .87231 m
.3292 .8757 L
s
.69007 .58051 m .71094 .58303 L .71399 .5812 L 0 1 .519 r
F
.69007 .58051 m .7007 .58273 L .71094 .58303 L F
0 g
.71094 .58303 m
.71592 .58656 L
s
.7007 .58273 m
.71094 .58303 L
s
.2832 .76983 m .27891 .76262 L .27287 .76765 L 0 1 .533 r
F
.2832 .76983 m .28643 .7595 L .27891 .76262 L F
.2832 .76983 m .29039 .76039 L .28643 .7595 L F
.2832 .76983 m .289 .76483 L .29039 .76039 L F
0 g
.28202 .7741 m
.2832 .76983 L
s
.27572 .77293 m
.2832 .76983 L
s
.46145 .66999 m .45282 .66626 L .45408 .66971 L 0 1 .5 r
F
.46145 .66999 m .45865 .66139 L .45282 .66626 L F
0 g
.45286 .67087 m
.45408 .66971 L
s
.4488 .67473 m
.45286 .67087 L
s
.46145 .66999 m .46768 .65835 L .45865 .66139 L 0 1 .5 r
F
.46145 .66999 m .47505 .65864 L .46768 .65835 L F
.46145 .66999 m .47584 .66205 L .47505 .65864 L F
.46145 .66999 m .47001 .66692 L .47584 .66205 L F
0 g
.47584 .66205 m
.48299 .66244 L
s
.45596 .67499 m
.46145 .66999 L
s
.45408 .66971 m
.46145 .66999 L
s
.47001 .66692 m
.47703 .66727 L
s
.35844 .77283 m .34991 .77575 L .35124 .76936 L 0 .203 .093 r
F
.35844 .77283 m .35153 .78541 L .34991 .77575 L F
.35844 .77283 m .35538 .78781 L .35153 .78541 L F
.35844 .77283 m .35887 .78134 L .35538 .78781 L F
.35844 .77283 m .36017 .77493 L .35887 .78134 L F
0 g
.35844 .77283 m
.35969 .77155 L
s
.35462 .77045 m
.35844 .77283 L
s
.53062 1.09572 m .53497 1.11112 L .53535 1.11138 L 0 0 .09 r
F
0 g
.52732 .99104 m
.52792 .99251 L
s
.66978 1.1599 m .66663 1.14976 L .66717 1.13893 L 0 .273 .105 r
F
0 g
.66663 1.14976 m
.66717 1.13893 L
s
.66452 1.13725 m
.66717 1.13893 L
s
.54004 .98506 m
.54099 .98594 L
s
.45208 .95082 m .44371 .94466 L .44186 .94271 L 0 .184 0 r
F
.45208 .95082 m .44802 .94871 L .44371 .94466 L F
.45208 .95082 m .45193 .95215 L .44802 .94871 L F
.45208 .95082 m .45366 .95306 L .45193 .95215 L F
0 g
.44777 .94678 m
.45208 .95082 L
s
.45208 .95082 m
.45401 .95124 L
s
.67963 1.14502 m .68943 1.13103 L .68907 1.14009 L 0 .21 .093 r
F
0 g
.49256 .83951 m
.49492 .84141 L
s
.49099 .83824 m
.49256 .83951 L
s
.6435 .84152 m
.64352 .84032 L
s
.64346 .84477 m
.6435 .84152 L
s
.64332 .84226 m
.64352 .84032 L
s
.63881 .88665 m
.63934 .88146 L
s
.63934 .88146 m
.64023 .87266 L
s
.64023 .87266 m
.64064 .86866 L
s
.64262 .84916 m
.64332 .84226 L
s
.43165 .93398 m .42279 .92672 L .42695 .9302 L 0 .136 .182 r
F
0 g
.42695 .9302 m
.42876 .93191 L
s
.79472 .96307 m .80483 .97668 L .80735 .96504 L 0 1 .414 r
F
.79472 .96307 m .80025 .98058 L .80483 .97668 L F
0 g
.80483 .97668 m
.80814 .98118 L
s
.4742 .66342 m
.47584 .66205 L
s
.47001 .66692 m
.4742 .66342 L
s
.45983 .81125 m
.46494 .81472 L
s
.45983 .81125 m
.46106 .81233 L
s
.54051 .97682 m
.54278 .98186 L
s
.53996 .97559 m
.54051 .97682 L
s
.58017 .61413 m .6003 .60748 L .59382 .60621 L 0 1 .516 r
F
0 g
.6003 .60748 m
.60897 .60519 L
s
.52659 1.04297 m
.52674 1.04423 L
s
.52674 1.04423 m
.52699 1.04628 L
s
.52699 1.04628 m
.52705 1.04675 L
s
.52705 1.04675 m
.52767 1.05198 L
s
.52659 1.04297 m
.52684 1.04446 L
s
.52684 1.04446 m
.52728 1.04717 L
s
.52728 1.04717 m
.52732 1.04738 L
s
.52732 1.04738 m
.52811 1.05217 L
s
.23565 .85162 m .22481 .85251 L .22936 .85378 L 0 1 .518 r
F
0 g
.22936 .85378 m
.23079 .85817 L
s
.68782 .89367 m
.69044 .8925 L
s
.69044 .8925 m
.691 .89225 L
s
.7901 .82715 m .80108 .81534 L .80555 .81401 L 0 0 0 r
F
.7901 .82715 m .79448 .82095 L .80108 .81534 L F
0 g
.80006 .81234 m
.80108 .81534 L
s
.66146 .73711 m
.66777 .74436 L
s
.66877 .74551 m
.66943 .74627 L
s
.43165 .93398 m .42143 .92494 L .42279 .92672 L 0 .136 .182 r
F
0 g
.41819 .92355 m
.42279 .92672 L
s
.532 .99155 m .53814 1.0234 L .53437 1.00651 L 0 .544 .169 r
F
.532 .99155 m .54166 1.03128 L .53814 1.0234 L F
.532 .99155 m .54254 1.02482 L .54166 1.03128 L F
.532 .99155 m .54014 1.00976 L .54254 1.02482 L F
0 g
.5363 1.01628 m
.53641 1.01673 L
s
.53584 1.01426 m
.5363 1.01628 L
s
.532 .99155 m .53608 .99618 L .54014 1.00976 L 0 .544 .169 r
F
0 g
.532 .99155 m
.53274 .99618 L
s
.53459 1.00881 m
.53584 1.01426 L
s
.53406 1.00647 m
.53459 1.00881 L
s
.53365 .98447 m
.53608 .99618 L
s
.53001 .98793 m
.532 .99155 L
s
.53333 .99003 m
.53608 .99618 L
s
.81278 .84052 m .82776 .84094 L .824 .8358 L 0 1 .516 r
F
0 g
.82715 .84597 m
.82776 .84094 L
s
.71699 1.1115 m .72635 1.10232 L .72228 1.10828 L 0 0 .016 r
F
.7228 1.1126 m .72635 1.10232 L .73098 1.09672 L 0 0 0 r
F
.7228 1.1126 m .72228 1.10828 L .72635 1.10232 L F
0 g
.72635 1.10232 m
.72707 1.09763 L
s
.72635 1.10232 m
.7269 1.10165 L
s
.41595 .78786 m
.41788 .78859 L
s
.76295 .67992 m .76431 .68413 L .76061 .68763 L 0 0 .03 r
F
.76295 .67992 m .77241 .67233 L .76431 .68413 L F
0 g
.76061 .68763 m
.76295 .67992 L
s
.75839 .68757 m
.76295 .67992 L
s
.43048 .7941 m .42441 .79131 L .42193 .79024 L 0 .289 .195 r
F
0 g
.41595 .78786 m
.42193 .79024 L
s
.43048 .7941 m .43027 .79376 L .42441 .79131 L 0 .289 .195 r
F
.43048 .7941 m .43629 .79662 L .43027 .79376 L F
.43048 .7941 m .43844 .79798 L .43629 .79662 L F
.43048 .7941 m .43594 .7969 L .43844 .79798 L F
.54626 1.13955 m .5517 1.14418 L .55239 1.14893 L 0 .507 .029 r
F
.75039 1.06402 m .74923 1.06947 L .7517 1.06929 L 0 1 .212 r
F
0 g
.74923 1.06947 m
.7517 1.06929 L
s
.74667 1.07578 m
.7517 1.06929 L
s
.2795 .67872 m
.28144 .67447 L
s
.33238 .67318 m
.34088 .66846 L
s
.61353 .59886 m .63321 .59683 L .63537 .59449 L 0 1 .516 r
F
.61353 .59886 m .62386 .59871 L .63321 .59683 L F
0 g
.63321 .59683 m
.63891 .5989 L
s
.62386 .59871 m
.62998 .60035 L
s
.62386 .59871 m
.63321 .59683 L
s
.40351 .78363 m .39404 .78124 L .39698 .78183 L 0 .415 .209 r
F
0 g
.39526 .78074 m
.39698 .78183 L
s
.33394 .87104 m .32389 .86687 L .32414 .8707 L 0 1 .535 r
F
0 g
.31891 .87186 m
.32414 .8707 L
s
.66978 1.1599 m .67632 1.13717 L .67963 1.14502 L 0 .273 .105 r
F
0 g
.671 1.13457 m
.67632 1.13717 L
s
.67632 1.13717 m
.67672 1.12815 L
s
.50514 .98931 m
.5055 .98532 L
s
.48666 .97601 m .48014 .97438 L .48373 .975 L 0 .45 .072 r
F
.48666 .97601 m .47775 .97458 L .48014 .97438 L F
.48666 .97601 m .47817 .97546 L .47775 .97458 L F
0 g
.48373 .975 m
.48572 .97377 L
s
.48666 .97601 m .4811 .97647 L .47817 .97546 L 0 .45 .072 r
F
.48666 .97601 m .48459 .97695 L .4811 .97647 L F
.48666 .97601 m .48697 .97675 L .48459 .97695 L F
0 g
.48666 .97601 m
.48911 .97452 L
s
.48373 .975 m
.48666 .97601 L
s
.48697 .97675 m
.48908 .97635 L
s
.45516 .62952 m .44556 .62855 L .44693 .62975 L 0 1 .411 r
F
0 g
.441 .63258 m
.44693 .62975 L
s
.45516 .62952 m .45209 .62654 L .44556 .62855 L 0 1 .411 r
F
.45516 .62952 m .46219 .62505 L .45209 .62654 L F
.45516 .62952 m .47042 .62482 L .46219 .62505 L F
.45516 .62952 m .47129 .626 L .47042 .62482 L F
.45516 .62952 m .46475 .62801 L .47129 .626 L F
0 g
.44693 .62975 m
.45516 .62952 L
s
.46475 .62801 m
.47275 .62776 L
s
.73132 .70948 m
.73221 .71114 L
s
.73221 .71114 m
.73291 .71243 L
s
.72374 .69532 m
.7272 .71213 L
s
.73462 .87639 m .74026 .87141 L .73584 .87368 L 0 1 .351 r
F
.73462 .87639 m .74576 .87109 L .74026 .87141 L F
.47528 .96934 m .46753 .96365 L .47144 .96578 L 0 .373 .039 r
F
0 g
.47144 .96578 m
.47356 .96562 L
s
.42143 .92494 m .41237 .91798 L .41654 .92148 L 0 .277 .222 r
F
0 g
.41654 .92148 m
.41819 .92355 L
s
.34396 .8758 m .33751 .86775 L .33394 .87104 L 0 1 .526 r
F
.34396 .8758 m .3431 .86691 L .33751 .86775 L F
.34396 .8758 m .34697 .86907 L .3431 .86691 L F
.34396 .8758 m .34734 .87288 L .34697 .86907 L F
0 g
.33839 .87663 m
.34396 .8758 L
s
.34396 .8758 m
.34448 .87946 L
s
.23565 .85162 m .22438 .84826 L .22481 .85251 L 0 1 .518 r
F
0 g
.21936 .85519 m
.22481 .85251 L
s
.4313 .67431 m
.43658 .66929 L
s
.42376 .67416 m
.4313 .67431 L
s
.28755 .66338 m .27919 .66255 L .28285 .66382 L 0 1 .539 r
F
.28755 .66338 m .27847 .66011 L .27919 .66255 L F
.28755 .66338 m .28118 .65811 L .27847 .66011 L F
.28755 .66338 m .28589 .65768 L .28118 .65811 L F
.28755 .66338 m .28945 .65909 L .28589 .65768 L F
.28755 .66338 m .29016 .66153 L .28945 .65909 L F
0 g
.28755 .66338 m
.28834 .6656 L
s
.28285 .66382 m
.28755 .66338 L
s
.74145 .65272 m .75885 .64188 L .75018 .64551 L 0 .845 .188 r
F
0 g
.75885 .64188 m
.76253 .6409 L
s
.27287 .76765 m .26101 .76962 L .26521 .77064 L 0 1 .539 r
F
0 g
.26464 .77607 m
.26521 .77064 L
s
.50036 .9837 m .49496 .98795 L .49768 .98476 L 0 .52 .097 r
F
.50036 .9837 m .49388 .99251 L .49496 .98795 L F
.50036 .9837 m .49517 .99539 L .49388 .99251 L F
.50036 .9837 m .49786 .99433 L .49517 .99539 L F
.50036 .9837 m .50015 .99003 L .49786 .99433 L F
0 g
.49905 .98422 m
.49999 .98385 L
s
.49768 .98476 m
.49905 .98422 L
s
.49768 .98476 m
.49868 .9822 L
s
.49868 .9822 m
.49912 .98105 L
s
.50036 .9837 m .50122 .98548 L .50015 .99003 L 0 .52 .097 r
F
0 g
.50036 .9837 m
.50128 .97998 L
s
.49999 .98385 m
.50036 .9837 L
s
.50122 .98548 m
.50357 .98173 L
s
.52634 1.05246 m .53188 1.08458 L .52908 1.06722 L 0 .062 .17 r
F
.52634 1.05246 m .53301 1.09434 L .53188 1.08458 L F
0 g
.52649 1.07337 m
.52688 1.07504 L
s
.52634 1.05246 m .53171 1.08995 L .53301 1.09434 L 0 .062 .17 r
F
0 g
.52688 1.07504 m
.52742 1.07734 L
s
.52634 1.05246 m .52897 1.07513 L .53171 1.08995 L 0 .062 .17 r
F
0 g
.52809 1.07755 m
.52815 1.07791 L
s
.52807 1.07744 m
.52809 1.07755 L
s
.52634 1.05246 m .52661 1.05979 L .52897 1.07513 L 0 .062 .17 r
F
0 g
.52724 1.05728 m
.5274 1.05813 L
s
.52713 1.05672 m
.52724 1.05728 L
s
.52686 1.05523 m
.52713 1.05672 L
s
.52648 1.05316 m
.52686 1.05523 L
s
.52634 1.05246 m
.52648 1.05316 L
s
.52811 1.05217 m
.52821 1.05278 L
s
.52767 1.05198 m
.52804 1.05504 L
s
.52615 1.0669 m
.52807 1.07744 L
s
.52576 1.05511 m
.52661 1.05979 L
s
.52631 1.05215 m
.52634 1.05246 L
s
.52612 1.05555 m
.52661 1.05979 L
s
.527 1.05212 m
.52722 1.05348 L
s
.52751 1.0553 m
.52753 1.05547 L
s
.52722 1.05348 m
.52751 1.0553 L
s
.31573 .67509 m .30324 .67628 L .30674 .67877 L 0 1 .514 r
F
.40375 .64087 m .39268 .64149 L .39501 .64277 L 0 1 .496 r
F
0 g
.39015 .64764 m
.39501 .64277 L
s
.40375 .64087 m .39826 .63763 L .39268 .64149 L 0 1 .496 r
F
.40375 .64087 m .40806 .63375 L .39826 .63763 L F
.40375 .64087 m .41682 .63185 L .40806 .63375 L F
.40375 .64087 m .41869 .63319 L .41682 .63185 L F
.40375 .64087 m .41309 .63706 L .41869 .63319 L F
0 g
.39851 .6445 m
.40375 .64087 L
s
.39501 .64277 m
.40375 .64087 L
s
.47639 .8245 m
.48095 .82812 L
s
.3453 .65905 m .33315 .6579 L .33631 .65987 L 0 1 .538 r
F
0 g
.33631 .65987 m
.3453 .65905 L
s
.34104 .66295 m
.3453 .65905 L
s
.33266 .66351 m
.33631 .65987 L
s
.7069 1.12719 m .71699 1.1115 L .71617 1.11784 L 0 0 .049 r
F
.42143 .92494 m .41121 .9158 L .41237 .91798 L 0 .277 .222 r
F
0 g
.40762 .91517 m
.41237 .91798 L
s
.7901 .82715 m .80555 .81401 L .80549 .81674 L 0 0 0 r
F
0 g
.80555 .81401 m
.81131 .80985 L
s
.69584 .89192 m
.69584 .89193 L
s
.44186 .94271 m .43376 .93554 L .43165 .93398 L 0 .031 0 r
F
.4467 .94791 m .43827 .93954 L .44217 .9433 L 0 0 .136 r
F
.4467 .94791 m .43982 .94092 L .43827 .93954 L F
.44186 .94271 m .43827 .93954 L .43616 .93767 L 0 .031 0 r
F
.43982 .94092 m .43717 .93823 L .43827 .93954 L 0 0 .136 r
F
.43616 .93767 m .43827 .93954 L .43376 .93554 L 0 .031 0 r
F
0 g
.43736 .93872 m
.4382 .93946 L
s
.4427 .94315 m
.4436 .94362 L
s
.44186 .94271 m .44217 .9433 L .43827 .93954 L 0 .031 0 r
F
.44186 .94271 m .44371 .94466 L .44217 .9433 L F
0 g
.43961 .94072 m
.44186 .94271 L
s
.44186 .94271 m
.4427 .94315 L
s
.40122 .67182 m
.40427 .67221 L
s
.39589 .67115 m
.40122 .67182 L
s
.34991 .77575 m
.35124 .76936 L
s
.58017 .61413 m .57485 .61 L .57367 .61287 L 0 1 .516 r
F
.58017 .61413 m .5835 .60714 L .57485 .61 L F
.58017 .61413 m .59382 .60621 L .5835 .60714 L F
.82906 .93676 m .83618 .92289 L .83159 .9258 L 0 1 .45 r
F
.8176 .94467 m .82906 .93676 L .82471 .93035 L 0 1 .439 r
F
.65039 .58759 m .6709 .58776 L .67352 .58567 L 0 1 .517 r
F
.65039 .58759 m .661 .58858 L .6709 .58776 L F
0 g
.6709 .58776 m
.67633 .59054 L
s
.5452 1.00914 m
.54579 1.01065 L
s
.54579 1.01065 m
.54587 1.01086 L
s
.54587 1.01086 m
.54726 1.01441 L
s
.54726 1.01441 m
.54745 1.01491 L
s
.49675 .62663 m
.50383 .62639 L
s
.72335 .75911 m
.73085 .77806 L
s
.64464 .59326 m .64079 .58861 L .63862 .59096 L 0 1 .51 r
F
.64464 .59326 m .65039 .58759 L .64079 .58861 L F
.64464 .59326 m .661 .58858 L .65039 .58759 L F
0 g
.661 .58858 m
.66698 .59088 L
s
.661 .58858 m
.6709 .58776 L
s
.29618 .67821 m .28797 .67562 L .29159 .67802 L 0 1 .516 r
F
.29618 .67821 m .28722 .67222 L .28797 .67562 L F
0 g
.29043 .68074 m
.29126 .67879 L
s
.29618 .67821 m .28984 .6701 L .28722 .67222 L 0 1 .516 r
F
0 g
.28746 .6758 m
.28797 .67562 L
s
.2795 .67872 m
.28746 .6758 L
s
.29618 .67821 m .29445 .67029 L .28984 .6701 L 0 1 .516 r
F
0 g
.29126 .67879 m
.29158 .67803 L
s
.29618 .67821 m .29797 .67265 L .29445 .67029 L 0 1 .516 r
F
.29618 .67821 m .29871 .67604 L .29797 .67265 L F
0 g
.29618 .67821 m
.29699 .68177 L
s
.29159 .67802 m
.29618 .67821 L
s
.54078 1.12895 m .53848 1.12167 L .53816 1.11903 L 0 .484 0 r
F
0 g
.53497 1.11112 m
.53816 1.11903 L
s
.43483 .49526 m .42265 .49617 L .42406 .49701 L 0 1 .29 r
F
0 g
.41571 .50117 m
.42406 .49701 L
s
.43483 .49526 m .43169 .49327 L .42265 .49617 L 0 1 .29 r
F
.43483 .49526 m .44516 .49023 L .43169 .49327 L F
.43483 .49526 m .45595 .48848 L .44516 .49023 L F
.43483 .49526 m .45684 .48918 L .45595 .48848 L F
.43483 .49526 m .44779 .49208 L .45684 .48918 L F
0 g
.42618 .49814 m
.43483 .49526 L
s
.42406 .49701 m
.43483 .49526 L
s
.44779 .49208 m
.45818 .49008 L
s
.79472 .96307 m .79592 .97476 L .80025 .98058 L 0 1 .414 r
F
0 g
.79672 .99079 m
.80025 .98058 L
s
.25816 .85813 m .25064 .85096 L .24691 .85491 L 0 1 .517 r
F
.25816 .85813 m .25675 .84905 L .25064 .85096 L F
.25816 .85813 m .26116 .85046 L .25675 .84905 L F
.25816 .85813 m .26175 .85436 L .26116 .85046 L F
0 g
.25207 .86002 m
.25816 .85813 L
s
.25816 .85813 m
.25888 .86186 L
s
.55101 1.02363 m
.55248 1.02753 L
s
.55003 1.02102 m
.5502 1.02148 L
s
.5502 1.02148 m
.55101 1.02363 L
s
.54961 1.01991 m
.54972 1.0202 L
s
.54972 1.0202 m
.55003 1.02102 L
s
.41121 .9158 m .40195 .9093 L .40612 .91276 L 0 .38 .321 r
F
0 g
.40612 .91276 m
.40762 .91517 L
s
.67242 .8496 m .68207 .85118 L .67569 .83135 L 0 .591 .297 r
F
0 g
.67569 .83135 m
.67718 .836 L
s
.67457 .81712 m
.67569 .83135 L
s
.68309 .5855 m
.6831 .5855 L
s
.68309 .58555 m
.68309 .58555 L
s
.68309 .58555 m
.68312 .58555 L
s
.53062 1.09572 m .53535 1.11138 L .53346 1.10492 L 0 0 .09 r
F
0 g
.54508 .62978 m
.54704 .6287 L
s
.54704 .6287 m
.55295 .62547 L
s
.53833 .62844 m
.54508 .62978 L
s
.74576 .87109 m .7513 .86572 L .74688 .868 L 0 1 .399 r
F
.74576 .87109 m .7569 .86578 L .7513 .86572 L F
.33954 .74793 m .33152 .752 L .33538 .74553 L 0 .767 .104 r
F
0 g
.54286 .99178 m
.54348 .99065 L
s
.54348 .99065 m
.54441 .98896 L
s
.72313 .66916 m .72389 .65831 L .7204 .65792 L 0 .583 .365 r
F
.72412 .66853 m .72415 .66796 L .72313 .66916 L 0 0 0 r
F
.72412 .66853 m .73277 .66036 L .72748 .66449 L F
.72415 .66796 m .72748 .66449 L .72735 .66425 L 0 .583 .365 r
F
.72415 .66796 m .72735 .66425 L .72389 .65831 L F
.72415 .66796 m .72389 .65831 L .72313 .66916 L F
.7231 .66918 m .72419 .66707 L .72083 .67063 L 0 0 0 r
F
.72313 .66916 m .72314 .66913 L .7231 .66918 L F
.72314 .66913 m .72419 .66707 L .7231 .66918 L F
.72415 .66796 m .72748 .66449 L .72419 .66707 L F
.72412 .66853 m .72748 .66449 L .72415 .66796 L F
.72431 .67403 m .73328 .67445 L .72748 .66449 L 0 .583 .365 r
F
.72431 .67403 m .72748 .66449 L .72415 .66796 L F
.72431 .67403 m .72415 .66796 L .72313 .66916 L F
.72415 .66796 m .72419 .66707 L .72313 .66916 L 0 0 0 r
F
0 g
.71637 .65923 m
.72188 .66951 L
s
.72206 .66984 m
.72224 .67018 L
s
.72225 .67019 m
.72227 .67023 L
s
.72224 .67018 m
.72225 .67019 L
s
.72224 .67026 m
.72227 .67023 L
s
.72227 .67023 m
.72318 .66939 L
s
.47528 .96934 m .46576 .96409 L .46753 .96365 L 0 .373 .039 r
F
0 g
.46361 .96026 m
.46753 .96365 L
s
.47528 .96934 m .46729 .96682 L .46576 .96409 L 0 .373 .039 r
F
.47528 .96934 m .47115 .97039 L .46729 .96682 L F
.47528 .96934 m .47474 .97241 L .47115 .97039 L F
.47528 .96934 m .47651 .97195 L .47474 .97241 L F
0 g
.47528 .96934 m
.47729 .96812 L
s
.47144 .96578 m
.47528 .96934 L
s
.6831 .5855 m
.6831 .58551 L
s
.67724 .57462 m
.68036 .58042 L
s
.68319 .58568 m .70132 .60228 L .69026 .58709 L 0 .415 .38 r
F
.68319 .58568 m .70726 .61336 L .70132 .60228 L F
.68319 .58568 m .70414 .61293 L .70726 .61336 L F
.68319 .58568 m .69382 .60106 L .70414 .61293 L F
0 g
.68309 .58555 m
.68319 .58568 L
s
.7007 .58273 m
.70637 .58575 L
s
.69382 .60106 m
.69946 .61196 L
s
.6831 .58551 m
.68319 .58568 L
s
.69946 .61196 m
.70066 .61374 L
s
.54182 .99366 m
.54204 .994 L
s
.54182 .99366 m
.54188 .99381 L
s
.54188 .99381 m
.54198 .99407 L
s
.54182 .99366 m
.54182 .99366 L
s
.54182 .99366 m
.54182 .99366 L
s
.54198 .99407 m
.54205 .99426 L
s
.54205 .99426 m
.54207 .9943 L
s
.54182 .99366 m
.54182 .99366 L
s
.5419 .99407 m
.54192 .99414 L
s
.54182 .99366 m
.5419 .99407 L
s
.32389 .86687 m .31393 .86698 L .31802 .86842 L 0 1 .539 r
F
0 g
.31802 .86842 m
.31891 .87186 L
s
.30753 .65987 m .29893 .65617 L .29478 .66112 L 0 1 .542 r
F
.30753 .65987 m .30803 .65085 L .29893 .65617 L F
.30753 .65987 m .31727 .64829 L .30803 .65085 L F
.30753 .65987 m .32046 .6502 L .31727 .64829 L F
.30753 .65987 m .31627 .65517 L .32046 .6502 L F
0 g
.30365 .66424 m
.30753 .65987 L
s
.29833 .66241 m
.30753 .65987 L
s
.53334 1.01358 m
.53388 1.01512 L
s
.37416 .77654 m .36611 .77757 L .36397 .77607 L 0 0 0 r
F
.37416 .77654 m .37232 .77899 L .36611 .77757 L F
.37416 .77654 m .37923 .78004 L .37232 .77899 L F
.37416 .77654 m .38221 .78001 L .37923 .78004 L F
.37416 .77654 m .38002 .77851 L .38221 .78001 L F
0 g
.37224 .77527 m
.37416 .77654 L
s
.36729 .7755 m
.37416 .77654 L
s
.72841 .7149 m
.72978 .71803 L
s
.7272 .71213 m
.72841 .7149 L
s
.72978 .71803 m
.73019 .71898 L
s
.73019 .71898 m
.73023 .71906 L
s
.73023 .71906 m
.73158 .72216 L
s
.73158 .72216 m
.73267 .72464 L
s
.5595 1.16648 m .55642 1.15726 L .55584 1.15043 L 0 .657 .074 r
F
0 g
.5517 1.14418 m
.55584 1.15043 L
s
.41309 .63706 m
.4215 .63507 L
s
.40427 .67221 m
.40883 .66647 L
s
.22438 .84826 m .21344 .8493 L .21799 .85059 L 0 1 .52 r
F
0 g
.21799 .85059 m
.21936 .85519 L
s
.67829 .79896 m .6803 .78513 L .67677 .78477 L 0 .62 .341 r
F
0 g
.66951 .77252 m
.67677 .78477 L
s
.28362 .93063 m .27394 .92817 L .27858 .92967 L 0 .476 .231 r
F
0 g
.27858 .92967 m
.28123 .93106 L
s
.55295 .62547 m .57189 .61721 L .56517 .61622 L 0 1 .518 r
F
0 g
.57189 .61721 m
.58017 .61413 L
s
.41121 .9158 m .40099 .90671 L .40195 .9093 L 0 .38 .321 r
F
0 g
.39703 .9069 m
.40195 .9093 L
s
.29016 .66153 m
.29478 .66112 L
s
.55295 .62547 m .54689 .62137 L .54621 .62449 L 0 1 .518 r
F
.55295 .62547 m .55502 .61783 L .54689 .62137 L F
.55295 .62547 m .56517 .61622 L .55502 .61783 L F
0 g
.54621 .62449 m
.55295 .62547 L
s
.38108 .66578 m .36973 .66279 L .37246 .66579 L 0 1 .523 r
F
0 g
.36845 .66951 m
.37246 .66579 L
s
.50441 .64705 m .51367 .64446 L .52076 .63942 L 0 1 .512 r
F
.54078 1.12895 m .5435 1.13156 L .54626 1.13955 L 0 .484 0 r
F
0 g
.54004 1.12277 m
.5435 1.13156 L
s
.54283 1.12685 m
.5435 1.13156 L
s
.28362 .93063 m .2721 .92667 L .27394 .92817 L 0 .476 .231 r
F
0 g
.26962 .92755 m
.27394 .92817 L
s
.31783 .76041 m .30811 .76069 L .30627 .76212 L 0 .838 .254 r
F
0 g
.2991 .76615 m
.30627 .76212 L
s
.31783 .76041 m .31455 .75866 L .30811 .76069 L 0 .838 .254 r
F
.31783 .76041 m .32217 .75705 L .31455 .75866 L F
.31783 .76041 m .32586 .75695 L .32217 .75705 L F
.31783 .76041 m .32399 .75839 L .32586 .75695 L F
0 g
.31621 .76147 m
.31783 .76041 L
s
.31025 .76201 m
.31783 .76041 L
s
.40351 .78363 m .39643 .78178 L .39404 .78124 L 0 .415 .209 r
F
0 g
.38767 .77927 m
.39404 .78124 L
s
.40351 .78363 m .40258 .7831 L .39643 .78178 L 0 .415 .209 r
F
0 g
.39698 .78183 m
.39818 .78216 L
s
.40138 .78282 m
.40153 .78288 L
s
.40351 .78363 m .40914 .78491 L .40258 .7831 L 0 .415 .209 r
F
.40351 .78363 m .4117 .78599 L .40914 .78491 L F
.40351 .78363 m .40928 .78544 L .4117 .78599 L F
.79472 .96307 m .80735 .96504 L .80615 .95338 L 0 1 .414 r
F
0 g
.80483 .97668 m
.80735 .96504 L
s
.80735 .96504 m
.8117 .97114 L
s
.69007 .58051 m .71399 .5812 L .70802 .57794 L 0 1 .519 r
F
0 g
.71399 .5812 m
.72382 .58223 L
s
.31573 .67509 m .30721 .66916 L .30324 .67628 L 0 1 .514 r
F
.31573 .67509 m .31604 .66214 L .30721 .66916 L F
.31573 .67509 m .32506 .65844 L .31604 .66214 L F
.31573 .67509 m .32823 .66053 L .32506 .65844 L F
0 g
.32607 .65911 m
.33315 .6579 L
s
.31573 .67509 m .32422 .66767 L .32823 .66053 L 0 1 .514 r
F
0 g
.31199 .68264 m
.31573 .67509 L
s
.30674 .67877 m
.31573 .67509 L
s
.54144 .98264 m .54729 .98941 L .54354 .98358 L 0 .037 .161 r
F
.54144 .98264 m .55105 1.00049 L .54729 .98941 L F
.54144 .98264 m .55231 1.00941 L .55105 1.00049 L F
.54144 .98264 m .55019 1.00844 L .55231 1.00941 L F
.54144 .98264 m .54611 .99826 L .55019 1.00844 L F
0 g
.54316 1.0001 m
.54323 1.00042 L
s
.54323 1.00042 m
.54334 1.00094 L
s
.54306 .99963 m
.54316 1.0001 L
s
.54296 .99915 m
.54306 .99963 L
s
.54334 1.00094 m
.54342 1.00134 L
s
.54144 .98264 m .54237 .98722 L .54611 .99826 L 0 .037 .161 r
F
0 g
.54113 .98199 m
.54144 .98264 L
s
.54099 .98594 m
.54237 .98722 L
s
.54278 .98186 m
.54354 .98358 L
s
.54004 .98506 m
.5434 .99306 L
s
.54144 .98264 m
.54354 .98358 L
s
.54192 .99414 m
.5421 .995 L
s
.5421 .995 m
.54214 .9952 L
s
.54214 .9952 m
.54219 .99546 L
s
.54219 .99546 m
.54222 .99559 L
s
.54222 .99559 m
.54226 .99578 L
s
.54226 .99578 m
.54277 .99821 L
s
.54277 .99821 m
.54296 .99915 L
s
.54281 .9962 m
.54375 .99862 L
s
.54225 .99478 m
.54281 .9962 L
s
.54207 .9943 m
.54225 .99478 L
s
.5424 .99455 m
.54249 .9947 L
s
.54249 .9947 m
.54343 .99614 L
s
.54204 .994 m
.5424 .99455 L
s
.54343 .99614 m
.54378 .99668 L
s
.54374 .99407 m
.54444 .99422 L
s
.54444 .99422 m
.54477 .9943 L
s
.34991 .77576 m .34126 .7576 L .33954 .74791 L 0 .709 .063 r
F
0 g
.34556 .76017 m
.34768 .76777 L
s
.33954 .74791 m
.34139 .74902 L
s
.52971 1.08335 m .52873 1.08296 L .53063 1.09274 L 0 0 .121 r
F
.52971 1.08335 m .52834 1.07893 L .52873 1.08296 L F
0 g
.52742 1.07734 m
.52873 1.08296 L
s
.52845 1.08007 m
.52873 1.08296 L
s
.52837 1.07921 m
.52845 1.08007 L
s
.52834 1.07898 m
.52837 1.07921 L
s
.52834 1.07893 m
.52834 1.07898 L
s
.52815 1.07791 m
.52834 1.07893 L
s
.33954 .74793 m .33015 .75808 L .33152 .752 L 0 .767 .104 r
F
.33954 .74793 m .33219 .75971 L .33015 .75808 L F
.33954 .74793 m .33637 .76212 L .33219 .75971 L F
.33954 .74793 m .3399 .7637 L .33637 .76212 L F
.33954 .74793 m .34125 .75761 L .3399 .7637 L F
0 g
.33538 .74553 m
.33954 .74793 L
s
.2721 .92667 m .26236 .92448 L .26699 .92595 L 0 .511 .24 r
F
0 g
.26699 .92595 m
.26962 .92755 L
s
.43165 .93398 m .4238 .92604 L .42143 .92494 L 0 .136 .182 r
F
.43165 .93398 m .42851 .92983 L .4238 .92604 L F
.43165 .93398 m .43241 .93377 L .42851 .92983 L F
.43165 .93398 m .43376 .93554 L .43241 .93377 L F
0 g
.42695 .9302 m
.43165 .93398 L
s
.43165 .93398 m
.4332 .93534 L
s
.2721 .92667 m .26057 .92278 L .26236 .92448 L 0 .511 .24 r
F
0 g
.258 .92413 m
.26236 .92448 L
s
.28945 .65909 m
.29016 .66153 L
s
.80092 .82174 m .81224 .81199 L .8167 .81061 L 0 0 0 r
F
0 g
.80059 .81576 m
.80108 .81534 L
s
.80092 .82174 m .80549 .81674 L .81224 .81199 L 0 0 0 r
F
0 g
.81131 .80985 m
.81224 .81199 L
s
.27287 .76765 m .26254 .76497 L .26101 .76962 L 0 1 .539 r
F
0 g
.25398 .77359 m
.26101 .76962 L
s
.22438 .84826 m .2131 .84484 L .21344 .8493 L 0 1 .52 r
F
0 g
.20793 .85218 m
.21344 .8493 L
s
.40098 .90671 m .39181 .90101 L .39582 .90426 L 0 .513 .396 r
F
0 g
.39582 .90426 m
.39703 .9069 L
s
.4977 .65152 m
.50441 .64705 L
s
.49056 .65112 m
.4977 .65152 L
s
.36017 .77493 m
.36396 .77607 L
s
.7569 .86578 m .76236 .86007 L .75793 .86232 L 0 1 .436 r
F
.7569 .86578 m .76805 .86052 L .76236 .86007 L F
0 g
.54442 1.0059 m
.54521 1.00772 L
s
.29871 .67604 m
.30323 .67629 L
s
.32389 .86687 m .31381 .86323 L .31393 .86698 L 0 1 .539 r
F
0 g
.30859 .86838 m
.31393 .86698 L
s
.7228 1.1126 m .73098 1.09672 L .73311 1.0952 L 0 0 0 r
F
0 g
.7269 1.10165 m
.73098 1.09672 L
s
.33394 .87104 m .32764 .86335 L .32389 .86687 L 0 1 .535 r
F
.33394 .87104 m .33339 .86208 L .32764 .86335 L F
.33394 .87104 m .33728 .86391 L .33339 .86208 L F
.33394 .87104 m .33751 .86775 L .33728 .86391 L F
0 g
.32821 .87231 m
.33394 .87104 L
s
.33394 .87104 m
.33432 .87485 L
s
.26057 .92278 m .25076 .92085 L .2554 .9223 L 0 .539 .248 r
F
0 g
.2554 .9223 m
.258 .92413 L
s
.54329 1.00071 m
.5435 1.00113 L
s
.67829 .79896 m .68729 .79906 L .6803 .78513 L 0 .62 .341 r
F
.67829 .79896 m .69309 .81732 L .68729 .79906 L F
.67829 .79896 m .69461 .83156 L .69309 .81732 L F
0 g
.67457 .81712 m
.67479 .81762 L
s
.67829 .79896 m .69084 .83227 L .69461 .83156 L 0 .62 .341 r
F
.67829 .79896 m .68384 .81828 L .69084 .83227 L F
0 g
.67479 .81762 m
.67882 .82676 L
s
.67585 .79345 m
.67829 .79896 L
s
.67677 .78477 m
.67829 .79896 L
s
.52096 .62832 m
.52541 .6288 L
s
.5137 .62712 m
.52096 .62832 L
s
.67242 .8496 m .68678 .87623 L .68207 .85118 L 0 .591 .297 r
F
.67242 .8496 m .68336 .89755 L .68734 .89614 L F
.67242 .8496 m .67696 .87755 L .68336 .89755 L F
0 g
.67735 .89813 m
.6782 .89293 L
s
.6782 .89293 m
.67874 .88968 L
s
.67874 .88968 m
.67945 .88534 L
s
.67212 .83866 m
.67242 .8496 L
s
.67036 .84186 m
.67242 .8496 L
s
.29797 .67265 m
.29871 .67604 L
s
.26057 .92278 m .24904 .91896 L .25076 .92085 L 0 .539 .248 r
F
0 g
.24639 .92077 m
.25076 .92085 L
s
.69681 1.1449 m .70406 1.12382 L .7069 1.12719 L 0 .053 .075 r
F
0 g
.70406 1.12382 m
.70491 1.11747 L
s
.70019 1.12513 m
.70406 1.12382 L
s
.67055 .75107 m
.67073 .75231 L
s
.67041 .75009 m
.67055 .75107 L
s
.67035 .74968 m
.67041 .75009 L
s
.67027 .74916 m
.67035 .74968 L
s
.67162 .75831 m .68246 .75824 L .67414 .747 L 0 .611 .374 r
F
.67162 .75831 m .68933 .77308 L .68246 .75824 L F
.67162 .75831 m .69102 .78457 L .68933 .77308 L F
.67162 .75831 m .6864 .78504 L .69102 .78457 L F
.67162 .75831 m .67809 .77378 L .6864 .78504 L F
0 g
.67073 .75231 m
.67162 .75831 L
s
.50748 .98964 m
.50751 .98879 L
s
.50734 .99397 m
.50748 .98964 L
s
.50716 .98993 m
.50751 .98879 L
s
.40098 .90671 m .39116 .89814 L .39181 .90101 L 0 .513 .396 r
F
0 g
.38686 .89918 m
.39181 .90101 L
s
.44966 .80482 m .44173 .79991 L .44396 .80113 L 0 .19 .182 r
F
0 g
.44318 .80061 m
.44396 .80113 L
s
.76431 .68413 m
.77241 .67233 L
s
.38108 .66578 m .37457 .65816 L .36973 .66279 L 0 1 .523 r
F
0 g
.36133 .66238 m
.36973 .66279 L
s
.38108 .66578 m .38377 .65498 L .37457 .65816 L 0 1 .523 r
F
.38108 .66578 m .39241 .65497 L .38377 .65498 L F
.38108 .66578 m .39471 .65814 L .39241 .65497 L F
.38108 .66578 m .38985 .66277 L .39471 .65814 L F
0 g
.37654 .67054 m
.38108 .66578 L
s
.37246 .66579 m
.38108 .66578 L
s
.43658 .66929 m .4261 .66406 L .42834 .66843 L 0 1 .506 r
F
.43658 .66929 m .4314 .65839 L .4261 .66406 L F
0 g
.42732 .6697 m
.42834 .66843 L
s
.42376 .67416 m
.42732 .6697 L
s
.43658 .66929 m .44073 .6552 L .4314 .65839 L 0 1 .506 r
F
.43658 .66929 m .44897 .65606 L .44073 .6552 L F
.43658 .66929 m .45063 .66041 L .44897 .65606 L F
.43658 .66929 m .44532 .66608 L .45063 .66041 L F
0 g
.42834 .66843 m
.43658 .66929 L
s
.5493 1.01942 m
.54984 1.02114 L
s
.52814 1.04631 m
.52827 1.04726 L
s
.52827 1.04726 m
.52904 1.05318 L
s
.52904 1.05318 m
.52919 1.05435 L
s
.52915 1.05224 m
.52953 1.05445 L
s
.52814 1.04631 m
.52837 1.04767 L
s
.52837 1.04767 m
.52915 1.05224 L
s
.61353 .59886 m .63537 .59449 L .62891 .59265 L 0 1 .516 r
F
0 g
.63537 .59449 m
.64464 .59326 L
s
.24904 .91896 m .23917 .91728 L .24381 .9187 L 0 .563 .265 r
F
0 g
.24381 .9187 m
.24639 .92077 L
s
.52572 .99527 m
.52827 1.00323 L
s
.52572 .99527 m
.52664 1.00171 L
s
.72305 .80681 m .72562 .78098 L .72156 .78127 L 0 .667 .303 r
F
0 g
.72057 .77849 m
.72156 .78127 L
s
.45282 .66626 m
.45865 .66139 L
s
.44532 .66608 m
.45282 .66626 L
s
.50441 .64705 m .49671 .64156 L .49714 .64581 L 0 1 .512 r
F
.50441 .64705 m .50381 .63652 L .49671 .64156 L F
.50441 .64705 m .5137 .63405 L .50381 .63652 L F
.50441 .64705 m .52097 .6353 L .5137 .63405 L F
.50441 .64705 m .52076 .63942 L .52097 .6353 L F
0 g
.52076 .63942 m
.52752 .64075 L
s
.51367 .64446 m
.52076 .63942 L
s
.53526 1.11069 m .53535 1.11138 L .53848 1.12167 L 0 0 .062 r
F
.53526 1.11069 m .53346 1.10492 L .53535 1.11138 L F
0 g
.53497 1.11112 m
.53535 1.11138 L
s
.24904 .91896 m .2375 .91516 L .23917 .91728 L 0 .563 .265 r
F
0 g
.23476 .91747 m
.23917 .91728 L
s
.52839 1.05793 m .52759 1.05582 L .52908 1.06722 L 0 .06 .168 r
F
0 g
.52791 1.05827 m
.528 1.05897 L
s
.52786 1.05786 m
.52791 1.05827 L
s
.52772 1.05682 m
.52786 1.05786 L
s
.52759 1.05582 m
.52772 1.05682 L
s
.52753 1.05547 m
.52759 1.05582 L
s
.52804 1.05504 m
.52827 1.05695 L
s
.52827 1.05695 m
.52831 1.05726 L
s
.52821 1.05278 m
.52876 1.0561 L
s
.5274 1.05813 m
.52765 1.05951 L
s
.42143 .92494 m .41384 .91639 L .41121 .9158 L 0 .277 .222 r
F
.42143 .92494 m .41874 .91984 L .41384 .91639 L F
.42143 .92494 m .42265 .92386 L .41874 .91984 L F
.42143 .92494 m .4238 .92604 L .42265 .92386 L F
0 g
.41654 .92148 m
.42143 .92494 L
s
.42143 .92494 m
.42279 .92672 L
s
.80092 .82174 m .8167 .81061 L .81651 .8125 L 0 0 0 r
F
0 g
.8167 .81061 m
.82257 .80717 L
s
.39044 .50773 m
.39877 .50357 L
s
.37967 .51151 m
.39044 .50773 L
s
.54509 .63304 m
.55301 .63505 L
s
.53834 .6311 m
.54509 .63304 L
s
.52971 1.08335 m .53063 1.09274 L .53342 1.10462 L 0 0 .121 r
F
0 g
.53062 1.09572 m
.531 1.09696 L
s
.53062 1.09572 m
.53063 1.09274 L
s
.48802 .97919 m .4811 .97647 L .48459 .97695 L 0 .472 .072 r
F
.48802 .97919 m .47957 .97841 L .4811 .97647 L F
0 g
.48459 .97695 m
.48697 .97675 L
s
.48802 .97919 m .48102 .98146 L .47957 .97841 L 0 .472 .072 r
F
.48802 .97919 m .48446 .98371 L .48102 .98146 L F
.48802 .97919 m .48759 .98364 L .48446 .98371 L F
.48802 .97919 m .48911 .98171 L .48759 .98364 L F
0 g
.48802 .97919 m
.48982 .97621 L
s
.48459 .97695 m
.48802 .97919 L
s
.47929 .62657 m .47042 .62482 L .47129 .626 L 0 1 .371 r
F
.47929 .62657 m .47749 .62368 L .47042 .62482 L F
0 g
.46475 .62801 m
.47129 .626 L
s
.47929 .62657 m .4878 .62333 L .47749 .62368 L 0 1 .371 r
F
.47929 .62657 m .4958 .62391 L .4878 .62333 L F
.47929 .62657 m .49616 .62501 L .4958 .62391 L F
.47929 .62657 m .48908 .62615 L .49616 .62501 L F
0 g
.47129 .626 m
.47929 .62657 L
s
.48908 .62615 m
.49675 .62663 L
s
.53037 .99851 m .53105 .99589 L .53437 1.00651 L 0 .589 .169 r
F
0 g
.53105 .99589 m
.53141 .99705 L
s
.52877 .98567 m
.53105 .99589 L
s
.37476 .6498 m .363 .65115 L .36577 .65265 L 0 1 .518 r
F
0 g
.36337 .65622 m
.36577 .65265 L
s
.37476 .6498 m .36815 .64607 L .363 .65115 L 0 1 .518 r
F
.37476 .6498 m .37782 .64079 L .36815 .64607 L F
.37476 .6498 m .38683 .63794 L .37782 .64079 L F
.37476 .6498 m .38917 .63942 L .38683 .63794 L F
.37476 .6498 m .38399 .64451 L .38917 .63942 L F
0 g
.36993 .65467 m
.37476 .6498 L
s
.36577 .65265 m
.37476 .6498 L
s
.54329 .98992 m
.54439 .99319 L
s
.54276 .98836 m
.54329 .98992 L
s
.54259 .98788 m
.54276 .98836 L
s
.54237 .98722 m
.54259 .98788 L
s
.65494 .92333 m .65781 .89923 L .66305 .88601 L 0 .402 .159 r
F
0 g
.66227 .88797 m
.66228 .88796 L
s
.66211 .88837 m
.66227 .88797 L
s
.66176 .88926 m
.66211 .88837 L
s
.66228 .88796 m
.66262 .88708 L
s
.66262 .88708 m
.66305 .88601 L
s
.66204 .91409 m
.66302 .92527 L
s
.66018 .89299 m
.6602 .8932 L
s
.66305 .92521 m
.66305 .91277 L
s
.66305 .92564 m
.66305 .92521 L
s
.39116 .89814 m .38179 .89308 L .3858 .89622 L 0 .68 .441 r
F
0 g
.3858 .89622 m
.38686 .89918 L
s
.2131 .84484 m .20205 .84604 L .20661 .84735 L 0 1 .522 r
F
0 g
.20661 .84735 m
.20793 .85218 L
s
.76805 .86052 m .77342 .8545 L .76899 .85672 L 0 1 .464 r
F
.76805 .86052 m .77922 .85535 L .77342 .8545 L F
0 g
.68734 .89614 m
.68737 .896 L
s
.59207 .65291 m
.60048 .65773 L
s
.58655 .64927 m
.59207 .65291 L
s
.24691 .85491 m .23951 .84746 L .23565 .85162 L 0 1 .517 r
F
.24691 .85491 m .24573 .84543 L .23951 .84746 L F
.24691 .85491 m .25014 .8469 L .24573 .84543 L F
.24691 .85491 m .25064 .85096 L .25014 .8469 L F
0 g
.24072 .85692 m
.24691 .85491 L
s
.24691 .85491 m
.24753 .85878 L
s
.56889 .64111 m
.57709 .64446 L
s
.2375 .91516 m .22756 .91374 L .23221 .91515 L 0 .584 .292 r
F
0 g
.23221 .91515 m
.23476 .91747 L
s
.61441 .66889 m
.62293 .67529 L
s
.60959 .6642 m
.61441 .66889 L
s
.69681 1.1449 m .69408 1.13949 L .69502 1.1312 L 0 .053 .075 r
F
0 g
.68943 1.13103 m
.69502 1.1312 L
s
.68111 .72427 m
.68268 .72322 L
s
.68534 .71763 m
.68666 .71587 L
s
.68076 .72376 m
.68213 .72193 L
s
.68666 .71587 m
.68759 .71463 L
s
.76162 1.04858 m .77045 1.03429 L .76593 1.0398 L 0 1 .279 r
F
.76261 1.02825 m .77045 1.03429 L .77389 1.02325 L 0 1 .353 r
F
.76261 1.02825 m .76593 1.0398 L .77045 1.03429 L F
0 g
.77045 1.03429 m
.77287 1.03526 L
s
.44966 .80482 m .4444 .80154 L .44173 .79991 L 0 .19 .182 r
F
.44966 .80482 m .45022 .80493 L .4444 .80154 L F
0 g
.44396 .80113 m
.44636 .80268 L
s
.44731 .80274 m
.44896 .8042 L
s
.44966 .80482 m .45595 .80864 L .45022 .80493 L 0 .19 .182 r
F
.44966 .80482 m .45774 .81017 L .45595 .80864 L F
.44966 .80482 m .45504 .80853 L .45774 .81017 L F
.2375 .91516 m .22596 .91139 L .22756 .91374 L 0 .584 .292 r
F
0 g
.22314 .91419 m
.22756 .91374 L
s
.47505 .65864 m
.48135 .65395 L
s
.67175 .74132 m
.67299 .73937 L
s
.67299 .73937 m
.67306 .73926 L
s
.53526 1.11069 m .53342 1.10462 L .53346 1.10492 L 0 0 .062 r
F
0 g
.531 1.09696 m
.53346 1.10492 L
s
.8176 .94467 m .82471 .93035 L .82012 .93353 L 0 1 .439 r
F
.80615 .95338 m .8176 .94467 L .81325 .93852 L 0 1 .427 r
F
.46742 .48857 m .45595 .48848 L .45684 .48918 L 0 .781 .248 r
F
0 g
.44779 .49208 m
.45684 .48918 L
s
.46742 .48857 m .46558 .48695 L .45595 .48848 L 0 .781 .248 r
F
.46742 .48857 m .47933 .4856 L .46558 .48695 L F
.46742 .48857 m .48993 .48499 L .47933 .4856 L F
.46742 .48857 m .49029 .48552 L .48993 .48499 L F
.46742 .48857 m .48064 .48705 L .49029 .48552 L F
0 g
.45818 .49008 m
.46742 .48857 L
s
.45684 .48918 m
.46742 .48857 L
s
.48064 .48705 m
.49084 .48615 L
s
.78532 1.00164 m .79339 .98681 L .78883 .99121 L 0 1 .402 r
F
.77395 1.014 m .78532 1.00164 L .78198 .99827 L 0 1 .38 r
F
.50936 .86105 m .50574 .85891 L .50609 .8567 L 0 .437 .009 r
F
0 g
.50337 .85006 m
.50609 .8567 L
s
.50936 .86105 m .50887 .86715 L .50574 .85891 L 0 .437 .009 r
F
.50936 .86105 m .51341 .87594 L .50887 .86715 L F
.50936 .86105 m .5167 .88031 L .51341 .87594 L F
.50936 .86105 m .51653 .87734 L .5167 .88031 L F
.50936 .86105 m .51338 .86908 L .51653 .87734 L F
0 g
.50662 .85162 m
.50936 .86105 L
s
.50609 .8567 m
.50936 .86105 L
s
.46576 .96409 m .45778 .95693 L .46168 .95985 L 0 .314 0 r
F
0 g
.46168 .95985 m
.46361 .96026 L
s
.39116 .89814 m .38132 .88981 L .38179 .89308 L 0 .68 .441 r
F
0 g
.37668 .89175 m
.38179 .89308 L
s
.49192 .98188 m
.49228 .9819 L
s
.48911 .98171 m
.49192 .98188 L
s
.65039 .58759 m .67352 .58567 L .66722 .58316 L 0 1 .517 r
F
0 g
.67352 .58567 m
.68309 .58555 L
s
.6876 .71122 m
.69088 .7093 L
s
.70277 .88862 m .71173 .8854 L .71586 .88353 L 0 .83 .205 r
F
.70277 .88862 m .70612 .88759 L .71173 .8854 L F
0 g
.71051 .8872 m
.71173 .8854 L
s
.22596 .91139 m .21596 .91023 L .2206 .91163 L 0 .626 .319 r
F
0 g
.2206 .91163 m
.22314 .91419 L
s
.5835 .60714 m .60281 .60355 L .6045 .60094 L 0 1 .521 r
F
.5835 .60714 m .59382 .60621 L .60281 .60355 L F
0 g
.60281 .60355 m
.60897 .60519 L
s
.59382 .60621 m
.6003 .60748 L
s
.59382 .60621 m
.60281 .60355 L
s
.34522 .66199 m .33298 .6636 L .33614 .6656 L 0 1 .517 r
F
0 g
.33238 .67318 m
.33614 .6656 L
s
.68617 .85402 m
.68695 .85832 L
s
.68617 .85402 m
.68626 .85731 L
s
.68734 .89602 m
.68734 .89613 L
s
.54402 .96994 m
.54762 .97793 L
s
.54402 .96994 m
.54502 .96616 L
s
.54521 .96545 m
.54533 .96501 L
s
.7228 1.1126 m .72075 1.1127 L .72228 1.10828 L 0 0 0 r
F
0 g
.71699 1.1115 m
.72228 1.10828 L
s
.2131 .84484 m .20181 .84135 L .20205 .84604 L 0 1 .522 r
F
0 g
.19648 .84914 m
.20205 .84604 L
s
.82346 .90538 m .83618 .92289 L .83758 .91109 L 0 1 .44 r
F
.82346 .90538 m .83159 .9258 L .83618 .92289 L F
0 g
.83618 .92289 m
.84055 .92954 L
s
.31381 .86323 m .30146 .86288 L .30683 .86461 L 0 1 .536 r
F
0 g
.30683 .86461 m
.30859 .86838 L
s
.50254 .98815 m .49786 .99433 L .50015 .99003 L 0 .539 .1 r
F
.50254 .98815 m .49716 .99985 L .49786 .99433 L F
.50254 .98815 m .49852 1.00291 L .49716 .99985 L F
.50254 .98815 m .50093 1.001 L .49852 1.00291 L F
.50254 .98815 m .50276 .99542 L .50093 1.001 L F
0 g
.50015 .99003 m
.50101 .98637 L
s
.50101 .98637 m
.50122 .98548 L
s
.50254 .98815 m .50345 .98992 L .50276 .99542 L 0 .539 .1 r
F
0 g
.50254 .98815 m
.50311 .98464 L
s
.50015 .99003 m
.50254 .98815 L
s
.50345 .98992 m
.5055 .98532 L
s
.27287 .76765 m .26881 .75977 L .26254 .76497 L 0 1 .539 r
F
.27287 .76765 m .27651 .75675 L .26881 .75977 L F
.27287 .76765 m .28048 .75794 L .27651 .75675 L F
.27287 .76765 m .27891 .76262 L .28048 .75794 L F
0 g
.27152 .77206 m
.27287 .76765 L
s
.26521 .77064 m
.27287 .76765 L
s
.78332 .97394 m .79339 .98681 L .79592 .97476 L 0 1 .399 r
F
.78332 .97394 m .78883 .99121 L .79339 .98681 L F
0 g
.79339 .98681 m
.79672 .99079 L
s
.65283 1.14542 m
.6534 1.14594 L
s
.41121 .9158 m .40387 .90673 L .40099 .90671 L 0 .38 .321 r
F
0 g
.40099 .90671 m
.40195 .9093 L
s
.41121 .9158 m .40897 .90977 L .40387 .90673 L 0 .38 .321 r
F
.41121 .9158 m .41288 .9138 L .40897 .90977 L F
.41121 .9158 m .41384 .91639 L .41288 .9138 L F
0 g
.40612 .91276 m
.41121 .9158 L
s
.41121 .9158 m
.41237 .91798 L
s
.22596 .91139 m .21441 .90764 L .21596 .91023 L 0 .626 .319 r
F
0 g
.21151 .91095 m
.21596 .91023 L
s
.34522 .66199 m .3376 .6572 L .33298 .6636 L 0 1 .517 r
F
.34522 .66199 m .34695 .65065 L .3376 .6572 L F
0 g
.33614 .6656 m
.34522 .66199 L
s
.34088 .66846 m
.34522 .66199 L
s
.47651 .97195 m
.48014 .97438 L
s
.27022 .67306 m
.2724 .6686 L
s
.64576 .83494 m
.64633 .83373 L
s
.64635 .8337 m
.64645 .83348 L
s
.64633 .83373 m
.64635 .8337 L
s
.7204 .65792 m
.72294 .66839 L
s
.71064 .64345 m
.7204 .65792 L
s
.66702 .87361 m
.66925 .88202 L
s
.66925 .88202 m
.67109 .88901 L
s
.67109 .88901 m
.67219 .89319 L
s
.67219 .89319 m
.6724 .89398 L
s
.6724 .89398 m
.67294 .89601 L
s
.67294 .89601 m
.67333 .89748 L
s
.66702 .87361 m
.66717 .89015 L
s
.66717 .89015 m
.66719 .89228 L
s
.75039 1.06402 m .76162 1.04858 L .75916 1.04872 L 0 1 .212 r
F
.77922 .85535 m .7845 .84905 L .78007 .85122 L 0 1 .484 r
F
.77922 .85535 m .79039 .8503 L .7845 .84905 L F
.70277 .88862 m .71586 .88353 L .71633 .88234 L 0 .83 .205 r
F
0 g
.70612 .88759 m
.71173 .8854 L
s
.70552 .88796 m
.70612 .88759 L
s
.71586 .88353 m
.72094 .88273 L
s
.48135 .65395 m .49055 .65112 L .49714 .64581 L 0 1 .509 r
F
.21441 .90764 m .20434 .90674 L .20899 .90813 L 0 .686 .345 r
F
0 g
.20899 .90813 m
.21151 .91095 L
s
.6803 .78513 m
.68729 .79906 L
s
.67808 .77378 m
.6803 .78513 L
s
.72431 .67403 m .74231 .69561 L .73328 .67445 L 0 .583 .365 r
F
0 g
.72313 .66916 m
.72431 .67403 L
s
.72227 .67023 m
.72431 .67403 L
s
.72374 .69532 m
.73132 .70948 L
s
.38132 .88981 m .37205 .8857 L .3759 .88857 L 0 .823 .469 r
F
0 g
.3759 .88857 m
.37668 .89175 L
s
.633 .91351 m
.63524 .88423 L
s
.67256 .7411 m
.67398 .74073 L
s
.21441 .90764 m .20285 .90389 L .20434 .90674 L 0 .686 .345 r
F
0 g
.19987 .90773 m
.20434 .90674 L
s
.32389 .86687 m .31774 .85966 L .31381 .86323 L 0 1 .539 r
F
0 g
.31381 .86323 m
.31393 .86698 L
s
.32389 .86687 m .32363 .85809 L .31774 .85966 L 0 1 .539 r
F
.32389 .86687 m .32754 .85959 L .32363 .85809 L F
.32389 .86687 m .32764 .86335 L .32754 .85959 L F
0 g
.31802 .86842 m
.32389 .86687 L
s
.32389 .86687 m
.32414 .8707 L
s
.44217 .9433 m
.44371 .94466 L
s
.44371 .94466 m
.44511 .94598 L
s
.43594 .7969 m
.44173 .79991 L
s
.43594 .7969 m
.43778 .79769 L
s
.73277 .66036 m .73258 .65862 L .73019 .66149 L 0 0 0 r
F
.73328 .67445 m .73262 .65863 L .73258 .65863 L 0 .642 .377 r
F
.73019 .66149 m .73258 .65862 L .73258 .65863 L 0 0 0 r
F
.72991 .66161 m .73258 .65863 L .72913 .65861 L 0 .642 .377 r
F
.72991 .66161 m .73258 .65863 L .72925 .6619 L 0 0 0 r
F
.73019 .66149 m .73258 .65863 L .72991 .66161 L F
.72998 .66185 m .73258 .65863 L .72991 .66161 L 0 .642 .377 r
F
.73328 .67445 m .73258 .65863 L .72998 .66185 L F
.7107 .67249 m .72925 .6619 L .73258 .65863 L 0 1 .243 r
F
.73258 .65862 m .73258 .65863 L .73258 .65862 L F
.7107 .67249 m .73258 .65863 L .73258 .65862 L F
.7326 .65859 m .73258 .65862 L .73262 .65858 L F
.7107 .67249 m .73258 .65862 L .7326 .65859 L F
.70921 .62639 m .7326 .65859 L .72755 .64514 L 0 .531 .387 r
F
.73277 .66036 m .73262 .65858 L .73258 .65862 L 0 0 0 r
F
.7326 .65859 m .73262 .65863 L .73261 .65859 L 0 .531 .387 r
F
.7107 .67249 m .7326 .65859 L .72804 .65901 L 0 1 .243 r
F
.7326 .65859 m .73262 .65858 L .73261 .65858 L F
.70921 .62639 m .72913 .65861 L .73262 .65863 L 0 .531 .387 r
F
.7326 .65859 m .73261 .65858 L .72804 .65901 L 0 1 .243 r
F
.7326 .65859 m .73261 .65859 L .73261 .65858 L 0 .531 .387 r
F
.7326 .65859 m .73261 .65858 L .72755 .64514 L F
.7326 .65859 m .73261 .65858 L .7326 .65859 L F
.73719 .65274 m .7377 .65374 L .74109 .65061 L 0 1 .278 r
F
.70921 .62639 m .71909 .64479 L .72913 .65861 L 0 .531 .387 r
F
.73572 .65469 m .7377 .65374 L .73719 .65274 L 0 1 .278 r
F
.73277 .66036 m .74145 .65272 L .73311 .65826 L 0 0 0 r
F
.74145 .65272 m .74109 .65061 L .7377 .65374 L 0 .845 .188 r
F
.71851 .66294 m .72804 .65901 L .73527 .65506 L 0 1 .278 r
F
.73549 .6548 m .73527 .65506 L .7377 .65374 L F
.7173 .62715 m .72755 .64514 L .73527 .65506 L 0 .602 .401 r
F
.7173 .62715 m .73527 .65506 L .73549 .6548 L F
.71851 .66294 m .73527 .65506 L .73549 .6548 L 0 1 .278 r
F
.73549 .6548 m .73527 .65506 L .73787 .65841 L 0 .602 .401 r
F
.73719 .65274 m .73787 .65841 L .74137 .65812 L F
.7173 .62715 m .73549 .6548 L .73719 .65274 L F
.73549 .6548 m .73572 .65469 L .73719 .65274 L 0 1 .278 r
F
.73549 .6548 m .73787 .65841 L .73719 .65274 L 0 .602 .401 r
F
.71851 .66294 m .73549 .6548 L .73719 .65274 L 0 1 .278 r
F
.7173 .62715 m .73719 .65274 L .73603 .64467 L 0 .602 .401 r
F
.71851 .66294 m .73719 .65274 L .73625 .65068 L 0 1 .278 r
F
.73719 .65274 m .74109 .65061 L .7384 .65065 L F
.73719 .65274 m .73747 .65225 L .73603 .64467 L 0 .602 .401 r
F
.73769 .65338 m .73895 .65203 L .73603 .64467 L F
.73719 .65274 m .7384 .65065 L .73625 .65068 L 0 1 .278 r
F
.73719 .65274 m .73749 .65234 L .73747 .65225 L 0 .602 .401 r
F
.73719 .65274 m .73769 .65338 L .73749 .65234 L F
.73769 .65338 m .74137 .65812 L .73895 .65203 L F
.73264 .65876 m .73311 .65826 L .73262 .65858 L 0 0 0 r
F
.73277 .66036 m .73311 .65826 L .73264 .65876 L F
0 g
.7327 .66039 m
.73277 .66036 L
s
.72525 .66623 m
.72748 .66449 L
s
.72748 .66449 m
.73013 .66242 L
s
.7327 .66041 m
.73277 .66036 L
s
.26254 .76497 m .25048 .76683 L .25469 .76799 L 0 1 .541 r
F
0 g
.25398 .77359 m
.25469 .76799 L
s
.46576 .96409 m .45623 .95671 L .45778 .95693 L 0 .314 0 r
F
0 g
.45366 .95306 m
.45778 .95693 L
s
.82346 .90538 m .82614 .9183 L .83159 .9258 L 0 1 .44 r
F
0 g
.82906 .93676 m
.83159 .9258 L
s
.45865 .66139 m .44897 .65606 L .45063 .66041 L 0 1 .507 r
F
.45865 .66139 m .45495 .65054 L .44897 .65606 L F
0 g
.4491 .66205 m
.45063 .66041 L
s
.44532 .66608 m
.4491 .66205 L
s
.45865 .66139 m .46459 .64752 L .45495 .65054 L 0 1 .507 r
F
.45865 .66139 m .47261 .64851 L .46459 .64752 L F
.45865 .66139 m .47366 .65283 L .47261 .64851 L F
.45865 .66139 m .46767 .65835 L .47366 .65283 L F
0 g
.45063 .66041 m
.45865 .66139 L
s
.46768 .65835 m
.47505 .65864 L
s
.50959 .99203 m
.50968 .9986 L
s
.50895 .99506 m
.50959 .99203 L
s
.52839 1.05793 m .53461 1.09369 L .53139 1.07413 L 0 .06 .168 r
F
.52839 1.05793 m .53611 1.10517 L .53461 1.09369 L F
.52839 1.05793 m .5349 1.10087 L .53611 1.10517 L F
.52839 1.05793 m .53188 1.08458 L .5349 1.10087 L F
.52839 1.05793 m .52908 1.06722 L .53188 1.08458 L F
0 g
.52884 1.06038 m
.52899 1.06119 L
s
.52872 1.0597 m
.52884 1.06038 L
s
.52853 1.05867 m
.52872 1.0597 L
s
.52839 1.05793 m
.52853 1.05867 L
s
.52765 1.05951 m
.52878 1.0656 L
s
.52878 1.0656 m
.52908 1.06722 L
s
.52876 1.0561 m
.52916 1.05856 L
s
.52831 1.05726 m
.52839 1.05793 L
s
.52896 1.06626 m
.52908 1.06722 L
s
.528 1.05897 m
.52896 1.06626 L
s
.52953 1.05445 m
.53023 1.0586 L
s
.53023 1.0586 m
.5306 1.06077 L
s
.52919 1.05435 m
.52992 1.05987 L
s
.52945 1.06031 m
.5295 1.06057 L
s
.52916 1.05856 m
.52945 1.06031 L
s
.38399 .64451 m
.39268 .64149 L
s
.48135 .65395 m .47261 .64851 L .47366 .65283 L 0 1 .509 r
F
.48135 .65395 m .47919 .6432 L .47261 .64851 L F
.48135 .65395 m .48902 .64044 L .47919 .6432 L F
.48135 .65395 m .49671 .64156 L .48902 .64044 L F
.48135 .65395 m .49714 .64581 L .49671 .64156 L F
0 g
.49055 .65112 m
.4927 .64939 L
s
.4927 .64939 m
.49714 .64581 L
s
.47366 .65283 m
.48135 .65395 L
s
.49714 .64581 m
.50441 .64705 L
s
.40883 .66647 m .39816 .66303 L .40045 .66638 L 0 1 .513 r
F
0 g
.39589 .67114 m
.40045 .66638 L
s
.76261 1.02825 m .77389 1.02325 L .77395 1.014 L 0 1 .353 r
F
0 g
.77045 1.03429 m
.77389 1.02325 L
s
.77389 1.02325 m
.77724 1.02657 L
s
.40883 .66647 m .40344 .65805 L .39816 .66303 L 0 1 .513 r
F
.40883 .66647 m .41279 .65478 L .40344 .65805 L F
.40883 .66647 m .4212 .65486 L .41279 .65478 L F
.40883 .66647 m .42303 .65825 L .4212 .65486 L F
.40883 .66647 m .41773 .66322 L .42303 .65825 L F
0 g
.40045 .66638 m
.40883 .66647 L
s
.20285 .90389 m .19273 .90327 L .19738 .90465 L 0 .746 .369 r
F
0 g
.19738 .90465 m
.19987 .90773 L
s
.38132 .88981 m .37188 .88214 L .37205 .8857 L 0 .823 .469 r
F
0 g
.36692 .88499 m
.37205 .8857 L
s
.30721 .66916 m .29445 .67029 L .29797 .67265 L 0 1 .522 r
F
.54366 .99368 m .55019 1.00844 L .54611 .99826 L 0 0 .129 r
F
0 g
.5435 1.00113 m
.54414 1.00242 L
s
.54329 1.00071 m
.54385 1.00219 L
s
.54366 .99368 m .55408 1.02196 L .55019 1.00844 L 0 0 .129 r
F
.54366 .99368 m .55516 1.02976 L .55408 1.02196 L F
.54366 .99368 m .55268 1.02512 L .55516 1.02976 L F
0 g
.55251 1.02752 m
.55303 1.02898 L
s
.55248 1.02753 m
.55303 1.02898 L
s
.54366 .99368 m .54831 1.01117 L .55268 1.02512 L 0 0 .129 r
F
0 g
.54745 1.01491 m
.54868 1.01805 L
s
.54754 1.01485 m
.54772 1.01528 L
s
.54767 1.01451 m
.54778 1.01481 L
s
.54924 1.01956 m
.5497 1.02098 L
s
.5497 1.02098 m
.55028 1.02279 L
s
.54442 1.0059 m
.54481 1.00693 L
s
.5509 1.02456 m
.55121 1.02552 L
s
.54366 .99368 m .54446 .99773 L .54831 1.01117 L 0 0 .129 r
F
0 g
.54493 1.00165 m
.54529 1.00257 L
s
.54375 .99862 m
.54493 1.00165 L
s
.54449 1.00666 m
.54456 1.00704 L
s
.54342 1.00134 m
.54394 1.00383 L
s
.54394 1.00383 m
.5442 1.00507 L
s
.5434 .99306 m
.54366 .99368 L
s
.54378 .99668 m
.5442 .99733 L
s
.5442 .99733 m
.54446 .99773 L
s
.54598 .99786 m
.54601 .99808 L
s
.54481 1.00693 m
.54767 1.01451 L
s
.54385 1.00219 m
.54562 1.00691 L
s
.54414 1.00242 m
.54561 1.00533 L
s
.5458 .99735 m
.54611 .99826 L
s
.54439 .99319 m
.5458 .99735 L
s
.54572 .99754 m
.54611 .99826 L
s
.54435 .99497 m
.54572 .99754 L
s
.54366 .99368 m
.54435 .99497 L
s
.5452 1.00914 m
.54754 1.01485 L
s
.47119 .65511 m
.47366 .65283 L
s
.46767 .65835 m
.47119 .65511 L
s
.40098 .90671 m .39429 .89756 L .39116 .89814 L 0 .513 .396 r
F
.40098 .90671 m .39947 .90002 L .39429 .89756 L F
.40098 .90671 m .40323 .90386 L .39947 .90002 L F
.40098 .90671 m .40387 .90673 L .40323 .90386 L F
0 g
.39582 .90426 m
.40098 .90671 L
s
.52897 1.07513 m
.52946 1.07783 L
s
.20285 .90389 m .19129 .90016 L .19273 .90327 L 0 .746 .369 r
F
0 g
.18824 .90454 m
.19273 .90327 L
s
.75774 .8438 m .7725 .82916 L .76851 .8382 L 0 .03 .052 r
F
0 g
.77212 .82322 m
.7725 .82916 L
s
.7725 .82916 m
.7788 .82155 L
s
.7128 .88262 m .72303 .88011 L .72846 .87741 L 0 .99 .239 r
F
.7128 .88262 m .71633 .88234 L .72303 .88011 L F
0 g
.72094 .88273 m
.72303 .88011 L
s
.50383 .62639 m .4958 .62391 L .49616 .62501 L 0 .889 .337 r
F
.50383 .62639 m .50333 .62371 L .4958 .62391 L F
0 g
.48908 .62615 m
.49616 .62501 L
s
.50383 .62639 m .51373 .62456 L .50333 .62371 L 0 .889 .337 r
F
.50383 .62639 m .52141 .62594 L .51373 .62456 L F
.50383 .62639 m .52124 .62692 L .52141 .62594 L F
.50383 .62639 m .5137 .62711 L .52124 .62692 L F
0 g
.49616 .62501 m
.50383 .62639 L
s
.50056 .48615 m .48993 .48499 L .49029 .48552 L 0 .661 .231 r
F
.50056 .48615 m .50005 .48496 L .48993 .48499 L F
0 g
.48064 .48705 m
.49029 .48552 L
s
.50056 .48615 m .51392 .48545 L .50005 .48496 L 0 .661 .231 r
F
.50056 .48615 m .5242 .48608 L .51392 .48545 L F
.50056 .48615 m .52402 .48643 L .5242 .48608 L F
.50056 .48615 m .51389 .48645 L .52402 .48643 L F
0 g
.49084 .48615 m
.50056 .48615 L
s
.49029 .48552 m
.50056 .48615 L
s
.51389 .48645 m
.52376 .48676 L
s
.29893 .65617 m .28589 .65767 L .28945 .65909 L 0 1 .541 r
F
.72305 .80681 m .73333 .80414 L .72562 .78098 L 0 .667 .303 r
F
0 g
.71547 .78128 m
.72305 .80681 L
s
.72335 .75911 m
.72562 .78098 L
s
.72156 .78127 m
.72305 .80681 L
s
.53037 .99851 m .53585 1.03388 L .53242 1.01474 L 0 .589 .169 r
F
.53706 1.03182 m .54945 1.10691 L .54554 1.07849 L 0 .14 .186 r
F
.53706 1.03182 m .54968 1.11556 L .54945 1.10691 L F
.53706 1.03182 m .54606 1.09752 L .54968 1.11556 L F
.53706 1.03182 m .54105 1.06509 L .54606 1.09752 L F
.53706 1.03182 m .53721 1.03706 L .54105 1.06509 L F
.53037 .99851 m .53921 1.04467 L .53585 1.03388 L 0 .589 .169 r
F
.53651 1.01719 m .54554 1.07849 L .54897 1.09196 L 0 .161 .193 r
F
.53651 1.01719 m .54062 1.04948 L .54554 1.07849 L F
.53651 1.01719 m .53676 1.0233 L .54062 1.04948 L F
.53706 1.03182 m .54554 1.07849 L .54062 1.04948 L 0 .14 .186 r
F
.53037 .99851 m .54023 1.03979 L .53921 1.04467 L 0 .589 .169 r
F
.53651 1.01719 m .54465 1.05422 L .53988 1.03037 L 0 .161 .193 r
F
.53651 1.01719 m .54856 1.08068 L .54465 1.05422 L F
.53651 1.01719 m .54897 1.09196 L .54856 1.08068 L F
.53037 .99851 m .53814 1.0234 L .54023 1.03979 L 0 .589 .169 r
F
0 g
.53906 1.02544 m
.53988 1.03037 L
s
.53037 .99851 m .53437 1.00651 L .53814 1.0234 L 0 .589 .169 r
F
0 g
.52792 .99251 m
.53037 .99851 L
s
.53274 .99618 m
.53345 1.00068 L
s
.53141 .99705 m
.53237 1.00012 L
s
.53833 .62844 m
.54621 .62449 L
s
.53364 1.02444 m
.53369 1.02469 L
s
.53369 1.02469 m
.53457 1.02939 L
s
.53364 1.02444 m
.5338 1.02499 L
s
.5338 1.02499 m
.53493 1.02899 L
s
.53493 1.02899 m
.53506 1.02946 L
s
.31381 .86323 m .30053 .85903 L .30146 .86288 L 0 1 .536 r
F
0 g
.29502 .86417 m
.30146 .86288 L
s
.66457 1.14805 m
.66663 1.14976 L
s
.46576 .96409 m .45807 .95935 L .45623 .95671 L 0 .314 0 r
F
.46576 .96409 m .46215 .9636 L .45807 .95935 L F
.46576 .96409 m .46575 .96662 L .46215 .9636 L F
.46576 .96409 m .46729 .96682 L .46575 .96662 L F
0 g
.46576 .96409 m
.46753 .96365 L
s
.46168 .95985 m
.46576 .96409 L
s
.23565 .85162 m .22837 .84385 L .22438 .84826 L 0 1 .518 r
F
.23565 .85162 m .23469 .84167 L .22837 .84385 L F
.23565 .85162 m .23911 .84319 L .23469 .84167 L F
.23565 .85162 m .23951 .84746 L .23911 .84319 L F
0 g
.22936 .85378 m
.23565 .85162 L
s
.23565 .85162 m
.23618 .85567 L
s
.46742 .8178 m .46042 .81219 L .4622 .81335 L 0 .06 .157 r
F
0 g
.46494 .81472 m
.46742 .8178 L
s
.46106 .81233 m
.4622 .81335 L
s
.32422 .66767 m
.33298 .6636 L
s
.79039 .8503 m .79559 .84372 L .79115 .84584 L 0 1 .498 r
F
.79039 .8503 m .80158 .84535 L .79559 .84372 L F
.68207 .85118 m .68517 .8327 L .68138 .83257 L 0 .677 .311 r
F
0 g
.67882 .82676 m
.68138 .83257 L
s
.67718 .836 m
.68142 .84918 L
s
.28722 .67222 m .27891 .6698 L .28254 .67209 L 0 1 .523 r
F
.28722 .67222 m .27822 .66651 L .27891 .6698 L F
0 g
.28144 .67447 m
.28219 .67285 L
s
.28722 .67222 m .28094 .66441 L .27822 .66651 L 0 1 .523 r
F
0 g
.27841 .66999 m
.27891 .66981 L
s
.27022 .67306 m
.27841 .66999 L
s
.28722 .67222 m .28563 .66454 L .28094 .66441 L 0 1 .523 r
F
0 g
.28219 .67285 m
.28254 .67209 L
s
.28722 .67222 m .28916 .66681 L .28563 .66454 L 0 1 .523 r
F
.28722 .67222 m .28984 .6701 L .28916 .66681 L F
0 g
.28722 .67222 m
.28797 .67562 L
s
.28254 .67209 m
.28722 .67222 L
s
.42742 .63224 m .41682 .63185 L .41869 .63319 L 0 1 .476 r
F
0 g
.41309 .63706 m
.41869 .63319 L
s
.42742 .63224 m .4231 .62885 L .41682 .63185 L 0 1 .476 r
F
.42742 .63224 m .43336 .6262 L .4231 .62885 L F
.42742 .63224 m .4421 .62525 L .43336 .6262 L F
.42742 .63224 m .44349 .62662 L .4421 .62525 L F
.42742 .63224 m .43719 .62962 L .44349 .62662 L F
0 g
.4215 .63507 m
.42742 .63224 L
s
.41869 .63319 m
.42742 .63224 L
s
.53891 1.02658 m
.53988 1.03037 L
s
.53819 1.02376 m
.53891 1.02658 L
s
.54772 1.01528 m
.54855 1.01732 L
s
.54868 1.01805 m
.54895 1.01875 L
s
.52736 .88672 m .52597 .89375 L .52527 .88572 L 0 .743 .081 r
F
0 g
.52527 .88572 m
.52616 .88615 L
s
.52317 .8778 m
.52527 .88572 L
s
.52736 .88672 m .5295 .90902 L .52597 .89375 L 0 .743 .081 r
F
.52736 .88672 m .53351 .92135 L .5295 .90902 L F
.52736 .88672 m .5356 .92231 L .53351 .92135 L F
.52736 .88672 m .53437 .91129 L .5356 .92231 L F
0 g
.53484 .90455 m
.53594 .91103 L
s
.52736 .88672 m .53084 .89605 L .53437 .91129 L 0 .743 .081 r
F
0 g
.53253 .89102 m
.53484 .90455 L
s
.53084 .89605 m
.53253 .89102 L
s
.52699 .88484 m
.52736 .88672 L
s
.52616 .88615 m
.52736 .88672 L
s
.61353 .59886 m .60872 .59442 L .60703 .59702 L 0 1 .516 r
F
.61353 .59886 m .61811 .59254 L .60872 .59442 L F
.61353 .59886 m .62891 .59265 L .61811 .59254 L F
0 g
.52953 1.04871 m
.53048 1.05553 L
s
.53149 1.05991 m
.53195 1.06256 L
s
.52953 1.04871 m
.53107 1.05749 L
s
.53107 1.05749 m
.53149 1.05991 L
s
.65557 .7759 m .66213 .76481 L .67 .74976 L 0 .922 .139 r
F
0 g
.66974 .75027 m
.67 .74976 L
s
.66973 .75028 m
.66974 .75027 L
s
.30811 .76069 m .29635 .76141 L .30032 .76186 L 0 1 .414 r
F
0 g
.2991 .76615 m
.30032 .76186 L
s
.52397 .99829 m
.52401 .99863 L
s
.51628 .87062 m
.51787 .87665 L
s
.51378 .86929 m
.51628 .87062 L
s
.51358 .86919 m
.51378 .86929 L
s
.51338 .86908 m
.51358 .86919 L
s
.43719 .62962 m
.44556 .62855 L
s
.55502 .61783 m .56517 .61622 L .57367 .61287 L 0 1 .522 r
F
0 g
.56517 .61622 m
.57189 .61721 L
s
.55502 .61783 m .57367 .61287 L .57485 .61 L 0 1 .522 r
F
0 g
.57367 .61287 m
.58017 .61413 L
s
.56517 .61622 m
.57367 .61287 L
s
.7128 .88262 m .72846 .87741 L .72971 .8749 L 0 .99 .239 r
F
0 g
.71633 .88234 m
.72303 .88011 L
s
.71586 .88353 m
.71633 .88234 L
s
.72846 .87741 m
.73462 .87639 L
s
.5137 .62711 m
.52124 .62692 L
s
.37188 .88214 m .36242 .87885 L .36628 .88154 L 0 .942 .486 r
F
0 g
.36628 .88154 m
.36692 .88499 L
s
.78332 .97394 m .79592 .97476 L .79472 .96307 L 0 1 .399 r
F
0 g
.79339 .98681 m
.79592 .97476 L
s
.79592 .97476 m
.80025 .98058 L
s
.42441 .79131 m .41555 .78761 L .4181 .78867 L 0 .393 .223 r
F
0 g
.41788 .78859 m
.4181 .78867 L
s
.43376 .93554 m
.43827 .93954 L
s
.73291 .71243 m
.73344 .7161 L
s
.73344 .7161 m
.73345 .71614 L
s
.73367 .71762 m
.73389 .71913 L
s
.73389 .71913 m
.7339 .71924 L
s
.7339 .71924 m
.73422 .72143 L
s
.81209 .91309 m .82471 .93035 L .82614 .9183 L 0 1 .429 r
F
.81209 .91309 m .82012 .93353 L .82471 .93035 L F
0 g
.82471 .93035 m
.82906 .93676 L
s
.54483 .99905 m
.54499 .99961 L
s
.54446 .99773 m
.54483 .99905 L
s
.54551 1.0014 m
.54576 1.00226 L
s
.54535 1.00086 m
.54551 1.0014 L
s
.54505 .99981 m
.54535 1.00086 L
s
.54499 .99961 m
.54505 .99981 L
s
.38985 .66277 m
.39816 .66303 L
s
.78332 .97394 m .78451 .9857 L .78883 .99121 L 0 1 .399 r
F
0 g
.78532 1.00164 m
.78883 .99121 L
s
.45623 .95671 m .44802 .94871 L .45193 .95215 L 0 .201 0 r
F
0 g
.45193 .95215 m
.45366 .95306 L
s
.46742 .8178 m .4633 .81471 L .46042 .81219 L 0 .06 .157 r
F
.46742 .8178 m .46895 .81925 L .4633 .81471 L F
.46742 .8178 m .4726 .82258 L .47551 .82513 L F
0 g
.4622 .81335 m
.46742 .8178 L
s
.39116 .89814 m .38471 .88859 L .38132 .88981 L 0 .68 .441 r
F
0 g
.38132 .88981 m
.38179 .89308 L
s
.39116 .89814 m .39008 .89051 L .38471 .88859 L 0 .68 .441 r
F
.39116 .89814 m .39384 .89429 L .39008 .89051 L F
.39116 .89814 m .39429 .89756 L .39384 .89429 L F
0 g
.3858 .89622 m
.39116 .89814 L
s
.39116 .89814 m
.39181 .90101 L
s
.53386 .48841 m .5242 .48608 L .52402 .48643 L 0 .546 .221 r
F
0 g
.51389 .48645 m
.52402 .48643 L
s
.53386 .48841 m .5347 .48771 L .5242 .48608 L 0 .546 .221 r
F
.53386 .48841 m .54853 .49021 L .5347 .48771 L F
.53386 .48841 m .55837 .4922 L .54853 .49021 L F
.53386 .48841 m .55766 .49234 L .55837 .4922 L F
.53386 .48841 m .54715 .49072 L .55766 .49234 L F
0 g
.52376 .48676 m
.53386 .48841 L
s
.52402 .48643 m
.53386 .48841 L
s
.54715 .49072 m
.55659 .49235 L
s
.68753 .70581 m .70412 .69035 L .70745 .68612 L 0 1 .189 r
F
.68753 .70581 m .6956 .69877 L .70412 .69035 L F
0 g
.70412 .69035 m
.70694 .68709 L
s
.69319 .7048 m
.69583 .70177 L
s
.52971 1.08335 m .53486 1.10666 L .5325 1.09523 L 0 0 .121 r
F
.52971 1.08335 m .53526 1.11069 L .53486 1.10666 L F
.52971 1.08335 m .53342 1.10462 L .53526 1.11069 L F
0 g
.53018 1.08534 m
.53094 1.08858 L
s
.52998 1.0845 m
.53018 1.08534 L
s
.52982 1.08384 m
.52998 1.0845 L
s
.52971 1.08335 m
.52982 1.08384 L
s
.52946 1.07783 m
.53076 1.0848 L
s
.52897 1.07513 m
.52971 1.08335 L
s
.53063 1.09274 m
.53305 1.10304 L
s
.53305 1.10304 m
.53342 1.10462 L
s
.53342 1.10462 m
.53346 1.10492 L
s
.70921 .62639 m .70726 .61336 L .70414 .61293 L 0 .531 .387 r
F
0 g
.69382 .60106 m
.70414 .61293 L
s
.70921 .62639 m .7173 .62715 L .70726 .61336 L 0 .531 .387 r
F
.70921 .62639 m .72755 .64514 L .7173 .62715 L F
0 g
.70414 .61293 m
.70921 .62639 L
s
.70066 .61374 m
.70921 .62639 L
s
.53526 1.11069 m .53848 1.12167 L .54078 1.12895 L 0 0 .062 r
F
0 g
.53535 1.11138 m
.53848 1.12167 L
s
.53816 1.11903 m
.53842 1.12114 L
s
.54626 1.13955 m .55239 1.14893 L .55008 1.14701 L 0 .507 .029 r
F
.55295 1.16103 m .55239 1.14893 L .55642 1.15726 L 0 .632 .058 r
F
.55295 1.16103 m .55008 1.14701 L .55239 1.14893 L F
0 g
.5517 1.14418 m
.55239 1.14893 L
s
.26254 .76497 m .25219 .76189 L .25048 .76683 L 0 1 .541 r
F
0 g
.24332 .77083 m
.25048 .76683 L
s
.27847 .66011 m .27002 .6592 L .27369 .66057 L 0 1 .538 r
F
.27847 .66011 m .26937 .65657 L .27002 .6592 L F
.27847 .66011 m .27218 .65445 L .26937 .65657 L F
.27847 .66011 m .27697 .65398 L .27218 .65445 L F
.27847 .66011 m .28054 .65549 L .27697 .65398 L F
.27847 .66011 m .28118 .65811 L .28054 .65549 L F
0 g
.27847 .66011 m
.27919 .66255 L
s
.27369 .66057 m
.27847 .66011 L
s
.52097 .6353 m
.5285 .63059 L
s
.5137 .63405 m
.52097 .6353 L
s
.73312 1.0952 m .74428 1.07968 L .73882 1.08789 L 0 0 0 r
F
.73665 1.08664 m .74428 1.07968 L .74923 1.06947 L 0 1 .165 r
F
.73665 1.08664 m .73882 1.08789 L .74428 1.07968 L F
0 g
.74428 1.07968 m
.74667 1.07578 L
s
.74428 1.07968 m
.74472 1.07877 L
s
.37188 .88214 m .36244 .87487 L .36242 .87885 L 0 .942 .486 r
F
0 g
.35714 .87867 m
.36242 .87885 L
s
.76261 1.02825 m .76257 1.03722 L .76593 1.0398 L 0 1 .353 r
F
0 g
.76162 1.04858 m
.76593 1.0398 L
s
.72595 .87424 m .73584 .87368 L .74026 .87141 L 0 1 .335 r
F
.72595 .87424 m .72972 .87489 L .73584 .87368 L F
0 g
.73462 .87639 m
.73584 .87368 L
s
.35591 .65437 m
.363 .65115 L
s
.80158 .84535 m .8067 .83852 L .80225 .84059 L 0 1 .508 r
F
.80158 .84535 m .81278 .84052 L .8067 .83852 L F
.33771 .65367 m .32522 .65307 L .3284 .65499 L 0 1 .54 r
F
0 g
.32522 .65855 m
.3284 .65499 L
s
.4261 .66406 m
.4314 .65839 L
s
.41773 .66322 m
.4261 .66406 L
s
.56695 .49584 m .55837 .4922 L .55766 .49234 L 0 .461 .222 r
F
0 g
.54715 .49072 m
.55766 .49234 L
s
.56695 .49584 m .56913 .49562 L .55837 .4922 L 0 .461 .222 r
F
.56695 .49584 m .58276 .50032 L .56913 .49562 L F
.56695 .49584 m .59205 .50381 L .58276 .50032 L F
0 g
.58895 .50346 m
.5902 .50411 L
s
.56695 .49584 m .59081 .50376 L .59205 .50381 L 0 .461 .222 r
F
.56695 .49584 m .58005 .50035 L .59081 .50376 L F
0 g
.55659 .49235 m
.56695 .49584 L
s
.55766 .49234 m
.56695 .49584 L
s
.58005 .50035 m
.58895 .50346 L
s
.30721 .66916 m .29867 .66343 L .29445 .67029 L 0 1 .522 r
F
.30721 .66916 m .30784 .65664 L .29867 .66343 L F
.30721 .66916 m .31711 .65314 L .30784 .65664 L F
.30721 .66916 m .32029 .65527 L .31711 .65314 L F
.30721 .66916 m .31604 .66214 L .32029 .65527 L F
0 g
.30324 .67628 m
.30721 .66916 L
s
.29797 .67265 m
.30721 .66916 L
s
.80615 .95338 m .81325 .93852 L .80867 .942 L 0 1 .427 r
F
.79472 .96307 m .80615 .95338 L .80182 .94751 L 0 1 .414 r
F
.5835 .60714 m .6045 .60094 L .59767 .5995 L 0 1 .521 r
F
0 g
.6045 .60094 m
.61353 .59886 L
s
.49762 .84803 m .49276 .843 L .49362 .84281 L 0 .276 0 r
F
0 g
.49099 .83824 m
.49362 .84281 L
s
.49762 .84803 m .49584 .8486 L .49276 .843 L 0 .276 0 r
F
.49762 .84803 m .50083 .85589 L .49584 .8486 L F
.49762 .84803 m .50481 .86106 L .50048 .85501 L F
.49762 .84803 m .50521 .86082 L .50486 .86113 L F
.50481 .86106 m .50486 .86113 L .50485 .86114 L F
.49762 .84803 m .50486 .86113 L .50481 .86106 L F
.49712 .85019 m .50397 .85943 L .49956 .85323 L 0 0 .14 r
F
.49614 .84898 m .49825 .85179 L .49712 .85019 L F
.49825 .85179 m .50397 .85943 L .49712 .85019 L F
.49584 .8486 m .49657 .84957 L .49614 .84898 L F
.49657 .84957 m .50397 .85943 L .49614 .84898 L F
.50048 .85501 m .50485 .86114 L .50083 .85589 L 0 .276 0 r
F
.50481 .86106 m .50485 .86114 L .50048 .85501 L F
.49762 .84803 m .5021 .85519 L .50521 .86082 L F
0 g
.49362 .84281 m
.49762 .84803 L
s
.49492 .84141 m
.49762 .84803 L
s
.58005 .50035 m
.58984 .50345 L
s
.28984 .6701 m
.29445 .67029 L
s
.48357 .83267 m .47753 .82679 L .4789 .82759 L 0 .099 0 r
F
0 g
.47639 .8245 m
.4789 .82759 L
s
.45623 .95671 m .4467 .94791 L .44802 .94871 L 0 .201 0 r
F
0 g
.44511 .94598 m
.44802 .94871 L
s
.69727 .8911 m
.69731 .89092 L
s
.69731 .89092 m
.69809 .88751 L
s
.69809 .88751 m
.69886 .88418 L
s
.69886 .88418 m
.69985 .87983 L
s
.47775 .97458 m .47115 .97039 L .47474 .97241 L 0 .386 .042 r
F
.47775 .97458 m .46884 .96958 L .47115 .97039 L F
.47775 .97458 m .46936 .97051 L .46884 .96958 L F
.47775 .97458 m .47237 .97269 L .46936 .97051 L F
0 g
.47474 .97241 m
.47651 .97195 L
s
.47775 .97458 m .47587 .97465 L .47237 .97269 L 0 .386 .042 r
F
.47775 .97458 m .47817 .97546 L .47587 .97465 L F
0 g
.47775 .97458 m
.48014 .97438 L
s
.47474 .97241 m
.47775 .97458 L
s
.47817 .97546 m
.4811 .97647 L
s
.81209 .91309 m .81472 .92614 L .82012 .93353 L 0 1 .429 r
F
0 g
.8176 .94467 m
.82012 .93353 L
s
.37457 .65816 m .36289 .65573 L .36563 .65848 L 0 1 .528 r
F
0 g
.36133 .66238 m
.36563 .65848 L
s
.40928 .78544 m
.41166 .78598 L
s
.72595 .87424 m .74026 .87141 L .74062 .8687 L 0 1 .335 r
F
0 g
.72972 .87489 m
.73584 .87368 L
s
.74026 .87141 m
.74576 .87109 L
s
.28916 .66681 m
.28984 .6701 L
s
.68753 .70581 m .70745 .68612 L .70365 .68756 L 0 1 .189 r
F
0 g
.7017 .69274 m
.70412 .69035 L
s
.6956 .69877 m
.69914 .69706 L
s
.6876 .71122 m
.6886 .71007 L
s
.6886 .71007 m
.69319 .7048 L
s
.70745 .68612 m
.7155 .67738 L
s
.61811 .59254 m .63862 .59096 L .64079 .58861 L 0 1 .521 r
F
.61811 .59254 m .62891 .59265 L .63862 .59096 L F
0 g
.63862 .59096 m
.64464 .59326 L
s
.62891 .59265 m
.63862 .59096 L
s
.62891 .59265 m
.63537 .59449 L
s
.54078 1.12895 m .54626 1.13955 L .54659 1.14222 L 0 .484 0 r
F
.59946 .50892 m .59205 .50381 L .59081 .50376 L 0 .414 .231 r
F
0 g
.59081 .50376 m
.59083 .50377 L
s
.58984 .50345 m
.59081 .50376 L
s
.59946 .50892 m .60296 .50915 L .59205 .50381 L 0 .414 .231 r
F
0 g
.59083 .50377 m
.59688 .50738 L
s
.59946 .50892 m .61625 .51623 L .60296 .50915 L 0 .414 .231 r
F
.59946 .50892 m .6249 .52139 L .61625 .51623 L F
0 g
.61535 .51764 m
.62051 .52063 L
s
.62051 .52063 m
.62099 .52098 L
s
.59946 .50892 m .62314 .52119 L .6249 .52139 L 0 .414 .231 r
F
0 g
.62099 .52098 m
.62171 .5215 L
s
.59946 .50892 m .61224 .51585 L .62314 .52119 L 0 .414 .231 r
F
0 g
.61224 .51585 m
.61535 .51764 L
s
.5902 .50411 m
.59946 .50892 L
s
.59688 .50738 m
.59946 .50892 L
s
.55301 .63505 m .54694 .63112 L .54625 .63195 L 0 .632 .318 r
F
0 g
.53834 .6311 m
.54625 .63195 L
s
.55301 .63505 m .55513 .63312 L .54694 .63112 L 0 .632 .318 r
F
.55301 .63505 m .56535 .63661 L .55513 .63312 L F
.55301 .63505 m .57211 .63972 L .56535 .63661 L F
.55301 .63505 m .5709 .64037 L .57211 .63972 L F
.55301 .63505 m .56272 .63837 L .5709 .64037 L F
0 g
.54625 .63195 m
.55301 .63505 L
s
.56272 .63837 m
.56889 .64111 L
s
.30053 .85903 m .28974 .85926 L .29413 .86059 L 0 1 .525 r
F
0 g
.29413 .86059 m
.29502 .86417 L
s
.73665 1.08664 m .74923 1.06947 L .75039 1.06402 L 0 1 .165 r
F
0 g
.74472 1.07877 m
.74923 1.06947 L
s
.48357 .83267 m .48052 .83055 L .47753 .82679 L 0 .099 0 r
F
.48357 .83267 m .48589 .83639 L .48052 .83055 L F
.48357 .83267 m .48957 .84021 L .48554 .83583 L F
.48357 .83267 m .49145 .84243 L .49136 .84233 L F
.48957 .84021 m .49136 .84233 L .49058 .84149 L F
.48357 .83267 m .49136 .84233 L .48957 .84021 L F
.48357 .83267 m .48844 .83865 L .49145 .84243 L F
.4824 .83172 m .48847 .83781 L .48344 .83237 L 0 .081 .176 r
F
.48093 .83081 m .48417 .83382 L .4824 .83172 L F
.48417 .83382 m .48847 .83781 L .4824 .83172 L F
.48052 .83055 m .48162 .83155 L .48093 .83081 L F
.48162 .83155 m .48847 .83781 L .48093 .83081 L F
.48554 .83583 m .49058 .84149 L .48589 .83639 L 0 .099 0 r
F
.48957 .84021 m .49058 .84149 L .48554 .83583 L F
0 g
.48095 .82812 m
.48337 .83233 L
s
.4789 .82759 m
.4831 .83216 L
s
.54554 1.00323 m .55269 1.02512 L .54832 1.01118 L 0 0 .106 r
F
0 g
.54521 1.00772 m
.54665 1.011 L
s
.54554 1.00323 m .55665 1.03998 L .55269 1.02512 L 0 0 .106 r
F
.54554 1.00323 m .55754 1.04579 L .55665 1.03998 L F
.54554 1.00323 m .55473 1.03773 L .55754 1.04579 L F
0 g
.54561 1.00533 m
.54564 1.0054 L
s
.54554 1.00323 m .55012 1.02126 L .55473 1.03773 L 0 0 .106 r
F
0 g
.55121 1.02552 m
.55148 1.02641 L
s
.54665 1.011 m
.54698 1.01176 L
s
.54554 1.00323 m .5462 1.00651 L .55012 1.02126 L 0 0 .106 r
F
0 g
.54747 1.01287 m
.54751 1.01297 L
s
.54529 1.00257 m
.54554 1.00323 L
s
.54698 1.01176 m
.54747 1.01287 L
s
.54669 1.00974 m
.54681 1.01005 L
s
.54562 1.00691 m
.54669 1.00974 L
s
.54564 1.0054 m
.5462 1.00651 L
s
.54895 1.01875 m
.54972 1.02144 L
s
.54576 1.00226 m
.54647 1.00476 L
s
.54679 1.00679 m
.54688 1.00705 L
s
.5467 1.00654 m
.54679 1.00679 L
s
.54595 1.00438 m
.5467 1.00654 L
s
.54579 1.00394 m
.54595 1.00438 L
s
.54554 1.00323 m
.54579 1.00394 L
s
.31381 .86323 m .30469 .8556 L .30053 .85903 L 0 1 .536 r
F
0 g
.30053 .85903 m
.30146 .86288 L
s
.31381 .86323 m .31169 .8542 L .30469 .8556 L 0 1 .536 r
F
.31381 .86323 m .31684 .85579 L .31169 .8542 L F
.31381 .86323 m .31774 .85966 L .31684 .85579 L F
0 g
.30683 .86461 m
.31381 .86323 L
s
.53027 1.06261 m .52954 1.06084 L .53139 1.07413 L 0 .063 .168 r
F
0 g
.52966 1.06171 m
.52974 1.0623 L
s
.52959 1.0612 m
.52966 1.06171 L
s
.52954 1.06084 m
.52959 1.0612 L
s
.53048 1.05553 m
.5313 1.06146 L
s
.5313 1.06146 m
.53137 1.06193 L
s
.5295 1.06057 m
.52954 1.06084 L
s
.52992 1.05987 m
.53015 1.06164 L
s
.53015 1.06164 m
.53021 1.0621 L
s
.53021 1.0621 m
.53022 1.06222 L
s
.52899 1.06119 m
.52985 1.06583 L
s
.60048 .65773 m .60959 .6642 L .61806 .66882 L 0 .561 .385 r
F
.60048 .65773 m .59663 .65206 L .59493 .65253 L F
.60048 .65773 m .60511 .65669 L .59663 .65206 L F
.60048 .65773 m .6147 .66332 L .60511 .65669 L F
.60048 .65773 m .62025 .66852 L .6147 .66332 L F
.60048 .65773 m .61806 .66882 L .62025 .66852 L F
.42441 .79131 m .41831 .78831 L .41555 .78761 L 0 .393 .223 r
F
0 g
.40928 .78544 m
.41555 .78761 L
s
.42441 .79131 m .42458 .79033 L .41831 .78831 L 0 .393 .223 r
F
.42441 .79131 m .43091 .79297 L .42458 .79033 L F
.42441 .79131 m .43306 .79447 L .43091 .79297 L F
.42441 .79131 m .43027 .79376 L .43306 .79447 L F
0 g
.4181 .78867 m
.42441 .79131 L
s
.57709 .64446 m .58655 .64927 L .59493 .65253 L 0 .576 .344 r
F
.57709 .64446 m .57211 .63972 L .5709 .64037 L F
0 g
.56272 .63837 m
.5709 .64037 L
s
.57709 .64446 m .58049 .64298 L .57211 .63972 L 0 .576 .344 r
F
.57709 .64446 m .59045 .64797 L .58049 .64298 L F
.57709 .64446 m .59663 .65206 L .59045 .64797 L F
.57709 .64446 m .59493 .65253 L .59663 .65206 L F
0 g
.58655 .64927 m
.59493 .65253 L
s
.5709 .64037 m
.57709 .64446 L
s
.59493 .65253 m
.60048 .65773 L
s
.50484 .99255 m .50093 1.001 L .50276 .99542 L 0 .558 .104 r
F
.50484 .99255 m .50062 1.0076 L .50093 1.001 L F
.50484 .99255 m .50204 1.01079 L .50062 1.0076 L F
.50484 .99255 m .50414 1.00789 L .50204 1.01079 L F
0 g
.50276 .99542 m
.50345 .98992 L
s
.50484 .99255 m .50549 1.00085 L .50414 1.00789 L 0 .558 .104 r
F
.50484 .99255 m .50579 .99428 L .50549 1.00085 L F
0 g
.50484 .99255 m
.50514 .98931 L
s
.50276 .99542 m
.50484 .99255 L
s
.50579 .99428 m
.50716 .98993 L
s
.38132 .88981 m .37552 .88025 L .37188 .88214 L 0 .823 .469 r
F
.38132 .88981 m .38095 .88148 L .37552 .88025 L F
.38132 .88981 m .38455 .88502 L .38095 .88148 L F
.38132 .88981 m .38471 .88859 L .38455 .88502 L F
0 g
.3759 .88857 m
.38132 .88981 L
s
.67322 .89727 m
.67333 .89749 L
s
.67322 .89726 m
.67322 .89727 L
s
.67292 .89664 m
.67322 .89726 L
s
.67246 .89567 m
.67292 .89664 L
s
.66719 .89228 m
.67075 .89457 L
s
.67075 .89457 m
.67246 .89567 L
s
.61224 .51585 m
.62252 .52088 L
s
.5285 .63059 m .52141 .62649 L .52124 .62975 L 0 1 .519 r
F
0 g
.52124 .62692 m
.52138 .62697 L
s
.42265 .49617 m
.43169 .49327 L
s
.41181 .49898 m
.42265 .49617 L
s
.62293 .67529 m .62025 .66852 L .61806 .66882 L 0 .576 .417 r
F
0 g
.60959 .6642 m
.61806 .66882 L
s
.62293 .67529 m .62874 .6746 L .62025 .66852 L 0 .576 .417 r
F
.62293 .67529 m .63786 .68301 L .62874 .6746 L F
.62293 .67529 m .64272 .68948 L .63786 .68301 L F
0 g
.63495 .68852 m
.63566 .68956 L
s
.62293 .67529 m .64008 .68969 L .64272 .68948 L 0 .576 .417 r
F
0 g
.63778 .69156 m
.6442 .69762 L
s
.63566 .68956 m
.63778 .69156 L
s
.62293 .67529 m .6316 .68361 L .64008 .68969 L 0 .576 .417 r
F
0 g
.61806 .66882 m
.62293 .67529 L
s
.63159 .68361 m
.63495 .68852 L
s
.39643 .78178 m .38666 .78023 L .38962 .78055 L 0 .512 .232 r
F
0 g
.38767 .77927 m
.38962 .78055 L
s
.22438 .84826 m .21723 .84015 L .2131 .84484 L 0 1 .52 r
F
.22438 .84826 m .22365 .8378 L .21723 .84015 L F
.22438 .84826 m .22807 .83936 L .22365 .8378 L F
.22438 .84826 m .22837 .84385 L .22807 .83936 L F
0 g
.21799 .85059 m
.22438 .84826 L
s
.22438 .84826 m
.22481 .85251 L
s
.82346 .90538 m .83758 .91109 L .83485 .89823 L 0 1 .44 r
F
0 g
.83618 .92289 m
.83758 .91109 L
s
.36244 .87487 m .35278 .87254 L .35664 .875 L 0 1 .497 r
F
0 g
.35664 .875 m
.35714 .87867 L
s
.76851 .8382 m .78348 .82511 L .7793 .83264 L 0 0 .029 r
F
0 g
.78326 .82038 m
.78348 .82511 L
s
.78348 .82511 m
.78994 .81855 L
s
.29893 .65617 m .2903 .65225 L .28589 .65767 L 0 1 .541 r
F
.29893 .65617 m .29977 .64643 L .2903 .65225 L F
.29893 .65617 m .30929 .64349 L .29977 .64643 L F
.29893 .65617 m .31249 .64542 L .30929 .64349 L F
.29893 .65617 m .30803 .65085 L .31249 .64542 L F
0 g
.28945 .65909 m
.29893 .65617 L
s
.29478 .66112 m
.29893 .65617 L
s
.6316 .68361 m
.63952 .6893 L
s
.5221 1.00012 m
.52225 1.00193 L
s
.54821 1.01592 m .55629 1.04534 L .55151 1.02789 L 0 0 .069 r
F
0 g
.54778 1.01481 m
.54821 1.01592 L
s
.28118 .65811 m
.28589 .65768 L
s
.64864 .79844 m .66477 .76283 L .66213 .76481 L 0 1 .138 r
F
0 g
.66477 .76283 m
.66616 .75909 L
s
.65909 .77937 m
.66133 .77214 L
s
.73667 .86735 m .74688 .868 L .7513 .86572 L 0 1 .403 r
F
.73667 .86735 m .74062 .8687 L .74688 .868 L F
0 g
.74576 .87109 m
.74688 .868 L
s
.54657 1.00793 m
.54664 1.00817 L
s
.5462 1.00651 m
.54657 1.00793 L
s
.72389 .65831 m
.72427 .65896 L
s
.72765 .66478 m
.72813 .66561 L
s
.72748 .66449 m
.72765 .66478 L
s
.72716 .66394 m
.72748 .66449 L
s
.72502 .66026 m
.72546 .66102 L
s
.72679 .6633 m
.72716 .66394 L
s
.71909 .64479 m
.72389 .65831 L
s
.65617 .58189 m .67746 .58253 L .68009 .58042 L 0 1 .522 r
F
.65617 .58189 m .66722 .58316 L .67746 .58253 L F
0 g
.67746 .58253 m
.68309 .5855 L
s
.47587 .97465 m
.47817 .97546 L
s
.28362 .93063 m .27429 .92616 L .2721 .92667 L 0 .476 .231 r
F
.28362 .93063 m .27935 .92711 L .27429 .92616 L F
.28362 .93063 m .28389 .9289 L .27935 .92711 L F
.28362 .93063 m .28572 .93041 L .28389 .9289 L F
0 g
.27858 .92967 m
.28362 .93063 L
s
.63106 .5282 m .6249 .52139 L .62314 .52119 L 0 .399 .286 r
F
0 g
.62252 .52088 m
.62314 .52119 L
s
.63106 .5282 m .63582 .52875 L .6249 .52139 L 0 .399 .286 r
F
.63106 .5282 m .64864 .53838 L .63582 .52875 L F
.63106 .5282 m .65656 .54539 L .64864 .53838 L F
.63106 .5282 m .65431 .54511 L .65656 .54539 L F
0 g
.65094 .54441 m
.65214 .54553 L
s
.63106 .5282 m .64338 .53774 L .65431 .54511 L 0 .399 .286 r
F
0 g
.64338 .53774 m
.65094 .54441 L
s
.62171 .5215 m
.63106 .5282 L
s
.62314 .52119 m
.63106 .5282 L
s
.73571 .7316 m .75324 .75508 L .74542 .73067 L 0 .656 .343 r
F
.73571 .7316 m .75607 .77434 L .75324 .75508 L F
.73571 .7316 m .75201 .77556 L .75607 .77434 L F
.73571 .7316 m .74327 .75722 L .75201 .77556 L F
0 g
.73335 .72621 m
.73571 .7316 L
s
.73461 .7241 m
.73571 .7316 L
s
.73331 .75864 m
.74111 .77653 L
s
.81278 .84052 m .81782 .83344 L .81337 .83546 L 0 1 .516 r
F
.81278 .84052 m .824 .8358 L .81782 .83344 L F
.68207 .85118 m .69167 .84973 L .68517 .8327 L 0 .677 .311 r
F
0 g
.68384 .81828 m
.68517 .8327 L
s
.33147 .75194 m
.33152 .7519 L
s
.32965 .75351 m
.33147 .75194 L
s
.32565 .75695 m
.32965 .75351 L
s
.37457 .65816 m .36803 .6511 L .36289 .65573 L 0 1 .528 r
F
0 g
.35417 .65598 m
.36289 .65573 L
s
.37457 .65816 m .37766 .64766 L .36803 .6511 L 0 1 .528 r
F
.37457 .65816 m .38663 .64733 L .37766 .64766 L F
.37457 .65816 m .38895 .65034 L .38663 .64733 L F
.37457 .65816 m .38377 .65498 L .38895 .65034 L F
0 g
.36973 .66279 m
.37457 .65816 L
s
.36563 .65848 m
.37457 .65816 L
s
.66143 .55414 m .68558 .57516 L .6796 .56711 L 0 .411 .369 r
F
.69007 .58051 m .68669 .57512 L .68565 .57595 L 0 1 .519 r
F
.69007 .58051 m .68565 .57595 L .68587 .57824 L F
.69026 .58709 m .68672 .57615 L .68554 .57604 L 0 .506 .402 r
F
.68506 .57779 m .68554 .57604 L .68401 .5759 L F
.69026 .58709 m .68554 .57604 L .68506 .57779 L F
.66197 .57615 m .68404 .57725 L .68554 .57604 L 0 1 .526 r
F
.68557 .57595 m .68554 .57604 L .68565 .57595 L F
.66197 .57615 m .68554 .57604 L .68557 .57595 L F
.68558 .57517 m .68565 .57595 L .68669 .57512 L F
.66143 .55414 m .68401 .5759 L .68554 .57604 L 0 .411 .369 r
F
.68555 .57595 m .68565 .57595 L .68558 .57517 L 0 1 .526 r
F
.68558 .57517 m .68554 .57604 L .68672 .57615 L 0 .411 .369 r
F
.66143 .55414 m .68554 .57604 L .68558 .57517 L F
.66143 .55414 m .67317 .56646 L .68401 .5759 L F
.66197 .57615 m .68555 .57595 L .68558 .57517 L 0 1 .526 r
F
.66197 .57615 m .68558 .57517 L .67974 .57218 L F
.68558 .57517 m .68669 .57512 L .68551 .57462 L F
.68558 .57516 m .68558 .57517 L .68556 .57499 L 0 .411 .369 r
F
.68558 .57516 m .68553 .57464 L .6796 .56711 L F
.68558 .57517 m .68551 .57462 L .67974 .57218 L 0 1 .526 r
F
.68556 .57499 m .68558 .57517 L .68553 .57464 L 0 .411 .369 r
F
.68558 .57517 m .68672 .57615 L .68554 .57466 L F
.68558 .57517 m .68554 .57466 L .68553 .57464 L F
.68587 .57824 m .68565 .57595 L .68404 .57725 L 0 1 .519 r
F
0 g
.68158 .57712 m
.68443 .58039 L
s
.68443 .58039 m
.68449 .58046 L
s
.68449 .58046 m
.68449 .58046 L
s
.69007 .58051 m .69698 .57542 L .68669 .57512 L 0 1 .519 r
F
.69007 .58051 m .70802 .57794 L .69698 .57542 L F
0 g
.68772 .57924 m
.69007 .58051 L
s
.70802 .57794 m
.71399 .5812 L
s
.68449 .58046 m
.68657 .58048 L
s
.68812 .58049 m
.69007 .58051 L
s
.64421 .69762 m .64272 .68948 L .64008 .68969 L 0 .608 .424 r
F
0 g
.63952 .6893 m
.64008 .68969 L
s
.64421 .69762 m .65112 .69706 L .64272 .68948 L 0 .608 .424 r
F
.64421 .69762 m .65968 .70739 L .65112 .69706 L F
.64421 .69762 m .66381 .71532 L .65968 .70739 L F
.64421 .69762 m .66075 .71557 L .66381 .71532 L F
0 g
.65775 .71786 m
.66411 .72516 L
s
.65564 .71544 m
.65775 .71786 L
s
.64421 .69762 m .65235 .70798 L .66075 .71557 L 0 .608 .424 r
F
0 g
.64008 .68969 m
.64421 .69762 L
s
.65235 .70798 m
.65564 .71544 L
s
.45504 .80853 m
.45669 .80953 L
s
.45504 .80853 m
.46042 .81219 L
s
.5835 .60714 m .57783 .60287 L .57664 .60571 L 0 1 .521 r
F
.5835 .60714 m .58685 .6002 L .57783 .60287 L F
.5835 .60714 m .59767 .5995 L .58685 .6002 L F
0 g
.67414 .747 m
.68246 .75824 L
s
.67301 .74276 m
.67414 .747 L
s
.67274 .74177 m
.67301 .74276 L
s
.67256 .7411 m
.67274 .74177 L
s
.67247 .74076 m
.67256 .7411 L
s
.67236 .74036 m
.67247 .74076 L
s
.30811 .76069 m .29841 .75918 L .29635 .76141 L 0 1 .414 r
F
0 g
.289 .76483 m
.29635 .76141 L
s
.54707 1.01074 m .54757 1.0131 L .55151 1.02789 L 0 0 .086 r
F
0 g
.54751 1.01297 m
.54757 1.0131 L
s
.65039 .58759 m .64623 .58271 L .64405 .58507 L 0 1 .517 r
F
.65039 .58759 m .65617 .58189 L .64623 .58271 L F
.65039 .58759 m .66722 .58316 L .65617 .58189 L F
0 g
.66722 .58316 m
.67352 .58567 L
s
.66722 .58316 m
.67746 .58253 L
s
.54707 1.01074 m .55473 1.03773 L .55012 1.02126 L 0 0 .086 r
F
0 g
.55148 1.02641 m
.55185 1.0276 L
s
.54707 1.01074 m .55871 1.05265 L .55473 1.03773 L 0 0 .086 r
F
.54707 1.01074 m .55151 1.02789 L .55629 1.04534 L F
0 g
.54707 1.01074 m
.5478 1.01326 L
s
.54681 1.01005 m
.54707 1.01074 L
s
.54821 1.01592 m
.54975 1.0215 L
s
.54933 1.02003 m
.54962 1.02107 L
s
.54855 1.01732 m
.54933 1.02003 L
s
.54664 1.00817 m
.54734 1.0108 L
s
.54757 1.0131 m
.54882 1.01778 L
s
.28054 .65549 m
.28118 .65811 L
s
.73667 .86735 m .7513 .86572 L .75153 .86253 L 0 1 .403 r
F
0 g
.7513 .86572 m
.7569 .86578 L
s
.52854 1.00405 m .52929 1.00202 L .53242 1.01474 L 0 .619 .168 r
F
0 g
.52732 .99104 m
.52929 1.00202 L
s
.34151 .76511 m .33638 .76212 L .33991 .76371 L 0 .026 .164 r
F
.34991 .77576 m .34561 .77323 L .34322 .76465 L 0 .709 .063 r
F
.34991 .77576 m .34322 .76465 L .34446 .76431 L F
.34762 .77043 m .34071 .76533 L .34151 .76511 L 0 .026 .164 r
F
.34071 .76533 m .33638 .76212 L .34151 .76511 L F
.34446 .76431 m .34322 .76465 L .34126 .7576 L 0 .709 .063 r
F
.34991 .77576 m .3497 .78379 L .34561 .77323 L F
.3497 .78379 m .34611 .7746 L .34561 .77323 L F
.34991 .77576 m .35153 .78543 L .34969 .78435 L F
.3497 .78379 m .34969 .78435 L .34611 .7746 L F
.35491 .79181 m .34561 .77335 L .34968 .78464 L 0 .324 .341 r
F
.35509 .79166 m .35495 .79178 L .35491 .79181 L 0 1 .491 r
F
.3552 .79156 m .35543 .79148 L .35509 .79166 L F
.35776 .78938 m .35549 .79143 L .3552 .79156 L F
.35549 .79143 m .35543 .79148 L .3552 .79156 L F
.35776 .78938 m .3559 .79064 L .35554 .79129 L F
.35549 .79143 m .35554 .79129 L .35543 .79148 L F
.35776 .78938 m .35554 .79129 L .35549 .79143 L F
.36611 .77757 m .35538 .78802 L .35887 .78143 L 0 0 0 r
F
.36611 .77757 m .35777 .78924 L .35538 .78802 L F
.36611 .77757 m .36483 .78278 L .35777 .78924 L F
.36483 .78278 m .36447 .78425 L .35816 .78895 L F
.36483 .78278 m .35816 .78895 L .35777 .78924 L F
.35776 .78931 m .36262 .77936 L .35826 .78308 L 0 1 .491 r
F
.35782 .78926 m .36262 .77936 L .35776 .78931 L F
.36611 .77757 m .37175 .78037 L .36447 .78425 L 0 0 0 r
F
.35776 .78938 m .36655 .78001 L .36262 .77936 L 0 1 .491 r
F
.35776 .78938 m .36446 .78431 L .36655 .78001 L F
.35761 .7955 m .36239 .78873 L .35826 .78308 L 0 .324 .341 r
F
.35629 .7882 m .35826 .78308 L .35442 .77784 L F
.35776 .78931 m .35826 .78308 L .35784 .78417 L 0 1 .491 r
F
.35776 .78938 m .35782 .78926 L .35776 .78931 L F
.35776 .78938 m .35785 .78342 L .35629 .7882 L F
.35558 .7904 m .35442 .77784 L .34762 .77043 L 0 .324 .341 r
F
.35572 .79076 m .35566 .79015 L .35558 .7904 L F
.35566 .79015 m .35442 .77784 L .35558 .7904 L F
.35338 .78769 m .34561 .77335 L .35306 .78813 L F
.35338 .78769 m .35306 .78813 L .35491 .79181 L F
.35543 .79148 m .35338 .78769 L .35491 .79181 L F
.35543 .79148 m .34762 .77043 L .34562 .77334 L F
.3559 .79064 m .35572 .79076 L .35543 .79148 L 0 1 .491 r
F
.34895 .812 m .35111 .80147 L .34973 .7978 L 0 1 .246 r
F
.34933 .79806 m .34973 .7978 L .34936 .79682 L F
.34895 .812 m .34973 .7978 L .34933 .79806 L F
.34895 .812 m .34936 .79682 L .34485 .80114 L F
.35543 .79148 m .34486 .80101 L .3458 .80015 L 0 1 .491 r
F
.35543 .79148 m .35497 .79177 L .35509 .79166 L F
.35491 .79181 m .34486 .80101 L .34937 .79653 L F
.35495 .79178 m .34486 .80101 L .35491 .79181 L F
.35543 .79148 m .34692 .79674 L .34487 .80099 L F
.34492 .80095 m .34487 .80099 L .34486 .80101 L F
.35543 .79148 m .34487 .80099 L .34492 .80095 L F
.35591 .79123 m .34762 .77043 L .35543 .79148 L 0 .324 .341 r
F
.35761 .7955 m .34562 .77334 L .34567 .77347 L F
.35572 .79076 m .34692 .79674 L .35543 .79148 L 0 1 .491 r
F
.35572 .79076 m .3542 .78653 L .34692 .79674 L F
.35776 .78938 m .35629 .7882 L .35572 .79076 L F
.35581 .79036 m .35442 .77784 L .35572 .79076 L 0 .324 .341 r
F
.35677 .79084 m .35442 .77784 L .35591 .79123 L F
.35629 .7882 m .3542 .78653 L .35572 .79076 L 0 1 .491 r
F
.35583 .79047 m .35581 .79036 L .35572 .79076 L 0 .324 .341 r
F
.35761 .7955 m .35826 .78308 L .35629 .7882 L F
.35784 .78417 m .35826 .78308 L .35785 .78342 L 0 1 .491 r
F
.35629 .7882 m .35785 .78342 L .3542 .78653 L F
.35591 .79123 m .35583 .79047 L .35572 .79076 L 0 .324 .341 r
F
.35761 .7955 m .35677 .79084 L .35591 .79123 L F
.3551 .79207 m .35543 .79148 L .35491 .79181 L F
.35761 .7955 m .35543 .79148 L .3551 .79207 L F
.35761 .7955 m .35591 .79123 L .35543 .79148 L F
.34567 .77347 m .34562 .77334 L .34561 .77335 L F
0 g
.34768 .76777 m
.34877 .77168 L
s
.32399 .75839 m
.32586 .75695 L
s
.51338 .86908 m
.51447 .87193 L
s
.45623 .95671 m .44884 .9503 L .4467 .94791 L 0 .201 0 r
F
.45623 .95671 m .45315 .95487 L .44884 .9503 L F
.45623 .95671 m .45675 .95857 L .45315 .95487 L F
.45623 .95671 m .45807 .95935 L .45675 .95857 L F
0 g
.45623 .95671 m
.45778 .95693 L
s
.45193 .95215 m
.45623 .95671 L
s
.36244 .87487 m .35296 .86815 L .35278 .87254 L 0 1 .497 r
F
0 g
.34734 .87288 m
.35278 .87254 L
s
.30053 .85903 m .28969 .85581 L .28974 .85926 L 0 1 .525 r
F
0 g
.28395 .8609 m
.28974 .85926 L
s
.73302 .69594 m
.74058 .70895 L
s
.74058 .70895 m
.74089 .70949 L
s
.74209 .71157 m
.74213 .71162 L
s
.73302 .69594 m
.73666 .7122 L
s
.73666 .7122 m
.73671 .71242 L
s
.64338 .53774 m
.65412 .54498 L
s
.74145 .65272 m .75018 .64551 L .74109 .65061 L 0 .845 .188 r
F
0 g
.73944 .65326 m
.74145 .65272 L
s
.73262 .65858 m
.73311 .65826 L
s
.73311 .65826 m
.73365 .6579 L
s
.73365 .6579 m
.73617 .65622 L
s
.73969 .65389 m
.74145 .65272 L
s
.33771 .65367 m .33007 .64847 L .32522 .65307 L 0 1 .54 r
F
0 g
.31914 .6545 m
.32522 .65307 L
s
.33771 .65367 m .33974 .64424 L .33007 .64847 L 0 1 .54 r
F
.33771 .65367 m .34781 .64413 L .33974 .64424 L F
.34781 .64413 m .35189 .64434 L .3491 .64247 L 0 1 .525 r
F
.34862 .64728 m .35189 .64434 L .34781 .64413 L F
.34781 .64413 m .35186 .64538 L .34909 .64292 L 0 1 .54 r
F
.33771 .65367 m .34862 .64728 L .34781 .64413 L F
.34862 .64728 m .35186 .64538 L .34781 .64413 L F
.3376 .6572 m .34862 .64728 L .34781 .64413 L 0 1 .525 r
F
.3376 .6572 m .34781 .64413 L .3397 .64582 L F
.34781 .64413 m .3491 .64247 L .34702 .64321 L F
.34781 .64413 m .34702 .64321 L .33974 .64424 L 0 1 .54 r
F
.34781 .64413 m .34702 .64321 L .3397 .64582 L 0 1 .525 r
F
.34781 .64413 m .34909 .64292 L .34702 .64321 L 0 1 .54 r
F
0 g
.33315 .6579 m
.33771 .65367 L
s
.3284 .65499 m
.33771 .65367 L
s
.2721 .92667 m .26284 .92199 L .26057 .92278 L 0 .511 .24 r
F
.2721 .92667 m .26797 .9227 L .26284 .92199 L F
.2721 .92667 m .27252 .92446 L .26797 .9227 L F
.2721 .92667 m .27429 .92616 L .27252 .92446 L F
0 g
.26699 .92595 m
.2721 .92667 L
s
.2721 .92667 m
.27394 .92817 L
s
.54762 .97793 m
.54777 .97705 L
s
.54787 .97642 m
.54789 .97634 L
s
.80074 .92148 m .81325 .93852 L .81472 .92614 L 0 1 .418 r
F
.80074 .92148 m .80867 .942 L .81325 .93852 L F
0 g
.81325 .93852 m
.8176 .94467 L
s
.26254 .76497 m .2587 .75645 L .25219 .76189 L 0 1 .541 r
F
.26254 .76497 m .26658 .7534 L .2587 .75645 L F
.26254 .76497 m .27055 .7548 L .26658 .7534 L F
.26254 .76497 m .26881 .75977 L .27055 .7548 L F
0 g
.26101 .76962 m
.26254 .76497 L
s
.25469 .76799 m
.26254 .76497 L
s
.69521 .69375 m .71245 .68005 L .7158 .67619 L 0 1 .203 r
F
0 g
.71916 .67309 m
.72224 .67026 L
s
.69521 .69375 m .70365 .68756 L .71245 .68005 L 0 1 .203 r
F
0 g
.71245 .68005 m
.7155 .67738 L
s
.47045 .96975 m
.47115 .97039 L
s
.46729 .96682 m
.47045 .96975 L
s
.55502 .61783 m .54859 .61367 L .54791 .61674 L 0 1 .522 r
F
.55502 .61783 m .5571 .61031 L .54859 .61367 L F
.55502 .61783 m .56776 .6089 L .5571 .61031 L F
.55502 .61783 m .57485 .61 L .56776 .6089 L F
0 g
.57485 .61 m
.5835 .60714 L
s
.54689 .62137 m
.55502 .61783 L
s
.37188 .88214 m .36631 .87225 L .36244 .87487 L 0 .942 .486 r
F
.37188 .88214 m .37193 .87284 L .36631 .87225 L F
.37188 .88214 m .37554 .87626 L .37193 .87284 L F
.37188 .88214 m .37552 .88025 L .37554 .87626 L F
0 g
.36628 .88154 m
.37188 .88214 L
s
.37188 .88214 m
.37205 .8857 L
s
.71909 .64479 m
.72767 .65661 L
s
.72903 .65847 m
.72913 .65861 L
s
.66723 .89314 m
.66726 .8939 L
s
.66719 .89229 m
.66723 .89314 L
s
.66719 .8923 m
.66926 .90463 L
s
.67175 .91952 m
.6722 .92218 L
s
.73333 .80414 m .73577 .77952 L .73171 .78023 L 0 .707 .314 r
F
0 g
.73085 .77806 m
.73171 .78023 L
s
.52013 1.00082 m
.52029 1.00403 L
s
.25219 .76189 m .23995 .76375 L .24416 .76502 L 0 1 .542 r
F
0 g
.24332 .77083 m
.24416 .76502 L
s
.74739 .86054 m .75793 .86232 L .76236 .86007 L 0 1 .446 r
F
.74739 .86054 m .75153 .86253 L .75793 .86232 L F
0 g
.7569 .86578 m
.75793 .86232 L
s
.53027 1.06261 m .53711 1.10224 L .53351 1.08031 L 0 .063 .168 r
F
.53027 1.06261 m .53898 1.11565 L .53711 1.10224 L F
0 g
.53094 1.08858 m
.531 1.08885 L
s
.53027 1.06261 m .53786 1.11151 L .53898 1.11565 L 0 .063 .168 r
F
.53027 1.06261 m .53461 1.09369 L .53786 1.11151 L F
.53027 1.06261 m .53139 1.07413 L .53461 1.09369 L F
0 g
.53041 1.06336 m
.53055 1.06412 L
s
.53027 1.06261 m
.53041 1.06336 L
s
.52985 1.06583 m
.53067 1.07023 L
s
.53123 1.06445 m
.5313 1.06484 L
s
.53114 1.06392 m
.53123 1.06445 L
s
.53101 1.06316 m
.53114 1.06392 L
s
.53097 1.0629 m
.53101 1.06316 L
s
.5306 1.06077 m
.53097 1.0629 L
s
.53022 1.06222 m
.53027 1.06261 L
s
.53137 1.06193 m
.53161 1.0637 L
s
.52974 1.0623 m
.53106 1.07176 L
s
.5316 1.08938 m
.53164 1.08955 L
s
.53164 1.08955 m
.53169 1.08985 L
s
.53151 1.08888 m
.5316 1.08938 L
s
.53076 1.0848 m
.5315 1.08883 L
s
.5315 1.08883 m
.53151 1.08888 L
s
.531 1.08885 m
.53226 1.09419 L
s
.53195 1.06256 m
.53235 1.06483 L
s
.53161 1.0637 m
.53165 1.06398 L
s
.51598 .99934 m
.51642 1.00299 L
s
.51582 1.00556 m
.51598 .99934 L
s
.49489 .98827 m
.49496 .98795 L
s
.30811 .76069 m .30515 .75665 L .29841 .75918 L 0 1 .414 r
F
.30811 .76069 m .31298 .75547 L .30515 .75665 L F
.30811 .76069 m .31665 .75642 L .31298 .75547 L F
.30811 .76069 m .31455 .75866 L .31665 .75642 L F
0 g
.30627 .76212 m
.30811 .76069 L
s
.30032 .76186 m
.30811 .76069 L
s
.49083 .98562 m .48446 .98371 L .48759 .98364 L 0 .506 .074 r
F
0 g
.48759 .98364 m
.48911 .98171 L
s
.49083 .98562 m .4833 .98632 L .48446 .98371 L 0 .506 .074 r
F
.49083 .98562 m .48489 .98973 L .4833 .98632 L F
.49083 .98562 m .48814 .99171 L .48489 .98973 L F
.49083 .98562 m .49087 .99093 L .48814 .99171 L F
.49083 .98562 m .49202 .98832 L .49087 .99093 L F
0 g
.49083 .98562 m
.49228 .9819 L
s
.48759 .98364 m
.49083 .98562 L
s
.49202 .98832 m
.49496 .98795 L
s
.73671 .71242 m
.73696 .71293 L
s
.73696 .71293 m
.73703 .71308 L
s
.73703 .71308 m
.73768 .71445 L
s
.73768 .71445 m
.73788 .71487 L
s
.73888 .71696 m
.73902 .71726 L
s
.68207 .85118 m .69656 .87237 L .69167 .84973 L 0 .677 .311 r
F
.68207 .85118 m .6933 .89338 L .69727 .89111 L F
0 g
.69601 .85341 m
.69643 .85543 L
s
.69601 .85341 m
.69606 .85498 L
s
.69665 .87257 m
.69705 .88473 L
s
.69705 .88473 m
.69726 .89093 L
s
.69726 .89093 m
.69727 .8911 L
s
.68207 .85118 m .68678 .87623 L .6933 .89338 L 0 .677 .311 r
F
0 g
.68737 .896 m
.68819 .89175 L
s
.68819 .89175 m
.68879 .88865 L
s
.68879 .88865 m
.6897 .8839 L
s
.68715 .8892 m
.68734 .89602 L
s
.68138 .83257 m
.68207 .85118 L
s
.68142 .84918 m
.68207 .85118 L
s
.687 .88391 m
.68715 .8892 L
s
.68679 .87624 m
.687 .88391 L
s
.68729 .79906 m .69102 .78457 L .6864 .78504 L 0 .706 .355 r
F
0 g
.67809 .77378 m
.6864 .78504 L
s
.6926 .79433 m .69908 .79698 L .69472 .79027 L 0 .706 .355 r
F
.69041 .79851 m .69073 .79845 L .6926 .79433 L F
.69073 .79845 m .69908 .79698 L .6926 .79433 L F
.69073 .79845 m .70521 .81401 L .69908 .79698 L F
.68729 .79906 m .68958 .80097 L .69073 .79845 L F
.68958 .80097 m .70521 .81401 L .69073 .79845 L F
.68729 .79906 m .7061 .82807 L .70521 .81401 L F
.68729 .79906 m .70115 .82976 L .7061 .82807 L F
.68729 .79906 m .69309 .81732 L .70115 .82976 L F
.69918 .78012 m .69727 .78232 L .7008 .77389 L 0 0 .052 r
F
.69918 .78012 m .6973 .78351 L .69761 .78344 L 0 .716 .392 r
F
.69918 .78012 m .69761 .78344 L .70106 .78258 L F
.69924 .77987 m .69934 .77965 L .69933 .77979 L 0 0 .052 r
F
.69918 .78012 m .70106 .78258 L .7001 .77829 L 0 .716 .392 r
F
.69908 .79698 m .70106 .78258 L .69761 .78344 L 0 .795 .372 r
F
.69736 .78398 m .69761 .78344 L .6973 .78351 L F
.69908 .79698 m .69761 .78344 L .69736 .78398 L F
.69936 .77942 m .70022 .77753 L .70016 .77787 L 0 0 .052 r
F
.69934 .77965 m .70016 .77787 L .69892 .78568 L F
.69936 .77942 m .70016 .77787 L .69934 .77965 L F
.69924 .78 m .69933 .77979 L .69892 .78568 L F
.69924 .77987 m .69933 .77979 L .69924 .78 L F
.69708 .78313 m .6973 .78351 L .69918 .78012 L 0 .716 .392 r
F
.68246 .75824 m .68933 .77308 L .69704 .78318 L F
.69708 .78313 m .69704 .78318 L .6973 .78351 L F
.68246 .75824 m .69704 .78318 L .69708 .78313 L F
.6846 .8362 m .69035 .80889 L .69704 .78318 L 0 0 .052 r
F
.69708 .78313 m .69704 .78318 L .69727 .78232 L F
.6846 .8362 m .69704 .78318 L .69708 .78313 L F
.6846 .8362 m .69708 .78313 L .69918 .78012 L F
.69708 .78313 m .69727 .78232 L .69918 .78012 L F
.68246 .75824 m .69708 .78313 L .69918 .78012 L 0 .716 .392 r
F
.68246 .75824 m .69918 .78012 L .69848 .77111 L F
.69918 .78012 m .69924 .77987 L .69924 .78 L 0 0 .052 r
F
.69924 .77987 m .69936 .77942 L .69934 .77965 L F
.69936 .77942 m .7008 .77389 L .70022 .77753 L F
.69918 .78012 m .7001 .77829 L .69848 .77111 L 0 .716 .392 r
F
.6901 .81678 m .69918 .78012 L .69892 .78568 L 0 0 .052 r
F
.68898 .81936 m .69918 .78012 L .6901 .81678 L F
.69908 .79698 m .70868 .79403 L .70106 .78258 L 0 .795 .372 r
F
.70703 .76781 m .70488 .77085 L .70758 .76616 L 0 0 .045 r
F
.71151 .76156 m .71864 .73943 L .71158 .76146 L 0 0 .036 r
F
.70954 .76468 m .70998 .76515 L .71158 .76146 L 0 .861 .416 r
F
.70998 .76515 m .71987 .77604 L .71186 .76194 L F
.70998 .76515 m .71186 .76194 L .71158 .76146 L F
.71158 .76146 m .71987 .77604 L .71681 .76472 L F
.71158 .76146 m .71681 .76472 L .71337 .75876 L F
.7129 .75943 m .71337 .75876 L .71335 .75872 L F
.71158 .76146 m .71337 .75876 L .7129 .75943 L F
.71585 .75511 m .72767 .72574 L .7159 .75503 L 0 0 .025 r
F
.71461 .75691 m .71473 .75703 L .7159 .75503 L 0 .922 .426 r
F
.71473 .75703 m .72929 .77192 L .7159 .75503 L F
.7159 .75503 m .72929 .77192 L .726 .7607 L F
.72001 .74855 m .73676 .71368 L .73396 .72191 L 0 0 .011 r
F
.72001 .74855 m .73872 .76744 L .7352 .75631 L 0 .976 .436 r
F
.71999 .74858 m .73676 .71368 L .72 .74857 L 0 0 .011 r
F
.71959 .74911 m .71963 .74915 L .72001 .74855 L 0 .976 .436 r
F
.71963 .74915 m .73872 .76744 L .72001 .74855 L F
.72215 .74522 m .73396 .72191 L .72652 .73767 L 0 0 .011 r
F
.71959 .74911 m .73495 .76927 L .73872 .76744 L 0 .976 .436 r
F
.71938 .7494 m .73495 .76927 L .71959 .74911 L F
.72199 .74549 m .72001 .74855 L .72252 .74525 L F
.72199 .74549 m .72001 .74855 L .72215 .74522 L 0 0 .011 r
F
.72001 .74855 m .73396 .72191 L .72215 .74522 L F
.71959 .74911 m .73676 .71368 L .72002 .74852 L F
.72001 .74855 m .73676 .71368 L .72001 .74855 L F
.7159 .75503 m .72511 .73484 L .71923 .74935 L 0 0 .025 r
F
.71461 .75691 m .72767 .72574 L .71585 .75512 L F
.7159 .75503 m .72767 .72574 L .72511 .73484 L F
.71494 .75612 m .72405 .73098 L .72767 .72574 L F
.70976 .76491 m .7161 .77756 L .71987 .77604 L 0 .861 .416 r
F
.70971 .76501 m .7161 .77756 L .70976 .76491 L F
.70924 .76503 m .7161 .77756 L .70954 .76468 L F
.70828 .76617 m .71505 .74545 L .70954 .76468 L 0 0 .036 r
F
.70488 .77085 m .70968 .75525 L .70772 .76543 L 0 0 .045 r
F
.70828 .76617 m .70758 .76616 L .71505 .74545 L 0 0 .036 r
F
.70715 .76453 m .70828 .76617 L .70829 .7633 L 0 .861 .416 r
F
.70828 .76617 m .7161 .77756 L .70924 .76503 L F
.70828 .76617 m .70924 .76503 L .70829 .7633 L F
.70746 .76812 m .71046 .77966 L .70764 .76825 L 0 .793 .405 r
F
.70703 .76781 m .70722 .76849 L .70746 .76812 L F
.70722 .76849 m .71046 .77966 L .70746 .76812 L F
.7044 .77242 m .70471 .77279 L .70703 .76781 L F
.70471 .77279 m .71046 .77966 L .70703 .76781 L F
.7044 .77242 m .7067 .78093 L .71046 .77966 L F
.70268 .77463 m .70612 .76229 L .7044 .77242 L 0 0 .045 r
F
.69283 .81006 m .69892 .78568 L .70208 .77541 L F
.70268 .77463 m .70208 .77541 L .70612 .76229 L F
.70268 .77463 m .70208 .77541 L .7067 .78093 L 0 .793 .405 r
F
.69283 .81006 m .70208 .77541 L .70268 .77463 L 0 0 .045 r
F
.69129 .75675 m .69848 .77111 L .70208 .77541 L 0 .793 .405 r
F
.69129 .75675 m .70208 .77541 L .70268 .77463 L F
.69129 .75675 m .70268 .77463 L .7044 .77242 L F
.70268 .77463 m .7067 .78093 L .7044 .77242 L F
.7044 .77242 m .70612 .76229 L .70968 .75525 L 0 0 .045 r
F
.69283 .81006 m .70268 .77463 L .7044 .77242 L F
.69283 .81006 m .70703 .76781 L .70115 .78798 L F
.70703 .76781 m .70758 .76616 L .70721 .76741 L F
.70703 .76781 m .70723 .76747 L .7072 .76743 L 0 .793 .405 r
F
.70703 .76781 m .70721 .76741 L .7072 .76743 L 0 0 .045 r
F
.70488 .77085 m .70772 .76543 L .70758 .76616 L F
.70703 .76781 m .7072 .76743 L .70013 .75431 L 0 .793 .405 r
F
.70703 .76781 m .7072 .76743 L .70115 .78798 L 0 0 .045 r
F
.70703 .76781 m .70764 .76825 L .70723 .76747 L 0 .793 .405 r
F
.7072 .76743 m .70758 .76616 L .70828 .76617 L 0 0 .036 r
F
.70715 .76453 m .70764 .76825 L .7161 .77756 L 0 .861 .416 r
F
.70013 .75431 m .7062 .76556 L .70715 .76453 L F
.7062 .76556 m .70764 .76825 L .70715 .76453 L F
.71412 .757 m .71631 .74944 L .72405 .73098 L 0 0 .025 r
F
.71158 .76146 m .71335 .75872 L .71319 .75845 L 0 .861 .416 r
F
.71175 .76103 m .71631 .74944 L .71344 .75774 L 0 0 .036 r
F
.71175 .76103 m .71344 .75774 L .71319 .75845 L F
.71161 .76153 m .71319 .75845 L .70954 .76899 L F
.71175 .76103 m .71319 .75845 L .71161 .76153 L F
.71461 .75691 m .71412 .757 L .71494 .75612 L 0 0 .025 r
F
.71383 .75775 m .71681 .76472 L .72552 .77362 L 0 .922 .426 r
F
.71379 .7578 m .71681 .76472 L .71383 .75775 L F
.71319 .75845 m .71681 .76472 L .71379 .7578 L F
.71319 .75845 m .71344 .75774 L .71374 .75785 L 0 0 .025 r
F
.71319 .75845 m .71379 .7578 L .71367 .75752 L 0 .922 .426 r
F
.71319 .75845 m .71374 .75785 L .71379 .75787 L 0 0 .025 r
F
.71383 .75775 m .71412 .757 L .71461 .75691 L F
.71461 .75691 m .72552 .77362 L .72929 .77192 L 0 .922 .426 r
F
.71383 .75775 m .71344 .75774 L .71412 .757 L 0 0 .025 r
F
.71344 .75774 m .71631 .74944 L .71412 .757 L F
.70954 .76468 m .71505 .74545 L .71864 .73943 L 0 0 .036 r
F
.71412 .757 m .72405 .73098 L .71494 .75612 L 0 0 .025 r
F
.70954 .76468 m .71864 .73943 L .71151 .76157 L 0 0 .036 r
F
.71158 .76146 m .71864 .73943 L .71631 .74944 L F
.70897 .75115 m .71383 .75775 L .71461 .75691 L 0 .922 .426 r
F
.71383 .75775 m .72552 .77362 L .71461 .75691 L F
.71379 .75787 m .71374 .75785 L .71383 .75775 L 0 0 .025 r
F
.71374 .75785 m .71344 .75774 L .71383 .75775 L F
.70954 .76899 m .71383 .75775 L .71461 .75691 L F
.71367 .75752 m .71379 .7578 L .71383 .75775 L 0 .922 .426 r
F
.70897 .75115 m .71319 .75845 L .71367 .75752 L F
.71129 .7603 m .71319 .75845 L .70897 .75115 L 0 .861 .416 r
F
.71158 .76146 m .71319 .75845 L .71129 .7603 L F
.70954 .76899 m .71319 .75845 L .71379 .75787 L 0 0 .025 r
F
.70115 .78798 m .7072 .76743 L .70828 .76617 L 0 0 .036 r
F
.70115 .78798 m .71175 .76103 L .70954 .76899 L F
.70954 .76468 m .70971 .76501 L .70976 .76491 L 0 .861 .416 r
F
.70829 .7633 m .70924 .76503 L .70954 .76468 L F
.70115 .78798 m .70828 .76617 L .70954 .76468 L 0 0 .036 r
F
.70013 .75431 m .70715 .76453 L .70829 .7633 L 0 .861 .416 r
F
.71959 .74911 m .73312 .71832 L .73676 .71368 L 0 0 .011 r
F
.71935 .74936 m .71938 .7494 L .71959 .74911 L 0 .976 .436 r
F
.7159 .75503 m .71943 .75003 L .7192 .74965 L 0 .922 .426 r
F
.71692 .75332 m .7159 .75503 L .7192 .74944 L 0 0 .025 r
F
.7159 .75503 m .71923 .74935 L .7192 .74944 L F
.71935 .74936 m .72511 .73484 L .73312 .71832 L 0 0 .011 r
F
.71915 .74956 m .726 .7607 L .7193 .7493 L 0 .976 .436 r
F
.718 .75239 m .71915 .74956 L .71935 .74936 L 0 0 .011 r
F
.71915 .74956 m .72511 .73484 L .71935 .74936 L F
.71935 .74936 m .726 .7607 L .73495 .76927 L 0 .976 .436 r
F
.7193 .7493 m .71934 .74937 L .71935 .74936 L F
.71934 .74937 m .726 .7607 L .71935 .74936 L F
.71783 .74743 m .71915 .74956 L .7193 .7493 L F
.71587 .75511 m .7192 .74944 L .71915 .74956 L 0 0 .025 r
F
.71873 .75026 m .7192 .74965 L .71915 .74956 L 0 .922 .426 r
F
.71623 .75465 m .71915 .74956 L .718 .75239 L 0 0 .025 r
F
.7159 .75503 m .7192 .74965 L .71873 .75026 L 0 .922 .426 r
F
.71587 .75511 m .71915 .74956 L .71623 .75465 L 0 0 .025 r
F
.718 .75239 m .71935 .74936 L .71959 .74911 L 0 0 .011 r
F
.71935 .74936 m .73312 .71832 L .71959 .74911 L F
.71783 .74743 m .71935 .74936 L .71959 .74911 L 0 .976 .436 r
F
.71783 .74743 m .72001 .74855 L .72199 .74549 L F
.72001 .74855 m .7352 .75631 L .72252 .74525 L F
.718 .75239 m .72001 .74855 L .72199 .74549 L 0 0 .011 r
F
.71956 .74918 m .71959 .74911 L .71995 .74866 L F
.71959 .74911 m .72002 .74852 L .71995 .74866 L F
.71783 .74743 m .71959 .74911 L .72001 .74855 L 0 .976 .436 r
F
.72 .74857 m .72001 .74855 L .72001 .74855 L 0 0 .011 r
F
.72252 .74525 m .7352 .75631 L .72671 .74329 L 0 .976 .436 r
F
.7159 .75503 m .726 .7607 L .71943 .75003 L 0 .922 .426 r
F
.718 .75239 m .72199 .74549 L .71841 .75442 L 0 0 .011 r
F
.72199 .74549 m .72652 .73767 L .72472 .74138 L F
.72199 .74549 m .72252 .74525 L .72237 .74492 L 0 .976 .436 r
F
.72252 .74525 m .72671 .74329 L .72514 .74179 L F
.72252 .74525 m .72514 .74179 L .72468 .74135 L F
.72239 .74494 m .72468 .74135 L .71775 .73471 L F
.72252 .74525 m .72468 .74135 L .72239 .74494 L F
.72557 .73995 m .7264 .7305 L .72294 .73223 L 0 1 .444 r
F
.72671 .74329 m .72659 .73836 L .72557 .73995 L F
.72558 .73992 m .72559 .73992 L .72557 .73995 L 0 0 0 r
F
.72652 .73767 m .72659 .73835 L .72558 .73992 L F
.72652 .73767 m .74286 .71028 L .73509 .72443 L F
.72671 .74329 m .73561 .73882 L .72993 .73369 L 0 1 .444 r
F
.72652 .73767 m .73509 .72443 L .72993 .73369 L 0 0 0 r
F
.72652 .73767 m .72993 .73369 L .72973 .73397 L F
.72652 .73767 m .72985 .73383 L .72659 .73836 L F
.72659 .73836 m .72993 .73369 L .7264 .7305 L 0 1 .444 r
F
.72671 .74329 m .72993 .73369 L .72659 .73836 L F
.72973 .73397 m .72993 .73369 L .72985 .73383 L 0 0 0 r
F
.72659 .73836 m .72985 .73383 L .72671 .73947 L F
.72659 .73836 m .7264 .7305 L .72559 .73975 L 0 1 .444 r
F
.72659 .73836 m .72559 .73975 L .72557 .73995 L F
.72557 .73995 m .72671 .73947 L .72338 .74525 L 0 0 0 r
F
.72559 .73992 m .72671 .73947 L .72557 .73995 L F
.72659 .73835 m .72671 .73947 L .72558 .73992 L F
.72199 .74549 m .72472 .74138 L .71841 .75442 L 0 0 .011 r
F
.71783 .74743 m .72199 .74549 L .71775 .73471 L 0 .976 .436 r
F
.72199 .74549 m .72237 .74492 L .71775 .73471 L F
.71995 .74866 m .71999 .74858 L .72 .74857 L 0 0 .011 r
F
.718 .75239 m .71956 .74918 L .71995 .74866 L F
.7159 .75503 m .71915 .74956 L .71783 .74743 L 0 .922 .426 r
F
.71587 .75511 m .7159 .75503 L .71692 .75332 L 0 0 .025 r
F
.71449 .75718 m .71461 .75691 L .7157 .75548 L F
.71461 .75691 m .71585 .75512 L .7157 .75548 L F
.70897 .75115 m .71461 .75691 L .7159 .75503 L 0 .922 .426 r
F
.70897 .75115 m .7159 .75503 L .71783 .74743 L F
.7157 .75548 m .71585 .75511 L .7159 .75503 L 0 0 .025 r
F
.70954 .76899 m .71449 .75718 L .7157 .75548 L F
.70954 .76899 m .71587 .75511 L .718 .75239 L F
.70941 .76506 m .70954 .76468 L .71139 .76195 L 0 0 .036 r
F
.70954 .76468 m .71151 .76157 L .71139 .76195 L F
.70013 .75431 m .70954 .76468 L .71158 .76146 L 0 .861 .416 r
F
.70013 .75431 m .71158 .76146 L .70897 .75115 L F
.71139 .76195 m .71151 .76156 L .71158 .76146 L 0 0 .036 r
F
.70115 .78798 m .70941 .76506 L .71139 .76195 L F
.7044 .77242 m .70449 .77214 L .70703 .76781 L 0 0 .045 r
F
.70449 .77214 m .70488 .77085 L .70703 .76781 L F
.69129 .75675 m .7044 .77242 L .70703 .76781 L 0 .793 .405 r
F
.69283 .81006 m .7044 .77242 L .70703 .76781 L 0 0 .045 r
F
.69129 .75675 m .70703 .76781 L .70013 .75431 L 0 .793 .405 r
F
.69256 .81091 m .69892 .78568 L .69283 .81006 L 0 0 .052 r
F
.6846 .8362 m .6901 .81678 L .69256 .81091 L F
.6901 .81678 m .69892 .78568 L .69256 .81091 L F
.70765 .77565 m .71016 .77111 L .70688 .77836 L 0 0 .025 r
F
.70954 .76899 m .71007 .7708 L .70765 .77565 L F
.71007 .7708 m .71016 .77111 L .70765 .77565 L F
.71586 .75864 m .71841 .75442 L .7151 .76085 L 0 0 .011 r
F
.718 .75239 m .71835 .75415 L .71586 .75864 L F
.71835 .75415 m .71841 .75442 L .71586 .75864 L F
.72492 .74233 m .72338 .74525 L .72671 .73947 L 0 .857 .124 r
F
.70954 .76899 m .718 .75239 L .71016 .77111 L 0 0 .025 r
F
.70575 .77299 m .7227 .74632 L .72492 .74233 L 0 .857 .124 r
F
.7227 .74632 m .72338 .74525 L .72492 .74233 L F
.71653 .75783 m .7151 .76085 L .71841 .75442 L 0 .834 .111 r
F
.70115 .78798 m .70954 .76899 L .70571 .77962 L 0 0 .036 r
F
.70133 .78842 m .70571 .77962 L .70197 .79001 L F
.70115 .78798 m .70571 .77962 L .70133 .78842 L F
.69813 .79138 m .70644 .77664 L .71481 .76138 L 0 .834 .111 r
F
.71484 .76131 m .71481 .76138 L .7151 .76085 L F
.69813 .79138 m .71481 .76138 L .71484 .76131 L F
.69813 .79138 m .71439 .76213 L .71653 .75783 L F
.71439 .76213 m .7151 .76085 L .71653 .75783 L F
.70193 .78851 m .70688 .77836 L .70734 .77733 L 0 .815 .1 r
F
.69908 .79698 m .71508 .81024 L .70868 .79403 L 0 .795 .372 r
F
.69908 .79698 m .71686 .82373 L .71508 .81024 L F
.69908 .79698 m .71283 .82549 L .71686 .82373 L F
.69908 .79698 m .70521 .81401 L .71283 .82549 L F
.6995 .79496 m .70197 .79001 L .69872 .79829 L 0 0 .036 r
F
.70115 .78798 m .70183 .78966 L .6995 .79496 L F
.70183 .78966 m .70197 .79001 L .6995 .79496 L F
.70819 .77522 m .70734 .77733 L .70905 .77343 L 0 .815 .1 r
F
.69283 .81006 m .70115 .78798 L .69775 .79904 L 0 0 .045 r
F
.69289 .81014 m .69775 .79904 L .69386 .81171 L F
.69283 .81006 m .69775 .79904 L .69289 .81014 L F
.69056 .81199 m .70644 .7792 L .70693 .77808 L 0 .815 .1 r
F
.70813 .77535 m .70693 .77808 L .70819 .77522 L F
.69056 .81199 m .70693 .77808 L .70813 .77535 L F
.70644 .7792 m .70734 .77733 L .70819 .77522 L F
.69056 .81199 m .70179 .78885 L .70193 .78851 L F
.70179 .78885 m .70688 .77836 L .70193 .78851 L F
.70905 .77343 m .70734 .77733 L .71016 .77111 L F
.6846 .8362 m .68898 .81936 L .6901 .81678 L 0 0 .052 r
F
.69918 .78012 m .69924 .78 L .69892 .78568 L F
.68729 .79906 m .69041 .79851 L .69102 .78457 L 0 .706 .355 r
F
.69041 .79851 m .69472 .79027 L .69102 .78457 L F
0 g
.6864 .78504 m
.68721 .79779 L
s
.68721 .79779 m
.68729 .79906 L
s
.68384 .81828 m
.68482 .82024 L
s
.68482 .82024 m
.68703 .82466 L
s
.68777 .82613 m
.68896 .82852 L
s
.39643 .78178 m .38932 .7804 L .38666 .78023 L 0 .512 .232 r
F
0 g
.38002 .77851 m
.38666 .78023 L
s
.39643 .78178 m .39585 .78096 L .38932 .7804 L 0 .512 .232 r
F
.39643 .78178 m .4027 .78219 L .39585 .78096 L F
.39643 .78178 m .40528 .78328 L .4027 .78219 L F
.39643 .78178 m .40258 .7831 L .40528 .78328 L F
.39826 .63763 m .38683 .63794 L .38917 .63942 L 0 1 .512 r
F
0 g
.38399 .64451 m
.38917 .63942 L
s
.39826 .63763 m .39276 .63389 L .38683 .63794 L 0 1 .512 r
F
.39826 .63763 m .40302 .62997 L .39276 .63389 L F
.39826 .63763 m .41213 .62817 L .40302 .62997 L F
.39826 .63763 m .41401 .6297 L .41213 .62817 L F
.39826 .63763 m .40806 .63375 L .41401 .6297 L F
0 g
.39268 .64149 m
.39826 .63763 L
s
.38917 .63942 m
.39826 .63763 L
s
.81209 .91309 m .82614 .9183 L .82346 .90538 L 0 1 .429 r
F
0 g
.82471 .93035 m
.82614 .9183 L
s
.82614 .9183 m
.83159 .9258 L
s
.55632 .97767 m
.55649 .97439 L
s
.55295 1.16103 m .55031 1.15218 L .55008 1.14701 L 0 .632 .058 r
F
0 g
.54626 1.13955 m
.55008 1.14701 L
s
.26057 .92278 m .25139 .91787 L .24904 .91896 L 0 .539 .248 r
F
.26057 .92278 m .25658 .91835 L .25139 .91787 L F
.26057 .92278 m .26114 .92009 L .25658 .91835 L F
.26057 .92278 m .26284 .92199 L .26114 .92009 L F
0 g
.2554 .9223 m
.26057 .92278 L
s
.26057 .92278 m
.26236 .92448 L
s
.72632 .73054 m
.72767 .72574 L
s
.7127 .74431 m
.71614 .73185 L
s
.71105 .75027 m
.7127 .74431 L
s
.7287 .72306 m
.73023 .71906 L
s
.72767 .72574 m
.7287 .72306 L
s
.71538 .74179 m
.71632 .73117 L
s
.71505 .74545 m
.71538 .74179 L
s
.72153 .73059 m
.72322 .72542 L
s
.71971 .73616 m
.72153 .73059 L
s
.7196 .73649 m
.71971 .73616 L
s
.7244 .72807 m
.72494 .72346 L
s
.72405 .73098 m
.7244 .72807 L
s
.51809 1.00052 m
.51815 1.00514 L
s
.71701 .74778 m
.71782 .74583 L
s
.72113 .73795 m
.72251 .73466 L
s
.72251 .73466 m
.7232 .73301 L
s
.72368 .73186 m
.72405 .73098 L
s
.55295 1.16103 m .55642 1.15726 L .5595 1.16648 L 0 .632 .058 r
F
0 g
.55239 1.14893 m
.55642 1.15726 L
s
.55584 1.15043 m
.55642 1.15726 L
s
.74739 .86054 m .76236 .86007 L .76245 .85645 L 0 1 .446 r
F
0 g
.76236 .86007 m
.76805 .86052 L
s
.64864 .79844 m .65488 .78646 L .66177 .77123 L 0 1 .138 r
F
0 g
.66164 .77152 m
.66177 .77123 L
s
.66136 .77213 m
.66164 .77152 L
s
.66072 .77354 m
.66136 .77213 L
s
.65861 .78092 m
.65909 .77937 L
s
.66143 .55414 m .65656 .54539 L .65431 .54511 L 0 .411 .369 r
F
0 g
.65412 .54498 m
.65431 .54511 L
s
.66143 .55414 m .66739 .55482 L .65656 .54539 L 0 .411 .369 r
F
.66143 .55414 m .6796 .56711 L .66739 .55482 L F
0 g
.65431 .54511 m
.66143 .55414 L
s
.65214 .54553 m
.66143 .55414 L
s
.67317 .56646 m
.6779 .57259 L
s
.43717 .93823 m .42851 .92983 L .43241 .93377 L 0 .129 .187 r
F
0 g
.43241 .93377 m
.43376 .93554 L
s
.72696 .73102 m
.73168 .72129 L
s
.73168 .72129 m
.73312 .71832 L
s
.73676 .71368 m
.73703 .71308 L
s
.73312 .71832 m
.73345 .71614 L
s
.77395 1.014 m .78198 .99827 L .77743 1.00328 L 0 1 .38 r
F
.77195 .98627 m .78198 .99827 L .78451 .9857 L 0 1 .383 r
F
.77195 .98627 m .77743 1.00328 L .78198 .99827 L F
0 g
.78198 .99827 m
.78532 1.00164 L
s
.2131 .84484 m .20607 .83638 L .20181 .84135 L 0 1 .522 r
F
0 g
.20181 .84135 m
.20205 .84604 L
s
.2131 .84484 m .21259 .83383 L .20607 .83638 L 0 1 .522 r
F
.2131 .84484 m .21702 .83543 L .21259 .83383 L F
.2131 .84484 m .21723 .84015 L .21702 .83543 L F
0 g
.20661 .84735 m
.2131 .84484 L
s
.2131 .84484 m
.21344 .8493 L
s
.34126 .7576 m
.34322 .76465 L
s
.34322 .76465 m
.34393 .76722 L
s
.3441 .76783 m
.34561 .77323 L
s
.3399 .7637 m
.34125 .75761 L
s
.71666 .74792 m
.71781 .74302 L
s
.7008 .77389 m
.7008 .77388 L
s
.70577 .75229 m
.70717 .74622 L
s
.7068 .75192 m
.70717 .74622 L
s
.35296 .86815 m .3431 .86691 L .34697 .86907 L 0 1 .508 r
F
0 g
.34697 .86907 m
.34734 .87288 L
s
.66411 .72516 m .66381 .71532 L .66075 .71557 L 0 .654 .412 r
F
0 g
.65235 .70798 m
.66075 .71557 L
s
.66411 .72516 m .67204 .72439 L .66381 .71532 L 0 .654 .412 r
F
0 g
.66075 .71557 m
.66411 .72516 L
s
.35905 .78133 m
.36242 .77954 L
s
.35887 .78143 m
.35905 .78133 L
s
.35887 .78134 m
.36017 .77493 L
s
.36611 .77757 m .37475 .78019 L .37175 .78037 L 0 0 0 r
F
.36611 .77757 m .37232 .77899 L .37475 .78019 L F
0 g
.36271 .77938 m
.36611 .77757 L
s
.36397 .77607 m
.36611 .77757 L
s
.49671 .64156 m
.50381 .63652 L
s
.48902 .64044 m
.49671 .64156 L
s
.80074 .92148 m .80332 .93471 L .80867 .942 L 0 1 .418 r
F
0 g
.80615 .95338 m
.80867 .942 L
s
.45209 .62654 m .4421 .62525 L .44349 .62662 L 0 1 .448 r
F
0 g
.43719 .62962 m
.44349 .62662 L
s
.45209 .62654 m .44901 .62311 L .4421 .62525 L 0 1 .448 r
F
.45209 .62654 m .45962 .62163 L .44901 .62311 L F
.45209 .62654 m .46823 .62155 L .45962 .62163 L F
.45209 .62654 m .46911 .62292 L .46823 .62155 L F
.45209 .62654 m .46219 .62505 L .46911 .62292 L F
0 g
.44556 .62855 m
.45209 .62654 L
s
.44349 .62662 m
.45209 .62654 L
s
.46219 .62505 m
.47042 .62482 L
s
.73396 .72191 m
.73676 .71368 L
s
.29867 .66343 m .28563 .66454 L .28917 .66681 L 0 1 .528 r
F
.4314 .65839 m .4212 .65486 L .42303 .65825 L 0 1 .512 r
F
.4314 .65839 m .42717 .6499 L .4212 .65486 L F
0 g
.42246 .65879 m
.42303 .65825 L
s
.41773 .66322 m
.42246 .65879 L
s
.4314 .65839 m .43697 .64669 L .42717 .6499 L 0 1 .512 r
F
.4314 .65839 m .44535 .64683 L .43697 .64669 L F
.4314 .65839 m .44671 .65024 L .44535 .64683 L F
.4314 .65839 m .44073 .65519 L .44671 .65024 L F
0 g
.42303 .65825 m
.4314 .65839 L
s
.69521 .69375 m .7158 .67619 L .71174 .67731 L 0 1 .203 r
F
0 g
.71022 .68196 m
.71245 .68005 L
s
.6956 .69877 m
.7017 .69274 L
s
.7158 .67619 m
.71916 .67309 L
s
.44897 .65606 m
.45495 .65054 L
s
.44073 .6552 m
.44897 .65606 L
s
.7228 1.1126 m .73311 1.0952 L .73162 1.09959 L 0 0 0 r
F
.24904 .91896 m .23994 .91376 L .2375 .91516 L 0 .563 .265 r
F
.24904 .91896 m .24519 .91401 L .23994 .91376 L F
.24904 .91896 m .24975 .91574 L .24519 .91401 L F
.24904 .91896 m .25139 .91787 L .24975 .91574 L F
0 g
.24381 .9187 m
.24904 .91896 L
s
.24904 .91896 m
.25076 .92085 L
s
.7793 .83264 m .79448 .82095 L .7901 .82715 L 0 0 .001 r
F
0 g
.79448 .82095 m
.80059 .81576 L
s
.7944 .81728 m
.79448 .82095 L
s
.3376 .6572 m .32506 .65844 L .32823 .66053 L 0 1 .525 r
F
0 g
.32422 .66767 m
.32823 .66053 L
s
.50381 .63652 m .5137 .63405 L .52124 .62975 L 0 1 .518 r
F
.76261 1.02825 m .77395 1.014 L .7706 1.01138 L 0 1 .353 r
F
.52854 1.00405 m .5333 1.04093 L .53024 1.02067 L 0 .619 .168 r
F
.52854 1.00405 m .53646 1.05386 L .5333 1.04093 L F
.52854 1.00405 m .5376 1.0507 L .53646 1.05386 L F
0 g
.53206 1.05199 m
.5322 1.05292 L
s
.5322 1.05292 m
.53241 1.05432 L
s
.53242 1.05357 m
.53272 1.05517 L
s
.5321 1.05182 m
.53242 1.05357 L
s
.52854 1.00405 m .53585 1.03388 L .5376 1.0507 L 0 .619 .168 r
F
0 g
.53656 1.03998 m
.53678 1.04117 L
s
.53678 1.04117 m
.53684 1.0415 L
s
.53684 1.0415 m
.53693 1.04198 L
s
.53693 1.04198 m
.53723 1.04354 L
s
.53723 1.04354 m
.53724 1.0436 L
s
.53177 1.05003 m
.5321 1.05182 L
s
.53177 1.05003 m
.53206 1.05199 L
s
.53075 1.05002 m
.53207 1.05912 L
s
.5364 1.03913 m
.53656 1.03998 L
s
.52854 1.00405 m .53242 1.01474 L .53585 1.03388 L 0 .619 .168 r
F
0 g
.53345 1.00068 m
.53437 1.00651 L
s
.52827 1.00323 m
.52854 1.00405 L
s
.53037 .99851 m
.53171 1.0091 L
s
.53237 1.00012 m
.53437 1.00651 L
s
.52929 1.00202 m
.5299 1.0045 L
s
.43717 .93823 m .42764 .92804 L .42851 .92983 L 0 .129 .187 r
F
0 g
.4238 .92604 m
.42851 .92983 L
s
.61811 .59254 m .64079 .58861 L .63398 .58658 L 0 1 .521 r
F
0 g
.64079 .58861 m
.65039 .58759 L
s
.28969 .85581 m .27876 .85593 L .28316 .85726 L 0 1 .514 r
F
0 g
.28316 .85726 m
.28395 .8609 L
s
.75813 .85388 m .76899 .85672 L .77342 .8545 L 0 1 .474 r
F
.75813 .85388 m .76245 .85645 L .76899 .85672 L F
0 g
.76805 .86052 m
.76899 .85672 L
s
.71371 .74916 m
.71436 .74735 L
s
.71436 .74735 m
.71505 .74545 L
s
.53577 1.05353 m
.53594 1.05451 L
s
.5353 1.05071 m
.53577 1.05353 L
s
.27822 .66651 m .26982 .66423 L .27346 .66643 L 0 1 .528 r
F
.27822 .66651 m .26919 .661 L .26982 .66423 L F
0 g
.2724 .6686 m
.27309 .66719 L
s
.27822 .66651 m .27201 .65889 L .26919 .661 L 0 1 .528 r
F
0 g
.26931 .66442 m
.26982 .66423 L
s
.2609 .66763 m
.26931 .66442 L
s
.26937 .65657 m
.27002 .6592 L
s
.27822 .66651 m .27678 .65897 L .27201 .65889 L 0 1 .528 r
F
0 g
.27309 .66719 m
.27346 .66643 L
s
.27822 .66651 m .28032 .66118 L .27678 .65897 L 0 1 .528 r
F
.27822 .66651 m .28094 .66441 L .28032 .66118 L F
0 g
.27822 .66651 m
.27891 .6698 L
s
.27346 .66643 m
.27822 .66651 L
s
.47957 .97841 m .47237 .97269 L .47587 .97465 L 0 .401 .039 r
F
0 g
.53106 .89702 m
.53199 .90101 L
s
.53084 .89605 m
.53106 .89702 L
s
.67963 1.14502 m .68907 1.14009 L .6851 1.14628 L 0 .21 .093 r
F
.6867 1.16473 m .68907 1.14009 L .69408 1.13949 L 0 .149 .095 r
F
.6867 1.16473 m .6851 1.14628 L .68907 1.14009 L F
0 g
.68907 1.14009 m
.68943 1.13103 L
s
.68907 1.14009 m
.69061 1.1399 L
s
.53301 1.09434 m .5325 1.09523 L .53486 1.10666 L 0 0 .11 r
F
.53301 1.09434 m .53171 1.08995 L .5325 1.09523 L F
0 g
.53226 1.09419 m
.5325 1.09523 L
s
.5324 1.09451 m
.5325 1.09523 L
s
.53233 1.09409 m
.5324 1.09451 L
s
.53219 1.09316 m
.53233 1.09409 L
s
.53192 1.09136 m
.53219 1.09316 L
s
.53191 1.0913 m
.53192 1.09136 L
s
.53172 1.09 m
.53191 1.0913 L
s
.53171 1.08995 m
.53172 1.09 L
s
.53169 1.08985 m
.53171 1.08995 L
s
.36244 .87487 m .35709 .86476 L .35296 .86815 L 0 1 .497 r
F
.36244 .87487 m .3629 .86463 L .35709 .86476 L F
.36244 .87487 m .36652 .86786 L .3629 .86463 L F
.36244 .87487 m .36631 .87225 L .36652 .86786 L F
0 g
.35664 .875 m
.36244 .87487 L
s
.36242 .87885 m
.36244 .87487 L
s
.67317 .56646 m
.67973 .57218 L
s
.40806 .63375 m
.41682 .63185 L
s
.4467 .94791 m .43962 .94025 L .43717 .93823 L 0 0 .136 r
F
.4467 .94791 m .44416 .94487 L .43962 .94025 L F
.4467 .94791 m .44776 .949 L .44416 .94487 L F
0 g
.44692 .94805 m
.44802 .94871 L
s
.4467 .94791 m .44884 .9503 L .44776 .949 L 0 0 .136 r
F
.50724 .99682 m .50414 1.00789 L .50549 1.00085 L 0 .575 .108 r
F
.50724 .99682 m .50422 1.01567 L .50414 1.00789 L F
.50724 .99682 m .5057 1.01896 L .50422 1.01567 L F
.50724 .99682 m .50746 1.01489 L .5057 1.01896 L F
0 g
.50549 1.00085 m
.50579 .99428 L
s
.50724 .99682 m .50831 1.00619 L .50746 1.01489 L 0 .575 .108 r
F
.50724 .99682 m .50822 .99847 L .50831 1.00619 L F
0 g
.50822 .99847 m
.50895 .99506 L
s
.50724 .99682 m
.50734 .99397 L
s
.50549 1.00085 m
.50724 .99682 L
s
.40344 .65805 m .39241 .65497 L .39471 .65814 L 0 1 .519 r
F
0 g
.38985 .66277 m
.39471 .65814 L
s
.79472 .96307 m .80182 .94751 L .79725 .95138 L 0 1 .414 r
F
.78332 .97394 m .79472 .96307 L .79041 .95752 L 0 1 .399 r
F
0 g
.73396 .72191 m
.74089 .70949 L
s
.50337 .85649 m
.50574 .85891 L
s
.5021 .85519 m
.50337 .85649 L
s
.25219 .76189 m .24183 .75852 L .23995 .76375 L 0 1 .542 r
F
0 g
.23263 .76783 m
.23995 .76375 L
s
.66978 1.1599 m .67963 1.14502 L .67913 1.15591 L 0 .273 .105 r
F
.7069 1.12719 m .71617 1.11784 L .7121 1.12463 L 0 0 .049 r
F
.71251 1.13272 m .71617 1.11784 L .72075 1.1127 L 0 0 .018 r
F
.71251 1.13272 m .7121 1.12463 L .71617 1.11784 L F
0 g
.71617 1.11784 m
.71699 1.1115 L
s
.71617 1.11784 m
.71683 1.1171 L
s
.40344 .65805 m .39803 .65007 L .39241 .65497 L 0 1 .519 r
F
.40344 .65805 m .40784 .6467 L .39803 .65007 L F
.40344 .65805 m .41659 .64662 L .40784 .6467 L F
.40344 .65805 m .41843 .64988 L .41659 .64662 L F
.40344 .65805 m .41279 .65478 L .41843 .64988 L F
0 g
.39816 .66303 m
.40344 .65805 L
s
.39471 .65814 m
.40344 .65805 L
s
.57722 .96457 m
.57752 .96678 L
s
.57752 .96678 m
.57787 .96929 L
s
.57787 .96929 m
.57967 .98252 L
s
.4444 .80154 m .43629 .79662 L .43844 .79798 L 0 .314 .217 r
F
0 g
.43844 .79798 m
.4444 .80154 L
s
.4444 .80154 m
.4444 .80154 L
s
.44173 .79991 m
.44436 .80151 L
s
.4444 .80153 m
.4444 .80154 L
s
.43778 .79769 m
.43844 .79798 L
s
.3376 .6572 m .32996 .65214 L .32506 .65844 L 0 1 .525 r
F
.3376 .6572 m .3397 .64582 L .32996 .65214 L F
0 g
.32823 .66053 m
.3376 .6572 L
s
.33298 .6636 m
.3376 .6572 L
s
.75813 .85388 m .77342 .8545 L .77338 .85051 L 0 1 .474 r
F
0 g
.77342 .8545 m
.77922 .85535 L
s
.5561 .97705 m
.55632 .97767 L
s
.35296 .86815 m .34346 .86218 L .3431 .86691 L 0 1 .508 r
F
0 g
.33751 .86775 m
.3431 .86691 L
s
.47522 .82482 m
.47753 .82679 L
s
.4726 .82258 m
.47406 .82386 L
s
.67333 .73956 m
.67362 .73987 L
s
.67306 .73926 m
.67333 .73956 L
s
.2375 .91516 m .22847 .90967 L .22596 .91139 L 0 .584 .292 r
F
.2375 .91516 m .23379 .90967 L .22847 .90967 L F
.2375 .91516 m .23835 .91141 L .23379 .90967 L F
.2375 .91516 m .23994 .91376 L .23835 .91141 L F
0 g
.23221 .91515 m
.2375 .91516 L
s
.2375 .91516 m
.23917 .91728 L
s
.45595 .48848 m
.46558 .48695 L
s
.44516 .49023 m
.45595 .48848 L
s
.42764 .92804 m .41874 .91984 L .42265 .92386 L 0 .264 .246 r
F
0 g
.42265 .92386 m
.4238 .92604 L
s
.65617 .58189 m .68009 .58042 L .67347 .57769 L 0 1 .522 r
F
0 g
.68009 .58042 m
.68449 .58046 L
s
.77195 .98627 m .78451 .9857 L .78332 .97394 L 0 1 .383 r
F
0 g
.78198 .99827 m
.78451 .9857 L
s
.78451 .9857 m
.78883 .99121 L
s
.53423 1.05912 m
.53442 1.06032 L
s
.53422 1.05902 m
.53423 1.05912 L
s
.47261 .64851 m
.47919 .6432 L
s
.47957 .97841 m .47111 .9737 L .47237 .97269 L 0 .401 .039 r
F
.47957 .97841 m .47292 .97703 L .47111 .9737 L F
.47957 .97841 m .47663 .9808 L .47292 .97703 L F
.47957 .97841 m .47976 .98249 L .47663 .9808 L F
.47957 .97841 m .48102 .98146 L .47976 .98249 L F
0 g
.47957 .97841 m
.4811 .97647 L
s
.47587 .97465 m
.47957 .97841 L
s
.70277 .88862 m .71633 .88234 L .71279 .88262 L 0 .83 .205 r
F
0 g
.71633 .88234 m
.71633 .88234 L
s
.53319 1.04537 m
.53382 1.04846 L
s
.48052 .83055 m
.48052 .83055 L
s
.36815 .64607 m .35606 .64702 L .35884 .64874 L 0 1 .526 r
F
0 g
.35751 .65057 m
.35884 .64874 L
s
.36815 .64607 m .36153 .64182 L .35606 .64702 L 0 1 .526 r
F
.36815 .64607 m .37162 .63659 L .36153 .64182 L F
.36815 .64607 m .38096 .63391 L .37162 .63659 L F
.36815 .64607 m .38331 .63558 L .38096 .63391 L F
.36815 .64607 m .37782 .64079 L .38331 .63558 L F
0 g
.363 .65115 m
.36815 .64607 L
s
.35884 .64874 m
.36815 .64607 L
s
.31604 .66214 m
.32506 .65844 L
s
.54559 1.01203 m .55269 1.02513 L .54832 1.01118 L 0 .182 .195 r
F
.54559 1.01203 m .55676 1.05755 L .55269 1.02513 L F
.54559 1.01203 m .55505 1.08779 L .55782 1.08698 L F
.54559 1.01203 m .55034 1.05948 L .55505 1.08779 L F
.54559 1.01203 m .5463 1.02709 L .55034 1.05948 L F
.54376 1.01421 m .5445 1.00652 L .54831 1.01118 L 0 .537 .185 r
F
0 g
.54791 1.01068 m
.5483 1.01116 L
s
.54788 1.01065 m
.54791 1.01068 L
s
.54781 1.01056 m
.54788 1.01065 L
s
.54774 1.01048 m
.54781 1.01056 L
s
.54764 1.01035 m
.54774 1.01048 L
s
.54742 1.01009 m
.54764 1.01035 L
s
.54741 1.01007 m
.54742 1.01009 L
s
.54721 1.00983 m
.54741 1.01007 L
s
.54662 1.00911 m
.54721 1.00983 L
s
.54653 1.009 m
.54662 1.00911 L
s
.54637 1.00881 m
.54653 1.009 L
s
.54499 1.00713 m
.54637 1.00881 L
s
.5445 1.00652 m
.54499 1.00713 L
s
.54792 1.01004 m
.54831 1.01117 L
s
.54831 1.01117 m
.54832 1.01118 L
s
.54831 1.01117 m
.54831 1.01117 L
s
.54717 1.00718 m
.54831 1.01117 L
s
.54688 1.00705 m
.54772 1.00948 L
s
.54772 1.00948 m
.54792 1.01004 L
s
.54647 1.00476 m
.54717 1.00718 L
s
.5442 1.00507 m
.5445 1.00652 L
s
.73333 .80414 m .74362 .80079 L .73577 .77952 L 0 .707 .314 r
F
0 g
.73451 .76886 m
.73577 .77952 L
s
.74286 .71028 m
.7446 .70606 L
s
.7446 .70606 m
.74475 .70567 L
s
.74475 .70567 m
.7459 .70289 L
s
.50381 .63652 m .52124 .62975 L .52141 .62649 L 0 1 .518 r
F
0 g
.52124 .62975 m
.5285 .63059 L
s
.5137 .63405 m
.52124 .62975 L
s
.30053 .85903 m .29404 .85254 L .28969 .85581 L 0 1 .525 r
F
.30053 .85903 m .30046 .85096 L .29404 .85254 L F
.30053 .85903 m .30467 .85214 L .30046 .85096 L F
.30053 .85903 m .30469 .8556 L .30467 .85214 L F
0 g
.29413 .86059 m
.30053 .85903 L
s
.80074 .92148 m .81472 .92614 L .81209 .91309 L 0 1 .418 r
F
0 g
.81325 .93852 m
.81472 .92614 L
s
.81472 .92614 m
.82012 .93353 L
s
.58685 .6002 m .60703 .59702 L .60872 .59442 L 0 1 .525 r
F
.58685 .6002 m .59767 .5995 L .60703 .59702 L F
0 g
.60703 .59702 m
.61353 .59886 L
s
.59767 .5995 m
.6045 .60094 L
s
.59767 .5995 m
.60703 .59702 L
s
.42764 .92804 m .4181 .9176 L .41874 .91984 L 0 .264 .246 r
F
0 g
.41384 .91639 m
.41874 .91984 L
s
.50381 .63652 m .49578 .63249 L .49613 .63585 L 0 1 .518 r
F
.50381 .63652 m .50333 .62819 L .49578 .63249 L F
.50381 .63652 m .51373 .62581 L .50333 .62819 L F
.50381 .63652 m .52141 .62649 L .51373 .62581 L F
.28969 .85581 m .27884 .85256 L .27876 .85593 L 0 1 .514 r
F
0 g
.27286 .85766 m
.27876 .85593 L
s
.69781 .77057 m
.69784 .76983 L
s
.53301 1.09434 m .5387 1.12162 L .53889 1.12106 L 0 0 .11 r
F
.53566 1.11203 m .54078 1.12895 L .54075 1.12867 L 0 0 .062 r
F
.53547 1.11139 m .53562 1.11189 L .53566 1.11203 L F
.53562 1.11189 m .54078 1.12895 L .53566 1.11203 L F
.53547 1.11138 m .54078 1.12895 L .53547 1.11139 L F
.53541 1.11121 m .54078 1.12895 L .53546 1.11136 L F
.53546 1.11136 m .53547 1.11138 L .53547 1.11139 L F
.53526 1.11069 m .54075 1.12867 L .5384 1.121 L F
.53969 1.12635 m .53794 1.12 L .5384 1.121 L 0 .445 0 r
F
.5387 1.12162 m .53794 1.12 L .53969 1.12635 L 0 0 .11 r
F
.53301 1.09434 m .53756 1.11802 L .5387 1.12162 L F
.53756 1.11802 m .53794 1.12 L .5387 1.12162 L F
.5397 1.12638 m .5384 1.121 L .54075 1.12867 L 0 .445 0 r
F
.53969 1.12635 m .53963 1.12614 L .5397 1.12638 L F
.53963 1.12614 m .5384 1.121 L .5397 1.12638 L F
.54078 1.12895 m .54659 1.14222 L .54426 1.13777 L 0 .484 0 r
F
.53996 1.12722 m .54075 1.12867 L .54415 1.14033 L 0 .445 0 r
F
.53974 1.12652 m .53983 1.12671 L .53996 1.12722 L F
.53983 1.12671 m .54075 1.12867 L .53996 1.12722 L F
.54386 1.14274 m .54223 1.13609 L .5431 1.13803 L 0 .5 0 r
F
.54306 1.13884 m .54223 1.13609 L .54386 1.14274 L 0 0 .102 r
F
.54006 1.12757 m .54415 1.14033 L .54634 1.14823 L 0 .445 0 r
F
.53969 1.12635 m .53996 1.12722 L .54006 1.12757 L F
.53996 1.12722 m .54415 1.14033 L .54006 1.12757 L F
.54302 1.13863 m .54193 1.13459 L .54306 1.13884 L 0 0 .102 r
F
.53969 1.12635 m .54589 1.14725 L .5431 1.13803 L 0 .445 0 r
F
.53978 1.12666 m .54634 1.14823 L .54589 1.14725 L F
.53969 1.12635 m .53976 1.1266 L .53978 1.12666 L F
.53976 1.1266 m .54634 1.14823 L .53978 1.12666 L F
.53611 1.10517 m .54304 1.13876 L .54267 1.1359 L 0 0 .102 r
F
.54304 1.13876 m .54306 1.13884 L .54305 1.1388 L F
.54304 1.13876 m .54305 1.1388 L .54267 1.1359 L F
.53611 1.10517 m .54191 1.13448 L .54302 1.13863 L F
.54191 1.13448 m .54193 1.13459 L .54302 1.13863 L F
.54193 1.13459 m .54223 1.13609 L .54306 1.13884 L F
.54306 1.13884 m .54386 1.14274 L .54341 1.14013 L F
.54306 1.13884 m .54341 1.14013 L .54267 1.1359 L F
.53973 1.12648 m .53973 1.12649 L .53974 1.12652 L 0 .445 0 r
F
.53973 1.12649 m .54075 1.12867 L .53974 1.12652 L F
.53969 1.12635 m .5397 1.12638 L .53973 1.12648 L F
.5397 1.12638 m .54075 1.12867 L .53973 1.12648 L F
.53611 1.10517 m .53889 1.12106 L .54173 1.13386 L 0 0 .102 r
F
.54175 1.13393 m .54173 1.13386 L .54177 1.13405 L F
.53611 1.10517 m .54173 1.13386 L .54175 1.13393 L F
.54196 1.13473 m .54177 1.13405 L .54223 1.13609 L F
.53611 1.10517 m .54177 1.13405 L .54196 1.13473 L F
.5387 1.12162 m .53969 1.12635 L .53923 1.12329 L 0 0 .11 r
F
.5387 1.12162 m .53923 1.12329 L .53889 1.12106 L F
.53526 1.11069 m .53541 1.11121 L .53546 1.11136 L 0 0 .062 r
F
.53301 1.09434 m .53486 1.10666 L .53728 1.11711 L 0 0 .11 r
F
.53756 1.11802 m .53728 1.11711 L .53794 1.12 L F
.53301 1.09434 m .53728 1.11711 L .53756 1.11802 L F
0 g
.53526 1.11069 m
.53551 1.11153 L
s
.53551 1.11153 m
.53552 1.11155 L
s
.53552 1.11155 m
.53575 1.11232 L
s
.53486 1.10666 m
.53526 1.11069 L
s
.53197 1.06631 m .53132 1.06495 L .53351 1.08031 L 0 .07 .169 r
F
0 g
.53132 1.06495 m
.53138 1.06538 L
s
.53182 1.06519 m
.53185 1.06544 L
s
.53185 1.06544 m
.53194 1.0661 L
s
.53165 1.06398 m
.53182 1.06519 L
s
.53235 1.06483 m
.53253 1.06587 L
s
.53106 1.07176 m
.53139 1.07413 L
s
.5313 1.06484 m
.53132 1.06495 L
s
.53067 1.07023 m
.53139 1.07413 L
s
.53207 1.05912 m
.53305 1.06591 L
s
.54188 1.13173 m
.54425 1.13775 L
s
.54166 1.1312 m
.54188 1.13173 L
s
.76889 .84739 m .78007 .85122 L .7845 .84905 L 0 1 .492 r
F
.76889 .84739 m .77338 .85051 L .78007 .85122 L F
0 g
.77922 .85535 m
.78007 .85122 L
s
.22596 .91139 m .217 .90557 L .21441 .90764 L 0 .626 .319 r
F
.22596 .91139 m .22238 .90532 L .217 .90557 L F
.22596 .91139 m .22694 .90706 L .22238 .90532 L F
.22596 .91139 m .22847 .90967 L .22694 .90706 L F
0 g
.2206 .91163 m
.22596 .91139 L
s
.22596 .91139 m
.22756 .91374 L
s
.69167 .84973 m .69461 .83156 L .69084 .83227 L 0 .75 .325 r
F
0 g
.68896 .82852 m
.69084 .83227 L
s
.68517 .8327 m
.68528 .83299 L
s
.2903 .65225 m .27698 .65398 L .28055 .65549 L 0 1 .54 r
F
0 g
.54729 .98941 m
.54768 .99058 L
s
.54768 .99058 m
.54819 .99208 L
s
.54819 .99208 m
.55091 1.00008 L
s
.54729 .98941 m
.54904 .98699 L
s
.78942 .93068 m .80182 .94751 L .80332 .93471 L 0 1 .405 r
F
.78942 .93068 m .79725 .95138 L .80182 .94751 L F
0 g
.80182 .94751 m
.80615 .95338 L
s
.48844 .83865 m
.49276 .843 L
s
.70294 .6827 m .72083 .67063 L .72419 .66707 L 0 1 .216 r
F
0 g
.72156 .67016 m
.72313 .66916 L
s
.70294 .6827 m .71174 .67731 L .72083 .67063 L 0 1 .216 r
F
0 g
.72083 .67063 m
.72156 .67016 L
s
.73665 1.08664 m .73555 1.09088 L .73882 1.08789 L 0 1 .165 r
F
0 g
.73555 1.09088 m
.73882 1.08789 L
s
.73312 1.0952 m
.73882 1.08789 L
s
.75039 1.06402 m .75916 1.04872 L .75466 1.05512 L 0 1 .212 r
F
.75131 1.04485 m .75916 1.04872 L .76257 1.03722 L 0 1 .32 r
F
.75131 1.04485 m .75466 1.05512 L .75916 1.04872 L F
0 g
.75916 1.04872 m
.76162 1.04858 L
s
.75916 1.04872 m
.75927 1.04837 L
s
.29841 .75918 m .28643 .7595 L .29039 .76039 L 0 1 .491 r
F
0 g
.289 .76483 m
.29039 .76039 L
s
.69681 1.1449 m .7069 1.12719 L .706 1.13549 L 0 .053 .075 r
F
.4444 .80154 m .43935 .79786 L .43629 .79662 L 0 .314 .217 r
F
.4444 .80154 m .4456 .80088 L .43935 .79786 L F
.4444 .80154 m .45159 .80446 L .4456 .80088 L F
.4444 .80154 m .45331 .80619 L .45159 .80446 L F
.4444 .80154 m .45022 .80493 L .45331 .80619 L F
0 g
.4444 .80154 m
.4444 .80154 L
s
.28094 .66441 m
.28563 .66454 L
s
.29867 .66343 m .29009 .65784 L .28563 .66454 L 0 1 .528 r
F
0 g
.38377 .65498 m
.39241 .65497 L
s
.76889 .84739 m .7845 .84905 L .78433 .84471 L 0 1 .492 r
F
0 g
.7845 .84905 m
.79039 .8503 L
s
.29867 .66343 m .2996 .65117 L .29009 .65784 L 0 1 .528 r
F
.29867 .66343 m .30915 .64777 L .2996 .65117 L F
.29867 .66343 m .31234 .64993 L .30915 .64777 L F
.29867 .66343 m .30784 .65664 L .31234 .64993 L F
0 g
.29445 .67029 m
.29867 .66343 L
s
.28917 .66681 m
.29867 .66343 L
s
.67696 .87755 m
.68123 .89091 L
s
.68123 .89091 m
.68266 .89538 L
s
.68266 .89538 m
.68299 .89641 L
s
.68299 .89641 m
.68331 .8974 L
s
.68331 .8974 m
.68336 .89755 L
s
.67696 .87755 m
.67733 .89701 L
s
.28032 .66118 m
.28094 .66441 L
s
.4181 .9176 m .40897 .90977 L .41288 .9138 L 0 .359 .337 r
F
0 g
.41288 .9138 m
.41384 .91639 L
s
.77195 .98627 m .77313 .99815 L .77743 1.00328 L 0 1 .383 r
F
0 g
.77395 1.014 m
.77743 1.00328 L
s
.45675 .95857 m
.45807 .95935 L
s
.46884 .96958 m .46215 .9636 L .46575 .96662 L 0 .331 0 r
F
.46884 .96958 m .45992 .96203 L .46215 .9636 L F
.46884 .96958 m .46054 .96295 L .45992 .96203 L F
0 g
.45807 .95935 m
.4612 .96261 L
s
.46884 .96958 m .46364 .96591 L .46054 .96295 L 0 .331 0 r
F
0 g
.4612 .96261 m
.46215 .9636 L
s
.46884 .96958 m .46713 .96894 L .46364 .96591 L 0 .331 0 r
F
0 g
.46575 .96662 m
.46575 .96662 L
s
.46575 .96662 m
.46729 .96682 L
s
.46884 .96958 m .46936 .97051 L .46713 .96894 L 0 .331 0 r
F
0 g
.46884 .96958 m
.47115 .97039 L
s
.46575 .96662 m
.46884 .96958 L
s
.69026 .58709 m .69735 .58759 L .68672 .57615 L 0 .506 .402 r
F
.69026 .58709 m .70882 .60259 L .69735 .58759 L F
.69026 .58709 m .71508 .6138 L .70882 .60259 L F
.69026 .58709 m .71195 .61373 L .71508 .6138 L F
0 g
.70726 .61336 m
.70842 .61494 L
s
.69026 .58709 m .70132 .60228 L .71195 .61373 L 0 .506 .402 r
F
0 g
.70132 .60228 m
.70726 .61336 L
s
.68507 .5778 m
.69026 .58709 L
s
.68449 .58046 m
.69026 .58709 L
s
.21441 .90764 m .20552 .90148 L .20285 .90389 L 0 .686 .345 r
F
.21441 .90764 m .21096 .90097 L .20552 .90148 L F
.21441 .90764 m .21553 .90271 L .21096 .90097 L F
.21441 .90764 m .217 .90557 L .21553 .90271 L F
0 g
.20899 .90813 m
.21441 .90764 L
s
.21441 .90764 m
.21596 .91023 L
s
.43717 .93823 m .43039 .9296 L .42764 .92804 L 0 .129 .187 r
F
.43717 .93823 m .43516 .93408 L .43039 .9296 L F
.43717 .93823 m .43876 .93847 L .43516 .93408 L F
.43717 .93823 m .43962 .94025 L .43876 .93847 L F
0 g
.43241 .93377 m
.43717 .93823 L
s
.43717 .93823 m
.43827 .93954 L
s
.26919 .661 m
.26982 .66423 L
s
.34346 .86218 m .33339 .86208 L .33728 .86391 L 0 1 .521 r
F
0 g
.33728 .86391 m
.33751 .86775 L
s
.74286 .71028 m
.74691 .70394 L
s
.74691 .70394 m
.74701 .70378 L
s
.74701 .70378 m
.74722 .70346 L
s
.35296 .86815 m .34783 .85804 L .34346 .86218 L 0 1 .508 r
F
.35296 .86815 m .35384 .85711 L .34783 .85804 L F
.35296 .86815 m .35747 .86002 L .35384 .85711 L F
.35296 .86815 m .35709 .86476 L .35747 .86002 L F
0 g
.34697 .86907 m
.35296 .86815 L
s
.35278 .87254 m
.35296 .86815 L
s
.43027 .79376 m
.43251 .79433 L
s
.43027 .79376 m
.43629 .79662 L
s
.7901 .82715 m .80549 .81674 L .80092 .82174 L 0 0 0 r
F
0 g
.80549 .81674 m
.80555 .81401 L
s
.80549 .81674 m
.81224 .81199 L
s
.46936 .97051 m
.47237 .97269 L
s
.52653 1.00807 m .52735 1.00665 L .53024 1.02067 L 0 .635 .166 r
F
0 g
.52664 1.00171 m
.52735 1.00665 L
s
.69892 .78568 m
.70197 .77576 L
s
.70197 .77576 m
.70208 .77541 L
s
.64208 .86022 m
.6421 .86012 L
s
.4181 .9176 m .40856 .90708 L .40897 .90977 L 0 .359 .337 r
F
0 g
.40387 .90673 m
.40897 .90977 L
s
.69309 .81732 m
.69903 .82648 L
s
.5293 .62253 m .53964 .62053 L .54791 .61674 L 0 1 .523 r
F
0 g
.53964 .62053 m
.54689 .62137 L
s
.7128 .88262 m .72971 .8749 L .72595 .87424 L 0 .99 .239 r
F
0 g
.72846 .87741 m
.72971 .8749 L
s
.45495 .65054 m .44535 .64683 L .44671 .65024 L 0 1 .513 r
F
.45495 .65054 m .45193 .64201 L .44535 .64683 L F
0 g
.44572 .65106 m
.44671 .65024 L
s
.44073 .65519 m
.44572 .65106 L
s
.45495 .65054 m .46207 .63901 L .45193 .64201 L 0 1 .513 r
F
.45495 .65054 m .47032 .63931 L .46207 .63901 L F
.45495 .65054 m .47118 .64271 L .47032 .63931 L F
.45495 .65054 m .46459 .64752 L .47118 .64271 L F
0 g
.44671 .65024 m
.45495 .65054 L
s
.46459 .64752 m
.47261 .64851 L
s
.54634 1.14823 m .54659 1.14222 L .55031 1.15218 L 0 .536 .026 r
F
.54634 1.14823 m .54426 1.13777 L .54659 1.14222 L F
0 g
.54626 1.13955 m
.54659 1.14222 L
s
.68246 .75824 m .68332 .74633 L .67988 .74678 L 0 .716 .392 r
F
0 g
.67362 .73987 m
.67988 .74678 L
s
.68246 .75824 m .69129 .75675 L .68332 .74633 L 0 .716 .392 r
F
.68246 .75824 m .69848 .77111 L .69129 .75675 L F
0 g
.67988 .74678 m
.68246 .75824 L
s
.47919 .64319 m .48902 .64043 L .49613 .63585 L 0 1 .515 r
F
0 g
.74109 .65061 m
.75018 .64551 L
s
.75131 1.04485 m .76257 1.03722 L .76261 1.02825 L 0 1 .32 r
F
0 g
.76257 1.03722 m
.76593 1.0398 L
s
.75927 1.04837 m
.76257 1.03722 L
s
.69102 .78457 m
.69267 .78711 L
s
.69267 .78711 m
.69347 .78834 L
s
.69347 .78834 m
.69456 .79001 L
s
.69456 .79001 m
.69472 .79027 L
s
.69472 .79027 m
.69506 .79079 L
s
.69861 .79625 m
.69904 .79692 L
s
.68933 .77308 m
.69102 .78457 L
s
.77966 .84108 m .79115 .84584 L .79559 .84372 L 0 1 .505 r
F
.77966 .84108 m .78433 .84471 L .79115 .84584 L F
0 g
.79039 .8503 m
.79115 .84584 L
s
.72023 .87386 m
.72102 .87181 L
s
.65557 .7759 m .67174 .74132 L .66475 .75119 L 0 .922 .139 r
F
0 g
.65786 .77986 m
.66072 .77354 L
s
.66213 .76481 m
.66442 .76044 L
s
.66442 .76044 m
.66973 .75028 L
s
.67174 .74132 m
.67256 .7411 L
s
.53197 1.06631 m .53936 1.10997 L .53541 1.08554 L 0 .07 .169 r
F
.53197 1.06631 m .54158 1.12549 L .53936 1.10997 L F
.53197 1.06631 m .54057 1.12164 L .54158 1.12549 L F
.53197 1.06631 m .53711 1.10224 L .54057 1.12164 L F
0 g
.53692 1.11614 m
.53747 1.11796 L
s
.53666 1.11532 m
.53692 1.11614 L
s
.53575 1.11232 m
.53666 1.11532 L
s
.53197 1.06631 m .53351 1.08031 L .53711 1.10224 L 0 .07 .169 r
F
0 g
.53197 1.06631 m
.53208 1.06688 L
s
.53188 1.08458 m
.53265 1.08873 L
s
.53265 1.08873 m
.53293 1.09022 L
s
.5324 1.08908 m
.53281 1.09261 L
s
.53188 1.08458 m
.5324 1.08908 L
s
.53281 1.09261 m
.53297 1.09398 L
s
.53055 1.06412 m
.53213 1.07279 L
s
.53303 1.0627 m
.53378 1.06688 L
s
.5332 1.06691 m
.53328 1.06745 L
s
.53305 1.06591 m
.5332 1.06691 L
s
.53285 1.06766 m
.53288 1.06783 L
s
.53264 1.06647 m
.53285 1.06766 L
s
.53253 1.06587 m
.53264 1.06647 L
s
.53194 1.0661 m
.53197 1.06631 L
s
.64179 .82527 m .6573 .78516 L .65488 .78646 L 0 1 .139 r
F
0 g
.65239 .8028 m
.65422 .79566 L
s
.6573 .78516 m
.65861 .78092 L
s
.65129 .80711 m
.65239 .8028 L
s
.48993 .48499 m
.50005 .48496 L
s
.47933 .4856 m
.48993 .48499 L
s
.20285 .90389 m .19404 .89739 L .19129 .90016 L 0 .746 .369 r
F
0 g
.19129 .90016 m
.19273 .90327 L
s
.20285 .90389 m .19954 .89661 L .19404 .89739 L 0 .746 .369 r
F
.20285 .90389 m .20411 .89835 L .19954 .89661 L F
.20285 .90389 m .20552 .90148 L .20411 .89835 L F
0 g
.19738 .90465 m
.20285 .90389 L
s
.20285 .90389 m
.20434 .90674 L
s
.68264 .89691 m
.68336 .89756 L
s
.67735 .89813 m
.67889 .89778 L
s
.67889 .89778 m
.68264 .89691 L
s
.36803 .6511 m .356 .64916 L .35876 .65174 L 0 1 .532 r
F
0 g
.35417 .65598 m
.35876 .65174 L
s
.78942 .93068 m .79194 .94418 L .79725 .95138 L 0 1 .405 r
F
0 g
.79472 .96307 m
.79725 .95138 L
s
.47919 .64319 m .47032 .63931 L .47118 .64271 L 0 1 .515 r
F
.47919 .64319 m .47743 .63472 L .47032 .63931 L F
0 g
.46953 .64392 m
.47118 .64271 L
s
.46459 .64752 m
.46953 .64392 L
s
.47919 .64319 m .48776 .632 L .47743 .63472 L 0 1 .515 r
F
.47919 .64319 m .49578 .63249 L .48776 .632 L F
.47919 .64319 m .49613 .63585 L .49578 .63249 L F
0 g
.48902 .64043 m
.49328 .63768 L
s
.49328 .63768 m
.49613 .63585 L
s
.47118 .64271 m
.47919 .64319 L
s
.49613 .63585 m
.50381 .63652 L
s
.24183 .75852 m .2294 .76045 L .23362 .7618 L 0 1 .542 r
F
0 g
.23263 .76783 m
.23362 .7618 L
s
.61811 .59254 m .61296 .58791 L .61126 .59051 L 0 1 .521 r
F
.61811 .59254 m .62271 .58622 L .61296 .58791 L F
.61811 .59254 m .63398 .58658 L .62271 .58622 L F
0 g
.73013 .66244 m
.73032 .66315 L
s
.72998 .66185 m
.73013 .66244 L
s
.72913 .65861 m
.72921 .6589 L
s
.72991 .66161 m
.72998 .66185 L
s
.73328 .67445 m .74226 .674 L .73262 .65863 L 0 .642 .377 r
F
.73328 .67445 m .75161 .69451 L .74226 .674 L F
0 g
.72813 .66561 m
.73328 .67445 L
s
.73032 .66315 m
.73328 .67445 L
s
.33007 .64847 m .31727 .64829 L .32046 .6502 L 0 1 .54 r
F
0 g
.31767 .65351 m
.32046 .6502 L
s
.27884 .85256 m .26776 .85254 L .27216 .85391 L 0 1 .507 r
F
0 g
.27216 .85391 m
.27286 .85766 L
s
.54014 1.00976 m
.5419 1.01193 L
s
.41901 .65484 m
.4212 .65486 L
s
.41279 .65478 m
.41901 .65484 L
s
.75256 .69818 m
.75257 .69817 L
s
.75257 .69817 m
.7532 .69689 L
s
.70294 .6827 m .72419 .66707 L .71987 .66785 L 0 1 .216 r
F
0 g
.71876 .67215 m
.72083 .67063 L
s
.72419 .66707 m
.72525 .66623 L
s
.71251 1.13272 m .72075 1.1127 L .7228 1.1126 L 0 0 .018 r
F
0 g
.72075 1.1127 m
.72228 1.10828 L
s
.71683 1.1171 m
.72075 1.1127 L
s
.46713 .96894 m
.46936 .97051 L
s
.5293 .62253 m .54791 .61674 L .54859 .61367 L 0 1 .523 r
F
0 g
.54791 .61674 m
.55502 .61783 L
s
.53964 .62053 m
.54791 .61674 L
s
.25219 .76189 m .24858 .75279 L .24183 .75852 L 0 1 .542 r
F
.25219 .76189 m .25664 .74963 L .24858 .75279 L F
.25219 .76189 m .26062 .75119 L .25664 .74963 L F
.25219 .76189 m .2587 .75645 L .26062 .75119 L F
0 g
.25048 .76683 m
.25219 .76189 L
s
.24416 .76502 m
.25219 .76189 L
s
.40856 .90708 m .39947 .90002 L .40323 .90386 L 0 .485 .398 r
F
0 g
.40323 .90386 m
.40387 .90673 L
s
.5571 .61031 m .56776 .6089 L .57664 .60571 L 0 1 .526 r
F
0 g
.56776 .6089 m
.57485 .61 L
s
.82346 .90538 m .83485 .89823 L .82939 .89069 L 0 1 .44 r
F
.5571 .61031 m .57664 .60571 L .57783 .60287 L 0 1 .526 r
F
0 g
.57664 .60571 m
.5835 .60714 L
s
.56776 .6089 m
.57664 .60571 L
s
.47749 .62368 m .46823 .62155 L .46911 .62292 L 0 1 .419 r
F
.47749 .62368 m .47569 .62031 L .46823 .62155 L F
0 g
.46219 .62505 m
.46911 .62292 L
s
.47749 .62368 m .48652 .62003 L .47569 .62031 L 0 1 .419 r
F
.47749 .62368 m .49491 .62079 L .48652 .62003 L F
.47749 .62368 m .49527 .6221 L .49491 .62079 L F
.47749 .62368 m .4878 .62333 L .49527 .6221 L F
0 g
.47042 .62482 m
.47749 .62368 L
s
.46911 .62292 m
.47749 .62368 L
s
.4878 .62333 m
.4958 .62391 L
s
.5097 1.00084 m .50746 1.01489 L .50831 1.00619 L 0 .591 .116 r
F
.5097 1.00084 m .50794 1.02393 L .50746 1.01489 L F
.5097 1.00084 m .50945 1.02725 L .50794 1.02393 L F
0 g
.50822 .99847 m
.50831 1.00619 L
s
.5097 1.00084 m .51084 1.02183 L .50945 1.02725 L 0 .591 .116 r
F
.5097 1.00084 m .51119 1.01132 L .51084 1.02183 L F
.5097 1.00084 m .5107 1.00235 L .51119 1.01132 L F
0 g
.50968 .9986 m
.5097 1.00084 L
s
.50831 1.00619 m
.5097 1.00084 L
s
.5107 1.00235 m
.51171 .99496 L
s
.31005 .64839 m
.3124 .64552 L
s
.77966 .84108 m .79559 .84372 L .7953 .83906 L 0 1 .505 r
F
0 g
.79559 .84372 m
.80158 .84535 L
s
.37782 .64079 m
.38683 .63794 L
s
.34346 .86218 m .33392 .85722 L .33339 .86208 L 0 1 .521 r
F
0 g
.32764 .86335 m
.33339 .86208 L
s
.53794 1.04241 m
.53815 1.04397 L
s
.53749 1.03914 m
.53794 1.04241 L
s
.41831 .78831 m .40914 .78491 L .4117 .78599 L 0 .488 .248 r
F
0 g
.41166 .78598 m
.4117 .78599 L
s
.69167 .84973 m .70124 .84654 L .69461 .83156 L 0 .75 .325 r
F
0 g
.69309 .81732 m
.69461 .83156 L
s
.64493 .90485 m .65781 .89923 L .65494 .92333 L 0 .703 .206 r
F
0 g
.65685 .86867 m
.65781 .89923 L
s
.65781 .89923 m
.66176 .88926 L
s
.34909 .6498 m
.35005 .64971 L
s
.3475 .64995 m
.34909 .6498 L
s
.73665 1.08664 m .75039 1.06402 L .74714 1.06696 L 0 1 .165 r
F
0 g
.48102 .98146 m
.48446 .98371 L
s
.54904 .98699 m
.54927 .98764 L
s
.54927 .98764 m
.55014 .99001 L
s
.42764 .92804 m .42116 .91863 L .4181 .9176 L 0 .264 .246 r
F
.42764 .92804 m .42616 .92282 L .42116 .91863 L F
.42764 .92804 m .42976 .92737 L .42616 .92282 L F
.42764 .92804 m .43039 .9296 L .42976 .92737 L F
0 g
.42265 .92386 m
.42764 .92804 L
s
.42764 .92804 m
.42851 .92983 L
s
.40856 .90708 m .39939 .897 L .39947 .90002 L 0 .485 .398 r
F
0 g
.39429 .89756 m
.39947 .90002 L
s
.78942 .93068 m .80332 .93471 L .80074 .92148 L 0 1 .405 r
F
0 g
.80182 .94751 m
.80332 .93471 L
s
.80332 .93471 m
.80867 .942 L
s
.72595 .87424 m .74062 .8687 L .73667 .86735 L 0 1 .335 r
F
0 g
.74026 .87141 m
.74062 .8687 L
s
.74062 .8687 m
.74688 .868 L
s
.52653 1.00807 m .5305 1.04461 L .52787 1.02427 L 0 .635 .166 r
F
0 g
.52854 1.00405 m
.52893 1.00793 L
s
.52653 1.00807 m .53342 1.05885 L .5305 1.04461 L 0 .635 .166 r
F
.52653 1.00807 m .53467 1.05735 L .53342 1.05885 L F
0 g
.53407 1.05807 m
.53422 1.05902 L
s
.53436 1.05773 m
.53494 1.06072 L
s
.52653 1.00807 m .5333 1.04093 L .53467 1.05735 L 0 .635 .166 r
F
0 g
.53446 1.04568 m
.5353 1.05071 L
s
.53453 1.05368 m
.53623 1.06425 L
s
.53419 1.05158 m
.53453 1.05368 L
s
.53075 1.05002 m
.53303 1.0627 L
s
.53241 1.05432 m
.53396 1.06458 L
s
.52653 1.00807 m .53024 1.02067 L .5333 1.04093 L 0 .635 .166 r
F
0 g
.5322 1.013 m
.53242 1.01474 L
s
.53212 1.01236 m
.5322 1.013 L
s
.53171 1.0091 m
.53193 1.01092 L
s
.53193 1.01092 m
.53212 1.01236 L
s
.53185 1.01242 m
.53242 1.01474 L
s
.52397 .99829 m
.52653 1.00807 L
s
.5299 1.0045 m
.53185 1.01242 L
s
.52141 .62594 m
.52231 .62603 L
s
.2903 .65225 m .28165 .64816 L .27698 .65398 L 0 1 .54 r
F
.2903 .65225 m .29148 .64189 L .28165 .64816 L F
.2903 .65225 m .30128 .63864 L .29148 .64189 L F
.2903 .65225 m .30449 .64059 L .30128 .63864 L F
.2903 .65225 m .29977 .64643 L .30449 .64059 L F
0 g
.28055 .65549 m
.2903 .65225 L
s
.28589 .65767 m
.2903 .65225 L
s
.27218 .65445 m
.27697 .65398 L
s
.73333 .80414 m .75004 .82997 L .74362 .80079 L 0 .707 .314 r
F
0 g
.73171 .78023 m
.73333 .80414 L
s
.72562 .78098 m
.73333 .80414 L
s
.34695 .65065 m
.34861 .64853 L
s
.34861 .64853 m
.34886 .64822 L
s
.34695 .65065 m
.34909 .6498 L
s
.34909 .6498 m
.34985 .6495 L
s
.36803 .6511 m .36146 .64443 L .356 .64916 L 0 1 .532 r
F
0 g
.34985 .6495 m
.35606 .64702 L
s
.35005 .64971 m
.356 .64916 L
s
.36803 .6511 m .37152 .64068 L .36146 .64443 L 0 1 .532 r
F
.36803 .6511 m .38083 .64003 L .37152 .64068 L F
.36803 .6511 m .38315 .64291 L .38083 .64003 L F
.36803 .6511 m .37766 .64766 L .38315 .64291 L F
0 g
.36289 .65573 m
.36803 .6511 L
s
.35876 .65174 m
.36803 .6511 L
s
.54634 1.14823 m .54415 1.14033 L .54426 1.13777 L 0 .536 .026 r
F
0 g
.54425 1.13775 m
.54426 1.13777 L
s
.52141 .62649 m
.52231 .62603 L
s
.29841 .75918 m .28871 .75654 L .28643 .7595 L 0 1 .491 r
F
0 g
.27891 .76262 m
.28643 .7595 L
s
.68933 .77308 m
.69643 .78238 L
s
.69643 .78238 m
.69704 .78318 L
s
.53301 1.09434 m .53889 1.12106 L .53609 1.10767 L 0 0 .11 r
F
0 g
.5333 1.09561 m
.5339 1.0982 L
s
.53324 1.09533 m
.5333 1.09561 L
s
.53301 1.09434 m
.53324 1.09533 L
s
.53297 1.09398 m
.53301 1.09434 L
s
.4633 .81471 m .45595 .80864 L .45774 .81017 L 0 .207 .2 r
F
0 g
.45669 .80953 m
.45774 .81017 L
s
.79045 .83494 m .80225 .84059 L .8067 .83852 L 0 1 .513 r
F
.79045 .83494 m .7953 .83906 L .80225 .84059 L F
0 g
.80158 .84535 m
.80225 .84059 L
s
.69167 .84973 m .70632 .86726 L .70124 .84654 L 0 .75 .325 r
F
0 g
.69084 .83227 m
.69167 .84973 L
s
.68546 .83347 m
.69167 .84973 L
s
.27884 .85256 m .26797 .84915 L .26776 .85254 L 0 1 .507 r
F
0 g
.26175 .85436 m
.26776 .85254 L
s
.6867 1.16473 m .69408 1.13949 L .69681 1.1449 L 0 .149 .095 r
F
0 g
.69408 1.13949 m
.69502 1.1312 L
s
.69061 1.1399 m
.69408 1.13949 L
s
.58685 .6002 m .60872 .59442 L .60152 .59282 L 0 1 .525 r
F
0 g
.60872 .59442 m
.61811 .59254 L
s
.5242 .48608 m
.5347 .48771 L
s
.51392 .48545 m
.5242 .48608 L
s
.49769 .99564 m
.49786 .99433 L
s
.74362 .80079 m .74592 .77723 L .74186 .77824 L 0 .747 .325 r
F
0 g
.74111 .77653 m
.74186 .77824 L
s
.82346 .90538 m .82939 .89069 L .82485 .89353 L 0 1 .44 r
F
.81209 .91309 m .82346 .90538 L .81805 .89794 L 0 1 .429 r
F
.54376 1.01421 m .54831 1.01118 L .55268 1.02512 L 0 .537 .185 r
F
0 g
.5483 1.01116 m
.54831 1.01118 L
s
.39939 .897 m .39008 .89051 L .39384 .89429 L 0 .632 .432 r
F
0 g
.39384 .89429 m
.39429 .89756 L
s
.44776 .949 m
.44884 .9503 L
s
.75929 .68944 m
.75942 .68926 L
s
.75942 .68926 m
.76061 .68763 L
s
.62271 .58622 m .64405 .58507 L .64623 .58271 L 0 1 .526 r
F
.62271 .58622 m .63398 .58658 L .64405 .58507 L F
0 g
.64405 .58507 m
.65039 .58759 L
s
.63398 .58658 m
.64405 .58507 L
s
.63398 .58658 m
.64079 .58861 L
s
.28969 .85581 m .28336 .84939 L .27884 .85256 L 0 1 .514 r
F
.28969 .85581 m .28993 .84793 L .28336 .84939 L F
.28969 .85581 m .29414 .84916 L .28993 .84793 L F
.28969 .85581 m .29404 .85254 L .29414 .84916 L F
0 g
.28316 .85726 m
.28969 .85581 L
s
.28969 .85581 m
.28974 .85926 L
s
.69892 .78568 m
.7001 .77829 L
s
.7001 .77829 m
.7008 .77389 L
s
.24183 .75852 m .23145 .75492 L .2294 .76045 L 0 1 .542 r
F
0 g
.22194 .76465 m
.2294 .76045 L
s
.34346 .86218 m .33853 .85255 L .33392 .85722 L 0 1 .521 r
F
.34346 .86218 m .34474 .85081 L .33853 .85255 L F
.34346 .86218 m .34838 .85316 L .34474 .85081 L F
.34346 .86218 m .34783 .85804 L .34838 .85316 L F
0 g
.33728 .86391 m
.34346 .86218 L
s
.3431 .86691 m
.34346 .86218 L
s
.5293 .62253 m .52182 .61843 L .52166 .62164 L 0 1 .523 r
F
.5293 .62253 m .5301 .61463 L .52182 .61843 L F
.5293 .62253 m .54096 .61277 L .5301 .61463 L F
.5293 .62253 m .54859 .61367 L .54096 .61277 L F
0 g
.52231 .62603 m
.5293 .62253 L
s
.80092 .82174 m .81651 .8125 L .81176 .81642 L 0 0 0 r
F
0 g
.81651 .8125 m
.8167 .81061 L
s
.79045 .83494 m .8067 .83852 L .80628 .83355 L 0 1 .513 r
F
0 g
.8067 .83852 m
.81278 .84052 L
s
.4231 .62885 m .41213 .62817 L .41401 .6297 L 0 1 .496 r
F
0 g
.40806 .63375 m
.41401 .6297 L
s
.4231 .62885 m .41877 .62503 L .41213 .62817 L 0 1 .496 r
F
.4231 .62885 m .42952 .62236 L .41877 .62503 L F
.4231 .62885 m .43863 .62151 L .42952 .62236 L F
.4231 .62885 m .44002 .62306 L .43863 .62151 L F
.4231 .62885 m .43336 .6262 L .44002 .62306 L F
0 g
.41682 .63185 m
.4231 .62885 L
s
.41401 .6297 m
.4231 .62885 L
s
.74542 .73067 m .75514 .72901 L .74623 .71178 L 0 .704 .355 r
F
.74542 .73067 m .76322 .75239 L .75514 .72901 L F
.74542 .73067 m .76623 .771 L .76322 .75239 L F
.74542 .73067 m .76217 .77238 L .76623 .771 L F
.74542 .73067 m .75324 .75508 L .76217 .77238 L F
0 g
.74261 .7133 m
.74542 .73067 L
s
.7394 .71805 m
.74542 .73067 L
s
.74327 .75722 m
.75136 .77419 L
s
.29009 .65784 m .27678 .65897 L .28033 .66118 L 0 1 .532 r
F
.33007 .64847 m .32241 .64333 L .31727 .64829 L 0 1 .54 r
F
0 g
.31206 .64974 m
.31727 .64829 L
s
.33007 .64847 m .33248 .63861 L .32241 .64333 L 0 1 .54 r
F
.33007 .64847 m .34214 .63687 L .33248 .63861 L F
.33007 .64847 m .34493 .63927 L .34214 .63687 L F
.33007 .64847 m .33974 .64424 L .34493 .63927 L F
0 g
.32522 .65307 m
.33007 .64847 L
s
.32046 .6502 m
.33007 .64847 L
s
.53347 1.06879 m .5329 1.06795 L .53541 1.08554 L 0 .079 .172 r
F
0 g
.5329 1.06795 m
.53294 1.06823 L
s
.53378 1.06688 m
.5341 1.06869 L
s
.53396 1.06458 m
.53449 1.06808 L
s
.53138 1.06538 m
.53339 1.07949 L
s
.53288 1.06783 m
.5329 1.06795 L
s
.53328 1.06745 m
.53342 1.06845 L
s
.53329 1.07914 m
.53346 1.08006 L
s
.53213 1.07279 m
.53329 1.07914 L
s
.4181 .9176 m .41192 .90753 L .40856 .90708 L 0 .359 .337 r
F
0 g
.40856 .90708 m
.40897 .90977 L
s
.4181 .9176 m .41715 .91133 L .41192 .90753 L 0 .359 .337 r
F
.4181 .9176 m .42075 .91595 L .41715 .91133 L F
.4181 .9176 m .42116 .91863 L .42075 .91595 L F
0 g
.41288 .9138 m
.4181 .9176 L
s
.4181 .9176 m
.41874 .91984 L
s
.66451 .91933 m .67333 .89749 L .67735 .89814 L 0 .202 .098 r
F
0 g
.67733 .89701 m
.67735 .89813 L
s
.66451 .91933 m .66783 .90654 L .67333 .89749 L 0 .202 .098 r
F
0 g
.67325 .89761 m
.67333 .89749 L
s
.67278 .8984 m
.67325 .89761 L
s
.41831 .78831 m .4122 .78521 L .40914 .78491 L 0 .488 .248 r
F
0 g
.40258 .7831 m
.40914 .78491 L
s
.41831 .78831 m .41887 .78669 L .4122 .78521 L 0 .488 .248 r
F
.41831 .78831 m .42551 .78902 L .41887 .78669 L F
.41831 .78831 m .42767 .79063 L .42551 .78902 L F
.41831 .78831 m .42458 .79033 L .42767 .79063 L F
0 g
.41555 .78761 m
.41831 .78831 L
s
.4117 .78599 m
.41831 .78831 L
s
.64838 .81915 m .64992 .81246 L .64699 .82508 L 0 0 0 r
F
.64097 .85775 m .64838 .81915 L .64264 .84651 L F
0 g
.64751 .82331 m
.64838 .81915 L
s
.64796 .82096 m
.64838 .81915 L
s
.6421 .86012 m
.64337 .85265 L
s
.39939 .897 m .39021 .88703 L .39008 .89051 L 0 .632 .432 r
F
0 g
.38471 .88859 m
.39008 .89051 L
s
.73667 .86735 m .75153 .86253 L .74739 .86054 L 0 1 .403 r
F
0 g
.7513 .86572 m
.75153 .86253 L
s
.75153 .86253 m
.75793 .86232 L
s
.78332 .97394 m .79041 .95752 L .78585 .96185 L 0 1 .399 r
F
.77195 .98627 m .78332 .97394 L .77902 .96876 L 0 1 .383 r
F
0 g
.55837 .4922 m
.56913 .49562 L
s
.54853 .49021 m
.55837 .4922 L
s
.49388 .99251 m .48814 .99171 L .49087 .99093 L 0 .541 .077 r
F
0 g
.49087 .99093 m
.49202 .98832 L
s
.49388 .99251 m .48737 .99515 L .48814 .99171 L 0 .541 .077 r
F
.49388 .99251 m .48909 .99895 L .48737 .99515 L F
.49388 .99251 m .49211 1.00053 L .48909 .99895 L F
.49388 .99251 m .49441 .99883 L .49211 1.00053 L F
.49388 .99251 m .49517 .99539 L .49441 .99883 L F
0 g
.49388 .99251 m
.49489 .98827 L
s
.49087 .99093 m
.49388 .99251 L
s
.49517 .99539 m
.49786 .99433 L
s
.4633 .81471 m .45918 .81063 L .45595 .80864 L 0 .207 .2 r
F
.4633 .81471 m .46529 .81482 L .45918 .81063 L F
.4633 .81471 m .47088 .81938 L .46529 .81482 L F
.4633 .81471 m .47221 .82126 L .47088 .81938 L F
.4633 .81471 m .46895 .81925 L .47221 .82126 L F
0 g
.45774 .81017 m
.4633 .81471 L
s
.6867 1.16473 m .68407 1.15683 L .6851 1.14628 L 0 .149 .095 r
F
0 g
.67963 1.14502 m
.6851 1.14628 L
s
.66197 .57615 m .67347 .57769 L .68404 .57725 L 0 1 .526 r
F
0 g
.68404 .57725 m
.68507 .5778 L
s
.47111 .9737 m .46364 .96592 L .46713 .96895 L 0 .343 0 r
F
0 g
.46713 .96895 m
.46713 .96895 L
s
.68669 .57512 m
.69698 .57542 L
s
.7107 .67249 m .71987 .66785 L .72925 .6619 L 0 1 .243 r
F
0 g
.72731 .66313 m
.72925 .6619 L
s
.72925 .6619 m
.72991 .66161 L
s
.77812 .94087 m .79041 .95752 L .79194 .94418 L 0 1 .391 r
F
.77812 .94087 m .78585 .96185 L .79041 .95752 L F
0 g
.79041 .95752 m
.79472 .96307 L
s
.33392 .85722 m .32363 .85809 L .32754 .85959 L 0 1 .536 r
F
0 g
.32754 .85959 m
.32764 .86335 L
s
.71251 1.13272 m .71053 1.13101 L .7121 1.12463 L 0 0 .018 r
F
0 g
.7069 1.12719 m
.7121 1.12463 L
s
.43336 .6262 m
.4421 .62525 L
s
.52437 1.01055 m .52525 1.00974 L .52787 1.02427 L 0 .641 .163 r
F
0 g
.52401 .99863 m
.52525 1.00974 L
s
.59205 .50381 m
.60296 .50915 L
s
.58276 .50032 m
.59205 .50381 L
s
.29841 .75918 m .29575 .75347 L .28871 .75654 L 0 1 .491 r
F
.29841 .75918 m .30381 .75224 L .29575 .75347 L F
.29841 .75918 m .30747 .75368 L .30381 .75224 L F
.29841 .75918 m .30515 .75665 L .30747 .75368 L F
0 g
.29635 .76141 m
.29841 .75918 L
s
.29039 .76039 m
.29841 .75918 L
s
.75131 1.04485 m .75129 1.05347 L .75466 1.05512 L 0 1 .32 r
F
0 g
.75129 1.05347 m
.75466 1.05512 L
s
.75039 1.06402 m
.75466 1.05512 L
s
.7608 .68995 m
.76431 .68413 L
s
.51221 1.00447 m .51084 1.02183 L .51119 1.01132 L 0 .605 .126 r
F
.51221 1.00447 m .51172 1.03219 L .51084 1.02183 L F
0 g
.5107 1.00235 m
.51119 1.01132 L
s
.51221 1.00447 m .51325 1.03544 L .51172 1.03219 L 0 .605 .126 r
F
.51221 1.00447 m .51427 1.0285 L .51325 1.03544 L F
.51221 1.00447 m .5141 1.01605 L .51427 1.0285 L F
.51221 1.00447 m .51322 1.00578 L .5141 1.01605 L F
0 g
.51322 1.00578 m
.51385 .99744 L
s
.51171 .99496 m
.51221 1.00447 L
s
.51119 1.01132 m
.51221 1.00447 L
s
.65617 .58189 m .65169 .57678 L .6495 .57915 L 0 1 .522 r
F
.65617 .58189 m .66197 .57615 L .65169 .57678 L F
.65617 .58189 m .67347 .57769 L .66197 .57615 L F
0 g
.67347 .57769 m
.68009 .58042 L
s
.67347 .57769 m
.68404 .57725 L
s
.45992 .96203 m .45316 .95487 L .45675 .95857 L 0 .22 0 r
F
.38932 .7804 m .37923 .78004 L .38221 .78001 L 0 .633 .266 r
F
0 g
.38002 .77851 m
.38221 .78001 L
s
.58685 .6002 m .58082 .59579 L .57962 .59862 L 0 1 .525 r
F
.58685 .6002 m .59021 .59331 L .58082 .59579 L F
.58685 .6002 m .60152 .59282 L .59021 .59331 L F
.80126 .82897 m .81337 .83546 L .81782 .83344 L 0 1 .519 r
F
.80126 .82897 m .80628 .83355 L .81337 .83546 L F
0 g
.81278 .84052 m
.81337 .83546 L
s
.8086 .83418 m
.81337 .83546 L
s
.65335 1.15813 m
.6545 1.15953 L
s
.50333 .62371 m .49491 .62079 L .49527 .6221 L 0 1 .394 r
F
.50333 .62371 m .50289 .62083 L .49491 .62079 L F
.50333 .62819 m .50289 .62083 L .4949 .62422 L 0 1 .522 r
F
.50289 .62083 m .50284 .62003 L .50185 .62056 L F
.50289 .62083 m .50185 .62056 L .49491 .62079 L 0 1 .394 r
F
.50289 .62083 m .50185 .62056 L .4949 .62422 L 0 1 .522 r
F
.50289 .62083 m .50284 .62052 L .50185 .62056 L 0 1 .394 r
F
0 g
.4878 .62333 m
.49527 .6221 L
s
.49527 .6221 m
.49792 .62263 L
s
.50289 .62083 m .51376 .61775 L .50284 .62003 L 0 1 .522 r
F
.50333 .62371 m .50902 .62249 L .50289 .62083 L 0 1 .394 r
F
.50333 .62819 m .51373 .62581 L .51628 .62447 L 0 1 .522 r
F
.51483 .62407 m .51628 .62447 L .52166 .62164 L F
.50333 .62371 m .51373 .62456 L .51669 .62446 L 0 1 .394 r
F
.51522 .62409 m .51669 .62446 L .52166 .62429 L F
.50902 .62249 m .52182 .61843 L .51376 .61775 L 0 1 .522 r
F
.50905 .6225 m .52182 .61843 L .50902 .62249 L F
.5124 .6234 m .52182 .61843 L .50899 .62252 L F
.50902 .62249 m .51376 .61775 L .50289 .62083 L F
.50902 .62249 m .51376 .62147 L .50313 .62085 L 0 1 .394 r
F
.50902 .62249 m .50313 .62085 L .50289 .62083 L F
.50333 .62371 m .5124 .6234 L .50902 .62249 L F
.5124 .6234 m .5125 .6234 L .51119 .62306 L F
.5124 .6234 m .51119 .62306 L .50902 .62249 L F
.5124 .6234 m .52166 .62164 L .52182 .61843 L 0 1 .522 r
F
.50333 .62371 m .51638 .62444 L .51499 .62408 L 0 1 .394 r
F
.50333 .62371 m .51483 .62407 L .5124 .6234 L F
.50333 .62819 m .51479 .62409 L .5124 .6234 L 0 1 .522 r
F
.51479 .62409 m .52166 .62164 L .5124 .6234 L F
.50899 .62252 m .50905 .6225 L .50902 .62249 L F
.50333 .62819 m .5124 .6234 L .50899 .62252 L F
.51499 .62408 m .51669 .62446 L .51522 .62409 L 0 1 .394 r
F
.51638 .62444 m .51669 .62446 L .51499 .62408 L F
.50289 .62098 m .50902 .62249 L .50289 .62088 L 0 1 .522 r
F
.50333 .62819 m .50899 .62252 L .50289 .62098 L F
.50899 .62252 m .50902 .62249 L .50289 .62098 L F
.50333 .62819 m .51628 .62447 L .51483 .62407 L F
.5124 .6234 m .52166 .62429 L .52183 .62309 L 0 1 .394 r
F
.51483 .62407 m .52166 .62429 L .5124 .6234 L F
.50902 .62249 m .52183 .62309 L .51376 .62147 L F
.5125 .6234 m .52183 .62309 L .50902 .62249 L F
.50289 .62088 m .50902 .62249 L .50289 .62083 L 0 1 .522 r
F
.50289 .62083 m .51376 .62147 L .50284 .62052 L 0 1 .394 r
F
0 g
.52166 .62164 m
.5293 .62253 L
s
.51551 .62488 m
.52141 .62594 L
s
.39021 .88702 m .38095 .88148 L .38455 .88502 L 0 .752 .451 r
F
0 g
.38455 .88502 m
.38471 .88859 L
s
.45992 .96203 m .451 .95274 L .45316 .95487 L 0 .22 0 r
F
.45992 .96203 m .45173 .95359 L .451 .95274 L F
0 g
.44884 .9503 m
.4519 .95354 L
s
.45992 .96203 m .4549 .95705 L .45173 .95359 L 0 .22 0 r
F
0 g
.4519 .95354 m
.45315 .95487 L
s
.45992 .96203 m .45839 .96082 L .4549 .95705 L 0 .22 0 r
F
.45992 .96203 m .46054 .96295 L .45839 .96082 L F
0 g
.45992 .96203 m
.46215 .9636 L
s
.45675 .95857 m
.45992 .96203 L
s
.33015 .75808 m .32217 .75705 L .32586 .75695 L 0 0 0 r
F
.33015 .75808 m .32103 .75743 L .32217 .75705 L F
.33015 .75808 m .3232 .75784 L .32103 .75743 L F
.33015 .75808 m .3275 .75898 L .3232 .75784 L F
.33015 .75808 m .33106 .76009 L .3275 .75898 L F
.33015 .75808 m .33219 .75971 L .33106 .76009 L F
0 g
.33015 .75808 m
.33152 .752 L
s
.32586 .75695 m
.33015 .75808 L
s
.64864 .79844 m .66213 .76481 L .65557 .7759 L 0 1 .138 r
F
0 g
.65195 .80153 m
.6532 .7983 L
s
.6532 .7983 m
.6539 .79649 L
s
.6539 .79649 m
.65433 .79535 L
s
.66213 .76481 m
.66477 .76283 L
s
.51942 .88251 m .5167 .88031 L .51653 .87734 L 0 .464 0 r
F
0 g
.51447 .87193 m
.51653 .87734 L
s
.51942 .88251 m .52022 .89056 L .5167 .88031 L 0 .464 0 r
F
.50887 .86715 m .51344 .87703 L .50838 .86808 L 0 .264 0 r
F
.51293 .87594 m .51712 .8834 L .51344 .87703 L F
.50887 .86715 m .5154 .88001 L .51246 .87492 L F
.50887 .86715 m .50485 .86114 L .50521 .86082 L F
.50887 .86715 m .50838 .86808 L .50485 .86114 L F
.50887 .86715 m .51695 .88291 L .51697 .88295 L F
.5154 .88001 m .51697 .88295 L .51712 .8834 L F
.50887 .86715 m .51697 .88295 L .5154 .88001 L F
.50887 .86715 m .51341 .87594 L .51695 .88291 L F
.50808 .86627 m .51347 .87382 L .50788 .8651 L 0 0 .157 r
F
.50832 .86774 m .50977 .86945 L .50808 .86627 L F
.50977 .86945 m .51347 .87382 L .50808 .86627 L F
.50838 .86808 m .50877 .86852 L .50832 .86774 L F
.50877 .86852 m .51347 .87382 L .50832 .86774 L F
.51246 .87492 m .51712 .88339 L .51293 .87594 L 0 .264 0 r
F
.5154 .88001 m .51712 .88339 L .51246 .87492 L F
.51712 .88339 m .51712 .8834 L .51293 .87594 L F
.50877 .86852 m .51754 .88139 L .51347 .87382 L 0 0 .157 r
F
.50843 .86814 m .50912 .86913 L .50877 .86852 L F
.50912 .86913 m .51754 .88139 L .50877 .86852 L F
.50838 .86808 m .50847 .86821 L .50843 .86814 L F
.50847 .86821 m .51754 .88139 L .50843 .86814 L F
.52022 .89056 m .52024 .89071 L .52012 .89037 L 0 .464 0 r
F
.52022 .89056 m .52012 .89037 L .5167 .88031 L F
.51942 .88251 m .5248 .90163 L .52024 .89071 L F
.51942 .88251 m .52698 .90552 L .52414 .89928 L F
.52025 .89074 m .52614 .90317 L .52105 .89207 L 0 0 .108 r
F
.52024 .89071 m .52033 .8909 L .52025 .89074 L F
.52033 .8909 m .52614 .90317 L .52025 .89074 L F
.51942 .88251 m .52771 .90682 L .52698 .90552 L 0 .464 0 r
F
.52414 .89928 m .52698 .90552 L .5248 .90163 L F
.51942 .88251 m .52701 .9028 L .52771 .90682 L F
.51942 .88251 m .52346 .89237 L .52701 .9028 L F
0 g
.51787 .87665 m
.51942 .88251 L
s
.51653 .87734 m
.51942 .88251 L
s
.81209 .91309 m .81805 .89794 L .81352 .90099 L 0 1 .429 r
F
.80074 .92148 m .81209 .91309 L .80673 .90576 L 0 1 .418 r
F
0 g
.6249 .52139 m
.63582 .52875 L
s
.61625 .51623 m
.6249 .52139 L
s
.26797 .84915 m .25675 .84905 L .26116 .85046 L 0 1 .504 r
F
0 g
.26116 .85046 m
.26175 .85436 L
s
.53735 1.04418 m .54606 1.09752 L .54105 1.06509 L 0 .127 .181 r
F
0 g
.53704 1.05225 m
.53726 1.05349 L
s
.53735 1.04418 m .5499 1.12652 L .54606 1.09752 L 0 .127 .181 r
F
.53735 1.04418 m .54997 1.13248 L .5499 1.12652 L F
.53735 1.04418 m .5462 1.11112 L .54997 1.13248 L F
.53735 1.04418 m .54116 1.07699 L .5462 1.11112 L F
.53735 1.04418 m .53738 1.04843 L .54116 1.07699 L F
0 g
.53962 1.04272 m
.54062 1.04948 L
s
.53724 1.0436 m
.53735 1.04418 L
s
.53735 1.04828 m
.53738 1.04843 L
s
.53944 1.04361 m
.54062 1.04948 L
s
.53815 1.04397 m
.5386 1.0472 L
s
.5386 1.0472 m
.53861 1.04733 L
s
.53781 1.04678 m
.53858 1.05113 L
s
.53737 1.04432 m
.53781 1.04678 L
s
.53735 1.04418 m
.53737 1.04432 L
s
.7173 .62715 m .71508 .6138 L .71195 .61373 L 0 .602 .401 r
F
0 g
.70132 .60228 m
.71195 .61373 L
s
.7173 .62715 m .7254 .62705 L .71508 .6138 L 0 .602 .401 r
F
.7173 .62715 m .73603 .64467 L .7254 .62705 L F
0 g
.71195 .61373 m
.7173 .62715 L
s
.70842 .61494 m
.7173 .62715 L
s
.69272 .89375 m
.6933 .89338 L
s
.68734 .89615 m
.68874 .89552 L
s
.68874 .89552 m
.69272 .89375 L
s
.76261 1.02825 m .7706 1.01138 L .76606 1.01716 L 0 1 .353 r
F
.76062 1.00043 m .7706 1.01138 L .77313 .99815 L 0 1 .364 r
F
.76062 1.00043 m .76606 1.01716 L .7706 1.01138 L F
0 g
.7706 1.01138 m
.77395 1.014 L
s
.42717 .6499 m .41659 .64662 L .41843 .64988 L 0 1 .517 r
F
.42717 .6499 m .42291 .64172 L .41659 .64662 L F
0 g
.41799 .65026 m
.41843 .64988 L
s
.41279 .65478 m
.41799 .65026 L
s
.42717 .6499 m .4332 .63845 L .42291 .64172 L 0 1 .517 r
F
.42717 .6499 m .44195 .63848 L .4332 .63845 L F
.42717 .6499 m .44331 .64179 L .44195 .63848 L F
.42717 .6499 m .43697 .64669 L .44331 .64179 L F
0 g
.4212 .65486 m
.42717 .6499 L
s
.41843 .64988 m
.42717 .6499 L
s
.32996 .65214 m .31711 .65314 L .32029 .65527 L 0 1 .53 r
F
0 g
.31604 .66214 m
.32029 .65527 L
s
.40856 .90708 m .40305 .89683 L .39939 .897 L 0 .485 .398 r
F
.40856 .90708 m .40839 .90005 L .40305 .89683 L F
.40856 .90708 m .41185 .90451 L .40839 .90005 L F
.40856 .90708 m .41192 .90752 L .41185 .90451 L F
0 g
.40323 .90386 m
.40856 .90708 L
s
.55295 1.16103 m .5595 1.16648 L .55975 1.17169 L 0 .632 .058 r
F
0 g
.5595 1.16648 m
.56386 1.17338 L
s
.31455 .75866 m
.31665 .75642 L
s
.32139 .75722 m
.32217 .75705 L
s
.31455 .75866 m
.32139 .75722 L
s
.5571 .61031 m .5503 .60608 L .54961 .60911 L 0 1 .526 r
F
.5571 .61031 m .5592 .60289 L .5503 .60608 L F
.5571 .61031 m .57036 .60165 L .5592 .60289 L F
.5571 .61031 m .57783 .60287 L .57036 .60165 L F
0 g
.54859 .61367 m
.5571 .61031 L
s
.57783 .60287 m
.58685 .6002 L
s
.53347 1.06879 m .54133 1.1165 L .53707 1.08953 L 0 .079 .172 r
F
.53347 1.06879 m .54388 1.13431 L .54133 1.1165 L F
.53347 1.06879 m .543 1.13092 L .54388 1.13431 L F
.53347 1.06879 m .53936 1.10997 L .543 1.13092 L F
0 g
.53728 1.11711 m
.53794 1.12 L
s
.53347 1.06879 m .53541 1.08554 L .53936 1.10997 L 0 .079 .172 r
F
0 g
.53347 1.06879 m
.53349 1.06891 L
s
.53349 1.06891 m
.53353 1.06915 L
s
.53353 1.06915 m
.53386 1.07105 L
s
.53346 1.08006 m
.53351 1.08031 L
s
.53342 1.06845 m
.53347 1.06879 L
s
.53349 1.08017 m
.53351 1.08031 L
s
.53339 1.07949 m
.53349 1.08017 L
s
.53486 1.10666 m
.53728 1.11711 L
s
.53419 1.09703 m
.53467 1.09964 L
s
.53408 1.09646 m
.53419 1.09703 L
s
.53367 1.09423 m
.53408 1.09646 L
s
.5339 1.0982 m
.53426 1.09974 L
s
.53451 1.10085 m
.53545 1.10493 L
s
.53426 1.09974 m
.53451 1.10085 L
s
.53293 1.09022 m
.53367 1.09423 L
s
.74739 .86054 m .76245 .85645 L .75813 .85388 L 0 1 .446 r
F
0 g
.76245 .85645 m
.76899 .85672 L
s
.76236 .86007 m
.76245 .85645 L
s
.54634 1.14823 m .55031 1.15218 L .55295 1.16103 L 0 .536 .026 r
F
0 g
.54659 1.14222 m
.55031 1.15218 L
s
.55008 1.14701 m
.55031 1.15218 L
s
.74231 .69561 m
.74675 .7027 L
s
.74675 .7027 m
.74722 .70346 L
s
.7482 .70503 m
.7483 .70519 L
s
.74876 .70592 m
.7506 .70887 L
s
.74231 .69561 m
.74448 .70453 L
s
.74448 .70453 m
.74472 .70555 L
s
.74472 .70555 m
.74475 .70567 L
s
.74475 .70567 m
.74485 .70607 L
s
.74485 .70607 m
.74504 .70687 L
s
.74555 .70896 m
.74559 .70911 L
s
.74559 .70911 m
.74565 .70935 L
s
.74575 .70977 m
.74623 .71178 L
s
.39021 .88702 m .38142 .87761 L .38095 .88148 L 0 .752 .451 r
F
0 g
.37552 .88025 m
.38095 .88148 L
s
.80126 .82897 m .81782 .83344 L .81728 .82818 L 0 1 .519 r
F
0 g
.81782 .83344 m
.824 .8358 L
s
.51322 1.00578 m
.51322 1.00581 L
s
.43876 .93847 m
.43962 .94025 L
s
.52437 1.01055 m .5275 1.04529 L .52533 1.02572 L 0 .641 .163 r
F
0 g
.52653 1.00807 m
.52672 1.01042 L
s
.52735 1.00665 m
.52823 1.01089 L
s
.52437 1.01055 m .53015 1.06004 L .5275 1.04529 L 0 .641 .163 r
F
.52437 1.01055 m .53148 1.06 L .53015 1.06004 L F
.52437 1.01055 m .5305 1.04461 L .53148 1.06 L F
.52437 1.01055 m .52787 1.02427 L .5305 1.04461 L F
0 g
.52893 1.00793 m
.53024 1.02067 L
s
.52982 1.01862 m
.53024 1.02067 L
s
.5221 1.00012 m
.52437 1.01055 L
s
.52823 1.01089 m
.52982 1.01862 L
s
.74362 .80079 m .75391 .79698 L .74592 .77723 L 0 .747 .325 r
F
0 g
.74327 .75722 m
.74592 .77723 L
s
.68753 .70581 m .70365 .68756 L .69521 .69375 L 0 1 .189 r
F
0 g
.70365 .68756 m
.71022 .68196 L
s
.70365 .68756 m
.70745 .68612 L
s
.69066 .80773 m
.69704 .78318 L
s
.69035 .80889 m
.69066 .80773 L
s
.39803 .65007 m .38663 .64733 L .38895 .65034 L 0 1 .523 r
F
0 g
.38377 .65498 m
.38895 .65034 L
s
.45022 .80493 m
.45595 .80864 L
s
.45022 .80493 m
.4524 .80582 L
s
.64227 .96286 m
.64381 .92914 L
s
.64132 .98385 m
.64227 .96286 L
s
.64381 .92914 m
.64492 .90461 L
s
.76062 1.00043 m .77313 .99815 L .77195 .98627 L 0 1 .364 r
F
0 g
.7706 1.01138 m
.77313 .99815 L
s
.77313 .99815 m
.77743 1.00328 L
s
.54376 1.01421 m .55048 1.05815 L .54631 1.03628 L 0 .537 .185 r
F
.54376 1.01421 m .55434 1.06291 L .55048 1.05815 L F
.54376 1.01421 m .55528 1.04729 L .55434 1.06291 L F
.54376 1.01421 m .55268 1.02512 L .55528 1.04729 L F
0 g
.5419 1.01193 m
.54376 1.01421 L
s
.5434 1.02548 m
.54445 1.02607 L
s
.54445 1.02607 m
.54517 1.02647 L
s
.54376 1.01421 m
.54417 1.01775 L
s
.33392 .85722 m .32432 .8535 L .32363 .85809 L 0 1 .536 r
F
0 g
.31774 .85966 m
.32363 .85809 L
s
.47111 .9737 m .46264 .96614 L .46364 .96592 L 0 .343 0 r
F
.47111 .9737 m .46481 .96947 L .46264 .96614 L F
.47111 .9737 m .46879 .97425 L .46481 .96947 L F
.47111 .9737 m .47193 .97726 L .46879 .97425 L F
.47111 .9737 m .47292 .97703 L .47193 .97726 L F
0 g
.47111 .9737 m
.47237 .97269 L
s
.46713 .96895 m
.47111 .9737 L
s
.39803 .65007 m .39259 .64244 L .38663 .64733 L 0 1 .523 r
F
.39803 .65007 m .40285 .63894 L .39259 .64244 L F
.39803 .65007 m .41196 .63867 L .40285 .63894 L F
.39803 .65007 m .41381 .64181 L .41196 .63867 L F
.39803 .65007 m .40784 .6467 L .41381 .64181 L F
0 g
.39241 .65497 m
.39803 .65007 L
s
.38895 .65034 m
.39803 .65007 L
s
.77812 .94087 m .79194 .94418 L .78942 .93068 L 0 1 .391 r
F
0 g
.79041 .95752 m
.79194 .94418 L
s
.79194 .94418 m
.79725 .95138 L
s
.46054 .96295 m
.46364 .96591 L
s
.69323 .89318 m
.6933 .89338 L
s
.69317 .89303 m
.69323 .89318 L
s
.68678 .87623 m
.69131 .88814 L
s
.69131 .88814 m
.69296 .89248 L
s
.69296 .89248 m
.69317 .89303 L
s
.68678 .87623 m
.68733 .89559 L
s
.68733 .89559 m
.68734 .89614 L
s
.64493 .90485 m .65007 .94849 L .64646 .95772 L 0 .703 .206 r
F
0 g
.64642 .95627 m
.64646 .95772 L
s
.64493 .90485 m .65494 .92333 L .65007 .94849 L 0 .703 .206 r
F
0 g
.64493 .90485 m
.64642 .95627 L
s
.43697 .64669 m
.44535 .64683 L
s
.73261 .65858 m
.73261 .65858 L
s
.73261 .65858 m
.73261 .65858 L
s
.73261 .65858 m
.73262 .65858 L
s
.70125 .84654 m .7061 .82807 L .70115 .82976 L 0 .816 .339 r
F
0 g
.70115 .82976 m
.70125 .84653 L
s
.70124 .84653 m
.70124 .84654 L
s
.69461 .83156 m
.70124 .84653 L
s
.69903 .82648 m
.70115 .82976 L
s
.73262 .65863 m
.733 .65922 L
s
.73261 .65858 m
.73262 .65863 L
s
.73261 .65858 m
.73261 .65858 L
s
.73255 .65844 m
.73261 .65858 L
s
.72755 .64514 m
.731 .65431 L
s
.73196 .65687 m
.73255 .65844 L
s
.48052 .83055 m .47419 .82372 L .47551 .82513 L 0 .081 .176 r
F
0 g
.47753 .82679 m
.48052 .83055 L
s
.47406 .82386 m
.47544 .82507 L
s
.65656 .54539 m
.66739 .55482 L
s
.64864 .53838 m
.65656 .54539 L
s
.77812 .94087 m .78058 .95472 L .78585 .96185 L 0 1 .391 r
F
0 g
.78332 .97394 m
.78585 .96185 L
s
.27201 .65889 m
.27678 .65897 L
s
.29009 .65784 m .28149 .65236 L .27678 .65897 L 0 1 .532 r
F
0 g
.45839 .96082 m
.46054 .96295 L
s
.69887 .79539 m
.69906 .79683 L
s
.67996 .73673 m
.68332 .74633 L
s
.74189 .85965 m
.74567 .85204 L
s
.38932 .7804 m .38217 .7796 L .37923 .78004 L 0 .633 .266 r
F
0 g
.37232 .77899 m
.37923 .78004 L
s
.38932 .7804 m .38909 .77898 L .38217 .7796 L 0 .633 .266 r
F
.38932 .7804 m .39623 .77937 L .38909 .77898 L F
.38932 .7804 m .39882 .78052 L .39623 .77937 L F
.38932 .7804 m .39585 .78096 L .39882 .78052 L F
.26797 .84915 m .25709 .84555 L .25675 .84905 L 0 1 .504 r
F
0 g
.25064 .85096 m
.25675 .84905 L
s
.32996 .65214 m .3223 .64692 L .31711 .65314 L 0 1 .53 r
F
0 g
.30784 .65664 m
.31711 .65314 L
s
.32996 .65214 m .33242 .64076 L .3223 .64692 L 0 1 .53 r
F
.32996 .65214 m .34212 .63761 L .33242 .64076 L F
.32996 .65214 m .34492 .63959 L .34212 .63761 L F
.32996 .65214 m .3397 .64582 L .34492 .63959 L F
0 g
.32506 .65844 m
.32996 .65214 L
s
.32029 .65527 m
.32996 .65214 L
s
.38142 .87761 m .37193 .87284 L .37554 .87626 L 0 .844 .459 r
F
0 g
.37552 .88025 m
.37554 .87626 L
s
.51373 .62581 m
.51616 .62453 L
s
.51616 .62453 m
.51622 .6245 L
s
.51622 .6245 m
.51628 .62447 L
s
.51971 .62266 m
.52166 .62164 L
s
.51373 .62581 m
.52141 .62649 L
s
.52931 .62678 m .52183 .62309 L .52166 .62429 L 0 .892 .382 r
F
0 g
.51628 .62447 m
.52166 .62429 L
s
.52931 .62678 m .53013 .62387 L .52183 .62309 L 0 .892 .382 r
F
.52931 .62678 m .54102 .62612 L .53013 .62387 L F
.52931 .62678 m .54867 .62861 L .54102 .62612 L F
.52931 .62678 m .54798 .62969 L .54867 .62861 L F
.52931 .62678 m .53968 .6289 L .54798 .62969 L F
0 g
.53968 .6289 m
.54694 .63112 L
s
.52231 .62603 m
.52931 .62678 L
s
.52166 .62429 m
.52931 .62678 L
s
.51473 1.00754 m .51427 1.0285 L .5141 1.01605 L 0 .617 .135 r
F
0 g
.51322 1.00581 m
.5141 1.01605 L
s
.51473 1.00754 m .51553 1.04017 L .51427 1.0285 L 0 .617 .135 r
F
.51473 1.00754 m .51705 1.04321 L .51553 1.04017 L F
.51473 1.00754 m .51768 1.03459 L .51705 1.04321 L F
.51473 1.00754 m .517 1.02014 L .51768 1.03459 L F
.51473 1.00754 m .51574 1.00858 L .517 1.02014 L F
0 g
.51642 1.00299 m
.51718 1.00946 L
s
.51574 1.00858 m
.51582 1.00556 L
s
.51385 .99744 m
.51473 1.00754 L
s
.5141 1.01605 m
.51473 1.00754 L
s
.29009 .65784 m .29134 .64573 L .28149 .65236 L 0 1 .532 r
F
0 g
.27698 .65398 m
.28165 .64816 L
s
.27678 .65897 m
.28149 .65236 L
s
.29009 .65784 m .30115 .64237 L .29134 .64573 L 0 1 .532 r
F
.29009 .65784 m .30435 .64453 L .30115 .64237 L F
.29009 .65784 m .2996 .65117 L .30435 .64453 L F
0 g
.28563 .66454 m
.29009 .65784 L
s
.28033 .66118 m
.29009 .65784 L
s
.39939 .897 m .39417 .88617 L .39021 .88703 L 0 .632 .432 r
F
0 g
.39008 .89051 m
.39021 .88703 L
s
.39939 .897 m .39973 .88887 L .39417 .88617 L 0 .632 .432 r
F
.39939 .897 m .4032 .89335 L .39973 .88887 L F
.39939 .897 m .40305 .89683 L .4032 .89335 L F
0 g
.39384 .89429 m
.39939 .897 L
s
.39939 .897 m
.39947 .90002 L
s
.66451 .91933 m .67735 .89814 L .67765 .90433 L 0 .202 .098 r
F
0 g
.67331 .91439 m
.67331 .90928 L
s
.67331 .91571 m
.67331 .91456 L
s
.6733 .92027 m
.67331 .91707 L
s
.67056 .91242 m
.6716 .91863 L
s
.66726 .8939 m
.66765 .90261 L
s
.67735 .89814 m
.67764 .89936 L
s
.67764 .89936 m
.67841 .90266 L
s
.67841 .90266 m
.67871 .90393 L
s
.67871 .90393 m
.67885 .90452 L
s
.28871 .75654 m .27651 .75675 L .28048 .75794 L 0 1 .52 r
F
0 g
.27891 .76262 m
.28048 .75794 L
s
.33991 .76371 m
.34151 .76511 L
s
.52208 1.01157 m .52301 1.01133 L .52533 1.02572 L 0 .64 .158 r
F
0 g
.52225 1.00193 m
.52301 1.01133 L
s
.62271 .58622 m .64623 .58271 L .63907 .58049 L 0 1 .526 r
F
0 g
.64623 .58271 m
.65617 .58189 L
s
.75131 1.04485 m .76261 1.02825 L .75926 1.02655 L 0 1 .32 r
F
.24183 .75852 m .23844 .74887 L .23145 .75492 L 0 1 .542 r
F
0 g
.2294 .76045 m
.23145 .75492 L
s
.24183 .75852 m .24669 .74557 L .23844 .74887 L 0 1 .542 r
F
.24183 .75852 m .25068 .74723 L .24669 .74557 L F
.24183 .75852 m .24858 .75279 L .25068 .74723 L F
0 g
.23362 .7618 m
.24183 .75852 L
s
.23995 .76375 m
.24183 .75852 L
s
.34562 .77334 m
.34762 .77043 L
s
.34561 .77335 m
.34562 .77334 L
s
.75813 .85388 m .77338 .85051 L .76889 .84739 L 0 1 .474 r
F
0 g
.77338 .85051 m
.78007 .85122 L
s
.77338 .85051 m
.77342 .8545 L
s
.48052 .83055 m .47758 .82681 L .47419 .82372 L 0 .081 .176 r
F
.48052 .83055 m .48344 .83237 L .47758 .82681 L F
.48052 .83055 m .48931 .83951 L .48847 .83781 L F
.48052 .83055 m .48589 .83639 L .48931 .83951 L F
.33392 .85722 m .32916 .84886 L .32432 .8535 L 0 1 .536 r
F
.33392 .85722 m .33556 .84648 L .32916 .84886 L F
.33392 .85722 m .33924 .84795 L .33556 .84648 L F
.33392 .85722 m .33853 .85255 L .33924 .84795 L F
0 g
.33339 .86208 m
.33392 .85722 L
s
.32754 .85959 m
.33392 .85722 L
s
.62874 .6746 m .63786 .68301 L .64668 .68887 L 0 .704 .447 r
F
0 g
.63786 .68301 m
.64272 .68948 L
s
.62874 .6746 m .62574 .66713 L .62354 .66779 L 0 .704 .447 r
F
.62874 .6746 m .63457 .67299 L .62574 .66713 L F
.62874 .6746 m .64414 .68146 L .63457 .67299 L F
.62874 .6746 m .64933 .68827 L .64414 .68146 L F
.62874 .6746 m .64668 .68887 L .64933 .68827 L F
0 g
.62025 .66852 m
.62874 .6746 L
s
.65112 .69706 m .64933 .68827 L .64668 .68887 L 0 .716 .443 r
F
0 g
.63786 .68301 m
.64668 .68887 L
s
.65112 .69706 m .65805 .69553 L .64933 .68827 L 0 .716 .443 r
F
.65112 .69706 m .66703 .70581 L .65805 .69553 L F
.65112 .69706 m .67146 .71401 L .66703 .70581 L F
.65112 .69706 m .6684 .71465 L .67146 .71401 L F
.65112 .69706 m .65968 .70739 L .6684 .71465 L F
0 g
.64272 .68948 m
.65112 .69706 L
s
.64668 .68887 m
.65112 .69706 L
s
.65968 .70739 m
.66381 .71532 L
s
.38142 .87761 m .37262 .86839 L .37193 .87284 L 0 .844 .459 r
F
0 g
.36631 .87225 m
.37193 .87284 L
s
.51574 1.00858 m
.51582 1.00933 L
s
.51582 1.00933 m
.51616 1.01244 L
s
.81427 .8715 m .82939 .89069 L .82965 .87835 L 0 1 .434 r
F
.81427 .8715 m .82485 .89353 L .82939 .89069 L F
0 g
.82939 .89069 m
.83485 .89823 L
s
.39276 .63389 m .38096 .63391 L .38331 .63558 L 0 1 .522 r
F
0 g
.37844 .6402 m
.38331 .63558 L
s
.39276 .63389 m .38723 .62972 L .38096 .63391 L 0 1 .522 r
F
.39276 .63389 m .39796 .62579 L .38723 .62972 L F
.39276 .63389 m .40743 .62409 L .39796 .62579 L F
.39276 .63389 m .40931 .62577 L .40743 .62409 L F
.39276 .63389 m .40302 .62997 L .40931 .62577 L F
0 g
.38683 .63794 m
.39276 .63389 L
s
.38331 .63558 m
.39276 .63389 L
s
.60511 .65669 m .6147 .66332 L .62354 .66779 L 0 .709 .433 r
F
0 g
.6147 .66332 m
.62025 .66852 L
s
.80074 .92148 m .80673 .90576 L .80221 .90906 L 0 1 .418 r
F
.78942 .93068 m .80074 .92148 L .79543 .91424 L 0 1 .405 r
F
.53475 1.06981 m .53426 1.06959 L .53707 1.08953 L 0 .09 .174 r
F
0 g
.53426 1.06959 m
.53432 1.06998 L
s
.53432 1.06998 m
.53437 1.07036 L
s
.53437 1.07036 m
.5344 1.07056 L
s
.5344 1.07056 m
.53444 1.07082 L
s
.53323 1.05792 m
.53389 1.06146 L
s
.5341 1.06869 m
.53426 1.06959 L
s
.53208 1.06688 m
.53457 1.08083 L
s
.27884 .85256 m .27267 .84598 L .26797 .84915 L 0 1 .507 r
F
.27884 .85256 m .27938 .84462 L .27267 .84598 L F
.27884 .85256 m .2836 .84599 L .27938 .84462 L F
.27884 .85256 m .28336 .84939 L .2836 .84599 L F
0 g
.27216 .85391 m
.27884 .85256 L
s
.27876 .85593 m
.27884 .85256 L
s
.53601 .91143 m .5356 .92231 L .53437 .91129 L 0 .82 .088 r
F
0 g
.53437 .91129 m
.53579 .91141 L
s
.53199 .90101 m
.53437 .91129 L
s
.53601 .91143 m .53949 .94242 L .5356 .92231 L 0 .82 .088 r
F
.53601 .91143 m .54345 .95821 L .53949 .94242 L F
.53601 .91143 m .54509 .9583 L .54345 .95821 L F
.53601 .91143 m .54332 .94267 L .54509 .9583 L F
.53601 .91143 m .53943 .92262 L .54332 .94267 L F
0 g
.54067 .91458 m
.54321 .93214 L
s
.53594 .91103 m
.53601 .91143 L
s
.53579 .91141 m
.53601 .91143 L
s
.53943 .92262 m
.54067 .91458 L
s
.42976 .92737 m
.43039 .9296 L
s
.60511 .65669 m .60092 .65035 L .5992 .65113 L 0 .709 .433 r
F
.60511 .65669 m .60976 .65483 L .60092 .65035 L F
.60511 .65669 m .61983 .66158 L .60976 .65483 L F
.60511 .65669 m .62574 .66713 L .61983 .66158 L F
.60511 .65669 m .62354 .66779 L .62574 .66713 L F
0 g
.6147 .66332 m
.62354 .66779 L
s
.59663 .65206 m
.60511 .65669 L
s
.62354 .66779 m
.62874 .6746 L
s
.37766 .64766 m
.38663 .64733 L
s
.70277 .88862 m .70717 .8848 L .70321 .88743 L 0 .83 .205 r
F
.70277 .88862 m .71279 .88262 L .70717 .8848 L F
0 g
.70277 .88862 m
.70321 .88743 L
s
.70722 .88461 m
.70813 .88129 L
s
.70717 .8848 m
.70722 .88461 L
s
.69859 .89051 m
.70277 .88862 L
s
.69727 .89111 m
.69831 .89064 L
s
.69837 .89061 m
.69859 .89051 L
s
.55513 .63312 m .54867 .62861 L .54798 .62969 L 0 .793 .387 r
F
0 g
.53968 .6289 m
.54798 .62969 L
s
.55513 .63312 m .55725 .63054 L .54867 .62861 L 0 .793 .387 r
F
.55513 .63312 m .56799 .63418 L .55725 .63054 L F
.55513 .63312 m .57514 .63761 L .56799 .63418 L F
0 g
.56585 .63684 m
.57211 .63972 L
s
.55513 .63312 m .57392 .63854 L .57514 .63761 L 0 .793 .387 r
F
.55513 .63312 m .56535 .63661 L .57392 .63854 L F
0 g
.54694 .63112 m
.55513 .63312 L
s
.54798 .62969 m
.55513 .63312 L
s
.56535 .63661 m
.56585 .63684 L
s
.52208 1.01157 m .52434 1.04348 L .52265 1.0253 L 0 .64 .158 r
F
.52208 1.01157 m .52668 1.05807 L .52434 1.04348 L F
.52208 1.01157 m .52809 1.05922 L .52668 1.05807 L F
.52208 1.01157 m .5275 1.04529 L .52809 1.05922 L F
.52208 1.01157 m .52533 1.02572 L .5275 1.04529 L F
0 g
.52525 1.00974 m
.5262 1.01501 L
s
.5262 1.01501 m
.52787 1.02427 L
s
.52013 1.00082 m
.52208 1.01157 L
s
.52672 1.01042 m
.52731 1.01747 L
s
.52731 1.01747 m
.52787 1.02427 L
s
.73527 .65506 m
.73549 .65534 L
s
.72755 .64514 m
.73339 .65265 L
s
.68551 .57462 m
.68558 .57465 L
s
.68558 .57465 m
.68669 .57512 L
s
.58049 .64298 m .59045 .64797 L .5992 .65113 L 0 .735 .408 r
F
0 g
.59045 .64797 m
.59663 .65206 L
s
.451 .95274 m .44416 .94487 L .44776 .949 L 0 0 .133 r
F
.81427 .8715 m .81837 .88531 L .82485 .89353 L 0 1 .434 r
F
0 g
.82346 .90538 m
.82485 .89353 L
s
.58049 .64298 m .57514 .63761 L .57392 .63854 L 0 .735 .408 r
F
0 g
.56535 .63661 m
.57392 .63854 L
s
.58049 .64298 m .58389 .64077 L .57514 .63761 L 0 .735 .408 r
F
.58049 .64298 m .59436 .64591 L .58389 .64077 L F
.58049 .64298 m .60092 .65035 L .59436 .64591 L F
.58049 .64298 m .5992 .65113 L .60092 .65035 L F
0 g
.59045 .64797 m
.5992 .65113 L
s
.57392 .63854 m
.58049 .64298 L
s
.57211 .63972 m
.58049 .64298 L
s
.5992 .65113 m
.60511 .65669 L
s
.70125 .84654 m .7138 .84087 L .7061 .82807 L 0 .816 .339 r
F
.70125 .84654 m .71912 .85964 L .7138 .84087 L F
.70125 .84654 m .71403 .8801 L .71922 .87647 L F
0 g
.71872 .84902 m
.7189 .85887 L
s
.70125 .84654 m .70632 .86725 L .71403 .8801 L 0 .816 .339 r
F
0 g
.70813 .88129 m
.7102 .87371 L
s
.7069 .87812 m
.70716 .88479 L
s
.70125 .84653 m
.70125 .84654 L
s
.70672 .87355 m
.7069 .87812 L
s
.70648 .86751 m
.70672 .87355 L
s
.52597 .89375 m
.52788 .90201 L
s
.52366 .89248 m
.52597 .89375 L
s
.52356 .89243 m
.52366 .89248 L
s
.52346 .89237 m
.52356 .89243 L
s
.4833 .98632 m .47663 .9808 L .47976 .98249 L 0 .425 .039 r
F
0 g
.47976 .98249 m
.48102 .98146 L
s
.51723 1.00988 m .51768 1.03459 L .517 1.02014 L 0 .627 .144 r
F
0 g
.517 1.02014 m
.51704 1.01845 L
s
.51616 1.01244 m
.517 1.02014 L
s
.51723 1.00988 m .51932 1.04749 L .51768 1.03459 L 0 .627 .144 r
F
.51723 1.00988 m .52083 1.05014 L .51932 1.04749 L F
.51723 1.00988 m .52105 1.03974 L .52083 1.05014 L F
0 g
.51809 1.00052 m
.5181 1.00059 L
s
.51723 1.00988 m .51986 1.02332 L .52105 1.03974 L 0 .627 .144 r
F
0 g
.5181 1.00059 m
.51964 1.01092 L
s
.52029 1.00403 m
.52061 1.01045 L
s
.51723 1.00988 m .51822 1.01058 L .51986 1.02332 L 0 .627 .144 r
F
0 g
.51718 1.00946 m
.51723 1.00988 L
s
.51704 1.01845 m
.51723 1.00988 L
s
.51815 1.00514 m
.51822 1.01058 L
s
.74362 .80079 m .76052 .8244 L .75391 .79698 L 0 .747 .325 r
F
.75774 .8438 m .76851 .8382 L .76231 .8471 L 0 .03 .052 r
F
.74362 .80079 m .76231 .8471 L .76052 .8244 L 0 .747 .325 r
F
.75774 .8438 m .76231 .8471 L .75807 .84986 L 0 .03 .052 r
F
.74362 .80079 m .75806 .84986 L .76231 .8471 L 0 .747 .325 r
F
.74362 .80079 m .75004 .82997 L .75806 .84986 L F
0 g
.73577 .77952 m
.74362 .80079 L
s
.74186 .77824 m
.74362 .80079 L
s
.43935 .79786 m .43091 .79297 L .43306 .79447 L 0 .414 .259 r
F
0 g
.43251 .79433 m
.43306 .79447 L
s
.50333 .62819 m .4949 .62422 L .49525 .62751 L 0 1 .522 r
F
0 g
.49578 .63249 m
.50333 .62819 L
s
.451 .95274 m .44208 .94233 L .44416 .94487 L 0 0 .133 r
F
.451 .95274 m .44291 .94307 L .44208 .94233 L F
0 g
.43962 .94025 m
.44247 .94315 L
s
.451 .95274 m .44616 .9468 L .44291 .94307 L 0 0 .133 r
F
0 g
.44247 .94315 m
.44416 .94487 L
s
.451 .95274 m .44965 .95105 L .44616 .9468 L 0 0 .133 r
F
.451 .95274 m .45173 .95359 L .44965 .95105 L F
0 g
.45117 .95291 m
.45316 .95487 L
s
.49584 .8486 m .49058 .84149 L .49145 .84243 L 0 0 .14 r
F
0 g
.48865 .83891 m
.49145 .84243 L
s
.51969 1.01129 m .52066 1.01156 L .52265 1.0253 L 0 .635 .152 r
F
0 g
.52061 1.01045 m
.52066 1.01156 L
s
.67204 .72439 m .67146 .71401 L .6684 .71465 L 0 .745 .426 r
F
0 g
.6684 .71465 m
.67204 .72439 L
s
.65968 .70739 m
.6684 .71465 L
s
.66381 .71532 m
.67204 .72439 L
s
.51822 1.01058 m
.51832 1.01129 L
s
.51832 1.01129 m
.51849 1.01262 L
s
.51969 1.01129 m .52105 1.03974 L .51986 1.02332 L 0 .635 .152 r
F
.51969 1.01129 m .52305 1.05366 L .52105 1.03974 L F
.51969 1.01129 m .52452 1.05569 L .52305 1.05366 L F
.51969 1.01129 m .52434 1.04348 L .52452 1.05569 L F
0 g
.52437 1.01055 m
.52533 1.02572 L
s
.51969 1.01129 m .52265 1.0253 L .52434 1.04348 L 0 .635 .152 r
F
0 g
.52301 1.01133 m
.52348 1.01425 L
s
.52348 1.01425 m
.52533 1.02572 L
s
.52208 1.01157 m
.52265 1.0253 L
s
.51969 1.01129 m
.51986 1.02332 L
s
.51849 1.01262 m
.51986 1.02332 L
s
.51964 1.01092 m
.51969 1.01129 L
s
.52066 1.01156 m
.5209 1.01319 L
s
.5209 1.01319 m
.52265 1.0253 L
s
.36153 .64182 m .3491 .64247 L .35189 .64434 L 0 1 .531 r
F
0 g
.35139 .64497 m
.35189 .64434 L
s
.68672 .57615 m
.69735 .58759 L
s
.68554 .57466 m
.68672 .57615 L
s
.68551 .57462 m
.68554 .57466 L
s
.6796 .56711 m
.68551 .57462 L
s
.39021 .88702 m .38566 .876 L .38142 .87761 L 0 .752 .451 r
F
.39021 .88702 m .39133 .878 L .38566 .876 L F
.39021 .88702 m .39465 .8823 L .39133 .878 L F
.39021 .88702 m .39417 .88616 L .39465 .8823 L F
0 g
.38455 .88502 m
.39021 .88702 L
s
.4833 .98632 m .47577 .98239 L .47663 .9808 L 0 .425 .039 r
F
.4833 .98632 m .47775 .98622 L .47577 .98239 L F
.4833 .98632 m .4813 .99006 L .47775 .98622 L F
.4833 .98632 m .48404 .99134 L .4813 .99006 L F
.4833 .98632 m .48489 .98973 L .48404 .99134 L F
0 g
.4833 .98632 m
.48446 .98371 L
s
.47976 .98249 m
.4833 .98632 L
s
.80312 .87871 m .81805 .89794 L .81837 .88531 L 0 1 .423 r
F
.80312 .87871 m .81352 .90099 L .81805 .89794 L F
0 g
.81805 .89794 m
.82346 .90538 L
s
.46264 .96614 m .4549 .95706 L .45839 .96082 L 0 .218 0 r
F
0 g
.45839 .96082 m
.4584 .96082 L
s
.36153 .64182 m .35489 .63719 L .3491 .64247 L 0 1 .531 r
F
.36153 .64182 m .36541 .63202 L .35489 .63719 L F
.36153 .64182 m .37508 .6295 L .36541 .63202 L F
.36153 .64182 m .37744 .63131 L .37508 .6295 L F
.36153 .64182 m .37162 .63659 L .37744 .63131 L F
0 g
.35606 .64702 m
.36153 .64182 L
s
.35189 .64434 m
.36153 .64182 L
s
.25709 .84555 m .24573 .84543 L .25014 .8469 L 0 1 .505 r
F
0 g
.25014 .8469 m
.25064 .85096 L
s
.37262 .86839 m .3629 .86463 L .36652 .86786 L 0 .915 .459 r
F
0 g
.36631 .87225 m
.36652 .86786 L
s
.50521 .86082 m
.50796 .86558 L
s
.5021 .85519 m
.50521 .86082 L
s
.50574 .85891 m
.50839 .8659 L
s
.59021 .59331 m .61126 .59051 L .61296 .58791 L 0 1 .528 r
F
.59021 .59331 m .60152 .59282 L .61126 .59051 L F
0 g
.61126 .59051 m
.61811 .59254 L
s
.60152 .59282 m
.60872 .59442 L
s
.60152 .59282 m
.61126 .59051 L
s
.53475 1.06981 m .543 1.12137 L .53848 1.09192 L 0 .09 .174 r
F
.53475 1.06981 m .54585 1.14159 L .543 1.12137 L F
.53475 1.06981 m .5451 1.13888 L .54585 1.14159 L F
.53475 1.06981 m .54133 1.1165 L .5451 1.13888 L F
0 g
.54416 1.14017 m
.54426 1.13777 L
s
.53475 1.06981 m .53707 1.08953 L .54133 1.1165 L 0 .09 .174 r
F
0 g
.53475 1.06981 m
.53475 1.06981 L
s
.53475 1.06981 m
.53487 1.07054 L
s
.53487 1.07054 m
.5349 1.0707 L
s
.5349 1.0707 m
.53492 1.07082 L
s
.53492 1.07082 m
.53503 1.07147 L
s
.53449 1.06808 m
.53475 1.06981 L
s
.53294 1.06823 m
.53512 1.08353 L
s
.55019 1.00844 m
.55102 1.00882 L
s
.49584 .8486 m .49405 .84611 L .49058 .84149 L 0 0 .14 r
F
.49584 .8486 m .49956 .85323 L .49405 .84611 L F
0 g
.49145 .84243 m
.49424 .84635 L
s
.49276 .843 m
.4955 .84797 L
s
.49584 .8486 m .50432 .86054 L .50397 .85943 L 0 0 .14 r
F
.49584 .8486 m .50083 .85589 L .50432 .86054 L F
0 g
.75807 .84986 m
.75807 .84986 L
s
.75246 .85278 m
.75648 .84594 L
s
.76062 1.00043 m .76178 1.01248 L .76606 1.01716 L 0 1 .364 r
F
0 g
.76261 1.02825 m
.76606 1.01716 L
s
.76889 .84739 m .78433 .84471 L .77966 .84108 L 0 1 .492 r
F
0 g
.78433 .84471 m
.79115 .84584 L
s
.78433 .84471 m
.7845 .84905 L
s
.53611 1.10517 m .5349 1.10087 L .53609 1.10767 L 0 0 .102 r
F
0 g
.53541 1.10379 m
.53573 1.10562 L
s
.53526 1.10292 m
.53541 1.10379 L
s
.53517 1.10241 m
.53526 1.10292 L
s
.53501 1.10149 m
.53517 1.10241 L
s
.5349 1.10087 m
.53501 1.10149 L
s
.53467 1.09964 m
.5349 1.10087 L
s
.55105 1.00049 m .55231 1.00941 L .55636 1.02659 L 0 .032 .151 r
F
0 g
.55105 1.00049 m
.55186 .99924 L
s
.55111 1.00886 m
.55231 1.00941 L
s
.55102 1.00882 m
.55111 1.00886 L
s
.55231 1.0158 m
.55357 1.02021 L
s
.55019 1.00844 m
.55231 1.0158 L
s
.55091 1.00008 m
.55105 1.00049 L
s
.70521 .81401 m
.7061 .82807 L
s
.80312 .87871 m .80712 .89276 L .81352 .90099 L 0 1 .423 r
F
0 g
.81209 .91309 m
.81352 .90099 L
s
.57508 .96264 m
.5767 .9654 L
s
.5767 .9654 m
.57752 .96678 L
s
.57752 .96678 m
.57954 .97021 L
s
.57523 .96978 m
.5764 1.02674 L
s
.5764 1.02674 m
.57705 1.05852 L
s
.57508 .96264 m
.57523 .96978 L
s
.33106 .76009 m
.33219 .75971 L
s
.33219 .75971 m
.33637 .76212 L
s
.45193 .64201 m .44195 .63848 L .44331 .64179 L 0 1 .518 r
F
.45193 .64201 m .4489 .63374 L .44195 .63848 L F
0 g
.44243 .64247 m
.44331 .64179 L
s
.43697 .64669 m
.44243 .64247 L
s
.45193 .64201 m .45953 .63072 L .4489 .63374 L 0 1 .518 r
F
.45193 .64201 m .46816 .63095 L .45953 .63072 L F
.45193 .64201 m .46903 .63426 L .46816 .63095 L F
.45193 .64201 m .46207 .63901 L .46903 .63426 L F
0 g
.44535 .64683 m
.45193 .64201 L
s
.44331 .64179 m
.45193 .64201 L
s
.46207 .63901 m
.47032 .63931 L
s
.53736 1.05406 m .5462 1.11112 L .54116 1.07699 L 0 .119 .179 r
F
.53736 1.05406 m .54993 1.13956 L .5462 1.11112 L F
.53736 1.05406 m .54982 1.14303 L .54993 1.13956 L F
.53736 1.05406 m .54595 1.11963 L .54982 1.14303 L F
0 g
.54415 1.14033 m
.54415 1.14031 L
s
.54415 1.14031 m
.54416 1.14017 L
s
.54216 1.13352 m
.54415 1.14033 L
s
.53736 1.05406 m .54095 1.08528 L .54595 1.11963 L 0 .119 .179 r
F
0 g
.53738 1.04843 m
.53806 1.05356 L
s
.53736 1.05406 m .53729 1.05731 L .54095 1.08528 L 0 .119 .179 r
F
0 g
.53726 1.05349 m
.53736 1.05406 L
s
.53861 1.04733 m
.53985 1.05637 L
s
.53858 1.05113 m
.53916 1.05441 L
s
.53916 1.05441 m
.53947 1.05617 L
s
.5365 1.05373 m
.53729 1.05731 L
s
.53461 1.09369 m
.53473 1.09467 L
s
.53473 1.09467 m
.53501 1.09677 L
s
.53501 1.09677 m
.53505 1.09705 L
s
.53461 1.09369 m
.53489 1.09525 L
s
.53489 1.09525 m
.53532 1.09761 L
s
.53532 1.09761 m
.53536 1.09779 L
s
.53536 1.09779 m
.53568 1.09958 L
s
.32432 .8535 m .31169 .8542 L .31684 .85579 L 0 1 .522 r
F
0 g
.32432 .8535 m
.32432 .8535 L
s
.31684 .85579 m
.31774 .85966 L
s
.36146 .64443 m .34909 .64292 L .35186 .64538 L 0 1 .534 r
F
0 g
.34886 .64822 m
.35186 .64538 L
s
.42075 .91595 m
.42116 .91863 L
s
.42116 .91863 m
.42616 .92282 L
s
.7228 1.1126 m .73162 1.09959 L .72747 1.10698 L 0 0 0 r
F
.72622 1.10731 m .73162 1.09959 L .73554 1.09089 L 0 .861 .122 r
F
.72622 1.10731 m .72747 1.10698 L .73162 1.09959 L F
0 g
.73162 1.09959 m
.73195 1.09884 L
s
.69521 .69375 m .71174 .67731 L .70294 .6827 L 0 1 .203 r
F
0 g
.71174 .67731 m
.71876 .67215 L
s
.71174 .67731 m
.7158 .67619 L
s
.40784 .6467 m
.41012 .64483 L
s
.4094 .64669 m
.41659 .64662 L
s
.40784 .6467 m
.4094 .64669 L
s
.70717 .8848 m
.71279 .88262 L
s
.7128 .88262 m .71922 .87647 L .71403 .88011 L 0 .99 .239 r
F
.7128 .88262 m .72595 .87424 L .71922 .87647 L F
0 g
.71403 .8801 m
.71403 .8801 L
s
.7128 .88262 m
.71403 .88011 L
s
.71922 .87647 m
.72023 .87386 L
s
.53611 1.10517 m .53609 1.10767 L .53889 1.12106 L 0 0 .102 r
F
0 g
.53545 1.10493 m
.53609 1.10767 L
s
.53573 1.10562 m
.53609 1.10767 L
s
.75391 .79698 m .75607 .77434 L .75201 .77556 L 0 .786 .336 r
F
0 g
.75136 .77419 m
.75201 .77556 L
s
.62529 .93927 m
.62543 .93078 L
s
.62435 .99798 m
.62465 .97939 L
s
.32241 .64333 m .30929 .64349 L .31249 .64542 L 0 1 .539 r
F
0 g
.3124 .64552 m
.31249 .64542 L
s
.50081 1.00338 m
.50093 1.001 L
s
.37262 .86839 m .3638 .85945 L .3629 .86463 L 0 .915 .459 r
F
0 g
.35709 .86476 m
.3629 .86463 L
s
.44901 .62311 m .43863 .62151 L .44002 .62306 L 0 1 .476 r
F
.44901 .62311 m .44592 .61926 L .43863 .62151 L F
0 g
.43336 .6262 m
.44002 .62306 L
s
.44901 .62311 m .45703 .6178 L .44592 .61926 L 0 1 .476 r
F
.44901 .62311 m .46604 .61785 L .45703 .6178 L F
.44901 .62311 m .46692 .61938 L .46604 .61785 L F
.44901 .62311 m .45962 .62163 L .46692 .61938 L F
0 g
.4421 .62525 m
.44901 .62311 L
s
.44002 .62306 m
.44901 .62311 L
s
.45962 .62163 m
.46823 .62155 L
s
.28871 .75654 m .27901 .75316 L .27651 .75675 L 0 1 .52 r
F
0 g
.26881 .75977 m
.27651 .75675 L
s
.40302 .62997 m
.41213 .62817 L
s
.47743 .63472 m .48776 .632 L .49525 .62751 L 0 1 .519 r
F
0 g
.48776 .632 m
.49578 .63249 L
s
.43935 .79786 m .43429 .79379 L .43091 .79297 L 0 .414 .259 r
F
.43935 .79786 m .44097 .79638 L .43429 .79379 L F
.43935 .79786 m .44728 .79978 L .44097 .79638 L F
.43935 .79786 m .44901 .80171 L .44728 .79978 L F
.43935 .79786 m .4456 .80088 L .44901 .80171 L F
0 g
.43629 .79662 m
.43935 .79786 L
s
.43306 .79447 m
.43935 .79786 L
s
.77195 .98627 m .77902 .96876 L .77448 .97366 L 0 1 .383 r
F
.76685 .95228 m .77902 .96876 L .78058 .95472 L 0 1 .376 r
F
.76685 .95228 m .77448 .97366 L .77902 .96876 L F
0 g
.77902 .96876 m
.78332 .97394 L
s
.30238 .6432 m
.30424 .64089 L
s
.46895 .81925 m
.4709 .82045 L
s
.46895 .81925 m
.47419 .82372 L
s
.44965 .95105 m
.45173 .95359 L
s
.45173 .95359 m
.4549 .95705 L
s
.55841 1.048 m
.55877 1.04896 L
s
.55883 1.04989 m
.5591 1.05084 L
s
.62544 .93118 m
.62571 .93822 L
s
.70366 .78648 m
.70432 .78748 L
s
.70339 .78608 m
.70366 .78648 L
s
.69848 .77111 m
.70003 .77799 L
s
.70003 .77799 m
.7001 .77829 L
s
.7001 .77829 m
.70042 .77973 L
s
.70042 .77973 m
.70056 .78035 L
s
.46264 .96614 m .45417 .95658 L .4549 .95706 L 0 .218 0 r
F
.34313 .76711 m .33911 .76431 L .33638 .76212 L 0 .026 .164 r
F
.33911 .76431 m .33815 .76162 L .33351 .7604 L 0 .262 .216 r
F
.33911 .76431 m .33351 .7604 L .33053 .75963 L F
.34762 .77043 m .33911 .76431 L .34313 .76711 L 0 .026 .164 r
F
.79199 .8864 m .80673 .90576 L .80712 .89276 L 0 1 .412 r
F
.79199 .8864 m .80221 .90906 L .80673 .90576 L F
0 g
.80673 .90576 m
.81209 .91309 L
s
.25709 .84555 m .2462 .84174 L .24573 .84543 L 0 1 .505 r
F
0 g
.23951 .84746 m
.24573 .84543 L
s
.42458 .79033 m
.43091 .79297 L
s
.47743 .63472 m .46816 .63095 L .46903 .63426 L 0 1 .519 r
F
.47743 .63472 m .47565 .62644 L .46816 .63095 L F
0 g
.46744 .63534 m
.46903 .63426 L
s
.46207 .63901 m
.46744 .63534 L
s
.47743 .63472 m .4865 .62376 L .47565 .62644 L 0 1 .519 r
F
.47743 .63472 m .4949 .62422 L .4865 .62376 L F
.47743 .63472 m .49525 .62751 L .4949 .62422 L F
0 g
.48776 .632 m
.49239 .62922 L
s
.49239 .62922 m
.49525 .62751 L
s
.46903 .63426 m
.47743 .63472 L
s
.47032 .63931 m
.47743 .63472 L
s
.49525 .62751 m
.50333 .62819 L
s
.38142 .87761 m .37714 .86588 L .37262 .86839 L 0 .844 .459 r
F
.38142 .87761 m .38304 .86722 L .37714 .86588 L F
.38142 .87761 m .38635 .87154 L .38304 .86722 L F
.38142 .87761 m .38566 .876 L .38635 .87154 L F
0 g
.37554 .87626 m
.38142 .87761 L
s
.38095 .88148 m
.38142 .87761 L
s
.34702 .64321 m
.34735 .64316 L
s
.34119 .64404 m
.34702 .64321 L
s
.5301 .61463 m .54096 .61277 L .54961 .60911 L 0 1 .526 r
F
0 g
.54096 .61277 m
.54859 .61367 L
s
.69656 .87237 m
.70134 .88319 L
s
.70134 .88319 m
.70289 .88671 L
s
.70312 .88724 m
.7032 .88742 L
s
.70289 .88671 m
.70312 .88724 L
s
.69656 .87237 m
.69726 .89085 L
s
.69726 .89085 m
.69727 .89111 L
s
.44208 .94233 m .43516 .93408 L .43876 .93848 L 0 .117 .185 r
F
.53578 1.0691 m .5354 1.0696 L .53848 1.09192 L 0 .099 .176 r
F
0 g
.5354 1.0696 m
.53558 1.07091 L
s
.53558 1.07091 m
.5356 1.07109 L
s
.5356 1.07109 m
.53572 1.07191 L
s
.53572 1.07191 m
.53577 1.07226 L
s
.53512 1.08353 m
.53541 1.08554 L
s
.53457 1.08083 m
.53541 1.08554 L
s
.53389 1.06146 m
.5354 1.0696 L
s
.69129 .75675 m .69191 .7445 L .68847 .74535 L 0 .793 .405 r
F
0 g
.67996 .73673 m
.68847 .74535 L
s
.69129 .75675 m .70013 .75431 L .69191 .7445 L 0 .793 .405 r
F
0 g
.68332 .74633 m
.69129 .75675 L
s
.68847 .74535 m
.69129 .75675 L
s
.674 .91198 m .67765 .90433 L .68336 .89756 L 0 0 .04 r
F
0 g
.67963 .90785 m
.67977 .90845 L
s
.67977 .90845 m
.68157 .91613 L
s
.68336 .91337 m
.68336 .90434 L
s
.68336 .90434 m
.68336 .90357 L
s
.78942 .93068 m .79543 .91424 L .79092 .91784 L 0 1 .405 r
F
.77812 .94087 m .78942 .93068 L .78415 .92352 L 0 1 .391 r
F
0 g
.34968 .78464 m
.35265 .7887 L
s
.3551 .79207 m
.35522 .79223 L
s
.35498 .79189 m
.3551 .79207 L
s
.55358 1.02025 m
.55411 1.01741 L
s
.55411 1.01741 m
.55415 1.0172 L
s
.47292 .97703 m
.47663 .9808 L
s
.76685 .95228 m .78058 .95472 L .77812 .94087 L 0 1 .376 r
F
0 g
.77902 .96876 m
.78058 .95472 L
s
.78058 .95472 m
.78585 .96185 L
s
.76062 1.00043 m .77195 .98627 L .76767 .98154 L 0 1 .364 r
F
.36146 .64443 m .35487 .63802 L .34909 .64292 L 0 1 .534 r
F
0 g
.34735 .64316 m
.34909 .64292 L
s
.36146 .64443 m .36536 .63395 L .35487 .63802 L 0 1 .534 r
F
.36146 .64443 m .375 .63299 L .36536 .63395 L F
.36146 .64443 m .37733 .63577 L .375 .63299 L F
.36146 .64443 m .37152 .64068 L .37733 .63577 L F
0 g
.356 .64916 m
.36146 .64443 L
s
.35186 .64538 m
.36146 .64443 L
s
.64179 .82527 m .65488 .78646 L .64864 .79844 L 0 1 .139 r
F
0 g
.65488 .78646 m
.6573 .78516 L
s
.65488 .78646 m
.65786 .77986 L
s
.65002 .81205 m
.65129 .80711 L
s
.79199 .8864 m .79589 .90077 L .80221 .90906 L 0 1 .412 r
F
0 g
.80074 .92148 m
.80221 .90906 L
s
.44208 .94233 m .43316 .93123 L .43516 .93408 L 0 .117 .185 r
F
.44208 .94233 m .43409 .93182 L .43316 .93123 L F
0 g
.43039 .9296 m
.43281 .93187 L
s
.44208 .94233 m .43742 .93568 L .43409 .93182 L 0 .117 .185 r
F
0 g
.43281 .93187 m
.43516 .93408 L
s
.44208 .94233 m .44091 .94022 L .43742 .93568 L 0 .117 .185 r
F
.44208 .94233 m .44291 .94307 L .44091 .94022 L F
0 g
.44208 .94233 m
.44416 .94487 L
s
.43876 .93848 m
.44208 .94233 L
s
.41192 .90753 m
.41715 .91133 L
s
.41185 .90451 m
.41192 .90752 L
s
.77966 .84108 m .7953 .83906 L .79045 .83494 L 0 1 .505 r
F
0 g
.7953 .83906 m
.80225 .84059 L
s
.7953 .83906 m
.79559 .84372 L
s
.62271 .58622 m .61721 .5814 L .61551 .584 L 0 1 .526 r
F
.62271 .58622 m .62732 .57989 L .61721 .5814 L F
.62271 .58622 m .63907 .58049 L .62732 .57989 L F
.72622 1.10731 m .73554 1.09089 L .73665 1.08664 L 0 .861 .122 r
F
0 g
.73195 1.09884 m
.73554 1.09089 L
s
.53578 1.0691 m .54433 1.12399 L .5396 1.0923 L 0 .099 .176 r
F
.53578 1.0691 m .54746 1.14665 L .54433 1.12399 L F
.53578 1.0691 m .54686 1.14492 L .54746 1.14665 L F
.53578 1.0691 m .543 1.12137 L .54686 1.14492 L F
.53578 1.0691 m .53848 1.09192 L .543 1.12137 L F
0 g
.53578 1.0691 m
.53607 1.07082 L
s
.53607 1.07082 m
.53615 1.07132 L
s
.53615 1.07132 m
.5362 1.07159 L
s
.5362 1.07159 m
.53626 1.07199 L
s
.53626 1.07199 m
.53628 1.0721 L
s
.53442 1.06032 m
.53578 1.0691 L
s
.53579 1.07242 m
.53586 1.07296 L
s
.53577 1.07226 m
.53579 1.07242 L
s
.53568 1.09958 m
.53647 1.10391 L
s
.53505 1.09705 m
.53586 1.10323 L
s
.53586 1.10323 m
.53587 1.10336 L
s
.5301 .61463 m .54961 .60911 L .5503 .60608 L 0 1 .526 r
F
0 g
.54961 .60911 m
.5571 .61031 L
s
.54096 .61277 m
.54961 .60911 L
s
.75514 .72901 m .75577 .71039 L .75195 .71103 L 0 .75 .365 r
F
0 g
.7506 .70887 m
.75195 .71103 L
s
.3638 .85945 m .35384 .85711 L .35747 .86002 L 0 .967 .451 r
F
0 g
.35709 .86476 m
.35747 .86002 L
s
.5592 .60289 m .57036 .60165 L .57962 .59862 L 0 1 .528 r
F
0 g
.57036 .60165 m
.57783 .60287 L
s
.7384 .65065 m
.73856 .65064 L
s
.73856 .65064 m
.74109 .65061 L
s
.46264 .96614 m .4567 .95973 L .45417 .95658 L 0 .218 0 r
F
.46264 .96614 m .46096 .96506 L .4567 .95973 L F
.46264 .96614 m .46409 .96902 L .46096 .96506 L F
.46264 .96614 m .46481 .96947 L .46409 .96902 L F
0 g
.46264 .96614 m
.46364 .96592 L
s
.4584 .96082 m
.46264 .96614 L
s
.5592 .60289 m .57962 .59862 L .58082 .59579 L 0 1 .528 r
F
0 g
.57962 .59862 m
.58685 .6002 L
s
.57036 .60165 m
.57962 .59862 L
s
.48489 .98973 m
.48814 .99171 L
s
.3397 .64582 m
.34702 .64321 L
s
.34702 .64321 m
.34728 .64312 L
s
.34728 .64312 m
.3491 .64247 L
s
.63501 .85776 m .64992 .81246 L .6477 .81251 L 0 1 .141 r
F
.63501 .85776 m .64699 .82508 L .64992 .81246 L F
0 g
.64986 .80693 m
.65195 .80153 L
s
.64736 .82352 m
.64796 .82096 L
s
.64705 .82482 m
.64736 .82352 L
s
.64591 .83091 m
.64751 .82331 L
s
.64992 .81246 m
.65002 .81205 L
s
.64954 .81247 m
.64992 .81246 L
s
.5371 1.06143 m .54595 1.11963 L .54095 1.08528 L 0 .112 .178 r
F
.5371 1.06143 m .54952 1.14662 L .54595 1.11963 L F
.5371 1.06143 m .54924 1.14795 L .54952 1.14662 L F
.5371 1.06143 m .54532 1.12367 L .54924 1.14795 L F
.5371 1.06143 m .54043 1.09024 L .54532 1.12367 L F
0 g
.53736 1.05406 m
.53823 1.05929 L
s
.53806 1.05356 m
.53894 1.06021 L
s
.53729 1.05731 m
.53775 1.06086 L
s
.54057 1.06242 m
.54105 1.06509 L
s
.54074 1.06283 m
.54105 1.06509 L
s
.5371 1.06143 m .53692 1.06369 L .54043 1.09024 L 0 .112 .178 r
F
0 g
.53594 1.05451 m
.5371 1.06143 L
s
.53985 1.05637 m
.54074 1.06283 L
s
.53947 1.05617 m
.54057 1.06242 L
s
.53775 1.06086 m
.53802 1.0629 L
s
.5371 1.06143 m
.53711 1.06153 L
s
.534 1.04937 m
.53692 1.06369 L
s
.71922 .87647 m
.72595 .87424 L
s
.72595 .87424 m .73052 .86856 L .72629 .87152 L 0 1 .335 r
F
.72595 .87424 m .73667 .86735 L .73052 .86856 L F
0 g
.72595 .87424 m
.72629 .87152 L
s
.73052 .86855 m
.73133 .86662 L
s
.69848 .77111 m
.70108 .77421 L
s
.70108 .77421 m
.7017 .77495 L
s
.7017 .77495 m
.70208 .77541 L
s
.70568 .77971 m
.70591 .77998 L
s
.70602 .78012 m
.7065 .78069 L
s
.76851 .8382 m .77295 .84035 L .76869 .84302 L 0 0 .029 r
F
.76851 .8382 m .7793 .83264 L .77295 .84035 L F
.49716 .99985 m .49211 1.00053 L .49441 .99883 L 0 .578 .081 r
F
0 g
.49441 .99883 m
.49517 .99539 L
s
.49716 .99985 m .49174 1.00496 L .49211 1.00053 L 0 .578 .081 r
F
.49716 .99985 m .49356 1.00918 L .49174 1.00496 L F
.49716 .99985 m .49632 1.0102 L .49356 1.00918 L F
.49716 .99985 m .49817 1.00734 L .49632 1.0102 L F
.49716 .99985 m .49852 1.00291 L .49817 1.00734 L F
0 g
.49716 .99985 m
.49769 .99564 L
s
.49441 .99883 m
.49716 .99985 L
s
.49852 1.00291 m
.50093 1.001 L
s
.4122 .78521 m .4027 .78219 L .40528 .78328 L 0 .6 .33 r
F
0 g
.40258 .7831 m
.40528 .78328 L
s
.26797 .84915 m .26198 .84227 L .25709 .84555 L 0 1 .504 r
F
.26797 .84915 m .26882 .84094 L .26198 .84227 L F
.26797 .84915 m .27305 .84246 L .26882 .84094 L F
.26797 .84915 m .27267 .84598 L .27305 .84246 L F
0 g
.26116 .85046 m
.26797 .84915 L
s
.26776 .85254 m
.26797 .84915 L
s
.32432 .8535 m .31164 .8503 L .31169 .8542 L 0 1 .522 r
F
0 g
.32363 .85809 m
.32432 .8535 L
s
.30469 .8556 m
.31169 .8542 L
s
.53657 1.06638 m .53629 1.06772 L .5396 1.0923 L 0 .106 .177 r
F
0 g
.53629 1.06772 m
.53655 1.06963 L
s
.53711 1.06153 m
.53768 1.065 L
s
.53823 1.05929 m
.53915 1.06487 L
s
.53894 1.06021 m
.53966 1.06568 L
s
.53802 1.0629 m
.53839 1.06569 L
s
.53386 1.07105 m
.53639 1.08557 L
s
.53633 1.07242 m
.53649 1.0734 L
s
.53628 1.0721 m
.53633 1.07242 L
s
.53494 1.06072 m
.53629 1.06772 L
s
.81427 .8715 m .82965 .87835 L .82543 .8647 L 0 1 .434 r
F
0 g
.82939 .89069 m
.82965 .87835 L
s
.74226 .674 m .74137 .65812 L .73787 .65841 L 0 .697 .388 r
F
0 g
.73549 .65534 m
.73787 .65841 L
s
.74226 .674 m .75125 .67284 L .74137 .65812 L 0 .697 .388 r
F
0 g
.733 .65922 m
.74226 .674 L
s
.73787 .65841 m
.74226 .674 L
s
.53692 1.06369 m
.53705 1.06467 L
s
.53705 1.06467 m
.53727 1.06631 L
s
.52346 .89237 m
.52458 .89565 L
s
.45417 .95658 m .44616 .94681 L .44965 .95105 L 0 0 .145 r
F
0 g
.44965 .95105 m
.44966 .95105 L
s
.28871 .75654 m .28635 .74956 L .27901 .75316 L 0 1 .52 r
F
.28871 .75654 m .29463 .74814 L .28635 .74956 L F
.28871 .75654 m .2983 .74986 L .29463 .74814 L F
.28871 .75654 m .29575 .75347 L .2983 .74986 L F
0 g
.28643 .7595 m
.28871 .75654 L
s
.28048 .75794 m
.28871 .75654 L
s
.75514 .72901 m .76487 .72677 L .75577 .71039 L 0 .75 .365 r
F
.75514 .72901 m .77321 .74928 L .76487 .72677 L F
.75514 .72901 m .77641 .76732 L .77321 .74928 L F
.75514 .72901 m .77234 .76883 L .77641 .76732 L F
.75514 .72901 m .76322 .75239 L .77234 .76883 L F
0 g
.74623 .71178 m
.75514 .72901 L
s
.75195 .71103 m
.75514 .72901 L
s
.75324 .75508 m
.7616 .77128 L
s
.32432 .8535 m .31675 .84668 L .31164 .8503 L 0 1 .522 r
F
0 g
.31164 .8503 m
.31169 .8542 L
s
.32432 .8535 m .32426 .84438 L .31675 .84668 L 0 1 .522 r
F
.32432 .8535 m .32914 .84494 L .32426 .84438 L F
.32432 .8535 m .32916 .84886 L .32914 .84494 L F
0 g
.31684 .85579 m
.32432 .8535 L
s
.71251 1.13272 m .7228 1.1126 L .72125 1.11896 L 0 0 .018 r
F
.37262 .86839 m .36862 .85577 L .3638 .85945 L 0 .915 .459 r
F
.37262 .86839 m .37474 .8563 L .36862 .85577 L F
.37262 .86839 m .37806 .86069 L .37474 .8563 L F
.37262 .86839 m .37714 .86588 L .37806 .86069 L F
0 g
.36652 .86786 m
.37262 .86839 L
s
.37193 .87284 m
.37262 .86839 L
s
.32241 .64333 m .31473 .63819 L .30929 .64349 L 0 1 .539 r
F
0 g
.30391 .64515 m
.30929 .64349 L
s
.32241 .64333 m .3252 .63304 L .31473 .63819 L 0 1 .539 r
F
.32241 .64333 m .33517 .63094 L .3252 .63304 L F
.32241 .64333 m .33796 .6333 L .33517 .63094 L F
.32241 .64333 m .33248 .63861 L .33796 .6333 L F
0 g
.31727 .64829 m
.32241 .64333 L
s
.31249 .64542 m
.32241 .64333 L
s
.53657 1.06638 m .54532 1.12367 L .54043 1.09024 L 0 .106 .177 r
F
.53657 1.06638 m .54869 1.14865 L .54532 1.12367 L F
.53657 1.06638 m .54825 1.14825 L .54869 1.14865 L F
.53657 1.06638 m .54433 1.12399 L .54825 1.14825 L F
.53657 1.06638 m .5396 1.0923 L .54433 1.12399 L F
0 g
.53699 1.06899 m
.53721 1.07034 L
s
.53721 1.07034 m
.53741 1.07159 L
s
.53741 1.07159 m
.53747 1.07196 L
s
.53747 1.07196 m
.53764 1.07297 L
s
.53764 1.07297 m
.53765 1.07307 L
s
.53657 1.06638 m
.53699 1.06899 L
s
.53765 1.07307 m
.5377 1.07335 L
s
.5377 1.07335 m
.53776 1.07372 L
s
.53776 1.07372 m
.54043 1.09024 L
s
.53762 1.06901 m
.53773 1.06978 L
s
.53773 1.06978 m
.5381 1.07263 L
s
.5381 1.07263 m
.53811 1.07269 L
s
.53811 1.07269 m
.53821 1.07343 L
s
.53821 1.07343 m
.53829 1.07404 L
s
.53727 1.06631 m
.53762 1.06901 L
s
.53829 1.07404 m
.5383 1.07413 L
s
.5383 1.07413 m
.53833 1.07438 L
s
.53833 1.07438 m
.53838 1.07476 L
s
.53838 1.07476 m
.54043 1.09024 L
s
.53623 1.06425 m
.53657 1.06638 L
s
.53444 1.07082 m
.53663 1.08638 L
s
.53503 1.07147 m
.53667 1.08119 L
s
.53586 1.07296 m
.53691 1.08058 L
s
.53957 1.09211 m
.5396 1.0923 L
s
.53839 1.06569 m
.53867 1.0679 L
s
.53832 1.08452 m
.53957 1.09211 L
s
.53649 1.0734 m
.53832 1.08452 L
s
.53925 1.07229 m
.53936 1.07316 L
s
.53907 1.07092 m
.53925 1.07229 L
s
.53892 1.06978 m
.53907 1.07092 L
s
.53867 1.0679 m
.53892 1.06978 L
s
.53936 1.07316 m
.53944 1.07373 L
s
.53944 1.07373 m
.53958 1.07479 L
s
.53958 1.07479 m
.53964 1.07531 L
s
.53789 1.08842 m
.53848 1.09192 L
s
.53784 1.08814 m
.53789 1.08842 L
s
.53667 1.08119 m
.53784 1.08814 L
s
.53966 1.06568 m
.54021 1.06983 L
s
.53915 1.06487 m
.53947 1.06681 L
s
.53947 1.06681 m
.53997 1.06981 L
s
.53691 1.08058 m
.5379 1.08772 L
s
.5379 1.08772 m
.53848 1.09192 L
s
.53929 1.07503 m
.53955 1.07662 L
s
.53923 1.07461 m
.53929 1.07503 L
s
.53955 1.07662 m
.54095 1.08528 L
s
.53921 1.07453 m
.53923 1.07461 L
s
.53817 1.06805 m
.53822 1.06836 L
s
.53768 1.065 m
.53817 1.06805 L
s
.53913 1.07398 m
.53921 1.07453 L
s
.53892 1.07269 m
.53913 1.07398 L
s
.53886 1.07236 m
.53892 1.07269 L
s
.53861 1.07076 m
.53886 1.07236 L
s
.53831 1.06893 m
.53861 1.07076 L
s
.53822 1.06836 m
.53831 1.06893 L
s
.53663 1.08638 m
.53707 1.08953 L
s
.53639 1.08557 m
.53707 1.08953 L
s
.53723 1.07468 m
.53841 1.08348 L
s
.53841 1.08348 m
.53957 1.09207 L
s
.53957 1.09207 m
.5396 1.0923 L
s
.53709 1.07369 m
.53723 1.07468 L
s
.53705 1.07341 m
.53709 1.07369 L
s
.53704 1.07334 m
.53705 1.07341 L
s
.53704 1.07332 m
.53704 1.07334 L
s
.53697 1.07276 m
.53704 1.07332 L
s
.53686 1.07197 m
.53697 1.07276 L
s
.53655 1.06963 m
.53686 1.07197 L
s
.54004 1.07027 m
.54045 1.07272 L
s
.53997 1.06981 m
.54004 1.07027 L
s
.54043 1.07147 m
.54066 1.07326 L
s
.54028 1.07034 m
.54043 1.07147 L
s
.54021 1.06983 m
.54028 1.07034 L
s
.53964 1.07531 m
.53967 1.0755 L
s
.53967 1.0755 m
.54095 1.08528 L
s
.54066 1.07326 m
.54079 1.0742 L
s
.54045 1.07272 m
.54065 1.07396 L
s
.54065 1.07396 m
.54076 1.0746 L
s
.54076 1.0746 m
.54098 1.07595 L
s
.54079 1.0742 m
.54087 1.07485 L
s
.54087 1.07485 m
.54103 1.07604 L
s
.54103 1.07604 m
.54112 1.0767 L
s
.54112 1.0767 m
.54116 1.07699 L
s
.5411 1.07668 m
.54116 1.07699 L
s
.54098 1.07595 m
.5411 1.07668 L
s
.53647 1.10391 m
.53657 1.10445 L
s
.71508 .6138 m
.7254 .62705 L
s
.70882 .60259 m
.71508 .6138 L
s
.68734 .89615 m
.6874 .89859 L
s
.68734 .89615 m
.6875 .89666 L
s
.6875 .89666 m
.68794 .89812 L
s
.6884 .89966 m
.68868 .90058 L
s
.68824 .89914 m
.6884 .89966 L
s
.75391 .79698 m .76421 .79285 L .75607 .77434 L 0 .786 .336 r
F
0 g
.75324 .75508 m
.75607 .77434 L
s
.78089 .89466 m .79543 .91424 L .79589 .90077 L 0 1 .4 r
F
.78089 .89466 m .79092 .91784 L .79543 .91424 L F
0 g
.79543 .91424 m
.80074 .92148 L
s
.2462 .84174 m .23469 .84167 L .23911 .84319 L 0 1 .508 r
F
0 g
.23911 .84319 m
.23951 .84746 L
s
.43316 .93123 m .42616 .92282 L .42976 .92737 L 0 .255 .249 r
F
.76685 .95228 m .76926 .9666 L .77448 .97366 L 0 1 .376 r
F
0 g
.77195 .98627 m
.77448 .97366 L
s
.80312 .87871 m .81837 .88531 L .81427 .8715 L 0 1 .423 r
F
0 g
.81805 .89794 m
.81837 .88531 L
s
.81837 .88531 m
.82485 .89353 L
s
.3638 .85945 m .35496 .85096 L .35384 .85711 L 0 .967 .451 r
F
0 g
.34783 .85804 m
.35384 .85711 L
s
.37678 .63511 m
.38096 .63391 L
s
.7375 1.06948 m .75129 1.05348 L .75131 1.04486 L 0 1 .272 r
F
.7375 1.06948 m .74714 1.06696 L .75129 1.05348 L F
0 g
.74735 1.06628 m
.75129 1.05348 L
s
.40305 .89683 m
.4032 .89335 L
s
.40305 .89683 m
.40839 .90005 L
s
.44091 .94022 m
.44291 .94307 L
s
.44291 .94307 m
.44616 .9468 L
s
.59021 .59331 m .61296 .58791 L .6054 .58616 L 0 1 .528 r
F
0 g
.61296 .58791 m
.62271 .58622 L
s
.62732 .57989 m .6495 .57915 L .65169 .57678 L 0 1 .529 r
F
.62732 .57989 m .63907 .58049 L .6495 .57915 L F
0 g
.6495 .57915 m
.65617 .58189 L
s
.63907 .58049 m
.6495 .57915 L
s
.63907 .58049 m
.64623 .58271 L
s
.7138 .84087 m .71686 .82373 L .71283 .82549 L 0 .893 .356 r
F
0 g
.71283 .82549 m
.7138 .84087 L
s
.70521 .81401 m
.71283 .82549 L
s
.71379 .84086 m
.7138 .84087 L
s
.7061 .82807 m
.71379 .84086 L
s
.5301 .61463 m .52224 .61052 L .52207 .61367 L 0 1 .526 r
F
.5301 .61463 m .53091 .60685 L .52224 .61052 L F
.5301 .61463 m .54229 .60511 L .53091 .60685 L F
.5301 .61463 m .5503 .60608 L .54229 .60511 L F
0 g
.52182 .61843 m
.5301 .61463 L
s
.43316 .93123 m .42423 .91974 L .42616 .92282 L 0 .255 .249 r
F
.43316 .93123 m .42527 .92017 L .42423 .91974 L F
.43316 .93123 m .42868 .92403 L .42527 .92017 L F
.43316 .93123 m .43217 .92874 L .42868 .92403 L F
.43316 .93123 m .43409 .93182 L .43217 .92874 L F
0 g
.43316 .93123 m
.43516 .93408 L
s
.42976 .92737 m
.43316 .93123 L
s
.45417 .95658 m .4457 .94572 L .44616 .94681 L 0 0 .145 r
F
.79045 .83494 m .80628 .83355 L .80126 .82897 L 0 1 .513 r
F
0 g
.80628 .83355 m
.8086 .83418 L
s
.80628 .83355 m
.8067 .83852 L
s
.73667 .86735 m .7411 .86123 L .73687 .86415 L 0 1 .403 r
F
.73667 .86735 m .74739 .86054 L .7411 .86123 L F
0 g
.73667 .86735 m
.73687 .86415 L
s
.7411 .86123 m
.74189 .85965 L
s
.73052 .86856 m
.73667 .86735 L
s
.3223 .64692 m .30915 .64777 L .31234 .64993 L 0 1 .533 r
F
0 g
.30784 .65664 m
.31234 .64993 L
s
.78089 .89466 m .78468 .90946 L .79092 .91784 L 0 1 .4 r
F
0 g
.78942 .93068 m
.79092 .91784 L
s
.48589 .83639 m
.49058 .84149 L
s
.79199 .8864 m .80712 .89276 L .80312 .87871 L 0 1 .412 r
F
0 g
.80673 .90576 m
.80712 .89276 L
s
.80712 .89276 m
.81352 .90099 L
s
.49491 .62079 m
.50185 .62056 L
s
.53611 1.10517 m .54267 1.1359 L .53944 1.12018 L 0 0 .102 r
F
0 g
.53802 1.11377 m
.5383 1.11503 L
s
.53732 1.11062 m
.53802 1.11377 L
s
.53667 1.10769 m
.53732 1.11062 L
s
.53645 1.1067 m
.53667 1.10769 L
s
.53643 1.10662 m
.53645 1.1067 L
s
.53642 1.10656 m
.53643 1.10662 L
s
.53611 1.10517 m
.53637 1.10632 L
s
.53637 1.10632 m
.53642 1.10656 L
s
.53762 1.11018 m
.53764 1.1103 L
s
.53736 1.10878 m
.53762 1.11018 L
s
.53657 1.10445 m
.53735 1.10872 L
s
.53735 1.10872 m
.53736 1.10878 L
s
.53767 1.11048 m
.5377 1.11062 L
s
.53764 1.1103 m
.53767 1.11048 L
s
.53587 1.10336 m
.53611 1.10517 L
s
.73665 1.08664 m .74714 1.06696 L .74163 1.07637 L 0 1 .165 r
F
.7375 1.06948 m .74163 1.07637 L .74714 1.06696 L 0 1 .272 r
F
0 g
.74714 1.06696 m
.75039 1.06402 L
s
.74714 1.06696 m
.74735 1.06628 L
s
.45918 .81063 m .45159 .80446 L .45331 .80619 L 0 .326 .248 r
F
0 g
.45331 .80619 m
.45917 .81062 L
s
.45918 .81063 m
.45918 .81063 L
s
.45595 .80864 m
.45918 .81063 L
s
.4524 .80582 m
.45331 .80619 L
s
.53969 1.12635 m
.53977 1.12665 L
s
.53977 1.12665 m
.5398 1.12673 L
s
.5398 1.12673 m
.54021 1.12815 L
s
.54021 1.12815 m
.54126 1.13174 L
s
.53889 1.12106 m
.53969 1.12635 L
s
.75391 .79698 m .77102 .81881 L .76421 .79285 L 0 .786 .336 r
F
.75391 .79698 m .77294 .84034 L .77102 .81881 L F
0 g
.76231 .8471 m
.76305 .84605 L
s
.75391 .79698 m .76869 .84302 L .77294 .84034 L 0 .786 .336 r
F
0 g
.76869 .84302 m
.76869 .84302 L
s
.75391 .79698 m .76052 .8244 L .76869 .84302 L 0 .786 .336 r
F
0 g
.74592 .77723 m
.75391 .79698 L
s
.75201 .77556 m
.75391 .79698 L
s
.76305 .84605 m
.76732 .83991 L
s
.4122 .78521 m .40606 .782 L .4027 .78219 L 0 .6 .33 r
F
0 g
.39585 .78096 m
.4027 .78219 L
s
.4122 .78521 m .41314 .78284 L .40606 .782 L 0 .6 .33 r
F
.4122 .78521 m .42009 .78477 L .41314 .78284 L F
.4122 .78521 m .42226 .78651 L .42009 .78477 L F
.4122 .78521 m .41887 .78669 L .42226 .78651 L F
0 g
.40914 .78491 m
.4122 .78521 L
s
.40528 .78328 m
.4122 .78521 L
s
.70632 .86726 m
.70716 .8847 L
s
.70716 .8847 m
.70716 .8848 L
s
.70632 .86725 m
.7118 .87638 L
s
.7118 .87638 m
.71358 .87936 L
s
.7139 .87988 m
.71398 .88003 L
s
.71358 .87936 m
.7139 .87988 L
s
.71398 .88003 m
.71403 .8801 L
s
.66978 1.1599 m .67913 1.15591 L .67514 1.16255 L 0 .273 .105 r
F
.67655 1.18657 m .67913 1.15591 L .68407 1.15683 L 0 .227 .11 r
F
.67655 1.18657 m .67514 1.16255 L .67913 1.15591 L F
0 g
.67913 1.15591 m
.67963 1.14502 L
s
.67913 1.15591 m
.68125 1.1563 L
s
.42291 .64172 m .41196 .63867 L .41381 .64181 L 0 1 .521 r
F
0 g
.41012 .64483 m
.41381 .64181 L
s
.42291 .64172 m .41864 .6338 L .41196 .63867 L 0 1 .521 r
F
.42291 .64172 m .42941 .63045 L .41864 .6338 L F
.42291 .64172 m .43853 .63036 L .42941 .63045 L F
.42291 .64172 m .4399 .63358 L .43853 .63036 L F
.42291 .64172 m .4332 .63845 L .4399 .63358 L F
0 g
.41659 .64662 m
.42291 .64172 L
s
.41381 .64181 m
.42291 .64172 L
s
.2462 .84174 m .2353 .83776 L .23469 .84167 L 0 1 .508 r
F
0 g
.22837 .84385 m
.23469 .84167 L
s
.55303 1.01246 m
.554 1.01657 L
s
.55231 1.00941 m
.55303 1.01246 L
s
.70294 .6827 m .71987 .66785 L .7107 .67249 L 0 1 .216 r
F
0 g
.71987 .66785 m
.72419 .66707 L
s
.71987 .66785 m
.72731 .66313 L
s
.70868 .79403 m .71046 .77966 L .7067 .78093 L 0 .861 .385 r
F
0 g
.7067 .78093 m
.70681 .78169 L
s
.7065 .78069 m
.7067 .78093 L
s
.70868 .79403 m .71828 .79034 L .71046 .77966 L 0 .861 .385 r
F
.70868 .79403 m .72495 .80586 L .71828 .79034 L F
.70868 .79403 m .72693 .81898 L .72495 .80586 L F
.70868 .79403 m .7229 .82094 L .72693 .81898 L F
.70868 .79403 m .71508 .81024 L .7229 .82094 L F
0 g
.70432 .78748 m
.70868 .79403 L
s
.70681 .78169 m
.70868 .79403 L
s
.27901 .75316 m .26658 .7534 L .27055 .7548 L 0 1 .532 r
F
0 g
.26881 .75977 m
.27055 .7548 L
s
.55295 1.16103 m .55975 1.17169 L .557 1.1694 L 0 .632 .058 r
F
.54634 1.14823 m .55295 1.16103 L .55285 1.16363 L 0 .536 .026 r
F
0 g
.30515 .75665 m
.30747 .75368 L
s
.7138 .84087 m .72402 .83557 L .71686 .82373 L 0 .893 .356 r
F
.7138 .84087 m .72954 .85314 L .72402 .83557 L F
.7138 .84087 m .72629 .87152 L .73052 .86855 L F
0 g
.72629 .87152 m
.72629 .87152 L
s
.7138 .84087 m .71912 .85964 L .72629 .87152 L 0 .893 .356 r
F
0 g
.72102 .87181 m
.72314 .86631 L
s
.7138 .84087 m
.7138 .84087 L
s
.39259 .64244 m .38083 .64003 L .38315 .64291 L 0 1 .527 r
F
0 g
.37766 .64766 m
.38315 .64291 L
s
.69681 1.1449 m .706 1.13549 L .70193 1.14319 L 0 .053 .075 r
F
.70223 1.15602 m .706 1.13549 L .71053 1.13101 L 0 0 .058 r
F
.70223 1.15602 m .70193 1.14319 L .706 1.13549 L F
0 g
.706 1.13549 m
.7069 1.12719 L
s
.706 1.13549 m
.70679 1.13471 L
s
.3638 .85945 m .3601 .84567 L .35496 .85096 L 0 .967 .451 r
F
.3638 .85945 m .36644 .84509 L .3601 .84567 L F
.3638 .85945 m .36976 .84962 L .36644 .84509 L F
.3638 .85945 m .36862 .85577 L .36976 .84962 L F
0 g
.35747 .86002 m
.3638 .85945 L
s
.3629 .86463 m
.3638 .85945 L
s
.66197 .57615 m .65717 .57082 L .65497 .57321 L 0 1 .526 r
F
.66197 .57615 m .6678 .57038 L .65717 .57082 L F
.66197 .57615 m .67974 .57218 L .6678 .57038 L F
0 g
.67974 .57218 m
.68551 .57462 L
s
.42423 .91974 m .41715 .91133 L .42076 .91595 L 0 .351 .339 r
F
0 g
.69331 .89475 m
.69331 .89609 L
s
.6874 .89859 m
.69044 .89591 L
s
.39259 .64244 m .38712 .63511 L .38083 .64003 L 0 1 .527 r
F
.39259 .64244 m .39785 .63143 L .38712 .63511 L F
.39259 .64244 m .4073 .63096 L .39785 .63143 L F
.39259 .64244 m .40917 .63402 L .4073 .63096 L F
.39259 .64244 m .40285 .63894 L .40917 .63402 L F
0 g
.38663 .64733 m
.39259 .64244 L
s
.38315 .64291 m
.39259 .64244 L
s
.39417 .88617 m
.39973 .88887 L
s
.39417 .88616 m
.39465 .8823 L
s
.7793 .83264 m .7836 .83379 L .77933 .83639 L 0 0 .001 r
F
.7793 .83264 m .7901 .82715 L .7836 .83379 L F
.77812 .94087 m .78415 .92352 L .77965 .92749 L 0 1 .391 r
F
.76685 .95228 m .77812 .94087 L .7729 .93379 L 0 1 .376 r
F
0 g
.53889 1.12106 m
.5417 1.13371 L
s
.55929 1.185 m .55975 1.17169 L .56399 1.18124 L 0 .741 .08 r
F
0 g
.56386 1.17338 m
.56399 1.18124 L
s
.55929 1.185 m .557 1.1694 L .55975 1.17169 L 0 .741 .08 r
F
0 g
.5595 1.16648 m
.55975 1.17169 L
s
.55975 1.17169 m
.56399 1.18124 L
s
.5167 .88031 m
.51759 .88292 L
s
.51616 .8796 m
.5167 .88031 L
s
.51444 .87731 m
.51616 .8796 L
s
.51341 .87594 m
.51444 .87731 L
s
.78089 .89466 m .79589 .90077 L .79199 .8864 L 0 1 .4 r
F
0 g
.79543 .91424 m
.79589 .90077 L
s
.79589 .90077 m
.80221 .90906 L
s
.65494 .92333 m .66783 .90654 L .66451 .91933 L 0 .402 .159 r
F
0 g
.66765 .90261 m
.66783 .90654 L
s
.66783 .90654 m
.67278 .8984 L
s
.59021 .59331 m .58382 .58876 L .58262 .59157 L 0 1 .528 r
F
.59021 .59331 m .59359 .58644 L .58382 .58876 L F
.59021 .59331 m .6054 .58616 L .59359 .58644 L F
.47569 .62031 m .46604 .61785 L .46692 .61938 L 0 1 .455 r
F
.47569 .62031 m .47388 .61652 L .46604 .61785 L F
0 g
.45962 .62163 m
.46692 .61938 L
s
.47569 .62031 m .48438 .61664 L .47388 .61652 L 0 1 .455 r
F
.48438 .61664 m .49402 .61611 L .48524 .61568 L 0 1 .523 r
F
.49122 .61769 m .49402 .61611 L .48438 .61664 L F
.50284 .62003 m .50164 .6195 L .49821 .61942 L 0 1 .525 r
F
.50284 .62003 m .49821 .61942 L .49917 .61973 L F
.50164 .6195 m .49402 .61611 L .49425 .61816 L F
.49917 .61973 m .49425 .61816 L .49438 .6187 L 0 1 .438 r
F
.50164 .6195 m .49425 .61816 L .49438 .61934 L 0 1 .525 r
F
.50284 .62052 m .49402 .61722 L .49425 .61816 L 0 1 .438 r
F
.50284 .62052 m .49425 .61816 L .49917 .61973 L F
.49917 .61973 m .49821 .61942 L .49438 .61934 L 0 1 .525 r
F
.47569 .62031 m .49438 .6187 L .49425 .61816 L 0 1 .455 r
F
.49122 .61769 m .49425 .6182 L .49402 .61611 L 0 1 .523 r
F
.49412 .61814 m .49425 .61816 L .49424 .61812 L 0 1 .455 r
F
.47569 .62031 m .49425 .61816 L .49412 .61814 L F
.49122 .61769 m .49424 .61812 L .49402 .61722 L F
.47569 .62031 m .49424 .61812 L .49122 .61769 L F
.47569 .62031 m .49122 .61769 L .48438 .61664 L F
.48432 .61671 m .49122 .61769 L .48438 .61664 L 0 1 .523 r
F
.47569 .62031 m .48652 .62003 L .49438 .6187 L 0 1 .455 r
F
.47565 .62644 m .49122 .61769 L .48432 .61671 L 0 1 .523 r
F
.47565 .62644 m .49438 .61934 L .49425 .6182 L F
.47565 .62644 m .49425 .6182 L .49122 .61769 L F
.49122 .61769 m .49402 .61722 L .4852 .61669 L 0 1 .455 r
F
.49122 .61769 m .4852 .61669 L .48438 .61664 L F
.48438 .61664 m .49402 .61722 L .48523 .61628 L F
.47565 .62644 m .48438 .61664 L .47387 .61834 L 0 1 .523 r
F
.48438 .61664 m .48524 .61568 L .48242 .61634 L F
.48418 .61664 m .48242 .61634 L .47388 .61652 L 0 1 .455 r
F
.48438 .61664 m .48242 .61634 L .48418 .61664 L F
.48051 .61596 m .48524 .61568 L .49349 .61131 L 0 1 .525 r
F
.48054 .61597 m .48524 .61568 L .48051 .61596 L F
.48062 .61598 m .48524 .61568 L .48054 .61597 L F
.48242 .61634 m .48524 .61568 L .48041 .616 L F
.48051 .61596 m .48523 .61628 L .49348 .61487 L 0 1 .48 r
F
.47388 .61652 m .48242 .61634 L .48051 .61596 L F
.48242 .61634 m .48523 .61628 L .48051 .61596 L F
.48055 .61599 m .48062 .61598 L .48048 .61597 L 0 1 .525 r
F
.48062 .61598 m .48054 .61597 L .48048 .61597 L F
.48048 .61597 m .48054 .61597 L .48051 .61596 L F
.47388 .61652 m .48051 .61596 L .47894 .61565 L 0 1 .48 r
F
.47387 .61834 m .49349 .61131 L .49314 .60814 L 0 1 .525 r
F
.47894 .61565 m .49348 .61487 L .49312 .61323 L 0 1 .48 r
F
.48051 .61596 m .49348 .61487 L .47894 .61565 L F
.47682 .61524 m .49314 .60814 L .48396 .60773 L 0 1 .525 r
F
.47388 .61652 m .47894 .61565 L .47682 .61524 L 0 1 .48 r
F
.47387 .61834 m .47894 .61565 L .47682 .61524 L 0 1 .525 r
F
.47894 .61565 m .49314 .60814 L .47682 .61524 L F
.47682 .61524 m .47894 .61565 L .47687 .61522 L 0 1 .48 r
F
.47687 .61522 m .49312 .61323 L .48394 .61214 L F
.47894 .61565 m .49312 .61323 L .47687 .61522 L F
.48041 .616 m .48055 .61599 L .48048 .61597 L 0 1 .525 r
F
.47387 .61834 m .48242 .61634 L .48041 .616 L F
.48438 .61664 m .48242 .61634 L .47387 .61834 L 0 1 .523 r
F
.48438 .61664 m .48523 .61628 L .48242 .61634 L 0 1 .455 r
F
0 g
.46692 .61938 m
.47427 .62016 L
s
.46823 .62155 m
.47435 .62054 L
s
.49139 .62047 m
.49355 .62067 L
s
.49355 .62067 m
.49491 .62079 L
s
.4457 .94572 m .43742 .93568 L .44091 .94022 L 0 .124 .189 r
F
0 g
.44091 .94022 m
.44092 .94022 L
s
.35496 .85096 m .34474 .85081 L .34838 .85316 L 0 1 .435 r
F
0 g
.34783 .85804 m
.34838 .85316 L
s
.53943 .92262 m
.54066 .92895 L
s
.53814 1.0234 m
.53911 1.02557 L
s
.4332 .63845 m
.44195 .63848 L
s
.75161 .69451 m
.75256 .69814 L
s
.75256 .69814 m
.75257 .69817 L
s
.75257 .69817 m
.75266 .69853 L
s
.75312 .7003 m
.75577 .71039 L
s
.55436 1.02398 m
.55442 1.02394 L
s
.55529 1.02335 m
.55556 1.02317 L
s
.5549 1.02362 m
.55529 1.02335 L
s
.42423 .91974 m .41531 .90805 L .41715 .91133 L 0 .351 .339 r
F
0 g
.43217 .92874 m
.43409 .93182 L
s
.43409 .93182 m
.43742 .93568 L
s
.74739 .86054 m .7517 .85407 L .74746 .85691 L 0 1 .446 r
F
.74739 .86054 m .75813 .85388 L .7517 .85407 L F
0 g
.74739 .86054 m
.74746 .85691 L
s
.75176 .85397 m
.75246 .85278 L
s
.7517 .85407 m
.75176 .85397 L
s
.7411 .86123 m
.74739 .86054 L
s
.76981 .9036 m .78415 .92352 L .78468 .90946 L 0 1 .387 r
F
.76981 .9036 m .77965 .92749 L .78415 .92352 L F
0 g
.78415 .92352 m
.78942 .93068 L
s
.32103 .75743 m .31298 .75547 L .31665 .75642 L 0 .515 .238 r
F
.3223 .64692 m .31461 .64161 L .30915 .64777 L 0 1 .533 r
F
0 g
.2996 .65117 m
.30915 .64777 L
s
.3223 .64692 m .32512 .63554 L .31461 .64161 L 0 1 .533 r
F
.3223 .64692 m .33512 .63252 L .32512 .63554 L F
.3223 .64692 m .33793 .63458 L .33512 .63252 L F
.3223 .64692 m .33242 .64076 L .33793 .63458 L F
0 g
.31711 .65314 m
.3223 .64692 L
s
.31234 .64993 m
.3223 .64692 L
s
.74933 1.01694 m .76178 1.01248 L .76062 1.00043 L 0 1 .343 r
F
.74933 1.01694 m .75926 1.02655 L .76178 1.01248 L F
0 g
.76178 1.01248 m
.76606 1.01716 L
s
.45918 .81063 m .45521 .80601 L .45159 .80446 L 0 .326 .248 r
F
.45918 .81063 m .46178 .80982 L .45521 .80601 L F
.45918 .81063 m .46767 .81428 L .46178 .80982 L F
.45918 .81063 m .46894 .81639 L .46767 .81428 L F
.45918 .81063 m .46529 .81482 L .46894 .81639 L F
0 g
.45917 .81062 m
.45918 .81063 L
s
.32103 .75743 m .31194 .75463 L .31298 .75547 L 0 .515 .238 r
F
.32103 .75743 m .31423 .75447 L .31194 .75463 L F
0 g
.30515 .75665 m
.31232 .75557 L
s
.31232 .75557 m
.31298 .75547 L
s
.32103 .75743 m .31862 .75548 L .31423 .75447 L 0 .515 .238 r
F
.32103 .75743 m .32217 .757 L .31862 .75548 L F
.32103 .75743 m .3232 .75784 L .32217 .757 L F
0 g
.31665 .75642 m
.32103 .75743 L
s
.42423 .91974 m .41645 .9083 L .41531 .90805 L 0 .351 .339 r
F
.42423 .91974 m .41993 .91209 L .41645 .9083 L F
0 g
.41531 .90805 m
.41715 .91133 L
s
.42423 .91974 m .42343 .91689 L .41993 .91209 L 0 .351 .339 r
F
.42423 .91974 m .42527 .92017 L .42343 .91689 L F
0 g
.42423 .91974 m
.42616 .92282 L
s
.42076 .91595 m
.42423 .91974 L
s
.33911 .76431 m .32751 .75898 L .33106 .76009 L 0 .262 .216 r
F
0 g
.71508 .81024 m
.71686 .82373 L
s
.75161 .69451 m
.7534 .69719 L
s
.7534 .69719 m
.75352 .69736 L
s
.58086 1.05543 m
.58114 1.07364 L
s
.58114 1.07364 m
.58121 1.07783 L
s
.58054 1.0343 m
.58086 1.05543 L
s
.5802 1.01271 m
.58054 1.0343 L
s
.57969 .97965 m
.5802 1.01271 L
s
.57967 .97818 m
.57969 .97965 L
s
.57954 .97021 m
.57967 .97818 L
s
.5592 .60289 m .55201 .59858 L .55132 .60157 L 0 1 .528 r
F
.5592 .60289 m .5613 .59553 L .55201 .59858 L F
.5592 .60289 m .57297 .59447 L .5613 .59553 L F
.5592 .60289 m .58082 .59579 L .57297 .59447 L F
0 g
.5503 .60608 m
.5592 .60289 L
s
.58082 .59579 m
.59021 .59331 L
s
.69727 .89112 m
.69733 .89129 L
s
.69733 .89129 m
.69735 .89133 L
s
.45417 .95658 m .44859 .94852 L .4457 .94572 L 0 0 .145 r
F
.45417 .95658 m .45312 .95406 L .44859 .94852 L F
.45417 .95658 m .45625 .95865 L .45312 .95406 L F
.45417 .95658 m .4567 .95973 L .45625 .95865 L F
0 g
.50427 .86037 m
.50485 .86114 L
s
.75131 1.04485 m .75926 1.02655 L .75473 1.0333 L 0 1 .32 r
F
.74933 1.01694 m .75473 1.0333 L .75926 1.02655 L 0 1 .343 r
F
0 g
.75926 1.02655 m
.76178 1.01248 L
s
.75926 1.02655 m
.76261 1.02825 L
s
.80126 .82897 m .81728 .82818 L .81208 .82316 L 0 1 .519 r
F
0 g
.81728 .82818 m
.81782 .83344 L
s
.41877 .62503 m .40743 .62409 L .40931 .62577 L 0 1 .511 r
F
0 g
.40302 .62997 m
.40931 .62577 L
s
.41877 .62503 m .41443 .62082 L .40743 .62409 L 0 1 .511 r
F
.41877 .62503 m .42567 .61814 L .41443 .62082 L F
.41877 .62503 m .43515 .61739 L .42567 .61814 L F
.41877 .62503 m .43655 .61909 L .43515 .61739 L F
.41877 .62503 m .42952 .62236 L .43655 .61909 L F
0 g
.41213 .62817 m
.41877 .62503 L
s
.40931 .62577 m
.41877 .62503 L
s
.4457 .94572 m .43723 .93403 L .43742 .93568 L 0 .124 .189 r
F
.72622 1.10731 m .72515 1.1103 L .72747 1.10698 L 0 .861 .122 r
F
0 g
.7228 1.1126 m
.72547 1.10938 L
s
.34762 .77043 m .34632 .76883 L .33911 .76431 L 0 .026 .164 r
F
0 g
.34151 .76511 m
.34442 .76764 L
s
.34762 .77043 m .35409 .7756 L .34632 .76883 L 0 .026 .164 r
F
.34762 .77043 m .35586 .77872 L .35409 .7756 L F
.35586 .77872 m .35638 .77923 L .35453 .77629 L F
.35586 .77872 m .35453 .77629 L .35409 .7756 L F
.35638 .77923 m .35728 .77757 L .35435 .77596 L 0 1 .452 r
F
.34692 .79674 m .3542 .78653 L .35659 .77957 L F
.35638 .77923 m .35659 .77957 L .35728 .77757 L F
.34762 .77043 m .35442 .77784 L .35659 .77957 L 0 .026 .164 r
F
.34762 .77043 m .35659 .77957 L .35638 .77923 L F
.34692 .79674 m .35659 .77957 L .35638 .77923 L 0 1 .452 r
F
.35638 .77923 m .35659 .77957 L .35721 .78007 L 0 .026 .164 r
F
.36533 .78483 m .35438 .77583 L .35721 .78007 L 0 .614 .427 r
F
.35438 .77583 m .35409 .7756 L .35435 .77596 L F
.35438 .77583 m .35435 .77596 L .35721 .78007 L F
.36553 .7762 m .35438 .77583 L .35728 .77757 L 0 1 .541 r
F
.35438 .77583 m .35427 .77583 L .35437 .77588 L F
.35438 .77583 m .35437 .77588 L .35728 .77757 L F
.35427 .77583 m .35409 .77582 L .35435 .77596 L F
.35436 .77588 m .35435 .77596 L .35728 .77757 L F
.35463 .77195 m .34614 .77012 L .34931 .77263 L 0 1 .536 r
F
.35787 .77153 m .35425 .7711 L .35463 .77195 L F
.35463 .77195 m .34625 .76585 L .3494 .76951 L 0 .679 .442 r
F
.35459 .77185 m .34625 .76585 L .35463 .77195 L F
.35482 .77147 m .35425 .7711 L .35491 .77208 L F
.35425 .7711 m .34625 .76585 L .35454 .77181 L F
.35425 .7711 m .35454 .77181 L .35491 .77208 L F
.33911 .76431 m .3494 .76951 L .34625 .76585 L 0 .262 .216 r
F
.33911 .76431 m .34632 .76883 L .3494 .76951 L F
.35787 .77153 m .35885 .76133 L .35287 .76407 L 0 1 .536 r
F
.35787 .77153 m .35287 .76407 L .35292 .76436 L F
.35787 .77153 m .35275 .76412 L .35358 .76803 L F
.35787 .77153 m .35358 .76803 L .35425 .7711 L F
.36553 .7762 m .35787 .77153 L .35525 .7745 L 0 1 .541 r
F
.36553 .7762 m .36611 .76756 L .35787 .77153 L F
.35787 .77153 m .36743 .76023 L .35885 .76133 L 0 1 .536 r
F
.35787 .77153 m .37022 .76271 L .36743 .76023 L F
.35787 .77153 m .36611 .76756 L .37022 .76271 L F
.35782 .77344 m .35877 .76469 L .35287 .76407 L 0 .679 .442 r
F
.35358 .76803 m .35287 .76407 L .35025 .76379 L F
.35782 .77344 m .35287 .76407 L .35358 .76803 L F
.35292 .76436 m .35287 .76407 L .35275 .76412 L 0 1 .536 r
F
.35422 .77108 m .35025 .76379 L .34625 .76585 L 0 .679 .442 r
F
.35421 .77102 m .35025 .76379 L .35422 .77108 L F
.35358 .76803 m .35025 .76379 L .35425 .7711 L F
.35358 .76803 m .35275 .76412 L .35021 .76528 L 0 1 .536 r
F
.35425 .7711 m .35421 .77102 L .35422 .77108 L 0 .679 .442 r
F
.35782 .77344 m .35358 .76803 L .35425 .7711 L F
.35358 .76803 m .35272 .76733 L .35425 .7711 L 0 1 .536 r
F
.35425 .7711 m .35021 .76528 L .34614 .77012 L F
.35272 .76733 m .35021 .76528 L .35425 .7711 L F
.35425 .7711 m .34614 .77012 L .35463 .77195 L F
.35491 .77208 m .35459 .77185 L .35463 .77195 L 0 .679 .442 r
F
.35782 .77344 m .35482 .77147 L .35491 .77208 L F
.35538 .77544 m .35525 .7745 L .35448 .77537 L 0 1 .541 r
F
.36553 .7762 m .35525 .7745 L .35538 .77544 L F
.35438 .77583 m .35448 .77537 L .35409 .7756 L 0 .614 .427 r
F
.35438 .77583 m .35448 .77537 L .35409 .77582 L 0 1 .541 r
F
.36553 .7762 m .35448 .77537 L .35438 .77583 L F
.35438 .77583 m .35452 .77535 L .35448 .77537 L 0 .614 .427 r
F
.36533 .78483 m .35782 .77344 L .35452 .77535 L F
.36533 .78483 m .35452 .77535 L .35438 .77583 L F
.35427 .77583 m .35434 .77595 L .35436 .77588 L 0 1 .541 r
F
.35434 .77595 m .35435 .77596 L .35436 .77588 L F
.34692 .79674 m .35638 .77923 L .35409 .77582 L 0 1 .452 r
F
.35638 .77923 m .35435 .77596 L .35409 .7756 L 0 .026 .164 r
F
.35638 .77923 m .35435 .77596 L .35409 .77582 L 0 1 .452 r
F
.35638 .77923 m .35721 .78007 L .35435 .77596 L 0 .026 .164 r
F
.31164 .8503 m .30046 .85096 L .30467 .85214 L 0 1 .46 r
F
0 g
.30467 .85214 m
.30469 .8556 L
s
.67843 .72105 m
.67845 .72107 L
s
.67841 .72103 m
.67843 .72105 L
s
.67146 .71401 m
.67699 .71959 L
s
.67765 .72026 m
.67841 .72103 L
s
.28962 .93018 m .27935 .92711 L .28389 .9289 L 0 .493 .241 r
F
0 g
.28389 .9289 m
.28572 .93041 L
s
.51341 .87594 m
.51522 .87951 L
s
.2353 .83776 m .22365 .8378 L .22807 .83936 L 0 1 .512 r
F
0 g
.22807 .83936 m
.22837 .84385 L
s
.4153 .90805 m .40839 .90005 L .41185 .90451 L 0 .477 .397 r
F
0 g
.38566 .876 m
.38635 .87154 L
s
.38566 .876 m
.39133 .878 L
s
.25709 .84555 m .25127 .83828 L .2462 .84174 L 0 1 .505 r
F
.25709 .84555 m .25826 .83691 L .25127 .83828 L F
.25709 .84555 m .26249 .83856 L .25826 .83691 L F
.25709 .84555 m .26198 .84227 L .26249 .83856 L F
0 g
.25014 .8469 m
.25709 .84555 L
s
.25675 .84905 m
.25709 .84555 L
s
.67229 .73413 m .67187 .72986 L .66894 .73613 L 0 .938 .161 r
F
.66475 .75119 m .67229 .73413 L .66457 .74617 L 0 .925 .15 r
F
0 g
.66718 .74211 m
.67229 .73413 L
s
.37152 .64068 m
.38083 .64003 L
s
.47577 .98239 m .46879 .97425 L .47193 .97726 L 0 .364 0 r
F
0 g
.47193 .97726 m
.47292 .97703 L
s
.38217 .7796 m .37175 .78037 L .37475 .78019 L 0 1 .412 r
F
0 g
.37232 .77899 m
.37467 .78015 L
s
.4456 .80088 m
.4482 .80151 L
s
.4456 .80088 m
.45159 .80446 L
s
.76421 .79285 m .76623 .771 L .76217 .77238 L 0 .824 .346 r
F
0 g
.7616 .77128 m
.76217 .77238 L
s
.4949 .62422 m
.50185 .62056 L
s
.50185 .62056 m
.50185 .62055 L
s
.50185 .62055 m
.50218 .62038 L
s
.6867 1.16473 m .69681 1.1449 L .69582 1.15548 L 0 .149 .095 r
F
.76981 .9036 m .7735 .91896 L .77965 .92749 L 0 1 .387 r
F
0 g
.77812 .94087 m
.77965 .92749 L
s
.54166 1.03128 m .54254 1.02482 L .54631 1.03628 L 0 .636 .185 r
F
0 g
.54302 1.02627 m
.54387 1.02885 L
s
.54254 1.02482 m
.54302 1.02627 L
s
.5434 1.02548 m
.54407 1.02949 L
s
.54497 1.03484 m
.54701 1.047 L
s
.54014 1.00976 m
.54254 1.02482 L
s
.50284 .62003 m .51376 .61775 L .52207 .61367 L 0 1 .525 r
F
0 g
.51376 .61775 m
.52182 .61843 L
s
.50414 1.00789 m
.50418 1.01151 L
s
.35496 .85096 m .3461 .8433 L .34474 .85081 L 0 1 .435 r
F
0 g
.33853 .85255 m
.34474 .85081 L
s
.55294 1.0256 m
.55307 1.02585 L
s
.55268 1.02512 m
.55294 1.0256 L
s
.55307 1.02585 m
.55308 1.02585 L
s
.55308 1.02585 m
.55314 1.02597 L
s
.55314 1.02597 m
.55356 1.02675 L
s
.55269 1.02512 m
.55293 1.02602 L
s
.55269 1.02512 m
.55269 1.02512 L
s
.55293 1.02602 m
.553 1.02629 L
s
.553 1.02629 m
.55342 1.02789 L
s
.55342 1.02789 m
.55347 1.02805 L
s
.55347 1.02805 m
.55366 1.02877 L
s
.55363 1.0332 m
.55387 1.03525 L
s
.55333 1.03065 m
.55363 1.0332 L
s
.5533 1.03041 m
.55333 1.03065 L
s
.55328 1.03021 m
.5533 1.03041 L
s
.55313 1.02891 m
.55328 1.03021 L
s
.55312 1.02885 m
.55313 1.02891 L
s
.55303 1.02809 m
.55312 1.02885 L
s
.55281 1.02623 m
.55303 1.02809 L
s
.55278 1.02596 m
.55281 1.02623 L
s
.55268 1.02512 m
.55278 1.02596 L
s
.55379 1.03387 m
.55382 1.03415 L
s
.55349 1.0315 m
.55379 1.03387 L
s
.55345 1.03124 m
.55349 1.0315 L
s
.55343 1.03103 m
.55345 1.03124 L
s
.55329 1.02995 m
.55343 1.03103 L
s
.55325 1.02961 m
.55329 1.02995 L
s
.5529 1.02685 m
.55325 1.02961 L
s
.55282 1.02622 m
.5529 1.02685 L
s
.55269 1.02513 m
.55282 1.02622 L
s
.28962 .93018 m .27835 .92557 L .27935 .92711 L 0 .493 .241 r
F
0 g
.27429 .92616 m
.27935 .92711 L
s
.75562 .96522 m .76926 .9666 L .76685 .95228 L 0 1 .36 r
F
.75562 .96522 m .76767 .98154 L .76926 .9666 L F
0 g
.76926 .9666 m
.77448 .97366 L
s
.76981 .9036 m .78468 .90946 L .78089 .89466 L 0 1 .387 r
F
0 g
.78415 .92352 m
.78468 .90946 L
s
.78468 .90946 m
.79092 .91784 L
s
.67844 .72109 m
.67845 .72107 L
s
.67845 .72107 m
.67905 .72028 L
s
.27901 .75316 m .26931 .74929 L .26658 .7534 L 0 1 .532 r
F
0 g
.2587 .75645 m
.26658 .7534 L
s
.70334 .90774 m .70717 .88481 L .70321 .88744 L 0 .896 .313 r
F
.69294 .89418 m .69712 .89145 L .70321 .88744 L 0 .806 .167 r
F
0 g
.70314 .88748 m
.70321 .88744 L
s
.4153 .90805 m .40673 .89675 L .40839 .90005 L 0 .477 .397 r
F
.35496 .85096 m .35156 .83563 L .3461 .8433 L 0 1 .435 r
F
.35496 .85096 m .35815 .83341 L .35156 .83563 L F
.35496 .85096 m .36147 .83815 L .35815 .83341 L F
.35496 .85096 m .3601 .84567 L .36147 .83815 L F
0 g
.35384 .85711 m
.35496 .85096 L
s
.34838 .85316 m
.35496 .85096 L
s
.76062 1.00043 m .76767 .98154 L .76314 .98716 L 0 1 .364 r
F
.75562 .96522 m .76314 .98716 L .76767 .98154 L 0 1 .36 r
F
0 g
.76767 .98154 m
.76926 .9666 L
s
.76767 .98154 m
.77195 .98627 L
s
.75813 .85388 m .76231 .84711 L .75807 .84987 L 0 1 .474 r
F
.76889 .84739 m .77295 .84035 L .76869 .84303 L 0 1 .492 r
F
.7687 .8432 m .77295 .84035 L .76869 .84303 L 0 1 .401 r
F
.75813 .85388 m .76889 .84739 L .76236 .84711 L 0 1 .474 r
F
.76889 .84739 m .77966 .84108 L .77299 .84035 L 0 1 .492 r
F
.77292 .8404 m .77299 .84035 L .77295 .84035 L F
.76889 .84739 m .77299 .84035 L .77292 .8404 L F
.77966 .84108 m .7836 .83379 L .77933 .83639 L 0 1 .505 r
F
.77934 .83654 m .7836 .83379 L .77933 .83639 L 0 1 .412 r
F
.77966 .84108 m .79045 .83494 L .78365 .8338 L 0 1 .505 r
F
.78357 .83384 m .78365 .8338 L .7836 .83379 L F
.77966 .84108 m .78365 .8338 L .78357 .83384 L F
.79045 .83494 m .79427 .82742 L .79 .82994 L 0 1 .513 r
F
.79001 .83008 m .79427 .82742 L .79 .82995 L 0 1 .423 r
F
.79045 .83494 m .80126 .82897 L .79432 .82743 L 0 1 .513 r
F
.79424 .82747 m .79432 .82743 L .79427 .82742 L F
.79045 .83494 m .79432 .82743 L .79424 .82747 L F
.80126 .82897 m .80496 .82123 L .80068 .82368 L 0 1 .519 r
F
.80069 .8238 m .80496 .82123 L .80068 .82368 L 0 1 .433 r
F
.80126 .82897 m .81208 .82316 L .80496 .82123 L 0 1 .519 r
F
.80159 .83622 m .80492 .82139 L .80069 .8238 L 0 1 .433 r
F
.80492 .82139 m .80496 .82123 L .80069 .8238 L F
.7908 .84275 m .79422 .82761 L .79001 .83008 L 0 1 .423 r
F
.79422 .82761 m .79427 .82742 L .79001 .83008 L F
.78002 .84953 m .78355 .83402 L .77934 .83654 L 0 1 .412 r
F
.78355 .83402 m .7836 .83379 L .77934 .83654 L F
.76926 .8566 m .77289 .84062 L .7687 .8432 L 0 1 .401 r
F
.77289 .84062 m .77295 .84035 L .7687 .8432 L F
.76229 .84715 m .76236 .84711 L .76231 .84711 L 0 1 .474 r
F
.75813 .85388 m .76236 .84711 L .76229 .84715 L F
.4153 .90805 m .40797 .89681 L .40673 .89675 L 0 .477 .397 r
F
.4153 .90805 m .41142 .90034 L .40797 .89681 L F
.4153 .90805 m .41478 .905 L .41142 .90034 L F
.4153 .90805 m .41645 .9083 L .41478 .905 L F
0 g
.41185 .90451 m
.4153 .90805 L
s
.42952 .62236 m
.43863 .62151 L
s
.55849 1.05157 m
.5586 1.0519 L
s
.56045 1.05769 m
.56045 1.05769 L
s
.55809 1.05033 m
.55849 1.05157 L
s
.43723 .93403 m .42868 .92403 L .43217 .92874 L 0 .249 .27 r
F
0 g
.43217 .92874 m
.43218 .92875 L
s
.42343 .91689 m
.42527 .92017 L
s
.42527 .92017 m
.42868 .92403 L
s
.62732 .57989 m .65169 .57678 L .64418 .57438 L 0 1 .529 r
F
0 g
.65169 .57678 m
.66197 .57615 L
s
.63501 .85776 m .64062 .84447 L .64699 .82508 L 0 1 .141 r
F
0 g
.64624 .82737 m
.64699 .82508 L
s
.64699 .82508 m
.64705 .82482 L
s
.54634 1.14823 m .55285 1.16363 L .55007 1.15822 L 0 .536 .026 r
F
.7901 .82715 m .79427 .82742 L .79 .82994 L 0 0 0 r
F
.7901 .82715 m .80092 .82174 L .79427 .82742 L F
0 g
.7836 .83379 m
.78362 .83376 L
s
.78362 .83376 m
.78364 .83374 L
s
.36508 .82109 m .35501 .80223 L .35805 .81414 L 0 .778 .408 r
F
.36508 .82109 m .35761 .79564 L .35501 .80223 L F
.66475 .75119 m .66457 .74617 L .66166 .75329 L 0 .925 .15 r
F
.65557 .7759 m .66475 .75119 L .65682 .76632 L 0 .922 .139 r
F
0 g
.57048 1.03 m
.57065 1.02151 L
s
.2353 .83776 m .22439 .83364 L .22365 .8378 L 0 1 .512 r
F
0 g
.21723 .84015 m
.22365 .8378 L
s
.70334 .90774 m .71332 .8992 L .70717 .88481 L 0 .896 .313 r
F
.69294 .89418 m .70716 .8848 L .70683 .88381 L 0 .806 .167 r
F
0 g
.70321 .88744 m
.70321 .88825 L
s
.69735 .89133 m
.69791 .89289 L
s
.69044 .89591 m
.6933 .89338 L
s
.69712 .89145 m
.70314 .88748 L
s
.35707 .82783 m .35501 .80244 L .35111 .80149 L 0 .584 .313 r
F
0 g
.35501 .80223 m
.35505 .80214 L
s
.35707 .82783 m .35805 .81423 L .35501 .80244 L 0 .584 .313 r
F
0 g
.74137 .65812 m
.75125 .67284 L
s
.73853 .65096 m
.74137 .65812 L
s
.7384 .65065 m
.73853 .65096 L
s
.73603 .64467 m
.7384 .65065 L
s
.27835 .92557 m .26797 .9227 L .27252 .92446 L 0 .514 .245 r
F
0 g
.27252 .92446 m
.27429 .92616 L
s
.71912 .85964 m
.71922 .87647 L
s
.71922 .87647 m
.71922 .87647 L
s
.72431 .86824 m
.72599 .87102 L
s
.72619 .87136 m
.72629 .87152 L
s
.72599 .87102 m
.72619 .87136 L
s
.38217 .7796 m .37498 .77893 L .37175 .78037 L 0 1 .412 r
F
.38217 .7796 m .3823 .77683 L .37498 .77893 L F
.38217 .7796 m .38975 .77624 L .3823 .77683 L F
.38217 .7796 m .39235 .77754 L .38975 .77624 L F
.38217 .7796 m .38909 .77898 L .39235 .77754 L F
0 g
.37923 .78004 m
.38217 .7796 L
s
.37475 .78019 m
.38217 .7796 L
s
.34973 .7978 m
.35111 .80147 L
s
.3494 .79692 m
.34973 .7978 L
s
.40673 .89675 m .39974 .88887 L .4032 .89335 L 0 .618 .429 r
F
.35707 .82783 m .35111 .80149 L .34895 .81201 L 0 .584 .313 r
F
0 g
.35111 .80149 m
.35501 .80244 L
s
.37714 .86588 m
.37806 .86069 L
s
.37714 .86588 m
.38304 .86722 L
s
.70223 1.15602 m .71053 1.13101 L .71251 1.13272 L 0 0 .058 r
F
0 g
.71053 1.13101 m
.7121 1.12463 L
s
.70679 1.13471 m
.71053 1.13101 L
s
.43723 .93403 m .42876 .92186 L .42868 .92403 L 0 .249 .27 r
F
0 g
.55815 .99412 m
.55849 .99503 L
s
.55698 1.00099 m
.55815 .99412 L
s
.47577 .98239 m .46823 .97493 L .46879 .97425 L 0 .364 0 r
F
0 g
.46481 .96947 m
.46879 .97425 L
s
.47577 .98239 m .47061 .97888 L .46823 .97493 L 0 .364 0 r
F
.47577 .98239 m .47446 .98402 L .47061 .97888 L F
.47577 .98239 m .4772 .98692 L .47446 .98402 L F
.47577 .98239 m .47775 .98622 L .4772 .98692 L F
0 g
.47577 .98239 m
.47663 .9808 L
s
.47193 .97726 m
.47577 .98239 L
s
.55929 1.185 m .5568 1.17509 L .557 1.1694 L 0 .741 .08 r
F
0 g
.55295 1.16103 m
.557 1.1694 L
s
.34717 .63899 m .34214 .63687 L .34493 .63927 L 0 1 .535 r
F
.3477 .63892 m .3473 .63877 L .34717 .63899 L F
.3473 .63877 m .34214 .63687 L .34717 .63899 L F
.34817 .63741 m .34214 .63687 L .3477 .63892 L F
.34817 .63741 m .34824 .63178 L .34214 .63687 L F
.35489 .63719 m .35076 .63416 L .34817 .63741 L 0 1 .534 r
F
.35489 .63719 m .34817 .63741 L .3477 .63892 L F
.35487 .63802 m .35076 .63416 L .34817 .63741 L 0 1 .535 r
F
.35489 .63719 m .35917 .62716 L .35577 .62876 L 0 1 .534 r
F
.35489 .63719 m .36918 .62476 L .35917 .62716 L F
.35489 .63719 m .37154 .62669 L .36918 .62476 L F
.35489 .63719 m .36541 .63202 L .37154 .62669 L F
.35487 .63802 m .35917 .62739 L .35577 .62876 L 0 1 .535 r
F
.35039 .63381 m .35577 .62876 L .34824 .63178 L F
.35076 .63416 m .34824 .63178 L .34817 .63709 L F
.34824 .63178 m .35916 .62569 L .36326 .61942 L F
.35916 .62569 m .36562 .62179 L .36452 .62085 L 0 1 .537 r
F
.35916 .62569 m .35917 .62716 L .36562 .62179 L F
.34824 .63178 m .35577 .62876 L .35916 .62569 L 0 1 .535 r
F
.34822 .63229 m .35577 .62876 L .35916 .62569 L 0 1 .537 r
F
.35577 .62876 m .35917 .62716 L .35916 .62569 L F
.35916 .62569 m .35917 .62739 L .36562 .62209 L 0 1 .535 r
F
.35577 .62876 m .35917 .62739 L .35916 .62569 L F
.35916 .62569 m .36562 .62209 L .36452 .62085 L F
.37613 .62036 m .36757 .61996 L .36562 .62179 L 0 1 .537 r
F
.38169 .62519 m .37613 .62036 L .36918 .62476 L 0 1 .533 r
F
.37611 .62104 m .36757 .61996 L .36562 .62209 L 0 1 .532 r
F
.36757 .61996 m .36326 .61942 L .36444 .62075 L F
.36757 .61996 m .37057 .61421 L .36326 .61942 L F
.37613 .62036 m .37396 .61839 L .36757 .61996 L 0 1 .537 r
F
.37611 .62104 m .37396 .61839 L .36757 .61996 L 0 1 .532 r
F
.37396 .61839 m .37057 .61421 L .36763 .61984 L F
.37396 .61839 m .3827 .60993 L .37057 .61421 L F
.37613 .62036 m .37826 .61741 L .37396 .61839 L 0 1 .537 r
F
.38169 .62519 m .38778 .61642 L .37613 .62036 L 0 1 .533 r
F
.37613 .62036 m .38289 .61622 L .37826 .61741 L 0 1 .537 r
F
.37826 .61741 m .39322 .60888 L .3827 .60993 L 0 1 .532 r
F
.38289 .61622 m .38296 .61617 L .37826 .61741 L 0 1 .537 r
F
.38289 .61622 m .39087 .61382 L .38296 .61617 L F
.37613 .62036 m .39047 .614 L .38289 .61622 L F
.39047 .614 m .39087 .61382 L .38289 .61622 L F
.37425 .61875 m .37826 .61741 L .37405 .6185 L 0 1 .532 r
F
.38752 .61293 m .39511 .61176 L .39322 .60888 L F
.38716 .61319 m .38958 .61275 L .38752 .61293 L F
.38958 .61275 m .39511 .61176 L .38752 .61293 L F
.41443 .62082 m .41007 .61628 L .4027 .61966 L 0 1 .521 r
F
.38169 .62519 m .39986 .61685 L .39796 .61491 L 0 1 .533 r
F
.41007 .61628 m .39796 .61491 L .39986 .61685 L 0 1 .528 r
F
.41007 .61628 m .40616 .61195 L .39796 .61491 L F
.41003 .61856 m .40616 .61195 L .39794 .61611 L 0 1 .529 r
F
.40616 .61195 m .4057 .61116 L .40426 .61208 L F
.40616 .61195 m .40426 .61208 L .39796 .61491 L 0 1 .528 r
F
.40616 .61195 m .40426 .61208 L .39794 .61611 L 0 1 .529 r
F
.40616 .61195 m .40569 .61143 L .40426 .61208 L 0 1 .528 r
F
.4057 .61116 m .39322 .60888 L .39511 .61176 L 0 1 .531 r
F
.4057 .61116 m .40134 .60387 L .39322 .60888 L F
.40539 .6114 m .4013 .60633 L .3932 .6099 L 0 1 .533 r
F
.40569 .61143 m .40564 .61137 L .40539 .6114 L F
.40564 .61137 m .4013 .60633 L .40539 .6114 L F
.39117 .61369 m .39511 .61176 L .38296 .61617 L 0 1 .532 r
F
.37613 .62036 m .38778 .61642 L .39331 .61304 L 0 1 .537 r
F
.37613 .62036 m .39331 .61304 L .39117 .61369 L F
.38169 .62519 m .39796 .61491 L .38778 .61642 L 0 1 .533 r
F
.37611 .62104 m .38777 .61697 L .39331 .61304 L 0 1 .532 r
F
.39117 .61369 m .39331 .61304 L .39511 .61176 L F
.37611 .62104 m .39331 .61304 L .39117 .61369 L F
.39087 .61382 m .39117 .61369 L .38296 .61617 L 0 1 .537 r
F
.39117 .61369 m .39511 .61194 L .38296 .61617 L F
.40438 .6115 m .3932 .6099 L .39511 .61194 L 0 1 .533 r
F
.40569 .61143 m .40539 .6114 L .40438 .6115 L F
.40539 .6114 m .3932 .6099 L .40438 .6115 L F
.38296 .61617 m .39266 .61265 L .38716 .61319 L 0 1 .532 r
F
.39266 .61265 m .39511 .61176 L .38716 .61319 L F
.37611 .62104 m .39117 .61369 L .38296 .61617 L F
.39117 .61369 m .39331 .61304 L .39511 .61194 L 0 1 .537 r
F
.37611 .62104 m .37815 .61761 L .37425 .61875 L 0 1 .532 r
F
.37815 .61761 m .37826 .61741 L .37425 .61875 L F
.38296 .61617 m .39511 .61194 L .3932 .6099 L 0 1 .537 r
F
.37815 .61761 m .38296 .61617 L .37826 .61741 L 0 1 .532 r
F
.37611 .62104 m .38296 .61617 L .37815 .61761 L F
.38296 .61617 m .39322 .60888 L .37826 .61741 L F
.38296 .61617 m .3932 .6099 L .37826 .61741 L 0 1 .537 r
F
.37826 .61741 m .3932 .6099 L .38267 .61134 L F
.37405 .6185 m .37826 .61741 L .37396 .61839 L 0 1 .532 r
F
.37826 .61741 m .3827 .60993 L .37396 .61839 L F
.37826 .61741 m .37827 .6174 L .37396 .61839 L 0 1 .537 r
F
.37396 .61839 m .38267 .61134 L .37055 .61528 L F
.37827 .6174 m .38267 .61134 L .37396 .61839 L F
.37396 .61839 m .36763 .61984 L .36757 .61996 L 0 1 .532 r
F
.37396 .61839 m .37393 .61836 L .36757 .61996 L 0 1 .537 r
F
.36757 .61996 m .37055 .61528 L .36325 .61976 L F
.37393 .61836 m .37055 .61528 L .36757 .61996 L F
.36757 .61996 m .36444 .62075 L .36452 .62085 L 0 1 .532 r
F
.36757 .61996 m .36637 .62031 L .36562 .62179 L 0 1 .537 r
F
.36657 .61992 m .36452 .62085 L .36562 .62179 L F
.36757 .61996 m .36452 .62085 L .36562 .62209 L 0 1 .532 r
F
.36757 .61996 m .36657 .61992 L .36637 .62031 L 0 1 .537 r
F
.36657 .61992 m .36325 .61976 L .36452 .62085 L F
.3614 .62227 m .36452 .62085 L .36326 .61942 L 0 1 .535 r
F
.35916 .62569 m .36452 .62085 L .3614 .62227 L F
.35879 .62591 m .35916 .62569 L .36434 .6207 L 0 1 .537 r
F
.35916 .62569 m .36452 .62085 L .36434 .6207 L F
.34822 .63229 m .35879 .62591 L .36325 .61976 L F
.35879 .62591 m .36434 .6207 L .36325 .61976 L F
.35076 .63416 m .35577 .62876 L .35039 .63381 L 0 1 .535 r
F
.35489 .63719 m .35577 .62876 L .35535 .62921 L 0 1 .534 r
F
.35489 .63719 m .35536 .62895 L .35076 .63416 L F
.35487 .63802 m .35577 .62876 L .35076 .63416 L 0 1 .535 r
F
.35535 .62921 m .35577 .62876 L .35536 .62895 L 0 1 .534 r
F
.35076 .63416 m .35536 .62895 L .34822 .63229 L F
.35076 .63416 m .34817 .63709 L .34817 .63741 L 0 1 .535 r
F
.35076 .63416 m .3504 .63389 L .34817 .63741 L 0 1 .534 r
F
.34817 .63741 m .34822 .63229 L .34212 .63761 L F
.3504 .63389 m .34822 .63229 L .34817 .63741 L F
.3477 .63892 m .34212 .63761 L .34492 .63959 L F
.34817 .63741 m .34212 .63761 L .3477 .63892 L F
.35487 .63802 m .34817 .63741 L .3477 .63892 L 0 1 .535 r
F
0 g
.3477 .63892 m
.34878 .63878 L
s
.3491 .64247 m
.35384 .63815 L
s
.50284 .62003 m .50235 .61203 L .49402 .61611 L 0 1 .525 r
F
.50284 .62003 m .51379 .60981 L .50235 .61203 L F
.50284 .62003 m .52224 .61052 L .51379 .60981 L F
.50284 .62003 m .52207 .61367 L .52224 .61052 L F
0 g
.52207 .61367 m
.5301 .61463 L
s
.5023 .62032 m
.50284 .62003 L
s
.51376 .61775 m
.52207 .61367 L
s
.47758 .82681 m .47088 .81938 L .47221 .82126 L 0 .226 .219 r
F
0 g
.4709 .82045 m
.47221 .82126 L
s
.31164 .8503 m .30127 .84812 L .30046 .85096 L 0 1 .46 r
F
0 g
.29404 .85254 m
.30046 .85096 L
s
.70852 .77181 m
.70862 .77222 L
s
.70945 .77555 m
.71046 .77966 L
s
.7093 .77495 m
.70945 .77555 L
s
.70899 .7737 m
.7093 .77495 L
s
.40285 .63894 m
.40414 .63793 L
s
.40285 .63894 m
.41196 .63867 L
s
.27835 .92557 m .26707 .92104 L .26797 .9227 L 0 .514 .245 r
F
0 g
.26284 .92199 m
.26797 .9227 L
s
.34492 .63959 m
.34705 .63907 L
s
.34705 .63907 m
.3477 .63892 L
s
.3397 .64582 m
.34492 .63959 L
s
.43429 .79379 m .42551 .78902 L .42767 .79063 L 0 .503 .341 r
F
0 g
.42458 .79033 m
.42767 .79063 L
s
.31473 .63819 m .30128 .63864 L .30449 .64059 L 0 1 .539 r
F
0 g
.30424 .64089 m
.30449 .64059 L
s
.68753 .70581 m .68662 .70223 L .68366 .70731 L 0 1 .189 r
F
.68753 .70581 m .69521 .69375 L .68662 .70223 L F
0 g
.68087 .71345 m
.68753 .70581 L
s
.40673 .89675 m .39815 .8854 L .39974 .88887 L 0 .618 .429 r
F
.50284 .62052 m .50234 .61687 L .49402 .61722 L 0 1 .438 r
F
0 g
.50277 .62003 m
.50284 .62003 L
s
.50284 .62052 m .51379 .6179 L .50234 .61687 L 0 1 .438 r
F
.50284 .62052 m .52226 .61973 L .51379 .6179 L F
.50284 .62052 m .52209 .62113 L .52226 .61973 L F
.50284 .62052 m .51376 .62147 L .52209 .62113 L F
0 g
.50185 .62056 m
.50284 .62052 L
s
.49917 .61973 m
.50284 .62052 L
s
.51376 .62147 m
.52183 .62309 L
s
.4489 .63374 m .43853 .63036 L .4399 .63358 L 0 1 .521 r
F
.4489 .63374 m .44585 .62566 L .43853 .63036 L F
0 g
.43909 .63417 m
.4399 .63358 L
s
.4332 .63845 m
.43909 .63417 L
s
.4489 .63374 m .45699 .62262 L .44585 .62566 L 0 1 .521 r
F
.4489 .63374 m .466 .62277 L .45699 .62262 L F
.4489 .63374 m .46687 .62602 L .466 .62277 L F
.4489 .63374 m .45953 .63072 L .46687 .62602 L F
0 g
.44195 .63848 m
.4489 .63374 L
s
.4399 .63358 m
.4489 .63374 L
s
.45953 .63072 m
.46816 .63095 L
s
.4457 .94572 m .44049 .93638 L .43723 .93403 L 0 .124 .189 r
F
.4457 .94572 m .44528 .94189 L .44049 .93638 L F
.4457 .94572 m .44842 .94688 L .44528 .94189 L F
.4457 .94572 m .44859 .94852 L .44842 .94688 L F
0 g
.44092 .94022 m
.4457 .94572 L
s
.4457 .94572 m
.44616 .94681 L
s
.72402 .83557 m .72693 .81898 L .7229 .82094 L 0 .951 .37 r
F
0 g
.71508 .81024 m
.7229 .82094 L
s
.72402 .83557 m .73425 .82996 L .72693 .81898 L 0 .951 .37 r
F
.72402 .83557 m .73998 .84658 L .73425 .82996 L F
.72402 .83557 m .73687 .86414 L .7411 .86123 L F
0 g
.73969 .83749 m
.74086 .85721 L
s
.74086 .85721 m
.7411 .86122 L
s
.73051 .86847 m
.73052 .86855 L
s
.73687 .86414 m
.73687 .86414 L
s
.72402 .83557 m .72954 .85314 L .73687 .86414 L 0 .951 .37 r
F
0 g
.73133 .86662 m
.7341 .85999 L
s
.73029 .86403 m
.73051 .86847 L
s
.71912 .85964 m
.72431 .86824 L
s
.7229 .82094 m
.72402 .83557 L
s
.71686 .82373 m
.72402 .83557 L
s
.73014 .86104 m
.73029 .86403 L
s
.72976 .85346 m
.73014 .86104 L
s
.81427 .8715 m .81894 .85644 L .81451 .85911 L 0 1 .434 r
F
.81427 .8715 m .82543 .8647 L .81894 .85644 L F
.80312 .87871 m .81427 .8715 L .80786 .86322 L 0 1 .423 r
F
.80312 .87871 m .80786 .86322 L .80343 .86604 L F
.79199 .8864 m .80312 .87871 L .7968 .87039 L 0 1 .412 r
F
.76685 .95228 m .7729 .93379 L .76841 .93821 L 0 1 .376 r
F
.75875 .91335 m .7729 .93379 L .7735 .91896 L 0 1 .373 r
F
.75875 .91335 m .76841 .93821 L .7729 .93379 L F
0 g
.7729 .93379 m
.77812 .94087 L
s
.40673 .89675 m .39949 .88525 L .39815 .8854 L 0 .618 .429 r
F
.40673 .89675 m .40302 .88865 L .39949 .88525 L F
0 g
.39815 .8854 m
.39974 .88887 L
s
.40673 .89675 m .40638 .89334 L .40302 .88865 L 0 .618 .429 r
F
.40673 .89675 m .40797 .89681 L .40638 .89334 L F
0 g
.40673 .89675 m
.40839 .90005 L
s
.4032 .89335 m
.40673 .89675 L
s
.71332 .8992 m .71922 .87648 L .71403 .88011 L 0 .946 .328 r
F
.70241 .88512 m .71403 .88011 L .71922 .87647 L 0 1 .228 r
F
0 g
.70717 .88481 m
.7072 .88489 L
s
.70241 .88512 m .70683 .88381 L .71403 .88011 L 0 1 .228 r
F
0 g
.71403 .88011 m
.71403 .88011 L
s
.76421 .79285 m .77453 .78849 L .76623 .771 L 0 .824 .346 r
F
0 g
.76322 .75239 m
.76623 .771 L
s
.38723 .62972 m .37508 .6295 L .37744 .63131 L 0 1 .529 r
F
0 g
.37525 .63329 m
.37744 .63131 L
s
.38723 .62972 m .38169 .62519 L .37508 .6295 L 0 1 .529 r
F
.38723 .62972 m .39288 .62125 L .38169 .62519 L F
.38723 .62972 m .4027 .61966 L .39288 .62125 L F
.38723 .62972 m .40459 .62147 L .4027 .61966 L F
.38723 .62972 m .39796 .62579 L .40459 .62147 L F
0 g
.38096 .63391 m
.38723 .62972 L
s
.37744 .63131 m
.38723 .62972 L
s
.53711 1.10224 m
.53734 1.10391 L
s
.53734 1.10391 m
.53767 1.10627 L
s
.53767 1.10627 m
.53796 1.10834 L
s
.53796 1.10834 m
.53811 1.10942 L
s
.53811 1.10942 m
.53831 1.11088 L
s
.53855 1.11034 m
.53863 1.11073 L
s
.53711 1.10224 m
.53748 1.10433 L
s
.53748 1.10433 m
.538 1.10723 L
s
.538 1.10723 m
.53848 1.10994 L
s
.53848 1.10994 m
.53855 1.11034 L
s
.32217 .757 m
.3232 .75784 L
s
.3232 .75784 m
.3275 .75898 L
s
.41645 .9083 m
.41993 .91209 L
s
.41478 .905 m
.41645 .9083 L
s
.33911 .76431 m .33053 .75963 L .32751 .75898 L 0 .262 .216 r
F
.7107 .67249 m .72804 .65901 L .71851 .66294 L 0 1 .243 r
F
0 g
.72804 .65901 m
.73527 .65506 L
s
.72804 .65901 m
.73261 .65858 L
s
.42876 .92186 m .41993 .91209 L .42343 .91689 L 0 .335 .343 r
F
0 g
.42343 .91689 m
.42344 .9169 L
s
.76869 .84303 m
.76869 .84303 L
s
.76231 .84711 m
.76236 .84711 L
s
.7375 1.06948 m .75131 1.04486 L .74719 1.04589 L 0 1 .272 r
F
.79199 .8864 m .7968 .87039 L .79238 .87337 L 0 1 .412 r
F
.78089 .89466 m .79199 .8864 L .78575 .87799 L 0 1 .4 r
F
0 g
.33469 .63821 m
.34214 .63687 L
s
.59359 .58644 m .61551 .584 L .61721 .5814 L 0 1 .531 r
F
.59359 .58644 m .6054 .58616 L .61551 .584 L F
0 g
.61551 .584 m
.62271 .58622 L
s
.6054 .58616 m
.61296 .58791 L
s
.6054 .58616 m
.61551 .584 L
s
.75875 .91335 m .7735 .91896 L .76981 .9036 L 0 1 .373 r
F
0 g
.7729 .93379 m
.7735 .91896 L
s
.7735 .91896 m
.77965 .92749 L
s
.76421 .79285 m .78153 .81324 L .77453 .78849 L 0 .824 .346 r
F
.76421 .79285 m .78359 .83378 L .78153 .81324 L F
0 g
.77295 .84035 m
.77366 .83948 L
s
.76421 .79285 m .77933 .83638 L .78359 .83378 L 0 .824 .346 r
F
0 g
.77933 .83638 m
.77933 .83639 L
s
.76421 .79285 m .77102 .81881 L .77933 .83638 L 0 .824 .346 r
F
0 g
.75607 .77434 m
.76421 .79285 L
s
.76217 .77238 m
.76421 .79285 L
s
.77366 .83948 m
.7782 .83398 L
s
.67329 .92874 m .68736 .95751 L .68336 .92378 L 0 .72 .27 r
F
.67329 .92874 m .68738 .98917 L .68736 .95751 L F
.67329 .92874 m .68336 .99746 L .68738 .98917 L F
.67329 .92874 m .67731 .97141 L .68336 .99746 L F
0 g
.6722 .92218 m
.67329 .92874 L
s
.67329 .92874 m
.6733 .92027 L
s
.48737 .99515 m .4813 .99006 L .48404 .99134 L 0 .456 .041 r
F
0 g
.48404 .99134 m
.48489 .98973 L
s
.48737 .99515 m .48085 .99239 L .4813 .99006 L 0 .456 .041 r
F
.48737 .99515 m .483 .99679 L .48085 .99239 L F
.48737 .99515 m .48634 1.00061 L .483 .99679 L F
.48737 .99515 m .48865 1.0013 L .48634 1.00061 L F
.48737 .99515 m .48909 .99895 L .48865 1.0013 L F
0 g
.48737 .99515 m
.48814 .99171 L
s
.48404 .99134 m
.48737 .99515 L
s
.26707 .92104 m .25658 .91835 L .26114 .92009 L 0 .53 .256 r
F
0 g
.26114 .92009 m
.26284 .92199 L
s
.47758 .82681 m .47464 .82185 L .47088 .81938 L 0 .226 .219 r
F
.47758 .82681 m .48098 .82703 L .47464 .82185 L F
.47758 .82681 m .48638 .83261 L .48098 .82703 L F
.47758 .82681 m .48721 .83486 L .48638 .83261 L F
.47758 .82681 m .48344 .83237 L .48721 .83486 L F
0 g
.47419 .82372 m
.47758 .82681 L
s
.47221 .82126 m
.47758 .82681 L
s
.74933 1.01694 m .76062 1.00043 L .75636 .99628 L 0 1 .343 r
F
.39814 .8854 m .39133 .878 L .39465 .8823 L 0 .732 .445 r
F
.67998 .72262 m .6966 .732 L .68793 .72006 L 0 .823 .437 r
F
.67998 .72262 m .70051 .74183 L .6966 .732 L F
.67998 .72262 m .69707 .74299 L .70051 .74183 L F
.67998 .72262 m .68827 .73475 L .69707 .74299 L F
0 g
.67845 .72107 m
.67998 .72262 L
s
.67881 .71969 m
.67998 .72262 L
s
.68827 .73475 m
.69191 .7445 L
s
.75562 .96522 m .76685 .95228 L .76169 .94526 L 0 1 .36 r
F
.27901 .75316 m .27695 .74519 L .26931 .74929 L 0 1 .532 r
F
.27901 .75316 m .28545 .74353 L .27695 .74519 L F
.27901 .75316 m .28913 .74543 L .28545 .74353 L F
.27901 .75316 m .28635 .74956 L .28913 .74543 L F
0 g
.27651 .75675 m
.27901 .75316 L
s
.27055 .7548 m
.27901 .75316 L
s
.47565 .62644 m .4865 .62376 L .49438 .61934 L 0 1 .523 r
F
0 g
.4865 .62376 m
.49149 .62096 L
s
.49149 .62096 m
.49438 .61934 L
s
.49438 .61934 m
.49917 .61973 L
s
.4865 .62376 m
.4949 .62422 L
s
.35487 .63802 m .36914 .62613 L .35917 .62739 L 0 1 .535 r
F
.35487 .63802 m .37149 .62885 L .36914 .62613 L F
.35487 .63802 m .36536 .63395 L .37149 .62885 L F
0 g
.34909 .64292 m
.35487 .63802 L
s
.34878 .63878 m
.35487 .63802 L
s
.65805 .69553 m .66703 .70581 L .67606 .71279 L 0 .805 .456 r
F
0 g
.66703 .70581 m
.67146 .71401 L
s
.36862 .85577 m
.36976 .84962 L
s
.36862 .85577 m
.37474 .8563 L
s
.73509 .72443 m .75181 .6997 L .7437 .71239 L 0 0 0 r
F
0 g
.75181 .6997 m
.75352 .69736 L
s
.75181 .6997 m
.75256 .69818 L
s
.3461 .8433 m .33556 .84648 L .33924 .84795 L 0 1 .434 r
F
0 g
.33853 .85255 m
.33924 .84795 L
s
.55767 1.00683 m
.55808 1.00854 L
s
.71332 .8992 m .72643 .88829 L .71922 .87648 L 0 .946 .328 r
F
0 g
.71346 .8804 m
.71403 .88011 L
s
.70241 .88512 m .71922 .87647 L .71958 .87368 L 0 1 .228 r
F
0 g
.714 .88096 m
.71403 .88011 L
s
.70683 .88381 m
.71346 .8804 L
s
.70683 .88381 m
.70716 .8848 L
s
.7072 .88489 m
.7078 .8863 L
s
.22439 .83364 m .21259 .83383 L .21702 .83543 L 0 1 .515 r
F
0 g
.21702 .83543 m
.21723 .84015 L
s
.50062 1.0076 m .49632 1.0102 L .49817 1.00734 L 0 .615 .086 r
F
0 g
.49817 1.00734 m
.49852 1.00291 L
s
.50062 1.0076 m .49636 1.01583 L .49632 1.0102 L 0 .615 .086 r
F
.50062 1.0076 m .49827 1.02047 L .49636 1.01583 L F
.50062 1.0076 m .50073 1.02072 L .49827 1.02047 L F
.50062 1.0076 m .5021 1.01641 L .50073 1.02072 L F
.50062 1.0076 m .50204 1.01079 L .5021 1.01641 L F
0 g
.50204 1.01079 m
.50414 1.00789 L
s
.50062 1.0076 m
.50081 1.00338 L
s
.49817 1.00734 m
.50062 1.0076 L
s
.42876 .92186 m .42029 .90942 L .41993 .91209 L 0 .335 .343 r
F
.65805 .69553 m .65596 .68621 L .65331 .68713 L 0 .805 .456 r
F
.65805 .69553 m .665 .69319 L .65596 .68621 L F
.65805 .69553 m .67439 .70342 L .665 .69319 L F
.65805 .69553 m .67913 .71182 L .67439 .70342 L F
.65805 .69553 m .67606 .71279 L .67913 .71182 L F
0 g
.66703 .70581 m
.67606 .71279 L
s
.64933 .68827 m
.65805 .69553 L
s
.67606 .71279 m
.678 .71766 L
s
.55128 1.17745 m .54991 1.17033 L .55054 1.17218 L 0 .565 .019 r
F
.55134 1.17701 m .55054 1.17218 L .55159 1.17527 L F
.55128 1.17745 m .55054 1.17218 L .55134 1.17701 L F
.55377 1.19157 m .55322 1.18819 L .55443 1.19539 L 0 0 .096 r
F
.54386 1.14274 m .54589 1.14725 L .54953 1.1606 L 0 .5 0 r
F
.54583 1.14945 m .54953 1.1606 L .5516 1.16922 L F
.54386 1.14274 m .54554 1.14802 L .54583 1.14945 L F
.54554 1.14802 m .54953 1.1606 L .54583 1.14945 L F
.54949 1.16786 m .54963 1.16884 L .55055 1.17357 L 0 0 .094 r
F
.54768 1.15889 m .54699 1.15534 L .54751 1.15611 L 0 .539 .006 r
F
.54665 1.15484 m .54627 1.15301 L .54751 1.15611 L F
.54405 1.14315 m .5431 1.13803 L .54589 1.14725 L 0 .5 0 r
F
.54619 1.15126 m .55073 1.16729 L .54751 1.15611 L F
.54694 1.15577 m .54595 1.15146 L .54699 1.15601 L 0 0 .096 r
F
.54441 1.14474 m .54603 1.15049 L .54619 1.15126 L 0 .5 0 r
F
.54435 1.14446 m .54603 1.15049 L .54441 1.14474 L F
.5448 1.14607 m .5516 1.16922 L .55073 1.16729 L F
.54386 1.14274 m .54468 1.14552 L .5448 1.14607 L F
.54468 1.14552 m .5516 1.16922 L .5448 1.14607 L F
.54603 1.15049 m .55073 1.16729 L .54619 1.15126 L F
.54786 1.15969 m .54751 1.15611 L .54839 1.15916 L 0 .539 .006 r
F
.54774 1.15981 m .54839 1.15916 L .54902 1.16301 L F
.54774 1.15981 m .55073 1.16729 L .55459 1.18275 L F
.54833 1.16217 m .54986 1.16807 L .54997 1.16875 L F
.54774 1.15981 m .54828 1.16191 L .54833 1.16217 L F
.54828 1.16191 m .54986 1.16807 L .54833 1.16217 L F
.5548 1.19818 m .55612 1.20606 L .55716 1.2131 L 0 0 .102 r
F
.54938 1.16622 m .55163 1.1744 L .55178 1.17559 L 0 .539 .006 r
F
.54923 1.16532 m .5565 1.19219 L .54938 1.16622 L F
.54997 1.16875 m .55182 1.17589 L .55159 1.17527 L F
.55182 1.17589 m .55522 1.18899 L .55187 1.17633 L F
.55182 1.17589 m .55187 1.17633 L .55159 1.17527 L F
.54774 1.15981 m .54923 1.16532 L .54938 1.16622 L F
.54774 1.15981 m .55459 1.18275 L .5565 1.19219 L F
.54388 1.13431 m .5493 1.16641 L .54999 1.17024 L 0 0 .096 r
F
.55683 1.2117 m .55857 1.22324 L .55942 1.22973 L 0 0 .108 r
F
.55167 1.17861 m .55159 1.17527 L .55344 1.18227 L 0 .565 .019 r
F
.55167 1.17861 m .55344 1.18227 L .55371 1.18456 L F
.55138 1.17674 m .55159 1.17527 L .55167 1.17861 L F
.54986 1.16807 m .55522 1.18899 L .54997 1.16875 L 0 .539 .006 r
F
.55241 1.1837 m .55296 1.18669 L .55377 1.19157 L 0 0 .096 r
F
.55296 1.18669 m .55322 1.18819 L .55377 1.19157 L F
.55241 1.1837 m .55443 1.19539 L .55281 1.18584 L F
.55957 1.23161 m .56054 1.23859 L .56119 1.24391 L 0 0 .115 r
F
.55191 1.17982 m .55432 1.1865 L .55478 1.19047 L 0 .565 .019 r
F
.55178 1.17893 m .55522 1.18899 L .55191 1.17982 L F
.55342 1.18913 m .55375 1.19165 L .55612 1.20606 L 0 0 .102 r
F
.55446 1.19567 m .55612 1.20606 L .5548 1.19818 L F
.5548 1.19818 m .55517 1.20038 L .55446 1.1958 L F
.54902 1.16301 m .54839 1.15916 L .55073 1.16729 L 0 .539 .006 r
F
.5548 1.19818 m .55716 1.2131 L .55517 1.20038 L 0 0 .102 r
F
.55487 1.1977 m .55514 1.20034 L .55857 1.22324 L 0 0 .108 r
F
.55626 1.20779 m .55655 1.20931 L .55683 1.2117 L F
.55128 1.17745 m .55465 1.19219 L .55473 1.19295 L 0 .565 .019 r
F
.57401 1.36827 m .57217 1.34666 L .57656 1.39435 L 0 0 .058 r
F
.57042 1.33 m .57164 1.34043 L .57217 1.34666 L 0 0 .028 r
F
.57187 1.33451 m .57075 1.32106 L .57518 1.36284 L F
.56889 1.30604 m .5685 1.30004 L .56903 1.30715 L 0 .556 0 r
F
.57586 1.40127 m .5733 1.37049 L .5729 1.3654 L 0 0 .082 r
F
.56122 1.2442 m .56604 1.28118 L .56649 1.28665 L 0 .556 0 r
F
.56687 1.29179 m .57075 1.32106 L .57187 1.33451 L 0 0 .028 r
F
.56122 1.24422 m .56649 1.28665 L .56554 1.27907 L 0 .556 0 r
F
.56122 1.2442 m .56649 1.28665 L .56122 1.24422 L F
.56241 1.2536 m .56198 1.25035 L .56554 1.27907 L 0 0 .028 r
F
.56241 1.2536 m .57051 1.32766 L .57042 1.33 L F
.56277 1.25704 m .56852 1.31184 L .56674 1.29459 L F
.56852 1.31184 m .56843 1.31078 L .56674 1.29459 L F
.56275 1.25686 m .56852 1.31188 L .56277 1.25704 L F
.56852 1.31188 m .57042 1.33 L .56852 1.31184 L F
.56852 1.31188 m .56852 1.31184 L .56277 1.25704 L F
.56649 1.28665 m .56647 1.28661 L .56554 1.27907 L 0 .556 0 r
F
.56649 1.28665 m .57075 1.32106 L .56647 1.28661 L F
.56241 1.2536 m .56554 1.27907 L .56647 1.28661 L 0 0 .028 r
F
.56649 1.28665 m .5685 1.30003 L .56889 1.30604 L 0 .556 0 r
F
.56638 1.28569 m .56647 1.28661 L .57075 1.32106 L 0 0 .028 r
F
.56241 1.2536 m .56647 1.28661 L .56638 1.28569 L F
.56241 1.2536 m .56638 1.28569 L .56687 1.29179 L F
.57051 1.32766 m .57582 1.37618 L .57042 1.33 L F
.57042 1.33 m .57217 1.34666 L .57082 1.33372 L F
.56121 1.24412 m .5685 1.30002 L .56122 1.2442 L 0 .556 0 r
F
.5685 1.30002 m .5685 1.30003 L .56122 1.2442 L F
.57075 1.31725 m .57075 1.31725 L .56122 1.2442 L F
.57075 1.31725 m .57313 1.3286 L .57403 1.34244 L F
.56119 1.24391 m .57014 1.3074 L .57075 1.31725 L F
.57014 1.3074 m .57313 1.3286 L .57075 1.31725 L F
.57358 1.37794 m .57286 1.37008 L .57137 1.35146 L 0 0 .082 r
F
.56475 1.26808 m .56754 1.28536 L .5677 1.28811 L 0 .556 0 r
F
.56273 1.25437 m .56463 1.26659 L .56475 1.26808 L F
.56463 1.26659 m .56754 1.28536 L .56475 1.26808 L F
.56264 1.2534 m .56754 1.28536 L .56273 1.25437 L F
.5679 1.29152 m .57025 1.30539 L .57014 1.3074 L F
.56284 1.25568 m .5677 1.28811 L .5679 1.29152 L F
.56273 1.25437 m .5677 1.28811 L .56284 1.25568 L F
.57469 1.3815 m .5729 1.3654 L .56921 1.32442 L 0 0 .058 r
F
.56119 1.24391 m .56375 1.2595 L .56429 1.26313 L 0 .556 0 r
F
.56928 1.32317 m .56923 1.32409 L .56829 1.31256 L 0 0 .058 r
F
.56923 1.32409 m .56921 1.32442 L .56829 1.31256 L F
.56119 1.24391 m .56429 1.26313 L .56458 1.26606 L 0 .556 0 r
F
.56241 1.2536 m .57518 1.36284 L .57582 1.37618 L 0 0 .028 r
F
.56305 1.25598 m .56286 1.25602 L .56674 1.29459 L 0 0 .058 r
F
.56829 1.31256 m .56921 1.32442 L .56305 1.25598 L F
.57469 1.3815 m .56921 1.32442 L .56928 1.32317 L F
.56305 1.25598 m .57054 1.33914 L .56731 1.30242 L F
.57054 1.33914 m .57045 1.33785 L .56731 1.30242 L F
.56808 1.31023 m .56305 1.25598 L .56804 1.3098 L F
.56808 1.31023 m .56804 1.3098 L .57167 1.34885 L F
.57167 1.349 m .56808 1.31023 L .57167 1.34885 L F
.5655 1.28057 m .56674 1.29459 L .57039 1.3296 L F
.56305 1.25598 m .56541 1.28069 L .5655 1.28057 L F
.56541 1.28069 m .56674 1.29459 L .5655 1.28057 L F
.57542 1.4001 m .56977 1.33029 L .57586 1.40127 L 0 0 .082 r
F
.57054 1.33914 m .5729 1.3654 L .57045 1.33785 L 0 0 .058 r
F
.56552 1.28055 m .57039 1.3296 L .56977 1.32277 L F
.56305 1.25598 m .5655 1.28057 L .56552 1.28055 L F
.5655 1.28057 m .57039 1.3296 L .56552 1.28055 L F
.57403 1.37996 m .57354 1.37344 L .57586 1.40127 L 0 0 .082 r
F
.56977 1.33029 m .57354 1.37344 L .57403 1.37996 L F
.57042 1.33 m .5705 1.3307 L .56674 1.29459 L 0 0 .028 r
F
.5705 1.3307 m .57082 1.33372 L .57039 1.3296 L F
.5705 1.3307 m .57039 1.3296 L .56674 1.29459 L F
.56305 1.25598 m .56766 1.3018 L .56836 1.31042 L 0 0 .058 r
F
.56458 1.26606 m .56429 1.26313 L .56759 1.28538 L 0 .556 0 r
F
.56458 1.26606 m .56759 1.28538 L .56754 1.28536 L F
.55768 1.21621 m .56609 1.26481 L .56142 1.23821 L 0 .589 .025 r
F
.55716 1.2131 m .55766 1.216 L .55768 1.21621 L F
.55766 1.216 m .56609 1.26481 L .55768 1.21621 L F
.56119 1.24391 m .56264 1.2534 L .56273 1.25437 L 0 .556 0 r
F
.56152 1.24621 m .56112 1.24316 L .56165 1.24734 L 0 0 .12 r
F
.55463 1.19207 m .561 1.21743 L .5593 1.21247 L 0 .565 .019 r
F
.55443 1.19053 m .561 1.21743 L .55463 1.19207 L F
.55181 1.17964 m .561 1.21743 L .55186 1.18 L F
.55535 1.1952 m .5593 1.21247 L .55544 1.19607 L F
.55478 1.19047 m .55522 1.18899 L .55925 1.20705 L F
.55432 1.1865 m .55522 1.18899 L .55478 1.19047 L F
.55371 1.18456 m .55344 1.18227 L .55522 1.18899 L F
.55178 1.17559 m .5565 1.19219 L .55522 1.18899 L 0 .539 .006 r
F
.55163 1.1744 m .5565 1.19219 L .55178 1.17559 L F
.5516 1.16922 m .55285 1.16363 L .5568 1.17509 L 0 .627 .051 r
F
.5516 1.16922 m .55007 1.15822 L .55285 1.16363 L F
.5516 1.16922 m .5568 1.17509 L .55929 1.185 L F
.5516 1.16922 m .55929 1.185 L .55876 1.18743 L F
.5516 1.16922 m .55876 1.18743 L .55555 1.18072 L F
.55128 1.17745 m .55925 1.20705 L .561 1.21743 L 0 .565 .019 r
F
.55556 1.19936 m .5553 1.1955 L .5593 1.21247 L 0 .581 .025 r
F
.55443 1.19539 m .55507 1.19547 L .55556 1.19936 L F
.55507 1.19547 m .5553 1.1955 L .55556 1.19936 L F
.56119 1.24391 m .56054 1.23859 L .56375 1.2595 L 0 .556 0 r
F
.56115 1.24317 m .56103 1.24241 L .56152 1.24621 L 0 0 .12 r
F
.55619 1.20436 m .56294 1.2378 L .55859 1.21661 L 0 .581 .025 r
F
.55443 1.19539 m .55611 1.20377 L .55619 1.20436 L F
.55611 1.20377 m .56294 1.2378 L .55619 1.20436 L F
.56035 1.23655 m .56067 1.2394 L .56115 1.24317 L 0 0 .12 r
F
.55443 1.19539 m .56504 1.24517 L .56294 1.2378 L 0 .581 .025 r
F
.55443 1.19539 m .56348 1.23377 L .56504 1.24517 L F
.55443 1.19539 m .5593 1.21247 L .56348 1.23377 L F
.55716 1.2131 m .55612 1.20606 L .55859 1.21661 L 0 .589 .025 r
F
.55716 1.2131 m .55859 1.21661 L .56294 1.2378 L F
.55716 1.2131 m .56859 1.2755 L .56609 1.26481 L F
.55716 1.2131 m .56723 1.26305 L .56859 1.2755 L F
.55716 1.2131 m .56294 1.2378 L .56723 1.26305 L F
.55942 1.22973 m .55857 1.22324 L .56142 1.23821 L 0 .584 .017 r
F
.56638 1.28569 m .57075 1.32106 L .56687 1.29179 L 0 0 .028 r
F
.56817 1.30169 m .56775 1.29605 L .56801 1.30013 L 0 0 .1 r
F
.56419 1.26218 m .56493 1.26725 L .56428 1.2631 L 0 .584 .017 r
F
.56493 1.26725 m .5676 1.28544 L .56496 1.26763 L F
.56493 1.26725 m .56496 1.26763 L .56428 1.2631 L F
.5676 1.28544 m .56759 1.28538 L .56375 1.2595 L F
.56419 1.26218 m .56428 1.2631 L .56375 1.2595 L F
.55973 1.23184 m .5716 1.3082 L .56871 1.29297 L F
.55942 1.22973 m .5597 1.23153 L .55973 1.23184 L F
.5597 1.23153 m .5716 1.3082 L .55973 1.23184 L F
.57358 1.37794 m .57119 1.34838 L .57339 1.37502 L 0 0 .082 r
F
.57119 1.34838 m .57111 1.34689 L .57339 1.37502 L F
.57358 1.37794 m .57137 1.35146 L .57119 1.34838 L F
.57379 1.38126 m .57286 1.37008 L .57358 1.37794 L F
.57672 1.40329 m .56305 1.25598 L .57656 1.39435 L 0 0 .058 r
F
.56562 1.27814 m .56731 1.30242 L .5729 1.3654 L 0 0 .082 r
F
.56955 1.32762 m .56958 1.32795 L .57339 1.37502 L F
.56977 1.33029 m .56766 1.30275 L .57174 1.35181 L F
.57146 1.34962 m .57174 1.35181 L .57354 1.37344 L F
.56977 1.33029 m .57174 1.35181 L .57146 1.34962 L F
.56836 1.31042 m .57137 1.33872 L .57216 1.34932 L 0 0 .058 r
F
.56977 1.32277 m .57039 1.3296 L .57217 1.34666 L F
.56852 1.31184 m .57042 1.33 L .56843 1.31078 L 0 0 .028 r
F
.56766 1.3018 m .57137 1.33872 L .56836 1.31042 L 0 0 .058 r
F
.56658 1.2897 m .56674 1.2916 L .57062 1.33811 L 0 0 .082 r
F
.57065 1.33849 m .57062 1.33811 L .57101 1.34275 L F
.56658 1.2897 m .57062 1.33811 L .57065 1.33849 L F
.57189 1.35361 m .56655 1.28936 L .57101 1.34275 L F
.56655 1.28936 m .56658 1.2897 L .57101 1.34275 L F
.5733 1.37049 m .57189 1.35361 L .57226 1.3577 L F
.57189 1.35361 m .57101 1.34275 L .57226 1.3577 L F
.56604 1.28118 m .5685 1.30003 L .56649 1.28665 L 0 .556 0 r
F
.55942 1.22973 m .57047 1.29484 L .5716 1.3082 L 0 .584 .017 r
F
.55942 1.22973 m .56609 1.26481 L .57047 1.29484 L F
.57328 1.3715 m .56501 1.25949 L .57207 1.35904 L 0 0 .1 r
F
.55942 1.22973 m .56142 1.23821 L .56609 1.26481 L 0 .584 .017 r
F
.56501 1.25949 m .56244 1.22464 L .56507 1.26141 L 0 0 .1 r
F
.56501 1.25949 m .56507 1.26141 L .57207 1.35904 L F
.56307 1.24754 m .56576 1.28233 L .56562 1.27814 L 0 0 .082 r
F
.56576 1.28233 m .56731 1.30242 L .56562 1.27814 L F
.56444 1.26457 m .56958 1.32795 L .56955 1.32762 L F
.56444 1.26457 m .56449 1.26513 L .56958 1.32795 L F
.57533 1.39971 m .57358 1.37794 L .57542 1.4001 L F
.57358 1.37794 m .57339 1.37502 L .57542 1.4001 L F
.57524 1.39809 m .57328 1.3715 L .57286 1.37008 L 0 0 .1 r
F
.57328 1.3715 m .57207 1.35904 L .57286 1.37008 L F
.56575 1.27982 m .56307 1.24754 L .56578 1.2801 L 0 0 .082 r
F
.56578 1.28013 m .56578 1.2801 L .56579 1.28014 L F
.56575 1.27982 m .56578 1.2801 L .56578 1.28013 L F
.56775 1.29605 m .56244 1.22464 L .56762 1.29482 L 0 0 .1 r
F
.56775 1.29605 m .56762 1.29482 L .56801 1.30013 L F
.55942 1.22973 m .56419 1.26218 L .56375 1.2595 L 0 .584 .017 r
F
.5676 1.28544 m .56871 1.29297 L .56759 1.28538 L F
.56604 1.28449 m .56602 1.28447 L .56563 1.27967 L 0 0 .082 r
F
.56566 1.27975 m .56563 1.27967 L .56307 1.24754 L F
.56604 1.28449 m .56563 1.27967 L .56566 1.27975 L F
.54952 1.14662 m .55999 1.23373 L .56035 1.23655 L 0 0 .12 r
F
.55999 1.23373 m .56067 1.2394 L .56035 1.23655 L F
.56067 1.2394 m .56103 1.24241 L .56115 1.24317 L F
.56103 1.24241 m .56112 1.24316 L .56152 1.24621 L F
.56927 1.32447 m .56597 1.28351 L .56952 1.32731 L 0 0 .082 r
F
.56927 1.32447 m .56952 1.32731 L .57111 1.34689 L F
.57119 1.34838 m .56927 1.32447 L .57111 1.34689 L F
.56597 1.28351 m .56444 1.26457 L .56601 1.28403 L F
.56597 1.28351 m .56601 1.28403 L .57111 1.34689 L F
.57495 1.3858 m .5729 1.3654 L .57469 1.3815 L 0 0 .058 r
F
.5767 1.40324 m .57167 1.349 L .57672 1.40329 L F
.57167 1.349 m .57167 1.34885 L .57672 1.40329 L F
.5733 1.37049 m .57226 1.3577 L .5729 1.3654 L 0 0 .082 r
F
.57586 1.40127 m .5729 1.3654 L .5759 1.40163 L F
.57421 1.38237 m .56651 1.27923 L .57396 1.37959 L 0 0 .1 r
F
.56651 1.27923 m .56244 1.22464 L .5665 1.27925 L F
.56651 1.27923 m .5665 1.27925 L .57396 1.37959 L F
.57421 1.38237 m .57196 1.35046 L .56656 1.27916 L F
.56651 1.27923 m .56656 1.27916 L .56244 1.22464 L F
.57421 1.38237 m .56656 1.27916 L .56651 1.27923 L F
.57119 1.34838 m .57137 1.35146 L .56602 1.28447 L 0 0 .082 r
F
.57119 1.34838 m .56602 1.28447 L .56604 1.28449 L F
.56754 1.28536 m .56759 1.28538 L .56871 1.29297 L 0 .556 0 r
F
.56834 1.30403 m .56817 1.30169 L .56858 1.30783 L 0 0 .1 r
F
.56817 1.30169 m .56801 1.30013 L .56858 1.30783 L F
.57396 1.37959 m .56834 1.30403 L .57317 1.37003 L F
.56834 1.30403 m .56858 1.30783 L .57317 1.37003 L F
.56977 1.33029 m .56307 1.24754 L .56766 1.30275 L 0 0 .082 r
F
.57528 1.39667 m .57442 1.38467 L .57421 1.38237 L 0 0 .1 r
F
.57442 1.38467 m .57196 1.35046 L .57421 1.38237 L F
.56119 1.24391 m .56273 1.25437 L .56284 1.25568 L 0 .556 0 r
F
.5677 1.28811 m .57025 1.30539 L .5679 1.29152 L F
.57525 1.39693 m .57396 1.37959 L .57524 1.39809 L 0 0 .1 r
F
.57396 1.37959 m .57317 1.37003 L .57524 1.39809 L F
.57528 1.39667 m .57421 1.38237 L .57525 1.39693 L F
.57421 1.38237 m .57396 1.37959 L .57525 1.39693 L F
.5677 1.28811 m .56871 1.29297 L .57025 1.30539 L 0 .556 0 r
F
.56754 1.28536 m .56871 1.29297 L .5677 1.28811 L F
.57014 1.3074 m .57025 1.30539 L .57313 1.3286 L F
.5767 1.40324 m .57495 1.3858 L .57469 1.3815 L 0 0 .058 r
F
.57533 1.39971 m .57379 1.38126 L .57358 1.37794 L 0 0 .082 r
F
.5685 1.30002 m .57075 1.31725 L .5685 1.30003 L 0 .556 0 r
F
.57075 1.31725 m .57403 1.34244 L .57075 1.31725 L F
.56444 1.26457 m .56307 1.24754 L .56449 1.26513 L 0 0 .082 r
F
.56596 1.28232 m .56575 1.27982 L .56597 1.28241 L F
.56596 1.28232 m .56597 1.28241 L .56625 1.28575 L F
.56624 1.2857 m .56596 1.28232 L .56625 1.28575 L F
.56575 1.27982 m .56579 1.28014 L .56625 1.28575 L F
.56624 1.2857 m .56625 1.28575 L .56674 1.2916 L F
.56624 1.2857 m .56674 1.2916 L .56658 1.2897 L F
.56655 1.28936 m .56624 1.2857 L .56658 1.2897 L F
.56241 1.2536 m .56275 1.25686 L .56277 1.25704 L 0 0 .028 r
F
.56119 1.24391 m .56122 1.2442 L .56122 1.24422 L 0 .556 0 r
F
.5685 1.30003 m .5685 1.30004 L .56889 1.30604 L F
.56903 1.30715 m .57017 1.31398 L .57075 1.32106 L F
.57017 1.31398 m .57086 1.31815 L .57075 1.32106 L F
.5685 1.30004 m .57086 1.31815 L .56903 1.30715 L F
.57216 1.34932 m .57217 1.34666 L .57401 1.36827 L 0 0 .058 r
F
.57137 1.33872 m .57217 1.34666 L .57216 1.34932 L F
.57164 1.34043 m .57582 1.37618 L .57217 1.34666 L 0 0 .028 r
F
.57086 1.31815 m .57403 1.34244 L .57075 1.32106 L 0 .556 0 r
F
.56119 1.24391 m .56121 1.24412 L .56122 1.2442 L F
.56165 1.24734 m .56198 1.25035 L .56241 1.2536 L 0 0 .12 r
F
.56112 1.24316 m .56198 1.25035 L .56165 1.24734 L F
.55186 1.18 m .55443 1.19053 L .55463 1.19207 L 0 .565 .019 r
F
.55128 1.17745 m .55181 1.17964 L .55186 1.18 L F
.5565 1.19219 m .55459 1.18275 L .55555 1.18072 L 0 .735 .07 r
F
.54993 1.13956 m .56279 1.25542 L .56305 1.25598 L 0 0 .125 r
F
.56279 1.25542 m .56286 1.25602 L .56288 1.25602 L F
.56279 1.25542 m .56288 1.25602 L .56305 1.25598 L F
.55443 1.19539 m .55322 1.18819 L .5553 1.1955 L 0 .581 .025 r
F
.54746 1.14665 m .55514 1.20034 L .55487 1.1977 L 0 0 .108 r
F
.54746 1.14665 m .5561 1.20617 L .55626 1.20779 L F
.5561 1.20617 m .55655 1.20931 L .55626 1.20779 L F
.55473 1.19295 m .55535 1.1952 L .5553 1.1955 L 0 .565 .019 r
F
.55465 1.19219 m .55535 1.1952 L .55473 1.19295 L F
.55535 1.1952 m .55544 1.19607 L .5553 1.1955 L F
.55655 1.20931 m .55857 1.22324 L .55683 1.2117 L 0 0 .108 r
F
.55683 1.2117 m .55942 1.22973 L .55717 1.21393 L F
.55683 1.2117 m .55717 1.21393 L .55639 1.20839 L F
.5516 1.16922 m .54953 1.1606 L .55007 1.15822 L 0 .627 .051 r
F
.54869 1.14865 m .55639 1.20839 L .55959 1.23166 L 0 0 .115 r
F
.56025 1.23635 m .55959 1.23166 L .56054 1.23859 L F
.55417 1.1902 m .55959 1.23166 L .56025 1.23635 L F
.55919 1.22833 m .56054 1.23859 L .55957 1.23161 L F
.55957 1.23161 m .56119 1.24391 L .55979 1.23312 L F
.55645 1.20427 m .55784 1.21793 L .56198 1.25035 L 0 0 .12 r
F
.54952 1.14662 m .55573 1.19982 L .55645 1.20427 L F
.55573 1.19982 m .55784 1.21793 L .55645 1.20427 L F
.54869 1.14865 m .55406 1.18954 L .55417 1.1902 L 0 0 .115 r
F
.55406 1.18954 m .55959 1.23166 L .55417 1.1902 L F
.55752 1.21598 m .55919 1.22833 L .55957 1.23161 L F
.54869 1.14865 m .55736 1.21446 L .55752 1.21598 L F
.55736 1.21446 m .55919 1.22833 L .55752 1.21598 L F
.54746 1.14665 m .55446 1.1958 L .55514 1.20034 L 0 0 .108 r
F
.55386 1.18781 m .55957 1.23161 L .55784 1.21793 L 0 0 .115 r
F
.54869 1.14865 m .55398 1.18898 L .55386 1.18781 L F
.55398 1.18898 m .55957 1.23161 L .55386 1.18781 L F
.55128 1.17745 m .55178 1.17893 L .55191 1.17982 L 0 .565 .019 r
F
.55957 1.23161 m .55979 1.23312 L .55784 1.21793 L 0 0 .115 r
F
.55028 1.16939 m .55208 1.18151 L .55375 1.19165 L 0 0 .102 r
F
.55028 1.16939 m .55375 1.19165 L .55342 1.18913 L F
.55176 1.1764 m .55683 1.2117 L .55639 1.20839 L 0 0 .108 r
F
.54746 1.14665 m .55193 1.17766 L .55176 1.1764 L F
.55193 1.17766 m .55683 1.2117 L .55176 1.1764 L F
.55128 1.17745 m .55138 1.17674 L .55167 1.17861 L 0 .565 .019 r
F
.55007 1.17002 m .54999 1.17024 L .55322 1.18819 L 0 0 .096 r
F
.54388 1.13431 m .54999 1.17024 L .55007 1.17002 L F
.54585 1.14159 m .55022 1.16957 L .55028 1.16939 L 0 0 .102 r
F
.55022 1.16957 m .55208 1.18151 L .55028 1.16939 L F
.55344 1.18962 m .55446 1.19567 L .5548 1.19818 L F
.54585 1.14159 m .55329 1.18828 L .55344 1.18962 L F
.55329 1.18828 m .55446 1.19567 L .55344 1.18962 L F
.54585 1.14159 m .5548 1.19818 L .55446 1.1958 L F
.54388 1.13431 m .55175 1.17973 L .55214 1.18213 L 0 0 .096 r
F
.55175 1.17973 m .55193 1.1808 L .55214 1.18213 L F
.54388 1.13431 m .55214 1.18213 L .55208 1.18151 L F
.55214 1.18213 m .55193 1.1808 L .55241 1.1837 L F
.55214 1.18213 m .55241 1.1837 L .55231 1.18302 L F
.55193 1.1808 m .55296 1.18669 L .55241 1.1837 L F
.55214 1.18213 m .55231 1.18302 L .55208 1.18151 L F
.55241 1.1837 m .55281 1.18584 L .55208 1.18151 L F
.54774 1.15981 m .54767 1.15867 L .54786 1.15969 L 0 .539 .006 r
F
.54767 1.15867 m .54751 1.15611 L .54786 1.15969 L F
.54158 1.12549 m .54935 1.16713 L .5493 1.16641 L 0 0 .094 r
F
.54935 1.16713 m .55055 1.17357 L .54976 1.16901 L F
.54935 1.16713 m .54976 1.16901 L .5493 1.16641 L F
.53898 1.11565 m .54593 1.15136 L .54694 1.15577 L 0 0 .096 r
F
.54593 1.15136 m .54595 1.15146 L .54694 1.15577 L F
.54386 1.14274 m .54435 1.14446 L .54441 1.14474 L 0 .5 0 r
F
.54892 1.16484 m .54887 1.16478 L .54949 1.16786 L 0 0 .094 r
F
.54158 1.12549 m .54844 1.16245 L .54892 1.16484 L F
.54844 1.16245 m .54887 1.16478 L .54892 1.16484 L F
.54887 1.16478 m .54963 1.16884 L .54949 1.16786 L F
.55055 1.17357 m .54991 1.17033 L .55128 1.17745 L F
.54963 1.16884 m .54991 1.17033 L .55055 1.17357 L F
.54774 1.15981 m .54665 1.15484 L .54699 1.15534 L 0 .539 .006 r
F
.54774 1.15981 m .54699 1.15534 L .54768 1.15889 L F
.54665 1.15484 m .54623 1.1529 L .54627 1.15301 L F
.55055 1.17357 m .55128 1.17745 L .55077 1.17462 L 0 0 .094 r
F
.55055 1.17357 m .55077 1.17462 L .5493 1.16641 L F
.54699 1.15601 m .54623 1.1529 L .54774 1.15981 L 0 0 .096 r
F
.54595 1.15146 m .54623 1.1529 L .54699 1.15601 L F
.54386 1.14274 m .54363 1.14133 L .54405 1.14315 L 0 .5 0 r
F
.54363 1.14133 m .5431 1.13803 L .54405 1.14315 L F
0 g
.54301 1.13783 m
.5431 1.13803 L
s
.54589 1.14725 m
.54615 1.14782 L
s
.54615 1.14782 m
.54617 1.14785 L
s
.54627 1.14808 m
.54634 1.14823 L
s
.54296 1.13757 m
.5431 1.13803 L
s
.54858 .94152 m
.55135 .96477 L
s
.55135 .96477 m
.55273 .97639 L
s
.54783 .95447 m
.54858 .94152 L
s
.47565 .62644 m .466 .62277 L .46687 .62602 L 0 1 .523 r
F
.47565 .62644 m .47387 .61834 L .466 .62277 L F
0 g
.46533 .62701 m
.46687 .62602 L
s
.45953 .63072 m
.46533 .62701 L
s
.46816 .63095 m
.47565 .62644 L
s
.46687 .62602 m
.47565 .62644 L
s
.70013 .75431 m .70051 .74183 L .69707 .74299 L 0 .861 .416 r
F
0 g
.68827 .73475 m
.69707 .74299 L
s
.70013 .75431 m .70897 .75115 L .70051 .74183 L 0 .861 .416 r
F
0 g
.69191 .7445 m
.70013 .75431 L
s
.69707 .74299 m
.70013 .75431 L
s
.26707 .92104 m .25578 .91652 L .25658 .91835 L 0 .53 .256 r
F
0 g
.25139 .91787 m
.25658 .91835 L
s
.78089 .89466 m .78575 .87799 L .78134 .88117 L 0 1 .4 r
F
.76981 .9036 m .78089 .89466 L .77473 .8861 L 0 1 .387 r
F
.72622 1.10731 m .73665 1.08664 L .73435 1.08992 L 0 .861 .122 r
F
.67655 1.18657 m .68407 1.15683 L .6867 1.16473 L 0 .227 .11 r
F
0 g
.68407 1.15683 m
.6851 1.14628 L
s
.68125 1.1563 m
.68407 1.15683 L
s
.3461 .8433 m .33716 .83774 L .33556 .84648 L 0 1 .434 r
F
0 g
.32916 .84886 m
.33556 .84648 L
s
.3461 .8433 m .34297 .82756 L .33716 .83774 L 0 1 .434 r
F
.3461 .8433 m .34983 .82291 L .34297 .82756 L F
.3461 .8433 m .35317 .82688 L .34983 .82291 L F
.3461 .8433 m .35156 .83563 L .35317 .82688 L F
0 g
.34474 .85081 m
.3461 .8433 L
s
.33924 .84795 m
.3461 .8433 L
s
.39814 .8854 m .38992 .8745 L .39133 .878 L 0 .732 .445 r
F
.75562 .96522 m .75798 .98017 L .76314 .98716 L 0 1 .36 r
F
0 g
.76062 1.00043 m
.76314 .98716 L
s
.43429 .79379 m .42921 .78938 L .42551 .78902 L 0 .503 .341 r
F
.43429 .79379 m .43632 .7915 L .42921 .78938 L F
.43429 .79379 m .44296 .79466 L .43632 .7915 L F
.43429 .79379 m .44469 .79676 L .44296 .79466 L F
.43429 .79379 m .44097 .79638 L .44469 .79676 L F
0 g
.43091 .79297 m
.43429 .79379 L
s
.42767 .79063 m
.43429 .79379 L
s
.31164 .8503 m .30658 .84549 L .30127 .84812 L 0 1 .46 r
F
.31164 .8503 m .31359 .84364 L .30658 .84549 L F
.31164 .8503 m .31759 .84382 L .31359 .84364 L F
.31164 .8503 m .31675 .84668 L .31759 .84382 L F
0 g
.30467 .85214 m
.31164 .8503 L
s
.63457 .67299 m .64414 .68146 L .65331 .68713 L 0 .807 .467 r
F
0 g
.64414 .68146 m
.64933 .68827 L
s
.74933 1.01694 m .75047 1.0292 L .75473 1.0333 L 0 1 .343 r
F
0 g
.75047 1.0292 m
.75473 1.0333 L
s
.75131 1.04485 m
.75473 1.0333 L
s
.80092 .82174 m .80496 .82122 L .80068 .82368 L 0 0 0 r
F
.80092 .82174 m .81176 .81642 L .80496 .82122 L F
0 g
.79427 .82742 m
.79429 .8274 L
s
.79429 .8274 m
.79431 .82738 L
s
.2462 .84174 m .24055 .83405 L .2353 .83776 L 0 1 .508 r
F
.2462 .84174 m .24769 .83258 L .24055 .83405 L F
.2462 .84174 m .25192 .83434 L .24769 .83258 L F
.2462 .84174 m .25127 .83828 L .25192 .83434 L F
0 g
.23911 .84319 m
.2462 .84174 L
s
.24573 .84543 m
.2462 .84174 L
s
.70919 .76995 m
.70925 .77001 L
s
.71019 .77105 m
.71085 .77177 L
s
.53898 1.11565 m .53786 1.11151 L .53944 1.12018 L 0 0 .096 r
F
0 g
.53913 1.11846 m
.53914 1.11855 L
s
.5387 1.1161 m
.53913 1.11846 L
s
.53855 1.11526 m
.5387 1.1161 L
s
.53817 1.1132 m
.53855 1.11526 L
s
.53786 1.11151 m
.53817 1.1132 L
s
.53863 1.11073 m
.5389 1.11229 L
s
.53831 1.11088 m
.53868 1.11352 L
s
.5377 1.11062 m
.53786 1.11151 L
s
.5383 1.11503 m
.53898 1.11808 L
s
.53898 1.11808 m
.53899 1.11816 L
s
.55408 1.02196 m .55516 1.02976 L .55933 1.05215 L 0 0 .104 r
F
0 g
.55408 1.02196 m
.55591 1.02567 L
s
.55591 1.02567 m
.55636 1.02659 L
s
.55449 1.03944 m
.55479 1.04186 L
s
.55479 1.04186 m
.5551 1.04433 L
s
.55382 1.03415 m
.55449 1.03944 L
s
.55431 1.03899 m
.5545 1.04068 L
s
.5545 1.04068 m
.55462 1.04168 L
s
.55462 1.04168 m
.55498 1.04475 L
s
.55387 1.03525 m
.55431 1.03899 L
s
.55617 1.03821 m
.55665 1.03998 L
s
.55503 1.03394 m
.55617 1.03821 L
s
.55366 1.02877 m
.55503 1.03394 L
s
.55356 1.02675 m
.55454 1.0286 L
s
.5547 1.02889 m
.55516 1.02976 L
s
.55454 1.0286 m
.5547 1.02889 L
s
.554 1.01657 m
.55605 1.02528 L
s
.55605 1.02528 m
.55636 1.02659 L
s
.55357 1.02021 m
.55408 1.02196 L
s
.39814 .8854 m .39136 .87412 L .38992 .8745 L 0 .732 .445 r
F
.39814 .8854 m .39486 .87723 L .39136 .87412 L F
.39814 .8854 m .39808 .88175 L .39486 .87723 L F
.39814 .8854 m .39949 .88525 L .39808 .88175 L F
0 g
.39465 .8823 m
.39814 .8854 L
s
.75875 .91335 m .76235 .92945 L .76841 .93821 L 0 1 .373 r
F
0 g
.76685 .95228 m
.76841 .93821 L
s
.63501 .85776 m .6477 .81251 L .64179 .82527 L 0 1 .141 r
F
0 g
.64324 .84364 m
.64407 .83969 L
s
.64407 .83969 m
.64591 .83091 L
s
.64577 .82879 m
.64624 .82737 L
s
.64287 .83763 m
.64577 .82879 L
s
.64112 .84295 m
.64287 .83763 L
s
.6477 .81251 m
.64954 .81247 L
s
.6477 .81251 m
.64986 .80693 L
s
.41887 .78669 m
.42551 .78902 L
s
.76487 .72677 m .76531 .7084 L .76149 .70926 L 0 .794 .376 r
F
0 g
.75436 .69863 m
.76149 .70926 L
s
.63457 .67299 m .63123 .66496 L .62903 .66592 L 0 .807 .467 r
F
.63457 .67299 m .64041 .67063 L .63123 .66496 L F
.63457 .67299 m .65044 .67914 L .64041 .67063 L F
.63457 .67299 m .65596 .68621 L .65044 .67914 L F
.63457 .67299 m .65331 .68713 L .65596 .68621 L F
0 g
.64414 .68146 m
.65331 .68713 L
s
.62574 .66713 m
.63457 .67299 L
s
.65331 .68713 m
.65805 .69553 L
s
.72954 .85314 m
.73517 .86159 L
s
.73677 .864 m
.73687 .86414 L
s
.73517 .86159 m
.73677 .864 L
s
.72954 .85314 m
.73052 .86855 L
s
.53091 .60685 m .54229 .60511 L .55132 .60157 L 0 1 .529 r
F
0 g
.54229 .60511 m
.5503 .60608 L
s
.76487 .72677 m .77462 .72407 L .76531 .7084 L 0 .794 .376 r
F
.76487 .72677 m .78321 .74585 L .77462 .72407 L F
.76487 .72677 m .7866 .76339 L .78321 .74585 L F
.76487 .72677 m .78252 .76499 L .7866 .76339 L F
.76487 .72677 m .77321 .74928 L .78252 .76499 L F
0 g
.75577 .71039 m
.76487 .72677 L
s
.76149 .70926 m
.76487 .72677 L
s
.76322 .75239 m
.77184 .76793 L
s
.66451 .91933 m .67765 .90433 L .674 .91198 L 0 .202 .098 r
F
0 g
.67735 .89814 m
.67765 .90433 L
s
.67765 .90433 m
.68336 .89756 L
s
.40638 .89334 m
.40797 .89681 L
s
.40797 .89681 m
.41142 .90034 L
s
.67655 1.18657 m .67403 1.17567 L .67514 1.16255 L 0 .227 .11 r
F
0 g
.66978 1.1599 m
.67514 1.16255 L
s
.26931 .74929 m .25664 .74963 L .26062 .75119 L 0 1 .537 r
F
0 g
.2587 .75645 m
.26062 .75119 L
s
.53013 .62387 m .52226 .61973 L .52209 .62113 L 0 1 .431 r
F
0 g
.51376 .62147 m
.52209 .62113 L
s
.53013 .62387 m .53095 .62044 L .52226 .61973 L 0 1 .431 r
F
.53013 .62387 m .54237 .6228 L .53095 .62044 L F
.53013 .62387 m .55042 .62554 L .54237 .6228 L F
.53013 .62387 m .54972 .62683 L .55042 .62554 L F
.53013 .62387 m .54102 .62612 L .54972 .62683 L F
0 g
.54102 .62612 m
.54867 .62861 L
s
.52183 .62309 m
.53013 .62387 L
s
.52209 .62113 m
.53013 .62387 L
s
.42028 .90942 m .41143 .90034 L .41479 .905 L 0 .443 .388 r
F
0 g
.41479 .905 m
.4148 .90501 L
s
.55473 1.03773 m
.55579 1.04171 L
s
.55579 1.04171 m
.55613 1.04296 L
s
.55613 1.04296 m
.55621 1.04327 L
s
.55621 1.04327 m
.55666 1.04496 L
s
.55473 1.03773 m
.55479 1.0379 L
s
.55479 1.0379 m
.55551 1.03996 L
s
.55551 1.03996 m
.55639 1.04249 L
s
.55639 1.04249 m
.55649 1.04277 L
s
.55649 1.04277 m
.55685 1.04382 L
s
.55685 1.04382 m
.55754 1.04579 L
s
.72643 .88829 m .73052 .86856 L .72629 .87153 L 0 1 .346 r
F
0 g
.71922 .87648 m
.72602 .88763 L
s
.71485 .87359 m .72629 .87152 L .73052 .86856 L 0 1 .36 r
F
.71485 .87359 m .71958 .87368 L .72629 .87152 L F
0 g
.33242 .64076 m
.34212 .63761 L
s
.55629 1.04534 m
.5572 1.04852 L
s
.43723 .93403 m .43238 .92368 L .42876 .92186 L 0 .249 .27 r
F
.43723 .93403 m .43745 .92898 L .43238 .92368 L F
.43723 .93403 m .44058 .93422 L .43745 .92898 L F
.43723 .93403 m .44049 .93638 L .44058 .93422 L F
0 g
.43218 .92875 m
.43723 .93403 L
s
.43723 .93403 m
.43742 .93568 L
s
.25578 .91652 m .24519 .91401 L .24975 .91574 L 0 .545 .276 r
F
0 g
.24975 .91574 m
.25139 .91787 L
s
.7375 1.06948 m .73749 1.07747 L .74163 1.07637 L 0 1 .272 r
F
0 g
.73749 1.07747 m
.74163 1.07637 L
s
.73665 1.08664 m
.74163 1.07637 L
s
.38992 .8745 m .38304 .86722 L .38636 .87154 L 0 .814 .451 r
F
.31473 .63819 m .30701 .63303 L .30128 .63864 L 0 1 .539 r
F
.31473 .63819 m .31789 .62748 L .30701 .63303 L F
.31473 .63819 m .32817 .62507 L .31789 .62748 L F
.31473 .63819 m .33097 .62741 L .32817 .62507 L F
.31473 .63819 m .3252 .63304 L .33097 .62741 L F
0 g
.30929 .64349 m
.31473 .63819 L
s
.30449 .64059 m
.31473 .63819 L
s
.36482 .78406 m
.37175 .78037 L
s
.60976 .65483 m .61983 .66158 L .62903 .66592 L 0 .826 .464 r
F
0 g
.61983 .66158 m
.62574 .66713 L
s
.22439 .83364 m .21347 .8294 L .21259 .83383 L 0 1 .515 r
F
0 g
.20607 .83638 m
.21259 .83383 L
s
.71828 .79034 m .71987 .77604 L .7161 .77756 L 0 .921 .397 r
F
0 g
.71085 .77177 m
.7161 .77756 L
s
.71828 .79034 m .7279 .78612 L .71987 .77604 L 0 .921 .397 r
F
.71828 .79034 m .73483 .80107 L .7279 .78612 L F
.71828 .79034 m .737 .81385 L .73483 .80107 L F
.71828 .79034 m .73297 .81594 L .737 .81385 L F
.71828 .79034 m .72495 .80586 L .73297 .81594 L F
0 g
.71046 .77966 m
.71828 .79034 L
s
.7161 .77756 m
.71828 .79034 L
s
.72495 .80586 m
.72693 .81898 L
s
.77933 .83639 m
.77933 .83639 L
s
.3601 .84567 m
.36147 .83815 L
s
.3601 .84567 m
.36644 .84509 L
s
.69521 .69375 m .69406 .69026 L .69108 .69492 L 0 1 .203 r
F
.69521 .69375 m .70294 .6827 L .69406 .69026 L F
0 g
.55285 1.16363 m
.5568 1.17509 L
s
.55689 1.1724 m
.557 1.1694 L
s
.55681 1.17476 m
.55689 1.1724 L
s
.5568 1.17509 m
.55681 1.17476 L
s
.55285 1.16363 m
.55295 1.16103 L
s
.5492 1.15587 m
.54985 1.15762 L
s
.54889 1.15506 m
.5492 1.15587 L
s
.54989 1.15774 m
.55007 1.15822 L
s
.54718 1.15049 m
.54728 1.15073 L
s
.54733 1.15087 m
.54851 1.15405 L
s
.54855 1.15414 m
.54889 1.15506 L
s
.54704 1.1501 m
.54718 1.15049 L
s
.54704 1.15009 m
.54704 1.1501 L
s
.5469 1.14972 m
.54704 1.15009 L
s
.54634 1.14823 m
.5469 1.14972 L
s
.60976 .65483 m .60521 .64792 L .60349 .64898 L 0 .826 .464 r
F
.60976 .65483 m .61442 .65227 L .60521 .64792 L F
.60976 .65483 m .62497 .65911 L .61442 .65227 L F
.60976 .65483 m .63123 .66496 L .62497 .65911 L F
.60976 .65483 m .62903 .66592 L .63123 .66496 L F
0 g
.61983 .66158 m
.62903 .66592 L
s
.60092 .65035 m
.60976 .65483 L
s
.62903 .66592 m
.63457 .67299 L
s
.76981 .9036 m .77473 .8861 L .77033 .88951 L 0 1 .387 r
F
.75875 .91335 m .76981 .9036 L .76374 .89483 L 0 1 .373 r
F
0 g
.46529 .81482 m
.47088 .81938 L
s
.46529 .81482 m
.46782 .81591 L
s
.70223 1.15602 m .7003 1.15199 L .70193 1.14319 L 0 0 .058 r
F
0 g
.69681 1.1449 m
.70193 1.14319 L
s
.62732 .57989 m .62149 .57488 L .61978 .57749 L 0 1 .529 r
F
.62732 .57989 m .63196 .57355 L .62149 .57488 L F
.62732 .57989 m .64418 .57438 L .63196 .57355 L F
.42028 .90942 m .41214 .89734 L .41143 .90034 L 0 .443 .388 r
F
.72643 .88829 m .73711 .87981 L .73052 .86856 L 0 1 .346 r
F
.71485 .87359 m .73052 .86856 L .72997 .86559 L 0 1 .36 r
F
0 g
.72629 .87153 m
.72629 .87206 L
s
.71958 .87368 m
.72629 .87152 L
s
.48909 .99895 m
.49211 1.00053 L
s
.53091 .60685 m .55132 .60157 L .55201 .59858 L 0 1 .529 r
F
0 g
.55132 .60157 m
.5592 .60289 L
s
.54229 .60511 m
.55132 .60157 L
s
.30127 .84812 m .28993 .84793 L .29414 .84916 L 0 1 .435 r
F
0 g
.29404 .85254 m
.29414 .84916 L
s
.35761 .7955 m .36618 .7958 L .36239 .78873 L 0 .324 .341 r
F
.35761 .7955 m .36412 .79869 L .36618 .7958 L F
0 g
.35522 .79223 m
.35761 .7955 L
s
.25578 .91652 m .24448 .91199 L .24519 .91401 L 0 .545 .276 r
F
0 g
.23994 .91376 m
.24519 .91401 L
s
.38992 .8745 m .3817 .8635 L .38304 .86722 L 0 .814 .451 r
F
.31461 .64161 m .30115 .64237 L .30435 .64453 L 0 1 .535 r
F
0 g
.29148 .64189 m
.30128 .63864 L
s
.2996 .65117 m
.30435 .64453 L
s
.54796 1.15481 m
.54881 1.15796 L
s
.54589 1.14725 m
.54635 1.14892 L
s
.54881 1.15796 m
.54935 1.15994 L
s
.54943 1.16023 m
.54953 1.1606 L
s
.36508 .82109 m .36412 .79876 L .35761 .79564 L 0 .778 .408 r
F
0 g
.35505 .80214 m
.35761 .79564 L
s
.58389 .64077 m .59436 .64591 L .60349 .64898 L 0 .863 .45 r
F
0 g
.59436 .64591 m
.60092 .65035 L
s
.5613 .59553 m .57297 .59447 L .58262 .59157 L 0 1 .531 r
F
0 g
.57297 .59447 m
.58082 .59579 L
s
.49405 .84611 m .48847 .83781 L .48931 .83951 L 0 .115 .187 r
F
0 g
.49058 .84149 m
.49405 .84611 L
s
.48589 .83639 m
.48931 .83951 L
s
.39796 .62579 m
.40743 .62409 L
s
.55725 .63054 m .55042 .62554 L .54972 .62683 L 0 .924 .436 r
F
0 g
.54102 .62612 m
.54972 .62683 L
s
.55725 .63054 m .55938 .62739 L .55042 .62554 L 0 .924 .436 r
F
.55725 .63054 m .57064 .63116 L .55938 .62739 L F
.55725 .63054 m .57817 .63486 L .57064 .63116 L F
0 g
.56933 .63482 m
.57514 .63761 L
s
.55725 .63054 m .57696 .63603 L .57817 .63486 L 0 .924 .436 r
F
.55725 .63054 m .56799 .63418 L .57696 .63603 L F
0 g
.54867 .62861 m
.55725 .63054 L
s
.54972 .62683 m
.55725 .63054 L
s
.56799 .63418 m
.56933 .63482 L
s
.5613 .59553 m .58262 .59157 L .58382 .58876 L 0 1 .531 r
F
0 g
.58262 .59157 m
.59021 .59331 L
s
.57297 .59447 m
.58262 .59157 L
s
.65557 .7759 m .65682 .76632 L .65328 .77657 L 0 .922 .139 r
F
.64864 .79844 m .65557 .7759 L .64862 .79122 L 0 1 .138 r
F
.38992 .8745 m .38324 .86285 L .3817 .8635 L 0 .814 .451 r
F
.38992 .8745 m .38681 .86581 L .38324 .86285 L F
.38992 .8745 m .39003 .8704 L .38681 .86581 L F
.38992 .8745 m .39136 .87412 L .39003 .8704 L F
0 g
.38992 .8745 m
.39133 .878 L
s
.38636 .87154 m
.38992 .8745 L
s
.76805 .84157 m
.76852 .84264 L
s
.76852 .84264 m
.76869 .84302 L
s
.58389 .64077 m .57817 .63486 L .57696 .63603 L 0 .863 .45 r
F
.58389 .64077 m .58731 .63793 L .57817 .63486 L F
.58389 .64077 m .59828 .64319 L .58731 .63793 L F
.58389 .64077 m .60521 .64792 L .59828 .64319 L F
.58389 .64077 m .60349 .64898 L .60521 .64792 L F
0 g
.59436 .64591 m
.60349 .64898 L
s
.57696 .63603 m
.58389 .64077 L
s
.57514 .63761 m
.58389 .64077 L
s
.60349 .64898 m
.60976 .65483 L
s
.68336 .92378 m .69742 .94439 L .69336 .91617 L 0 .781 .284 r
F
.68336 .92378 m .69745 .97084 L .69742 .94439 L F
.68336 .92378 m .69341 .97776 L .69745 .97084 L F
.68336 .92378 m .68736 .95751 L .69341 .97776 L F
0 g
.68336 .92378 m
.68336 .91337 L
s
.68157 .91613 m
.68336 .92378 L
s
.56799 .63418 m
.57696 .63603 L
s
.33556 .84648 m
.33716 .83774 L
s
.29575 .75347 m
.2983 .74986 L
s
.46823 .97493 m .46096 .96506 L .46409 .96902 L 0 .226 0 r
F
0 g
.46409 .96902 m
.46481 .96947 L
s
.63135 .96198 m
.63203 .95306 L
s
.63203 .95306 m
.63225 .95022 L
s
.39949 .88525 m
.40302 .88865 L
s
.39808 .88175 m
.39949 .88525 L
s
.40606 .782 m .39623 .77937 L .39882 .78052 L 0 .848 .415 r
F
0 g
.39585 .78096 m
.39882 .78052 L
s
.76926 .8566 m .78575 .87799 L .78519 .86444 L 0 1 .401 r
F
.76926 .8566 m .78134 .88117 L .78575 .87799 L F
0 g
.78575 .87799 m
.79199 .8864 L
s
.78002 .84953 m .79238 .87337 L .7968 .87039 L 0 1 .412 r
F
.78002 .84953 m .78519 .86444 L .79238 .87337 L F
0 g
.79199 .8864 m
.79238 .87337 L
s
.54991 1.15897 m
.54998 1.15864 L
s
.55 1.15855 m
.55007 1.15822 L
s
.54978 1.15953 m
.54991 1.15897 L
s
.54973 1.15974 m
.54978 1.15953 L
s
.54953 1.1606 m
.54973 1.15974 L
s
.53898 1.11565 m .53944 1.12018 L .54267 1.1359 L 0 0 .096 r
F
0 g
.53899 1.11816 m
.53944 1.12018 L
s
.53914 1.11855 m
.53944 1.12018 L
s
.5417 1.13371 m
.54223 1.13609 L
s
.74772 .92409 m .76235 .92945 L .75875 .91335 L 0 1 .358 r
F
.74772 .92409 m .76169 .94526 L .76235 .92945 L F
0 g
.76235 .92945 m
.76841 .93821 L
s
.76926 .8566 m .77428 .87201 L .78134 .88117 L 0 1 .401 r
F
0 g
.77781 .87658 m
.78134 .88117 L
s
.78089 .89466 m
.78134 .88117 L
s
.78002 .84953 m .7968 .87039 L .79612 .85727 L 0 1 .412 r
F
0 g
.7968 .87039 m
.80312 .87871 L
s
.41214 .89734 m .40302 .88865 L .40638 .89334 L 0 .565 .412 r
F
0 g
.40638 .89334 m
.4064 .89335 L
s
.3817 .8635 m .37474 .8563 L .37806 .86069 L 0 .872 .448 r
F
.33911 .76431 m .34625 .76585 L .33815 .76162 L 0 .262 .216 r
F
.77453 .78849 m .77641 .76732 L .77234 .76883 L 0 .862 .357 r
F
0 g
.77184 .76793 m
.77234 .76883 L
s
.73711 .87981 m .7411 .86123 L .73687 .86415 L 0 1 .361 r
F
.725 .86461 m .73687 .86415 L .7411 .86123 L 0 1 .428 r
F
.725 .86461 m .72997 .86559 L .73687 .86415 L F
.71332 .8992 m .73084 .90771 L .72643 .88829 L 0 .946 .328 r
F
0 g
.72602 .88763 m
.72643 .88829 L
s
.71332 .8992 m .73015 .92684 L .73084 .90771 L 0 .946 .328 r
F
.71332 .8992 m .7248 .93293 L .73015 .92684 L F
.71332 .8992 m .71758 .92106 L .7248 .93293 L F
0 g
.71332 .8992 m
.714 .88096 L
s
.70334 .90774 m .71758 .92106 L .71332 .8992 L 0 .896 .313 r
F
0 g
.7078 .8863 m
.71332 .8992 L
s
.69336 .91617 m .70749 .93225 L .70334 .90774 L 0 .839 .298 r
F
.69336 .91617 m .70757 .95517 L .70749 .93225 L F
.69336 .91617 m .70352 .96115 L .70757 .95517 L F
.69336 .91617 m .69742 .94439 L .70352 .96115 L F
0 g
.69331 .89609 m
.69336 .91617 L
s
.68868 .90058 m
.69336 .91617 L
s
.24448 .91199 m .23379 .90967 L .23835 .91141 L 0 .56 .3 r
F
0 g
.23835 .91141 m
.23994 .91376 L
s
.75853 .86398 m .77473 .8861 L .77428 .87201 L 0 1 .388 r
F
.75853 .86398 m .77033 .88951 L .77473 .8861 L F
0 g
.77473 .8861 m
.78089 .89466 L
s
.70334 .90774 m .71773 .94145 L .71758 .92106 L 0 .896 .313 r
F
.70334 .90774 m .71366 .94672 L .71773 .94145 L F
.70334 .90774 m .70749 .93225 L .71366 .94672 L F
0 g
.69791 .89289 m
.70334 .90774 L
s
.70321 .88825 m
.70334 .90774 L
s
.7908 .84275 m .80343 .86604 L .80786 .86322 L 0 1 .423 r
F
0 g
.7888 .86892 m
.79238 .87337 L
s
.7908 .84275 m .79612 .85727 L .80343 .86604 L 0 1 .423 r
F
0 g
.80312 .87871 m
.80343 .86604 L
s
.44592 .61926 m .43515 .61739 L .43655 .61909 L 0 1 .496 r
F
.44592 .61926 m .44282 .61503 L .43515 .61739 L F
0 g
.42952 .62236 m
.43655 .61909 L
s
.44592 .61926 m .45444 .61358 L .44282 .61503 L 0 1 .496 r
F
.44592 .61926 m .46383 .61375 L .45444 .61358 L F
.44592 .61926 m .46471 .61544 L .46383 .61375 L F
.44592 .61926 m .45703 .6178 L .46471 .61544 L F
0 g
.43863 .62151 m
.44592 .61926 L
s
.43655 .61909 m
.44592 .61926 L
s
.73425 .82996 m .737 .81385 L .73297 .81594 L 0 1 .383 r
F
0 g
.72495 .80586 m
.73297 .81594 L
s
.73425 .82996 m .74448 .82418 L .737 .81385 L 0 1 .383 r
F
.73425 .82996 m .75043 .84004 L .74448 .82418 L F
.73425 .82996 m .74746 .85691 L .7517 .85407 L F
0 g
.75004 .82997 m
.75751 .84849 L
s
.75004 .82997 m
.75158 .85237 L
s
.75158 .85237 m
.7517 .85406 L
s
.74746 .85691 m
.74746 .85691 L
s
.73425 .82996 m .73998 .84658 L .74746 .85691 L 0 1 .383 r
F
0 g
.73297 .81594 m
.73425 .82996 L
s
.72693 .81898 m
.73425 .82996 L
s
.35707 .82783 m .35893 .82512 L .35805 .81423 L 0 .584 .313 r
F
0 g
.35805 .81414 m
.35823 .81432 L
s
.72643 .88829 m .74167 .89779 L .73711 .87981 L 0 1 .346 r
F
.72643 .88829 m .74182 .91458 L .74167 .89779 L F
.72643 .88829 m .73744 .91898 L .74182 .91458 L F
.72643 .88829 m .73085 .9077 L .73744 .91898 L F
0 g
.72629 .87206 m
.72643 .88829 L
s
.45703 .6178 m
.46604 .61785 L
s
.7908 .84275 m .80786 .86322 L .80707 .85045 L 0 1 .423 r
F
0 g
.80786 .86322 m
.81427 .8715 L
s
.75853 .86398 m .76339 .88003 L .77033 .88951 L 0 1 .388 r
F
0 g
.76686 .88477 m
.77033 .88951 L
s
.76981 .9036 m
.77033 .88951 L
s
.41864 .6338 m .4073 .63096 L .40917 .63402 L 0 1 .525 r
F
.41864 .6338 m .41434 .62609 L .4073 .63096 L F
.41864 .6338 m .4256 .62265 L .41434 .62609 L F
.41864 .6338 m .43509 .62243 L .4256 .62265 L F
.41864 .6338 m .43647 .62558 L .43509 .62243 L F
.41864 .6338 m .42941 .63045 L .43647 .62558 L F
0 g
.41196 .63867 m
.41864 .6338 L
s
.40917 .63402 m
.41864 .6338 L
s
.42876 .92186 m .42426 .91067 L .42029 .90942 L 0 .335 .343 r
F
0 g
.41993 .91209 m
.42029 .90942 L
s
.42876 .92186 m .42961 .91564 L .42426 .91067 L 0 .335 .343 r
F
.42876 .92186 m .43274 .92102 L .42961 .91564 L F
.42876 .92186 m .43238 .92368 L .43274 .92102 L F
0 g
.42344 .9169 m
.42876 .92186 L
s
.42868 .92403 m
.42876 .92186 L
s
.38712 .63511 m .375 .63299 L .37733 .63577 L 0 1 .529 r
F
0 g
.37152 .64068 m
.37733 .63577 L
s
.47775 .98622 m
.4813 .99006 L
s
.54166 1.03128 m .54779 1.08396 L .54389 1.05653 L 0 .636 .185 r
F
.54727 1.04854 m .55195 1.10158 L .55693 1.14114 L 0 .112 .168 r
F
.54727 1.04854 m .54783 1.06207 L .55195 1.10158 L F
.54856 1.08068 m .55693 1.14114 L .55195 1.10158 L 0 .057 .147 r
F
.54856 1.08068 m .56115 1.18467 L .55693 1.14114 L F
.55929 1.185 m .56671 1.19746 L .56354 1.19461 L 0 .741 .08 r
F
.5565 1.19219 m .55876 1.18743 L .56289 1.20086 L 0 .735 .07 r
F
.5565 1.19219 m .56289 1.20086 L .56521 1.21209 L F
.54856 1.08068 m .56175 1.20276 L .56115 1.18467 L 0 .057 .147 r
F
.54856 1.08068 m .55827 1.18116 L .56175 1.20276 L F
.54856 1.08068 m .5531 1.13478 L .55827 1.18116 L F
.54856 1.08068 m .54897 1.09196 L .5531 1.13478 L F
.54166 1.03128 m .55161 1.09567 L .54779 1.08396 L 0 .636 .185 r
F
.54727 1.04854 m .55924 1.12768 L .55505 1.08779 L 0 .112 .168 r
F
.54727 1.04854 m .56008 1.15246 L .55924 1.12768 L F
.54727 1.04854 m .55693 1.14114 L .56008 1.15246 L F
.54166 1.03128 m .55276 1.08365 L .55161 1.09567 L 0 .636 .185 r
F
.54727 1.04854 m .55505 1.08779 L .55034 1.05948 L 0 .112 .168 r
F
.54166 1.03128 m .55048 1.05815 L .55276 1.08365 L 0 .636 .185 r
F
.54166 1.03128 m .54631 1.03628 L .55048 1.05815 L F
0 g
.54417 1.01775 m
.54631 1.03628 L
s
.53911 1.02557 m
.54166 1.03128 L
s
.54387 1.02885 m
.54631 1.03628 L
s
.3817 .8635 m .37348 .85226 L .37474 .8563 L 0 .872 .448 r
F
0 g
.35156 .83563 m
.35815 .83341 L
s
.41214 .89734 m .404 .88517 L .40302 .88865 L 0 .565 .412 r
F
.49405 .84611 m .49234 .84161 L .48847 .83781 L 0 .115 .187 r
F
.49405 .84611 m .49834 .84839 L .49234 .84161 L F
.49405 .84611 m .50311 .85502 L .49834 .84839 L F
.49405 .84611 m .50345 .85706 L .50311 .85502 L F
.49405 .84611 m .49956 .85323 L .50345 .85706 L F
0 g
.48931 .83951 m
.49405 .84611 L
s
.75562 .96522 m .76169 .94526 L .75721 .95025 L 0 1 .36 r
F
.74772 .92409 m .75721 .95025 L .76169 .94526 L 0 1 .358 r
F
0 g
.76169 .94526 m
.76235 .92945 L
s
.76169 .94526 m
.76685 .95228 L
s
.73711 .87981 m .74781 .87171 L .7411 .86123 L 0 1 .361 r
F
.73711 .87981 m .75252 .8886 L .74781 .87171 L F
.73711 .87981 m .75276 .90427 L .75252 .8886 L F
.73711 .87981 m .74838 .90827 L .75276 .90427 L F
.73711 .87981 m .74167 .89779 L .74838 .90827 L F
0 g
.73052 .86856 m
.73711 .87981 L
s
.73687 .86415 m
.73711 .87981 L
s
.80496 .82122 m
.81176 .81642 L
s
.59359 .58644 m .61721 .5814 L .60929 .5795 L 0 1 .531 r
F
0 g
.61721 .5814 m
.62732 .57989 L
s
.63196 .57355 m .65497 .57321 L .65717 .57082 L 0 1 .531 r
F
.63196 .57355 m .64418 .57438 L .65497 .57321 L F
0 g
.65497 .57321 m
.66197 .57615 L
s
.64418 .57438 m
.65497 .57321 L
s
.64418 .57438 m
.65169 .57678 L
s
.38712 .63511 m .38163 .62799 L .375 .63299 L 0 1 .529 r
F
.38712 .63511 m .39282 .62413 L .38163 .62799 L F
.38712 .63511 m .40263 .62346 L .39282 .62413 L F
.38712 .63511 m .4045 .62644 L .40263 .62346 L F
.38712 .63511 m .39785 .63143 L .4045 .62644 L F
0 g
.40414 .63793 m
.40917 .63402 L
s
.38083 .64003 m
.38712 .63511 L
s
.37733 .63577 m
.38712 .63511 L
s
.80159 .83622 m .81451 .85911 L .81894 .85644 L 0 1 .433 r
F
0 g
.79981 .8617 m
.80343 .86604 L
s
.80159 .83622 m .80707 .85045 L .81451 .85911 L 0 1 .433 r
F
0 g
.81427 .8715 m
.81451 .85911 L
s
.24448 .91199 m .23318 .90743 L .23379 .90967 L 0 .56 .3 r
F
0 g
.22847 .90967 m
.23379 .90967 L
s
.725 .86461 m .7411 .86123 L .74038 .85774 L 0 1 .428 r
F
0 g
.73998 .84658 m
.7411 .86123 L
s
.53091 .60685 m .52266 .60271 L .52249 .60582 L 0 1 .529 r
F
.53091 .60685 m .53172 .59916 L .52266 .60271 L F
.53091 .60685 m .54361 .59754 L .53172 .59916 L F
.53091 .60685 m .55201 .59858 L .54361 .59754 L F
0 g
.52224 .61052 m
.53091 .60685 L
s
.26931 .74929 m .25959 .74506 L .25664 .74963 L 0 1 .537 r
F
0 g
.24858 .75279 m
.25664 .74963 L
s
.73998 .84658 m
.74719 .85654 L
s
.74736 .85678 m
.74746 .85691 L
s
.74719 .85654 m
.74736 .85678 L
s
.34895 .812 m .33918 .8282 L .34384 .82346 L 0 1 .246 r
F
.34895 .812 m .33741 .82354 L .33918 .8282 L F
.34895 .812 m .33972 .81259 L .33741 .82354 L F
0 g
.34384 .82346 m
.3462 .81816 L
s
.34895 .812 m .34485 .80114 L .33972 .81259 L 0 1 .246 r
F
0 g
.3462 .81816 m
.34895 .812 L
s
.3817 .8635 m .37512 .85126 L .37348 .85226 L 0 .872 .448 r
F
.3817 .8635 m .37876 .85407 L .37512 .85126 L F
.3817 .8635 m .38198 .85881 L .37876 .85407 L F
.3817 .8635 m .38324 .86285 L .38198 .85881 L F
0 g
.3817 .8635 m
.38304 .86722 L
s
.37806 .86069 m
.3817 .8635 L
s
.35707 .82783 m .34895 .81201 L .34983 .8229 L 0 .584 .313 r
F
.75875 .91335 m .76374 .89483 L .75935 .8985 L 0 1 .373 r
F
.74781 .87171 m .76374 .89483 L .76339 .88003 L 0 1 .375 r
F
.74781 .87171 m .75935 .8985 L .76374 .89483 L F
0 g
.76374 .89483 m
.76981 .9036 L
s
.74772 .92409 m .75875 .91335 L .75276 .90427 L 0 1 .358 r
F
0 g
.55754 1.04962 m
.55823 1.05199 L
s
.55629 1.04534 m
.55754 1.04962 L
s
.55829 1.05222 m
.55868 1.05354 L
s
.55823 1.05199 m
.55829 1.05222 L
s
.55806 1.05155 m
.55865 1.0536 L
s
.5572 1.04852 m
.55806 1.05155 L
s
.55824 1.05088 m
.55871 1.05265 L
s
.55802 1.05005 m
.55824 1.05088 L
s
.55666 1.04496 m
.55802 1.05005 L
s
.5551 1.04433 m
.55572 1.04924 L
s
.54654 1.14963 m
.54735 1.15258 L
s
.36872 .63116 m
.37508 .6295 L
s
.79 .82994 m
.79 .82995 L
s
.80159 .83622 m .81894 .85644 L .81805 .84394 L 0 1 .433 r
F
0 g
.81894 .85644 m
.82543 .8647 L
s
.64097 .85775 m .64264 .84651 L .63976 .86248 L 0 0 0 r
F
.63372 .90821 m .64097 .85775 L .63549 .8899 L 0 .717 .051 r
F
0 g
.64066 .85958 m
.64097 .85775 L
s
.63805 .88389 m
.64208 .86022 L
s
.64082 .85836 m
.64097 .85775 L
s
.63792 .88462 m
.63828 .88543 L
s
.63857 .88608 m
.63881 .88665 L
s
.63828 .88543 m
.63857 .88608 L
s
.63792 .88462 m
.63805 .88389 L
s
.39003 .8704 m
.39136 .87412 L
s
.39136 .87412 m
.39486 .87723 L
s
.37348 .85226 m .36644 .84509 L .36976 .84961 L 0 .899 .435 r
F
.74443 .98011 m .75798 .98017 L .75562 .96522 L 0 1 .343 r
F
.74443 .98011 m .75636 .99628 L .75798 .98017 L F
0 g
.75798 .98017 m
.76314 .98716 L
s
.31461 .64161 m .3069 .63624 L .30115 .64237 L 0 1 .535 r
F
0 g
.29134 .64573 m
.30115 .64237 L
s
.31461 .64161 m .3178 .63021 L .3069 .63624 L 0 1 .535 r
F
0 g
.30128 .63864 m
.30701 .63303 L
s
.31461 .64161 m .3281 .62727 L .3178 .63021 L 0 1 .535 r
F
.31461 .64161 m .33091 .62939 L .3281 .62727 L F
.31461 .64161 m .32512 .63554 L .33091 .62939 L F
0 g
.30915 .64777 m
.31461 .64161 L
s
.30435 .64453 m
.31461 .64161 L
s
.30127 .84812 m .29089 .84547 L .28993 .84793 L 0 1 .435 r
F
0 g
.28336 .84939 m
.28993 .84793 L
s
.74781 .87171 m .75252 .8886 L .75935 .8985 L 0 1 .375 r
F
0 g
.75252 .8886 m
.75595 .89357 L
s
.75595 .89357 m
.75935 .8985 L
s
.75875 .91335 m
.75935 .8985 L
s
.74781 .87171 m .76339 .88003 L .75853 .86398 L 0 1 .375 r
F
0 g
.76339 .88003 m
.76374 .89483 L
s
.76339 .88003 m
.76686 .88477 L
s
.31194 .75463 m .30381 .75223 L .30748 .75368 L 0 .884 .405 r
F
.46823 .97493 m .46069 .96495 L .46096 .96506 L 0 .226 0 r
F
0 g
.4567 .95973 m
.46096 .96506 L
s
.74781 .87171 m .7517 .85407 L .74746 .85692 L 0 1 .375 r
F
.74781 .87171 m .75853 .86398 L .7517 .85407 L F
0 g
.7411 .86123 m
.74781 .87171 L
s
.74746 .85692 m
.74781 .87171 L
s
.31194 .75463 m .30285 .75076 L .30381 .75223 L 0 .884 .405 r
F
.31194 .75463 m .30525 .75024 L .30285 .75076 L F
0 g
.29575 .75347 m
.30317 .75233 L
s
.30317 .75233 m
.30381 .75224 L
s
.31194 .75463 m .30972 .7512 L .30525 .75024 L 0 .884 .405 r
F
.31194 .75463 m .31328 .753 L .30972 .7512 L F
.31194 .75463 m .31423 .75447 L .31328 .753 L F
0 g
.31194 .75463 m
.31298 .75547 L
s
.30748 .75368 m
.31194 .75463 L
s
.40606 .782 m .3999 .77861 L .39623 .77937 L 0 .848 .415 r
F
.40606 .782 m .40739 .77873 L .3999 .77861 L F
.40606 .782 m .41466 .78022 L .40739 .77873 L F
.40606 .782 m .41683 .78208 L .41466 .78022 L F
.40606 .782 m .41314 .78284 L .41683 .78208 L F
0 g
.4027 .78219 m
.40606 .782 L
s
.39882 .78052 m
.40606 .782 L
s
.404 .88516 m .39486 .87723 L .39808 .88175 L 0 .661 .425 r
F
0 g
.39808 .88175 m
.39809 .88176 L
s
.76531 .7084 m
.77462 .72407 L
s
.76092 .69279 m
.76531 .7084 L
s
.5295 .90902 m .52771 .90682 L .52701 .9028 L 0 .474 0 r
F
0 g
.52458 .89565 m
.52701 .9028 L
s
.5295 .90902 m .53062 .91492 L .52771 .90682 L 0 .474 0 r
F
.53062 .91492 m .52875 .91037 L .52771 .90682 L F
.52342 .89744 m .52945 .91102 L .52614 .90317 L 0 0 .108 r
F
.52024 .89071 m .52478 .90072 L .52342 .89744 L F
.52478 .90072 m .52945 .91102 L .52342 .89744 L F
.53062 .91492 m .53163 .92018 L .52875 .91037 L 0 .474 0 r
F
.5295 .90902 m .53617 .934 L .53163 .92018 L F
.5295 .90902 m .53867 .94026 L .53792 .9384 L F
.53691 .93545 m .53792 .9384 L .53729 .9368 L F
.5295 .90902 m .53792 .9384 L .53691 .93545 L F
.5295 .90902 m .53729 .9368 L .53556 .93172 L F
.5295 .90902 m .53744 .93475 L .53867 .94026 L F
.5295 .90902 m .53351 .92135 L .53744 .93475 L F
.53164 .92019 m .53882 .93591 L .53375 .92195 L 0 0 .129 r
F
.53163 .92018 m .53167 .92028 L .53164 .92019 L F
.53167 .92028 m .53882 .93591 L .53164 .92019 L F
.5316 .92007 m .53375 .92195 L .52945 .91102 L F
.53163 .92018 m .53164 .92019 L .5316 .92007 L F
.53164 .92019 m .53375 .92195 L .5316 .92007 L F
.53556 .93172 m .53729 .9368 L .53617 .934 L 0 .474 0 r
F
0 g
.52788 .90201 m
.5295 .90902 L
s
.52701 .9028 m
.5295 .90902 L
s
.45521 .80601 m .44728 .79978 L .44901 .80171 L 0 .413 .332 r
F
0 g
.4482 .80151 m
.44901 .80171 L
s
.55667 1.03786 m
.5568 1.03854 L
s
.55617 1.03518 m
.55667 1.03786 L
s
.55609 1.03473 m
.55617 1.03518 L
s
.55581 1.03323 m
.55609 1.03473 L
s
.55516 1.02976 m
.55581 1.03323 L
s
.5568 1.03854 m
.55791 1.04454 L
s
.75853 .86398 m .77428 .87201 L .76926 .8566 L 0 1 .388 r
F
0 g
.77428 .87201 m
.77473 .8861 L
s
.77428 .87201 m
.77781 .87658 L
s
.33053 .75963 m .31862 .75548 L .32217 .757 L 0 .499 .368 r
F
0 g
.77321 .74928 m
.78209 .76426 L
s
.2353 .83776 m .22983 .82963 L .22439 .83364 L 0 1 .512 r
F
.2353 .83776 m .2371 .82801 L .22983 .82963 L F
.2353 .83776 m .24134 .82986 L .2371 .82801 L F
.2353 .83776 m .24055 .83405 L .24134 .82986 L F
0 g
.22807 .83936 m
.2353 .83776 L
s
.23469 .84167 m
.2353 .83776 L
s
.37348 .85226 m .36526 .84054 L .36644 .84509 L 0 .899 .435 r
F
.23318 .90743 m .22238 .90532 L .22694 .90706 L 0 .596 .326 r
F
0 g
.22694 .90706 m
.22847 .90967 L
s
.42941 .63045 m
.43853 .63036 L
s
.77453 .78849 m .78486 .78397 L .77641 .76732 L 0 .862 .357 r
F
0 g
.77321 .74928 m
.77641 .76732 L
s
.77453 .78849 m .79206 .8077 L .78486 .78397 L 0 .862 .357 r
F
.77453 .78849 m .79426 .82741 L .79206 .8077 L F
0 g
.78364 .83374 m
.78429 .83308 L
s
.77453 .78849 m .78999 .82994 L .79426 .82741 L 0 .862 .357 r
F
0 g
.79 .82994 m
.79 .82994 L
s
.77453 .78849 m .78153 .81324 L .78999 .82994 L 0 .862 .357 r
F
0 g
.76623 .771 m
.77453 .78849 L
s
.77234 .76883 m
.77453 .78849 L
s
.78429 .83308 m
.7891 .82817 L
s
.38909 .77898 m
.39623 .77937 L
s
.73517 .856 m .74746 .85691 L .7517 .85407 L 0 1 .465 r
F
.73517 .856 m .74038 .85774 L .74746 .85691 L F
.71851 .66294 m .73625 .65068 L .72634 .65393 L 0 1 .278 r
F
0 g
.73625 .65068 m
.7384 .65065 L
s
.28962 .93018 m .28159 .92529 L .27835 .92557 L 0 .493 .241 r
F
.28962 .93018 m .28734 .92657 L .28159 .92529 L F
.28962 .93018 m .29176 .92854 L .28734 .92657 L F
.28962 .93018 m .29273 .93009 L .29176 .92854 L F
0 g
.28389 .9289 m
.28962 .93018 L
s
.404 .88516 m .3962 .8734 L .39486 .87723 L 0 .661 .425 r
F
.37348 .85226 m .367 .83899 L .36526 .84054 L 0 .899 .435 r
F
.37348 .85226 m .37072 .84164 L .367 .83899 L F
.37348 .85226 m .37394 .84671 L .37072 .84164 L F
.37348 .85226 m .37512 .85126 L .37394 .84671 L F
0 g
.37348 .85226 m
.37474 .8563 L
s
.36976 .84961 m
.37348 .85226 L
s
.76926 .8566 m .78519 .86444 L .78002 .84953 L 0 1 .401 r
F
0 g
.78519 .86444 m
.7888 .86892 L
s
.78519 .86444 m
.78575 .87799 L
s
.74772 .92409 m .75276 .90427 L .74838 .90827 L 0 1 .358 r
F
0 g
.75252 .8886 m
.75276 .90427 L
s
.75276 .90427 m
.75875 .91335 L
s
.50838 .86808 m .50397 .85943 L .50432 .86054 L 0 0 .157 r
F
0 g
.50083 .85589 m
.50432 .86054 L
s
.42028 .90942 m .41647 .898 L .41214 .89734 L 0 .443 .388 r
F
.42028 .90942 m .42198 .90243 L .41647 .898 L F
.42028 .90942 m .42499 .90767 L .42198 .90243 L F
.42028 .90942 m .42426 .91067 L .42499 .90767 L F
0 g
.4148 .90501 m
.42028 .90942 L
s
.46823 .97493 m .46347 .96877 L .46069 .96495 L 0 .226 0 r
F
.46823 .97493 m .46761 .97471 L .46347 .96877 L F
.46823 .97493 m .47035 .97879 L .46761 .97471 L F
.46823 .97493 m .47061 .97888 L .47035 .97879 L F
0 g
.46823 .97493 m
.46879 .97425 L
s
.46409 .96902 m
.46823 .97493 L
s
.74167 .89779 m
.74838 .90827 L
s
.36526 .84054 m .35816 .83341 L .36147 .83814 L 0 .875 .405 r
F
.53898 1.11565 m .54615 1.15109 L .54253 1.13259 L 0 0 .096 r
F
.53898 1.11565 m .54774 1.15981 L .54615 1.15109 L F
0 g
.5477 1.15389 m
.54786 1.15446 L
s
.54735 1.15258 m
.5477 1.15389 L
s
.53898 1.11565 m .54267 1.1359 L .54623 1.1529 L 0 0 .096 r
F
0 g
.54069 1.12382 m
.54072 1.12395 L
s
.54007 1.12087 m
.54069 1.12382 L
s
.53977 1.11941 m
.54007 1.12087 L
s
.53929 1.11715 m
.53977 1.11941 L
s
.53898 1.11565 m
.53929 1.11715 L
s
.54032 1.12021 m
.54041 1.12072 L
s
.53956 1.11597 m
.54032 1.12021 L
s
.5389 1.11229 m
.53956 1.11597 L
s
.53868 1.11352 m
.53898 1.11565 L
s
.33715 .83774 m .32426 .84438 L .32914 .84494 L 0 1 .186 r
F
0 g
.32914 .84494 m
.32916 .84886 L
s
.33715 .83774 m .3251 .84043 L .32426 .84438 L 0 1 .186 r
F
.33715 .83774 m .33112 .83573 L .3251 .84043 L F
.33715 .83774 m .33916 .8285 L .33112 .83573 L F
.33715 .83774 m .34384 .82359 L .33916 .8285 L F
.33715 .83774 m .34297 .82756 L .34384 .82359 L F
0 g
.32914 .84494 m
.33715 .83774 L
s
.30115 .64237 m
.3069 .63624 L
s
.23318 .90743 m .22186 .90283 L .22238 .90532 L 0 .596 .326 r
F
0 g
.217 .90557 m
.22238 .90532 L
s
.70294 .6827 m .70154 .67922 L .69854 .68353 L 0 1 .216 r
F
.70294 .6827 m .7107 .67249 L .70154 .67922 L F
.75853 .86398 m .76231 .84711 L .75807 .84987 L 0 1 .388 r
F
0 g
.75807 .84987 m
.75807 .85007 L
s
.7517 .85407 m
.75174 .85407 L
s
.75174 .85407 m
.75813 .85388 L
s
.75807 .84987 m
.75813 .85388 L
s
.75853 .86398 m .76926 .8566 L .76231 .84711 L 0 1 .388 r
F
0 g
.75807 .85007 m
.75853 .86398 L
s
.76236 .84711 m
.76888 .84739 L
s
.7517 .85407 m
.75853 .86398 L
s
.36536 .63395 m
.375 .63299 L
s
.36526 .84054 m .35707 .82783 L .35816 .83341 L 0 .875 .405 r
F
0 g
.38198 .85881 m
.38324 .86285 L
s
.38324 .86285 m
.38681 .86581 L
s
.59359 .58644 m .58684 .58175 L .58563 .58455 L 0 1 .531 r
F
.59359 .58644 m .59699 .57958 L .58684 .58175 L F
.59359 .58644 m .60929 .5795 L .59699 .57958 L F
0 g
.56411 1.07492 m
.56413 1.075 L
s
.73517 .856 m .7517 .85407 L .75081 .85014 L 0 1 .465 r
F
.74772 .92409 m .75122 .94118 L .75721 .95025 L 0 1 .358 r
F
.74933 1.01694 m .75636 .99628 L .75185 1.00282 L 0 1 .343 r
F
.74443 .98011 m .75185 1.00282 L .75636 .99628 L F
0 g
.75636 .99628 m
.75798 .98017 L
s
.75636 .99628 m
.76062 1.00043 L
s
.3962 .8734 m .38681 .86581 L .39003 .8704 L 0 .728 .429 r
F
0 g
.77863 .83489 m
.77917 .83605 L
s
.77917 .83605 m
.77933 .83638 L
s
.74443 .98011 m .75562 .96522 L .75051 .95827 L 0 1 .343 r
F
0 g
.75562 .96522 m
.75721 .95025 L
s
.48344 .83237 m
.48569 .83385 L
s
.48344 .83237 m
.48847 .83781 L
s
.36526 .84054 m .35893 .82512 L .35707 .82783 L 0 .875 .405 r
F
.36526 .84054 m .36272 .82751 L .35893 .82512 L F
0 g
.35805 .81423 m
.35893 .82512 L
s
.36526 .84054 m .36592 .83341 L .36272 .82751 L 0 .875 .405 r
F
.36526 .84054 m .367 .83899 L .36592 .83341 L F
0 g
.36526 .84054 m
.36644 .84509 L
s
.36147 .83814 m
.36526 .84054 L
s
.78002 .84953 m .79612 .85727 L .7908 .84275 L 0 1 .412 r
F
0 g
.79612 .85727 m
.79981 .8617 L
s
.79612 .85727 m
.7968 .87039 L
s
.45521 .80601 m .45124 .80086 L .44728 .79978 L 0 .413 .332 r
F
.45521 .80601 m .45826 .80425 L .45124 .80086 L F
.45521 .80601 m .46449 .80857 L .45826 .80425 L F
.45521 .80601 m .46576 .81092 L .46449 .80857 L F
.45521 .80601 m .46178 .80982 L .46576 .81092 L F
0 g
.45159 .80446 m
.45521 .80601 L
s
.44901 .80171 m
.45521 .80601 L
s
.35707 .82783 m .34983 .8229 L .35317 .82688 L 0 .584 .313 r
F
0 g
.35317 .82688 m
.35707 .82783 L
s
.35707 .82783 m
.35816 .83341 L
s
.35316 .82689 m
.35317 .82688 L
s
.35156 .83563 m
.35316 .82689 L
s
.34895 .81201 m
.34983 .8229 L
s
.5613 .59553 m .55374 .59114 L .55305 .5941 L 0 1 .531 r
F
.5613 .59553 m .56341 .58823 L .55374 .59114 L F
.5613 .59553 m .5756 .58732 L .56341 .58823 L F
.5613 .59553 m .58382 .58876 L .5756 .58732 L F
0 g
.55201 .59858 m
.5613 .59553 L
s
.58382 .58876 m
.59359 .58644 L
s
.71681 .76472 m
.71987 .77604 L
s
.50838 .86808 m .50788 .8651 L .50397 .85943 L 0 0 .157 r
F
.50838 .86808 m .51738 .88275 L .51754 .88139 L F
.50838 .86808 m .51344 .87703 L .51738 .88275 L F
0 g
.50432 .86054 m
.50838 .86808 L
s
.71251 1.13272 m .72125 1.11896 L .71711 1.12755 L 0 0 .018 r
F
.71583 1.13175 m .72125 1.11896 L .72515 1.1103 L 0 0 0 r
F
.71583 1.13175 m .71711 1.12755 L .72125 1.11896 L F
0 g
.72125 1.11896 m
.7228 1.1126 L
s
.72125 1.11896 m
.72166 1.11806 L
s
.22186 .90283 m .21096 .90097 L .21553 .90271 L 0 .651 .352 r
F
0 g
.21553 .90271 m
.217 .90557 L
s
.80068 .82368 m
.80068 .82368 L
s
.3962 .8734 m .3884 .86143 L .38681 .86581 L 0 .728 .429 r
F
0 g
.73084 .90772 m
.73084 .90771 L
s
.48796 .61582 m
.49402 .61611 L
s
.74448 .82418 m .75043 .84004 L .75806 .84986 L 0 1 .396 r
F
0 g
.75043 .84004 m
.75781 .84954 L
s
.75043 .84004 m
.7517 .85407 L
s
.75805 .84983 m
.75806 .84986 L
s
.75789 .84943 m
.75805 .84983 L
s
.75751 .84849 m
.75789 .84943 L
s
.35893 .82512 m
.36272 .82751 L
s
.73672 .93607 m .74772 .92409 L .74182 .91458 L 0 1 .342 r
F
.73672 .93607 m .75122 .94118 L .74772 .92409 L F
0 g
.74772 .92409 m
.74838 .90827 L
s
.37394 .84671 m
.37512 .85126 L
s
.37512 .85126 m
.37876 .85407 L
s
.46069 .96495 m .45312 .95406 L .45625 .95865 L 0 0 .15 r
F
0 g
.45625 .95865 m
.4567 .95973 L
s
.73554 1.04154 m .75047 1.0292 L .74932 1.01694 L 0 1 .317 r
F
.73554 1.04154 m .74719 1.04589 L .75047 1.0292 L F
0 g
.74721 1.04579 m
.75047 1.0292 L
s
.76869 .84303 m
.7687 .8432 L
s
.76926 .8566 m .78002 .84953 L .77295 .84035 L 0 1 .401 r
F
0 g
.7687 .8432 m
.76926 .8566 L
s
.77299 .84035 m
.77958 .84107 L
s
.77295 .84035 m
.77299 .84035 L
s
.76231 .84711 m
.76926 .8566 L
s
.53585 1.03388 m
.5359 1.03403 L
s
.26931 .74929 m .26752 .7405 L .25959 .74506 L 0 1 .537 r
F
.26931 .74929 m .27626 .73858 L .26752 .7405 L F
.26931 .74929 m .27994 .7406 L .27626 .73858 L F
.26931 .74929 m .27695 .74519 L .27994 .7406 L F
0 g
.26658 .7534 m
.26931 .74929 L
s
.26062 .75119 m
.26931 .74929 L
s
.34814 .82406 m
.34983 .82291 L
s
.34803 .82413 m
.34814 .82406 L
s
.34297 .82756 m
.34803 .82413 L
s
.34383 .82362 m
.34384 .82359 L
s
.34382 .82364 m
.34383 .82362 L
s
.34297 .82756 m
.34382 .82364 L
s
.41214 .89734 m .40868 .8852 L .404 .88517 L 0 .565 .412 r
F
0 g
.40302 .88865 m
.404 .88517 L
s
.41214 .89734 m .41445 .88921 L .40868 .8852 L 0 .565 .412 r
F
.41214 .89734 m .41746 .89451 L .41445 .88921 L F
.41214 .89734 m .41647 .898 L .41746 .89451 L F
0 g
.4064 .89335 m
.41214 .89734 L
s
.41143 .90034 m
.41214 .89734 L
s
.44097 .79638 m
.44728 .79978 L
s
.27835 .92557 m .27044 .92056 L .26707 .92104 L 0 .514 .245 r
F
.27835 .92557 m .2763 .92167 L .27044 .92056 L F
.27835 .92557 m .28072 .92362 L .2763 .92167 L F
.27835 .92557 m .28159 .92529 L .28072 .92362 L F
0 g
.27252 .92446 m
.27835 .92557 L
s
.27835 .92557 m
.27935 .92711 L
s
.52024 .89071 m .51712 .8834 L .51695 .88291 L 0 0 .108 r
F
0 g
.51929 .88847 m
.52001 .89018 L
s
.51695 .88291 m
.51929 .88847 L
s
.51545 .87995 m
.51695 .88291 L
s
.74448 .82418 m .75806 .84986 L .76231 .8471 L 0 1 .396 r
F
0 g
.75781 .84954 m
.75806 .84986 L
s
.74536 .84774 m .75806 .84987 L .76231 .84711 L 0 1 .487 r
F
.74536 .84774 m .75081 .85014 L .75806 .84987 L F
.50235 .61203 m .51379 .60981 L .52249 .60582 L 0 1 .527 r
F
0 g
.51379 .60981 m
.52224 .61052 L
s
.73672 .93607 m .75051 .95827 L .75122 .94118 L 0 1 .342 r
F
0 g
.75122 .94118 m
.75721 .95025 L
s
.22186 .90283 m .21054 .89822 L .21096 .90097 L 0 .651 .352 r
F
0 g
.20552 .90148 m
.21096 .90097 L
s
.3884 .86143 m .37876 .85406 L .38198 .85881 L 0 .772 .428 r
F
.7908 .84275 m .80707 .85045 L .80159 .83622 L 0 1 .423 r
F
0 g
.80707 .85045 m
.80786 .86322 L
s
.80707 .85045 m
.81451 .85911 L
s
.74448 .82418 m .74709 .80849 L .74305 .81066 L 0 1 .396 r
F
.74448 .82418 m .75474 .81832 L .74709 .80849 L F
.74448 .82418 m .76089 .83359 L .75474 .81832 L F
.75474 .81832 m .76869 .84302 L .77294 .84034 L 0 1 .407 r
F
.77189 .84031 m .76869 .84303 L .77294 .84035 L 0 1 .5 r
F
.74448 .82418 m .76226 .84704 L .76089 .83359 L 0 1 .396 r
F
.76226 .84704 m .7623 .84701 L .76089 .83359 L F
.75474 .81832 m .76089 .83359 L .76869 .84302 L 0 1 .407 r
F
.75557 .83981 m .76818 .8429 L .77189 .84031 L 0 1 .5 r
F
.76818 .8429 m .76869 .84303 L .77189 .84031 L F
.76226 .84704 m .76231 .8471 L .7623 .84701 L 0 1 .396 r
F
0 g
.76052 .8244 m
.7606 .82542 L
s
.76129 .83407 m
.76175 .84 L
s
.76186 .84135 m
.76219 .8456 L
s
.76219 .8456 m
.76231 .8471 L
s
.76052 .8244 m
.76138 .82636 L
s
.737 .81385 m
.74448 .82418 L
s
.73672 .93607 m .74182 .91458 L .73744 .91898 L 0 1 .342 r
F
0 g
.74182 .91458 m
.74772 .92409 L
s
.74167 .89779 m
.74182 .91458 L
s
.73085 .9077 m
.73744 .91898 L
s
.69294 .89418 m .70683 .88381 L .7024 .88512 L 0 .806 .167 r
F
0 g
.70683 .88381 m
.70683 .88381 L
s
.367 .83899 m
.37072 .84164 L
s
.34824 .63178 m .33517 .63094 L .33796 .6333 L 0 1 .535 r
F
0 g
.33719 .63404 m
.33796 .6333 L
s
.30127 .84812 m .29642 .8434 L .29089 .84547 L 0 1 .435 r
F
.30127 .84812 m .30358 .84235 L .29642 .8434 L F
.30127 .84812 m .30758 .84301 L .30358 .84235 L F
.30127 .84812 m .30658 .84549 L .30758 .84301 L F
0 g
.30046 .85096 m
.30127 .84812 L
s
.29414 .84916 m
.30127 .84812 L
s
.5445 .94106 m .54509 .9583 L .54332 .94267 L 0 .899 .096 r
F
0 g
.54332 .94267 m
.5445 .94106 L
s
.54066 .92895 m
.54332 .94267 L
s
.54321 .93214 m
.5445 .94106 L
s
.37282 .83593 m .36273 .82751 L .36592 .83341 L 0 .791 .411 r
F
.37282 .83593 m .36508 .82109 L .36273 .82751 L F
0 g
.36592 .83341 m
.367 .83899 L
s
.67913 .71182 m
.68087 .71345 L
s
.48523 .61628 m
.49402 .61722 L
s
.3884 .86143 m .3806 .84906 L .37876 .85406 L 0 .772 .428 r
F
.29089 .84547 m .27938 .84462 L .2836 .84599 L 0 1 .438 r
F
0 g
.28336 .84939 m
.2836 .84599 L
s
.39785 .63143 m
.4073 .63096 L
s
.25959 .74506 m .24669 .74557 L .25068 .74723 L 0 1 .539 r
F
0 g
.24858 .75279 m
.25068 .74723 L
s
.63196 .57355 m .65717 .57082 L .64932 .56824 L 0 1 .531 r
F
0 g
.65717 .57082 m
.6678 .57038 L
s
.74536 .84774 m .76231 .84711 L .76125 .8428 L 0 1 .487 r
F
0 g
.7617 .84131 m
.7623 .84701 L
s
.7623 .84701 m
.76231 .8471 L
s
.31328 .753 m
.31423 .75447 L
s
.31423 .75447 m
.31862 .75548 L
s
.71583 1.13175 m .72515 1.1103 L .72622 1.10731 L 0 0 0 r
F
0 g
.72515 1.1103 m
.72747 1.10698 L
s
.52024 .89071 m .52105 .89207 L .51712 .8834 L 0 0 .108 r
F
0 g
.51759 .88292 m
.51964 .88896 L
s
.52024 .89071 m .52875 .91035 L .52945 .91102 L 0 0 .108 r
F
.52024 .89071 m .5248 .90163 L .52875 .91035 L F
.50422 1.01567 m .50073 1.02072 L .5021 1.01641 L 0 .652 .092 r
F
.50422 1.01567 m .50118 1.02776 L .50073 1.02072 L F
.50422 1.01567 m .50316 1.03284 L .50118 1.02776 L F
0 g
.50204 1.01079 m
.5021 1.01641 L
s
.50422 1.01567 m .5053 1.03207 L .50316 1.03284 L 0 .652 .092 r
F
.50422 1.01567 m .50616 1.02599 L .5053 1.03207 L F
.50422 1.01567 m .5057 1.01896 L .50616 1.02599 L F
0 g
.5057 1.01896 m
.50746 1.01489 L
s
.50418 1.01151 m
.50422 1.01567 L
s
.5021 1.01641 m
.50422 1.01567 L
s
.7279 .78612 m .73483 .80107 L .74305 .81066 L 0 .976 .409 r
F
0 g
.73483 .80107 m
.737 .81385 L
s
.33053 .75963 m .32194 .75456 L .31862 .75548 L 0 .499 .368 r
F
.3806 .84906 m .37072 .84164 L .37394 .84671 L 0 .792 .421 r
F
.46069 .96495 m .45315 .95325 L .45312 .95406 L 0 0 .15 r
F
0 g
.44859 .94852 m
.45312 .95406 L
s
.21054 .89822 m .19954 .89661 L .20411 .89835 L 0 .708 .376 r
F
0 g
.20411 .89835 m
.20552 .90148 L
s
.7279 .78612 m .72929 .77192 L .72552 .77362 L 0 .976 .409 r
F
.7279 .78612 m .73752 .78152 L .72929 .77192 L F
.7279 .78612 m .74472 .79601 L .73752 .78152 L F
.7279 .78612 m .74709 .80849 L .74472 .79601 L F
.7279 .78612 m .74305 .81066 L .74709 .80849 L F
0 g
.73483 .80107 m
.74305 .81066 L
s
.72552 .77362 m
.7279 .78612 L
s
.71987 .77604 m
.7279 .78612 L
s
.74305 .81066 m
.74448 .82418 L
s
.3806 .84906 m .37282 .83593 L .37072 .84164 L 0 .792 .421 r
F
.41443 .62082 m .4027 .61966 L .40459 .62147 L 0 1 .521 r
F
0 g
.40141 .62354 m
.40459 .62147 L
s
.41443 .62082 m .4218 .61358 L .41007 .61628 L 0 1 .521 r
F
.41443 .62082 m .43166 .61293 L .4218 .61358 L F
.41443 .62082 m .43306 .61475 L .43166 .61293 L F
.41443 .62082 m .42567 .61814 L .43306 .61475 L F
0 g
.40459 .62147 m
.41443 .62082 L
s
.40743 .62409 m
.41443 .62082 L
s
.62833 .89782 m .64264 .84651 L .64062 .84447 L 0 1 .147 r
F
0 g
.64094 .8448 m
.64133 .84519 L
s
.64133 .84519 m
.64189 .84576 L
s
.62833 .89782 m .63976 .86248 L .64264 .84651 L 0 1 .147 r
F
0 g
.64264 .84651 m
.64324 .84364 L
s
.6396 .86577 m
.64066 .85958 L
s
.64037 .8601 m
.64082 .85836 L
s
.64189 .84576 m
.64264 .84651 L
s
.44585 .62566 m .43509 .62243 L .43647 .62558 L 0 1 .524 r
F
.44585 .62566 m .44279 .61776 L .43509 .62243 L F
0 g
.43571 .6261 m
.43647 .62558 L
s
.42941 .63045 m
.43571 .6261 L
s
.44585 .62566 m .45443 .61467 L .44279 .61776 L 0 1 .524 r
F
.44585 .62566 m .46382 .61475 L .45443 .61467 L F
.44585 .62566 m .46469 .61794 L .46382 .61475 L F
.44585 .62566 m .45699 .62262 L .46469 .61794 L F
0 g
.43853 .63036 m
.44585 .62566 L
s
.43647 .62558 m
.44585 .62566 L
s
.45699 .62262 m
.466 .62277 L
s
.77933 .83639 m
.77934 .83654 L
s
.78002 .84953 m .7908 .84275 L .7836 .83379 L 0 1 .412 r
F
0 g
.77934 .83654 m
.78002 .84953 L
s
.78365 .8338 m
.79031 .83492 L
s
.7836 .83379 m
.78365 .8338 L
s
.77295 .84035 m
.78002 .84953 L
s
.34822 .63229 m .33512 .63252 L .33793 .63458 L 0 1 .537 r
F
0 g
.34214 .63687 m
.34741 .63247 L
s
.33242 .64076 m
.33793 .63458 L
s
.5356 .92231 m
.53756 .93244 L
s
.5378 .93368 m
.53783 .93382 L
s
.53783 .93382 m
.53792 .93431 L
s
.53357 .92138 m
.5356 .92231 L
s
.53354 .92136 m
.53357 .92138 L
s
.53351 .92135 m
.53354 .92136 L
s
.404 .88516 m .40121 .8728 L .3962 .8734 L 0 .661 .425 r
F
.404 .88516 m .40714 .87622 L .40121 .8728 L F
.404 .88516 m .41003 .88137 L .40714 .87622 L F
.404 .88516 m .40868 .8852 L .41003 .88137 L F
0 g
.39809 .88176 m
.404 .88516 L
s
.22439 .83364 m .21909 .82507 L .21347 .8294 L 0 1 .515 r
F
0 g
.21259 .83383 m
.21347 .8294 L
s
.22439 .83364 m .22651 .82326 L .21909 .82507 L 0 1 .515 r
F
.22439 .83364 m .23075 .82518 L .22651 .82326 L F
.22439 .83364 m .22983 .82963 L .23075 .82518 L F
0 g
.21702 .83543 m
.22439 .83364 L
s
.22365 .8378 m
.22439 .83364 L
s
.50235 .61203 m .49314 .60814 L .49349 .61131 L 0 1 .527 r
F
.50235 .61203 m .50185 .60414 L .49314 .60814 L F
.50235 .61203 m .51382 .60199 L .50185 .60414 L F
.50235 .61203 m .52266 .60271 L .51382 .60199 L F
.50235 .61203 m .52249 .60582 L .52266 .60271 L F
0 g
.52249 .60582 m
.53091 .60685 L
s
.49349 .61131 m
.50235 .61203 L
s
.49402 .61611 m
.50235 .61203 L
s
.51379 .60981 m
.52249 .60582 L
s
.53936 1.10997 m
.53943 1.11049 L
s
.53943 1.11049 m
.53971 1.11241 L
s
.53971 1.11241 m
.5398 1.11305 L
s
.53936 1.10997 m
.53948 1.11066 L
s
.53948 1.11066 m
.53993 1.11326 L
s
.53993 1.11326 m
.54013 1.11442 L
s
.54013 1.11442 m
.54129 1.12109 L
s
.47388 .61652 m .46383 .61375 L .46471 .61544 L 0 1 .48 r
F
.47388 .61652 m .47301 .61451 L .46383 .61375 L F
.47387 .61834 m .47301 .61451 L .46382 .61475 L 0 1 .525 r
F
.47301 .61451 m .47208 .61038 L .46663 .61327 L F
.47388 .61652 m .4768 .61525 L .47301 .61451 L 0 1 .48 r
F
.47301 .61451 m .48396 .60773 L .47208 .61038 L 0 1 .525 r
F
.4768 .61525 m .47682 .61524 L .47301 .61451 L 0 1 .48 r
F
.47387 .61834 m .47682 .61524 L .47301 .61451 L 0 1 .525 r
F
.47682 .61524 m .48396 .60773 L .47301 .61451 L F
.47682 .61524 m .48394 .61214 L .47301 .61451 L 0 1 .48 r
F
.47301 .61451 m .48394 .61214 L .47207 .61234 L F
.47301 .61451 m .46663 .61327 L .46661 .61328 L 0 1 .525 r
F
.47301 .61451 m .46661 .61328 L .46383 .61375 L 0 1 .48 r
F
.47301 .61451 m .46661 .61328 L .46382 .61475 L 0 1 .525 r
F
.47301 .61451 m .47207 .61234 L .46661 .61328 L 0 1 .48 r
F
0 g
.46604 .61785 m
.47042 .61711 L
s
.80159 .83622 m .81805 .84394 L .81241 .82992 L 0 1 .433 r
F
0 g
.81805 .84394 m
.81894 .85644 L
s
.64864 .79844 m .64862 .79122 L .64595 .80051 L 0 1 .138 r
F
.64179 .82527 m .64864 .79844 L .64196 .81569 L 0 1 .139 r
F
0 g
.31675 .84668 m
.32426 .84438 L
s
.71681 .76472 m
.72552 .77362 L
s
.21054 .89822 m .19921 .89358 L .19954 .89661 L 0 .708 .376 r
F
0 g
.19404 .89739 m
.19954 .89661 L
s
.65494 .92333 m .65923 .93276 L .65554 .9378 L 0 .402 .159 r
F
0 g
.65547 .93625 m
.65554 .9378 L
s
.65494 .92333 m .66451 .91933 L .65923 .93276 L 0 .402 .159 r
F
0 g
.65494 .92333 m
.65547 .93625 L
s
.65283 .93423 m
.65494 .92333 L
s
.65007 .94849 m
.65283 .93423 L
s
.26707 .92104 m .25929 .91582 L .25578 .91652 L 0 .53 .256 r
F
.26707 .92104 m .26524 .91676 L .25929 .91582 L F
.26707 .92104 m .26967 .91873 L .26524 .91676 L F
.26707 .92104 m .27044 .92056 L .26967 .91873 L F
0 g
.26114 .92009 m
.26707 .92104 L
s
.26707 .92104 m
.26797 .9227 L
s
.34824 .63178 m .34158 .62564 L .33517 .63094 L 0 1 .535 r
F
.34824 .63178 m .35295 .62094 L .34158 .62564 L F
.34824 .63178 m .36326 .61942 L .35295 .62094 L F
0 g
.34432 .63236 m
.34824 .63178 L
s
.34762 .6323 m
.34824 .63178 L
s
.42921 .78938 m .42009 .78477 L .42226 .78651 L 0 .692 .41 r
F
0 g
.41887 .78669 m
.42226 .78651 L
s
.55713 1.04219 m
.55793 1.04582 L
s
.55696 1.04142 m
.55713 1.04219 L
s
.55665 1.03998 m
.55696 1.04142 L
s
.71758 .92106 m
.71758 .92108 L
s
.65237 .75227 m .66894 .73613 L .67187 .72986 L 0 1 .307 r
F
0 g
.6624 .75568 m
.66475 .75119 L
s
.6631 .75231 m
.66475 .75119 L
s
.66594 .74403 m
.66718 .74211 L
s
.65237 .75227 m .6606 .74572 L .66894 .73613 L 0 1 .307 r
F
0 g
.66894 .73613 m
.67229 .73413 L
s
.66892 .73616 m
.66894 .73613 L
s
.78486 .78397 m .7866 .76339 L .78252 .76499 L 0 .898 .367 r
F
0 g
.78209 .76426 m
.78252 .76499 L
s
.70241 .88512 m .71958 .87368 L .71485 .87359 L 0 1 .228 r
F
0 g
.71922 .87647 m
.71958 .87368 L
s
.77102 .81881 m
.77294 .84034 L
s
.75557 .83981 m .76125 .8428 L .76869 .84303 L 0 1 .5 r
F
0 g
.76804 .84301 m
.76869 .84303 L
s
.76089 .83359 m
.76631 .84014 L
s
.76089 .83359 m
.76156 .84 L
s
.70897 .75115 m .70912 .73852 L .70567 .73992 L 0 .922 .426 r
F
.70897 .75115 m .71783 .74743 L .70912 .73852 L F
0 g
.70051 .74183 m
.70897 .75115 L
s
.65237 .75227 m .67187 .72986 L .66763 .72963 L 0 1 .307 r
F
0 g
.67187 .72986 m
.67844 .72109 L
s
.37498 .77893 m .36262 .77936 L .36655 .78001 L 0 1 .523 r
F
0 g
.36655 .78001 m
.37497 .77893 L
s
.36468 .78386 m
.36655 .78001 L
s
.37175 .78037 m
.37498 .77893 L
s
.74443 .98011 m .75051 .95827 L .74604 .96398 L 0 1 .343 r
F
.73672 .93607 m .74604 .96398 L .75051 .95827 L 0 1 .342 r
F
0 g
.75051 .95827 m
.75122 .94118 L
s
.75051 .95827 m
.75562 .96522 L
s
.34822 .63229 m .34154 .62716 L .33512 .63252 L 0 1 .537 r
F
0 g
.32805 .63244 m
.33517 .63094 L
s
.34822 .63229 m .35292 .62207 L .34154 .62716 L 0 1 .537 r
F
.34822 .63229 m .36325 .61976 L .35292 .62207 L F
0 g
.34212 .63761 m
.34822 .63229 L
s
.33793 .63458 m
.34822 .63229 L
s
.64578 .77094 m .66457 .74617 L .6606 .74572 L 0 1 .293 r
F
.64578 .77094 m .66166 .75329 L .66457 .74617 L F
0 g
.65881 .76253 m
.6624 .75568 L
s
.66457 .74617 m
.66594 .74403 L
s
.45699 .62262 m
.46317 .61887 L
s
.48085 .99239 m .47446 .98402 L .4772 .98692 L 0 .384 0 r
F
0 g
.4772 .98692 m
.47775 .98622 L
s
.37498 .77893 m .36553 .7762 L .36262 .77936 L 0 1 .523 r
F
.37498 .77893 m .37337 .77263 L .36553 .7762 L F
.37498 .77893 m .38183 .77154 L .37337 .77263 L F
.37498 .77893 m .38524 .77367 L .38183 .77154 L F
.37498 .77893 m .3823 .77683 L .38524 .77367 L F
0 g
.37497 .77893 m
.37498 .77893 L
s
.7375 1.06948 m .74719 1.04589 L .74166 1.05593 L 0 1 .272 r
F
.73554 1.04154 m .74166 1.05593 L .74719 1.04589 L 0 1 .317 r
F
0 g
.74719 1.04589 m
.74721 1.04579 L
s
.74719 1.04589 m
.75131 1.04486 L
s
.56393 1.07455 m
.56419 1.0757 L
s
.47464 .82185 m .46767 .81428 L .46894 .81639 L 0 .331 .31 r
F
0 g
.46894 .81639 m
.47463 .82185 L
s
.47464 .82185 m
.47464 .82185 L
s
.47088 .81938 m
.47464 .82185 L
s
.46782 .81591 m
.46894 .81639 L
s
.34487 .80099 m
.34692 .79674 L
s
.34486 .80101 m
.34487 .80099 L
s
.65901 .73563 m .67628 .72094 L .67923 .71533 L 0 1 .324 r
F
.65901 .73563 m .66763 .72963 L .67628 .72094 L F
0 g
.67628 .72094 m
.67881 .71969 L
s
.7107 .67249 m .70906 .66892 L .70605 .67296 L 0 1 .243 r
F
.7107 .67249 m .71851 .66294 L .70906 .66892 L F
.74443 .98011 m .74673 .9959 L .75185 1.00282 L 0 1 .343 r
F
0 g
.74673 .9959 m
.75185 1.00282 L
s
.74933 1.01694 m
.75185 1.00282 L
s
.29089 .84547 m .28051 .84216 L .27938 .84462 L 0 1 .438 r
F
0 g
.27267 .84598 m
.27938 .84462 L
s
.49047 .61291 m
.49055 .61287 L
s
.68793 .72006 m .6966 .732 L .70567 .73992 L 0 .89 .447 r
F
0 g
.6966 .732 m
.70051 .74183 L
s
.59699 .57958 m .61978 .57749 L .62149 .57488 L 0 1 .533 r
F
.59699 .57958 m .60929 .5795 L .61978 .57749 L F
0 g
.61978 .57749 m
.62732 .57989 L
s
.60929 .5795 m
.61721 .5814 L
s
.60929 .5795 m
.61978 .57749 L
s
.78486 .78397 m .79521 .77933 L .7866 .76339 L 0 .898 .367 r
F
.78486 .78397 m .80261 .80221 L .79521 .77933 L F
.78486 .78397 m .80495 .82122 L .80261 .80221 L F
.78486 .78397 m .80068 .82368 L .80495 .82122 L F
0 g
.78923 .82843 m
.78999 .82994 L
s
.80068 .82368 m
.80068 .82367 L
s
.78486 .78397 m .79206 .8077 L .80068 .82368 L 0 .898 .367 r
F
0 g
.79431 .82738 m
.80004 .82249 L
s
.77641 .76732 m
.78486 .78397 L
s
.78252 .76499 m
.78486 .78397 L
s
.45315 .95325 m .44528 .94189 L .44842 .94688 L 0 .124 .191 r
F
0 g
.44842 .94688 m
.44859 .94852 L
s
.3962 .8734 m .39375 .86018 L .3884 .86143 L 0 .728 .429 r
F
.3962 .8734 m .39993 .86317 L .39375 .86018 L F
.3962 .8734 m .40282 .86842 L .39993 .86317 L F
.3962 .8734 m .40121 .8728 L .40282 .86842 L F
0 g
.39003 .8704 m
.3962 .8734 L
s
.39486 .87723 m
.3962 .8734 L
s
.28635 .74956 m
.28828 .74669 L
s
.28828 .74669 m
.28913 .74543 L
s
.54267 1.1359 m
.54386 1.14274 L
s
.54267 1.1359 m
.54329 1.13885 L
s
.64578 .77094 m .65362 .76389 L .66166 .75329 L 0 1 .293 r
F
0 g
.66132 .75374 m
.66166 .75329 L
s
.66166 .75329 m
.6631 .75231 L
s
.65696 .76605 m
.65881 .76253 L
s
.46069 .96495 m .45633 .95676 L .45315 .95325 L 0 0 .15 r
F
.46069 .96495 m .46077 .96307 L .45633 .95676 L F
.46069 .96495 m .46351 .96797 L .46077 .96307 L F
.46069 .96495 m .46347 .96877 L .46351 .96797 L F
0 g
.45625 .95865 m
.46069 .96495 L
s
.42567 .61814 m
.43515 .61739 L
s
.47387 .61834 m .46382 .61475 L .46469 .61794 L 0 1 .525 r
F
0 g
.46469 .61794 m
.47387 .61834 L
s
.46317 .61887 m
.46469 .61794 L
s
.466 .62277 m
.47387 .61834 L
s
.76501 .81245 m .77933 .83638 L .78359 .83378 L 0 1 .418 r
F
.78258 .8337 m .77933 .83639 L .78359 .83379 L 0 1 .509 r
F
.75474 .81832 m .77289 .84028 L .77137 .82725 L 0 1 .407 r
F
.77289 .84028 m .77293 .84025 L .77137 .82725 L F
.76501 .81245 m .77137 .82725 L .77933 .83638 L 0 1 .418 r
F
.76581 .83218 m .77884 .83624 L .78258 .8337 L 0 1 .509 r
F
.77884 .83624 m .77933 .83639 L .78258 .8337 L F
.77289 .84028 m .77294 .84034 L .77293 .84025 L 0 1 .407 r
F
0 g
.77102 .81881 m
.77158 .82 L
s
.75557 .83981 m .77294 .84035 L .77172 .83571 L 0 1 .5 r
F
0 g
.7722 .83417 m
.77293 .84025 L
s
.77293 .84025 m
.77294 .84034 L
s
.49956 .85323 m
.50397 .85943 L
s
.49956 .85323 m
.50146 .8551 L
s
.79 .82995 m
.79003 .83046 L
s
.7908 .84275 m .80159 .83622 L .79427 .82742 L 0 1 .423 r
F
0 g
.79003 .83046 m
.7908 .84275 L
s
.79432 .82743 m
.80106 .82893 L
s
.79427 .82742 m
.79432 .82743 L
s
.7836 .83379 m
.7908 .84275 L
s
.70223 1.15602 m .71251 1.13272 L .71091 1.1415 L 0 0 .058 r
F
.25959 .74506 m .24985 .74059 L .24669 .74557 L 0 1 .539 r
F
0 g
.23844 .74887 m
.24669 .74557 L
s
.73554 1.04154 m .74932 1.01694 L .74434 1.01504 L 0 1 .317 r
F
.72326 .95297 m .73015 .92684 L .7248 .93293 L 0 1 .323 r
F
.72326 .95297 m .73672 .93607 L .73015 .92684 L F
0 g
.73015 .92684 m
.73084 .90772 L
s
.71758 .92106 m
.7248 .93293 L
s
.65901 .73563 m .67923 .71533 L .6747 .71518 L 0 1 .324 r
F
0 g
.67923 .71533 m
.68087 .71345 L
s
.68793 .72006 m .68681 .70894 L .68374 .71017 L 0 .89 .447 r
F
.68793 .72006 m .6959 .71686 L .68681 .70894 L F
.68793 .72006 m .70494 .72864 L .6959 .71686 L F
.68793 .72006 m .70912 .73852 L .70494 .72864 L F
.68793 .72006 m .70567 .73992 L .70912 .73852 L F
0 g
.6966 .732 m
.70567 .73992 L
s
.68087 .71345 m
.68793 .72006 L
s
.70567 .73992 m
.70897 .75115 L
s
.38169 .62519 m .36918 .62476 L .37154 .62669 L 0 1 .533 r
F
0 g
.37044 .62764 m
.37154 .62669 L
s
.38169 .62519 m .39288 .62125 L .39986 .61685 L 0 1 .533 r
F
0 g
.37508 .6295 m
.38169 .62519 L
s
.37154 .62669 m
.38169 .62519 L
s
.54386 1.14274 m
.54441 1.14474 L
s
.54441 1.14474 m
.54488 1.14646 L
s
.54617 1.15121 m
.54619 1.15126 L
s
.54619 1.15126 m
.54624 1.15145 L
s
.54624 1.15145 m
.54642 1.15211 L
s
.49174 1.00496 m .48634 1.00061 L .48865 1.0013 L 0 .492 .044 r
F
.49174 1.00496 m .48631 1.00389 L .48634 1.00061 L F
0 g
.48865 1.0013 m
.48886 1.0002 L
s
.48886 1.0002 m
.48909 .99895 L
s
.49174 1.00496 m .48859 1.00894 L .48631 1.00389 L 0 .492 .044 r
F
.49174 1.00496 m .4917 1.01262 L .48859 1.00894 L F
.49174 1.00496 m .49355 1.01246 L .4917 1.01262 L F
.49174 1.00496 m .49356 1.00918 L .49355 1.01246 L F
0 g
.49174 1.00496 m
.49211 1.00053 L
s
.48865 1.0013 m
.49174 1.00496 L
s
.32512 .63554 m
.33512 .63252 L
s
.73672 .93607 m .74013 .95447 L .74604 .96398 L 0 1 .342 r
F
0 g
.73672 .93607 m
.73744 .91898 L
s
.72326 .95297 m .74013 .95447 L .73672 .93607 L 0 1 .323 r
F
0 g
.73015 .92684 m
.73672 .93607 L
s
.42921 .78938 m .42411 .78467 L .42009 .78477 L 0 .692 .41 r
F
.42921 .78938 m .43165 .78628 L .42411 .78467 L F
.42921 .78938 m .43863 .78917 L .43165 .78628 L F
.42921 .78938 m .44036 .79141 L .43863 .78917 L F
.42921 .78938 m .43632 .7915 L .44036 .79141 L F
0 g
.42551 .78902 m
.42921 .78938 L
s
.42226 .78651 m
.42921 .78938 L
s
.5701 1.0277 m
.57048 1.03 L
s
.71485 .87359 m .72997 .86559 L .725 .86461 L 0 1 .36 r
F
0 g
.72997 .86559 m
.73687 .86415 L
s
.72997 .86559 m
.73052 .86856 L
s
.33053 .75963 m .32995 .75485 L .32194 .75456 L 0 .499 .368 r
F
.33053 .75963 m .33836 .75749 L .32995 .75485 L F
.33053 .75963 m .34152 .7607 L .33836 .75749 L F
.33053 .75963 m .33815 .76162 L .34152 .7607 L F
0 g
.32751 .75898 m
.33053 .75963 L
s
.32217 .757 m
.33053 .75963 L
s
.25578 .91652 m .24812 .91102 L .24448 .91199 L 0 .545 .276 r
F
.25578 .91652 m .25418 .9118 L .24812 .91102 L F
.25578 .91652 m .25861 .91379 L .25418 .9118 L F
.25578 .91652 m .25929 .91582 L .25861 .91379 L F
0 g
.24975 .91574 m
.25578 .91652 L
s
.25578 .91652 m
.25658 .91835 L
s
.45315 .95325 m .44561 .94045 L .44528 .94189 L 0 .124 .191 r
F
0 g
.44049 .93638 m
.44528 .94189 L
s
.41314 .78284 m
.42009 .78477 L
s
.48085 .99239 m .47433 .98534 L .47446 .98402 L 0 .384 0 r
F
0 g
.47061 .97888 m
.47446 .98402 L
s
.48085 .99239 m .4769 .99 L .47433 .98534 L 0 .384 0 r
F
.48085 .99239 m .48057 .99548 L .4769 .99 L F
.48085 .99239 m .48288 .99812 L .48057 .99548 L F
.48085 .99239 m .483 .99679 L .48288 .99812 L F
0 g
.48085 .99239 m
.4813 .99006 L
s
.4772 .98692 m
.48085 .99239 L
s
.55817 1.04945 m
.55882 1.05322 L
s
.55754 1.04579 m
.55817 1.04945 L
s
.6568 .98563 m
.65708 .98669 L
s
.47464 .82185 m .47181 .81625 L .46767 .81428 L 0 .331 .31 r
F
.47464 .82185 m .47862 .82101 L .47181 .81625 L F
.47464 .82185 m .48434 .82649 L .47862 .82101 L F
.47464 .82185 m .48515 .82902 L .48434 .82649 L F
.47464 .82185 m .48098 .82703 L .48515 .82902 L F
0 g
.47463 .82185 m
.47464 .82185 L
s
.3884 .86143 m .38629 .84713 L .3806 .84906 L 0 .772 .428 r
F
.3884 .86143 m .39272 .84975 L .38629 .84713 L F
.3884 .86143 m .39561 .85517 L .39272 .84975 L F
.3884 .86143 m .39375 .86018 L .39561 .85517 L F
0 g
.38198 .85881 m
.3884 .86143 L
s
.38681 .86581 m
.3884 .86143 L
s
.75474 .81832 m .7572 .80301 L .75315 .80521 L 0 1 .407 r
F
.75474 .81832 m .76501 .81245 L .7572 .80301 L F
.75474 .81832 m .77137 .82725 L .76501 .81245 L F
0 g
.74709 .80849 m
.75474 .81832 L
s
.53172 .59916 m .54361 .59754 L .55305 .5941 L 0 1 .531 r
F
0 g
.54361 .59754 m
.55201 .59858 L
s
.68252 .70584 m .68366 .70731 L .68662 .70223 L 0 1 .342 r
F
.665 .69319 m .67439 .70342 L .68191 .70885 L 0 .88 .466 r
F
.665 .69319 m .68191 .70885 L .68197 .70856 L F
.68197 .70856 m .68366 .70731 L .68252 .70584 L 0 1 .342 r
F
.68197 .70856 m .68191 .70885 L .68366 .70731 L F
.68252 .70584 m .68374 .71017 L .68681 .70894 L 0 .88 .466 r
F
.68391 .69807 m .69108 .69492 L .69406 .69026 L 0 1 .362 r
F
.665 .69319 m .68137 .70803 L .68202 .70548 L 0 .88 .466 r
F
.665 .69319 m .68177 .70039 L .67196 .69021 L F
.665 .69319 m .68202 .70548 L .68177 .70039 L F
.68202 .70548 m .68229 .70419 L .68177 .70039 L F
.68252 .70584 m .68278 .70209 L .68177 .70039 L F
.6724 .70693 m .68182 .70205 L .68291 .70122 L 0 1 .362 r
F
.67196 .69021 m .68177 .70039 L .68295 .70118 L 0 .943 .474 r
F
.68328 .69993 m .68295 .70118 L .68328 .70093 L 0 1 .362 r
F
.68351 .69979 m .68328 .70093 L .69108 .69492 L F
.68328 .69993 m .68328 .70093 L .68351 .69979 L F
.68417 .6949 m .69406 .69026 L .68897 .68999 L F
.67196 .69021 m .68295 .70118 L .68328 .69993 L 0 .943 .474 r
F
.68384 .69813 m .69406 .69026 L .68417 .6949 L 0 1 .362 r
F
.68347 .69982 m .69108 .69492 L .68391 .69807 L F
.68417 .6949 m .69451 .70549 L .68917 .69682 L 0 .943 .474 r
F
.68515 .68884 m .70154 .67922 L .69616 .6788 L 0 1 .381 r
F
.67196 .69021 m .6829 .69762 L .68368 .69471 L 0 .943 .474 r
F
.67196 .69021 m .68368 .69471 L .67894 .68668 L F
.68368 .69471 m .68417 .6949 L .68378 .69429 L F
.68368 .69471 m .68378 .69429 L .67894 .68668 L F
.68434 .69203 m .68442 .69199 L .68451 .69134 L 0 1 .381 r
F
.68442 .69199 m .68897 .68999 L .68462 .6913 L F
.68458 .69129 m .68897 .68999 L .69854 .68353 L F
.68458 .69132 m .68897 .68999 L .68458 .69129 L F
.68461 .69128 m .69854 .68353 L .68482 .69049 L F
.68368 .69471 m .68375 .6982 L .68417 .6949 L 0 .943 .474 r
F
.6829 .69762 m .68375 .6982 L .68368 .69471 L F
.68252 .70584 m .68662 .70223 L .68278 .70209 L 0 1 .342 r
F
.68375 .6982 m .69143 .70694 L .69451 .70549 L 0 .943 .474 r
F
.67196 .69021 m .68328 .69993 L .68375 .6982 L F
.68375 .6982 m .68347 .69982 L .68391 .69807 L 0 1 .362 r
F
.68328 .69993 m .68347 .69982 L .68375 .6982 L F
.68328 .69993 m .69143 .70694 L .68375 .6982 L 0 .943 .474 r
F
.6724 .70693 m .68328 .69993 L .68375 .6982 L 0 1 .362 r
F
.6724 .70693 m .68417 .6949 L .67915 .69431 L F
.68417 .6949 m .68897 .68999 L .68434 .69203 L F
.68417 .6949 m .68419 .6946 L .67894 .68668 L 0 .943 .474 r
F
.68446 .69501 m .68494 .69262 L .6846 .69229 L F
.68435 .69484 m .6846 .69229 L .67894 .68668 L F
.68446 .69501 m .6846 .69229 L .68435 .69484 L F
.68582 .68278 m .69616 .6788 L .68594 .68258 L 0 1 .381 r
F
.68577 .68326 m .69616 .6788 L .68582 .68278 L F
.67894 .68668 m .6851 .68882 L .68582 .68278 L 0 .997 .48 r
F
.6851 .68882 m .68515 .68884 L .68582 .68278 L F
.67894 .68668 m .68458 .69129 L .68486 .69047 L F
.67894 .68668 m .68495 .68994 L .68515 .68884 L F
.68486 .69047 m .6849 .69044 L .68515 .68884 L 0 1 .381 r
F
.68495 .68994 m .685 .68996 L .68515 .68884 L 0 .997 .48 r
F
.67894 .68668 m .68486 .69047 L .685 .68996 L F
.67894 .68668 m .68434 .69203 L .68458 .69129 L F
.67915 .69431 m .68486 .69047 L .68515 .68884 L 0 1 .381 r
F
.68491 .68906 m .68515 .68884 L .68547 .68339 L F
.68515 .68884 m .69616 .6788 L .68592 .68319 L F
.68515 .68884 m .68592 .68319 L .68547 .68339 L F
.6849 .69044 m .70154 .67922 L .68515 .68884 L F
.68515 .68884 m .685 .68996 L .68531 .68889 L 0 .997 .48 r
F
.67915 .69431 m .68582 .68278 L .67629 .68907 L 0 1 .381 r
F
.67894 .68668 m .68582 .68278 L .67595 .67632 L 0 .997 .48 r
F
.68582 .68278 m .68594 .68258 L .68584 .68265 L 0 1 .381 r
F
.68582 .68278 m .68594 .68271 L .68584 .68265 L 0 .997 .48 r
F
.68582 .68277 m .68584 .68264 L .67595 .67632 L F
.68594 .68258 m .69276 .67158 L .68719 .67486 L 0 1 .399 r
F
.68594 .68258 m .70605 .67296 L .70906 .66892 L F
.68594 .68258 m .69616 .6788 L .70605 .67296 L F
.68594 .68258 m .70906 .66892 L .70338 .66832 L F
.68594 .68258 m .70338 .66832 L .69276 .67158 L F
.68594 .68271 m .69296 .67836 L .68719 .67486 L 0 1 .486 r
F
.68586 .68246 m .68719 .67486 L .68265 .6721 L F
.68594 .68258 m .68719 .67486 L .68648 .6789 L 0 1 .399 r
F
.68594 .68271 m .68719 .67486 L .68586 .68246 L 0 1 .486 r
F
.68648 .6789 m .68719 .67486 L .68707 .67493 L 0 1 .399 r
F
.68585 .68257 m .68265 .6721 L .67997 .67383 L 0 1 .486 r
F
.68585 .68257 m .68265 .6721 L .68585 .68257 L F
.68586 .68246 m .68265 .6721 L .68585 .68257 L F
.68586 .68246 m .68707 .67493 L .6828 .67745 L 0 1 .399 r
F
.68594 .68258 m .68707 .67493 L .68586 .68246 L F
.68585 .68257 m .68585 .68257 L .68585 .68257 L 0 1 .486 r
F
.68594 .68258 m .68586 .68246 L .68585 .68257 L 0 1 .399 r
F
.68594 .68271 m .68586 .68246 L .68585 .68257 L 0 1 .486 r
F
.68585 .68257 m .6828 .67745 L .68019 .68201 L 0 1 .399 r
F
.68586 .68246 m .6828 .67745 L .68585 .68257 L F
.68582 .68278 m .68584 .68265 L .68584 .68264 L 0 .997 .48 r
F
.68582 .68278 m .68584 .68264 L .68582 .68277 L F
.68582 .68278 m .68584 .68265 L .68584 .68265 L 0 1 .381 r
F
.68582 .68278 m .68584 .68265 L .67629 .68907 L F
.68582 .68278 m .68515 .68884 L .68594 .68271 L 0 .997 .48 r
F
.68547 .68339 m .68577 .68326 L .68582 .68278 L 0 1 .381 r
F
.67915 .69431 m .68491 .68906 L .68547 .68339 L F
.68417 .6949 m .68434 .69203 L .67915 .69431 L 0 1 .362 r
F
.68417 .6949 m .6842 .69462 L .68419 .6946 L 0 .943 .474 r
F
.68486 .69047 m .69914 .7032 L .70223 .70159 L 0 .997 .48 r
F
.68458 .69129 m .69914 .7032 L .68486 .69047 L F
.68442 .69199 m .68462 .6913 L .68458 .69132 L 0 1 .381 r
F
.68447 .69164 m .68458 .69132 L .68451 .69134 L F
.68442 .69199 m .68458 .69132 L .68447 .69164 L F
.6849 .69044 m .69854 .68353 L .70154 .67922 L F
.6849 .69045 m .69854 .68353 L .6849 .69044 L F
.68531 .68889 m .70223 .70159 L .69658 .69281 L 0 .997 .48 r
F
.68482 .69049 m .6849 .69045 L .6849 .69044 L 0 1 .381 r
F
.68486 .69047 m .70223 .70159 L .68531 .68889 L 0 .997 .48 r
F
.68458 .69129 m .68917 .69682 L .69914 .7032 L F
.68434 .69203 m .68917 .69682 L .68458 .69129 L F
.68451 .69134 m .68458 .69132 L .68458 .69129 L 0 1 .381 r
F
.67915 .69431 m .68434 .69203 L .68451 .69134 L F
.68515 .68884 m .68531 .68889 L .68561 .68597 L 0 .997 .48 r
F
.68515 .68884 m .68561 .68597 L .68594 .68271 L F
.68531 .68889 m .69658 .69281 L .68673 .68345 L F
.68531 .68889 m .68673 .68345 L .68594 .68271 L F
.67915 .69431 m .68461 .69128 L .68482 .69049 L 0 1 .381 r
F
.68375 .6982 m .68384 .69813 L .68417 .6949 L 0 1 .362 r
F
.68375 .6982 m .69451 .70549 L .68417 .6949 L 0 .943 .474 r
F
.6724 .70693 m .68375 .6982 L .68417 .6949 L 0 1 .362 r
F
.68417 .6949 m .68446 .69501 L .6842 .69462 L 0 .943 .474 r
F
.68446 .69501 m .68917 .69682 L .68494 .69262 L F
.68328 .69993 m .68295 .70118 L .69143 .70694 L F
.68315 .70002 m .68291 .70122 L .68295 .70118 L 0 1 .362 r
F
.68315 .70002 m .68295 .70118 L .68328 .69993 L F
.6724 .70693 m .68291 .70122 L .68315 .70002 L F
.68202 .70548 m .68252 .70584 L .68229 .70419 L 0 .88 .466 r
F
.68252 .70584 m .68681 .70894 L .68278 .70209 L F
.68202 .70548 m .68197 .70856 L .68252 .70584 L F
.68137 .70803 m .68197 .70856 L .68202 .70548 L F
.66568 .72062 m .68252 .70584 L .68182 .70205 L 0 1 .342 r
F
.68252 .70584 m .68278 .70209 L .68182 .70205 L F
.68197 .70856 m .68374 .71017 L .68252 .70584 L 0 .88 .466 r
F
.66568 .72062 m .6747 .71518 L .68191 .70885 L 0 1 .342 r
F
.66568 .72062 m .68191 .70885 L .68197 .70856 L F
.66568 .72062 m .68197 .70856 L .68252 .70584 L F
.68197 .70856 m .68191 .70885 L .68374 .71017 L 0 .88 .466 r
F
0 g
.68215 .70902 m
.68215 .70902 L
s
.68191 .70885 m
.68215 .70902 L
s
.67639 .70486 m
.67822 .70619 L
s
.68215 .70902 m
.68374 .71017 L
s
.68374 .71017 m
.68793 .72006 L
s
.67547 .70534 m
.67685 .70777 L
s
.67893 .71147 m
.67913 .71182 L
s
.68545 .70662 m
.68753 .70581 L
s
.35826 .78308 m
.36084 .78662 L
s
.35723 .78168 m
.35826 .78308 L
s
.3563 .78041 m
.35723 .78168 L
s
.35659 .77957 m
.35721 .78007 L
s
.78321 .74585 m
.7866 .76339 L
s
.72703 1.0924 m .73748 1.07747 L .7375 1.06949 L 0 1 .212 r
F
.72703 1.0924 m .73435 1.08992 L .73748 1.07747 L F
0 g
.73451 1.08926 m
.73748 1.07747 L
s
.7866 .76339 m
.79521 .77933 L
s
.78153 .81324 m
.78359 .83378 L
s
.76581 .83218 m .77172 .83571 L .77933 .83639 L 0 1 .509 r
F
0 g
.7787 .83633 m
.77933 .83639 L
s
.36508 .82109 m .37117 .8057 L .36412 .79876 L 0 .778 .408 r
F
.36508 .82109 m .37404 .81182 L .37117 .8057 L F
.36508 .82109 m .37142 .81842 L .37404 .81182 L F
.37282 .83593 m .37142 .81842 L .36508 .82109 L 0 .791 .411 r
F
0 g
.36273 .82751 m
.36508 .82109 L
s
.35823 .81432 m
.36508 .82109 L
s
.66636 1.20994 m .66914 1.17268 L .67403 1.17567 L 0 .291 .135 r
F
.66636 1.20994 m .66513 1.17955 L .66914 1.17268 L F
0 g
.66914 1.17268 m
.66978 1.1599 L
s
.66471 1.17919 m
.66513 1.17955 L
s
.70749 .93225 m
.71075 .93988 L
s
.69028 .69862 m
.69095 .69796 L
s
.63775 .79746 m .65682 .76632 L .65362 .7639 L 0 1 .278 r
F
.63775 .79746 m .65328 .77657 L .65682 .76632 L F
0 g
.65682 .76632 m
.65696 .76605 L
s
.65628 .76591 m
.65682 .76632 L
s
.74443 .98011 m
.74604 .96398 L
s
.74013 .95447 m
.74604 .96398 L
s
.54158 1.12549 m .54057 1.12164 L .54253 1.13259 L 0 0 .094 r
F
0 g
.54124 1.12537 m
.54127 1.12554 L
s
.54088 1.12334 m
.54124 1.12537 L
s
.5407 1.12236 m
.54088 1.12334 L
s
.54057 1.12164 m
.5407 1.12236 L
s
.54129 1.12109 m
.54204 1.12539 L
s
.5398 1.11305 m
.54126 1.12323 L
s
.54126 1.12323 m
.54147 1.12474 L
s
.54041 1.12072 m
.54057 1.12164 L
s
.54072 1.12395 m
.54127 1.12659 L
s
.665 .69319 m .66261 .68346 L .65995 .68464 L 0 .88 .466 r
F
.665 .69319 m .67196 .69021 L .66261 .68346 L F
0 g
.65596 .68621 m
.665 .69319 L
s
.49356 1.00918 m
.49632 1.0102 L
s
.72622 1.10731 m .73435 1.08992 L .73016 1.09856 L 0 .861 .122 r
F
.72703 1.0924 m .73016 1.09856 L .73435 1.08992 L 0 1 .212 r
F
0 g
.73435 1.08992 m
.73665 1.08664 L
s
.73435 1.08992 m
.73451 1.08926 L
s
.46178 .80982 m
.46476 .81065 L
s
.46178 .80982 m
.46767 .81428 L
s
.80069 .8238 m
.80071 .82416 L
s
.80068 .82368 m
.80069 .8238 L
s
.80159 .83622 m .81241 .82992 L .80496 .82123 L 0 1 .433 r
F
0 g
.80071 .82416 m
.80159 .83622 L
s
.80496 .82123 m
.81208 .82316 L
s
.79427 .82742 m
.80159 .83622 L
s
.63196 .57355 m .62578 .56836 L .62406 .57097 L 0 1 .531 r
F
.63196 .57355 m .63662 .56719 L .62578 .56836 L F
.63196 .57355 m .64932 .56824 L .63662 .56719 L F
0 g
.64932 .56824 m
.65717 .57082 L
s
.3806 .84906 m .37884 .83338 L .37282 .83593 L 0 .792 .421 r
F
.3806 .84906 m .38553 .83573 L .37884 .83338 L F
.3806 .84906 m .3884 .84142 L .38553 .83573 L F
.3806 .84906 m .38629 .84713 L .3884 .84142 L F
0 g
.37394 .84671 m
.3806 .84906 L
s
.37876 .85406 m
.3806 .84906 L
s
.30285 .75076 m .29464 .74814 L .29831 .74986 L 0 1 .489 r
F
.53921 1.04467 m .54023 1.03979 L .54389 1.05653 L 0 .702 .183 r
F
0 g
.54023 1.03979 m
.541 1.04331 L
s
.54166 1.03128 m
.54293 1.0457 L
s
.53814 1.0234 m
.54023 1.03979 L
s
.53172 .59916 m .55305 .5941 L .55374 .59114 L 0 1 .531 r
F
0 g
.55305 .5941 m
.5613 .59553 L
s
.54361 .59754 m
.55305 .5941 L
s
.44561 .94045 m .43745 .92898 L .44058 .93422 L 0 .242 .28 r
F
0 g
.44049 .93638 m
.44058 .93422 L
s
.38163 .62799 m .36914 .62613 L .37149 .62885 L 0 1 .531 r
F
0 g
.36536 .63395 m
.37149 .62885 L
s
.30285 .75076 m .29376 .74626 L .29464 .74814 L 0 1 .489 r
F
.30285 .75076 m .29626 .74547 L .29376 .74626 L F
0 g
.28635 .74956 m
.29397 .74826 L
s
.29397 .74826 m
.29463 .74814 L
s
.30285 .75076 m .30082 .74637 L .29626 .74547 L 0 1 .489 r
F
.30285 .75076 m .30438 .74836 L .30082 .74637 L F
.30285 .75076 m .30525 .75024 L .30438 .74836 L F
0 g
.30285 .75076 m
.30381 .75223 L
s
.29831 .74986 m
.30285 .75076 L
s
.55121 1.09443 m
.55195 1.10158 L
s
.72326 .95297 m .73861 .97453 L .74013 .95447 L 0 1 .323 r
F
.50234 .61687 m .49312 .61323 L .49348 .61487 L 0 1 .469 r
F
.50234 .61687 m .50184 .61281 L .49312 .61323 L F
0 g
.48523 .61628 m
.49348 .61487 L
s
.49055 .61287 m
.49349 .61131 L
s
.50234 .61687 m .51382 .61391 L .50184 .61281 L 0 1 .469 r
F
.50234 .61687 m .52268 .61591 L .51382 .61391 L F
.50234 .61687 m .52251 .61749 L .52268 .61591 L F
.50234 .61687 m .51379 .6179 L .52251 .61749 L F
0 g
.49402 .61722 m
.50234 .61687 L
s
.49348 .61487 m
.50234 .61687 L
s
.51379 .6179 m
.52226 .61973 L
s
.77529 .8066 m .78999 .82994 L .79426 .82741 L 0 1 .428 r
F
.79329 .82728 m .78999 .82994 L .79426 .82742 L 0 1 .515 r
F
.76501 .81245 m .78354 .83372 L .78187 .82103 L 0 1 .418 r
F
.78354 .83372 m .78358 .8337 L .78187 .82103 L F
.77529 .8066 m .78187 .82103 L .78999 .82994 L 0 1 .428 r
F
.77606 .82482 m .78952 .82977 L .79329 .82728 L 0 1 .515 r
F
.78952 .82977 m .78999 .82994 L .79329 .82728 L F
.78354 .83372 m .78359 .83378 L .78358 .8337 L 0 1 .418 r
F
0 g
.78153 .81324 m
.78177 .81371 L
s
.76581 .83218 m .78359 .83379 L .7822 .82884 L 0 1 .509 r
F
0 g
.77137 .82725 m
.77418 .83047 L
s
.77137 .82725 m
.77181 .83096 L
s
.78358 .8337 m
.78359 .83378 L
s
.41434 .62609 m .40263 .62346 L .4045 .62644 L 0 1 .527 r
F
.41434 .62609 m .41003 .61856 L .40263 .62346 L F
.41434 .62609 m .42178 .61501 L .41003 .61856 L F
.41434 .62609 m .43164 .61466 L .42178 .61501 L F
.41434 .62609 m .43302 .61775 L .43164 .61466 L F
.41434 .62609 m .4256 .62265 L .43302 .61775 L F
0 g
.4073 .63096 m
.41434 .62609 L
s
.4045 .62644 m
.41434 .62609 L
s
.37282 .83593 m .37834 .82093 L .37142 .81842 L 0 .791 .411 r
F
.37282 .83593 m .38121 .82694 L .37834 .82093 L F
.37282 .83593 m .37884 .83338 L .38121 .82694 L F
0 g
.36592 .83341 m
.37282 .83593 L
s
.37072 .84164 m
.37282 .83593 L
s
.56341 .58823 m .5756 .58732 L .58563 .58455 L 0 1 .533 r
F
0 g
.5756 .58732 m
.58382 .58876 L
s
.55874 1.05282 m
.55881 1.05324 L
s
.55871 1.05265 m
.55874 1.05282 L
s
.725 .86461 m .74038 .85774 L .73517 .856 L 0 1 .428 r
F
0 g
.74038 .85774 m
.7411 .86123 L
s
.74038 .85774 m
.74746 .85691 L
s
.32194 .75456 m .30972 .7512 L .31328 .753 L 0 .823 .457 r
F
.56341 .58823 m .58563 .58455 L .58684 .58175 L 0 1 .533 r
F
0 g
.58563 .58455 m
.59359 .58644 L
s
.5756 .58732 m
.58563 .58455 L
s
.38163 .62799 m .37611 .62104 L .36914 .62613 L 0 1 .531 r
F
.38163 .62799 m .38777 .61697 L .37611 .62104 L F
.38163 .62799 m .39794 .61611 L .38777 .61697 L F
.38163 .62799 m .39982 .61903 L .39794 .61611 L F
.38163 .62799 m .39282 .62413 L .39982 .61903 L F
0 g
.375 .63299 m
.38163 .62799 L
s
.37149 .62885 m
.38163 .62799 L
s
.39785 .63143 m
.4045 .62644 L
s
.68278 .70209 m
.68295 .7021 L
s
.68295 .7021 m
.68437 .70215 L
s
.3999 .77861 m .38975 .77624 L .39235 .77754 L 0 1 .48 r
F
0 g
.38909 .77898 m
.39235 .77754 L
s
.24448 .91199 m .23694 .90616 L .23318 .90743 L 0 .56 .3 r
F
.24448 .91199 m .24311 .90674 L .23694 .90616 L F
.24448 .91199 m .24754 .90877 L .24311 .90674 L F
.24448 .91199 m .24812 .91102 L .24754 .90877 L F
0 g
.23835 .91141 m
.24448 .91199 L
s
.24448 .91199 m
.24519 .91401 L
s
.64041 .67063 m .65044 .67914 L .65995 .68464 L 0 .889 .48 r
F
0 g
.65044 .67914 m
.65596 .68621 L
s
.28051 .84216 m .26882 .84094 L .27305 .84246 L 0 1 .452 r
F
0 g
.27267 .84598 m
.27305 .84246 L
s
.73075 1.00205 m .74673 .9959 L .74442 .98012 L 0 1 .322 r
F
.73075 1.00205 m .74434 1.01504 L .74673 .9959 L F
.6867 1.16473 m .69582 1.15548 L .69174 1.16416 L 0 .149 .095 r
F
.69196 1.18295 m .69582 1.15548 L .7003 1.15199 L 0 .03 .087 r
F
.69196 1.18295 m .69174 1.16416 L .69582 1.15548 L F
0 g
.69582 1.15548 m
.69681 1.1449 L
s
.69582 1.15548 m
.6968 1.15471 L
s
.36412 .79869 m
.36414 .79866 L
s
.44561 .94045 m .43807 .92697 L .43745 .92898 L 0 .242 .28 r
F
0 g
.43238 .92368 m
.43745 .92898 L
s
.80061 .82355 m
.80068 .82368 L
s
.79206 .8077 m
.79426 .82741 L
s
.73752 .78152 m .74472 .79601 L .75315 .80521 L 0 1 .419 r
F
0 g
.74472 .79601 m
.74709 .80849 L
s
.726 .7607 m
.72929 .77192 L
s
.25959 .74506 m .25808 .73559 L .24985 .74059 L 0 1 .539 r
F
0 g
.24669 .74557 m
.24985 .74059 L
s
.25959 .74506 m .26704 .73341 L .25808 .73559 L 0 1 .539 r
F
.25959 .74506 m .27073 .7355 L .26704 .73341 L F
.25959 .74506 m .26752 .7405 L .27073 .7355 L F
0 g
.25664 .74963 m
.25959 .74506 L
s
.25068 .74723 m
.25959 .74506 L
s
.73075 1.00205 m .74442 .98012 L .73861 .97453 L 0 1 .322 r
F
0 g
.51344 .87703 m
.51467 .87883 L
s
.51344 .87703 m
.51712 .8834 L
s
.45315 .95325 m .44919 .94352 L .44561 .94045 L 0 .124 .191 r
F
.45315 .95325 m .45393 .9499 L .44919 .94352 L F
.45315 .95325 m .45666 .95533 L .45393 .9499 L F
.45315 .95325 m .45633 .95676 L .45666 .95533 L F
0 g
.44842 .94688 m
.45315 .95325 L
s
.45312 .95406 m
.45315 .95325 L
s
.64041 .67063 m .63675 .66214 L .63454 .66334 L 0 .889 .48 r
F
.64041 .67063 m .64627 .66763 L .63675 .66214 L F
.64041 .67063 m .65675 .67617 L .64627 .66763 L F
.64041 .67063 m .66261 .68346 L .65675 .67617 L F
.64041 .67063 m .65995 .68464 L .66261 .68346 L F
0 g
.65044 .67914 m
.65995 .68464 L
s
.63123 .66496 m
.64041 .67063 L
s
.65995 .68464 m
.665 .69319 L
s
.71583 1.13175 m .71478 1.13304 L .71711 1.12755 L 0 0 0 r
F
0 g
.71251 1.13272 m
.71711 1.12755 L
s
.66451 .91933 m .66848 .92112 L .66477 .92561 L 0 .202 .098 r
F
.66451 .91933 m .674 .91198 L .66848 .92112 L F
0 g
.66451 .91933 m
.66476 .9253 L
s
.66333 .92232 m
.66451 .91933 L
s
.6601 .93055 m
.66333 .92232 L
s
.65923 .93276 m
.6601 .93055 L
s
.63775 .79746 m .64512 .7899 L .65328 .77657 L 0 1 .278 r
F
0 g
.64971 .7824 m
.65223 .77828 L
s
.65223 .77828 m
.65328 .77657 L
s
.6501 .78796 m
.65557 .7759 L
s
.6487 .79105 m
.6501 .78796 L
s
.65328 .77657 m
.65557 .7759 L
s
.73752 .78152 m .75315 .80521 L .7572 .80301 L 0 1 .419 r
F
0 g
.75315 .80521 m
.75474 .81832 L
s
.74472 .79601 m
.75315 .80521 L
s
.29089 .84547 m .28626 .84023 L .28051 .84216 L 0 1 .438 r
F
.29089 .84547 m .2936 .8397 L .28626 .84023 L F
.29089 .84547 m .29759 .84093 L .2936 .8397 L F
.29089 .84547 m .29642 .8434 L .29759 .84093 L F
0 g
.28993 .84793 m
.29089 .84547 L
s
.2836 .84599 m
.29089 .84547 L
s
.49234 .84161 m .48638 .83261 L .48721 .83486 L 0 .247 .275 r
F
0 g
.48569 .83385 m
.48721 .83486 L
s
.4027 .61966 m
.40661 .61786 L
s
.39788 .62044 m
.4027 .61966 L
s
.59699 .57958 m .62149 .57488 L .61319 .57284 L 0 1 .533 r
F
0 g
.62149 .57488 m
.63196 .57355 L
s
.53172 .59916 m .52308 .59499 L .52291 .59807 L 0 1 .531 r
F
.53172 .59916 m .53253 .59155 L .52308 .59499 L F
.53172 .59916 m .54495 .59004 L .53253 .59155 L F
.53172 .59916 m .55374 .59114 L .54495 .59004 L F
0 g
.52266 .60271 m
.53172 .59916 L
s
.77606 .82482 m .7822 .82884 L .78999 .82994 L 0 1 .515 r
F
0 g
.78939 .82986 m
.78999 .82994 L
s
.78294 .82894 m
.78358 .8337 L
s
.43503 .62243 m
.43509 .62243 L
s
.4256 .62265 m
.43503 .62243 L
s
.35956 .62707 m
.36918 .62476 L
s
.80496 .82123 m
.81241 .82992 L
s
.43807 .92697 m .42961 .91564 L .43274 .92102 L 0 .321 .341 r
F
0 g
.43238 .92368 m
.43274 .92102 L
s
.39883 .6175 m
.39986 .61685 L
s
.61442 .65227 m .62497 .65911 L .63454 .66334 L 0 .916 .483 r
F
0 g
.62497 .65911 m
.63123 .66496 L
s
.35917 .62739 m
.36914 .62613 L
s
.3999 .77861 m .39372 .77482 L .38975 .77624 L 0 1 .48 r
F
.3999 .77861 m .40162 .77424 L .39372 .77482 L F
.3999 .77861 m .4092 .77531 L .40162 .77424 L F
.3999 .77861 m .41139 .77732 L .4092 .77531 L F
.3999 .77861 m .40739 .77873 L .41139 .77732 L F
0 g
.39623 .77937 m
.3999 .77861 L
s
.39235 .77754 m
.3999 .77861 L
s
.45124 .80086 m .44296 .79466 L .44469 .79676 L 0 .55 .396 r
F
0 g
.44097 .79638 m
.44469 .79676 L
s
.69406 .69026 m
.69524 .68926 L
s
.69524 .68926 m
.70294 .6827 L
s
.73752 .78152 m .73872 .76744 L .73495 .76927 L 0 1 .419 r
F
.73752 .78152 m .74716 .77666 L .73872 .76744 L F
.73752 .78152 m .75463 .79077 L .74716 .77666 L F
.73752 .78152 m .7572 .80301 L .75463 .79077 L F
0 g
.72929 .77192 m
.73752 .78152 L
s
.73495 .76927 m
.73752 .78152 L
s
.73517 .856 m .75081 .85014 L .74536 .84774 L 0 1 .465 r
F
0 g
.75081 .85014 m
.7517 .85407 L
s
.75081 .85014 m
.75806 .84987 L
s
.71851 .66294 m .71661 .65924 L .71358 .66305 L 0 1 .278 r
F
.71851 .66294 m .72634 .65393 L .71661 .65924 L F
0 g
.70906 .66892 m
.71851 .66294 L
s
.52875 .91037 m
.52983 .91404 L
s
.52771 .90682 m
.52778 .90708 L
s
.52873 .9103 m
.52875 .91037 L
s
.52758 .90659 m
.52771 .90682 L
s
.36262 .77936 m
.36553 .7762 L
s
.3542 .78653 m
.35662 .78447 L
s
.35662 .78447 m
.35686 .78427 L
s
.35686 .78427 m
.35826 .78308 L
s
.35826 .78308 m
.35992 .78166 L
s
.36204 .77985 m
.36262 .77936 L
s
.71304 .968 m .71773 .94145 L .71366 .94672 L 0 1 .307 r
F
.71304 .968 m .72326 .95297 L .71773 .94145 L F
0 g
.71758 .92108 m
.71773 .94145 L
s
.71075 .93988 m
.71366 .94672 L
s
.23318 .90743 m .22576 .90125 L .22186 .90283 L 0 .596 .326 r
F
.23318 .90743 m .23202 .9016 L .22576 .90125 L F
.23318 .90743 m .23646 .90366 L .23202 .9016 L F
.23318 .90743 m .23694 .90616 L .23646 .90366 L F
0 g
.22694 .90706 m
.23318 .90743 L
s
.23318 .90743 m
.23379 .90967 L
s
.36918 .62476 m
.37485 .62117 L
s
.53095 .62044 m .52268 .61591 L .52251 .61749 L 0 1 .465 r
F
0 g
.51379 .6179 m
.52251 .61749 L
s
.53095 .62044 m .53177 .61656 L .52268 .61591 L 0 1 .465 r
F
.53095 .62044 m .54372 .61901 L .53177 .61656 L F
.53095 .62044 m .55216 .62197 L .54372 .61901 L F
.53095 .62044 m .55146 .62345 L .55216 .62197 L F
.53095 .62044 m .54237 .6228 L .55146 .62345 L F
0 g
.54237 .6228 m
.55042 .62554 L
s
.52226 .61973 m
.53095 .62044 L
s
.52251 .61749 m
.53095 .62044 L
s
.28051 .84216 m .27013 .83827 L .26882 .84094 L 0 1 .452 r
F
0 g
.26198 .84227 m
.26882 .84094 L
s
.69742 .94439 m
.7012 .95478 L
s
.61442 .65227 m .60952 .64489 L .6078 .64617 L 0 .916 .483 r
F
.61442 .65227 m .6191 .64912 L .60952 .64489 L F
.61442 .65227 m .63013 .65604 L .6191 .64912 L F
.61442 .65227 m .63675 .66214 L .63013 .65604 L F
.61442 .65227 m .63454 .66334 L .63675 .66214 L F
0 g
.62497 .65911 m
.63454 .66334 L
s
.60521 .64792 m
.61442 .65227 L
s
.63454 .66334 m
.64041 .67063 L
s
.62833 .89782 m .64062 .84447 L .63501 .85776 L 0 1 .147 r
F
0 g
.63989 .86195 m
.64037 .8601 L
s
.64062 .84447 m
.64112 .84295 L
s
.64062 .84447 m
.64094 .8448 L
s
.5333 1.04093 m
.53332 1.04122 L
s
.7856 .80079 m .80068 .82368 L .80495 .82122 L 0 1 .437 r
F
.80402 .82105 m .80068 .82368 L .80495 .82122 L 0 1 .52 r
F
.77529 .8066 m .79421 .82735 L .79239 .81493 L 0 1 .428 r
F
.79421 .82735 m .79425 .82733 L .79239 .81493 L F
.7856 .80079 m .79239 .81493 L .80068 .82368 L 0 1 .437 r
F
.78634 .8177 m .80022 .82349 L .80402 .82105 L 0 1 .52 r
F
.80022 .82349 m .80068 .82368 L .80402 .82105 L F
.79421 .82735 m .79426 .82741 L .79425 .82733 L 0 1 .428 r
F
.77606 .82482 m .79426 .82742 L .79271 .82218 L 0 1 .515 r
F
0 g
.79425 .82733 m
.79426 .82741 L
s
.43807 .92697 m .43053 .91311 L .42961 .91564 L 0 .321 .341 r
F
0 g
.42426 .91067 m
.42961 .91564 L
s
.50794 1.02393 m .5053 1.03207 L .50616 1.02599 L 0 .687 .099 r
F
.50794 1.02393 m .50616 1.04077 L .5053 1.03207 L F
.50794 1.02393 m .50818 1.04626 L .50616 1.04077 L F
0 g
.5057 1.01896 m
.50616 1.02599 L
s
.50794 1.02393 m .50996 1.04416 L .50818 1.04626 L 0 .687 .099 r
F
.50794 1.02393 m .51032 1.03591 L .50996 1.04416 L F
.50794 1.02393 m .50945 1.02725 L .51032 1.03591 L F
0 g
.50746 1.01489 m
.50794 1.02393 L
s
.50616 1.02599 m
.50794 1.02393 L
s
.50945 1.02725 m
.51084 1.02183 L
s
.76501 .81245 m .76732 .79744 L .76327 .79968 L 0 1 .418 r
F
.76501 .81245 m .77529 .8066 L .76732 .79744 L F
.76501 .81245 m .78187 .82103 L .77529 .8066 L F
0 g
.78187 .82103 m
.78225 .82384 L
s
.78187 .82103 m
.78416 .82354 L
s
.7572 .80301 m
.76501 .81245 L
s
.3823 .77683 m
.38975 .77624 L
s
.3823 .77683 m
.38459 .77437 L
s
.49234 .84161 m .49061 .83565 L .48638 .83261 L 0 .247 .275 r
F
.49234 .84161 m .49712 .84198 L .49061 .83565 L F
.49234 .84161 m .50226 .84876 L .49712 .84198 L F
.49234 .84161 m .5026 .85146 L .50226 .84876 L F
.49234 .84161 m .49834 .84839 L .5026 .85146 L F
0 g
.48847 .83781 m
.49234 .84161 L
s
.48721 .83486 m
.49234 .84161 L
s
.67655 1.18657 m .6867 1.16473 L .68562 1.1779 L 0 .227 .11 r
F
0 g
.30438 .74836 m
.30525 .75024 L
s
.30525 .75024 m
.30972 .7512 L
s
.58731 .63793 m .59828 .64319 L .6078 .64617 L 0 .96 .477 r
F
0 g
.59828 .64319 m
.60521 .64792 L
s
.44282 .61503 m .43166 .61293 L .43306 .61475 L 0 1 .51 r
F
.44282 .61503 m .44017 .61116 L .43166 .61293 L F
.44279 .61776 m .44017 .61116 L .43164 .61466 L 0 1 .527 r
F
.44017 .61116 m .43971 .60999 L .43796 .61101 L F
.44017 .61116 m .43796 .61101 L .43166 .61293 L 0 1 .51 r
F
.44017 .61116 m .43796 .61101 L .43164 .61466 L 0 1 .527 r
F
.44017 .61116 m .4397 .61047 L .43796 .61101 L 0 1 .51 r
F
0 g
.43515 .61739 m
.43815 .61647 L
s
.43191 .61528 m
.43265 .61494 L
s
.44017 .61116 m .45186 .60686 L .43971 .60999 L 0 1 .527 r
F
.44282 .61503 m .44784 .61169 L .44017 .61116 L 0 1 .51 r
F
.44784 .61169 m .46164 .60687 L .45186 .60686 L 0 1 .527 r
F
.44282 .61503 m .45272 .61201 L .44784 .61169 L 0 1 .51 r
F
.45272 .61201 m .46251 .61001 L .46164 .60687 L 0 1 .527 r
F
.44282 .61503 m .45676 .61227 L .45272 .61201 L 0 1 .51 r
F
.44279 .61776 m .45443 .61467 L .45842 .61237 L 0 1 .527 r
F
.45676 .61227 m .45842 .61237 L .46251 .61001 L F
.44282 .61503 m .45444 .61358 L .45842 .61237 L 0 1 .51 r
F
.44282 .61503 m .45842 .61237 L .45823 .61236 L F
.44282 .61503 m .45876 .61226 L .45715 .61219 L F
.44279 .61776 m .45842 .61237 L .45676 .61227 L 0 1 .527 r
F
.45823 .61236 m .45842 .61237 L .45876 .61226 L 0 1 .51 r
F
.45715 .61219 m .45876 .61226 L .4625 .61113 L F
.44027 .61141 m .44784 .61169 L .4402 .61123 L 0 1 .527 r
F
.44279 .61776 m .44778 .61176 L .44027 .61141 L F
.44778 .61176 m .44784 .61169 L .44027 .61141 L F
.44279 .61776 m .45676 .61227 L .45272 .61201 L F
.45676 .61227 m .46251 .61001 L .45272 .61201 L F
.45676 .61227 m .45692 .61223 L .45272 .61201 L 0 1 .51 r
F
.45272 .61201 m .4625 .61113 L .46162 .60931 L F
.45692 .61223 m .4625 .61113 L .45272 .61201 L F
.44778 .61176 m .45272 .61201 L .44784 .61169 L 0 1 .527 r
F
.44279 .61776 m .45272 .61201 L .44778 .61176 L F
.45272 .61201 m .46164 .60687 L .44784 .61169 L F
.45272 .61201 m .45281 .61199 L .44784 .61169 L 0 1 .51 r
F
.44784 .61169 m .46162 .60931 L .45184 .60902 L F
.45281 .61199 m .46162 .60931 L .44784 .61169 L F
.4402 .61123 m .44784 .61169 L .44017 .61116 L 0 1 .527 r
F
.44784 .61169 m .45186 .60686 L .44017 .61116 L F
.44017 .61116 m .45184 .60902 L .4397 .61047 L 0 1 .51 r
F
.44784 .61169 m .45184 .60902 L .44017 .61116 L F
.32194 .75456 m .31332 .74916 L .30972 .7512 L 0 .823 .457 r
F
0 g
.5248 .90163 m
.52677 .90597 L
s
.54158 1.12549 m .54253 1.13259 L .54615 1.15109 L 0 0 .094 r
F
0 g
.54127 1.12659 m
.54253 1.13259 L
s
.54127 1.12554 m
.54253 1.13259 L
s
.58731 .63793 m .58122 .63156 L .58 .63295 L 0 .96 .477 r
F
.58731 .63793 m .59074 .63454 L .58122 .63156 L F
.58731 .63793 m .60222 .6399 L .59074 .63454 L F
.58731 .63793 m .60952 .64489 L .60222 .6399 L F
.58731 .63793 m .6078 .64617 L .60952 .64489 L F
0 g
.59828 .64319 m
.6078 .64617 L
s
.57817 .63486 m
.58731 .63793 L
s
.6078 .64617 m
.61442 .65227 L
s
.674 .91198 m
.67402 .91349 L
s
.67402 .91378 m
.67403 .91424 L
s
.67057 .91766 m
.674 .91198 L
s
.66951 .91941 m
.67057 .91766 L
s
.36914 .62613 m
.37611 .62104 L
s
.55938 .62739 m .55216 .62197 L .55146 .62345 L 0 1 .468 r
F
0 g
.54237 .6228 m
.55146 .62345 L
s
.55938 .62739 m .56152 .62375 L .55216 .62197 L 0 1 .468 r
F
.55938 .62739 m .5733 .62762 L .56152 .62375 L F
.55938 .62739 m .58122 .63156 L .5733 .62762 L F
0 g
.57323 .63243 m
.57817 .63486 L
s
.55938 .62739 m .58 .63295 L .58122 .63156 L 0 1 .468 r
F
.55938 .62739 m .57064 .63116 L .58 .63295 L F
0 g
.58 .63295 m
.58731 .63793 L
s
.55042 .62554 m
.55938 .62739 L
s
.55146 .62345 m
.55938 .62739 L
s
.57064 .63116 m
.57323 .63243 L
s
.69389 .69026 m
.69406 .69026 L
s
.59699 .57958 m .58986 .57475 L .58865 .57755 L 0 1 .533 r
F
.59699 .57958 m .60039 .57273 L .58986 .57475 L F
.59699 .57958 m .61319 .57284 L .60039 .57273 L F
0 g
.54909 .96265 m
.55168 .97928 L
s
.54783 .95447 m
.54909 .96265 L
s
.483 .99679 m
.48634 1.00061 L
s
.57064 .63116 m
.58 .63295 L
s
.45124 .80086 m .44725 .79529 L .44296 .79466 L 0 .55 .396 r
F
.45124 .80086 m .45473 .79824 L .44725 .79529 L F
.45124 .80086 m .4613 .80236 L .45473 .79824 L F
.45124 .80086 m .46258 .8049 L .4613 .80236 L F
.45124 .80086 m .45826 .80425 L .46258 .8049 L F
0 g
.44728 .79978 m
.45124 .80086 L
s
.44469 .79676 m
.45124 .80086 L
s
.34632 .76883 m
.34708 .769 L
s
.3527 .77438 m
.35409 .7756 L
s
.34632 .76883 m
.34684 .76928 L
s
.35051 .77248 m
.3527 .77438 L
s
.43053 .9131 m .42198 .90243 L .42499 .90767 L 0 .418 .377 r
F
0 g
.42426 .91067 m
.42499 .90767 L
s
.44561 .94045 m .44205 .92953 L .43807 .92697 L 0 .242 .28 r
F
.44561 .94045 m .44709 .93577 L .44205 .92953 L F
.44561 .94045 m .44982 .94152 L .44709 .93577 L F
.44561 .94045 m .44919 .94352 L .44982 .94152 L F
0 g
.44058 .93422 m
.44561 .94045 L
s
.44528 .94189 m
.44561 .94045 L
s
.46383 .61375 m
.46661 .61328 L
s
.45627 .61361 m
.46383 .61375 L
s
.34158 .62564 m .32817 .62507 L .33097 .62741 L 0 1 .536 r
F
0 g
.3298 .62855 m
.33097 .62741 L
s
.54158 1.12549 m .5493 1.16641 L .54531 1.14464 L 0 0 .094 r
F
.54158 1.12549 m .54615 1.15109 L .54991 1.17033 L F
0 g
.54595 1.15159 m
.54623 1.1529 L
s
.54722 1.15505 m
.54751 1.15611 L
s
.54147 1.12474 m
.54158 1.12549 L
s
.54204 1.12539 m
.54234 1.12715 L
s
.54234 1.12715 m
.54274 1.12943 L
s
.54274 1.12943 m
.54288 1.13022 L
s
.54578 1.15077 m
.54595 1.15159 L
s
.54575 1.15064 m
.54578 1.15077 L
s
.54329 1.13885 m
.54554 1.1496 L
s
.54554 1.1496 m
.54575 1.15064 L
s
.54158 1.12549 m
.54189 1.12707 L
s
.54189 1.12707 m
.54242 1.12982 L
s
.54242 1.12982 m
.54245 1.12994 L
s
.47433 .98534 m .46761 .97471 L .47035 .97879 L 0 .23 0 r
F
0 g
.47035 .97879 m
.47061 .97888 L
s
.726 .7607 m
.73495 .76927 L
s
.62833 .89782 m .63364 .88446 L .63976 .86248 L 0 1 .147 r
F
0 g
.63837 .86749 m
.6387 .86628 L
s
.6387 .86628 m
.63976 .86248 L
s
.6366 .88339 m
.63699 .8811 L
s
.63699 .8811 m
.6396 .86577 L
s
.63629 .88518 m
.6366 .88339 L
s
.63976 .86248 m
.63989 .86195 L
s
.73554 1.04154 m .73666 1.05408 L .74166 1.05593 L 0 1 .317 r
F
0 g
.73666 1.05408 m
.7416 1.05591 L
s
.7416 1.05591 m
.74163 1.05592 L
s
.74163 1.05592 m
.74166 1.05593 L
s
.7375 1.06948 m
.74166 1.05593 L
s
.56341 .58823 m .55547 .58374 L .55477 .58669 L 0 1 .533 r
F
.56341 .58823 m .56553 .58096 L .55547 .58374 L F
.56341 .58823 m .57823 .58021 L .56553 .58096 L F
.56341 .58823 m .58684 .58175 L .57823 .58021 L F
0 g
.55374 .59114 m
.56341 .58823 L
s
.58684 .58175 m
.59699 .57958 L
s
.78634 .8177 m .79271 .82218 L .80068 .82368 L 0 1 .52 r
F
0 g
.80009 .82357 m
.80068 .82368 L
s
.7935 .82233 m
.79425 .82733 L
s
.72326 .95297 m .73316 .98289 L .73861 .97453 L 0 1 .323 r
F
.72326 .95297 m .72657 .97364 L .73316 .98289 L F
0 g
.72326 .95297 m
.7248 .93293 L
s
.71304 .968 m .72657 .97364 L .72326 .95297 L 0 1 .307 r
F
0 g
.71773 .94145 m
.72326 .95297 L
s
.43632 .7915 m
.44296 .79466 L
s
.22186 .90283 m .21457 .89628 L .21054 .89822 L 0 .651 .352 r
F
.22186 .90283 m .22093 .89639 L .21457 .89628 L F
.22186 .90283 m .22537 .89848 L .22093 .89639 L F
.22186 .90283 m .22576 .90125 L .22537 .89848 L F
0 g
.21553 .90271 m
.22186 .90283 L
s
.22186 .90283 m
.22238 .90532 L
s
.39282 .62413 m
.40263 .62346 L
s
.38975 .77624 m
.39372 .77482 L
s
.43053 .9131 m .42329 .89958 L .42198 .90243 L 0 .418 .377 r
F
0 g
.41647 .898 m
.42198 .90243 L
s
.71583 1.13175 m .72622 1.10731 L .72391 1.11275 L 0 0 0 r
F
.74536 .84774 m .76125 .8428 L .75557 .83981 L 0 1 .487 r
F
0 g
.76125 .8428 m
.76231 .84711 L
s
.76125 .8428 m
.76804 .84301 L
s
.69196 1.18295 m .7003 1.15199 L .70223 1.15602 L 0 .03 .087 r
F
0 g
.7003 1.15199 m
.70193 1.14319 L
s
.6968 1.15471 m
.7003 1.15199 L
s
.27695 .74519 m
.27919 .74174 L
s
.27919 .74174 m
.27994 .7406 L
s
.80261 .80221 m
.80495 .82122 L
s
.73075 1.00205 m .73861 .97453 L .73316 .98289 L 0 1 .322 r
F
0 g
.73861 .97453 m
.74442 .98012 L
s
.73861 .97453 m
.74013 .95447 L
s
.54302 1.12831 m
.54312 1.12903 L
s
.46382 .61475 m
.46661 .61328 L
s
.46661 .61328 m
.46741 .61285 L
s
.45443 .61467 m
.46382 .61475 L
s
.48098 .82703 m
.48638 .83261 L
s
.48098 .82703 m
.48387 .82841 L
s
.67901 .90859 m
.6817 .90539 L
s
.63168 .82107 m .64862 .79122 L .64512 .78991 L 0 1 .27 r
F
0 g
.64821 .79107 m
.64825 .79109 L
s
.63168 .82107 m .64595 .80051 L .64862 .79122 L 0 1 .27 r
F
0 g
.64494 .80799 m
.64864 .79844 L
s
.64862 .79122 m
.6487 .79105 L
s
.64825 .79109 m
.64862 .79122 L
s
.50185 .60414 m .51382 .60199 L .52291 .59807 L 0 1 .529 r
F
0 g
.51382 .60199 m
.52266 .60271 L
s
.34692 .79674 m .33536 .79746 L .33885 .80142 L 0 1 .452 r
F
0 g
.33885 .80142 m
.34058 .80041 L
s
.33972 .81259 m
.34204 .80741 L
s
.34204 .80741 m
.34485 .80114 L
s
.34692 .79674 m .33843 .7885 L .33536 .79746 L 0 1 .452 r
F
.34692 .79674 m .34601 .78051 L .33843 .7885 L F
.34692 .79674 m .35409 .77582 L .34601 .78051 L F
0 g
.34058 .80041 m
.34692 .79674 L
s
.73554 1.04154 m .74434 1.01504 L .73883 1.02479 L 0 1 .317 r
F
.73075 1.00205 m .73883 1.02479 L .74434 1.01504 L 0 1 .322 r
F
0 g
.74434 1.01504 m
.74932 1.01694 L
s
.74434 1.01504 m
.74673 .9959 L
s
.63635 .96942 m
.6374 1.00309 L
s
.63756 1.0082 m
.63779 1.01536 L
s
.63598 .95771 m
.63635 .96942 L
s
.6359 .95505 m
.63598 .95771 L
s
.63448 1.03353 m
.63498 1.00607 L
s
.63357 1.08398 m
.6336 1.08202 L
s
.6336 1.08202 m
.63364 1.08016 L
s
.63498 1.00607 m
.63582 .9593 L
s
.63582 .9593 m
.6359 .95505 L
s
.63332 1.09768 m
.63357 1.08398 L
s
.53921 1.04467 m .54465 1.10069 L .54109 1.07065 L 0 .702 .183 r
F
.53921 1.04467 m .54837 1.11781 L .54465 1.10069 L F
.54945 1.10691 m .54968 1.11556 L .55375 1.15814 L 0 .017 .133 r
F
.53921 1.04467 m .54973 1.11032 L .54837 1.11781 L 0 .702 .183 r
F
0 g
.54133 1.1165 m
.54302 1.12831 L
s
.54133 1.1165 m
.54351 1.12944 L
s
.54945 1.10691 m .55827 1.18116 L .5531 1.13478 L 0 .017 .133 r
F
.5565 1.19219 m .55555 1.18072 L .55876 1.18743 L 0 .735 .07 r
F
.5565 1.19219 m .56425 1.21417 L .56065 1.20567 L F
.5565 1.19219 m .56521 1.21209 L .56425 1.21417 L F
.561 1.21743 m .56065 1.20567 L .56425 1.21417 L 0 .816 .084 r
F
.561 1.21743 m .55925 1.20705 L .56065 1.20567 L F
.561 1.21743 m .56425 1.21417 L .56855 1.23017 L F
.561 1.21743 m .56855 1.23017 L .57067 1.24305 L F
.561 1.21743 m .56928 1.24448 L .5653 1.23348 L F
.561 1.21743 m .57067 1.24305 L .56928 1.24448 L F
.54945 1.10691 m .56244 1.22464 L .55827 1.18116 L 0 .017 .133 r
F
.54945 1.10691 m .56277 1.23566 L .56244 1.22464 L F
.54945 1.10691 m .55902 1.20689 L .56277 1.23566 L F
.54945 1.10691 m .55375 1.15814 L .55902 1.20689 L F
.53921 1.04467 m .54779 1.08396 L .54973 1.11032 L 0 .702 .183 r
F
.53921 1.04467 m .54389 1.05653 L .54779 1.08396 L F
0 g
.54293 1.0457 m
.54389 1.05653 L
s
.5359 1.03403 m
.53921 1.04467 L
s
.541 1.04331 m
.54304 1.05263 L
s
.54304 1.05263 m
.54389 1.05653 L
s
.72703 1.0924 m .7375 1.06949 L .73437 1.07051 L 0 1 .212 r
F
.33741 .82353 m .33884 .80143 L .33536 .79747 L 0 1 .29 r
F
.33741 .82353 m .33972 .81258 L .33884 .80143 L F
0 g
.33884 .80143 m
.33962 .81134 L
s
.33962 .81134 m
.33971 .81241 L
s
.33971 .81241 m
.33972 .81258 L
s
.32509 .84049 m .31359 .84364 L .31759 .84382 L 0 0 0 r
F
0 g
.31759 .84382 m
.32489 .84058 L
s
.32426 .84438 m
.32494 .84116 L
s
.32494 .84116 m
.32508 .8405 L
s
.32508 .84049 m
.3251 .84043 L
s
.31675 .84668 m
.31759 .84382 L
s
.63925 1.22268 m
.63925 1.22268 L
s
.71783 .74743 m .71775 .73471 L .7143 .73629 L 0 .976 .436 r
F
0 g
.70912 .73852 m
.71783 .74743 L
s
.32892 .79959 m .32108 .79228 L .32462 .7977 L 0 1 .426 r
F
.32892 .79959 m .32011 .78681 L .32108 .79228 L F
.42329 .89958 m .41445 .88921 L .41746 .89451 L 0 .526 .398 r
F
0 g
.41647 .898 m
.41746 .89451 L
s
.55616 .97099 m
.55923 1.00257 L
s
.55923 1.00257 m
.56063 1.01705 L
s
.55594 .99221 m
.55616 .97099 L
s
.7856 .80079 m .80495 .82122 L .80292 .80895 L 0 1 .437 r
F
.78634 .8177 m .80495 .82122 L .80324 .81571 L 0 1 .52 r
F
.34158 .62564 m .3349 .61957 L .32817 .62507 L 0 1 .536 r
F
.34158 .62564 m .3467 .61457 L .3349 .61957 L F
.34158 .62564 m .35735 .6128 L .3467 .61457 L F
.34158 .62564 m .35972 .61544 L .35735 .6128 L F
.34158 .62564 m .35295 .62094 L .35972 .61544 L F
0 g
.33517 .63094 m
.34158 .62564 L
s
.33097 .62741 m
.34158 .62564 L
s
.54814 1.08871 m
.54829 1.08932 L
s
.54829 1.08932 m
.54847 1.09002 L
s
.54847 1.09002 m
.54861 1.09057 L
s
.54861 1.09057 m
.54897 1.09196 L
s
.34154 .62716 m .3281 .62727 L .33091 .62939 L 0 1 .539 r
F
0 g
.32512 .63554 m
.33091 .62939 L
s
.44279 .61776 m .43164 .61466 L .43302 .61775 L 0 1 .527 r
F
0 g
.43302 .61775 m
.44279 .61776 L
s
.43229 .61823 m
.43302 .61775 L
s
.4256 .62265 m
.43229 .61823 L
s
.43509 .62243 m
.44279 .61776 L
s
.55434 1.06291 m .55528 1.04729 L .55933 1.05216 L 0 .587 .2 r
F
0 g
.55932 1.05215 m
.55933 1.05216 L
s
.55886 1.05159 m
.55932 1.05215 L
s
.55871 1.05142 m
.55886 1.05159 L
s
.5585 1.05117 m
.55871 1.05142 L
s
.5581 1.05068 m
.5585 1.05117 L
s
.55805 1.05062 m
.5581 1.05068 L
s
.55804 1.05061 m
.55805 1.05062 L
s
.55735 1.04977 m
.55804 1.05061 L
s
.55644 1.04869 m
.55735 1.04977 L
s
.55528 1.04729 m
.55644 1.04869 L
s
.55793 1.04582 m
.55862 1.04894 L
s
.55862 1.04894 m
.55885 1.04997 L
s
.55885 1.04997 m
.55933 1.05215 L
s
.55933 1.05215 m
.55933 1.05216 L
s
.55791 1.04454 m
.55908 1.05079 L
s
.55933 1.05215 m
.55933 1.05215 L
s
.55908 1.05079 m
.55933 1.05215 L
s
.55498 1.04475 m
.55528 1.04729 L
s
.69294 .89418 m .69629 .88915 L .69257 .8932 L 0 .806 .167 r
F
.69294 .89418 m .7024 .88512 L .69629 .88915 L F
0 g
.68701 .89941 m
.69294 .89418 L
s
.27013 .83827 m .25826 .83691 L .26249 .83856 L 0 1 .468 r
F
0 g
.26198 .84227 m
.26249 .83856 L
s
.6833 .70298 m
.68681 .70894 L
s
.68302 .70251 m
.6833 .70298 L
s
.68278 .70209 m
.68302 .70251 L
s
.68274 .70203 m
.68278 .70209 L
s
.68246 .70156 m
.68274 .70203 L
s
.54734 1.15567 m
.54751 1.15611 L
s
.5467 1.15407 m
.54677 1.15426 L
s
.55883 1.18708 m
.55906 1.18606 L
s
.45842 .61237 m
.45858 .61232 L
s
.3542 .78653 m
.35594 .78146 L
s
.35594 .78146 m
.35605 .78114 L
s
.35605 .78114 m
.35659 .77957 L
s
.55549 1.18054 m
.55555 1.18072 L
s
.5545 1.17766 m
.55549 1.18054 L
s
.55418 1.17671 m
.5545 1.17766 L
s
.55298 1.17322 m
.554 1.17619 L
s
.55408 1.17645 m
.55418 1.17671 L
s
.55278 1.17266 m
.55298 1.17322 L
s
.55259 1.17209 m
.55278 1.17266 L
s
.55221 1.171 m
.55244 1.17167 L
s
.55209 1.17065 m
.55221 1.171 L
s
.55209 1.17065 m
.55209 1.17065 L
s
.5516 1.16922 m
.55169 1.16947 L
s
.55169 1.16947 m
.55209 1.17065 L
s
.55073 1.16729 m
.55124 1.16841 L
s
.55133 1.16862 m
.5516 1.16922 L
s
.69169 .68816 m
.69854 .68353 L
s
.70154 .67922 m
.70267 .67839 L
s
.70267 .67839 m
.7107 .67249 L
s
.69854 .68353 m
.70294 .6827 L
s
.43807 .92697 m .43491 .91511 L .43053 .91311 L 0 .321 .341 r
F
0 g
.42961 .91564 m
.43053 .91311 L
s
.43807 .92697 m .44025 .92107 L .43491 .91511 L 0 .321 .341 r
F
.43807 .92697 m .44298 .927 L .44025 .92107 L F
.43807 .92697 m .44205 .92953 L .44298 .927 L F
0 g
.43274 .92102 m
.43807 .92697 L
s
.43745 .92898 m
.43807 .92697 L
s
.32892 .79959 m .32237 .78493 L .32011 .78681 L 0 1 .426 r
F
.32892 .79959 m .32667 .78681 L .32237 .78493 L F
.32892 .79959 m .33014 .7912 L .32667 .78681 L F
.32892 .79959 m .33111 .79668 L .33014 .7912 L F
.33741 .82353 m .32892 .79959 L .32979 .81075 L 0 1 .29 r
F
.33741 .82353 m .33111 .79668 L .32892 .79959 L F
0 g
.32462 .7977 m
.32892 .79959 L
s
.63451 .92256 m
.63481 .92034 L
s
.63481 .92034 m
.63533 .91651 L
s
.63533 .91651 m
.63582 .91289 L
s
.64179 .82527 m .64196 .81569 L .63931 .82665 L 0 1 .139 r
F
.63501 .85776 m .64179 .82527 L .63537 .84474 L 0 1 .141 r
F
.42329 .89958 m .41604 .88592 L .41445 .88921 L 0 .526 .398 r
F
0 g
.40868 .8852 m
.41445 .88921 L
s
.32194 .75456 m .32172 .74824 L .31332 .74916 L 0 .823 .457 r
F
.32194 .75456 m .33042 .74981 L .32172 .74824 L F
.32194 .75456 m .3336 .75282 L .33042 .74981 L F
.32194 .75456 m .32995 .75485 L .3336 .75282 L F
0 g
.31862 .75548 m
.32194 .75456 L
s
.31328 .753 m
.32194 .75456 L
s
.50788 .8651 m .50311 .85502 L .50345 .85706 L 0 .159 .229 r
F
0 g
.50397 .85943 m
.50788 .8651 L
s
.50146 .8551 m
.50345 .85706 L
s
.32011 .78681 m .31216 .78069 L .31574 .78499 L 0 1 .472 r
F
.74716 .77666 m .76327 .79968 L .76732 .79744 L 0 1 .429 r
F
.74716 .77666 m .75463 .79077 L .76327 .79968 L F
0 g
.76327 .79968 m
.76501 .81245 L
s
.75463 .79077 m
.7572 .80301 L
s
.75463 .79077 m
.76327 .79968 L
s
.47433 .98534 m .4678 .9751 L .46761 .97471 L 0 .23 0 r
F
0 g
.46347 .96877 m
.46761 .97471 L
s
.50185 .60414 m .49225 .60027 L .49261 .6034 L 0 1 .529 r
F
.50185 .60414 m .50136 .59634 L .49225 .60027 L F
.50185 .60414 m .51385 .59425 L .50136 .59634 L F
.50185 .60414 m .52308 .59499 L .51385 .59425 L F
.50185 .60414 m .52291 .59807 L .52308 .59499 L F
0 g
.52291 .59807 m
.53172 .59916 L
s
.49314 .60814 m
.50185 .60414 L
s
.51382 .60199 m
.52291 .59807 L
s
.66408 1.19344 m
.66513 1.17955 L
s
.72703 1.0924 m .72703 1.09964 L .73016 1.09856 L 0 1 .212 r
F
0 g
.72622 1.10731 m
.73016 1.09856 L
s
.42411 .78467 m .41466 .78022 L .41683 .78208 L 0 .87 .46 r
F
0 g
.41314 .78284 m
.41683 .78208 L
s
.21054 .89822 m .20337 .89127 L .19921 .89358 L 0 .708 .376 r
F
0 g
.19921 .89358 m
.19954 .89661 L
s
.21054 .89822 m .20983 .89112 L .20337 .89127 L 0 .708 .376 r
F
.21054 .89822 m .21427 .89323 L .20983 .89112 L F
.21054 .89822 m .21457 .89628 L .21427 .89323 L F
0 g
.20411 .89835 m
.21054 .89822 L
s
.21054 .89822 m
.21096 .90097 L
s
.33741 .82353 m .33536 .79747 L .33111 .79668 L 0 1 .29 r
F
0 g
.33111 .79668 m
.33536 .79747 L
s
.66636 1.20994 m .67403 1.17567 L .67655 1.18657 L 0 .291 .135 r
F
0 g
.66914 1.17268 m
.67403 1.17567 L
s
.67403 1.17567 m
.67514 1.16255 L
s
.70241 .88512 m .70762 .8773 L .70274 .88233 L 0 1 .228 r
F
.70241 .88512 m .71485 .87359 L .70762 .8773 L F
.64578 .77094 m .6606 .74572 L .65237 .75227 L 0 1 .293 r
F
0 g
.65362 .76389 m
.66132 .75374 L
s
.6606 .74572 m
.66457 .74617 L
s
.6606 .74572 m
.66892 .73616 L
s
.47433 .98534 m .47081 .97971 L .4678 .9751 L 0 .23 0 r
F
.47433 .98534 m .4748 .98628 L .47081 .97971 L F
.47433 .98534 m .47711 .99041 L .4748 .98628 L F
.47433 .98534 m .4769 .99 L .47711 .99041 L F
0 g
.47433 .98534 m
.47446 .98402 L
s
.47035 .97879 m
.47433 .98534 L
s
.77529 .8066 m .79239 .81493 L .7856 .80079 L 0 1 .428 r
F
0 g
.79239 .81493 m
.79269 .81695 L
s
.79239 .81493 m
.79414 .81678 L
s
.34154 .62716 m .33483 .62187 L .3281 .62727 L 0 1 .539 r
F
0 g
.31789 .62748 m
.32817 .62507 L
s
.34154 .62716 m .34664 .61679 L .33483 .62187 L 0 1 .539 r
F
.34154 .62716 m .35731 .61455 L .34664 .61679 L F
.34154 .62716 m .35969 .61666 L .35731 .61455 L F
.34154 .62716 m .35292 .62207 L .35969 .61666 L F
0 g
.35917 .62739 m
.36562 .62209 L
s
.33512 .63252 m
.34154 .62716 L
s
.33091 .62939 m
.34154 .62716 L
s
.45443 .61467 m
.45842 .61237 L
s
.32011 .78681 m .31123 .77632 L .31216 .78069 L 0 1 .472 r
F
.32011 .78681 m .31357 .77481 L .31123 .77632 L F
.32011 .78681 m .31795 .77663 L .31357 .77481 L F
.32011 .78681 m .32144 .78057 L .31795 .77663 L F
.32011 .78681 m .32237 .78493 L .32144 .78057 L F
0 g
.32011 .78681 m
.32108 .79228 L
s
.31574 .78499 m
.32011 .78681 L
s
.68736 .95751 m
.6913 .9707 L
s
.33014 .7912 m
.33111 .79668 L
s
.77529 .8066 m .77746 .79185 L .7734 .79409 L 0 1 .428 r
F
.77529 .8066 m .7856 .80079 L .77746 .79185 L F
.65237 .75227 m .66763 .72963 L .65901 .73563 L 0 1 .307 r
F
0 g
.66763 .72963 m
.67187 .72986 L
s
.66763 .72963 m
.67628 .72094 L
s
.41604 .88592 m .40714 .87622 L .41003 .88137 L 0 .613 .409 r
F
0 g
.40868 .8852 m
.41003 .88137 L
s
.6959 .71686 m .70494 .72864 L .7143 .73629 L 0 .949 .455 r
F
0 g
.70494 .72864 m
.70912 .73852 L
s
.75557 .83981 m .77172 .83571 L .76581 .83218 L 0 1 .5 r
F
0 g
.77172 .83571 m
.77294 .84035 L
s
.77172 .83571 m
.7787 .83633 L
s
.3178 .63021 m
.3281 .62727 L
s
.29376 .74626 m .28546 .74353 L .28913 .74543 L 0 1 .519 r
F
.47181 .81625 m .46449 .80857 L .46576 .81092 L 0 .422 .375 r
F
0 g
.46476 .81065 m
.46576 .81092 L
s
.32509 .84049 m .31516 .84457 L .31359 .84364 L 0 0 0 r
F
0 g
.30658 .84549 m
.31359 .84364 L
s
.32509 .84049 m .3213 .84599 L .31516 .84457 L 0 0 0 r
F
.32509 .84049 m .32885 .84265 L .3213 .84599 L F
.32509 .84049 m .33274 .83678 L .32885 .84265 L F
.32509 .84049 m .33112 .83587 L .33274 .83678 L F
.63168 .82107 m .6387 .81329 L .64595 .80051 L 0 1 .27 r
F
0 g
.64519 .80185 m
.64595 .80051 L
s
.64595 .80051 m
.64864 .79844 L
s
.64335 .81209 m
.64494 .80799 L
s
.64258 .81409 m
.64335 .81209 L
s
.28051 .84216 m .27611 .83623 L .27013 .83827 L 0 1 .452 r
F
.28051 .84216 m .28362 .83592 L .27611 .83623 L F
.28051 .84216 m .28761 .83756 L .28362 .83592 L F
.28051 .84216 m .28626 .84023 L .28761 .83756 L F
0 g
.27305 .84246 m
.28051 .84216 L
s
.27938 .84462 m
.28051 .84216 L
s
.41604 .88592 m .4091 .87271 L .40714 .87622 L 0 .613 .409 r
F
0 g
.40121 .8728 m
.40714 .87622 L
s
.47208 .61038 m .48396 .60773 L .49261 .6034 L 0 1 .528 r
F
0 g
.48396 .60773 m
.49314 .60814 L
s
.29376 .74626 m .28465 .74136 L .28546 .74353 L 0 1 .519 r
F
.29376 .74626 m .28726 .74035 L .28465 .74136 L F
0 g
.27695 .74519 m
.28475 .74367 L
s
.28475 .74367 m
.28545 .74353 L
s
.29376 .74626 m .2919 .74119 L .28726 .74035 L 0 1 .519 r
F
.29376 .74626 m .29547 .7433 L .2919 .74119 L F
.29376 .74626 m .29626 .74547 L .29547 .7433 L F
0 g
.29376 .74626 m
.29464 .74814 L
s
.28913 .74543 m
.29376 .74626 L
s
.70288 .98556 m .70757 .95517 L .70352 .96115 L 0 1 .291 r
F
.70288 .98556 m .71304 .968 L .70757 .95517 L F
0 g
.70749 .93225 m
.70757 .95517 L
s
.7012 .95478 m
.70352 .96115 L
s
.32817 .62507 m
.3349 .61957 L
s
.47208 .61038 m .46164 .60687 L .46251 .61001 L 0 1 .528 r
F
.47208 .61038 m .47028 .60253 L .46164 .60687 L F
.47208 .61038 m .48268 .59989 L .47028 .60253 L F
.47208 .61038 m .49225 .60027 L .48268 .59989 L F
.47208 .61038 m .49261 .6034 L .49225 .60027 L F
0 g
.48957 .60493 m
.49261 .6034 L
s
.46741 .61285 m
.47208 .61038 L
s
.49261 .6034 m
.50185 .60414 L
s
.27013 .83827 m .25974 .83394 L .25826 .83691 L 0 1 .468 r
F
0 g
.25127 .83828 m
.25826 .83691 L
s
.69616 .6788 m
.70154 .67922 L
s
.39986 .61685 m
.40122 .61677 L
s
.40616 .61195 m .41794 .60749 L .4057 .61116 L 0 1 .529 r
F
.41007 .61628 m .41515 .61138 L .40616 .61195 L 0 1 .528 r
F
.41515 .61138 m .42817 .60702 L .41794 .60749 L 0 1 .529 r
F
.41007 .61628 m .42213 .61086 L .41515 .61138 L 0 1 .528 r
F
.42213 .61086 m .42956 .61006 L .42817 .60702 L 0 1 .529 r
F
.41007 .61628 m .42923 .6102 L .42213 .61086 L 0 1 .528 r
F
.41007 .61628 m .4218 .61358 L .42935 .61019 L F
.41003 .61856 m .42178 .61501 L .42935 .61019 L 0 1 .529 r
F
.42923 .6102 m .42935 .61019 L .42956 .61006 L F
.41007 .61628 m .42935 .61019 L .42923 .6102 L 0 1 .528 r
F
.41003 .61856 m .42935 .61019 L .42923 .6102 L 0 1 .529 r
F
.42923 .6102 m .42935 .61019 L .42955 .6101 L 0 1 .528 r
F
.42954 .6101 m .42955 .6101 L .42956 .6101 L F
.41007 .61628 m .42955 .6101 L .42954 .6101 L F
.40642 .6124 m .41515 .61138 L .40624 .61208 L 0 1 .529 r
F
.41003 .61856 m .41504 .61154 L .40642 .6124 L F
.41504 .61154 m .41515 .61138 L .40642 .6124 L F
.41003 .61856 m .42923 .6102 L .42213 .61086 L F
.42923 .6102 m .42956 .61006 L .42213 .61086 L F
.42923 .6102 m .42936 .61016 L .42213 .61086 L 0 1 .528 r
F
.42213 .61086 m .42956 .6101 L .42815 .60815 L F
.42936 .61016 m .42956 .6101 L .42213 .61086 L F
.41504 .61154 m .42213 .61086 L .41515 .61138 L 0 1 .529 r
F
.41003 .61856 m .42213 .61086 L .41504 .61154 L F
.42213 .61086 m .42817 .60702 L .41515 .61138 L F
.42213 .61086 m .42218 .61083 L .41515 .61138 L 0 1 .528 r
F
.41515 .61138 m .42815 .60815 L .41792 .60873 L F
.42218 .61083 m .42815 .60815 L .41515 .61138 L F
.40624 .61208 m .41515 .61138 L .40616 .61195 L 0 1 .529 r
F
.41515 .61138 m .41794 .60749 L .40616 .61195 L F
.40616 .61195 m .41792 .60873 L .40569 .61143 L 0 1 .528 r
F
.41515 .61138 m .41792 .60873 L .40616 .61195 L F
.43053 .9131 m .42805 .90104 L .42329 .89958 L 0 .418 .377 r
F
.43053 .9131 m .4336 .90648 L .42805 .90104 L F
.43053 .9131 m .43622 .91227 L .4336 .90648 L F
.43053 .9131 m .4349 .91511 L .43622 .91227 L F
0 g
.42499 .90767 m
.43053 .9131 L
s
.60039 .57273 m .62406 .57097 L .62578 .56836 L 0 1 .534 r
F
.60039 .57273 m .61319 .57284 L .62406 .57097 L F
0 g
.62406 .57097 m
.63196 .57355 L
s
.61319 .57284 m
.62406 .57097 L
s
.61319 .57284 m
.62149 .57488 L
s
.50788 .8651 m .50741 .85965 L .50311 .85502 L 0 .159 .229 r
F
.50788 .8651 m .5135 .86789 L .50741 .85965 L F
.50788 .8651 m .51795 .87597 L .5135 .86789 L F
.50788 .8651 m .51779 .87848 L .51795 .87597 L F
.50788 .8651 m .51347 .87381 L .51779 .87848 L F
0 g
.50345 .85706 m
.50788 .8651 L
s
.31332 .74916 m .30082 .74637 L .30438 .74836 L 0 1 .497 r
F
.74716 .77666 m .76732 .79744 L .76456 .78542 L 0 1 .429 r
F
0 g
.76732 .79744 m
.77529 .8066 L
s
.71485 .87359 m .71826 .86677 L .71428 .87063 L 0 1 .36 r
F
.71485 .87359 m .725 .86461 L .71826 .86677 L F
.42411 .78467 m .41899 .77964 L .41466 .78022 L 0 .87 .46 r
F
.42411 .78467 m .42697 .78073 L .41899 .77964 L F
.42411 .78467 m .43428 .78333 L .42697 .78073 L F
.42411 .78467 m .43602 .7857 L .43428 .78333 L F
.42411 .78467 m .43165 .78628 L .43602 .7857 L F
0 g
.42009 .78477 m
.42411 .78467 L
s
.41683 .78208 m
.42411 .78467 L
s
.63775 .79746 m .65362 .7639 L .64578 .77095 L 0 1 .278 r
F
0 g
.65362 .7639 m
.65628 .76591 L
s
.64695 .7906 m
.64821 .79107 L
s
.64512 .7899 m
.64971 .7824 L
s
.6959 .71686 m .69451 .70549 L .69143 .70694 L 0 .949 .455 r
F
.6959 .71686 m .70389 .71315 L .69451 .70549 L F
.6959 .71686 m .71329 .7248 L .70389 .71315 L F
.6959 .71686 m .71775 .73471 L .71329 .7248 L F
.6959 .71686 m .7143 .73629 L .71775 .73471 L F
0 g
.70494 .72864 m
.7143 .73629 L
s
.69143 .70694 m
.6959 .71686 L
s
.68681 .70894 m
.6959 .71686 L
s
.7143 .73629 m
.71783 .74743 L
s
.5305 1.04461 m
.53064 1.04687 L
s
.4091 .87271 m .39993 .86317 L .40282 .86842 L 0 .674 .416 r
F
0 g
.40121 .8728 m
.40282 .86842 L
s
.33843 .7885 m .32667 .78681 L .33015 .7912 L 0 1 .485 r
F
0 g
.65677 .98302 m
.65679 .98448 L
s
.74716 .77666 m .74817 .76268 L .74439 .76461 L 0 1 .429 r
F
.74716 .77666 m .75682 .7716 L .74817 .76268 L F
.74716 .77666 m .76456 .78542 L .75682 .7716 L F
0 g
.73872 .76744 m
.74716 .77666 L
s
.65901 .73563 m .6747 .71518 L .66568 .72062 L 0 1 .324 r
F
0 g
.6747 .71518 m
.67923 .71533 L
s
.6747 .71518 m
.68191 .70885 L
s
.40739 .77873 m
.41466 .78022 L
s
.65678 .98316 m
.65685 .98403 L
s
.65685 .98403 m
.66167 1.03999 L
s
.69196 1.18295 m .69008 1.17593 L .69174 1.16416 L 0 .03 .087 r
F
0 g
.6867 1.16473 m
.69174 1.16416 L
s
.32144 .78057 m
.32237 .78493 L
s
.32237 .78493 m
.32667 .78681 L
s
.4091 .87271 m .40217 .85931 L .39993 .86317 L 0 .674 .416 r
F
0 g
.39375 .86018 m
.39993 .86317 L
s
.56761 1.19974 m
.56941 1.20432 L
s
.56521 1.21209 m .56354 1.19461 L .56671 1.19746 L 0 .812 .096 r
F
0 g
.56671 1.19746 m
.56722 1.19875 L
s
.56671 1.19746 m
.56681 1.19448 L
s
.31123 .77632 m .30318 .77087 L .30678 .77464 L 0 1 .495 r
F
0 g
.72394 .74389 m
.72557 .73995 L
s
.71948 .75219 m
.72112 .74881 L
s
.72198 .74703 m
.7247 .74141 L
s
.7247 .74141 m
.72472 .74138 L
s
.72472 .74138 m
.72485 .74112 L
s
.72485 .74112 m
.7255 .73976 L
s
.47181 .81625 m .46898 .81004 L .46449 .80857 L 0 .422 .375 r
F
.47181 .81625 m .47626 .81436 L .46898 .81004 L F
.47181 .81625 m .48233 .81971 L .47626 .81436 L F
.47181 .81625 m .48314 .8225 L .48233 .81971 L F
.47181 .81625 m .47862 .82101 L .48314 .8225 L F
0 g
.46767 .81428 m
.47181 .81625 L
s
.46576 .81092 m
.47181 .81625 L
s
.72657 .97364 m
.73316 .98289 L
s
.71304 .968 m .72597 .99497 L .72657 .97364 L 0 1 .307 r
F
0 g
.72657 .97365 m
.72657 .97364 L
s
.4678 .9751 m .46077 .96307 L .46351 .96797 L 0 0 .154 r
F
0 g
.46347 .96877 m
.46351 .96797 L
s
.58682 1.05759 m
.58689 1.08283 L
s
.58689 1.08283 m
.58694 1.09849 L
s
.58674 1.02576 m
.58679 1.04418 L
s
.58679 1.04418 m
.5868 1.04881 L
s
.5868 1.04881 m
.58682 1.05759 L
s
.58502 1.02959 m
.58538 1.025 L
s
.49636 1.01583 m .4917 1.01262 L .49355 1.01246 L 0 .534 .049 r
F
0 g
.49355 1.01246 m
.49356 1.00918 L
s
.49636 1.01583 m .49209 1.01706 L .4917 1.01262 L 0 .534 .049 r
F
.49636 1.01583 m .49448 1.02285 L .49209 1.01706 L F
.49636 1.01583 m .49731 1.02622 L .49448 1.02285 L F
.49636 1.01583 m .49868 1.02493 L .49731 1.02622 L F
.49636 1.01583 m .49827 1.02047 L .49868 1.02493 L F
0 g
.49632 1.0102 m
.49636 1.01583 L
s
.49355 1.01246 m
.49636 1.01583 L
s
.36562 .62209 m
.37611 .62104 L
s
.71547 .75976 m
.71586 .75864 L
s
.71586 .75864 m
.71701 .75528 L
s
.71723 .75463 m
.718 .75239 L
s
.71128 .76844 m
.71238 .76581 L
s
.71311 .76408 m
.71375 .76253 L
s
.71375 .76253 m
.71637 .75629 L
s
.71672 .75545 m
.718 .75239 L
s
.47207 .61234 m .46162 .60931 L .4625 .61113 L 0 1 .499 r
F
.47207 .61234 m .47024 .60781 L .46162 .60931 L F
0 g
.45858 .61232 m
.4625 .61113 L
s
.47126 .61035 m
.47208 .61038 L
s
.47207 .61234 m .48264 .60764 L .47024 .60781 L 0 1 .499 r
F
.47207 .61234 m .49222 .60886 L .48264 .60764 L F
0 g
.48396 .60773 m
.48957 .60493 L
s
.47207 .61234 m .49258 .61065 L .49222 .60886 L 0 1 .499 r
F
.47207 .61234 m .48394 .61214 L .49258 .61065 L F
0 g
.46661 .61328 m
.47207 .61234 L
s
.4625 .61113 m
.47207 .61234 L
s
.48394 .61214 m
.49312 .61323 L
s
.33741 .82353 m .32979 .81075 L .33314 .82274 L 0 1 .29 r
F
0 g
.32892 .79959 m
.32979 .81075 L
s
.40217 .85931 m .39272 .84975 L .39561 .85517 L 0 .715 .419 r
F
0 g
.39375 .86018 m
.39561 .85517 L
s
.33843 .7885 m .32996 .77894 L .32667 .78681 L 0 1 .485 r
F
.53253 .59155 m .54495 .59004 L .55477 .58669 L 0 1 .532 r
F
0 g
.54495 .59004 m
.55374 .59114 L
s
.38138 .81675 m .37117 .8057 L .37404 .81182 L 0 .705 .426 r
F
.38138 .81675 m .37446 .80205 L .37117 .8057 L F
0 g
.36412 .79876 m
.37117 .8057 L
s
.37142 .81842 m
.37404 .81182 L
s
.3281 .62727 m
.33483 .62187 L
s
.49834 .84839 m
.5009 .85024 L
s
.49834 .84839 m
.50311 .85502 L
s
.31123 .77632 m .3023 .76703 L .30318 .77087 L 0 1 .495 r
F
.31123 .77632 m .30473 .76567 L .3023 .76703 L F
.31123 .77632 m .30919 .76736 L .30473 .76567 L F
.31123 .77632 m .3127 .77097 L .30919 .76736 L F
.31123 .77632 m .31357 .77481 L .3127 .77097 L F
0 g
.31123 .77632 m
.31216 .78069 L
s
.30678 .77464 m
.31123 .77632 L
s
.42329 .89958 m .42119 .88685 L .41604 .88592 L 0 .526 .398 r
F
0 g
.41445 .88921 m
.41604 .88592 L
s
.42329 .89958 m .42702 .89193 L .42119 .88685 L 0 .526 .398 r
F
.42329 .89958 m .42965 .89777 L .42702 .89193 L F
.42329 .89958 m .42805 .90104 L .42965 .89777 L F
0 g
.41746 .89451 m
.42329 .89958 L
s
.42198 .90243 m
.42329 .89958 L
s
.37446 .80205 m .36239 .78873 L .36618 .7958 L 0 .651 .427 r
F
0 g
.36414 .79866 m
.36618 .7958 L
s
.52105 1.03974 m
.52195 1.04596 L
s
.52087 1.0482 m
.52105 1.03974 L
s
.55073 1.16729 m
.55148 1.17029 L
s
.55163 1.17089 m
.55217 1.17305 L
s
.55265 1.17499 m
.55299 1.17634 L
s
.55217 1.17305 m
.55265 1.17499 L
s
.55339 1.17794 m
.55347 1.17827 L
s
.55321 1.17721 m
.55339 1.17794 L
s
.55347 1.17827 m
.55459 1.18275 L
s
.73561 .73882 m .73506 .72598 L .73501 .72601 L 0 1 .452 r
F
.73238 .72986 m .73501 .72601 L .73235 .72991 L 0 0 0 r
F
.73509 .72443 m .73501 .72601 L .73245 .72972 L F
.73245 .72972 m .73501 .72601 L .73238 .72986 L F
.73501 .72601 m .73501 .72601 L .73245 .72972 L F
.71189 .70903 m .73159 .72783 L .73501 .72601 L 0 1 .469 r
F
.73509 .72443 m .73506 .72593 L .73501 .72601 L 0 0 0 r
F
.73501 .726 m .73501 .72601 L .73502 .726 L 0 .882 .138 r
F
.73504 .72596 m .73502 .726 L .73506 .72593 L F
.73504 .72596 m .73501 .72601 L .73504 .72597 L 0 1 .469 r
F
.71189 .70903 m .73501 .72601 L .73504 .72596 L F
.73235 .72991 m .73501 .72601 L .73159 .72783 L 0 1 .452 r
F
.73561 .73882 m .73501 .72601 L .73235 .72991 L F
.73235 .72991 m .73501 .72601 L .73171 .73119 L 0 0 0 r
F
.71343 .7564 m .73171 .73119 L .73501 .72601 L 0 .882 .138 r
F
.71343 .7564 m .73501 .72601 L .73501 .726 L F
.71343 .7564 m .73502 .726 L .73504 .72596 L F
.73509 .72443 m .7437 .71239 L .73506 .72593 L 0 0 0 r
F
.7437 .71239 m .74346 .71354 L .74009 .71837 L F
.73939 .71867 m .7394 .71867 L .73961 .71832 L 0 .907 .153 r
F
.7394 .71867 m .74009 .71837 L .73961 .71832 L F
.71992 .70457 m .73961 .71832 L .73848 .71122 L 0 1 .474 r
F
.73961 .71832 m .74009 .71837 L .74346 .71354 L 0 .907 .153 r
F
.71992 .70457 m .73792 .721 L .73961 .71832 L 0 1 .474 r
F
.71992 .70457 m .7377 .72135 L .73792 .721 L F
.73775 .72121 m .73792 .721 L .7393 .71871 L 0 .907 .153 r
F
.73792 .721 m .74009 .71837 L .73939 .71867 L F
.73792 .721 m .73939 .71867 L .7393 .71871 L F
.71992 .70457 m .73006 .71602 L .7377 .72135 L 0 1 .474 r
F
.71189 .70903 m .73487 .72584 L .73006 .71602 L 0 1 .469 r
F
.73487 .72584 m .73493 .72574 L .73006 .71602 L F
.73493 .72574 m .73493 .72574 L .73006 .71602 L F
.73504 .72597 m .73505 .72595 L .73504 .72595 L F
.73504 .72596 m .73504 .72595 L .73006 .71602 L F
.73504 .72596 m .73506 .72593 L .73504 .72595 L 0 .882 .138 r
F
.73504 .72597 m .73504 .72595 L .73504 .72596 L 0 1 .469 r
F
.71343 .7564 m .73504 .72596 L .73057 .73022 L 0 .882 .138 r
F
.73504 .72596 m .73504 .72595 L .73057 .73022 L F
.72116 .74128 m .73057 .73022 L .73752 .72156 L 0 .907 .153 r
F
.73775 .72121 m .73752 .72156 L .74009 .71837 L F
.72116 .74128 m .73752 .72156 L .73775 .72121 L F
.73504 .72596 m .73504 .72596 L .73493 .72574 L 0 1 .469 r
F
.73504 .72596 m .73493 .72574 L .73493 .72574 L F
.73792 .721 m .7377 .72135 L .74027 .72314 L 0 1 .474 r
F
.71189 .70903 m .72167 .72056 L .73159 .72783 L 0 1 .469 r
F
.72116 .74128 m .73961 .71832 L .7387 .71737 L 0 .907 .153 r
F
.73961 .71832 m .74346 .71354 L .74082 .71566 L F
.73961 .71832 m .74082 .71566 L .73848 .71122 L 0 1 .474 r
F
.73961 .71832 m .74082 .71566 L .7387 .71737 L 0 .907 .153 r
F
.73961 .71832 m .74103 .71605 L .74082 .71566 L 0 1 .474 r
F
.73961 .71832 m .74375 .7212 L .74103 .71605 L F
.73961 .71832 m .74027 .72314 L .74375 .7212 L F
.73792 .721 m .74027 .72314 L .73961 .71832 L F
.7393 .71871 m .73939 .71867 L .73961 .71832 L 0 .907 .153 r
F
.72116 .74128 m .73775 .72121 L .7393 .71871 L F
.73487 .72584 m .73504 .72596 L .73493 .72574 L 0 1 .469 r
F
.73504 .72596 m .73504 .72597 L .73504 .72596 L F
.73504 .72597 m .73506 .72598 L .73505 .72595 L F
.73504 .72597 m .73501 .72601 L .73506 .72598 L F
0 g
.73469 .72523 m
.73486 .72487 L
s
.72775 .73761 m
.72985 .73383 L
s
.72985 .73383 m
.72993 .73369 L
s
.72993 .73369 m
.73002 .73353 L
s
.73466 .72519 m
.73478 .72498 L
s
.725 .86461 m .72825 .85744 L .72425 .86111 L 0 1 .428 r
F
.725 .86461 m .73517 .856 L .72825 .85744 L F
.40217 .85931 m .39523 .84559 L .39272 .84975 L 0 .715 .419 r
F
0 g
.38629 .84713 m
.39272 .84975 L
s
.41003 .61856 m .39794 .61611 L .39982 .61903 L 0 1 .529 r
F
0 g
.39982 .61903 m
.41003 .61856 L
s
.40263 .62346 m
.41003 .61856 L
s
.39282 .62413 m
.39982 .61903 L
s
.51172 1.03219 m .50996 1.04416 L .51032 1.03591 L 0 .717 .106 r
F
.51172 1.03219 m .51123 1.05475 L .50996 1.04416 L F
0 g
.50945 1.02725 m
.51032 1.03591 L
s
.51172 1.03219 m .51328 1.06058 L .51123 1.05475 L 0 .717 .106 r
F
.51172 1.03219 m .51469 1.0568 L .51328 1.06058 L F
.51172 1.03219 m .51452 1.04597 L .51469 1.0568 L F
.51172 1.03219 m .51325 1.03544 L .51452 1.04597 L F
0 g
.51325 1.03544 m
.51427 1.0285 L
s
.51084 1.02183 m
.51172 1.03219 L
s
.51032 1.03591 m
.51172 1.03219 L
s
.51427 1.0285 m
.51544 1.03936 L
s
.76581 .83218 m .7822 .82884 L .77606 .82482 L 0 1 .509 r
F
0 g
.7822 .82884 m
.78359 .83379 L
s
.7822 .82884 m
.78939 .82986 L
s
.49827 1.02047 m
.50073 1.02072 L
s
.45826 .80425 m
.46449 .80857 L
s
.68346 .70153 m
.69143 .70694 L
s
.6832 .70135 m
.68346 .70153 L
s
.68295 .70118 m
.6832 .70135 L
s
.3883 .83143 m .37834 .82093 L .38121 .82694 L 0 .736 .424 r
F
.3883 .83143 m .38138 .81675 L .37834 .82093 L F
0 g
.37142 .81842 m
.37834 .82093 L
s
.37884 .83338 m
.38121 .82694 L
s
.39523 .84559 m .38553 .83573 L .3884 .84142 L 0 .737 .422 r
F
0 g
.38629 .84713 m
.3884 .84142 L
s
.33843 .7885 m .33783 .77283 L .32996 .77894 L 0 1 .485 r
F
.33843 .7885 m .34614 .77012 L .33783 .77283 L F
.33843 .7885 m .34931 .77263 L .34614 .77012 L F
.33843 .7885 m .34601 .78051 L .34931 .77263 L F
0 g
.33536 .79746 m
.33843 .7885 L
s
.33015 .7912 m
.33843 .7885 L
s
.37446 .80205 m .36533 .78483 L .36239 .78873 L 0 .651 .427 r
F
0 g
.36084 .78662 m
.36239 .78873 L
s
.39523 .84559 m .3883 .83143 L .38553 .83573 L 0 .737 .422 r
F
0 g
.37884 .83338 m
.38553 .83573 L
s
.43166 .61293 m
.43796 .61101 L
s
.42428 .61342 m
.43166 .61293 L
s
.7856 .80079 m .80292 .80895 L .79592 .79503 L 0 1 .437 r
F
0 g
.80292 .80895 m
.80495 .82122 L
s
.48631 1.00389 m .48057 .99548 L .48288 .99812 L 0 .403 0 r
F
0 g
.48288 .99812 m
.483 .99679 L
s
.53253 .59155 m .55477 .58669 L .55547 .58374 L 0 1 .532 r
F
0 g
.55477 .58669 m
.56341 .58823 L
s
.54495 .59004 m
.55477 .58669 L
s
.54388 1.13431 m .543 1.13092 L .54531 1.14464 L 0 0 .096 r
F
0 g
.54323 1.13229 m
.54326 1.13247 L
s
.543 1.13092 m
.54323 1.13229 L
s
.544 1.13232 m
.544 1.13233 L
s
.54351 1.12944 m
.544 1.13232 L
s
.544 1.13233 m
.54428 1.13399 L
s
.54312 1.12903 m
.54356 1.13206 L
s
.54356 1.13206 m
.54372 1.13318 L
s
.54245 1.12994 m
.54382 1.137 L
s
.54288 1.13022 m
.543 1.13092 L
s
.4678 .9751 m .46128 .96265 L .46077 .96307 L 0 0 .154 r
F
0 g
.45633 .95676 m
.46077 .96307 L
s
.69616 .6788 m
.70605 .67296 L
s
.70605 .67296 m
.7107 .67249 L
s
.25974 .83394 m .24769 .83258 L .25192 .83434 L 0 1 .483 r
F
0 g
.25127 .83828 m
.25192 .83434 L
s
.36553 .7762 m .37439 .76618 L .36611 .76756 L 0 1 .541 r
F
.36553 .7762 m .37718 .76833 L .37439 .76618 L F
.36553 .7762 m .37337 .77262 L .37718 .76833 L F
0 g
.36022 .77708 m
.36553 .7762 L
s
.52105 .89207 m .51754 .88139 L .51738 .88275 L 0 .05 .17 r
F
0 g
.51467 .87883 m
.51738 .88275 L
s
.29547 .7433 m
.29626 .74547 L
s
.29626 .74547 m
.30082 .74637 L
s
.56553 .58096 m .57823 .58021 L .58865 .57755 L 0 1 .534 r
F
0 g
.57823 .58021 m
.58684 .58175 L
s
.5275 1.04529 m
.52768 1.04962 L
s
.56553 .58096 m .58865 .57755 L .58986 .57475 L 0 1 .534 r
F
0 g
.58865 .57755 m
.59699 .57958 L
s
.57823 .58021 m
.58865 .57755 L
s
.75682 .7716 m .7734 .79409 L .77746 .79185 L 0 1 .438 r
F
.75682 .7716 m .76456 .78542 L .7734 .79409 L F
0 g
.7734 .79409 m
.77529 .8066 L
s
.76456 .78542 m
.76732 .79744 L
s
.76456 .78542 m
.7734 .79409 L
s
.31332 .74916 m .3047 .7435 L .30082 .74637 L 0 1 .497 r
F
.67196 .69021 m .66927 .68013 L .6666 .68153 L 0 .943 .474 r
F
.67196 .69021 m .67894 .68668 L .66927 .68013 L F
0 g
.66261 .68346 m
.67196 .69021 L
s
.71304 .968 m .72184 1.00272 L .72597 .99497 L 0 1 .307 r
F
.71304 .968 m .7163 .99114 L .72184 1.00272 L F
.70288 .98556 m .7163 .99114 L .71304 .968 L 0 1 .291 r
F
0 g
.70757 .95517 m
.71304 .968 L
s
.71304 .968 m
.71366 .94672 L
s
.7856 .80079 m .78761 .78625 L .78355 .78849 L 0 1 .437 r
F
.7856 .80079 m .79592 .79503 L .78761 .78625 L F
.41604 .88592 m .41461 .87318 L .4091 .87271 L 0 .613 .409 r
F
.41604 .88592 m .42065 .87774 L .41461 .87318 L F
.41604 .88592 m .42316 .88335 L .42065 .87774 L F
.41604 .88592 m .42118 .88685 L .42316 .88335 L F
0 g
.41003 .88137 m
.41604 .88592 L
s
.73075 1.00205 m .733 1.01923 L .73883 1.02479 L 0 1 .322 r
F
0 g
.733 1.01923 m
.73883 1.02479 L
s
.73554 1.04154 m
.73883 1.02479 L
s
.73075 1.00205 m
.73316 .98289 L
s
.32996 .77894 m .31795 .77662 L .32144 .78056 L 0 1 .507 r
F
0 g
.52434 1.04348 m
.52443 1.04977 L
s
.70765 .77565 m
.70837 .77313 L
s
.70861 .77228 m
.70888 .77131 L
s
.70888 .77131 m
.70954 .76899 L
s
.70461 .78268 m
.70571 .77962 L
s
.70571 .77962 m
.70745 .77479 L
s
.70788 .7736 m
.70832 .77238 L
s
.70832 .77238 m
.70954 .76899 L
s
.66568 .72062 m .68182 .70205 L .6724 .70693 L 0 1 .342 r
F
0 g
.68182 .70205 m
.68295 .70118 L
s
.68182 .70205 m
.68278 .70209 L
s
.39372 .77482 m .38183 .77154 L .38524 .77367 L 0 1 .518 r
F
0 g
.38459 .77437 m
.38524 .77367 L
s
.35464 .62069 m
.36326 .61942 L
s
.56521 1.21209 m .56289 1.20086 L .56354 1.19461 L 0 .812 .096 r
F
0 g
.56289 1.20086 m
.5629 1.20077 L
s
.5629 1.20077 m
.56295 1.20027 L
s
.56295 1.20027 m
.56354 1.19461 L
s
.56132 1.18959 m
.56354 1.19461 L
s
.7437 .71239 m .75236 .70132 L .74346 .71354 L 0 0 0 r
F
0 g
.74258 .71424 m
.7437 .71239 L
s
.73506 .72593 m
.73606 .72436 L
s
.73606 .72436 m
.7379 .72149 L
s
.74245 .71435 m
.7437 .71239 L
s
.72511 1.06466 m .73666 1.05409 L .73554 1.04154 L 0 1 .289 r
F
.72511 1.06466 m .73437 1.07051 L .73666 1.05409 L F
.73517 .856 m .73825 .84856 L .73425 .85206 L 0 1 .465 r
F
.73517 .856 m .74536 .84774 L .73825 .84856 L F
0 g
.55038 1.0919 m
.55195 1.10158 L
s
.72671 .74329 m .7352 .75631 L .74439 .76461 L 0 1 .444 r
F
0 g
.7352 .75631 m
.73872 .76744 L
s
.43164 .61466 m
.43796 .61101 L
s
.43796 .61101 m
.43797 .611 L
s
.42917 .61475 m
.43164 .61466 L
s
.42178 .61501 m
.42917 .61475 L
s
.26752 .7405 m
.27007 .73654 L
s
.27007 .73654 m
.27073 .7355 L
s
.48631 1.00389 m .48088 .99761 L .48057 .99548 L 0 .403 0 r
F
.48631 1.00389 m .48362 1.0031 L .48088 .99761 L F
.48631 1.00389 m .48707 1.00888 L .48362 1.0031 L F
.48631 1.00389 m .48892 1.01108 L .48707 1.00888 L F
.48631 1.00389 m .48859 1.00894 L .48892 1.01108 L F
0 g
.48631 1.00389 m
.48634 1.00061 L
s
.48288 .99812 m
.48631 1.00389 L
s
.33741 .82354 m
.33918 .8282 L
s
.53646 1.05386 m .5376 1.0507 L .54109 1.07065 L 0 .741 .179 r
F
0 g
.53585 1.03388 m
.5376 1.0507 L
s
.33112 .83573 m
.33916 .8285 L
s
.3127 .77097 m
.31357 .77481 L
s
.31357 .77481 m
.31795 .77663 L
s
.44725 .79529 m .43863 .78917 L .44036 .79141 L 0 .711 .442 r
F
0 g
.43632 .7915 m
.44036 .79141 L
s
.39372 .77482 m .38559 .76893 L .38183 .77154 L 0 1 .518 r
F
.39372 .77482 m .39403 .76757 L .38559 .76893 L F
.39372 .77482 m .40254 .76873 L .39403 .76757 L F
.39372 .77482 m .40541 .77163 L .40254 .76873 L F
.39372 .77482 m .40162 .77424 L .40541 .77163 L F
0 g
.38524 .77367 m
.39372 .77482 L
s
.72671 .74329 m .74439 .76461 L .74817 .76268 L 0 1 .444 r
F
0 g
.74439 .76461 m
.74716 .77666 L
s
.7352 .75631 m
.74439 .76461 L
s
.60039 .57273 m .62578 .56836 L .61712 .56618 L 0 1 .534 r
F
0 g
.62578 .56836 m
.63662 .56719 L
s
.53253 .59155 m .52351 .58734 L .52334 .59039 L 0 1 .532 r
F
.53253 .59155 m .53335 .58399 L .52351 .58734 L F
.53253 .59155 m .54629 .58258 L .53335 .58399 L F
.53253 .59155 m .55547 .58374 L .54629 .58258 L F
0 g
.52308 .59499 m
.53253 .59155 L
s
.71775 .73471 m
.72258 .73934 L
s
.72271 .73946 m
.72382 .74053 L
s
.72448 .74116 m
.72468 .74135 L
s
.72468 .74135 m
.72472 .74138 L
s
.72472 .74138 m
.72491 .74156 L
s
.72552 .74216 m
.7257 .74232 L
s
.72529 .74193 m
.72552 .74216 L
s
.35292 .62207 m
.36325 .61976 L
s
.4678 .9751 m .46472 .96699 L .46128 .96265 L 0 0 .154 r
F
.4678 .9751 m .46903 .97414 L .46472 .96699 L F
.4678 .9751 m .47134 .97931 L .46903 .97414 L F
.4678 .9751 m .47081 .97971 L .47134 .97931 L F
0 g
.46351 .96797 m
.4678 .9751 L
s
.49061 .83565 m .48434 .82649 L .48515 .82902 L 0 .337 .346 r
F
0 g
.48515 .82902 m
.49061 .83564 L
s
.49061 .83565 m
.49061 .83565 L
s
.48638 .83261 m
.49061 .83565 L
s
.48387 .82841 m
.48515 .82902 L
s
.4769 .99 m
.48057 .99548 L
s
.62567 .84847 m .64196 .81569 L .6387 .81329 L 0 1 .264 r
F
.62567 .84847 m .63931 .82665 L .64196 .81569 L F
0 g
.63994 .8263 m
.64179 .82527 L
s
.64196 .81569 m
.64258 .81409 L
s
.543 1.12137 m
.54303 1.1216 L
s
.543 1.12137 m
.54306 1.12174 L
s
.4091 .87271 m .40804 .8594 L .40217 .85931 L 0 .674 .416 r
F
.4091 .87271 m .41435 .86368 L .40804 .8594 L F
.4091 .87271 m .41687 .86931 L .41435 .86368 L F
.4091 .87271 m .41461 .87318 L .41687 .86931 L F
0 g
.40282 .86842 m
.4091 .87271 L
s
.40714 .87622 m
.4091 .87271 L
s
.25974 .83394 m .24934 .82927 L .24769 .83258 L 0 1 .483 r
F
0 g
.24055 .83405 m
.24769 .83258 L
s
.3023 .76703 m .29415 .76202 L .29776 .76547 L 0 1 .507 r
F
.46128 .96265 m .45393 .9499 L .45666 .95533 L 0 .128 .206 r
F
0 g
.45633 .95676 m
.45666 .95533 L
s
.64627 .66763 m .65675 .67617 L .6666 .68153 L 0 .957 .489 r
F
0 g
.65675 .67617 m
.66261 .68346 L
s
.32996 .77894 m .32146 .76988 L .31795 .77662 L 0 1 .507 r
F
.77606 .82482 m .79271 .82218 L .78634 .8177 L 0 1 .515 r
F
0 g
.79271 .82218 m
.79426 .82742 L
s
.79271 .82218 m
.80009 .82357 L
s
.55552 1.18079 m
.55555 1.18072 L
s
.55506 1.18175 m
.55552 1.18079 L
s
.55496 1.18197 m
.55506 1.18175 L
s
.55469 1.18254 m
.5547 1.18251 L
s
.55476 1.1824 m
.55496 1.18197 L
s
.55459 1.18275 m
.55469 1.18254 L
s
.52105 .89207 m .52187 .88836 L .51754 .88139 L 0 .05 .17 r
F
.52105 .89207 m .52748 .89905 L .52187 .88836 L F
.52105 .89207 m .53117 .90842 L .52748 .89905 L F
.52105 .89207 m .53048 .91019 L .53117 .90842 L F
.52105 .89207 m .52614 .90317 L .53048 .91019 L F
0 g
.51712 .8834 m
.52105 .89207 L
s
.51738 .88275 m
.52105 .89207 L
s
.75682 .7716 m .77746 .79185 L .7745 .77999 L 0 1 .438 r
F
0 g
.77746 .79185 m
.7856 .80079 L
s
.63168 .82107 m .64512 .78991 L .63775 .79746 L 0 1 .27 r
F
0 g
.64182 .81559 m
.64196 .81569 L
s
.64092 .81492 m
.64182 .81559 L
s
.63988 .81415 m
.64092 .81492 L
s
.63978 .81408 m
.63988 .81415 L
s
.64512 .78991 m
.64695 .7906 L
s
.64169 .80801 m
.64519 .80185 L
s
.64016 .81072 m
.64169 .80801 L
s
.35409 .7756 m
.35448 .77537 L
s
.27013 .83827 m .26596 .83163 L .25974 .83394 L 0 1 .468 r
F
.27013 .83827 m .27364 .83132 L .26596 .83163 L F
.27013 .83827 m .27763 .83325 L .27364 .83132 L F
.27013 .83827 m .27611 .83623 L .27763 .83325 L F
0 g
.26249 .83856 m
.27013 .83827 L
s
.26882 .84094 m
.27013 .83827 L
s
.35409 .77582 m
.35448 .77537 L
s
.35448 .77537 m
.35525 .7745 L
s
.35525 .7745 m
.35666 .7729 L
s
.34601 .78051 m
.35409 .77582 L
s
.56154 1.19647 m
.56289 1.20086 L
s
.55892 1.18795 m
.55984 1.19096 L
s
.70223 1.15602 m .71091 1.1415 L .70678 1.15152 L 0 0 .058 r
F
.70549 1.16089 m .71091 1.1415 L .71478 1.13304 L 0 0 0 r
F
.70549 1.16089 m .70678 1.15152 L .71091 1.1415 L F
0 g
.71091 1.1415 m
.71251 1.13272 L
s
.71091 1.1415 m
.71141 1.14042 L
s
.3023 .76703 m .29332 .75847 L .29415 .76202 L 0 1 .507 r
F
.3023 .76703 m .29585 .75718 L .29332 .75847 L F
.3023 .76703 m .30039 .75875 L .29585 .75718 L F
.3023 .76703 m .30391 .76212 L .30039 .75875 L F
.3023 .76703 m .30473 .76567 L .30391 .76212 L F
0 g
.3023 .76703 m
.30318 .77087 L
s
.29776 .76547 m
.3023 .76703 L
s
.5657 1.05795 m
.5661 1.06041 L
s
.39796 .61491 m
.40426 .61208 L
s
.38875 .61628 m
.39796 .61491 L
s
.34601 .78051 m
.34931 .77263 L
s
.72041 1.0225 m .73075 1.00205 L .72597 .99497 L 0 1 .303 r
F
.72041 1.0225 m .733 1.01923 L .73075 1.00205 L F
0 g
.72463 .7372 m
.7251 .73857 L
s
.7255 .73975 m
.72557 .73995 L
s
.72603 .74129 m
.72611 .74154 L
s
.72589 .74089 m
.72603 .74129 L
s
.72671 .74329 m .74441 .75163 L .73561 .73882 L 0 1 .444 r
F
.72671 .74329 m .74817 .76268 L .74441 .75163 L F
0 g
.7257 .74232 m
.72671 .74329 L
s
.72611 .74154 m
.72671 .74329 L
s
.39331 .61304 m
.39511 .61194 L
s
.50184 .61281 m .49222 .60886 L .49258 .61065 L 0 1 .491 r
F
.50184 .61281 m .50133 .60838 L .49222 .60886 L F
0 g
.48394 .61214 m
.49258 .61065 L
s
.50184 .61281 m .51385 .60953 L .50133 .60838 L 0 1 .491 r
F
.50184 .61281 m .52311 .6117 L .51385 .60953 L F
.50184 .61281 m .52294 .61343 L .52311 .6117 L F
.50184 .61281 m .51382 .61391 L .52294 .61343 L F
0 g
.49312 .61323 m
.50184 .61281 L
s
.49258 .61065 m
.50184 .61281 L
s
.51382 .61391 m
.52268 .61591 L
s
.64627 .66763 m .64228 .65875 L .64007 .66017 L 0 .957 .489 r
F
.64627 .66763 m .65215 .6641 L .64228 .65875 L F
.64627 .66763 m .66308 .67266 L .65215 .6641 L F
.64627 .66763 m .66927 .68013 L .66308 .67266 L F
.64627 .66763 m .6666 .68153 L .66927 .68013 L F
0 g
.65675 .67617 m
.6666 .68153 L
s
.63675 .66214 m
.64627 .66763 L
s
.6666 .68153 m
.67196 .69021 L
s
.31332 .74916 m .31346 .74166 L .3047 .7435 L 0 1 .497 r
F
.31332 .74916 m .32245 .74246 L .31346 .74166 L F
.31332 .74916 m .32564 .74537 L .32245 .74246 L F
.31332 .74916 m .32172 .74824 L .32564 .74537 L F
0 g
.30972 .7512 m
.31332 .74916 L
s
.30438 .74836 m
.31332 .74916 L
s
.44725 .79529 m .44326 .78935 L .43863 .78917 L 0 .711 .442 r
F
.44725 .79529 m .45118 .79185 L .44326 .78935 L F
.44725 .79529 m .4581 .79575 L .45118 .79185 L F
.44725 .79529 m .45938 .79844 L .4581 .79575 L F
.44725 .79529 m .45473 .79824 L .45938 .79844 L F
0 g
.44296 .79466 m
.44725 .79529 L
s
.44036 .79141 m
.44725 .79529 L
s
.74536 .84774 m .74828 .84007 L .74427 .84342 L 0 1 .487 r
F
.74536 .84774 m .75557 .83981 L .74828 .84007 L F
.46128 .96265 m .45477 .94876 L .45393 .9499 L 0 .128 .206 r
F
0 g
.44919 .94352 m
.45393 .9499 L
s
.40217 .85931 m .40147 .84547 L .39523 .84559 L 0 .715 .419 r
F
.40217 .85931 m .40805 .84961 L .40147 .84547 L F
.40217 .85931 m .41057 .85524 L .40805 .84961 L F
.40217 .85931 m .40804 .8594 L .41057 .85524 L F
0 g
.39561 .85517 m
.40217 .85931 L
s
.39993 .86317 m
.40217 .85931 L
s
.72511 1.06466 m .73554 1.04154 L .73158 1.03901 L 0 1 .289 r
F
0 g
.73441 1.07026 m
.73666 1.05409 L
s
.38777 .61697 m
.39254 .61359 L
s
.39254 .61359 m
.39331 .61304 L
s
.38777 .61697 m
.39794 .61611 L
s
.74346 .71354 m
.7471 .70854 L
s
.7471 .70854 m
.75236 .70132 L
s
.49061 .83565 m .48896 .82897 L .48434 .82649 L 0 .337 .346 r
F
.49061 .83565 m .49594 .83481 L .48896 .82897 L F
.49061 .83565 m .50143 .84147 L .49594 .83481 L F
.49061 .83565 m .50176 .84447 L .50143 .84147 L F
.49061 .83565 m .49712 .84197 L .50176 .84447 L F
0 g
.49061 .83564 m
.49061 .83565 L
s
.33112 .83587 m
.33274 .83678 L
s
.32996 .77894 m .32965 .76481 L .32146 .76988 L 0 1 .507 r
F
.32996 .77894 m .33819 .76318 L .32965 .76481 L F
.32996 .77894 m .34137 .76607 L .33819 .76318 L F
0 g
.33815 .76162 m
.34625 .76585 L
s
.32996 .77894 m .33783 .77283 L .34137 .76607 L 0 1 .507 r
F
0 g
.32667 .78681 m
.32996 .77894 L
s
.32144 .78056 m
.32996 .77894 L
s
.69278 1.00669 m .69745 .97084 L .69341 .97776 L 0 .982 .277 r
F
.69278 1.00669 m .70288 .98556 L .69745 .97084 L F
0 g
.69742 .94439 m
.69745 .97084 L
s
.6913 .9707 m
.69341 .97776 L
s
.33314 .82274 m
.33741 .82353 L
s
.70549 1.16089 m .71478 1.13304 L .71583 1.13175 L 0 0 0 r
F
0 g
.71478 1.13304 m
.71711 1.12755 L
s
.71141 1.14042 m
.71478 1.13304 L
s
.31516 .84457 m .30358 .84235 L .30758 .84301 L 0 0 0 r
F
0 g
.30658 .84549 m
.30755 .84311 L
s
.43165 .78628 m
.43863 .78917 L
s
.60039 .57273 m .59291 .56776 L .59169 .57056 L 0 1 .534 r
F
.60039 .57273 m .60382 .56588 L .59291 .56776 L F
.60039 .57273 m .61712 .56618 L .60382 .56588 L F
0 g
.61712 .56618 m
.62578 .56836 L
s
.39794 .61611 m
.40426 .61208 L
s
.40426 .61208 m
.40426 .61208 L
s
.40426 .61208 m
.40524 .61146 L
s
.28465 .74136 m .27626 .73858 L .27994 .7406 L 0 1 .531 r
F
.29812 .93003 m .28734 .92657 L .29176 .92854 L 0 .534 .252 r
F
0 g
.29176 .92854 m
.29273 .93009 L
s
.75682 .7716 m .75764 .75772 L .75385 .75973 L 0 1 .438 r
F
.75682 .7716 m .7665 .76641 L .75764 .75772 L F
.75682 .7716 m .7745 .77999 L .7665 .76641 L F
0 g
.74817 .76268 m
.75682 .7716 L
s
.39523 .84559 m .3949 .83138 L .3883 .83143 L 0 .737 .422 r
F
.39523 .84559 m .40175 .83556 L .3949 .83138 L F
.39523 .84559 m .40427 .84117 L .40175 .83556 L F
.39523 .84559 m .40147 .84547 L .40427 .84117 L F
0 g
.3884 .84142 m
.39523 .84559 L
s
.39272 .84975 m
.39523 .84559 L
s
.72703 1.0924 m .73437 1.07051 L .73019 1.0799 L 0 1 .212 r
F
.72511 1.06466 m .73019 1.0799 L .73437 1.07051 L 0 1 .289 r
F
0 g
.73437 1.07051 m
.73441 1.07026 L
s
.73437 1.07051 m
.7375 1.06949 L
s
.54388 1.13431 m .55208 1.18151 L .54776 1.15593 L 0 0 .096 r
F
0 g
.54932 1.16732 m
.54939 1.1677 L
s
.54388 1.13431 m .54531 1.14464 L .5493 1.16641 L 0 0 .096 r
F
0 g
.54326 1.13247 m
.54531 1.14464 L
s
.54428 1.13399 m
.54486 1.13744 L
s
.54486 1.13744 m
.54506 1.13866 L
s
.54372 1.13318 m
.54388 1.13431 L
s
.54382 1.137 m
.54531 1.14464 L
s
.54457 1.13249 m
.54489 1.13477 L
s
.54517 1.13676 m
.54523 1.1372 L
s
.54489 1.13477 m
.54517 1.13676 L
s
.54565 1.13752 m
.54578 1.13834 L
s
.54497 1.13342 m
.54565 1.13752 L
s
.54615 1.15109 m
.54736 1.15772 L
s
.54736 1.15772 m
.54774 1.15981 L
s
.54705 1.15567 m
.54794 1.16027 L
s
.54794 1.16027 m
.54895 1.16545 L
s
.54895 1.16545 m
.54906 1.16599 L
s
.54906 1.16599 m
.54932 1.16732 L
s
.54615 1.15109 m
.54705 1.15567 L
s
.54388 1.13431 m
.54415 1.13583 L
s
.54415 1.13583 m
.54417 1.13593 L
s
.72041 1.0225 m .73158 1.03901 L .733 1.01923 L 0 1 .303 r
F
.28465 .74136 m .27553 .73618 L .27626 .73858 L 0 1 .531 r
F
.28465 .74136 m .27824 .735 L .27553 .73618 L F
0 g
.26752 .7405 m
.27549 .73875 L
s
.27549 .73875 m
.27626 .73858 L
s
.28465 .74136 m .28296 .73576 L .27824 .735 L 0 1 .531 r
F
.28465 .74136 m .28654 .73796 L .28296 .73576 L F
.28465 .74136 m .28726 .74035 L .28654 .73796 L F
0 g
.28465 .74136 m
.28546 .74353 L
s
.27994 .7406 m
.28465 .74136 L
s
.32146 .76988 m .30919 .76736 L .3127 .77097 L 0 1 .516 r
F
0 g
.47862 .82101 m
.48204 .82214 L
s
.47862 .82101 m
.48434 .82649 L
s
.6191 .64912 m .63013 .65604 L .64007 .66017 L 0 .988 .496 r
F
0 g
.63013 .65604 m
.63675 .66214 L
s
.56553 .58096 m .55721 .57638 L .55651 .57932 L 0 1 .534 r
F
.56553 .58096 m .56766 .57371 L .55721 .57638 L F
.56553 .58096 m .58088 .57311 L .56766 .57371 L F
.56553 .58096 m .58986 .57475 L .58088 .57311 L F
0 g
.55547 .58374 m
.56553 .58096 L
s
.58986 .57475 m
.60039 .57273 L
s
.67227 .9157 m .67699 .91061 L .6833 .90364 L 0 .845 .141 r
F
0 g
.68308 .90389 m
.6833 .90364 L
s
.68307 .9039 m
.68308 .90389 L
s
.67774 .9101 m
.67901 .90859 L
s
.53163 .92018 m .52945 .91102 L .52875 .91035 L 0 0 .129 r
F
0 g
.53132 .91911 m
.53155 .91991 L
s
.52875 .91035 m
.53132 .91911 L
s
.52677 .90597 m
.52875 .91035 L
s
.66357 .93239 m .66797 .924 L .67403 .91447 L 0 0 0 r
F
0 g
.67391 .91466 m
.67403 .91447 L
s
.67403 .91424 m
.67403 .91447 L
s
.66848 .92112 m
.66951 .91941 L
s
.66476 .9253 m
.66477 .92561 L
s
.51347 .87382 m
.51754 .88139 L
s
.51347 .87381 m
.5156 .87612 L
s
.6995 .79496 m
.70015 .79223 L
s
.70026 .79176 m
.70078 .78955 L
s
.70078 .78955 m
.70115 .78798 L
s
.69775 .79904 m
.69932 .79394 L
s
.6995 .79334 m
.70045 .79024 L
s
.70045 .79024 m
.70115 .78798 L
s
.68101 .90128 m .69257 .8932 L .69629 .88915 L 0 1 .21 r
F
.68101 .90128 m .68604 .8984 L .69257 .8932 L F
0 g
.69257 .8932 m
.69294 .89418 L
s
.45477 .94876 m .44709 .93577 L .44982 .94152 L 0 .238 .286 r
F
0 g
.44919 .94352 m
.44982 .94152 L
s
.24934 .82927 m .2371 .82801 L .24134 .82986 L 0 1 .494 r
F
0 g
.24055 .83405 m
.24134 .82986 L
s
.66447 .92632 m
.66477 .92561 L
s
.50136 .59634 m .51385 .59425 L .52334 .59039 L 0 1 .531 r
F
0 g
.51385 .59425 m
.52308 .59499 L
s
.3883 .83143 m .38832 .81721 L .38138 .81675 L 0 .736 .424 r
F
.3883 .83143 m .39543 .82169 L .38832 .81721 L F
.3883 .83143 m .39796 .82721 L .39543 .82169 L F
.3883 .83143 m .3949 .83138 L .39796 .82721 L F
0 g
.38121 .82694 m
.3883 .83143 L
s
.38553 .83573 m
.3883 .83143 L
s
.68101 .90128 m .69629 .88915 L .6951 .8871 L 0 1 .21 r
F
0 g
.69629 .88915 m
.7024 .88512 L
s
.53949 .94242 m .53867 .94026 L .53744 .93475 L 0 .457 0 r
F
0 g
.53593 .92959 m
.53744 .93475 L
s
.55048 1.05815 m
.55193 1.05994 L
s
.3047 .7435 m .2919 .74118 L .29547 .7433 L 0 1 .516 r
F
0 g
.54774 1.15981 m
.54812 1.16135 L
s
.54812 1.16135 m
.54826 1.16188 L
s
.54997 1.16875 m
.5503 1.17007 L
s
.54984 1.16825 m
.54997 1.16875 L
s
.55054 1.17105 m
.55063 1.17141 L
s
.53163 .92018 m .53617 .934 L .53826 .93932 L 0 0 .129 r
F
.53771 .9372 m .53826 .93932 L .5405 .94501 L F
.53163 .92018 m .53826 .93932 L .53771 .9372 L F
.53949 .94242 m .54208 .95399 L .53867 .94026 L 0 .457 0 r
F
.54208 .95399 m .54294 .95783 L .54097 .94972 L F
.54208 .95399 m .54097 .94972 L .53867 .94026 L F
0 g
.53792 .93431 m
.53938 .94189 L
s
.53744 .93475 m
.53923 .94146 L
s
.43971 .60999 m .42817 .60702 L .42956 .61006 L 0 1 .529 r
F
.43971 .60999 m .43662 .60234 L .42817 .60702 L F
.43971 .60999 m .44928 .59915 L .43662 .60234 L F
.43971 .60999 m .45944 .59908 L .44928 .59915 L F
.43971 .60999 m .46032 .60218 L .45944 .59908 L F
.43971 .60999 m .45186 .60686 L .46032 .60218 L F
0 g
.43797 .611 m
.43971 .60999 L
s
.35463 .77195 m
.35491 .77208 L
s
.38138 .81675 m .38174 .80332 L .37446 .80205 L 0 .705 .426 r
F
0 g
.37117 .8057 m
.37446 .80205 L
s
.38138 .81675 m .38911 .80826 L .38174 .80332 L 0 .705 .426 r
F
.38138 .81675 m .39164 .81357 L .38911 .80826 L F
.38138 .81675 m .38832 .81721 L .39164 .81357 L F
0 g
.37404 .81182 m
.38138 .81675 L
s
.37834 .82093 m
.38138 .81675 L
s
.53646 1.05386 m .54111 1.10842 L .53795 1.07847 L 0 .741 .179 r
F
0 g
.53921 1.04467 m
.53996 1.05491 L
s
.53646 1.05386 m .54466 1.1288 L .54111 1.10842 L 0 .741 .179 r
F
.53646 1.05386 m .5462 1.12574 L .54466 1.1288 L F
.53646 1.05386 m .54465 1.10069 L .5462 1.12574 L F
0 g
.54306 1.12174 m
.54497 1.13342 L
s
.54303 1.1216 m
.54457 1.13249 L
s
.53646 1.05386 m .54109 1.07065 L .54465 1.10069 L 0 .741 .179 r
F
0 g
.5333 1.04093 m
.53646 1.05386 L
s
.53996 1.05491 m
.54012 1.05714 L
s
.69276 .67158 m .71358 .66305 L .71661 .65924 L 0 1 .416 r
F
.69276 .67158 m .70338 .66832 L .71358 .66305 L F
0 g
.71358 .66305 m
.71851 .66294 L
s
.78634 .8177 m .80324 .81571 L .79664 .8108 L 0 1 .52 r
F
0 g
.80324 .81571 m
.80495 .82122 L
s
.72041 1.0225 m .72597 .99497 L .72184 1.00272 L 0 1 .303 r
F
0 g
.72597 .99497 m
.73075 1.00205 L
s
.72597 .99497 m
.72657 .97365 L
s
.6191 .64912 m .61385 .64133 L .61211 .64281 L 0 .988 .496 r
F
.6191 .64912 m .62379 .64545 L .61385 .64133 L F
.6191 .64912 m .63531 .65244 L .62379 .64545 L F
.6191 .64912 m .64228 .65875 L .63531 .65244 L F
.6191 .64912 m .64007 .66017 L .64228 .65875 L F
0 g
.63013 .65604 m
.64007 .66017 L
s
.60952 .64489 m
.6191 .64912 L
s
.64007 .66017 m
.64627 .66763 L
s
.7665 .76641 m .78355 .78849 L .78761 .78625 L 0 1 .446 r
F
.7665 .76641 m .7745 .77999 L .78355 .78849 L F
0 g
.78355 .78849 m
.7856 .80079 L
s
.7745 .77999 m
.77746 .79185 L
s
.7745 .77999 m
.78355 .78849 L
s
.37446 .80205 m .37305 .78671 L .36533 .78483 L 0 .651 .427 r
F
0 g
.36239 .78873 m
.36533 .78483 L
s
.37446 .80205 m .38137 .79297 L .37305 .78671 L 0 .651 .427 r
F
.37446 .80205 m .38471 .79943 L .38137 .79297 L F
.37446 .80205 m .38174 .80332 L .38471 .79943 L F
0 g
.36618 .7958 m
.37446 .80205 L
s
.29812 .93003 m .28722 .92514 L .28734 .92657 L 0 .534 .252 r
F
0 g
.28159 .92529 m
.28734 .92657 L
s
.30391 .76212 m
.30473 .76567 L
s
.30473 .76567 m
.30919 .76736 L
s
.54859 1.1166 m
.54963 1.12443 L
s
.54963 1.12443 m
.54965 1.12458 L
s
.54921 1.11319 m
.54968 1.11556 L
s
.68979 .88843 m .70274 .88233 L .70762 .8773 L 0 1 .333 r
F
.68979 .88843 m .69511 .8871 L .70274 .88233 L F
0 g
.70241 .88512 m
.70274 .88233 L
s
.51553 1.04017 m .51469 1.0568 L .51452 1.04597 L 0 .741 .115 r
F
0 g
.51325 1.03544 m
.51452 1.04597 L
s
.51553 1.04017 m .51635 1.06951 L .51469 1.0568 L 0 .741 .115 r
F
.51553 1.04017 m .51839 1.07557 L .51635 1.06951 L F
.51553 1.04017 m .51941 1.06967 L .51839 1.07557 L F
.51553 1.04017 m .51871 1.05582 L .51941 1.06967 L F
.51553 1.04017 m .51705 1.04321 L .51871 1.05582 L F
0 g
.51768 1.03459 m
.51923 1.04678 L
s
.51705 1.04321 m
.51768 1.03459 L
s
.51544 1.03936 m
.51553 1.04017 L
s
.51452 1.04597 m
.51553 1.04017 L
s
.65899 .93916 m
.65923 .93276 L
s
.4397 .61047 m .42815 .60815 L .42956 .6101 L 0 1 .52 r
F
.4397 .61047 m .43658 .60561 L .42815 .60815 L F
0 g
.42943 .61016 m
.42956 .6101 L
s
.42935 .61019 m
.42943 .61016 L
s
.42178 .61501 m
.42907 .61037 L
s
.42907 .61037 m
.42935 .61019 L
s
.43939 .60999 m
.43971 .60999 L
s
.4397 .61047 m .44923 .60417 L .43658 .60561 L 0 1 .52 r
F
.4397 .61047 m .45939 .60454 L .44923 .60417 L F
.4397 .61047 m .46028 .60648 L .45939 .60454 L F
0 g
.45832 .60686 m
.46164 .60687 L
s
.4397 .61047 m .45184 .60902 L .46028 .60648 L 0 1 .52 r
F
0 g
.43796 .61101 m
.4397 .61047 L
s
.42956 .6101 m
.4397 .61047 L
s
.37337 .77263 m
.37771 .77207 L
s
.37771 .77207 m
.38183 .77154 L
s
.37337 .77262 m
.37628 .76934 L
s
.71665 1.1201 m .72703 1.09964 L .72703 1.0924 L 0 1 .156 r
F
.71665 1.1201 m .72391 1.11275 L .72703 1.09964 L F
0 g
.72703 1.09964 m
.73016 1.09856 L
s
.72412 1.11187 m
.72703 1.09964 L
s
.75557 .83981 m .75833 .83194 L .75431 .83515 L 0 1 .5 r
F
.75557 .83981 m .76581 .83218 L .75833 .83194 L F
.45477 .94876 m .44825 .934 L .44709 .93577 L 0 .238 .286 r
F
0 g
.44205 .92953 m
.44709 .93577 L
s
.53177 .61656 m .52311 .6117 L .52294 .61343 L 0 1 .488 r
F
0 g
.51382 .61391 m
.52294 .61343 L
s
.53177 .61656 m .5326 .61229 L .52311 .6117 L 0 1 .488 r
F
.53177 .61656 m .54508 .61481 L .5326 .61229 L F
.53177 .61656 m .55392 .61795 L .54508 .61481 L F
.53177 .61656 m .55321 .61961 L .55392 .61795 L F
.53177 .61656 m .54372 .61901 L .55321 .61961 L F
0 g
.54372 .61901 m
.55216 .62197 L
s
.52268 .61591 m
.53177 .61656 L
s
.52294 .61343 m
.53177 .61656 L
s
.68917 .69682 m
.69451 .70549 L
s
.41899 .77964 m .4092 .77531 L .41139 .77732 L 0 1 .492 r
F
0 g
.40739 .77873 m
.41139 .77732 L
s
.70389 .71315 m .71329 .7248 L .72294 .73223 L 0 1 .462 r
F
0 g
.71329 .7248 m
.71775 .73471 L
s
.38183 .77154 m
.38559 .76893 L
s
.68979 .88843 m .70762 .8773 L .70704 .87341 L 0 1 .333 r
F
0 g
.69511 .8871 m
.70274 .88233 L
s
.70762 .8773 m
.71485 .87359 L
s
.46128 .96265 m .45863 .95268 L .45477 .94876 L 0 .128 .206 r
F
.46128 .96265 m .46326 .96001 L .45863 .95268 L F
.46128 .96265 m .46557 .96587 L .46326 .96001 L F
.46128 .96265 m .46472 .96699 L .46557 .96587 L F
0 g
.46077 .96307 m
.46128 .96265 L
s
.45666 .95533 m
.46128 .96265 L
s
.62567 .84847 m .63234 .8407 L .63931 .82665 L 0 1 .264 r
F
0 g
.63798 .82933 m
.63827 .82876 L
s
.63827 .82876 m
.63913 .82702 L
s
.63913 .82702 m
.63931 .82665 L
s
.63931 .82665 m
.63994 .8263 L
s
.48859 1.00894 m
.4917 1.01262 L
s
.65078 .95554 m
.65554 .9378 L
s
.32146 .76988 m .31293 .76128 L .30919 .76736 L 0 1 .516 r
F
.59074 .63454 m .60222 .6399 L .61211 .64281 L 0 1 .495 r
F
0 g
.60222 .6399 m
.60952 .64489 L
s
.66724 .98552 m
.67127 1.00992 L
s
.50136 .59634 m .49136 .59248 L .49172 .59559 L 0 1 .531 r
F
.50136 .59634 m .50086 .58862 L .49136 .59248 L F
.50136 .59634 m .51388 .58658 L .50086 .58862 L F
.50136 .59634 m .52351 .58734 L .51388 .58658 L F
.50136 .59634 m .52334 .59039 L .52351 .58734 L F
0 g
.52334 .59039 m
.53253 .59155 L
s
.49225 .60027 m
.50136 .59634 L
s
.51385 .59425 m
.52334 .59039 L
s
.29332 .75847 m .28508 .7538 L .28871 .75703 L 0 1 .514 r
F
0 g
.45184 .60902 m
.46162 .60931 L
s
.53163 .92018 m .54171 .94581 L .53882 .93591 L 0 0 .129 r
F
.53163 .92018 m .5405 .94501 L .54171 .94581 L F
0 g
.53155 .91991 m
.53163 .92018 L
s
.52983 .91404 m
.53163 .92018 L
s
.59074 .63454 m .58428 .62778 L .58305 .62935 L 0 1 .495 r
F
.59074 .63454 m .59419 .63068 L .58428 .62778 L F
.59074 .63454 m .60616 .63613 L .59419 .63068 L F
.59074 .63454 m .61385 .64133 L .60616 .63613 L F
.59074 .63454 m .61211 .64281 L .61385 .64133 L F
0 g
.60222 .6399 m
.61211 .64281 L
s
.58122 .63156 m
.59074 .63454 L
s
.61211 .64281 m
.6191 .64912 L
s
.24934 .82927 m .23893 .82435 L .2371 .82801 L 0 1 .494 r
F
0 g
.22983 .82963 m
.2371 .82801 L
s
.70137 .87326 m .71428 .87063 L .71826 .86677 L 0 1 .425 r
F
.70137 .87326 m .70705 .87341 L .71428 .87063 L F
0 g
.71428 .87063 m
.71485 .87359 L
s
.56152 .62375 m .55392 .61795 L .55321 .61961 L 0 1 .49 r
F
0 g
.54372 .61901 m
.55321 .61961 L
s
.56152 .62375 m .56367 .61967 L .55392 .61795 L 0 1 .49 r
F
.56152 .62375 m .57597 .62363 L .56367 .61967 L F
.56152 .62375 m .58428 .62778 L .57597 .62363 L F
0 g
.57786 .62989 m
.58122 .63156 L
s
.56152 .62375 m .58305 .62935 L .58428 .62778 L 0 1 .49 r
F
.56152 .62375 m .5733 .62762 L .58305 .62935 L F
0 g
.58305 .62935 m
.59074 .63454 L
s
.55216 .62197 m
.56152 .62375 L
s
.55321 .61961 m
.56152 .62375 L
s
.5733 .62762 m
.57786 .62989 L
s
.46898 .81004 m .4613 .80236 L .46258 .8049 L 0 .575 .42 r
F
0 g
.45826 .80425 m
.46258 .8049 L
s
.5733 .62762 m
.58305 .62935 L
s
.44825 .934 m .44025 .92107 L .44298 .927 L 0 .313 .336 r
F
0 g
.44205 .92953 m
.44298 .927 L
s
.70389 .71315 m .72294 .73223 L .7264 .7305 L 0 1 .462 r
F
0 g
.72294 .73223 m
.72448 .73676 L
s
.71329 .7248 m
.72294 .73223 L
s
.28722 .92514 m .2763 .92167 L .28072 .92362 L 0 .524 .248 r
F
0 g
.28072 .92362 m
.28159 .92529 L
s
.29332 .75847 m .28431 .75043 L .28508 .7538 L 0 1 .514 r
F
.29332 .75847 m .28694 .74915 L .28431 .75043 L F
.29332 .75847 m .29156 .7506 L .28694 .74915 L F
.29332 .75847 m .29509 .75381 L .29156 .7506 L F
.29332 .75847 m .29585 .75718 L .29509 .75381 L F
0 g
.29332 .75847 m
.29415 .76202 L
s
.28871 .75703 m
.29332 .75847 L
s
.50741 .85965 m .50226 .84876 L .5026 .85146 L 0 .271 .308 r
F
0 g
.5009 .85024 m
.5026 .85146 L
s
.71583 1.13175 m .72391 1.11275 L .71974 1.12304 L 0 0 0 r
F
.71665 1.1201 m .71974 1.12304 L .72391 1.11275 L 0 1 .156 r
F
0 g
.72391 1.11275 m
.72622 1.10731 L
s
.72391 1.11275 m
.72412 1.11187 L
s
.31516 .84457 m .30538 .84281 L .30358 .84235 L 0 0 0 r
F
0 g
.29642 .8434 m
.30358 .84235 L
s
.7665 .76641 m .78761 .78625 L .78447 .77453 L 0 1 .446 r
F
0 g
.78761 .78625 m
.79592 .79503 L
s
.62339 1.05074 m
.62351 1.04809 L
s
.62698 .97385 m
.62698 .97384 L
s
.36533 .78483 m .36593 .77503 L .35782 .77344 L 0 .614 .427 r
F
.36533 .78483 m .37409 .77981 L .36593 .77503 L F
.36533 .78483 m .37682 .78456 L .37409 .77981 L F
.36533 .78483 m .37305 .78671 L .37682 .78456 L F
0 g
.35721 .78007 m
.36533 .78483 L
s
.70137 .87326 m .71826 .86677 L .71679 .86306 L 0 1 .425 r
F
0 g
.70705 .87341 m
.71428 .87063 L
s
.71826 .86677 m
.725 .86461 L
s
.69276 .67158 m .71661 .65924 L .71064 .65843 L 0 1 .416 r
F
0 g
.70338 .66832 m
.71358 .66305 L
s
.70338 .66832 m
.70906 .66892 L
s
.71661 .65924 m
.72634 .65393 L
s
.47028 .60253 m .48268 .59989 L .49172 .59559 L 0 1 .529 r
F
0 g
.48268 .59989 m
.49225 .60027 L
s
.41899 .77964 m .41387 .77425 L .4092 .77531 L 0 1 .492 r
F
.41899 .77964 m .42228 .77485 L .41387 .77425 L F
.41899 .77964 m .42992 .77717 L .42228 .77485 L F
.41899 .77964 m .43167 .77967 L .42992 .77717 L F
.41899 .77964 m .42697 .78073 L .43167 .77967 L F
0 g
.41466 .78022 m
.41899 .77964 L
s
.41139 .77732 m
.41899 .77964 L
s
.47028 .60253 m .45944 .59908 L .46032 .60218 L 0 1 .529 r
F
.47028 .60253 m .46847 .59477 L .45944 .59908 L F
0 g
.45875 .60305 m
.46032 .60218 L
s
.45627 .60443 m
.45875 .60305 L
s
.47028 .60253 m .4814 .59213 L .46847 .59477 L 0 1 .529 r
F
.47028 .60253 m .49136 .59248 L .4814 .59213 L F
.47028 .60253 m .49172 .59559 L .49136 .59248 L F
0 g
.48268 .59989 m
.48853 .5971 L
s
.48853 .5971 m
.49172 .59559 L
s
.46032 .60218 m
.47028 .60253 L
s
.46164 .60687 m
.47028 .60253 L
s
.49172 .59559 m
.50136 .59634 L
s
.5521 .98147 m
.55273 .97639 L
s
.69196 1.18295 m .70223 1.15602 L .7006 1.16778 L 0 .03 .087 r
F
.70389 .71315 m .70223 .70159 L .69914 .7032 L 0 1 .462 r
F
.70389 .71315 m .71189 .70903 L .70223 .70159 L F
.70389 .71315 m .72167 .72056 L .71189 .70903 L F
.70389 .71315 m .7264 .7305 L .72167 .72056 L F
0 g
.69451 .70549 m
.70389 .71315 L
s
.69914 .7032 m
.70389 .71315 L
s
.70288 .98556 m .71568 1.01565 L .7163 .99114 L 0 1 .291 r
F
0 g
.7163 .99114 m
.72184 1.00272 L
s
.44825 .934 m .44173 .91875 L .44025 .92107 L 0 .313 .336 r
F
0 g
.43491 .91511 m
.44025 .92107 L
s
.28654 .73796 m
.28726 .74035 L
s
.28726 .74035 m
.2919 .74119 L
s
.51705 1.04321 m
.51717 1.04408 L
s
.34931 .77263 m
.35437 .77198 L
s
.35437 .77198 m
.35448 .77197 L
s
.35448 .77197 m
.35463 .77195 L
s
.40162 .77424 m
.4092 .77531 L
s
.3047 .7435 m .29605 .73767 L .2919 .74118 L 0 1 .516 r
F
.25974 .83394 m .2558 .82661 L .24934 .82927 L 0 1 .483 r
F
.25974 .83394 m .26367 .8262 L .2558 .82661 L F
.25974 .83394 m .26766 .8283 L .26367 .8262 L F
.25974 .83394 m .26596 .83163 L .26766 .8283 L F
0 g
.25192 .83434 m
.25974 .83394 L
s
.25826 .83691 m
.25974 .83394 L
s
.55078 1.11071 m
.55141 1.11734 L
s
.55059 1.10884 m
.55078 1.11071 L
s
.54956 1.09807 m
.55059 1.10884 L
s
.54943 1.09674 m
.54956 1.09807 L
s
.54937 1.0961 m
.54943 1.09674 L
s
.54897 1.09196 m
.54937 1.0961 L
s
.28722 .92514 m .27631 .92026 L .2763 .92167 L 0 .524 .248 r
F
0 g
.27044 .92056 m
.2763 .92167 L
s
.32146 .76988 m .32145 .75678 L .31293 .76128 L 0 1 .516 r
F
.32146 .76988 m .33025 .75568 L .32145 .75678 L F
.32146 .76988 m .33343 .75872 L .33025 .75568 L F
.32146 .76988 m .32965 .76481 L .33343 .75872 L F
0 g
.31795 .77662 m
.32146 .76988 L
s
.3127 .77097 m
.32146 .76988 L
s
.54493 1.12827 m
.54503 1.12905 L
s
.545 1.12812 m
.54576 1.13284 L
s
.48088 .99761 m .4748 .98628 L .47711 .99041 L 0 0 .099 r
F
0 g
.4769 .99 m
.47711 .99041 L
s
.37057 .61421 m .35735 .6128 L .35972 .61544 L 0 1 .533 r
F
0 g
.35898 .61603 m
.35972 .61544 L
s
.6152 1.37211 m
.61523 1.37338 L
s
.61223 1.3721 m
.61226 1.37507 L
s
.71082 .86199 m .72425 .86111 L .72825 .85744 L 0 1 .46 r
F
.71082 .86199 m .71679 .86306 L .72425 .86111 L F
0 g
.72425 .86111 m
.725 .86461 L
s
.46898 .81004 m .46614 .80336 L .4613 .80236 L 0 .575 .42 r
F
.46898 .81004 m .47389 .80724 L .46614 .80336 L F
.46898 .81004 m .48031 .81239 L .47389 .80724 L F
.46898 .81004 m .48112 .81538 L .48031 .81239 L F
.46898 .81004 m .47626 .81436 L .48112 .81538 L F
0 g
.46449 .80857 m
.46898 .81004 L
s
.46258 .8049 m
.46898 .81004 L
s
.76581 .83218 m .76841 .82412 L .76438 .82721 L 0 1 .509 r
F
.76581 .83218 m .77606 .82482 L .76841 .82412 L F
.73561 .73882 m .74441 .75163 L .75385 .75973 L 0 1 .452 r
F
0 g
.74441 .75163 m
.74817 .76268 L
s
.73561 .73882 m .75385 .75973 L .75764 .75772 L 0 1 .452 r
F
0 g
.75385 .75973 m
.75682 .7716 L
s
.74441 .75163 m
.75385 .75973 L
s
.44173 .91874 m .4336 .90648 L .43622 .91227 L 0 .404 .366 r
F
0 g
.4349 .91511 m
.43622 .91227 L
s
.37057 .61421 m .36501 .60746 L .35735 .6128 L 0 1 .533 r
F
.37057 .61421 m .3776 .60297 L .36501 .60746 L F
.37057 .61421 m .38849 .60174 L .3776 .60297 L F
.37057 .61421 m .39039 .60459 L .38849 .60174 L F
.37057 .61421 m .3827 .60993 L .39039 .60459 L F
0 g
.36326 .61942 m
.37057 .61421 L
s
.35972 .61544 m
.37057 .61421 L
s
.31293 .76128 m .30039 .75874 L .30392 .76212 L 0 1 .52 r
F
.45477 .94876 m .45255 .9374 L .44825 .934 L 0 .238 .286 r
F
.45477 .94876 m .4575 .94466 L .45255 .9374 L F
.45477 .94876 m .45981 .95092 L .4575 .94466 L F
.45477 .94876 m .45863 .95268 L .45981 .95092 L F
0 g
.44982 .94152 m
.45477 .94876 L
s
.45393 .9499 m
.45477 .94876 L
s
.62567 .84847 m .6387 .81329 L .63168 .82107 L 0 1 .264 r
F
0 g
.63645 .84146 m
.63683 .84032 L
s
.63683 .84032 m
.64179 .82527 L
s
.63615 .84236 m
.63645 .84146 L
s
.6387 .81329 m
.63978 .81408 L
s
.6387 .81329 m
.64016 .81072 L
s
.4057 .61116 m .41408 .60007 L .40134 .60387 L 0 1 .531 r
F
.4057 .61116 m .42468 .59947 L .41408 .60007 L F
.4057 .61116 m .42608 .60248 L .42468 .59947 L F
.4057 .61116 m .41794 .60749 L .42608 .60248 L F
0 g
.40554 .61126 m
.4057 .61116 L
s
.40547 .61117 m
.4057 .61116 L
s
.33783 .77283 m
.34614 .77012 L
s
.50741 .85965 m .50693 .85245 L .50226 .84876 L 0 .271 .308 r
F
.50741 .85965 m .51352 .8601 L .50693 .85245 L F
.50741 .85965 m .51836 .86832 L .51352 .8601 L F
.50741 .85965 m .5182 .87161 L .51836 .86832 L F
.50741 .85965 m .5135 .86789 L .5182 .87161 L F
0 g
.50311 .85502 m
.50741 .85965 L
s
.5026 .85146 m
.50741 .85965 L
s
.71082 .86199 m .72825 .85744 L .72657 .85332 L 0 1 .46 r
F
0 g
.72825 .85744 m
.73517 .856 L
s
.63372 .90821 m .63549 .8899 L .63267 .91053 L 0 .717 .051 r
F
.62177 .94812 m .63549 .8899 L .63364 .88446 L 0 1 .171 r
F
.62177 .94812 m .63267 .91053 L .63549 .8899 L F
0 g
.633 .94031 m
.63417 .92505 L
s
.63549 .8899 m
.63629 .88518 L
s
.63539 .8896 m
.63549 .8899 L
s
.70288 .98556 m .71159 1.02514 L .71568 1.01565 L 0 1 .291 r
F
.70288 .98556 m .70609 1.01221 L .71159 1.02514 L F
.69278 1.00669 m .70609 1.01221 L .70288 .98556 L 0 .982 .277 r
F
0 g
.69745 .97084 m
.70288 .98556 L
s
.70288 .98556 m
.70352 .96115 L
s
.45473 .79824 m
.4613 .80236 L
s
.39511 .61194 m
.40438 .6115 L
s
.40569 .61143 m .41402 .60361 L .4013 .60633 L 0 1 .533 r
F
.40569 .61143 m .42463 .60311 L .41402 .60361 L F
.40569 .61143 m .42604 .60516 L .42463 .60311 L F
.40569 .61143 m .41792 .60873 L .42604 .60516 L F
0 g
.40426 .61208 m
.40569 .61143 L
s
.40438 .6115 m
.40569 .61143 L
s
.37055 .61528 m .35731 .61455 L .35969 .61666 L 0 1 .539 r
F
0 g
.35292 .62207 m
.35969 .61666 L
s
.44173 .91874 m .43547 .90388 L .4336 .90648 L 0 .404 .366 r
F
0 g
.42805 .90104 m
.4336 .90648 L
s
.65007 .94849 m
.65007 .95729 L
s
.23893 .82435 m .22651 .82326 L .23075 .82518 L 0 1 .504 r
F
0 g
.22983 .82963 m
.23075 .82518 L
s
.4092 .77531 m
.41387 .77425 L
s
.37055 .61528 m .36495 .61 L .35731 .61455 L 0 1 .539 r
F
.37055 .61528 m .37753 .60603 L .36495 .61 L F
.37055 .61528 m .38843 .60465 L .37753 .60603 L F
.37055 .61528 m .39034 .60678 L .38843 .60465 L F
.37055 .61528 m .38267 .61134 L .39034 .60678 L F
0 g
.36325 .61976 m
.37055 .61528 L
s
.35969 .61666 m
.37055 .61528 L
s
.53335 .58399 m .54629 .58258 L .55651 .57932 L 0 1 .534 r
F
0 g
.54629 .58258 m
.55547 .58374 L
s
.55924 1.12768 m .56736 1.20026 L .56233 1.1479 L 0 0 .125 r
F
.55434 1.06291 m .56127 1.14251 L .55688 1.10355 L 0 .587 .2 r
F
.55434 1.06291 m .56539 1.14755 L .56127 1.14251 L F
.55434 1.06291 m .56644 1.11517 L .56539 1.14755 L F
0 g
.55434 1.06291 m
.55493 1.0724 L
s
.55193 1.05994 m
.55434 1.06291 L
s
.5661 1.06041 m
.56682 1.0648 L
s
.53342 1.05885 m .53467 1.05735 L .53795 1.07847 L 0 .761 .173 r
F
0 g
.5376 1.0507 m
.53937 1.06079 L
s
.53332 1.04122 m
.53467 1.05735 L
s
.49712 .84198 m
.50226 .84876 L
s
.49712 .84197 m
.50041 .84375 L
s
.65237 .75227 m .6506 .74526 L .64807 .75208 L 0 1 .307 r
F
.65237 .75227 m .65901 .73563 L .6506 .74526 L F
.64578 .77094 m .65237 .75227 L .64428 .76291 L 0 1 .293 r
F
.27631 .92026 m .26524 .91676 L .26967 .91873 L 0 .516 .253 r
F
0 g
.26967 .91873 m
.27044 .92056 L
s
.29509 .75381 m
.29585 .75718 L
s
.29585 .75718 m
.30039 .75875 L
s
.72511 1.06466 m .73158 1.03901 L .72741 1.0482 L 0 1 .289 r
F
.72041 1.0225 m .72741 1.0482 L .73158 1.03901 L 0 1 .303 r
F
0 g
.73158 1.03901 m
.733 1.01923 L
s
.73158 1.03901 m
.73554 1.04154 L
s
.63501 .85776 m .63537 .84474 L .63275 .8579 L 0 1 .141 r
F
.62833 .89782 m .63501 .85776 L .62885 .87979 L 0 1 .147 r
F
0 g
.63451 .85779 m
.63501 .85776 L
s
.63414 .88592 m
.63539 .8896 L
s
.63397 .88544 m
.63414 .88592 L
s
.63386 .88512 m
.63397 .88544 L
s
.50118 1.02776 m .49731 1.02622 L .49868 1.02493 L 0 .586 .056 r
F
0 g
.49827 1.02047 m
.49868 1.02493 L
s
.50118 1.02776 m .49813 1.03213 L .49731 1.02622 L 0 .586 .056 r
F
.50118 1.02776 m .50061 1.03873 L .49813 1.03213 L F
.50118 1.02776 m .50312 1.04158 L .50061 1.03873 L F
.50118 1.02776 m .50399 1.03876 L .50312 1.04158 L F
.50118 1.02776 m .50316 1.03284 L .50399 1.03876 L F
0 g
.50316 1.03284 m
.5053 1.03207 L
s
.50073 1.02072 m
.50118 1.02776 L
s
.49868 1.02493 m
.50118 1.02776 L
s
.68917 .69682 m
.69914 .7032 L
s
.65901 .73563 m .65697 .72935 L .65442 .73552 L 0 1 .324 r
F
.65901 .73563 m .66568 .72062 L .65697 .72935 L F
.72031 .85149 m .73425 .85206 L .73825 .84856 L 0 1 .481 r
F
.72031 .85149 m .72657 .85332 L .73425 .85206 L F
0 g
.73425 .85206 m
.73517 .856 L
s
.43547 .90388 m .42702 .89193 L .42965 .89777 L 0 .506 .385 r
F
0 g
.42805 .90104 m
.42965 .89777 L
s
.54509 .9583 m
.54621 .96553 L
s
.54683 .96953 m
.54761 .97455 L
s
.54761 .97455 m
.54765 .97478 L
s
.54765 .97478 m
.54796 .97678 L
s
.54345 .95821 m
.54509 .9583 L
s
.7665 .76641 m .76713 .75261 L .76333 .75467 L 0 1 .446 r
F
.7665 .76641 m .7762 .76113 L .76713 .75261 L F
.7665 .76641 m .78447 .77453 L .7762 .76113 L F
0 g
.78447 .77453 m
.78761 .78625 L
s
.31516 .84457 m .3118 .8441 L .30538 .84281 L 0 0 0 r
F
.31516 .84457 m .31942 .84567 L .3118 .8441 L F
.31516 .84457 m .32314 .84647 L .31942 .84567 L F
.31516 .84457 m .3213 .84599 L .32314 .84647 L F
0 g
.31359 .84364 m
.31516 .84457 L
s
.30758 .84301 m
.31516 .84457 L
s
.3467 .61457 m
.35735 .6128 L
s
.54585 1.14159 m .5451 1.13888 L .54776 1.15593 L 0 0 .102 r
F
0 g
.5451 1.13888 m
.54513 1.13907 L
s
.54503 1.12905 m
.54673 1.14138 L
s
.54578 1.13834 m
.54598 1.13956 L
s
.54559 1.13979 m
.5458 1.14124 L
s
.54523 1.1372 m
.54559 1.13979 L
s
.54506 1.13866 m
.5451 1.13888 L
s
.7264 .7305 m
.728 .73195 L
s
.72862 .73251 m
.7289 .73277 L
s
.72991 .73368 m
.72993 .73369 L
s
.7312 .73484 m
.73161 .73521 L
s
.73031 .73403 m
.7312 .73484 L
s
.72993 .73369 m
.73031 .73403 L
s
.72167 .72056 m
.7264 .7305 L
s
.3047 .7435 m .30518 .73508 L .29605 .73767 L 0 1 .516 r
F
.3047 .7435 m .31446 .73528 L .30518 .73508 L F
.3047 .7435 m .31766 .73814 L .31446 .73528 L F
.3047 .7435 m .31346 .74166 L .31766 .73814 L F
0 g
.30082 .74637 m
.3047 .7435 L
s
.29547 .7433 m
.3047 .7435 L
s
.51932 1.04749 m .51941 1.06967 L .51871 1.05582 L 0 .758 .129 r
F
0 g
.51717 1.04408 m
.51871 1.05582 L
s
.51932 1.04749 m .52145 1.08466 L .51941 1.06967 L 0 .758 .129 r
F
.51932 1.04749 m .52348 1.09073 L .52145 1.08466 L F
.51932 1.04749 m .52408 1.08225 L .52348 1.09073 L F
.51932 1.04749 m .52286 1.06499 L .52408 1.08225 L F
.51932 1.04749 m .52083 1.05014 L .52286 1.06499 L F
0 g
.52195 1.04596 m
.52282 1.05205 L
s
.51923 1.04678 m
.51932 1.04749 L
s
.51871 1.05582 m
.51932 1.04749 L
s
.52083 1.05014 m
.52087 1.0482 L
s
.56676 1.04122 m
.56769 1.05255 L
s
.56769 1.05255 m
.56809 1.0574 L
s
.56528 1.02315 m
.56676 1.04122 L
s
.5633 .99894 m
.56528 1.02315 L
s
.56363 1.029 m
.56366 1.03198 L
s
.56366 1.03215 m
.56369 1.03436 L
s
.5633 .99894 m
.56353 1.01974 L
s
.56353 1.01974 m
.56363 1.029 L
s
.31293 .76128 m .30437 .75306 L .30039 .75874 L 0 1 .52 r
F
0 g
.52614 .90317 m
.52747 .90532 L
s
.52614 .90317 m
.52945 .91102 L
s
.35025 .76379 m .33836 .75749 L .34152 .7607 L 0 .796 .464 r
F
0 g
.33815 .76162 m
.34152 .7607 L
s
.48088 .99761 m .47545 .98734 L .4748 .98628 L 0 0 .099 r
F
0 g
.47081 .97971 m
.4748 .98628 L
s
.67655 1.18657 m .68562 1.1779 L .68153 1.18754 L 0 .227 .11 r
F
.68168 1.21382 m .68562 1.1779 L .69008 1.17593 L 0 .144 .107 r
F
.68168 1.21382 m .68153 1.18754 L .68562 1.1779 L F
0 g
.68562 1.1779 m
.6867 1.16473 L
s
.68562 1.1779 m
.68692 1.17732 L
s
.53335 .58399 m .55651 .57932 L .55721 .57638 L 0 1 .534 r
F
0 g
.55651 .57932 m
.56553 .58096 L
s
.54629 .58258 m
.55651 .57932 L
s
.48088 .99761 m .47865 .99289 L .47545 .98734 L 0 0 .099 r
F
.48088 .99761 m .48244 1.00011 L .47865 .99289 L F
0 g
.48057 .99548 m
.48079 .99697 L
s
.48088 .99761 m .48429 1.00418 L .48244 1.00011 L 0 0 .099 r
F
.48088 .99761 m .48362 1.0031 L .48429 1.00418 L F
.43547 .90388 m .42921 .88892 L .42702 .89193 L 0 .506 .385 r
F
0 g
.42119 .88685 m
.42702 .89193 L
s
.44825 .934 m .44646 .92159 L .44173 .91875 L 0 .313 .336 r
F
0 g
.44025 .92107 m
.44173 .91875 L
s
.44825 .934 m .45174 .9286 L .44646 .92159 L 0 .313 .336 r
F
.44825 .934 m .45405 .93509 L .45174 .9286 L F
.44825 .934 m .45255 .9374 L .45405 .93509 L F
0 g
.44298 .927 m
.44825 .934 L
s
.44709 .93577 m
.44825 .934 L
s
.35782 .77344 m .36723 .76863 L .35877 .76469 L 0 .679 .442 r
F
.35782 .77344 m .36998 .77298 L .36723 .76863 L F
.35782 .77344 m .36593 .77503 L .36998 .77298 L F
0 g
.35448 .77537 m
.35782 .77344 L
s
.35491 .77208 m
.35782 .77344 L
s
.27631 .92026 m .26538 .91527 L .26524 .91676 L 0 .516 .253 r
F
0 g
.25929 .91582 m
.26524 .91676 L
s
.73187 .72859 m
.73198 .72888 L
s
.7328 .73113 m
.73313 .73202 L
s
.7325 .7303 m
.7328 .73113 L
s
.73242 .73008 m
.7325 .7303 L
s
.73561 .73882 m .74452 .73409 L .73506 .72598 L 0 1 .452 r
F
.73561 .73882 m .75365 .74674 L .74452 .73409 L F
.73561 .73882 m .75764 .75772 L .75365 .74674 L F
0 g
.73313 .73202 m
.73561 .73882 L
s
.73161 .73521 m
.73561 .73882 L
s
.75764 .75772 m
.7665 .76641 L
s
.6999 .79498 m .69872 .79829 L .70197 .79001 L 0 .801 .091 r
F
.69283 .81006 m .69366 .81138 L .69143 .81724 L 0 0 .045 r
F
.6846 .8362 m .68606 .83158 L .68582 .83703 L 0 0 .052 r
F
.68606 .83158 m .69283 .81006 L .68988 .82143 L F
.68606 .83158 m .68988 .82143 L .68582 .83703 L F
.69922 .79662 m .69793 .80015 L .6999 .79498 L 0 .801 .091 r
F
.68305 .83538 m .69752 .80113 L .69922 .79662 L F
.69752 .80113 m .69793 .80015 L .69922 .79662 L F
.69793 .80015 m .69872 .79829 L .6999 .79498 L F
.69143 .81724 m .69386 .81171 L .69063 .82132 L 0 0 .045 r
F
.69366 .81138 m .69386 .81171 L .69143 .81724 L F
0 g
.69275 .81046 m
.69283 .81006 L
s
.69214 .81358 m
.69275 .81046 L
s
.68988 .82143 m
.69136 .8157 L
s
.69154 .81503 m
.69268 .81062 L
s
.69268 .81062 m
.69283 .81006 L
s
.28431 .75043 m .27597 .74602 L .27962 .74908 L 0 1 .519 r
F
0 g
.42461 .60718 m
.42817 .60702 L
s
.42106 .60734 m
.42461 .60718 L
s
.56766 .57371 m .58088 .57311 L .59169 .57056 L 0 1 .535 r
F
0 g
.58088 .57311 m
.58986 .57475 L
s
.70549 1.16089 m .70445 1.15984 L .70678 1.15152 L 0 0 0 r
F
0 g
.70223 1.15602 m
.70678 1.15152 L
s
.72511 1.06466 m .72622 1.0774 L .73019 1.0799 L 0 1 .289 r
F
0 g
.73005 1.07981 m
.73011 1.07985 L
s
.73011 1.07985 m
.73019 1.0799 L
s
.72031 .85149 m .73825 .84856 L .73637 .84408 L 0 1 .481 r
F
0 g
.73825 .84856 m
.74536 .84774 L
s
.27553 .73618 m .26705 .7334 L .27073 .7355 L 0 1 .535 r
F
.56766 .57371 m .59169 .57056 L .59291 .56776 L F
0 g
.59169 .57056 m
.60039 .57273 L
s
.58088 .57311 m
.59169 .57056 L
s
.77606 .82482 m .77851 .81657 L .77447 .81956 L 0 1 .515 r
F
.77606 .82482 m .78634 .8177 L .77851 .81657 L F
.23893 .82435 m .22851 .81925 L .22651 .82326 L 0 1 .504 r
F
0 g
.21909 .82507 m
.22651 .82326 L
s
.64578 .77094 m .64428 .76291 L .64176 .77054 L 0 1 .293 r
F
.63775 .79746 m .64578 .77095 L .63757 .78432 L 0 1 .278 r
F
.44326 .78935 m .43428 .78333 L .43602 .7857 L 0 .847 .472 r
F
0 g
.43165 .78628 m
.43602 .7857 L
s
.5462 1.11112 m
.54679 1.11566 L
s
.54896 1.13217 m
.54937 1.13533 L
s
.54937 1.13533 m
.54959 1.13695 L
s
.54857 1.1292 m
.54896 1.13217 L
s
.54705 1.1176 m
.5472 1.11879 L
s
.5472 1.11879 m
.54857 1.1292 L
s
.54679 1.11566 m
.54705 1.1176 L
s
.5462 1.11112 m
.54689 1.11502 L
s
.54689 1.11502 m
.54758 1.11899 L
s
.54758 1.11899 m
.54926 1.1285 L
s
.54926 1.1285 m
.54932 1.12881 L
s
.54932 1.12881 m
.54972 1.13109 L
s
.54972 1.13109 m
.54986 1.13189 L
s
.27553 .73618 m .26639 .73082 L .26705 .7334 L 0 1 .535 r
F
.27553 .73618 m .2692 .72947 L .26639 .73082 L F
0 g
.25808 .73559 m
.26619 .73361 L
s
.26619 .73361 m
.26704 .73341 L
s
.27553 .73618 m .274 .73016 L .2692 .72947 L 0 1 .535 r
F
.27553 .73618 m .27759 .73242 L .274 .73016 L F
.27553 .73618 m .27824 .735 L .27759 .73242 L F
0 g
.27553 .73618 m
.27626 .73858 L
s
.27073 .7355 m
.27553 .73618 L
s
.67894 .68668 m .67595 .67632 L .67327 .6779 L 0 .997 .48 r
F
0 g
.66927 .68013 m
.67894 .68668 L
s
.66568 .72062 m .66338 .71484 L .66081 .72048 L 0 1 .342 r
F
.66568 .72062 m .6724 .70693 L .66338 .71484 L F
.71665 1.1201 m .72703 1.0924 L .72394 1.0955 L 0 1 .156 r
F
0 g
.72703 1.0924 m
.73019 1.0799 L
s
.42921 .88892 m .42065 .87774 L .42316 .88335 L 0 .588 .397 r
F
0 g
.42118 .88685 m
.42316 .88335 L
s
.28431 .75043 m .27527 .74275 L .27597 .74602 L 0 1 .519 r
F
.28431 .75043 m .27799 .74146 L .27527 .74275 L F
.28431 .75043 m .2827 .7428 L .27799 .74146 L F
.28431 .75043 m .28624 .74588 L .2827 .7428 L F
.28431 .75043 m .28694 .74915 L .28624 .74588 L F
0 g
.28431 .75043 m
.28508 .7538 L
s
.27962 .74908 m
.28431 .75043 L
s
.48896 .82897 m .48233 .81971 L .48314 .8225 L 0 .455 .391 r
F
0 g
.48204 .82214 m
.48314 .8225 L
s
.30538 .84281 m .2936 .8397 L .29759 .84093 L 0 .489 .239 r
F
0 g
.29642 .8434 m
.29759 .84093 L
s
.47024 .60781 m .45939 .60454 L .46028 .60648 L 0 1 .512 r
F
.47024 .60781 m .46841 .60297 L .45939 .60454 L F
0 g
.45184 .60902 m
.46028 .60648 L
s
.47024 .60781 m .48134 .60283 L .46841 .60297 L 0 1 .512 r
F
.47024 .60781 m .49132 .60416 L .48134 .60283 L F
.47024 .60781 m .49168 .60608 L .49132 .60416 L F
.47024 .60781 m .48264 .60764 L .49168 .60608 L F
0 g
.46162 .60931 m
.47024 .60781 L
s
.46028 .60648 m
.47024 .60781 L
s
.48264 .60764 m
.49222 .60886 L
s
.35735 .6128 m
.36501 .60746 L
s
.41792 .60873 m
.42815 .60815 L
s
.53342 1.05885 m .53722 1.10855 L .5345 1.08068 L 0 .761 .173 r
F
0 g
.53646 1.05386 m
.53681 1.05962 L
s
.53342 1.05885 m .54055 1.13009 L .53722 1.10855 L 0 .761 .173 r
F
.53342 1.05885 m .54224 1.13066 L .54055 1.13009 L F
.53342 1.05885 m .54111 1.10842 L .54224 1.13066 L F
.53342 1.05885 m .53795 1.07847 L .54111 1.10842 L F
0 g
.54012 1.05714 m
.54109 1.07065 L
s
.53937 1.06079 m
.54109 1.07065 L
s
.5305 1.04461 m
.53342 1.05885 L
s
.29605 .73767 m .28296 .73576 L .28654 .73795 L 0 1 .525 r
F
.29812 .93003 m .29149 .92521 L .28722 .92514 L 0 .534 .252 r
F
.29812 .93003 m .29789 .92669 L .29149 .92521 L F
.29812 .93003 m .30212 .92861 L .29789 .92669 L F
.29812 .93003 m .30221 .93003 L .30212 .92861 L F
0 g
.29176 .92854 m
.29812 .93003 L
s
.34664 .61679 m
.35731 .61455 L
s
.54682 1.13472 m
.54742 1.13919 L
s
.54657 1.1329 m
.54682 1.13472 L
s
.54573 1.12667 m
.54657 1.1329 L
s
.54699 1.13403 m
.54727 1.13574 L
s
.54579 1.12655 m
.54699 1.13403 L
s
.52083 1.05014 m
.52139 1.05422 L
s
.42921 .88892 m .42321 .87459 L .42065 .87774 L 0 .588 .397 r
F
0 g
.41461 .87318 m
.42065 .87774 L
s
.53335 .58399 m .52393 .57973 L .52376 .58277 L 0 1 .534 r
F
.53335 .58399 m .53417 .57647 L .52393 .57973 L F
.53335 .58399 m .54764 .57515 L .53417 .57647 L F
.53335 .58399 m .55721 .57638 L .54764 .57515 L F
0 g
.52351 .58734 m
.53335 .58399 L
s
.38558 .76893 m .37439 .76618 L .37718 .76833 L 0 1 .534 r
F
0 g
.37628 .76934 m
.37718 .76833 L
s
.68277 1.03329 m .68738 .98917 L .68336 .99746 L 0 .943 .263 r
F
.68277 1.03329 m .69278 1.00669 L .68738 .98917 L F
0 g
.68736 .95751 m
.68738 .98917 L
s
.67731 .97141 m
.68336 .99746 L
s
.72982 .84161 m .74427 .84342 L .74828 .84007 L 0 1 .493 r
F
.72982 .84161 m .73637 .84408 L .74427 .84342 L F
0 g
.74427 .84342 m
.74536 .84774 L
s
.26538 .91527 m .25418 .9118 L .25861 .91379 L 0 .516 .268 r
F
0 g
.25861 .91379 m
.25929 .91582 L
s
.44173 .91874 m .44062 .9062 L .43547 .90388 L 0 .404 .366 r
F
.44173 .91874 m .44614 .91268 L .44062 .9062 L F
.44173 .91874 m .44836 .91899 L .44614 .91268 L F
.44173 .91874 m .44646 .92159 L .44836 .91899 L F
0 g
.43622 .91227 m
.44173 .91874 L
s
.57226 1.0411 m
.57475 1.07123 L
s
.56997 1.01332 m
.57226 1.0411 L
s
.5698 1.01122 m
.56997 1.01332 L
s
.57012 1.02882 m
.57086 1.06866 L
s
.56981 1.0122 m
.57012 1.02882 L
s
.57086 1.06866 m
.5709 1.07076 L
s
.5698 1.01122 m
.56981 1.0122 L
s
.44326 .78935 m .43925 .78309 L .43428 .78333 L 0 .847 .472 r
F
.44326 .78935 m .44763 .78516 L .43925 .78309 L F
.44326 .78935 m .45489 .78882 L .44763 .78516 L F
.44326 .78935 m .45618 .79163 L .45489 .78882 L F
.44326 .78935 m .45118 .79185 L .45618 .79163 L F
0 g
.43863 .78917 m
.44326 .78935 L
s
.43602 .7857 m
.44326 .78935 L
s
.24934 .82927 m .24563 .82132 L .23893 .82435 L 0 1 .494 r
F
.24934 .82927 m .25368 .82071 L .24563 .82132 L F
.24934 .82927 m .25768 .82294 L .25368 .82071 L F
.24934 .82927 m .2558 .82661 L .25768 .82294 L F
0 g
.24134 .82986 m
.24934 .82927 L
s
.24769 .83258 m
.24934 .82927 L
s
.62177 .94812 m .63364 .88446 L .62833 .89782 L 0 1 .171 r
F
0 g
.63335 .90903 m
.63372 .90821 L
s
.63268 .91051 m
.63269 .91049 L
s
.63269 .91049 m
.63335 .90903 L
s
.63364 .88446 m
.63386 .88512 L
s
.63364 .88446 m
.63837 .86749 L
s
.63246 .94749 m
.633 .94031 L
s
.63225 .95022 m
.63246 .94749 L
s
.31293 .76128 m .31323 .74884 L .30437 .75306 L 0 1 .52 r
F
.31293 .76128 m .32228 .74799 L .31323 .74884 L F
.31293 .76128 m .32547 .75108 L .32228 .74799 L F
.31293 .76128 m .32145 .75678 L .32547 .75108 L F
0 g
.30919 .76736 m
.31293 .76128 L
s
.30392 .76212 m
.31293 .76128 L
s
.35025 .76379 m .34265 .75514 L .33836 .75749 L 0 .796 .464 r
F
0 g
.32995 .75485 m
.33836 .75749 L
s
.42321 .87459 m .41435 .86368 L .41687 .86931 L 0 .65 .405 r
F
0 g
.41461 .87318 m
.41687 .86931 L
s
.66636 1.20994 m .67655 1.18657 L .67539 1.20259 L 0 .291 .135 r
F
0 g
.3855 .60965 m
.39322 .60888 L
s
.52187 .88836 m .51795 .87597 L .51779 .87848 L 0 .205 .265 r
F
0 g
.51754 .88139 m
.52187 .88836 L
s
.5156 .87612 m
.51779 .87848 L
s
.64434 .97143 m
.64646 .95772 L
s
.61972 .88071 m .63537 .84474 L .63234 .8407 L 0 1 .26 r
F
0 g
.63271 .84119 m
.63316 .84178 L
s
.63316 .84178 m
.63335 .84205 L
s
.61972 .88071 m .63275 .8579 L .63537 .84474 L 0 1 .26 r
F
0 g
.63537 .84474 m
.63615 .84236 L
s
.63276 .8579 m
.63451 .85779 L
s
.63335 .84205 m
.63537 .84474 L
s
.48896 .82897 m .48731 .82162 L .48233 .81971 L 0 .455 .391 r
F
.48896 .82897 m .49477 .82697 L .48731 .82162 L F
.48896 .82897 m .50061 .83346 L .49477 .82697 L F
.48896 .82897 m .50094 .83675 L .50061 .83346 L F
.48896 .82897 m .49594 .83481 L .50094 .83675 L F
0 g
.48434 .82649 m
.48896 .82897 L
s
.48314 .8225 m
.48896 .82897 L
s
.68101 .90128 m .6951 .8871 L .68979 .88843 L 0 1 .21 r
F
0 g
.6951 .8871 m
.69629 .88915 L
s
.35731 .61455 m
.36495 .61 L
s
.67227 .9157 m .68604 .8984 L .68101 .90128 L 0 .845 .141 r
F
0 g
.68604 .8984 m
.69257 .8932 L
s
.68604 .8984 m
.68701 .89941 L
s
.42697 .78073 m
.43428 .78333 L
s
.54595 1.11963 m
.54742 1.13078 L
s
.54595 1.11963 m
.54765 1.12995 L
s
.54765 1.12995 m
.54782 1.13097 L
s
.54782 1.13097 m
.5487 1.13626 L
s
.5487 1.13626 m
.54899 1.13806 L
s
.72982 .84161 m .74828 .84007 L .74619 .83529 L 0 1 .493 r
F
0 g
.74828 .84007 m
.75557 .83981 L
s
.30437 .75306 m .29156 .7506 L .2951 .75381 L 0 1 .522 r
F
.42321 .87459 m .41721 .86029 L .41435 .86368 L 0 .65 .405 r
F
0 g
.40804 .8594 m
.41435 .86368 L
s
.70549 1.16089 m .71583 1.13175 L .71352 1.14002 L 0 0 0 r
F
.65215 .6641 m .66308 .67266 L .67327 .6779 L 0 1 .495 r
F
0 g
.66308 .67266 m
.66927 .68013 L
s
.26538 .91527 m .25445 .91013 L .25418 .9118 L 0 .516 .268 r
F
0 g
.24812 .91102 m
.25418 .9118 L
s
.49209 1.01706 m .48707 1.00888 L .48892 1.01108 L 0 .424 0 r
F
0 g
.48859 1.00894 m
.48892 1.01108 L
s
.47545 .98734 m .46903 .97414 L .47134 .97931 L 0 0 .156 r
F
0 g
.47081 .97971 m
.47134 .97931 L
s
.26639 .73082 m
.26705 .7334 L
s
.38558 .76893 m .37896 .76323 L .37439 .76618 L 0 1 .534 r
F
.38558 .76893 m .38784 .76145 L .37896 .76323 L F
.38558 .76893 m .39628 .76204 L .38784 .76145 L F
.38558 .76893 m .39863 .76462 L .39628 .76204 L F
.38558 .76893 m .39403 .76757 L .39863 .76462 L F
0 g
.37718 .76833 m
.38558 .76893 L
s
.47626 .81436 m
.48233 .81971 L
s
.54585 1.14159 m .55446 1.1958 L .54984 1.1659 L 0 0 .102 r
F
.54585 1.14159 m .54776 1.15593 L .55208 1.18151 L F
0 g
.54984 1.17002 m
.54991 1.17033 L
s
.54941 1.16779 m
.54984 1.17002 L
s
.54939 1.1677 m
.54941 1.16779 L
s
.5508 1.17208 m
.55146 1.17473 L
s
.54513 1.13907 m
.54753 1.15445 L
s
.54576 1.13284 m
.54752 1.14371 L
s
.54689 1.14247 m
.5472 1.14478 L
s
.54673 1.14138 m
.54689 1.14247 L
s
.54417 1.13593 m
.54727 1.15318 L
s
.54598 1.13956 m
.54639 1.14204 L
s
.5458 1.14124 m
.54585 1.14159 L
s
.54902 1.14284 m
.54927 1.1447 L
s
.54742 1.13078 m
.54902 1.14284 L
s
.54585 1.14159 m
.54591 1.14197 L
s
.66357 .93239 m .67699 .91061 L .67227 .9157 L 0 0 0 r
F
0 g
.67699 .91061 m
.68307 .9039 L
s
.67699 .91061 m
.67774 .9101 L
s
.65899 .93916 m
.66447 .92632 L
s
.66799 .92391 m
.66848 .92112 L
s
.52305 1.05366 m .52408 1.08225 L .52286 1.06499 L 0 .768 .143 r
F
0 g
.52139 1.05422 m
.52286 1.06499 L
s
.52305 1.05366 m .52648 1.09957 L .52408 1.08225 L 0 .768 .143 r
F
.52305 1.05366 m .52847 1.10529 L .52648 1.09957 L F
.52305 1.05366 m .52864 1.09376 L .52847 1.10529 L F
.52305 1.05366 m .52691 1.07281 L .52864 1.09376 L F
0 g
.52768 1.04962 m
.52784 1.05326 L
s
.5275 1.04529 m
.52835 1.05003 L
s
.52305 1.05366 m .52452 1.05569 L .52691 1.07281 L 0 .768 .143 r
F
0 g
.52282 1.05205 m
.52305 1.05366 L
s
.52286 1.06499 m
.52305 1.05366 L
s
.52443 1.04977 m
.52452 1.05569 L
s
.52434 1.04348 m
.52648 1.05683 L
s
.68979 .88843 m .70704 .87341 L .70136 .87326 L 0 1 .333 r
F
0 g
.70704 .87341 m
.70762 .8773 L
s
.78634 .8177 m .78863 .80927 L .78458 .81216 L 0 1 .52 r
F
.78634 .8177 m .79664 .8108 L .78863 .80927 L F
.6724 .70693 m .66982 .70148 L .66724 .7067 L 0 1 .362 r
F
.6724 .70693 m .67915 .69431 L .66982 .70148 L F
.43547 .90388 m .43477 .89075 L .42921 .88892 L 0 .506 .385 r
F
0 g
.42702 .89193 m
.42921 .88892 L
s
.43547 .90388 m .44061 .89687 L .43477 .89075 L 0 .506 .385 r
F
.43547 .90388 m .44282 .9032 L .44061 .89687 L F
.43547 .90388 m .44062 .9062 L .44282 .9032 L F
0 g
.42965 .89777 m
.43547 .90388 L
s
.4336 .90648 m
.43547 .90388 L
s
.38267 .61134 m
.3932 .6099 L
s
.53015 1.06004 m .53148 1.06 L .5345 1.08068 L 0 .771 .166 r
F
0 g
.53064 1.04687 m
.53148 1.06 L
s
.41721 .86029 m .40805 .84961 L .41057 .85524 L 0 .696 .412 r
F
0 g
.40804 .8594 m
.41057 .85524 L
s
.72167 .72056 m
.73123 .72756 L
s
.27759 .73242 m
.27824 .735 L
s
.27824 .735 m
.28296 .73576 L
s
.30538 .84281 m .29562 .83928 L .2936 .8397 L 0 .489 .239 r
F
0 g
.28626 .84023 m
.2936 .8397 L
s
.28624 .74588 m
.28694 .74915 L
s
.28694 .74915 m
.29156 .7506 L
s
.49209 1.01706 m .48782 1.01205 L .48707 1.00888 L 0 .424 0 r
F
.49209 1.01706 m .49069 1.01851 L .48782 1.01205 L F
.49209 1.01706 m .49388 1.02452 L .49069 1.01851 L F
.49209 1.01706 m .49525 1.02605 L .49388 1.02452 L F
.49209 1.01706 m .49448 1.02285 L .49525 1.02605 L F
0 g
.4917 1.01262 m
.49209 1.01706 L
s
.48892 1.01108 m
.49209 1.01706 L
s
.36611 .76756 m
.36774 .76564 L
s
.36611 .76756 m
.37439 .76618 L
s
.55011 1.17094 m
.55012 1.17097 L
s
.55104 1.17366 m
.55149 1.17498 L
s
.35021 .76528 m .33819 .76318 L .34137 .76607 L 0 1 .532 r
F
0 g
.34625 .76585 m
.34677 .76558 L
s
.33783 .77283 m
.34137 .76607 L
s
.29605 .73767 m .28738 .7317 L .28296 .73576 L 0 1 .525 r
F
.74452 .73409 m .76333 .75467 L .76713 .75261 L 0 1 .459 r
F
.74452 .73409 m .75365 .74674 L .76333 .75467 L F
0 g
.76333 .75467 m
.7665 .76641 L
s
.75365 .74674 m
.75764 .75772 L
s
.75365 .74674 m
.76333 .75467 L
s
.41721 .86029 m .41121 .84606 L .40805 .84961 L 0 .696 .412 r
F
0 g
.40147 .84547 m
.40805 .84961 L
s
.65215 .6641 m .64783 .65488 L .64561 .65648 L 0 1 .495 r
F
.65215 .6641 m .65804 .66012 L .64783 .65488 L F
.65215 .6641 m .66942 .6687 L .65804 .66012 L F
.65215 .6641 m .67595 .67632 L .66942 .6687 L F
.65215 .6641 m .67327 .6779 L .67595 .67632 L F
0 g
.66308 .67266 m
.67327 .6779 L
s
.64228 .65875 m
.65215 .6641 L
s
.67327 .6779 m
.67894 .68668 L
s
.73936 .83225 m .75431 .83515 L .75833 .83194 L 0 1 .502 r
F
.73936 .83225 m .74619 .83529 L .75431 .83515 L F
0 g
.75431 .83515 m
.75557 .83981 L
s
.43662 .60234 m .42468 .59947 L .42608 .60248 L 0 1 .53 r
F
0 g
.42476 .60329 m
.42608 .60248 L
s
.43662 .60234 m .43351 .59477 L .42468 .59947 L 0 1 .53 r
F
.43662 .60234 m .44669 .59152 L .43351 .59477 L F
.43662 .60234 m .45724 .59138 L .44669 .59152 L F
.43662 .60234 m .45812 .59445 L .45724 .59138 L F
.43662 .60234 m .44928 .59915 L .45812 .59445 L F
0 g
.42817 .60702 m
.43662 .60234 L
s
.42608 .60248 m
.43662 .60234 L
s
.44928 .59915 m
.45944 .59908 L
s
.71665 1.1201 m .71663 1.12621 L .71974 1.12304 L 0 1 .156 r
F
0 g
.71583 1.13175 m
.71974 1.12304 L
s
.56766 .57371 m .55896 .56904 L .55826 .57197 L 0 1 .535 r
F
.56766 .57371 m .5698 .56648 L .55896 .56904 L F
.56766 .57371 m .58354 .56601 L .5698 .56648 L F
.56766 .57371 m .59291 .56776 L .58354 .56601 L F
0 g
.55721 .57638 m
.56766 .57371 L
s
.59291 .56776 m
.60382 .56588 L
s
.72041 1.0225 m .72262 1.04112 L .72741 1.0482 L 0 1 .303 r
F
.71015 1.04761 m .72041 1.0225 L .71568 1.01565 L 0 1 .285 r
F
.71015 1.04761 m .72262 1.04112 L .72041 1.0225 L F
0 g
.72041 1.0225 m
.72184 1.00272 L
s
.52452 1.05569 m
.52481 1.05777 L
s
.52481 1.05777 m
.52539 1.0619 L
s
.68168 1.21382 m .69008 1.17593 L .69196 1.18295 L 0 .144 .107 r
F
0 g
.69008 1.17593 m
.69174 1.16416 L
s
.68692 1.17732 m
.69008 1.17593 L
s
.25445 .91013 m .24311 .90674 L .24754 .90877 L 0 .523 .292 r
F
0 g
.24754 .90877 m
.24812 .91102 L
s
.50086 .58862 m .51388 .58658 L .52376 .58277 L 0 1 .532 r
F
0 g
.51388 .58658 m
.52351 .58734 L
s
.58354 .56601 m
.59291 .56776 L
s
.28722 .92514 m .28076 .92033 L .27631 .92026 L 0 .524 .248 r
F
.28722 .92514 m .28729 .92185 L .28076 .92033 L F
.28722 .92514 m .29153 .9238 L .28729 .92185 L F
.28722 .92514 m .29149 .92521 L .29153 .9238 L F
0 g
.28072 .92362 m
.28722 .92514 L
s
.28722 .92514 m
.28734 .92657 L
s
.53015 1.06004 m .53304 1.10304 L .53081 1.0784 L 0 .771 .166 r
F
.53015 1.06004 m .5361 1.12407 L .53304 1.10304 L F
.53015 1.06004 m .53791 1.12726 L .5361 1.12407 L F
.53015 1.06004 m .53722 1.10855 L .53791 1.12726 L F
.53015 1.06004 m .5345 1.08068 L .53722 1.10855 L F
0 g
.53467 1.05735 m
.53704 1.0726 L
s
.53704 1.0726 m
.53795 1.07847 L
s
.53342 1.05885 m
.5345 1.08068 L
s
.52835 1.05003 m
.53015 1.06004 L
s
.53681 1.05962 m
.53775 1.07513 L
s
.53775 1.07513 m
.53795 1.07847 L
s
.47545 .98734 m .47003 .97424 L .46903 .97414 L 0 0 .156 r
F
0 g
.46472 .96699 m
.46903 .97414 L
s
.30437 .75306 m .29578 .74513 L .29156 .7506 L 0 1 .522 r
F
.70137 .87326 m .71679 .86306 L .71082 .86199 L 0 1 .425 r
F
0 g
.71679 .86306 m
.72425 .86111 L
s
.71679 .86306 m
.71826 .86677 L
s
.53984 .94507 m
.54097 .94972 L
s
.53873 .9405 m
.53984 .94507 L
s
.33691 .84106 m .32885 .84276 L .33273 .83703 L 0 .817 .106 r
F
0 g
.5135 .86789 m
.51641 .87019 L
s
.42921 .88892 m .42917 .87602 L .42321 .87459 L 0 .588 .397 r
F
.42921 .88892 m .43524 .8816 L .42917 .87602 L F
.42921 .88892 m .43736 .88761 L .43524 .8816 L F
.42921 .88892 m .43477 .89075 L .43736 .88761 L F
0 g
.42316 .88335 m
.42921 .88892 L
s
.52187 .88836 m .52265 .88154 L .51795 .87597 L 0 .205 .265 r
F
0 g
.5135 .86789 m
.51795 .87597 L
s
.52187 .88836 m .52876 .89152 L .52265 .88154 L 0 .205 .265 r
F
.52187 .88836 m .53285 .90145 L .52876 .89152 L F
.52187 .88836 m .53219 .90467 L .53285 .90145 L F
.52187 .88836 m .52748 .89905 L .53219 .90467 L F
0 g
.51779 .87848 m
.52187 .88836 L
s
.63775 .79746 m .63757 .78432 L .6345 .79508 L 0 1 .278 r
F
0 g
.63663 .79664 m
.63775 .79746 L
s
.63168 .82107 m .63775 .79746 L .63046 .81028 L 0 1 .27 r
F
.41121 .84606 m .40175 .83556 L .40427 .84117 L 0 .73 .418 r
F
0 g
.40147 .84547 m
.40427 .84117 L
s
.54449 .96247 m
.54517 .96526 L
s
.54345 .95821 m
.54391 .96011 L
s
.27527 .74275 m .26684 .73855 L .2705 .7415 L 0 1 .522 r
F
.52668 1.05807 m .52864 1.09376 L .52691 1.07281 L 0 .772 .156 r
F
.52668 1.05807 m .53139 1.11321 L .52864 1.09376 L F
.52668 1.05807 m .5333 1.11805 L .53139 1.11321 L F
.52668 1.05807 m .53304 1.10304 L .5333 1.11805 L F
.52668 1.05807 m .53081 1.0784 L .53304 1.10304 L F
0 g
.53148 1.06 m
.53252 1.06709 L
s
.53252 1.06709 m
.5345 1.08068 L
s
.52668 1.05807 m .52809 1.05922 L .53081 1.0784 L 0 .772 .156 r
F
0 g
.52784 1.05326 m
.52809 1.05922 L
s
.52648 1.05683 m
.52668 1.05807 L
s
.52539 1.0619 m
.52691 1.07281 L
s
.52668 1.05807 m
.52684 1.06855 L
s
.52684 1.06855 m
.52691 1.07281 L
s
.53015 1.06004 m
.53081 1.0784 L
s
.41386 .77425 m .40254 .76873 L .40541 .77163 L 0 1 .511 r
F
0 g
.40162 .77424 m
.40541 .77163 L
s
.35025 .76379 m .35104 .75865 L .34265 .75514 L 0 .796 .464 r
F
.35104 .75865 m .35109 .75835 L .35089 .75828 L F
.35104 .75865 m .35089 .75828 L .34265 .75514 L F
.34265 .75514 m .34866 .75154 L .34433 .74635 L 0 .919 .485 r
F
.34866 .75154 m .34832 .7508 L .34433 .74635 L F
.34887 .75141 m .35348 .74647 L .34646 .7469 L 0 1 .53 r
F
.34887 .75141 m .34701 .74704 L .34646 .7469 L 0 .919 .485 r
F
.34887 .75141 m .34646 .7469 L .34433 .74635 L F
.34866 .75154 m .34887 .75141 L .34832 .7508 L F
.35089 .75828 m .3496 .75522 L .34265 .75514 L 0 .796 .464 r
F
.35109 .75835 m .3496 .75522 L .35089 .75828 L F
.34933 .75382 m .35158 .75438 L .35627 .74937 L 0 1 .53 r
F
.34887 .75141 m .35627 .74937 L .35348 .74647 L F
.34903 .7518 m .35627 .74937 L .34887 .75141 L F
.34265 .75514 m .34933 .75382 L .34887 .75141 L 0 .919 .485 r
F
.34265 .75514 m .3496 .75522 L .34933 .75382 L F
.34908 .75398 m .34933 .75382 L .34827 .75205 L 0 1 .53 r
F
.34933 .75382 m .35627 .74937 L .34895 .75182 L F
.34933 .75382 m .34895 .75182 L .34827 .75205 L F
.34937 .75403 m .35158 .75438 L .34933 .75382 L F
.35109 .75835 m .36046 .75359 L .35158 .75438 L 0 1 .532 r
F
.35163 .75978 m .36046 .75359 L .35109 .75835 L F
.35025 .76379 m .35266 .76248 L .35109 .75835 L 0 .796 .464 r
F
.35025 .76379 m .35279 .7635 L .35266 .76248 L F
.35279 .7635 m .35294 .7634 L .35266 .76248 L 0 1 .532 r
F
.35294 .7634 m .36325 .75632 L .35266 .76248 L F
.35266 .76248 m .36325 .75632 L .36046 .75359 L F
.35266 .76248 m .36046 .75359 L .35209 .75945 L F
.35294 .7634 m .35885 .76133 L .36325 .75632 L F
.35311 .76395 m .35885 .76133 L .35294 .7634 L F
.35279 .7635 m .35877 .76469 L .3631 .76235 L 0 .796 .464 r
F
.35025 .76379 m .35287 .76407 L .35279 .7635 L F
.35279 .7635 m .35311 .76395 L .35294 .7634 L 0 1 .532 r
F
.35287 .76407 m .35311 .76395 L .35279 .7635 L F
.35287 .76407 m .35877 .76469 L .35279 .7635 L 0 .796 .464 r
F
.35021 .76528 m .35287 .76407 L .35279 .7635 L 0 1 .532 r
F
.35266 .76248 m .36034 .75833 L .3514 .75835 L 0 .796 .464 r
F
.35266 .76248 m .35209 .75945 L .35084 .76033 L 0 1 .532 r
F
.35266 .76248 m .3514 .75835 L .35109 .75835 L 0 .796 .464 r
F
.35119 .75766 m .36034 .75833 L .35156 .75524 L F
.35109 .75835 m .3514 .75835 L .35119 .75766 L F
.3514 .75835 m .36034 .75833 L .35119 .75766 L F
.35279 .7635 m .35285 .7635 L .35266 .76248 L F
.35021 .76528 m .35279 .7635 L .35266 .76248 L 0 1 .532 r
F
.3516 .7637 m .35266 .76248 L .35084 .76033 L F
.35266 .76248 m .3631 .76235 L .36034 .75833 L 0 .796 .464 r
F
.35285 .7635 m .3631 .76235 L .35266 .76248 L F
.35084 .76033 m .35163 .75978 L .35109 .75835 L 0 1 .532 r
F
.35021 .76528 m .3516 .7637 L .35084 .76033 L F
.34937 .75382 m .35156 .75524 L .35619 .75247 L 0 .919 .485 r
F
.34933 .75382 m .34938 .75385 L .34937 .75382 L F
.3496 .75522 m .35158 .75438 L .34908 .75398 L 0 1 .53 r
F
.34938 .75385 m .35156 .75524 L .34937 .75382 L 0 .919 .485 r
F
.3496 .75522 m .35156 .75524 L .34933 .75382 L F
.34887 .75141 m .35619 .75247 L .35342 .74868 L F
.34933 .75382 m .35619 .75247 L .34887 .75141 L F
.34908 .75398 m .34937 .75403 L .34933 .75382 L 0 1 .53 r
F
.34256 .75817 m .3496 .75522 L .34908 .75398 L F
.34256 .75817 m .34887 .75141 L .34431 .74703 L F
.34887 .75141 m .34646 .7469 L .34431 .74703 L F
.34265 .75514 m .335 .74704 L .33042 .74981 L 0 .919 .485 r
F
.34265 .75514 m .34433 .74635 L .335 .74704 L F
.335 .74704 m .34433 .74635 L .34623 .74511 L 0 1 .499 r
F
.34599 .74402 m .34623 .74511 L .34928 .74205 L 0 1 .529 r
F
.34599 .74402 m .34623 .74511 L .34925 .74313 L 0 1 .499 r
F
.335 .74704 m .34623 .74511 L .34599 .74402 L F
.34535 .74441 m .34585 .74549 L .34623 .74511 L 0 1 .529 r
F
.34535 .74441 m .34623 .74511 L .34599 .74402 L F
.3349 .75067 m .34431 .74703 L .34585 .74549 L F
.3349 .75067 m .34585 .74549 L .34535 .74441 L F
.34887 .75141 m .35342 .74868 L .34701 .74704 L 0 .919 .485 r
F
.34827 .75205 m .34903 .7518 L .34887 .75141 L 0 1 .53 r
F
.34256 .75817 m .34908 .75398 L .34827 .75205 L F
.35021 .76528 m .35109 .75835 L .34256 .75817 L 0 1 .532 r
F
.35109 .75835 m .35158 .75438 L .3496 .75522 L F
.35109 .75835 m .3496 .75522 L .34256 .75817 L F
.35109 .75835 m .35156 .75524 L .3496 .75522 L 0 .796 .464 r
F
0 g
.34809 .76491 m
.3492 .76433 L
s
.34152 .7607 m
.3476 .76285 L
s
.52809 1.05922 m
.52856 1.06254 L
s
.52856 1.06254 m
.53081 1.0784 L
s
.73936 .83225 m .75833 .83194 L .75604 .82688 L 0 1 .502 r
F
0 g
.75833 .83194 m
.76581 .83218 L
s
.50133 .60838 m .49132 .60416 L .49168 .60608 L 0 1 .506 r
F
.50133 .60838 m .50083 .60361 L .49132 .60416 L F
0 g
.48264 .60764 m
.49167 .60608 L
s
.49167 .60608 m
.49168 .60608 L
s
.50133 .60838 m .51388 .60481 L .50083 .60361 L 0 1 .506 r
F
.50133 .60838 m .52354 .60712 L .51388 .60481 L F
.50133 .60838 m .52337 .60899 L .52354 .60712 L F
.50133 .60838 m .51385 .60953 L .52337 .60899 L F
0 g
.49222 .60886 m
.50133 .60838 L
s
.49168 .60608 m
.50133 .60838 L
s
.51385 .60953 m
.52311 .6117 L
s
.53823 .93923 m
.53827 .93935 L
s
.53617 .934 m
.53823 .93923 L
s
.46614 .80336 m .4581 .79575 L .45938 .79844 L 0 .71 .449 r
F
0 g
.45473 .79824 m
.45938 .79844 L
s
.41121 .84606 m .40519 .83197 L .40175 .83556 L 0 .73 .418 r
F
0 g
.3949 .83138 m
.40175 .83556 L
s
.55035 1.11378 m
.55068 1.11631 L
s
.55017 1.11246 m
.55035 1.11378 L
s
.54952 1.10751 m
.55017 1.11246 L
s
.54952 1.10745 m
.54952 1.10751 L
s
.25445 .91013 m .24351 .90483 L .24311 .90674 L 0 .523 .292 r
F
0 g
.23694 .90616 m
.24311 .90674 L
s
.50086 .58862 m .49046 .58476 L .49082 .58784 L 0 1 .532 r
F
.50086 .58862 m .50036 .58095 L .49046 .58476 L F
.50086 .58862 m .5139 .57895 L .50036 .58095 L F
.50086 .58862 m .52393 .57973 L .5139 .57895 L F
.50086 .58862 m .52376 .58277 L .52393 .57973 L F
0 g
.52376 .58277 m
.53335 .58399 L
s
.49136 .59248 m
.50086 .58862 L
s
.51388 .58658 m
.52376 .58277 L
s
.48362 1.0031 m
.48707 1.00888 L
s
.27527 .74275 m .2662 .73535 L .26684 .73855 L 0 1 .522 r
F
.27527 .74275 m .26902 .73403 L .2662 .73535 L F
.27527 .74275 m .27381 .73527 L .26902 .73403 L F
.27527 .74275 m .27737 .73825 L .27381 .73527 L F
.27527 .74275 m .27799 .74146 L .27737 .73825 L F
0 g
.27527 .74275 m
.27597 .74602 L
s
.2705 .7415 m
.27527 .74275 L
s
.62379 .64545 m .63531 .65244 L .64561 .65648 L 0 1 .504 r
F
0 g
.63531 .65244 m
.64228 .65875 L
s
.41386 .77425 m .40711 .76658 L .40254 .76873 L 0 1 .511 r
F
.41386 .77425 m .41611 .76661 L .40711 .76658 L F
.41386 .77425 m .42459 .76924 L .41611 .76661 L F
.41386 .77425 m .42689 .7727 L .42459 .76924 L F
.41386 .77425 m .42228 .77484 L .42689 .7727 L F
0 g
.40541 .77163 m
.41386 .77425 L
s
.34265 .75514 m .33042 .74981 L .3336 .75282 L 0 .919 .485 r
F
0 g
.3336 .75282 m
.34265 .75514 L
s
.32273 .74842 m
.33042 .74981 L
s
.32995 .75485 m
.3336 .75282 L
s
.71189 .70903 m .70997 .6973 L .70687 .69906 L 0 1 .469 r
F
.71189 .70903 m .71992 .70457 L .70997 .6973 L F
.71189 .70903 m .73006 .71602 L .71992 .70457 L F
0 g
.70223 .70159 m
.71189 .70903 L
s
.55505 1.08779 m
.55579 1.08757 L
s
.55579 1.08757 m
.55588 1.08755 L
s
.71015 1.04761 m .71568 1.01565 L .71159 1.02514 L 0 1 .285 r
F
0 g
.71568 1.01565 m
.72041 1.0225 L
s
.71568 1.01565 m
.7163 .99114 L
s
.50693 .85245 m .50143 .84147 L .50176 .84447 L 0 .355 .357 r
F
0 g
.50176 .84447 m
.50693 .85245 L
s
.50693 .85245 m
.50693 .85245 L
s
.50226 .84876 m
.50693 .85245 L
s
.50041 .84375 m
.50176 .84447 L
s
.42321 .87459 m .42356 .8614 L .41721 .86029 L 0 .65 .405 r
F
.42321 .87459 m .42993 .86669 L .42356 .8614 L F
.42321 .87459 m .43205 .87263 L .42993 .86669 L F
.42321 .87459 m .42917 .87602 L .43205 .87263 L F
0 g
.41687 .86931 m
.42321 .87459 L
s
.42065 .87774 m
.42321 .87459 L
s
.47545 .98734 m .47368 .97956 L .47003 .97424 L 0 0 .156 r
F
.47545 .98734 m .47782 .98762 L .47368 .97956 L F
.47545 .98734 m .47966 .99302 L .47782 .98762 L F
.47545 .98734 m .47865 .99289 L .47966 .99302 L F
0 g
.4748 .98628 m
.47545 .98734 L
s
.47134 .97931 m
.47545 .98734 L
s
.35021 .76528 m .34256 .75817 L .33819 .76318 L 0 1 .532 r
F
0 g
.34614 .77012 m
.35021 .76528 L
s
.32965 .76481 m
.33819 .76318 L
s
.34137 .76607 m
.35021 .76528 L
s
.71082 .86199 m .72657 .85332 L .72031 .85149 L 0 1 .46 r
F
0 g
.72657 .85332 m
.72825 .85744 L
s
.72657 .85332 m
.73425 .85206 L
s
.40519 .83197 m .39543 .82169 L .39796 .82721 L 0 .754 .425 r
F
0 g
.3949 .83138 m
.39796 .82721 L
s
.71478 1.0931 m .72622 1.0774 L .72511 1.06466 L 0 1 .26 r
F
.71478 1.0931 m .72394 1.0955 L .72622 1.0774 L F
0 g
.72622 1.0774 m
.73005 1.07981 L
s
.55715 1.00245 m
.55787 1.00848 L
s
.55935 1.02098 m
.56053 1.03095 L
s
.55594 .99221 m
.55715 1.00245 L
s
.29605 .73767 m .29688 .72848 L .28738 .7317 L 0 1 .525 r
F
.29605 .73767 m .30644 .72818 L .29688 .72848 L F
.29605 .73767 m .30965 .73101 L .30644 .72818 L F
.29605 .73767 m .30518 .73508 L .30965 .73101 L F
0 g
.2919 .74118 m
.29605 .73767 L
s
.28654 .73795 m
.29605 .73767 L
s
.70575 .77299 m .71443 .75958 L .72338 .74525 L 0 .857 .124 r
F
.23893 .82435 m .23545 .81582 L .22851 .81925 L 0 1 .504 r
F
0 g
.22651 .82326 m
.22851 .81925 L
s
.23893 .82435 m .24369 .81498 L .23545 .81582 L 0 1 .504 r
F
.23893 .82435 m .24769 .81729 L .24369 .81498 L F
.23893 .82435 m .24563 .82132 L .24769 .81729 L F
0 g
.23075 .82518 m
.23893 .82435 L
s
.2371 .82801 m
.23893 .82435 L
s
.47003 .97424 m .46326 .96001 L .46557 .96587 L 0 .135 .218 r
F
0 g
.46472 .96699 m
.46557 .96587 L
s
.74452 .73409 m .76713 .75261 L .7629 .74168 L 0 1 .459 r
F
0 g
.76713 .75261 m
.7762 .76113 L
s
.70575 .77299 m .72671 .73947 L .72247 .74421 L 0 .857 .124 r
F
0 g
.72671 .73947 m
.72775 .73761 L
s
.46847 .59477 m .45724 .59138 L .45812 .59445 L 0 1 .531 r
F
.46847 .59477 m .46666 .58709 L .45724 .59138 L F
0 g
.45648 .59532 m
.45812 .59445 L
s
.46847 .59477 m .48011 .58444 L .46666 .58709 L 0 1 .531 r
F
.46847 .59477 m .49046 .58476 L .48011 .58444 L F
.46847 .59477 m .49082 .58784 L .49046 .58476 L F
.46847 .59477 m .4814 .59213 L .49082 .58784 L F
0 g
.49082 .58784 m
.50086 .58862 L
s
.45944 .59908 m
.46847 .59477 L
s
.45812 .59445 m
.46847 .59477 L
s
.4814 .59213 m
.49136 .59248 L
s
.46614 .80336 m .46329 .79631 L .4581 .79575 L 0 .71 .449 r
F
.46614 .80336 m .47151 .79976 L .46329 .79631 L F
.46614 .80336 m .47829 .80469 L .47151 .79976 L F
.46614 .80336 m .4791 .80781 L .47829 .80469 L F
.46614 .80336 m .47389 .80724 L .4791 .80781 L F
0 g
.4613 .80236 m
.46614 .80336 L
s
.45938 .79844 m
.46614 .80336 L
s
.48743 .58939 m
.49082 .58784 L
s
.4814 .59213 m
.48743 .58939 L
s
.67915 .69431 m .67629 .68907 L .6737 .69393 L 0 1 .381 r
F
.62379 .64545 m .61818 .63731 L .61645 .63897 L 0 1 .504 r
F
.62379 .64545 m .6285 .64135 L .61818 .63731 L F
.62379 .64545 m .6405 .6484 L .6285 .64135 L F
.62379 .64545 m .64783 .65488 L .6405 .6484 L F
.62379 .64545 m .64561 .65648 L .64783 .65488 L F
0 g
.63531 .65244 m
.64561 .65648 L
s
.61385 .64133 m
.62379 .64545 L
s
.64561 .65648 m
.65215 .6641 L
s
.43658 .60561 m .42463 .60311 L .42604 .60516 L 0 1 .527 r
F
.43658 .60561 m .43344 .60048 L .42463 .60311 L F
0 g
.41792 .60873 m
.42604 .60516 L
s
.43658 .60561 m .4466 .59903 L .43344 .60048 L 0 1 .527 r
F
.43658 .60561 m .45716 .59949 L .4466 .59903 L F
0 g
.44928 .59915 m
.45648 .59532 L
s
.43658 .60561 m .45806 .60154 L .45716 .59949 L 0 1 .527 r
F
.43658 .60561 m .44923 .60417 L .45806 .60154 L F
0 g
.42815 .60815 m
.43658 .60561 L
s
.42604 .60516 m
.43658 .60561 L
s
.33691 .84106 m .32745 .84915 L .32885 .84276 L 0 .817 .106 r
F
.33691 .84106 m .32948 .85194 L .32745 .84915 L F
.33691 .84106 m .33368 .85599 L .32948 .85194 L F
.33691 .84106 m .33724 .85861 L .33368 .85599 L F
.33691 .84106 m .33862 .85219 L .33724 .85861 L F
0 g
.33273 .83703 m
.33691 .84106 L
s
.69813 .79138 m .71841 .75442 L .71443 .75958 L 0 .834 .111 r
F
0 g
.71841 .75442 m
.71948 .75219 L
s
.70314 .78678 m
.70413 .78402 L
s
.70716 .77737 m
.70765 .77565 L
s
.74893 .82333 m .76438 .82721 L .76841 .82412 L 0 1 .508 r
F
.74893 .82333 m .75604 .82688 L .76438 .82721 L F
0 g
.76438 .82721 m
.76581 .83218 L
s
.40519 .83197 m .39917 .81817 L .39543 .82169 L 0 .754 .425 r
F
0 g
.38832 .81721 m
.39543 .82169 L
s
.2662 .73535 m
.26684 .73855 L
s
.24351 .90483 m .23202 .9016 L .23646 .90366 L 0 .538 .321 r
F
0 g
.23646 .90366 m
.23694 .90616 L
s
.71343 .7564 m .72247 .74421 L .73171 .73119 L 0 .882 .138 r
F
0 g
.7295 .7343 m
.73171 .73119 L
s
.72261 .74648 m
.72338 .74525 L
s
.72104 .749 m
.72261 .74648 L
s
.71015 1.04761 m .7212 1.0636 L .72262 1.04112 L 0 1 .285 r
F
0 g
.72262 1.04112 m
.72741 1.0482 L
s
.30437 .75306 m .30498 .74103 L .29578 .74513 L 0 1 .522 r
F
.30437 .75306 m .3143 .74027 L .30498 .74103 L F
.30437 .75306 m .31749 .74336 L .3143 .74027 L F
.30437 .75306 m .31323 .74884 L .31749 .74336 L F
0 g
.30039 .75874 m
.30437 .75306 L
s
.2951 .75381 m
.30437 .75306 L
s
.61979 1.16502 m
.62011 1.17936 L
s
.61634 1.01032 m
.61634 1.01033 L
s
.61681 1.03111 m
.61723 1.05026 L
s
.6188 1.30679 m
.6189 1.31864 L
s
.6163 1.01041 m
.6163 1.01043 L
s
.6165 1.03382 m
.61666 1.05369 L
s
.61875 1.30053 m
.6188 1.30679 L
s
.61913 1.34636 m
.61931 1.36741 L
s
.61904 1.33509 m
.61913 1.34636 L
s
.61896 1.32559 m
.61904 1.33509 L
s
.6189 1.31864 m
.61896 1.32559 L
s
.71262 .76538 m
.7143 .76232 L
s
.7143 .76232 m
.7151 .76085 L
s
.56625 1.06435 m
.56682 1.0648 L
s
.55738 1.19505 m
.55793 1.19684 L
s
.55676 1.19304 m
.55738 1.19505 L
s
.55674 1.19298 m
.55676 1.19304 L
s
.5565 1.19219 m
.55674 1.19298 L
s
.55522 1.18899 m
.55549 1.18967 L
s
.55561 1.18996 m
.5565 1.19219 L
s
.61972 .88071 m .63234 .8407 L .62567 .84847 L 0 1 .26 r
F
0 g
.63234 .8407 m
.63798 .82933 L
s
.63234 .8407 m
.63271 .84119 L
s
.45118 .79185 m
.4581 .79575 L
s
.29578 .74513 m .2827 .7428 L .28625 .74588 L 0 1 .524 r
F
.41721 .86029 m .41795 .84696 L .41121 .84606 L 0 .696 .412 r
F
.41721 .86029 m .42462 .85202 L .41795 .84696 L F
.41721 .86029 m .42674 .85785 L .42462 .85202 L F
.41721 .86029 m .42356 .8614 L .42674 .85785 L F
0 g
.41057 .85524 m
.41721 .86029 L
s
.41435 .86368 m
.41721 .86029 L
s
.73504 .72595 m
.73505 .72595 L
s
.73505 .72595 m
.73506 .72593 L
s
.73506 .72598 m
.73574 .72656 L
s
.73505 .72595 m
.73506 .72598 L
s
.73504 .72595 m
.73505 .72595 L
s
.73493 .72573 m
.73504 .72595 L
s
.73006 .71602 m
.73397 .72381 L
s
.73464 .72515 m
.73493 .72573 L
s
.27631 .92026 m .27001 .91524 L .26538 .91527 L 0 .516 .253 r
F
.27631 .92026 m .27668 .91677 L .27001 .91524 L F
.27631 .92026 m .28093 .91883 L .27668 .91677 L F
.27631 .92026 m .28076 .92033 L .28093 .91883 L F
0 g
.26967 .91873 m
.27631 .92026 L
s
.2763 .92167 m
.27631 .92026 L
s
.74452 .73409 m .74375 .7212 L .74027 .72314 L 0 1 .459 r
F
.74452 .73409 m .75345 .72915 L .74375 .7212 L F
.74452 .73409 m .7629 .74168 L .75345 .72915 L F
0 g
.74027 .72314 m
.74452 .73409 L
s
.73574 .72656 m
.74452 .73409 L
s
.7629 .74168 m
.76713 .75261 L
s
.40134 .60387 m .38849 .60174 L .39039 .60459 L 0 1 .532 r
F
0 g
.38915 .60545 m
.39039 .60459 L
s
.40134 .60387 m .39697 .59666 L .38849 .60174 L 0 1 .532 r
F
.40134 .60387 m .4102 .59272 L .39697 .59666 L F
.40134 .60387 m .42118 .59201 L .4102 .59272 L F
.40134 .60387 m .42259 .59498 L .42118 .59201 L F
.40134 .60387 m .41408 .60007 L .42259 .59498 L F
0 g
.39322 .60888 m
.40134 .60387 L
s
.39039 .60459 m
.40134 .60387 L
s
.47003 .97424 m .46461 .95928 L .46326 .96001 L 0 .135 .218 r
F
0 g
.45863 .95268 m
.46326 .96001 L
s
.29562 .83928 m .28362 .83592 L .28761 .83756 L 0 .548 .322 r
F
0 g
.28626 .84023 m
.28761 .83756 L
s
.61972 .88071 m .62605 .87331 L .63275 .8579 L 0 1 .26 r
F
0 g
.62605 .87331 m
.63125 .86134 L
s
.63125 .86134 m
.6314 .86101 L
s
.6314 .86101 m
.63182 .86004 L
s
.63182 .86004 m
.63275 .8579 L
s
.63046 .87405 m
.63501 .85776 L
s
.63042 .87417 m
.63046 .87405 L
s
.63038 .87433 m
.63042 .87417 L
s
.63275 .8579 m
.63276 .8579 L
s
.30538 .84281 m .30234 .83995 L .29562 .83928 L 0 .489 .239 r
F
.30538 .84281 m .31017 .84184 L .30234 .83995 L F
.30538 .84281 m .31387 .84369 L .31017 .84184 L F
.30538 .84281 m .3118 .8441 L .31387 .84369 L F
0 g
.29759 .84093 m
.30538 .84281 L
s
.59419 .63068 m .60616 .63613 L .61645 .63897 L 0 1 .506 r
F
0 g
.60616 .63613 m
.61385 .64133 L
s
.5326 .61229 m .52354 .60712 L .52337 .60899 L 0 1 .504 r
F
0 g
.51385 .60953 m
.52337 .60899 L
s
.5326 .61229 m .53343 .60765 L .52354 .60712 L 0 1 .504 r
F
.5326 .61229 m .54645 .61024 L .53343 .60765 L F
.5326 .61229 m .55568 .61354 L .54645 .61024 L F
.5326 .61229 m .55497 .61535 L .55568 .61354 L F
.5326 .61229 m .54508 .61481 L .55497 .61535 L F
0 g
.54508 .61481 m
.55392 .61795 L
s
.52311 .6117 m
.5326 .61229 L
s
.52337 .60899 m
.5326 .61229 L
s
.69276 .67158 m .71064 .65843 L .69961 .66118 L 0 1 .416 r
F
0 g
.71064 .65843 m
.71661 .65924 L
s
.50693 .85245 m .50648 .84448 L .50143 .84147 L 0 .355 .357 r
F
.50693 .85245 m .51355 .85152 L .50648 .84448 L F
.50693 .85245 m .51875 .85952 L .51355 .85152 L F
.50693 .85245 m .51859 .86314 L .51875 .85952 L F
.50693 .85245 m .51352 .8601 L .51859 .86314 L F
0 g
.50693 .85245 m
.50693 .85245 L
s
.39917 .81817 m .38911 .80826 L .39164 .81357 L 0 .773 .432 r
F
0 g
.38832 .81721 m
.39164 .81357 L
s
.24351 .90483 m .23256 .89942 L .23202 .9016 L 0 .538 .321 r
F
0 g
.22576 .90125 m
.23202 .9016 L
s
.74893 .82333 m .76841 .82412 L .76591 .8188 L 0 1 .508 r
F
0 g
.76841 .82412 m
.77606 .82482 L
s
.44923 .60417 m
.45939 .60454 L
s
.49448 1.02285 m
.49731 1.02622 L
s
.28738 .7317 m .27401 .73016 L .27759 .73241 L 0 1 .529 r
F
.71478 1.0931 m .72511 1.06466 L .7212 1.0636 L 0 1 .26 r
F
0 g
.724 1.09499 m
.72622 1.0774 L
s
.72412 1.09531 m
.72703 1.0924 L
s
.72511 1.06466 m
.72741 1.0482 L
s
.49594 .83481 m
.49983 .83632 L
s
.49594 .83481 m
.50143 .84147 L
s
.5493 1.16641 m
.54968 1.1685 L
s
.54968 1.1685 m
.54989 1.16967 L
s
.54989 1.16967 m
.55006 1.17064 L
s
.55006 1.17064 m
.55068 1.17411 L
s
.5493 1.16641 m
.54999 1.17024 L
s
.69278 1.00669 m .70549 1.0413 L .70609 1.01221 L 0 .982 .277 r
F
0 g
.70609 1.01221 m
.71159 1.02514 L
s
.54746 1.14665 m .54686 1.14492 L .54984 1.1659 L 0 0 .108 r
F
0 g
.54686 1.14492 m
.54697 1.1457 L
s
.54639 1.14204 m
.54686 1.14492 L
s
.54727 1.15318 m
.54776 1.15593 L
s
.54753 1.15445 m
.54776 1.15593 L
s
.68168 1.21382 m .67984 1.20292 L .68153 1.18754 L 0 .144 .107 r
F
0 g
.67655 1.18657 m
.68153 1.18754 L
s
.69056 .81199 m .71016 .77111 L .70644 .77664 L 0 .815 .1 r
F
0 g
.71016 .77111 m
.71128 .76844 L
s
.69647 .8032 m
.69775 .79904 L
s
.72031 .85149 m .73637 .84408 L .72982 .84161 L 0 1 .481 r
F
0 g
.73637 .84408 m
.73825 .84856 L
s
.73637 .84408 m
.74427 .84342 L
s
.59419 .63068 m .58735 .62357 L .58612 .6253 L 0 1 .506 r
F
.59419 .63068 m .59764 .6264 L .58735 .62357 L F
.59419 .63068 m .61013 .63193 L .59764 .6264 L F
.59419 .63068 m .61818 .63731 L .61013 .63193 L F
.59419 .63068 m .61645 .63897 L .61818 .63731 L F
0 g
.60616 .63613 m
.61645 .63897 L
s
.58428 .62778 m
.59419 .63068 L
s
.61645 .63897 m
.62379 .64545 L
s
.73752 .72156 m
.7377 .72135 L
s
.56411 1.07493 m
.56412 1.07494 L
s
.56383 1.07434 m
.56411 1.07493 L
s
.56383 1.07435 m
.56424 1.0767 L
s
.56383 1.07435 m
.56383 1.07435 L
s
.56424 1.0767 m
.5643 1.07708 L
s
.56445 1.08412 m
.56458 1.08612 L
s
.56383 1.07435 m
.56385 1.07464 L
s
.5648 1.08957 m
.56481 1.08967 L
s
.56458 1.08612 m
.5648 1.08957 L
s
.56481 1.08967 m
.56489 1.09093 L
s
.56489 1.09093 m
.56496 1.09206 L
s
.56541 1.099 m
.56633 1.11338 L
s
.56515 1.09494 m
.56541 1.099 L
s
.56496 1.09206 m
.56515 1.09494 L
s
.56642 1.11481 m
.56644 1.11517 L
s
.56633 1.11338 m
.56642 1.11481 L
s
.56468 1.08566 m
.56478 1.08703 L
s
.56383 1.07436 m
.56385 1.07468 L
s
.56478 1.08703 m
.56496 1.08946 L
s
.56496 1.08946 m
.56504 1.09046 L
s
.56504 1.09046 m
.56513 1.09163 L
s
.56513 1.09163 m
.5652 1.09262 L
s
.56556 1.09743 m
.56647 1.10955 L
s
.5652 1.09262 m
.56556 1.09743 L
s
.56647 1.10955 m
.56695 1.11584 L
s
.27737 .73825 m
.27799 .74146 L
s
.27799 .74146 m
.2827 .7428 L
s
.39917 .81817 m .39314 .80492 L .38911 .80826 L 0 .773 .432 r
F
0 g
.38174 .80332 m
.38911 .80826 L
s
.39403 .76757 m
.40254 .76873 L
s
.56367 .61967 m .57597 .62363 L .58612 .6253 L 0 1 .505 r
F
0 g
.57597 .62363 m
.58428 .62778 L
s
.56367 .61967 m .55568 .61354 L .55497 .61535 L 0 1 .505 r
F
0 g
.54508 .61481 m
.55497 .61535 L
s
.56367 .61967 m .56583 .61521 L .55568 .61354 L 0 1 .505 r
F
.56367 .61967 m .57865 .61924 L .56583 .61521 L F
.56367 .61967 m .58735 .62357 L .57865 .61924 L F
.56367 .61967 m .58612 .6253 L .58735 .62357 L F
0 g
.55497 .61535 m
.56367 .61967 L
s
.55392 .61795 m
.56367 .61967 L
s
.58612 .6253 m
.59419 .63068 L
s
.57597 .62363 m
.58612 .6253 L
s
.63046 .76498 m .64807 .75208 L .6506 .74526 L 0 1 .379 r
F
0 g
.64572 .76102 m
.65237 .75227 L
s
.63046 .76498 m .63945 .76052 L .64807 .75208 L 0 1 .379 r
F
0 g
.64807 .75208 m
.65237 .75227 L
s
.63046 .76498 m .6506 .74526 L .64547 .7433 L 0 1 .379 r
F
0 g
.64745 .75269 m
.64807 .75208 L
s
.64453 .76258 m
.64572 .76102 L
s
.6506 .74526 m
.65901 .73563 L
s
.41121 .84606 m .41233 .83279 L .40519 .83197 L 0 .73 .418 r
F
.41121 .84606 m .4193 .83768 L .41233 .83279 L F
.41121 .84606 m .42143 .84337 L .4193 .83768 L F
.41121 .84606 m .41795 .84696 L .42143 .84337 L F
0 g
.40427 .84117 m
.41121 .84606 L
s
.40805 .84961 m
.41121 .84606 L
s
.68594 .68271 m .69658 .69281 L .70687 .69906 L 0 1 .486 r
F
0 g
.69658 .69281 m
.70223 .70159 L
s
.53417 .57647 m .54764 .57515 L .55826 .57197 L 0 1 .535 r
F
0 g
.54764 .57515 m
.55721 .57638 L
s
.46461 .95928 m .4575 .94466 L .45981 .95092 L 0 .24 .288 r
F
0 g
.45863 .95268 m
.45981 .95092 L
s
.69278 1.00669 m .70145 1.05339 L .70549 1.0413 L 0 .982 .277 r
F
.69278 1.00669 m .69599 1.0385 L .70145 1.05339 L F
.68277 1.03329 m .69599 1.0385 L .69278 1.00669 L 0 .943 .263 r
F
0 g
.68738 .98917 m
.69278 1.00669 L
s
.69278 1.00669 m
.69341 .97776 L
s
.62489 .78429 m .64428 .76291 L .63945 .76052 L 0 1 .363 r
F
.62489 .78429 m .64176 .77054 L .64428 .76291 L F
0 g
.63961 .78099 m
.64578 .77095 L
s
.64428 .76291 m
.64453 .76258 L
s
.64258 .76207 m
.64428 .76291 L
s
.68584 .68264 m
.68584 .68265 L
s
.68584 .68264 m
.68584 .68264 L
s
.67595 .67632 m
.68144 .67983 L
s
.6857 .68256 m
.68584 .68264 L
s
.69167 .81779 m .69063 .82132 L .69386 .81171 L 0 .795 .086 r
F
.6846 .8362 m .68554 .83684 L .68344 .84338 L 0 0 .052 r
F
.68344 .84338 m .68582 .83703 L .68264 .84838 L F
.68554 .83684 m .68582 .83703 L .68344 .84338 L F
.67857 .85784 m .68582 .83703 L .68284 .84294 L 0 .795 .084 r
F
.67854 .85801 m .68582 .83703 L .67857 .85784 L F
.6776 .8636 m .67791 .86261 L .6784 .85843 L F
.67791 .86261 m .68582 .83703 L .67854 .85801 L F
.67791 .86261 m .67854 .85801 L .6784 .85843 L F
.67844 .86089 m .68264 .84838 L .68582 .83703 L F
.67999 .85017 m .6898 .82359 L .69167 .81779 L 0 .795 .086 r
F
.67965 .85111 m .67995 .85029 L .67999 .85017 L F
.67995 .85029 m .6898 .82359 L .67999 .85017 L F
.67926 .85235 m .67955 .85155 L .67965 .85111 L F
.67955 .85155 m .6898 .82359 L .67988 .85049 L F
.67955 .85155 m .67988 .85049 L .67965 .85111 L F
.68003 .8492 m .69386 .81171 L .68003 .84919 L F
.67959 .85127 m .69386 .81171 L .68003 .8492 L F
.67993 .84925 m .67959 .85127 L .68003 .84919 L 0 1 .453 r
F
.67535 .85215 m .67959 .85127 L .67993 .84925 L F
.67535 .85215 m .67993 .84925 L .6811 .84243 L F
.67993 .84925 m .68003 .84919 L .6811 .84243 L F
.67704 .85945 m .67821 .85964 L .6784 .85843 L 0 1 .438 r
F
.66759 .86652 m .67555 .8642 L .67704 .85945 L F
.6776 .8636 m .67724 .86541 L .67791 .86261 L 0 .795 .084 r
F
.65811 .88632 m .674 .87812 L .67503 .86886 L 0 1 .418 r
F
.674 .87812 m .67753 .87631 L .67577 .87107 L F
.674 .87812 m .67577 .87107 L .67503 .86886 L F
.674 .87812 m .67342 .8839 L .67753 .87631 L F
.65811 .88632 m .67253 .88404 L .674 .87812 L F
.67253 .88404 m .67342 .8839 L .674 .87812 L F
.65811 .88632 m .66511 .88819 L .67244 .88441 L F
.67253 .88404 m .67244 .88441 L .67342 .8839 L F
.65811 .88632 m .67244 .88441 L .67253 .88404 L F
.67692 .86642 m .67647 .86831 L .67702 .86612 L 0 .795 .084 r
F
.67702 .86612 m .67647 .86831 L .67672 .86749 L F
.67724 .86541 m .67684 .86711 L .68264 .84838 L F
.67835 .86128 m .68264 .84838 L .67844 .86089 L F
.67724 .86541 m .68264 .84838 L .67791 .86261 L F
.68065 .85105 m .69154 .85312 L .69492 .8481 L 0 1 .453 r
F
.67857 .85784 m .68284 .84294 L .67894 .8534 L 0 .795 .084 r
F
.67925 .85239 m .68284 .84294 L .69063 .82132 L 0 .795 .086 r
F
.67535 .85215 m .67894 .8534 L .67925 .85239 L 0 1 .453 r
F
.66759 .86652 m .6784 .85843 L .67535 .85215 L 0 1 .438 r
F
.6784 .85843 m .67857 .85784 L .67844 .85803 L 0 .795 .084 r
F
.6784 .85843 m .67854 .85801 L .67857 .85784 L F
.6784 .85843 m .68316 .85486 L .67894 .8534 L 0 1 .438 r
F
.6784 .85843 m .67894 .8534 L .67535 .85215 L F
.6784 .85843 m .67844 .85803 L .67844 .85803 L 0 .795 .084 r
F
.67561 .86231 m .67894 .8534 L .67925 .85239 L 0 .795 .086 r
F
.67894 .8534 m .68284 .84294 L .67925 .85239 L F
.67959 .85127 m .68055 .85146 L .68065 .85105 L 0 1 .453 r
F
.67947 .8513 m .67958 .85132 L .67959 .85127 L F
.67958 .85132 m .68055 .85146 L .67959 .85127 L F
.68055 .85146 m .69154 .85312 L .68065 .85105 L F
.67715 .86572 m .67672 .86749 L .67684 .86711 L 0 .795 .084 r
F
.67715 .86572 m .67684 .86711 L .67724 .86541 L F
.67702 .86612 m .67672 .86749 L .67715 .86572 L F
.68128 .8484 m .69492 .8481 L .69133 .84204 L 0 1 .453 r
F
.68003 .84919 m .68111 .84911 L .68128 .8484 L F
.68111 .84911 m .69492 .8481 L .68128 .8484 L F
.6776 .8636 m .68313 .8665 L .68649 .86101 L 0 1 .438 r
F
.66759 .86652 m .6769 .8665 L .6776 .8636 L F
.67687 .86657 m .6769 .8665 L .6776 .8636 L 0 .795 .084 r
F
.6769 .8665 m .67724 .86541 L .6776 .8636 L F
.66759 .86652 m .67504 .86886 L .67642 .86845 L 0 1 .438 r
F
.6769 .8665 m .67669 .86736 L .67692 .86642 L 0 .795 .084 r
F
.6764 .86853 m .67647 .86831 L .67692 .86642 L F
.6769 .8665 m .67642 .86845 L .68313 .8665 L 0 1 .438 r
F
.66759 .86652 m .67642 .86845 L .6769 .8665 L F
.6769 .8665 m .68313 .8665 L .6776 .8636 L F
.66826 .89376 m .6764 .86853 L .67669 .86736 L 0 .795 .084 r
F
.66826 .89376 m .67669 .86736 L .6769 .8665 L F
.66826 .89376 m .67513 .87262 L .67638 .86858 L F
.6764 .86853 m .67638 .86858 L .67647 .86831 L F
.66826 .89376 m .67638 .86858 L .6764 .86853 L F
.66826 .89376 m .67687 .86657 L .6776 .8636 L F
.67555 .8642 m .6776 .8636 L .67704 .85945 L 0 1 .438 r
F
.6776 .8636 m .67786 .86352 L .67775 .86298 L F
.6776 .8636 m .67775 .86298 L .67704 .85945 L F
.67791 .86261 m .67835 .86128 L .67844 .86089 L 0 .795 .084 r
F
.67786 .86352 m .68649 .86101 L .67827 .85965 L 0 1 .438 r
F
.67786 .86352 m .67827 .85965 L .67704 .85945 L F
.65811 .88632 m .67503 .86886 L .66759 .86652 L 0 1 .418 r
F
.66826 .89376 m .6784 .85843 L .67561 .86231 L 0 .795 .084 r
F
.6784 .85843 m .67844 .85803 L .67561 .86231 L F
.67857 .85784 m .67894 .8534 L .67561 .86231 L F
.67925 .85239 m .67926 .85235 L .67959 .85127 L 0 .795 .086 r
F
.67911 .85137 m .67932 .85239 L .67947 .8513 L 0 1 .453 r
F
.67535 .85215 m .67902 .85237 L .67911 .85137 L F
.67902 .85237 m .67932 .85239 L .67911 .85137 L F
.67925 .85239 m .67914 .85347 L .67932 .85239 L F
.67894 .8534 m .67914 .85347 L .67925 .85239 L F
.67959 .85127 m .67926 .85235 L .67965 .85111 L 0 .795 .086 r
F
.67932 .85239 m .69154 .85312 L .67947 .8513 L 0 1 .453 r
F
.67561 .86231 m .67925 .85239 L .67959 .85127 L 0 .795 .086 r
F
.6811 .84243 m .69063 .81767 L .68305 .83538 L F
.67561 .86231 m .68004 .84917 L .6811 .84243 L F
.68004 .84917 m .69063 .81767 L .6811 .84243 L F
.67535 .85215 m .6811 .84243 L .67474 .84071 L 0 1 .453 r
F
.6811 .84243 m .68121 .84203 L .68164 .83928 L 0 .795 .086 r
F
.68003 .84919 m .69386 .81171 L .69063 .81767 L F
.68305 .83538 m .70197 .79001 L .6985 .79582 L 0 .801 .091 r
F
.68305 .83538 m .69063 .81767 L .69872 .79829 L F
.68305 .83538 m .6985 .79582 L .69056 .81199 L F
.68305 .83538 m .69056 .81199 L .684 .82769 L F
.68341 .83036 m .684 .82769 L .68349 .82776 L 0 1 .465 r
F
.68267 .83291 m .68349 .82776 L .68228 .82793 L F
.68305 .83538 m .684 .82769 L .68272 .8335 L 0 .801 .091 r
F
.68123 .84197 m .68305 .83538 L .68167 .83921 L 0 .795 .086 r
F
.68272 .8335 m .68349 .82776 L .68267 .83291 L 0 1 .465 r
F
.68315 .83898 m .68342 .82991 L .68272 .8335 L F
.68342 .82991 m .68349 .82776 L .68272 .8335 L F
.68199 .83717 m .68228 .82793 L .67926 .83293 L F
.68267 .83291 m .68228 .82793 L .68199 .83717 L F
.68272 .8335 m .68238 .83158 L .682 .83714 L 0 .801 .091 r
F
.68272 .8335 m .682 .83714 L .68199 .83717 L F
.6811 .84243 m .6816 .83929 L .67474 .84071 L 0 1 .453 r
F
.68199 .83717 m .68238 .83158 L .67948 .8414 L 0 .801 .091 r
F
.68199 .83717 m .682 .83714 L .68199 .83717 L F
.682 .83714 m .68238 .83158 L .68199 .83717 L F
.68305 .83538 m .68272 .8335 L .68199 .83717 L F
.68272 .8335 m .684 .82769 L .68238 .83158 L F
.68315 .83898 m .69098 .82673 L .684 .82769 L 0 1 .465 r
F
.68315 .83898 m .684 .82769 L .68341 .83036 L F
.68121 .84203 m .68123 .84197 L .68166 .83923 L 0 .795 .086 r
F
.68123 .84197 m .68167 .83921 L .68166 .83923 L F
.68121 .84203 m .68166 .83923 L .68164 .83928 L F
.68315 .83898 m .68267 .83291 L .68199 .83717 L 0 1 .465 r
F
.6811 .84243 m .68164 .83928 L .68164 .83929 L 0 .795 .086 r
F
.6811 .84243 m .68164 .83929 L .6816 .83929 L 0 1 .453 r
F
.6811 .84243 m .68164 .83929 L .6816 .83939 L 0 .795 .086 r
F
.6811 .84243 m .68315 .83898 L .68164 .83929 L 0 1 .453 r
F
.6811 .84243 m .68003 .84919 L .68165 .84151 L F
.68107 .84257 m .6811 .84243 L .6816 .83939 L 0 .795 .086 r
F
.67561 .86231 m .68107 .84257 L .67517 .85722 L F
.68107 .84257 m .6816 .83939 L .67517 .85722 L F
.67973 .8506 m .68003 .8492 L .68001 .84925 L F
.67959 .85127 m .68003 .8492 L .67973 .8506 L F
.68165 .84151 m .69133 .84204 L .68315 .83898 L 0 1 .453 r
F
.68003 .84919 m .69133 .84204 L .68165 .84151 L F
.67959 .85127 m .69492 .8481 L .68003 .84919 L F
.68001 .84925 m .68003 .8492 L .68003 .84919 L 0 .795 .086 r
F
.67561 .86231 m .67959 .85127 L .68001 .84925 L F
.67914 .85347 m .67917 .85348 L .67923 .85305 L 0 1 .453 r
F
.67914 .85347 m .67923 .85305 L .67932 .85239 L F
.68345 .83881 m .70338 .83616 L .69953 .83012 L 0 1 .465 r
F
.68315 .83898 m .68341 .83894 L .68345 .83881 L F
.68341 .83894 m .70338 .83616 L .68345 .83881 L F
.68339 .839 m .69133 .84204 L .69999 .84083 L F
.68315 .83898 m .68338 .83906 L .68339 .839 L F
.68338 .83906 m .69133 .84204 L .68339 .839 L F
.68355 .83892 m .69999 .84083 L .70338 .83616 L F
.68315 .83898 m .68353 .83902 L .68355 .83892 L F
.68353 .83902 m .69999 .84083 L .68355 .83892 L F
.68032 .85245 m .68316 .85486 L .69154 .85312 L 0 1 .453 r
F
.67932 .85239 m .6802 .85295 L .68032 .85245 L F
.6802 .85295 m .68316 .85486 L .68032 .85245 L F
.67917 .85348 m .68316 .85486 L .67932 .85239 L F
.66826 .89376 m .6776 .8636 L .6784 .85843 L 0 .795 .084 r
F
.6784 .85843 m .68649 .86101 L .68316 .85486 L 0 1 .438 r
F
.67821 .85964 m .68649 .86101 L .6784 .85843 L F
.6898 .82359 m .69063 .82132 L .69167 .81779 L 0 .795 .086 r
F
0 g
.68582 .83703 m
.68592 .83667 L
s
.68592 .83667 m
.68681 .83325 L
s
.69056 .81199 m .6985 .79582 L .70688 .77836 L 0 .815 .1 r
F
0 g
.70603 .78012 m
.70688 .77836 L
s
.70422 .78389 m
.70603 .78012 L
s
.69386 .81171 m
.69507 .80777 L
s
.69507 .80777 m
.69592 .80501 L
s
.70197 .79001 m
.70314 .78678 L
s
.74082 .71566 m
.74346 .71354 L
s
.53375 .92195 m .53117 .90842 L .53048 .91019 L 0 .125 .211 r
F
0 g
.53048 .91019 m
.53093 .9118 L
s
.52747 .90532 m
.53048 .91019 L
s
.63605 .74752 m .65442 .73552 L .65697 .72935 L 0 1 .395 r
F
.63605 .74752 m .64547 .7433 L .65442 .73552 L F
0 g
.65442 .73552 m
.65901 .73563 L
s
.23256 .89942 m .22093 .89639 L .22537 .89848 L 0 .59 .35 r
F
0 g
.22537 .89848 m
.22576 .90125 L
s
.29578 .74513 m .28717 .73744 L .2827 .7428 L 0 1 .524 r
F
.43925 .78309 m .42992 .77717 L .43167 .77967 L 0 .954 .491 r
F
0 g
.42697 .78073 m
.43167 .77967 L
s
.4013 .60633 m .38843 .60465 L .39034 .60678 L 0 1 .536 r
F
0 g
.38267 .61134 m
.39034 .60678 L
s
.4013 .60633 m .39689 .601 L .38843 .60465 L 0 1 .536 r
F
.4013 .60633 m .41011 .59826 L .39689 .601 L F
.4013 .60633 m .4211 .59781 L .41011 .59826 L F
.4013 .60633 m .42251 .59996 L .4211 .59781 L F
.4013 .60633 m .41402 .60361 L .42251 .59996 L F
0 g
.3932 .6099 m
.4013 .60633 L
s
.39034 .60678 m
.4013 .60633 L
s
.40254 .76873 m
.40711 .76658 L
s
.62489 .78429 m .63346 .77969 L .64176 .77054 L 0 1 .363 r
F
0 g
.64079 .7716 m
.64176 .77054 L
s
.63876 .78238 m
.63961 .78099 L
s
.64176 .77054 m
.64578 .77094 L
s
.42228 .59961 m
.42468 .59947 L
s
.75853 .81479 m .77447 .81956 L .77851 .81657 L 0 1 .513 r
F
.75853 .81479 m .76591 .8188 L .77447 .81956 L F
0 g
.77447 .81956 m
.77606 .82482 L
s
.5556 1.19071 m
.55561 1.19076 L
s
.55522 1.18899 m
.5556 1.19071 L
s
.62177 .94812 m .6268 .93549 L .63267 .91053 L 0 1 .171 r
F
0 g
.63111 .91717 m
.63133 .91622 L
s
.63133 .91622 m
.63196 .91356 L
s
.63196 .91356 m
.63267 .91053 L
s
.63063 .95104 m
.63451 .92256 L
s
.63267 .91053 m
.63268 .91051 L
s
.63114 .92713 m
.63372 .90821 L
s
.6285 .94645 m
.63008 .9349 L
s
.63008 .9349 m
.63014 .93445 L
s
.63019 .93409 m
.63114 .92713 L
s
.63014 .93445 m
.63019 .93409 L
s
.46461 .95928 m .4592 .94321 L .4575 .94466 L 0 .24 .288 r
F
0 g
.45255 .9374 m
.4575 .94466 L
s
.5499 1.11789 m
.55002 1.11914 L
s
.54968 1.11556 m
.5499 1.11789 L
s
.48731 .82162 m .48031 .81239 L .48112 .81538 L 0 .593 .421 r
F
0 g
.47626 .81436 m
.48112 .81538 L
s
.63605 .74752 m .65697 .72935 L .65153 .72766 L 0 1 .395 r
F
0 g
.65697 .72935 m
.66568 .72062 L
s
.29562 .83928 m .28587 .83468 L .28362 .83592 L 0 .548 .322 r
F
0 g
.27611 .83623 m
.28362 .83592 L
s
.50616 1.04077 m .50312 1.04158 L .50399 1.03876 L 0 .648 .065 r
F
0 g
.50316 1.03284 m
.50399 1.03876 L
s
.50616 1.04077 m .50437 1.04931 L .50312 1.04158 L 0 .648 .065 r
F
.50616 1.04077 m .5069 1.05681 L .50437 1.04931 L F
.50616 1.04077 m .50908 1.05882 L .5069 1.05681 L F
.50616 1.04077 m .50943 1.05399 L .50908 1.05882 L F
.50616 1.04077 m .50818 1.04626 L .50943 1.05399 L F
0 g
.5053 1.03207 m
.50616 1.04077 L
s
.50399 1.03876 m
.50616 1.04077 L
s
.50818 1.04626 m
.50996 1.04416 L
s
.53417 .57647 m .55826 .57197 L .55896 .56904 L 0 1 .535 r
F
0 g
.55826 .57197 m
.56766 .57371 L
s
.54764 .57515 m
.55826 .57197 L
s
.37896 .76323 m .36743 .76023 L .37022 .76271 L 0 1 .536 r
F
0 g
.36774 .76564 m
.37022 .76271 L
s
.68594 .68271 m .70687 .69906 L .70997 .6973 L 0 1 .486 r
F
0 g
.70687 .69906 m
.71189 .70903 L
s
.69658 .69281 m
.70687 .69906 L
s
.47003 .97424 m .46872 .96418 L .46461 .95928 L 0 .135 .218 r
F
.47003 .97424 m .4732 .97257 L .46872 .96418 L F
.47003 .97424 m .47504 .97885 L .4732 .97257 L F
.47003 .97424 m .47368 .97956 L .47504 .97885 L F
0 g
.46903 .97414 m
.47003 .97424 L
s
.46557 .96587 m
.47003 .97424 L
s
.2692 .72947 m
.274 .73016 L
s
.39313 .80492 m .38137 .79297 L .38471 .79943 L 0 .797 .441 r
F
0 g
.38174 .80332 m
.38471 .79943 L
s
.34256 .75817 m .33025 .75568 L .33343 .75872 L 0 1 .53 r
F
0 g
.33858 .75737 m
.34265 .75514 L
s
.32965 .76481 m
.33343 .75872 L
s
.23256 .89942 m .2216 .8939 L .22093 .89639 L 0 .59 .35 r
F
0 g
.21457 .89628 m
.22093 .89639 L
s
.40519 .83197 m .4067 .81901 L .39917 .81817 L 0 .754 .425 r
F
.40519 .83197 m .41396 .82377 L .4067 .81901 L F
.40519 .83197 m .4161 .82928 L .41396 .82377 L F
.40519 .83197 m .41233 .83279 L .4161 .82928 L F
0 g
.39796 .82721 m
.40519 .83197 L
s
.40175 .83556 m
.40519 .83197 L
s
.26538 .91527 m .25926 .9099 L .25445 .91013 L 0 .516 .268 r
F
.26538 .91527 m .26607 .91137 L .25926 .9099 L F
.26538 .91527 m .27032 .91357 L .26607 .91137 L F
.26538 .91527 m .27001 .91524 L .27032 .91357 L F
0 g
.25861 .91379 m
.26538 .91527 L
s
.26524 .91676 m
.26538 .91527 L
s
.28738 .7317 m .27869 .72564 L .27401 .73016 L 0 1 .529 r
F
.63168 .82107 m .63046 .81028 L .62814 .81979 L 0 1 .27 r
F
.62567 .84847 m .63168 .82107 L .62467 .83514 L 0 1 .264 r
F
0 g
.63097 .82081 m
.63168 .82107 L
s
.68585 .68257 m
.68585 .68257 L
s
.68584 .68265 m
.68584 .68265 L
s
.68584 .68265 m
.68588 .68262 L
s
.72982 .84161 m .74619 .83529 L .73936 .83225 L 0 1 .493 r
F
0 g
.74619 .83529 m
.74828 .84007 L
s
.74619 .83529 m
.75431 .83515 L
s
.43925 .78309 m .43523 .77653 L .42992 .77717 L 0 .954 .491 r
F
.43925 .78309 m .44407 .77818 L .43523 .77653 L F
.43925 .78309 m .45168 .78161 L .44407 .77818 L F
.43925 .78309 m .45296 .78453 L .45168 .78161 L F
.43925 .78309 m .44763 .78516 L .45296 .78453 L F
0 g
.43428 .78333 m
.43925 .78309 L
s
.43167 .77967 m
.43925 .78309 L
s
.68594 .68271 m .70401 .68843 L .69296 .67836 L 0 1 .486 r
F
.68594 .68271 m .70997 .6973 L .70401 .68843 L F
0 g
.68584 .68265 m
.68594 .68271 L
s
.68585 .68257 m
.68594 .68271 L
s
.4592 .94321 m .45174 .9286 L .45405 .93509 L 0 .31 .33 r
F
0 g
.45255 .9374 m
.45405 .93509 L
s
.3213 .84599 m
.32314 .84647 L
s
.32879 .84267 m
.32885 .84265 L
s
.32693 .8435 m
.32879 .84267 L
s
.3213 .84599 m
.32693 .8435 L
s
.75853 .81479 m .77851 .81657 L .77581 .81101 L 0 1 .513 r
F
0 g
.77851 .81657 m
.78634 .8177 L
s
.71665 1.1201 m .72394 1.0955 L .71979 1.10692 L 0 1 .156 r
F
.71478 1.0931 m .71979 1.10692 L .72394 1.0955 L 0 1 .26 r
F
0 g
.72394 1.0955 m
.72412 1.09531 L
s
.72394 1.0955 m
.724 1.09499 L
s
.56634 1.21497 m
.56651 1.21538 L
s
.56521 1.21209 m
.56634 1.21497 L
s
.56439 1.21388 m
.56521 1.21209 L
s
.56425 1.21417 m
.56439 1.21388 L
s
.64169 .73159 m .66081 .72048 L .66338 .71484 L 0 1 .41 r
F
.64169 .73159 m .65153 .72766 L .66081 .72048 L F
0 g
.66081 .72048 m
.66568 .72062 L
s
.54746 1.14665 m .55639 1.20839 L .55153 1.17372 L 0 0 .108 r
F
0 g
.54752 1.14371 m
.54789 1.14605 L
s
.54591 1.14197 m
.54595 1.14223 L
s
.54746 1.14665 m .54984 1.1659 L .55446 1.1958 L 0 0 .108 r
F
0 g
.55068 1.17411 m
.55128 1.17745 L
s
.54999 1.17024 m
.55017 1.17124 L
s
.55017 1.17124 m
.55045 1.17277 L
s
.55045 1.17277 m
.55051 1.17314 L
s
.5472 1.14478 m
.54746 1.14665 L
s
.54763 1.14778 m
.54824 1.1518 L
s
.54751 1.14698 m
.54763 1.14778 L
s
.54746 1.14665 m
.54751 1.14698 L
s
.48731 .82162 m .48565 .8138 L .48031 .81239 L 0 .593 .421 r
F
.48731 .82162 m .49359 .81866 L .48565 .8138 L F
.48731 .82162 m .4998 .82493 L .49359 .81866 L F
.48731 .82162 m .50012 .82839 L .4998 .82493 L F
.48731 .82162 m .49477 .82697 L .50012 .82839 L F
0 g
.48233 .81971 m
.48731 .82162 L
s
.48112 .81538 m
.48731 .82162 L
s
.61811 .81118 m .63757 .78432 L .63346 .77969 L 0 1 .345 r
F
.61811 .81118 m .6345 .79508 L .63757 .78432 L F
0 g
.63757 .78432 m
.63876 .78238 L
s
.63434 .78068 m
.63757 .78432 L
s
.42228 .77485 m
.42992 .77717 L
s
.69175 .81562 m
.69197 .81448 L
s
.3776 .60297 m
.38849 .60174 L
s
.4592 .94321 m .45378 .92655 L .45174 .9286 L 0 .31 .33 r
F
0 g
.44646 .92159 m
.45174 .9286 L
s
.53417 .57647 m .52436 .57217 L .52419 .57519 L 0 1 .535 r
F
.53417 .57647 m .535 .56898 L .52436 .57217 L F
.53417 .57647 m .54899 .56775 L .535 .56898 L F
.53417 .57647 m .55896 .56904 L .54899 .56775 L F
0 g
.52393 .57973 m
.53417 .57647 L
s
.39313 .80492 m .38518 .7887 L .38137 .79297 L 0 .797 .441 r
F
0 g
.37305 .78671 m
.38137 .79297 L
s
.2216 .8939 m .20983 .89112 L .21427 .89323 L 0 .651 .377 r
F
0 g
.21427 .89323 m
.21457 .89628 L
s
.73807 .72161 m
.74027 .72314 L
s
.7377 .72135 m
.73807 .72161 L
s
.73006 .71602 m
.73643 .72046 L
s
.55128 1.17745 m
.55129 1.17751 L
s
.55129 1.17751 m
.55133 1.17769 L
s
.47389 .80724 m
.48031 .81239 L
s
.38849 .60174 m
.39697 .59666 L
s
.37896 .76323 m .37232 .75682 L .36743 .76023 L 0 1 .536 r
F
0 g
.36211 .76091 m
.36743 .76023 L
s
.37896 .76323 m .38164 .75476 L .37232 .75682 L 0 1 .536 r
F
.37896 .76323 m .39041 .75528 L .38164 .75476 L F
.37896 .76323 m .39276 .75804 L .39041 .75528 L F
.37896 .76323 m .38784 .76145 L .39276 .75804 L F
0 g
.37439 .76618 m
.37896 .76323 L
s
.37022 .76271 m
.37896 .76323 L
s
.48782 1.01205 m .48244 1.00011 L .48429 1.00418 L 0 0 .104 r
F
0 g
.48362 1.0031 m
.48422 1.00407 L
s
.335 .74704 m .32245 .74246 L .32564 .74537 L 0 1 .499 r
F
0 g
.32203 .74801 m
.32564 .74537 L
s
.52265 .88154 m .51836 .86832 L .5182 .87161 L 0 .298 .318 r
F
0 g
.51641 .87019 m
.5182 .87161 L
s
.64169 .73159 m .66338 .71484 L .65762 .71331 L 0 1 .41 r
F
0 g
.66338 .71484 m
.6724 .70693 L
s
.29578 .74513 m .2967 .73335 L .28717 .73744 L 0 1 .524 r
F
.29578 .74513 m .30629 .73258 L .2967 .73335 L F
.29578 .74513 m .30949 .73565 L .30629 .73258 L F
.29578 .74513 m .30498 .74103 L .30949 .73565 L F
0 g
.29156 .7506 m
.29578 .74513 L
s
.28625 .74588 m
.29578 .74513 L
s
.52748 .89905 m
.52987 .9019 L
s
.39917 .81817 m .40105 .80578 L .39314 .80492 L 0 .773 .432 r
F
0 g
.38911 .80826 m
.39314 .80492 L
s
.39917 .81817 m .40861 .8104 L .40105 .80578 L 0 .773 .432 r
F
.39917 .81817 m .41076 .81568 L .40861 .8104 L F
.39917 .81817 m .4067 .81901 L .41076 .81568 L F
0 g
.39164 .81357 m
.39917 .81817 L
s
.39543 .82169 m
.39917 .81817 L
s
.45378 .92654 m .44614 .91268 L .44836 .91899 L 0 .403 .356 r
F
0 g
.44646 .92159 m
.44836 .91899 L
s
.28717 .73744 m .27381 .73527 L .27737 .73825 L 0 1 .525 r
F
0 g
.41402 .60361 m
.42463 .60311 L
s
.53375 .92195 m .53587 .91695 L .53117 .90842 L 0 .125 .211 r
F
0 g
.52748 .89905 m
.53117 .90842 L
s
.53375 .92195 m .54145 .93014 L .53587 .91695 L 0 .125 .211 r
F
.53375 .92195 m .54474 .94198 L .54145 .93014 L F
.53375 .92195 m .54353 .94451 L .54474 .94198 L F
.53375 .92195 m .53882 .93591 L .54353 .94451 L F
0 g
.52945 .91102 m
.53375 .92195 L
s
.53093 .9118 m
.53375 .92195 L
s
.2216 .8939 m .21064 .88832 L .20983 .89112 L 0 .651 .377 r
F
0 g
.20337 .89127 m
.20983 .89112 L
s
.34256 .75817 m .3349 .75067 L .33025 .75568 L 0 1 .53 r
F
0 g
.32145 .75678 m
.33025 .75568 L
s
.76815 .80657 m .78458 .81216 L .78863 .80927 L 0 1 .516 r
F
.76815 .80657 m .77581 .81101 L .78458 .81216 L F
0 g
.78458 .81216 m
.78634 .8177 L
s
.45378 .92654 m .44858 .91033 L .44614 .91268 L 0 .403 .356 r
F
0 g
.44062 .9062 m
.44614 .91268 L
s
.42992 .77717 m
.43523 .77653 L
s
.46461 .95928 m .46377 .94756 L .4592 .94321 L 0 .24 .288 r
F
.46461 .95928 m .46859 .95594 L .46377 .94756 L F
.46461 .95928 m .47043 .96275 L .46859 .95594 L F
.46461 .95928 m .46872 .96418 L .47043 .96275 L F
0 g
.45981 .95092 m
.46461 .95928 L
s
.46326 .96001 m
.46461 .95928 L
s
.68979 .88843 m .6937 .87803 L .68918 .88454 L 0 1 .333 r
F
.68979 .88843 m .70136 .87326 L .6937 .87803 L F
.68101 .90128 m .68979 .88843 L .68322 .89364 L 0 1 .21 r
F
.67294 1.06988 m .67737 1.01188 L .67341 1.02282 L 0 .913 .25 r
F
.67294 1.06988 m .68277 1.03329 L .67737 1.01188 L F
0 g
.67731 .97141 m
.67737 1.01188 L
s
.67127 1.00992 m
.67341 1.02282 L
s
.46841 .60297 m .45716 .59949 L .45806 .60154 L 0 1 .521 r
F
.46841 .60297 m .46658 .59785 L .45716 .59949 L F
0 g
.44923 .60417 m
.45806 .60154 L
s
.46841 .60297 m .48003 .59772 L .46658 .59785 L 0 1 .521 r
F
.46841 .60297 m .49041 .59915 L .48003 .59772 L F
.46841 .60297 m .49077 .60119 L .49041 .59915 L F
.46841 .60297 m .48134 .60283 L .49077 .60119 L F
0 g
.45939 .60454 m
.46841 .60297 L
s
.45806 .60154 m
.46841 .60297 L
s
.48134 .60283 m
.49132 .60416 L
s
.61811 .81118 m .62617 .80658 L .6345 .79508 L 0 1 .345 r
F
0 g
.63286 .79734 m
.6345 .79508 L
s
.63201 .80755 m
.63775 .79746 L
s
.63157 .80833 m
.63201 .80755 L
s
.6345 .79508 m
.63663 .79664 L
s
.34256 .75817 m .34431 .74703 L .3349 .75067 L 0 1 .53 r
F
0 g
.33343 .75872 m
.34256 .75817 L
s
.33819 .76318 m
.34256 .75817 L
s
.69196 1.18295 m .7006 1.16778 L .69647 1.17946 L 0 .03 .087 r
F
.69521 1.19586 m .7006 1.16778 L .70445 1.15984 L 0 0 .051 r
F
.69521 1.19586 m .69647 1.17946 L .7006 1.16778 L F
0 g
.7006 1.16778 m
.70223 1.15602 L
s
.7006 1.16778 m
.70121 1.16652 L
s
.28738 .7317 m .28855 .72186 L .27869 .72564 L 0 1 .529 r
F
.28738 .7317 m .29839 .72113 L .28855 .72186 L F
.28738 .7317 m .30161 .72395 L .29839 .72113 L F
.28738 .7317 m .29688 .72848 L .30161 .72395 L F
0 g
.27759 .73241 m
.28738 .7317 L
s
.28296 .73576 m
.28738 .7317 L
s
.69063 .81767 m
.69291 .81221 L
s
.69587 .80513 m
.69783 .80042 L
s
.69783 .80042 m
.69872 .79829 L
s
.70137 .87326 m .70356 .86477 L .69986 .86955 L 0 1 .425 r
F
.70137 .87326 m .71082 .86199 L .70356 .86477 L F
.65804 .66012 m .66942 .6687 L .67997 .67383 L 0 1 .5 r
F
0 g
.66942 .6687 m
.67595 .67632 L
s
.28587 .83468 m .27364 .83132 L .27763 .83325 L 0 .704 .399 r
F
0 g
.27611 .83623 m
.27763 .83325 L
s
.73936 .83225 m .75604 .82688 L .74893 .82333 L 0 1 .502 r
F
0 g
.75604 .82688 m
.76438 .82721 L
s
.75604 .82688 m
.75833 .83194 L
s
.25445 .91013 m .2485 .90433 L .24351 .90483 L 0 .523 .292 r
F
.25445 .91013 m .25545 .90568 L .2485 .90433 L F
.25445 .91013 m .2597 .90799 L .25545 .90568 L F
.25445 .91013 m .25926 .9099 L .2597 .90799 L F
0 g
.24754 .90877 m
.25445 .91013 L
s
.25418 .9118 m
.25445 .91013 L
s
.43351 .59477 m .42118 .59201 L .42259 .59498 L 0 1 .531 r
F
0 g
.41762 .59795 m
.42259 .59498 L
s
.43351 .59477 m .43039 .58728 L .42118 .59201 L 0 1 .531 r
F
.43351 .59477 m .44408 .58395 L .43039 .58728 L F
.43351 .59477 m .45502 .58374 L .44408 .58395 L F
.43351 .59477 m .45591 .58679 L .45502 .58374 L F
.43351 .59477 m .44669 .59152 L .45591 .58679 L F
0 g
.42468 .59947 m
.43351 .59477 L
s
.42259 .59498 m
.43351 .59477 L
s
.44669 .59152 m
.45724 .59138 L
s
.68101 .90128 m .68322 .89364 L .6798 .89925 L 0 1 .21 r
F
.67227 .9157 m .68101 .90128 L .67468 .90828 L 0 .845 .141 r
F
.44858 .91033 m .44061 .89687 L .44282 .9032 L 0 .502 .373 r
F
0 g
.44062 .9062 m
.44282 .9032 L
s
.26902 .73403 m
.27381 .73527 L
s
.37753 .60603 m
.38843 .60465 L
s
.51352 .8601 m
.51726 .86234 L
s
.64735 .71692 m .66724 .7067 L .66982 .70148 L 0 1 .424 r
F
.64735 .71692 m .65762 .71331 L .66724 .7067 L F
0 g
.66724 .7067 m
.6724 .70693 L
s
.38518 .7887 m .37409 .77981 L .37682 .78456 L 0 .836 .452 r
F
0 g
.37305 .78671 m
.37682 .78456 L
s
.46329 .79631 m .45489 .78882 L .45618 .79163 L 0 .823 .469 r
F
0 g
.45118 .79185 m
.45618 .79163 L
s
.69521 1.19586 m .70445 1.15984 L .70549 1.16089 L 0 0 .051 r
F
0 g
.70445 1.15984 m
.70678 1.15152 L
s
.70121 1.16652 m
.70445 1.15984 L
s
.76815 .80657 m .78863 .80927 L .78574 .80348 L 0 1 .516 r
F
0 g
.78863 .80927 m
.79664 .8108 L
s
.38843 .60465 m
.39689 .601 L
s
.55896 .56904 m
.5698 .56648 L
s
.54899 .56775 m
.55896 .56904 L
s
.44858 .91033 m .44338 .89413 L .44061 .89687 L 0 .502 .373 r
F
0 g
.43477 .89075 m
.44061 .89687 L
s
.70635 1.15418 m .71663 1.12621 L .71665 1.1201 L 0 .962 .123 r
F
.70635 1.15418 m .71352 1.14002 L .71663 1.12621 L F
0 g
.71663 1.12621 m
.71974 1.12304 L
s
.71379 1.13883 m
.71663 1.12621 L
s
.71082 .86199 m .71281 .85343 L .70911 .85786 L 0 1 .46 r
F
.71082 .86199 m .72031 .85149 L .71281 .85343 L F
.39313 .80492 m .39361 .78947 L .38518 .7887 L 0 .797 .441 r
F
0 g
.38137 .79297 m
.38518 .7887 L
s
.39313 .80492 m .40207 .79497 L .39361 .78947 L 0 .797 .441 r
F
.39313 .80492 m .40489 .80152 L .40207 .79497 L F
.39313 .80492 m .40105 .80578 L .40489 .80152 L F
0 g
.38471 .79943 m
.39313 .80492 L
s
.48782 1.01205 m .48356 1.00205 L .48244 1.00011 L 0 0 .104 r
F
0 g
.47865 .99289 m
.48244 1.00011 L
s
.48782 1.01205 m .48691 1.00871 L .48356 1.00205 L 0 0 .104 r
F
.48782 1.01205 m .49046 1.01662 L .48691 1.00871 L F
0 g
.48707 1.00888 m
.48716 1.00928 L
s
.48782 1.01205 m .49183 1.02048 L .49046 1.01662 L 0 0 .104 r
F
.48782 1.01205 m .49069 1.01851 L .49183 1.02048 L F
.50036 .58095 m .5139 .57895 L .52419 .57519 L 0 1 .533 r
F
0 g
.5139 .57895 m
.52393 .57973 L
s
.28717 .73744 m .27852 .72994 L .27381 .73527 L 0 1 .525 r
F
.71992 .70457 m .71773 .6927 L .71462 .69458 L 0 1 .474 r
F
.71992 .70457 m .72796 .69984 L .71773 .6927 L F
.71992 .70457 m .73848 .71122 L .72796 .69984 L F
0 g
.70997 .6973 m
.71992 .70457 L
s
.52265 .88154 m .52342 .87269 L .51836 .86832 L 0 .298 .318 r
F
0 g
.51352 .8601 m
.51836 .86832 L
s
.52265 .88154 m .53003 .88183 L .52342 .87269 L 0 .298 .318 r
F
.52265 .88154 m .53451 .8918 L .53003 .88183 L F
.52265 .88154 m .53384 .89593 L .53451 .8918 L F
.52265 .88154 m .52876 .89152 L .53384 .89593 L F
0 g
.51795 .87597 m
.52265 .88154 L
s
.5182 .87161 m
.52265 .88154 L
s
.50648 .84448 m .50061 .83346 L .50094 .83675 L 0 .492 .388 r
F
0 g
.49983 .83632 m
.50094 .83675 L
s
.29562 .83928 m .29289 .83467 L .28587 .83468 L 0 .548 .322 r
F
.29562 .83928 m .30095 .8364 L .29289 .83467 L F
.29562 .83928 m .30463 .83872 L .30095 .8364 L F
.29562 .83928 m .30234 .83995 L .30463 .83872 L F
0 g
.28761 .83756 m
.29562 .83928 L
s
.2936 .8397 m
.29562 .83928 L
s
.71478 1.0931 m .7212 1.0636 L .71708 1.07495 L 0 1 .26 r
F
.71015 1.04761 m .71708 1.07495 L .7212 1.0636 L 0 1 .285 r
F
0 g
.7212 1.0636 m
.72511 1.06466 L
s
.7212 1.0636 m
.72262 1.04112 L
s
.335 .74704 m .32733 .73924 L .32245 .74246 L 0 1 .499 r
F
0 g
.31597 .74189 m
.32245 .74246 L
s
.74375 .7212 m
.75345 .72915 L
s
.4592 .94321 m .45881 .93031 L .45378 .92655 L 0 .31 .33 r
F
0 g
.45174 .9286 m
.45378 .92655 L
s
.4592 .94321 m .46398 .93844 L .45881 .93031 L 0 .31 .33 r
F
.4592 .94321 m .46582 .94552 L .46398 .93844 L F
.4592 .94321 m .46377 .94756 L .46582 .94552 L F
0 g
.45405 .93509 m
.4592 .94321 L
s
.4575 .94466 m
.4592 .94321 L
s
.31323 .74884 m
.31741 .74346 L
s
.54869 1.14865 m .54825 1.14825 L .55153 1.17372 L 0 0 .115 r
F
0 g
.54825 1.14825 m
.54827 1.14838 L
s
.54827 1.14838 m
.54851 1.15029 L
s
.54851 1.15029 m
.54858 1.15081 L
s
.54858 1.15081 m
.54867 1.15152 L
s
.54789 1.14605 m
.54825 1.14825 L
s
.54595 1.14223 m
.54881 1.15961 L
s
.5499 1.12652 m .55902 1.20689 L .55375 1.15814 L 0 0 .128 r
F
0 g
.54959 1.13695 m
.54973 1.13802 L
s
.5499 1.12652 m .56307 1.24754 L .55902 1.20689 L 0 0 .128 r
F
.5499 1.12652 m .56313 1.25235 L .56307 1.24754 L F
.5499 1.12652 m .55918 1.21981 L .56313 1.25235 L F
0 g
.55578 1.19151 m
.55684 1.19625 L
s
.54824 1.1518 m
.5485 1.15355 L
s
.5606 1.20553 m
.56065 1.20567 L
s
.5499 1.12652 m .55391 1.17221 L .55918 1.21981 L 0 0 .128 r
F
.5499 1.12652 m .54997 1.13248 L .55391 1.17221 L F
0 g
.54965 1.12458 m
.5499 1.12652 L
s
.55141 1.11734 m
.5531 1.13478 L
s
.54986 1.13189 m
.54997 1.13248 L
s
.55068 1.11631 m
.5531 1.13478 L
s
.55002 1.11914 m
.55082 1.12747 L
s
.5499 1.12652 m
.55047 1.1312 L
s
.65804 .66012 m .65339 .65061 L .65117 .65236 L 0 1 .5 r
F
.65804 .66012 m .66395 .65574 L .65339 .65061 L F
.65804 .66012 m .67579 .66435 L .66395 .65574 L F
.65804 .66012 m .68265 .6721 L .67579 .66435 L F
.65804 .66012 m .67997 .67383 L .68265 .6721 L F
0 g
.66942 .6687 m
.67997 .67383 L
s
.64783 .65488 m
.65804 .66012 L
s
.67997 .67383 m
.68261 .67777 L
s
.44338 .89412 m .43524 .8816 L .43736 .88761 L 0 .585 .386 r
F
0 g
.43477 .89075 m
.43736 .88761 L
s
.74103 .71605 m
.74375 .7212 L
s
.74082 .71566 m
.74103 .71605 L
s
.73848 .71122 m
.74082 .71566 L
s
.64735 .71692 m .66982 .70148 L .66375 .70002 L 0 1 .424 r
F
0 g
.66982 .70148 m
.67915 .69431 L
s
.46329 .79631 m .46043 .78898 L .45489 .78882 L 0 .823 .469 r
F
.46329 .79631 m .46912 .792 L .46043 .78898 L F
.46329 .79631 m .47626 .7967 L .46912 .792 L F
.46329 .79631 m .47708 .79993 L .47626 .7967 L F
.46329 .79631 m .47151 .79976 L .47708 .79993 L F
0 g
.4581 .79575 m
.46329 .79631 L
s
.45618 .79163 m
.46329 .79631 L
s
.69276 .67158 m .68934 .66648 L .68827 .66824 L 0 1 .416 r
F
.68825 .66839 m .68827 .66824 L .6882 .66835 L F
.69276 .67158 m .68827 .66824 L .68825 .66839 L F
.66395 .65574 m .67579 .66435 L .68668 .6694 L 0 1 .504 r
F
.66395 .65574 m .68668 .6694 L .6882 .66835 L F
.6882 .66827 m .6882 .66835 L .68827 .66824 L 0 1 .461 r
F
.68823 .66701 m .68827 .66824 L .68934 .66648 L F
.68823 .66701 m .6882 .66835 L .68937 .66754 L 0 1 .504 r
F
.66395 .65574 m .6882 .66835 L .68823 .66701 L F
.66452 .67852 m .68672 .67079 L .6882 .66835 L 0 1 .461 r
F
.66452 .67852 m .6882 .66835 L .6882 .66827 L F
.66452 .67852 m .68827 .66824 L .68823 .66701 L F
.66395 .65574 m .68823 .66701 L .68218 .65967 L 0 1 .504 r
F
.68823 .66701 m .68838 .66708 L .68823 .66691 L F
.66452 .67852 m .68823 .66701 L .68232 .6649 L 0 1 .461 r
F
.68823 .66701 m .68934 .66648 L .68815 .66621 L F
.68823 .66701 m .68822 .6669 L .68218 .65967 L 0 1 .504 r
F
.68838 .66708 m .68843 .66652 L .68218 .65967 L F
.68823 .66701 m .68815 .66621 L .68232 .6649 L 0 1 .461 r
F
.68823 .66701 m .68823 .66691 L .68822 .6669 L 0 1 .504 r
F
.68838 .66708 m .68937 .66754 L .68843 .66652 L F
.69276 .67158 m .6882 .66835 L .68774 .67093 L 0 1 .416 r
F
.69296 .67836 m .68937 .66754 L .6882 .66835 L 0 1 .49 r
F
.68774 .67093 m .6882 .66835 L .68668 .6694 L F
.69296 .67836 m .6882 .66835 L .68774 .67093 L F
.68774 .67093 m .6882 .66835 L .68672 .67079 L 0 1 .416 r
F
.69276 .67158 m .69961 .66118 L .68934 .66648 L F
0 g
.69061 .6713 m
.69276 .67158 L
s
.68394 .67677 m
.68719 .67486 L
s
.68719 .67486 m
.68953 .67348 L
s
.69104 .67259 m
.69276 .67158 L
s
.38518 .7887 m .37866 .77663 L .37409 .77981 L 0 .836 .452 r
F
0 g
.36593 .77503 m
.37409 .77981 L
s
.56062 1.20569 m
.56065 1.20567 L
s
.67227 .9157 m .67468 .90828 L .67127 .9147 L 0 .845 .141 r
F
.66357 .93239 m .67227 .9157 L .66618 .92527 L 0 0 0 r
F
.40711 .76658 m .39628 .76204 L .39863 .76462 L 0 1 .523 r
F
0 g
.39403 .76757 m
.39863 .76462 L
s
.44338 .89412 m .43839 .87875 L .43524 .8816 L 0 .585 .386 r
F
0 g
.42917 .87602 m
.43524 .8816 L
s
.50036 .58095 m .48956 .57709 L .48992 .58016 L 0 1 .533 r
F
.50036 .58095 m .49986 .57332 L .48956 .57709 L F
.50036 .58095 m .51393 .57136 L .49986 .57332 L F
.50036 .58095 m .52436 .57217 L .51393 .57136 L F
.50036 .58095 m .52419 .57519 L .52436 .57217 L F
0 g
.52419 .57519 m
.53417 .57647 L
s
.49046 .58476 m
.50036 .58095 L
s
.5139 .57895 m
.52419 .57519 L
s
.28587 .83468 m .27612 .82939 L .27364 .83132 L 0 .704 .399 r
F
0 g
.26596 .83163 m
.27364 .83132 L
s
.6309 .95514 m
.63124 .96026 L
s
.63124 .96026 m
.63135 .96198 L
s
.63081 .95376 m
.6309 .95514 L
s
.63075 .95283 m
.63081 .95376 L
s
.63063 .95105 m
.63075 .95283 L
s
.72031 .85149 m .7221 .84286 L .71838 .847 L 0 1 .481 r
F
.72031 .85149 m .72982 .84161 L .7221 .84286 L F
.61298 .83461 m .63046 .81028 L .62617 .80659 L 0 1 .328 r
F
.61298 .83461 m .62814 .81979 L .63046 .81028 L F
0 g
.62815 .81979 m
.63097 .82081 L
s
.63046 .81028 m
.63157 .80833 L
s
.44763 .78516 m
.45489 .78882 L
s
.62489 .78429 m .63945 .76052 L .63046 .76498 L 0 1 .363 r
F
0 g
.63346 .77969 m
.64079 .7716 L
s
.63945 .76052 m
.64745 .75269 L
s
.63945 .76052 m
.64258 .76207 L
s
.50648 .84448 m .50602 .83582 L .50061 .83346 L 0 .492 .388 r
F
.50648 .84448 m .51358 .84226 L .50602 .83582 L F
.50648 .84448 m .51914 .85002 L .51358 .84226 L F
.50648 .84448 m .51898 .8539 L .51914 .85002 L F
.50648 .84448 m .51355 .85152 L .51898 .8539 L F
0 g
.50143 .84147 m
.50648 .84448 L
s
.50094 .83675 m
.50648 .84448 L
s
.45378 .92654 m .45405 .91353 L .44858 .91033 L 0 .403 .356 r
F
.45378 .92654 m .4595 .92109 L .45405 .91353 L F
.45378 .92654 m .46127 .92797 L .4595 .92109 L F
.45378 .92654 m .45881 .9303 L .46127 .92797 L F
0 g
.44836 .91899 m
.45378 .92654 L
s
.24351 .90483 m .23774 .89857 L .23256 .89942 L 0 .538 .321 r
F
.24351 .90483 m .24483 .89974 L .23774 .89857 L F
.24351 .90483 m .24908 .90214 L .24483 .89974 L F
.24351 .90483 m .2485 .90433 L .24908 .90214 L F
0 g
.23646 .90366 m
.24351 .90483 L
s
.24311 .90674 m
.24351 .90483 L
s
.46666 .58709 m .45502 .58374 L .45591 .58679 L 0 1 .532 r
F
.46666 .58709 m .46484 .57946 L .45502 .58374 L F
0 g
.45416 .58769 m
.45591 .58679 L
s
.44669 .59152 m
.45416 .58769 L
s
.46666 .58709 m .47881 .57679 L .46484 .57946 L 0 1 .532 r
F
.46666 .58709 m .48956 .57709 L .47881 .57679 L F
.46666 .58709 m .48992 .58016 L .48956 .57709 L F
.46666 .58709 m .48011 .58444 L .48992 .58016 L F
0 g
.48992 .58016 m
.50036 .58095 L
s
.45724 .59138 m
.46666 .58709 L
s
.45591 .58679 m
.46666 .58709 L
s
.48011 .58444 m
.49046 .58476 L
s
.49477 .82697 m
.50061 .83346 L
s
.3349 .75067 m .32228 .74799 L .32547 .75108 L 0 1 .529 r
F
0 g
.32145 .75678 m
.32547 .75108 L
s
.74893 .82333 m .76591 .8188 L .75853 .81479 L 0 1 .508 r
F
0 g
.76591 .8188 m
.77447 .81956 L
s
.76591 .8188 m
.76841 .82412 L
s
.43839 .87875 m .42993 .86669 L .43205 .87263 L 0 .65 .395 r
F
0 g
.42917 .87602 m
.43205 .87263 L
s
.48625 .58176 m
.48992 .58016 L
s
.48011 .58444 m
.48625 .58176 L
s
.63046 .76498 m .64547 .7433 L .63605 .74752 L 0 1 .379 r
F
0 g
.64547 .7433 m
.6506 .74526 L
s
.64547 .7433 m
.65442 .73552 L
s
.49813 1.03213 m .49388 1.02452 L .49525 1.02605 L 0 .446 0 r
F
0 g
.49448 1.02285 m
.49525 1.02605 L
s
.70549 1.16089 m .71352 1.14002 L .70938 1.15238 L 0 0 0 r
F
.70635 1.15418 m .70938 1.15238 L .71352 1.14002 L 0 .962 .123 r
F
0 g
.71352 1.14002 m
.71583 1.13175 L
s
.71352 1.14002 m
.71379 1.13883 L
s
.69063 .81767 m
.69228 .81464 L
s
.335 .74704 m .33706 .73784 L .32733 .73924 L 0 1 .499 r
F
.335 .74704 m .34517 .74036 L .33706 .73784 L F
.34517 .74036 m .34518 .74036 L .34517 .74036 L F
.34517 .74036 m .34517 .74036 L .33706 .73784 L F
.34518 .74036 m .34439 .73914 L .33706 .73784 L F
.32733 .73924 m .33706 .73784 L .34229 .73418 L 0 1 .509 r
F
.32722 .74301 m .33701 .73947 L .34209 .73468 L 0 1 .528 r
F
.34206 .73463 m .34209 .73468 L .34228 .7345 L F
.32722 .74301 m .34209 .73468 L .34206 .73463 L F
.34518 .74036 m .34928 .74205 L .34648 .73905 L 0 1 .529 r
F
.34599 .74402 m .34928 .74205 L .34518 .74036 L F
.34518 .74036 m .34925 .74313 L .34647 .73951 L 0 1 .499 r
F
.335 .74704 m .34599 .74402 L .34518 .74036 L F
.34599 .74402 m .34925 .74313 L .34518 .74036 L F
.3349 .75067 m .34599 .74402 L .34518 .74036 L 0 1 .529 r
F
.3349 .75067 m .34518 .74036 L .33701 .73947 L F
.34518 .74036 m .34648 .73905 L .34439 .73914 L F
.34518 .74036 m .34439 .73914 L .33701 .73947 L F
.34518 .74036 m .34647 .73951 L .34439 .73914 L 0 1 .499 r
F
0 g
.32564 .74537 m
.335 .74704 L
s
.33053 .74974 m
.335 .74704 L
s
.54869 1.14865 m .55784 1.21793 L .55278 1.17834 L 0 0 .115 r
F
.54869 1.14865 m .55153 1.17372 L .55639 1.20839 L F
0 g
.54742 1.13919 m
.54869 1.14865 L
s
.54867 1.15152 m
.5491 1.15489 L
s
.55051 1.17314 m
.55176 1.1801 L
s
.55176 1.1801 m
.55243 1.18384 L
s
.54916 1.15206 m
.54918 1.15216 L
s
.5491 1.15161 m
.54916 1.15206 L
s
.54893 1.15036 m
.5491 1.15161 L
s
.54869 1.14865 m
.54893 1.15036 L
s
.40711 .76658 m .4016 .75984 L .39628 .76204 L 0 1 .523 r
F
.40711 .76658 m .41106 .7595 L .4016 .75984 L F
.40711 .76658 m .41958 .76146 L .41106 .7595 L F
.40711 .76658 m .42146 .76442 L .41958 .76146 L F
.40711 .76658 m .4161 .76661 L .42146 .76442 L F
0 g
.39863 .76462 m
.40711 .76658 L
s
.6285 .64135 m .6405 .6484 L .65117 .65236 L 0 1 .51 r
F
0 g
.6405 .6484 m
.64783 .65488 L
s
.43839 .87875 m .4334 .86361 L .42993 .86669 L 0 .65 .395 r
F
0 g
.42356 .8614 m
.42993 .86669 L
s
.54294 .95783 m .54171 .94581 L .5405 .94501 L 0 0 .142 r
F
0 g
.53827 .93935 m
.5405 .94501 L
s
.55161 1.09567 m .55276 1.08365 L .55688 1.10355 L 0 .738 .197 r
F
0 g
.55505 1.08779 m
.55653 1.10188 L
s
.55048 1.05815 m
.55276 1.08365 L
s
.49813 1.03213 m .49508 1.02905 L .49388 1.02452 L 0 .446 0 r
F
.49813 1.03213 m .49805 1.03665 L .49508 1.02905 L F
.49813 1.03213 m .50095 1.04276 L .49879 1.0382 L F
.49813 1.03213 m .49879 1.0382 L .49806 1.03639 L F
.49509 1.02902 m .49877 1.0363 L .4955 1.02769 L 0 0 .106 r
F
.49508 1.02905 m .49518 1.02925 L .49509 1.02902 L F
.49518 1.02925 m .49877 1.0363 L .49509 1.02902 L F
.49806 1.03639 m .49879 1.0382 L .49805 1.03665 L 0 .446 0 r
F
.49813 1.03213 m .50182 1.04329 L .50095 1.04276 L F
.49813 1.03213 m .50061 1.03873 L .50182 1.04329 L F
0 g
.49731 1.02622 m
.49813 1.03213 L
s
.49525 1.02605 m
.49813 1.03213 L
s
.61811 .81118 m .63346 .77969 L .62489 .78429 L 0 1 .345 r
F
0 g
.63346 .77969 m
.63434 .78068 L
s
.62753 .80776 m
.63046 .81028 L
s
.62678 .80711 m
.62753 .80776 L
s
.62617 .80658 m
.63286 .79734 L
s
.54997 1.13248 m
.55023 1.13512 L
s
.65304 .7033 m .6737 .69393 L .67629 .68907 L 0 1 .438 r
F
.65304 .7033 m .66375 .70002 L .6737 .69393 L F
0 g
.6737 .69393 m
.67915 .69431 L
s
.62833 .89782 m .62885 .87979 L .62627 .89584 L 0 1 .147 r
F
0 g
.62885 .87979 m
.63038 .87433 L
s
.62879 .87965 m
.62885 .87979 L
s
.62605 .87331 m
.62879 .87965 L
s
.50083 .60361 m .49041 .59915 L .49077 .60119 L 0 1 .517 r
F
.50083 .60361 m .50032 .59855 L .49041 .59915 L F
0 g
.48134 .60283 m
.49073 .6012 L
s
.49073 .6012 m
.49077 .60119 L
s
.50083 .60361 m .51391 .59978 L .50032 .59855 L 0 1 .517 r
F
.50083 .60361 m .52397 .60221 L .51391 .59978 L F
.50083 .60361 m .5238 .60421 L .52397 .60221 L F
.50083 .60361 m .51388 .60481 L .5238 .60421 L F
0 g
.49132 .60416 m
.50083 .60361 L
s
.49077 .60119 m
.50083 .60361 L
s
.51388 .60481 m
.52354 .60712 L
s
.28717 .73744 m .28841 .7258 L .27852 .72994 L 0 1 .525 r
F
0 g
.27401 .73016 m
.27869 .72564 L
s
.27381 .73527 m
.27852 .72994 L
s
.28717 .73744 m .29826 .72497 L .28841 .7258 L 0 1 .525 r
F
.28717 .73744 m .30147 .72801 L .29826 .72497 L F
.28717 .73744 m .2967 .73335 L .30147 .72801 L F
0 g
.2827 .7428 m
.28717 .73744 L
s
.27737 .73825 m
.28717 .73744 L
s
.44858 .91033 m .44929 .8968 L .44338 .89413 L 0 .502 .373 r
F
0 g
.44061 .89687 m
.44338 .89413 L
s
.44858 .91033 m .45507 .90394 L .44929 .8968 L 0 .502 .373 r
F
.44858 .91033 m .45684 .91079 L .45507 .90394 L F
.44858 .91033 m .45405 .91353 L .45684 .91079 L F
0 g
.44282 .9032 m
.44858 .91033 L
s
.44614 .91268 m
.44858 .91033 L
s
.56432 1.21444 m
.5674 1.2259 L
s
.56425 1.21417 m
.56432 1.21444 L
s
.38784 .76145 m
.39628 .76204 L
s
.48356 1.00205 m .47782 .98762 L .47966 .99302 L 0 0 .156 r
F
0 g
.47865 .99289 m
.47966 .99302 L
s
.54779 1.08396 m
.54821 1.08524 L
s
.33724 .85861 m
.33862 .85219 L
s
.37866 .77663 m .36723 .76863 L .36998 .77298 L 0 .886 .464 r
F
0 g
.36593 .77503 m
.36998 .77298 L
s
.57067 1.24305 m .56855 1.23017 L .56963 1.22334 L 0 .856 .108 r
F
0 g
.56855 1.23017 m
.56872 1.22908 L
s
.56872 1.22908 m
.56963 1.22334 L
s
.5674 1.2259 m
.56855 1.23017 L
s
.56651 1.21538 m
.56963 1.22334 L
s
.63605 .74752 m .65153 .72766 L .64169 .73159 L 0 1 .395 r
F
0 g
.65153 .72766 m
.65697 .72935 L
s
.65153 .72766 m
.66081 .72048 L
s
.4334 .86361 m .42462 .85202 L .42674 .85785 L 0 .705 .404 r
F
0 g
.42356 .8614 m
.42674 .85785 L
s
.72982 .84161 m .73142 .8329 L .72769 .83681 L 0 1 .493 r
F
.72982 .84161 m .73936 .83225 L .73142 .8329 L F
.43344 .60048 m .4211 .59781 L .42251 .59996 L 0 1 .532 r
F
.43344 .60048 m .43028 .59511 L .4211 .59781 L F
0 g
.41402 .60361 m
.42251 .59996 L
s
.43344 .60048 m .44397 .59365 L .43028 .59511 L 0 1 .532 r
F
.43344 .60048 m .45492 .59418 L .44397 .59365 L F
.43344 .60048 m .45582 .59633 L .45492 .59418 L F
.43344 .60048 m .4466 .59903 L .45582 .59633 L F
0 g
.42463 .60311 m
.43344 .60048 L
s
.42251 .59996 m
.43344 .60048 L
s
.38518 .7887 m .38752 .77715 L .37866 .77663 L 0 .836 .452 r
F
.38518 .7887 m .39592 .7813 L .38752 .77715 L F
.38518 .7887 m .39822 .7863 L .39592 .7813 L F
.38518 .7887 m .39361 .78947 L .39822 .7863 L F
0 g
.37682 .78456 m
.38518 .7887 L
s
.37232 .75682 m .36046 .75359 L .36325 .75632 L 0 1 .534 r
F
0 g
.36084 .75906 m
.36325 .75632 L
s
.6285 .64135 m .62254 .6329 L .6208 .63471 L 0 1 .51 r
F
.6285 .64135 m .63322 .63687 L .62254 .6329 L F
.6285 .64135 m .64571 .64397 L .63322 .63687 L F
.6285 .64135 m .65339 .65061 L .64571 .64397 L F
.6285 .64135 m .65117 .65236 L .65339 .65061 L F
0 g
.6405 .6484 m
.65117 .65236 L
s
.61818 .63731 m
.6285 .64135 L
s
.65117 .65236 m
.65804 .66012 L
s
.69296 .67836 m .70401 .68843 L .71462 .69458 L 0 1 .49 r
F
0 g
.70401 .68843 m
.70997 .6973 L
s
.61298 .83461 m .62066 .83021 L .62814 .81979 L 0 1 .328 r
F
0 g
.62673 .82175 m
.62685 .82158 L
s
.62685 .82158 m
.62722 .82106 L
s
.62722 .82106 m
.62814 .81979 L
s
.62613 .83222 m
.62617 .83213 L
s
.62617 .83213 m
.63168 .82107 L
s
.62814 .81979 m
.62815 .81979 L
s
.62627 .89584 m
.62637 .89594 L
s
.62177 .94812 m .62833 .89782 L .62243 .92277 L 0 1 .171 r
F
0 g
.62495 .91212 m
.62833 .89782 L
s
.62453 .91389 m
.62495 .91212 L
s
.62403 .916 m
.62453 .91389 L
s
.62637 .89594 m
.62833 .89782 L
s
.6268 .93549 m
.63111 .91717 L
s
.48565 .8138 m .47829 .80469 L .4791 .80781 L 0 .71 .441 r
F
0 g
.47389 .80724 m
.4791 .80781 L
s
.68168 1.21382 m .69196 1.18295 L .6903 1.19834 L 0 .144 .107 r
F
.32733 .73924 m .31446 .73528 L .31766 .73814 L 0 1 .509 r
F
0 g
.31468 .74064 m
.31766 .73814 L
s
.4334 .86361 m .4284 .84879 L .42462 .85202 L 0 .705 .404 r
F
0 g
.41795 .84696 m
.42462 .85202 L
s
.44338 .89412 m .44473 .88097 L .43839 .87875 L 0 .585 .386 r
F
.44338 .89412 m .45077 .88749 L .44473 .88097 L F
.44338 .89412 m .45247 .89396 L .45077 .88749 L F
.44338 .89412 m .44929 .89679 L .45247 .89396 L F
0 g
.43736 .88761 m
.44338 .89412 L
s
.71478 1.0931 m .71586 1.10591 L .71979 1.10692 L 0 1 .26 r
F
0 g
.71952 1.10685 m
.71964 1.10688 L
s
.71964 1.10688 m
.71979 1.10692 L
s
.43523 .77653 m .42459 .76924 L .42689 .7727 L 0 1 .503 r
F
0 g
.42228 .77484 m
.42689 .7727 L
s
.3349 .75067 m .32722 .74301 L .32228 .74799 L 0 1 .529 r
F
0 g
.31323 .74884 m
.32228 .74799 L
s
.27612 .82939 m .26367 .8262 L .26766 .8283 L 0 .828 .445 r
F
0 g
.26596 .83163 m
.26766 .8283 L
s
.71015 1.04761 m .71234 1.06809 L .71708 1.07495 L 0 1 .285 r
F
.70002 1.07958 m .71015 1.04761 L .70549 1.0413 L 0 1 .267 r
F
.70002 1.07958 m .71234 1.06809 L .71015 1.04761 L F
0 g
.71015 1.04761 m
.71159 1.02514 L
s
.65304 .7033 m .67629 .68907 L .66991 .68761 L 0 1 .438 r
F
0 g
.67629 .68907 m
.68584 .68265 L
s
.23256 .89942 m .22696 .89268 L .2216 .8939 L 0 .59 .35 r
F
.23256 .89942 m .2342 .89361 L .22696 .89268 L F
.23256 .89942 m .23845 .89608 L .2342 .89361 L F
.23256 .89942 m .23774 .89857 L .23845 .89608 L F
0 g
.22537 .89848 m
.23256 .89942 L
s
.23202 .9016 m
.23256 .89942 L
s
.66357 .93239 m .66618 .92527 L .66279 .93295 L 0 0 0 r
F
.69296 .67836 m .71462 .69458 L .71773 .6927 L 0 1 .49 r
F
0 g
.71462 .69458 m
.71992 .70457 L
s
.70401 .68843 m
.71462 .69458 L
s
.54952 1.14662 m .54924 1.14795 L .55278 1.17834 L 0 0 .12 r
F
0 g
.54918 1.15216 m
.54935 1.15342 L
s
.54727 1.13574 m
.54924 1.14795 L
s
.42118 .59201 m
.43039 .58728 L
s
.4102 .59272 m
.42118 .59201 L
s
.68773 .67518 m
.68827 .67551 L
s
.68719 .67486 m
.68773 .67518 L
s
.68276 .67217 m
.68719 .67486 L
s
.67579 .66435 m
.67871 .66766 L
s
.62567 .84847 m .62467 .83514 L .62237 .8461 L 0 1 .264 r
F
0 g
.62237 .8461 m
.62249 .84618 L
s
.61972 .88071 m .62567 .84847 L .61894 .8639 L 0 1 .26 r
F
0 g
.62127 .85856 m
.62567 .84847 L
s
.6209 .8594 m
.62127 .85856 L
s
.62046 .86041 m
.6209 .8594 L
s
.62249 .84618 m
.62567 .84847 L
s
.43523 .77653 m .42993 .76751 L .42459 .76924 L 0 1 .503 r
F
.43523 .77653 m .43937 .76867 L .42993 .76751 L F
.43523 .77653 m .44774 .77251 L .43937 .76867 L F
.43523 .77653 m .44944 .77646 L .44774 .77251 L F
.43523 .77653 m .44406 .77818 L .44944 .77646 L F
0 g
.42689 .7727 m
.43523 .77653 L
s
.68856 .82707 m
.68969 .82393 L
s
.68454 .83822 m
.68572 .83496 L
s
.68969 .82393 m
.69063 .82132 L
s
.3118 .8441 m
.31387 .84369 L
s
.3118 .8441 m
.31942 .84567 L
s
.48565 .8138 m .48399 .80564 L .47829 .80469 L 0 .71 .441 r
F
.48565 .8138 m .4924 .81005 L .48399 .80564 L F
.48565 .8138 m .49897 .81605 L .4924 .81005 L F
.48565 .8138 m .4993 .81964 L .49897 .81605 L F
.48565 .8138 m .49359 .81866 L .4993 .81964 L F
0 g
.48031 .81239 m
.48565 .8138 L
s
.4791 .80781 m
.48565 .8138 L
s
.3349 .75067 m .33701 .73947 L .32722 .74301 L 0 1 .529 r
F
0 g
.32547 .75108 m
.3349 .75067 L
s
.33025 .75568 m
.3349 .75067 L
s
.48356 1.00205 m .4793 .98841 L .47782 .98762 L 0 0 .156 r
F
0 g
.47368 .97956 m
.47782 .98762 L
s
.59764 .6264 m .61013 .63193 L .6208 .63471 L 0 1 .514 r
F
0 g
.61013 .63193 m
.61818 .63731 L
s
.54993 1.13956 m .55918 1.21981 L .55391 1.17221 L 0 0 .125 r
F
.54993 1.13956 m .56305 1.25598 L .55918 1.21981 L F
.54993 1.13956 m .55878 1.22254 L .56286 1.25602 L F
.54993 1.13956 m .55359 1.17838 L .55878 1.22254 L F
.54993 1.13956 m .54982 1.14303 L .55359 1.17838 L F
0 g
.55047 1.1312 m
.55152 1.13976 L
s
.55023 1.13512 m
.55075 1.14038 L
s
.54973 1.13802 m
.54993 1.13956 L
s
.54881 1.15961 m
.54984 1.1659 L
s
.54697 1.1457 m
.54984 1.1659 L
s
.54899 1.13806 m
.54982 1.14303 L
s
.75853 .81479 m .77581 .81101 L .76815 .80657 L 0 1 .513 r
F
0 g
.77581 .81101 m
.78458 .81216 L
s
.77581 .81101 m
.77851 .81657 L
s
.4466 .59903 m
.45716 .59949 L
s
.4284 .84879 m .4193 .83768 L .42143 .84337 L 0 .752 .412 r
F
0 g
.41795 .84696 m
.42143 .84337 L
s
.37866 .77663 m .37212 .76547 L .36723 .76863 L 0 .886 .464 r
F
0 g
.35877 .76469 m
.36723 .76863 L
s
.54952 1.14662 m .55878 1.22254 L .55359 1.17838 L 0 0 .12 r
F
.54952 1.14662 m .56241 1.2536 L .55878 1.22254 L F
.54952 1.14662 m .55278 1.17834 L .55784 1.21793 L F
0 g
.54952 1.14662 m
.55019 1.15183 L
s
.55019 1.15183 m
.55055 1.15463 L
s
.55055 1.15463 m
.55065 1.15544 L
s
.55065 1.15544 m
.55078 1.15646 L
s
.55078 1.15646 m
.55082 1.15679 L
s
.55082 1.15679 m
.55085 1.157 L
s
.54965 1.1515 m
.54989 1.15355 L
s
.54989 1.15355 m
.55007 1.15508 L
s
.55007 1.15508 m
.55013 1.15558 L
s
.55013 1.15558 m
.55027 1.15678 L
s
.55027 1.15678 m
.55075 1.16092 L
s
.54935 1.15342 m
.55038 1.16086 L
s
.55008 1.16408 m
.55153 1.17372 L
s
.5485 1.15355 m
.55008 1.16408 L
s
.55029 1.16415 m
.55153 1.17372 L
s
.5491 1.15489 m
.55029 1.16415 L
s
.54993 1.13956 m
.55093 1.14775 L
s
.54927 1.1447 m
.54952 1.14662 L
s
.54924 1.14795 m
.54965 1.1515 L
s
.53343 .60765 m .52397 .60221 L .5238 .60421 L 0 1 .515 r
F
0 g
.51388 .60481 m
.5238 .60421 L
s
.53343 .60765 m .53426 .60269 L .52397 .60221 L 0 1 .515 r
F
.53343 .60765 m .54781 .60534 L .53426 .60269 L F
.53343 .60765 m .55745 .60878 L .54781 .60534 L F
.53343 .60765 m .55674 .61073 L .55745 .60878 L F
.53343 .60765 m .54645 .61024 L .55674 .61073 L F
0 g
.54645 .61024 m
.55568 .61354 L
s
.52354 .60712 m
.53343 .60765 L
s
.5238 .60421 m
.53343 .60765 L
s
.43839 .87875 m .44016 .86546 L .4334 .86361 L 0 .65 .395 r
F
.43839 .87875 m .44652 .87158 L .44016 .86546 L F
.43839 .87875 m .44822 .87791 L .44652 .87158 L F
.43839 .87875 m .44473 .88097 L .44822 .87791 L F
0 g
.43205 .87263 m
.43839 .87875 L
s
.43524 .8816 m
.43839 .87875 L
s
.37232 .75682 m .36567 .74987 L .36046 .75359 L 0 1 .534 r
F
0 g
.35324 .75423 m
.36046 .75359 L
s
.37232 .75682 m .37542 .74763 L .36567 .74987 L 0 1 .534 r
F
.37232 .75682 m .38453 .74813 L .37542 .74763 L F
.37232 .75682 m .38688 .75104 L .38453 .74813 L F
.37232 .75682 m .38164 .75476 L .38688 .75104 L F
0 g
.36743 .76023 m
.37232 .75682 L
s
.36325 .75632 m
.37232 .75682 L
s
.70635 1.15418 m .71665 1.1201 L .71359 1.12611 L 0 .962 .123 r
F
0 g
.71665 1.1201 m
.71979 1.10692 L
s
.5516 1.1598 m
.55161 1.15982 L
s
.55155 1.15928 m
.5516 1.1598 L
s
.55142 1.15808 m
.55155 1.15928 L
s
.55108 1.15491 m
.55142 1.15808 L
s
.55039 1.14845 m
.55108 1.15491 L
s
.54982 1.14303 m
.55039 1.14845 L
s
.59764 .6264 m .59043 .61898 L .5892 .62086 L 0 1 .514 r
F
.59764 .6264 m .60111 .62176 L .59043 .61898 L F
.59764 .6264 m .6141 .62735 L .60111 .62176 L F
.59764 .6264 m .62254 .6329 L .6141 .62735 L F
.59764 .6264 m .6208 .63471 L .62254 .6329 L F
0 g
.61013 .63193 m
.6208 .63471 L
s
.58735 .62357 m
.59764 .6264 L
s
.6208 .63471 m
.6285 .64135 L
s
.47151 .79976 m
.47829 .80469 L
s
.53587 .91695 m .53285 .90145 L .53219 .90467 L 0 .252 .278 r
F
0 g
.53587 .91695 m
.53587 .91695 L
s
.52987 .9019 m
.53219 .90467 L
s
.49069 1.01851 m
.49388 1.02452 L
s
.68934 .66648 m
.69961 .66118 L
s
.52342 .87269 m .51875 .85952 L .51859 .86314 L 0 .41 .351 r
F
0 g
.51859 .86314 m
.52342 .87268 L
s
.52342 .87269 m
.52342 .87269 L
s
.51836 .86832 m
.52342 .87269 L
s
.51726 .86234 m
.51859 .86314 L
s
.30498 .74103 m
.3091 .73612 L
s
.52436 .57217 m
.535 .56898 L
s
.51393 .57136 m
.52436 .57217 L
s
.68798 .67126 m
.68826 .67167 L
s
.6878 .67101 m
.68798 .67126 L
s
.68774 .67093 m
.6878 .67101 L
s
.69296 .67836 m .7 .6737 L .68937 .66754 L 0 1 .49 r
F
.69296 .67836 m .71147 .68376 L .7 .6737 L F
.69296 .67836 m .71773 .6927 L .71147 .68376 L F
0 g
.68826 .67167 m
.69296 .67836 L
s
.68827 .67551 m
.69296 .67836 L
s
.64169 .73159 m .65762 .71331 L .64735 .71692 L 0 1 .41 r
F
0 g
.65762 .71331 m
.66338 .71484 L
s
.65762 .71331 m
.66724 .7067 L
s
.28587 .83468 m .28344 .82873 L .27612 .82939 L 0 .704 .399 r
F
.28587 .83468 m .29172 .83017 L .28344 .82873 L F
.28587 .83468 m .29541 .83274 L .29172 .83017 L F
.28587 .83468 m .29289 .83467 L .29541 .83274 L F
0 g
.27763 .83325 m
.28587 .83468 L
s
.28362 .83592 m
.28587 .83468 L
s
.4284 .84879 m .42339 .83437 L .4193 .83768 L 0 .752 .412 r
F
0 g
.41233 .83279 m
.4193 .83768 L
s
.73936 .83225 m .74077 .82346 L .73703 .82718 L 0 1 .502 r
F
.73936 .83225 m .74893 .82333 L .74077 .82346 L F
.66636 1.20994 m .67539 1.20259 L .67128 1.21302 L 0 .291 .135 r
F
.67139 1.24849 m .67539 1.20259 L .67984 1.20292 L 0 .233 .136 r
F
.67139 1.24849 m .67128 1.21302 L .67539 1.20259 L F
0 g
.67539 1.20259 m
.67655 1.18657 L
s
.67539 1.20259 m
.67729 1.20273 L
s
.67499 .88954 m .6937 .87803 L .69216 .87239 L 0 1 .419 r
F
.67499 .88954 m .68918 .88454 L .6937 .87803 L F
0 g
.6937 .87803 m
.70136 .87326 L
s
.68465 .89251 m
.68979 .88843 L
s
.67499 .88954 m .68117 .88948 L .68918 .88454 L 0 1 .419 r
F
0 g
.68918 .88454 m
.68979 .88843 L
s
.51123 1.05475 m .50908 1.05882 L .50943 1.05399 L 0 .717 .077 r
F
0 g
.50818 1.04626 m
.50943 1.05399 L
s
.51123 1.05475 m .51073 1.0688 L .50908 1.05882 L 0 .717 .077 r
F
.51123 1.05475 m .5133 1.07728 L .51073 1.0688 L F
.51123 1.05475 m .51511 1.07803 L .5133 1.07728 L F
.51123 1.05475 m .51494 1.07055 L .51511 1.07803 L F
.51123 1.05475 m .51328 1.06058 L .51494 1.07055 L F
0 g
.51328 1.06058 m
.51469 1.0568 L
s
.50996 1.04416 m
.51123 1.05475 L
s
.50943 1.05399 m
.51123 1.05475 L
s
.51469 1.0568 m
.51613 1.06785 L
s
.70002 1.07958 m .70549 1.0413 L .70145 1.05339 L 0 1 .267 r
F
0 g
.70549 1.0413 m
.71015 1.04761 L
s
.70549 1.0413 m
.70609 1.01221 L
s
.50078 1.03893 m
.50312 1.04158 L
s
.50061 1.03873 m
.50078 1.03893 L
s
.54294 .95783 m .54637 .95978 L .54171 .94581 L 0 0 .142 r
F
.54294 .95783 m .55137 .97767 L .54637 .95978 L F
.54294 .95783 m .55211 .98988 L .55384 .99061 L F
.54294 .95783 m .54743 .9758 L .55211 .98988 L F
0 g
.5405 .94501 m
.54294 .95783 L
s
.54097 .94972 m
.54294 .95783 L
s
.56583 .61521 m .57865 .61924 L .5892 .62086 L 0 1 .515 r
F
0 g
.57865 .61924 m
.58735 .62357 L
s
.27612 .82939 m .26636 .82367 L .26367 .8262 L 0 .828 .445 r
F
0 g
.2558 .82661 m
.26367 .8262 L
s
.56583 .61521 m .55745 .60878 L .55674 .61073 L 0 1 .515 r
F
0 g
.54645 .61024 m
.55674 .61073 L
s
.56583 .61521 m .56799 .6104 L .55745 .60878 L 0 1 .515 r
F
.56583 .61521 m .58135 .6145 L .56799 .6104 L F
.56583 .61521 m .59043 .61898 L .58135 .6145 L F
.56583 .61521 m .5892 .62086 L .59043 .61898 L F
0 g
.55674 .61073 m
.56583 .61521 L
s
.55568 .61354 m
.56583 .61521 L
s
.5892 .62086 m
.59764 .6264 L
s
.57865 .61924 m
.5892 .62086 L
s
.68557 .87137 m .69986 .86955 L .70356 .86477 L 0 1 .449 r
F
.68557 .87137 m .69216 .87238 L .69986 .86955 L F
0 g
.69986 .86955 m
.70137 .87326 L
s
.32733 .73924 m .31963 .73162 L .31446 .73528 L 0 1 .509 r
F
0 g
.30898 .73516 m
.31446 .73528 L
s
.66698 .90541 m .68322 .89364 L .68117 .88948 L 0 1 .381 r
F
.66698 .90541 m .6798 .89925 L .68322 .89364 L F
0 g
.67604 .90677 m
.68101 .90128 L
s
.68322 .89364 m
.68465 .89251 L
s
.56053 1.03095 m
.56058 1.02417 L
s
.56063 1.01746 m
.56063 1.01705 L
s
.61298 .83461 m .62617 .80659 L .61811 .81119 L 0 1 .328 r
F
0 g
.62467 .83514 m
.62613 .83222 L
s
.62066 .83021 m
.62673 .82175 L
s
.62617 .80659 m
.62678 .80711 L
s
.48356 1.00205 m .48313 .99489 L .4793 .98841 L 0 0 .156 r
F
.48356 1.00205 m .48704 1.00395 L .48313 .99489 L F
.48356 1.00205 m .4884 1.00954 L .48704 1.00395 L F
.48356 1.00205 m .48691 1.00871 L .4884 1.00954 L F
0 g
.48244 1.00011 m
.48356 1.00205 L
s
.47966 .99302 m
.48356 1.00205 L
s
.52876 .89152 m
.53206 .89439 L
s
.68557 .87137 m .70356 .86477 L .70115 .8599 L 0 1 .449 r
F
0 g
.69216 .87238 m
.69986 .86955 L
s
.70356 .86477 m
.71082 .86199 L
s
.65877 .69054 m .68019 .68201 L .6828 .67745 L 0 1 .45 r
F
.65877 .69054 m .66991 .68761 L .68019 .68201 L F
0 g
.68019 .68201 m
.68585 .68257 L
s
.4334 .86361 m .43559 .85032 L .4284 .84879 L 0 .705 .404 r
F
.4334 .86361 m .44227 .85609 L .43559 .85032 L F
.4334 .86361 m .44397 .86223 L .44227 .85609 L F
.4334 .86361 m .44016 .86546 L .44397 .86223 L F
0 g
.42674 .85785 m
.4334 .86361 L
s
.42993 .86669 m
.4334 .86361 L
s
.66698 .90541 m .67285 .90429 L .6798 .89925 L 0 1 .381 r
F
0 g
.6798 .89925 m
.68101 .90128 L
s
.4793 .98841 m .4732 .97257 L .47504 .97885 L 0 .147 .228 r
F
0 g
.47368 .97956 m
.47504 .97885 L
s
.2216 .8939 m .21618 .8867 L .21064 .88832 L 0 .651 .377 r
F
0 g
.20983 .89112 m
.21064 .88832 L
s
.2216 .8939 m .22356 .88736 L .21618 .8867 L 0 .651 .377 r
F
.2216 .8939 m .22781 .88987 L .22356 .88736 L F
.2216 .8939 m .22696 .89268 L .22781 .88987 L F
0 g
.21427 .89323 m
.2216 .8939 L
s
.22093 .89639 m
.2216 .8939 L
s
.51355 .85152 m
.51798 .85346 L
s
.53882 .93591 m
.54171 .94581 L
s
.70575 .77299 m .72247 .74421 L .71343 .7564 L 0 .857 .124 r
F
0 g
.72247 .74421 m
.72671 .73947 L
s
.72247 .74421 m
.7295 .7343 L
s
.30907 .92997 m .29789 .92669 L .30212 .92861 L 0 .619 .246 r
F
0 g
.30212 .92861 m
.30221 .93003 L
s
.42339 .83437 m .41396 .82377 L .4161 .82928 L 0 .794 .421 r
F
0 g
.41233 .83279 m
.4161 .82928 L
s
.69813 .79138 m .71443 .75958 L .70575 .77299 L 0 .834 .111 r
F
0 g
.71443 .75958 m
.72104 .749 L
s
.71443 .75958 m
.71841 .75442 L
s
.70655 .77647 m
.71016 .77111 L
s
.70665 .77625 m
.71262 .76538 L
s
.69923 .79461 m
.70197 .79001 L
s
.69521 1.19586 m .69416 1.1915 L .69647 1.17946 L 0 0 .051 r
F
0 g
.69196 1.18295 m
.69647 1.17946 L
s
.32745 .84915 m .31943 .84568 L .32314 .84647 L 0 .217 0 r
F
.37866 .77663 m .38141 .76561 L .37212 .76547 L 0 .886 .464 r
F
.37866 .77663 m .39013 .76927 L .38141 .76561 L F
.37866 .77663 m .39245 .774 L .39013 .76927 L F
.37866 .77663 m .38752 .77715 L .39245 .774 L F
0 g
.36998 .77298 m
.37866 .77663 L
s
.37409 .77981 m
.37866 .77663 L
s
.69422 .85818 m .70911 .85786 L .71281 .85343 L 0 1 .466 r
F
.69422 .85818 m .70115 .8599 L .70911 .85786 L F
0 g
.70911 .85786 m
.71082 .86199 L
s
.62066 .83021 m
.62467 .83514 L
s
.41611 .76661 m
.42459 .76924 L
s
.32722 .74301 m .3143 .74027 L .31749 .74336 L 0 1 .528 r
F
0 g
.31741 .74346 m
.31749 .74336 L
s
.54933 .98568 m .55412 1.00744 L .5495 .98354 L 0 0 .054 r
F
.54933 .98568 m .55322 1.00656 L .55786 1.03058 L F
0 g
.5482 .97867 m
.54933 .98568 L
s
.46043 .78898 m .45168 .78161 L .45296 .78453 L 0 .914 .482 r
F
0 g
.44763 .78516 m
.45296 .78453 L
s
.50602 .83582 m .4998 .82493 L .50012 .82839 L 0 .615 .409 r
F
0 g
.49477 .82697 m
.50012 .82839 L
s
.4793 .98841 m .47504 .97237 L .4732 .97257 L 0 .147 .228 r
F
0 g
.46872 .96418 m
.4732 .97257 L
s
.71773 .6927 m
.72796 .69984 L
s
.71147 .68376 m
.71773 .6927 L
s
.71343 .7564 m .73057 .73022 L .72116 .74128 L 0 .882 .138 r
F
0 g
.73057 .73022 m
.73752 .72156 L
s
.73057 .73022 m
.73504 .72595 L
s
.37212 .76547 m .36034 .75833 L .3631 .76235 L 0 .946 .475 r
F
0 g
.35877 .76469 m
.3631 .76235 L
s
.52342 .87269 m .52417 .86304 L .51875 .85952 L 0 .41 .351 r
F
0 g
.51355 .85152 m
.51875 .85952 L
s
.52342 .87269 m .53126 .87137 L .52417 .86304 L 0 .41 .351 r
F
.52342 .87269 m .53611 .88095 L .53126 .87137 L F
.52342 .87269 m .53548 .88538 L .53611 .88095 L F
.52342 .87269 m .53003 .88183 L .53548 .88538 L F
0 g
.52342 .87268 m
.52342 .87269 L
s
.65902 .92381 m .67468 .90828 L .67285 .90429 L 0 1 .328 r
F
.65902 .92381 m .67127 .9147 L .67468 .90828 L F
0 g
.66763 .92299 m
.67227 .9157 L
s
.67468 .90828 m
.67604 .90677 L
s
.69422 .85818 m .71281 .85343 L .71017 .84838 L 0 1 .466 r
F
0 g
.71281 .85343 m
.72031 .85149 L
s
.42339 .83437 m .41837 .82043 L .41396 .82377 L 0 .794 .421 r
F
0 g
.4067 .81901 m
.41396 .82377 L
s
.68277 1.03329 m .69544 1.07461 L .69599 1.0385 L 0 .943 .263 r
F
0 g
.69599 1.0385 m
.70145 1.05339 L
s
.76815 .80657 m .78574 .80348 L .7778 .79863 L 0 1 .516 r
F
0 g
.78574 .80348 m
.78863 .80927 L
s
.32733 .73924 m .32977 .72959 L .31963 .73162 L 0 1 .509 r
F
.32733 .73924 m .33949 .73068 L .32977 .72959 L F
.32733 .73924 m .34229 .73418 L .33949 .73068 L F
0 g
.32298 .74211 m
.32733 .73924 L
s
.31766 .73814 m
.32733 .73924 L
s
.45502 .58374 m
.46484 .57946 L
s
.44408 .58395 m
.45502 .58374 L
s
.32745 .84915 m .31826 .84619 L .31943 .84568 L 0 .217 0 r
F
.32745 .84915 m .32043 .84767 L .31826 .84619 L F
.32745 .84915 m .32475 .85036 L .32043 .84767 L F
.32745 .84915 m .32833 .85246 L .32475 .85036 L F
.32745 .84915 m .32948 .85194 L .32833 .85246 L F
0 g
.32745 .84915 m
.32885 .84276 L
s
.32314 .84647 m
.32745 .84915 L
s
.42459 .76924 m
.42993 .76751 L
s
.4284 .84879 m .431 .83564 L .42339 .83437 L 0 .752 .412 r
F
.4284 .84879 m .438 .84107 L .431 .83564 L F
.4284 .84879 m .43971 .84701 L .438 .84107 L F
.4284 .84879 m .43559 .85032 L .43971 .84701 L F
0 g
.42143 .84337 m
.4284 .84879 L
s
.42462 .85202 m
.4284 .84879 L
s
.69056 .81199 m .70644 .77664 L .69813 .79138 L 0 .815 .1 r
F
0 g
.70644 .77664 m
.70655 .77647 L
s
.70644 .77664 m
.70665 .77625 L
s
.69971 .79331 m
.70422 .78389 L
s
.69228 .81464 m
.69386 .81171 L
s
.69291 .81221 m
.69587 .80513 L
s
.6985 .79582 m
.69923 .79461 L
s
.6985 .79582 m
.69971 .79331 L
s
.65877 .69054 m .6828 .67745 L .6761 .67595 L 0 1 .45 r
F
0 g
.6828 .67745 m
.68394 .67677 L
s
.74893 .82333 m .75014 .81444 L .74639 .818 L 0 1 .508 r
F
.74893 .82333 m .75853 .81479 L .75014 .81444 L F
0 g
.48956 .57709 m
.49986 .57332 L
s
.47881 .57679 m
.48956 .57709 L
s
.55208 1.18151 m
.55304 1.18733 L
s
.57265 1.06801 m
.57282 1.06931 L
s
.57286 1.06959 m
.57359 1.07506 L
s
.57473 1.0836 m
.57501 1.08569 L
s
.57282 1.06931 m
.57286 1.06959 L
s
.57161 1.07789 m
.5718 1.07607 L
s
.57197 1.07447 m
.57265 1.06801 L
s
.30907 .92997 m .29864 .92586 L .29789 .92669 L 0 .619 .246 r
F
0 g
.29149 .92521 m
.29789 .92669 L
s
.68277 1.03329 m .69148 1.09086 L .69544 1.07461 L 0 .943 .263 r
F
.68277 1.03329 m .68603 1.07305 L .69148 1.09086 L F
.67294 1.06988 m .68603 1.07305 L .68277 1.03329 L 0 .913 .25 r
F
0 g
.67737 1.01188 m
.68277 1.03329 L
s
.68277 1.03329 m
.68336 .99746 L
s
.70002 1.07958 m .71094 1.09429 L .71234 1.06809 L 0 1 .267 r
F
0 g
.71234 1.06809 m
.71708 1.07495 L
s
.67579 .66435 m
.6803 .66644 L
s
.46043 .78898 m .45757 .7814 L .45168 .78161 L 0 .914 .482 r
F
.46043 .78898 m .46673 .78404 L .45757 .7814 L F
.46043 .78898 m .47423 .78851 L .46673 .78404 L F
.46043 .78898 m .47504 .79181 L .47423 .78851 L F
.46043 .78898 m .46912 .792 L .47504 .79181 L F
0 g
.45489 .78882 m
.46043 .78898 L
s
.45296 .78453 m
.46043 .78898 L
s
.4211 .59781 m
.43028 .59511 L
s
.41011 .59826 m
.4211 .59781 L
s
.53587 .91695 m .53789 .90804 L .53285 .90145 L 0 .252 .278 r
F
0 g
.52876 .89152 m
.53285 .90145 L
s
.53117 .90842 m
.53587 .91695 L
s
.65902 .92381 m .66457 .92136 L .67127 .9147 L 0 1 .328 r
F
0 g
.67127 .9147 m
.67227 .9157 L
s
.64735 .71692 m .66375 .70002 L .65304 .7033 L 0 1 .424 r
F
0 g
.66375 .70002 m
.66982 .70148 L
s
.66375 .70002 m
.6737 .69393 L
s
.70291 .84607 m .71838 .847 L .7221 .84286 L 0 1 .478 r
F
.70291 .84607 m .71017 .84838 L .71838 .847 L F
0 g
.71838 .847 m
.72031 .85149 L
s
.26636 .82367 m .25368 .82071 L .25768 .82294 L 0 .919 .472 r
F
0 g
.2558 .82661 m
.25768 .82294 L
s
.47504 .97237 m .46859 .95594 L .47043 .96275 L 0 .246 .287 r
F
0 g
.46872 .96418 m
.47043 .96275 L
s
.50602 .83582 m .50557 .82672 L .4998 .82493 L 0 .615 .409 r
F
.50602 .83582 m .5136 .83259 L .50557 .82672 L F
.50602 .83582 m .51953 .84003 L .5136 .83259 L F
.50602 .83582 m .51937 .84407 L .51953 .84003 L F
.50602 .83582 m .51358 .84226 L .51937 .84407 L F
0 g
.50061 .83346 m
.50602 .83582 L
s
.50012 .82839 m
.50602 .83582 L
s
.53587 .91695 m .54396 .92009 L .53789 .90804 L 0 .252 .278 r
F
.53587 .91695 m .54766 .93243 L .54396 .92009 L F
.53587 .91695 m .54651 .9368 L .54766 .93243 L F
.53587 .91695 m .54145 .93014 L .54651 .9368 L F
0 g
.53882 .93591 m
.54026 .93854 L
s
.53219 .90467 m
.53587 .91695 L
s
.4016 .75984 m .39041 .75528 L .39276 .75804 L 0 1 .526 r
F
0 g
.38784 .76145 m
.39276 .75804 L
s
.41837 .82043 m .40861 .8104 L .41076 .81568 L 0 .832 .429 r
F
0 g
.4067 .81901 m
.41076 .81568 L
s
.49359 .81866 m
.4998 .82493 L
s
.69521 1.19586 m .70549 1.16089 L .7032 1.17288 L 0 0 .051 r
F
.72116 .74128 m .7387 .71737 L .72893 .72737 L 0 .907 .153 r
F
0 g
.7387 .71737 m
.74082 .71566 L
s
.44407 .77818 m
.45168 .78161 L
s
.68548 .83771 m
.68582 .83703 L
s
.47504 .97237 m .47079 .95488 L .46859 .95594 L 0 .246 .287 r
F
0 g
.46377 .94756 m
.46859 .95594 L
s
.46658 .59785 m .45492 .59418 L .45582 .59633 L 0 1 .527 r
F
.46658 .59785 m .46473 .59247 L .45492 .59418 L F
0 g
.4466 .59903 m
.45582 .59633 L
s
.46658 .59785 m .47872 .59235 L .46473 .59247 L 0 1 .527 r
F
.46658 .59785 m .4895 .59388 L .47872 .59235 L F
.46658 .59785 m .48986 .59602 L .4895 .59388 L F
.46658 .59785 m .48003 .59772 L .48986 .59602 L F
0 g
.45716 .59949 m
.46658 .59785 L
s
.45582 .59633 m
.46658 .59785 L
s
.70291 .84607 m .7221 .84286 L .71922 .83763 L 0 1 .478 r
F
0 g
.7221 .84286 m
.72982 .84161 L
s
.6246 .90022 m
.62627 .89584 L
s
.62457 .90029 m
.6246 .90022 L
s
.6245 .90047 m
.62457 .90029 L
s
.62432 .90095 m
.6245 .90047 L
s
.61984 .91271 m
.62432 .90095 L
s
.48003 .59772 m
.49041 .59915 L
s
.37212 .76547 m .36554 .75507 L .36034 .75833 L 0 .946 .475 r
F
0 g
.35156 .75524 m
.36034 .75833 L
s
.32722 .74301 m .31951 .73532 L .3143 .74027 L 0 1 .528 r
F
0 g
.30498 .74103 m
.3143 .74027 L
s
.31963 .73162 m .30644 .72818 L .30965 .73101 L 0 1 .515 r
F
0 g
.30708 .73335 m
.30965 .73101 L
s
.42339 .83437 m .42641 .82149 L .41837 .82043 L 0 .794 .421 r
F
.42339 .83437 m .43373 .82658 L .42641 .82149 L F
.42339 .83437 m .43544 .83231 L .43373 .82658 L F
.42339 .83437 m .431 .83564 L .43544 .83231 L F
0 g
.4161 .82928 m
.42339 .83437 L
s
.4193 .83768 m
.42339 .83437 L
s
.70459 1.12903 m .71586 1.10591 L .71478 1.0931 L 0 1 .226 r
F
.70459 1.12903 m .71359 1.12611 L .71586 1.10591 L F
0 g
.71586 1.10591 m
.71952 1.10685 L
s
.47079 .95488 m .46398 .93844 L .46582 .94552 L 0 .313 .323 r
F
0 g
.46377 .94756 m
.46582 .94552 L
s
.41837 .82043 m .41334 .80706 L .40861 .8104 L 0 .832 .429 r
F
0 g
.40105 .80578 m
.40861 .8104 L
s
.70635 1.15418 m .70631 1.15848 L .70938 1.15238 L 0 .962 .123 r
F
0 g
.70549 1.16089 m
.70938 1.15238 L
s
.34646 .7469 m
.34701 .74704 L
s
.34485 .74649 m
.34646 .7469 L
s
.66395 .65574 m .65898 .64598 L .65674 .64787 L 0 1 .504 r
F
.66395 .65574 m .66988 .65104 L .65898 .64598 L F
.66395 .65574 m .68218 .65967 L .66988 .65104 L F
0 g
.65339 .65061 m
.66395 .65574 L
s
.4793 .98841 m .47936 .97839 L .47504 .97237 L 0 .147 .228 r
F
.4793 .98841 m .48363 .98798 L .47936 .97839 L F
.4793 .98841 m .48499 .99471 L .48363 .98798 L F
.4793 .98841 m .48313 .99489 L .48499 .99471 L F
0 g
.47782 .98762 m
.4793 .98841 L
s
.47504 .97885 m
.4793 .98841 L
s
.36567 .74987 m .35348 .74647 L .35627 .74937 L 0 1 .532 r
F
0 g
.35496 .75078 m
.35627 .74937 L
s
.62081 .84852 m
.62237 .8461 L
s
.6208 .84855 m
.62081 .84852 L
s
.62075 .84862 m
.6208 .84855 L
s
.62064 .84879 m
.62075 .84862 L
s
.61519 .85726 m
.62064 .84879 L
s
.4016 .75984 m .39608 .75272 L .39041 .75528 L 0 1 .526 r
F
.4016 .75984 m .406 .75206 L .39608 .75272 L F
.4016 .75984 m .41488 .75387 L .406 .75206 L F
.4016 .75984 m .41676 .75694 L .41488 .75387 L F
.4016 .75984 m .41106 .7595 L .41676 .75694 L F
0 g
.39628 .76204 m
.4016 .75984 L
s
.39276 .75804 m
.4016 .75984 L
s
.3869 .75507 m
.39041 .75528 L
s
.26636 .82367 m .2566 .81766 L .25368 .82071 L 0 .919 .472 r
F
0 g
.24563 .82132 m
.25368 .82071 L
s
.32722 .74301 m .3297 .7318 L .31951 .73532 L 0 1 .528 r
F
.32722 .74301 m .33947 .73145 L .3297 .7318 L F
.32722 .74301 m .34228 .7345 L .33947 .73145 L F
0 g
.31749 .74336 m
.32722 .74301 L
s
.32228 .74799 m
.32722 .74301 L
s
.45168 .78161 m
.45757 .7814 L
s
.47079 .95488 m .46655 .93668 L .46398 .93844 L 0 .313 .323 r
F
0 g
.45881 .93031 m
.46398 .93844 L
s
.29864 .92586 m .28729 .92185 L .29153 .9238 L 0 .498 .229 r
F
0 g
.29149 .92521 m
.29153 .9238 L
s
.63046 .76498 m .62738 .75599 L .62527 .76304 L 0 1 .379 r
F
.63046 .76498 m .63605 .74752 L .62738 .75599 L F
.62489 .78429 m .63046 .76498 L .62211 .77415 L 0 1 .363 r
F
0 g
.62757 .7639 m
.63046 .76498 L
s
.34431 .74703 m
.34585 .74549 L
s
.34585 .74549 m
.34623 .74511 L
s
.34431 .74703 m
.34646 .7469 L
s
.27612 .82939 m .27398 .8224 L .26636 .82367 L 0 .828 .445 r
F
.27612 .82939 m .28249 .82348 L .27398 .8224 L F
.27612 .82939 m .28619 .8262 L .28249 .82348 L F
.27612 .82939 m .28344 .82873 L .28619 .8262 L F
0 g
.26766 .8283 m
.27612 .82939 L
s
.27364 .83132 m
.27612 .82939 L
s
.65114 .94593 m .66618 .92527 L .66457 .92136 L 0 1 .26 r
F
.65114 .94593 m .66279 .93295 L .66618 .92527 L F
0 g
.66618 .92527 m
.66763 .92299 L
s
.71163 .83479 m .72769 .83681 L .73142 .8329 L 0 1 .487 r
F
.71163 .83479 m .71922 .83763 L .72769 .83681 L F
0 g
.72769 .83681 m
.72982 .84161 L
s
.2967 .73335 m
.30069 .72888 L
s
.66452 .67852 m .6761 .67595 L .68672 .67079 L 0 1 .461 r
F
0 g
.68672 .67079 m
.68774 .67093 L
s
.30234 .83995 m
.30463 .83872 L
s
.67139 1.24849 m .67984 1.20292 L .68168 1.21382 L 0 .233 .136 r
F
0 g
.67984 1.20292 m
.68153 1.18754 L
s
.67729 1.20273 m
.67984 1.20292 L
s
.63929 1.22438 m
.6393 1.2244 L
s
.70459 1.12903 m .71478 1.0931 L .71094 1.09429 L 0 1 .226 r
F
0 g
.71369 1.12521 m
.71586 1.10591 L
s
.71367 1.12595 m
.71665 1.1201 L
s
.71478 1.0931 m
.71708 1.07495 L
s
.48399 .80564 m .47626 .7967 L .47708 .79993 L 0 .809 .456 r
F
0 g
.47151 .79976 m
.47708 .79993 L
s
.63605 .74752 m .63268 .7394 L .63056 .74586 L 0 1 .395 r
F
.63605 .74752 m .64169 .73159 L .63268 .7394 L F
.46655 .93668 m .4595 .92109 L .46127 .92797 L 0 .414 .346 r
F
0 g
.45881 .9303 m
.46127 .92797 L
s
.75853 .81479 m .75955 .80579 L .75578 .80921 L 0 1 .513 r
F
.75853 .81479 m .76815 .80657 L .75955 .80579 L F
.37212 .76547 m .37527 .75475 L .36554 .75507 L 0 .946 .475 r
F
.37212 .76547 m .38432 .75787 L .37527 .75475 L F
0 g
.38164 .75476 m
.3869 .75507 L
s
.37212 .76547 m .38665 .76236 L .38432 .75787 L 0 .946 .475 r
F
.37212 .76547 m .38141 .76561 L .38665 .76236 L F
0 g
.36723 .76863 m
.37212 .76547 L
s
.3631 .76235 m
.37212 .76547 L
s
.62489 .78429 m .62211 .77415 L .62002 .78192 L 0 1 .363 r
F
0 g
.62391 .78381 m
.62489 .78429 L
s
.61811 .81118 m .62489 .78429 L .61652 .79581 L 0 1 .345 r
F
.46655 .93668 m .46247 .91899 L .4595 .92109 L 0 .414 .346 r
F
0 g
.45405 .91353 m
.4595 .92109 L
s
.49508 1.02905 m .49046 1.01662 L .49183 1.02048 L 0 0 .106 r
F
0 g
.49069 1.01851 m
.49183 1.02048 L
s
.67499 .88954 m .69216 .87239 L .68557 .87137 L 0 1 .419 r
F
0 g
.68117 .88948 m
.68918 .88454 L
s
.69216 .87239 m
.6937 .87803 L
s
.58168 1.11354 m
.58172 1.11108 L
s
.71163 .83479 m .73142 .8329 L .7283 .8275 L 0 1 .487 r
F
0 g
.73142 .8329 m
.73936 .83225 L
s
.66698 .90541 m .68117 .88948 L .67499 .88955 L 0 1 .381 r
F
0 g
.68117 .88948 m
.68322 .89364 L
s
.48399 .80564 m .48232 .79726 L .47626 .7967 L 0 .809 .456 r
F
.48399 .80564 m .49122 .80123 L .48232 .79726 L F
.48399 .80564 m .49815 .80696 L .49122 .80123 L F
.48399 .80564 m .49848 .81062 L .49815 .80696 L F
.48399 .80564 m .4924 .81005 L .49848 .81062 L F
0 g
.47829 .80469 m
.48399 .80564 L
s
.47708 .79993 m
.48399 .80564 L
s
.46247 .91899 m .45507 .90394 L .45684 .91079 L 0 .513 .361 r
F
0 g
.45405 .91353 m
.45684 .91079 L
s
.41334 .80706 m .40207 .79497 L .40489 .80152 L 0 .875 .439 r
F
0 g
.40105 .80578 m
.40489 .80152 L
s
.29864 .92586 m .2882 .92133 L .28729 .92185 L 0 .498 .229 r
F
0 g
.28076 .92033 m
.28729 .92185 L
s
.31963 .73162 m .31191 .72411 L .30644 .72818 L 0 1 .515 r
F
0 g
.30117 .72835 m
.30644 .72818 L
s
.41837 .82043 m .4218 .8079 L .41334 .80706 L 0 .832 .429 r
F
0 g
.40861 .8104 m
.41334 .80706 L
s
.41837 .82043 m .42944 .81266 L .4218 .8079 L 0 .832 .429 r
F
.41837 .82043 m .43116 .81816 L .42944 .81266 L F
.41837 .82043 m .42641 .82149 L .43116 .81816 L F
0 g
.41076 .81568 m
.41837 .82043 L
s
.41396 .82377 m
.41837 .82043 L
s
.55161 1.09567 m .55795 1.1879 L .5538 1.14008 L 0 .738 .197 r
F
.56504 1.24517 m .56348 1.23377 L .5653 1.23348 L 0 .873 .094 r
F
.56115 1.18467 m .56175 1.20276 L .56633 1.27318 L 0 0 .113 r
F
.55161 1.09567 m .56215 1.20852 L .55795 1.1879 L 0 .738 .197 r
F
.56504 1.24517 m .5653 1.23348 L .56928 1.24448 L 0 .873 .094 r
F
.56859 1.2755 m .56723 1.26305 L .56947 1.26461 L 0 .914 .1 r
F
.5716 1.3082 m .57047 1.29484 L .57311 1.29945 L 0 .945 .104 r
F
.55924 1.12768 m .57013 1.29552 L .57334 1.31692 L 0 0 .125 r
F
.55924 1.12768 m .5647 1.22386 L .57013 1.29552 L F
.55924 1.12768 m .56008 1.15246 L .5647 1.22386 L F
.56115 1.18467 m .57013 1.29552 L .5647 1.22386 L 0 0 .113 r
F
.56115 1.18467 m .57487 1.36802 L .57013 1.29552 L F
.56115 1.18467 m .57567 1.39175 L .57487 1.36802 L F
.56115 1.18467 m .57196 1.35046 L .57567 1.39175 L F
.56115 1.18467 m .56633 1.27318 L .57196 1.35046 L F
.55161 1.09567 m .56355 1.18763 L .56215 1.20852 L 0 .738 .197 r
F
0 g
.55369 1.19126 m
.55375 1.19165 L
s
.55375 1.19165 m
.55402 1.19331 L
s
.55402 1.19331 m
.55403 1.19339 L
s
.55403 1.19339 m
.55416 1.19414 L
s
.55924 1.12768 m .57211 1.27284 L .56736 1.20026 L 0 0 .125 r
F
.55924 1.12768 m .57334 1.31692 L .57211 1.27284 L F
.55161 1.09567 m .56127 1.14251 L .56355 1.18763 L 0 .738 .197 r
F
0 g
.55288 1.17287 m
.55359 1.17838 L
s
.55085 1.157 m
.55288 1.17287 L
s
.5531 1.16399 m
.55391 1.17221 L
s
.5531 1.16397 m
.5531 1.16399 L
s
.55304 1.1634 m
.5531 1.16397 L
s
.55295 1.16249 m
.55304 1.1634 L
s
.55294 1.16243 m
.55295 1.16249 L
s
.55207 1.17224 m
.55278 1.17834 L
s
.55075 1.16092 m
.55207 1.17224 L
s
.55176 1.15049 m
.55252 1.15817 L
s
.55272 1.16014 m
.55294 1.16243 L
s
.55252 1.15817 m
.55272 1.16014 L
s
.55201 1.17275 m
.55278 1.17834 L
s
.55038 1.16086 m
.55201 1.17275 L
s
.55316 1.15323 m
.55375 1.15814 L
s
.55336 1.15406 m
.55375 1.15814 L
s
.55275 1.16265 m
.55391 1.17221 L
s
.55271 1.16234 m
.55275 1.16265 L
s
.55267 1.16199 m
.55271 1.16234 L
s
.55255 1.16105 m
.55267 1.16199 L
s
.55242 1.15999 m
.55255 1.16105 L
s
.55194 1.15601 m
.55242 1.15999 L
s
.55183 1.15512 m
.55194 1.15601 L
s
.55093 1.14775 m
.55183 1.15512 L
s
.55165 1.1602 m
.55289 1.17181 L
s
.55289 1.17181 m
.55359 1.17838 L
s
.55161 1.15982 m
.55165 1.1602 L
s
.55304 1.18733 m
.55369 1.19126 L
s
.562 1.1434 m
.56233 1.1479 L
s
.55161 1.09567 m .55688 1.10355 L .56127 1.14251 L 0 .738 .197 r
F
0 g
.55226 1.14249 m
.55336 1.15406 L
s
.55152 1.13976 m
.55316 1.15323 L
s
.55075 1.14038 m
.55176 1.15049 L
s
.55082 1.12747 m
.55226 1.14249 L
s
.54821 1.08524 m
.55161 1.09567 L
s
.55493 1.0724 m
.55688 1.10355 L
s
.55276 1.08365 m
.55688 1.10355 L
s
.52417 .86304 m .51914 .85002 L .51898 .8539 L 0 .537 .374 r
F
0 g
.51798 .85346 m
.51898 .8539 L
s
.65304 .7033 m .66991 .68761 L .65877 .69054 L 0 1 .438 r
F
0 g
.66991 .68761 m
.67629 .68907 L
s
.66991 .68761 m
.68019 .68201 L
s
.68557 .87137 m .70115 .8599 L .69422 .85818 L 0 1 .449 r
F
0 g
.70115 .8599 m
.70911 .85786 L
s
.70115 .8599 m
.70356 .86477 L
s
.63322 .63687 m .64571 .64397 L .65674 .64787 L 0 1 .514 r
F
0 g
.64571 .64397 m
.65339 .65061 L
s
.36567 .74987 m .35901 .74253 L .35348 .74647 L 0 1 .532 r
F
0 g
.34646 .7469 m
.35348 .74647 L
s
.36567 .74987 m .36919 .74018 L .35901 .74253 L 0 1 .532 r
F
.36567 .74987 m .37863 .74068 L .36919 .74018 L F
.36567 .74987 m .38099 .74369 L .37863 .74068 L F
.36567 .74987 m .37542 .74763 L .38099 .74369 L F
0 g
.36046 .75359 m
.36567 .74987 L
s
.35627 .74937 m
.36567 .74987 L
s
.46247 .91899 m .45839 .9014 L .45507 .90394 L 0 .513 .361 r
F
0 g
.44929 .8968 m
.45507 .90394 L
s
.34498 .86914 m .33369 .856 L .33724 .85862 L 0 0 .112 r
F
.36554 .75507 m .35342 .74868 L .35619 .75247 L 0 1 .485 r
F
0 g
.35156 .75524 m
.35619 .75247 L
s
.62415 1.07871 m
.62504 1.05941 L
s
.62519 1.05614 m
.62557 1.04807 L
s
.62557 1.04807 m
.62563 1.04683 L
s
.62563 1.04683 m
.62568 1.04574 L
s
.62568 1.04574 m
.62581 1.04284 L
s
.62581 1.04284 m
.62722 1.01242 L
s
.47504 .97237 m .47559 .9603 L .47079 .95488 L 0 .246 .287 r
F
.47504 .97237 m .48022 .96994 L .47559 .9603 L F
.47504 .97237 m .48158 .97736 L .48022 .96994 L F
.47504 .97237 m .47936 .97839 L .48158 .97736 L F
0 g
.47043 .96275 m
.47504 .97237 L
s
.4732 .97257 m
.47504 .97237 L
s
.64169 .73159 m .63801 .72412 L .63588 .73009 L 0 1 .41 r
F
.64169 .73159 m .64735 .71692 L .63801 .72412 L F
.65114 .94593 m .65636 .94179 L .66279 .93295 L 0 1 .26 r
F
0 g
.6593 .9424 m
.66357 .93239 L
s
.66279 .93295 m
.66357 .93239 L
s
.32833 .85246 m
.32948 .85194 L
s
.32948 .85194 m
.33368 .85599 L
s
.68815 .66621 m
.68819 .66622 L
s
.68819 .66622 m
.68934 .66648 L
s
.30907 .92997 m .3039 .92667 L .29864 .92586 L 0 .619 .246 r
F
.30907 .92997 m .31089 .92803 L .3039 .92667 L F
.30907 .92997 m .31492 .92904 L .31089 .92803 L F
.30907 .92997 m .31413 .92987 L .31492 .92904 L F
0 g
.30212 .92861 m
.30907 .92997 L
s
.53789 .90804 m .53451 .8918 L .53384 .89593 L 0 .341 .314 r
F
0 g
.53206 .89439 m
.53384 .89593 L
s
.31951 .73532 m .30629 .73258 L .30949 .73565 L 0 1 .527 r
F
0 g
.3091 .73612 m
.30949 .73565 L
s
.46912 .792 m
.47626 .7967 L
s
.62168 1.20796 m
.62171 1.21054 L
s
.62121 1.17426 m
.62168 1.20796 L
s
.62305 1.30745 m
.62317 1.3161 L
s
.67638 .86858 m
.67642 .86845 L
s
.45839 .9014 m .45077 .88749 L .45247 .89396 L 0 .597 .374 r
F
0 g
.44929 .89679 m
.45247 .89396 L
s
.65902 .92381 m .67285 .90429 L .66698 .90541 L 0 1 .328 r
F
0 g
.67285 .90429 m
.6798 .89925 L
s
.67285 .90429 m
.67468 .90828 L
s
.2566 .81766 m .24369 .81498 L .24769 .81729 L 0 .987 .489 r
F
0 g
.24563 .82132 m
.24769 .81729 L
s
.53003 .88183 m
.53428 .8846 L
s
.72039 .8242 m .73703 .82718 L .74077 .82346 L 0 1 .494 r
F
.72039 .8242 m .7283 .8275 L .73703 .82718 L F
0 g
.73703 .82718 m
.73936 .83225 L
s
.55729 1.02945 m
.55745 1.03079 L
s
.5571 1.02783 m
.55729 1.02945 L
s
.55439 1.00484 m
.55472 1.00761 L
s
.55495 1.00961 m
.55576 1.01649 L
s
.55675 1.02482 m
.5571 1.02783 L
s
.55378 1.00573 m
.55439 1.00484 L
s
.68937 .66754 m
.7 .6737 L
s
.68821 .66628 m
.68937 .66754 L
s
.68815 .66621 m
.68821 .66628 L
s
.68218 .65967 m
.68815 .66621 L
s
.45839 .9014 m .45448 .88484 L .45077 .88749 L 0 .597 .374 r
F
0 g
.44473 .88097 m
.45077 .88749 L
s
.42993 .7675 m .41958 .76146 L .42146 .76442 L 0 1 .511 r
F
0 g
.4161 .76661 m
.42146 .76442 L
s
.67139 1.24849 m .66956 1.23265 L .67128 1.21302 L 0 .233 .136 r
F
0 g
.66956 1.23265 m
.67128 1.21302 L
s
.66636 1.20994 m
.67128 1.21302 L
s
.50032 .59855 m .4895 .59388 L .48986 .59602 L 0 1 .524 r
F
.50032 .59855 m .49981 .59321 L .4895 .59388 L F
0 g
.48003 .59772 m
.48978 .59603 L
s
.48978 .59603 m
.48986 .59602 L
s
.50032 .59855 m .51394 .59448 L .49981 .59321 L 0 1 .524 r
F
.50032 .59855 m .52441 .59702 L .51394 .59448 L F
.50032 .59855 m .52423 .59913 L .52441 .59702 L F
.50032 .59855 m .51391 .59978 L .52423 .59913 L F
0 g
.49041 .59915 m
.50032 .59855 L
s
.48986 .59602 m
.50032 .59855 L
s
.51391 .59978 m
.52397 .60221 L
s
.41334 .80706 m .4067 .79045 L .40207 .79497 L 0 .875 .439 r
F
0 g
.39361 .78947 m
.40207 .79497 L
s
.63322 .63687 m .62691 .62815 L .62516 .63009 L 0 1 .514 r
F
.63322 .63687 m .63796 .63205 L .62691 .62815 L F
.63322 .63687 m .65093 .6392 L .63796 .63205 L F
.63322 .63687 m .65898 .64598 L .65093 .6392 L F
.63322 .63687 m .65674 .64787 L .65898 .64598 L F
0 g
.64571 .64397 m
.65674 .64787 L
s
.62254 .6329 m
.63322 .63687 L
s
.65674 .64787 m
.66395 .65574 L
s
.62844 .94602 m
.6285 .94645 L
s
.6268 .93549 m
.62844 .94602 L
s
.31963 .73162 m .32245 .72151 L .31191 .72411 L 0 1 .515 r
F
.31963 .73162 m .33248 .72211 L .32245 .72151 L F
.31963 .73162 m .33529 .72551 L .33248 .72211 L F
.31963 .73162 m .32977 .72959 L .33529 .72551 L F
0 g
.30965 .73101 m
.31963 .73162 L
s
.31556 .7345 m
.31963 .73162 L
s
.49508 1.02905 m .49203 1.0197 L .49046 1.01662 L 0 0 .106 r
F
0 g
.48691 1.00871 m
.49046 1.01662 L
s
.49508 1.02905 m .4955 1.02769 L .49203 1.0197 L 0 0 .106 r
F
.49508 1.02905 m .49964 1.03977 L .49877 1.0363 L F
.49508 1.02905 m .49805 1.03665 L .49964 1.03977 L F
0 g
.49183 1.02048 m
.49508 1.02905 L
s
.57558 1.12364 m
.57571 1.12485 L
s
.69422 .85818 m .71017 .84838 L .70291 .84607 L 0 1 .466 r
F
0 g
.71017 .84838 m
.71281 .85343 L
s
.71017 .84838 m
.71838 .847 L
s
.47079 .95488 m .47183 .94142 L .46655 .93668 L 0 .313 .323 r
F
0 g
.46398 .93844 m
.46655 .93668 L
s
.47079 .95488 m .47682 .9508 L .47183 .94142 L 0 .313 .323 r
F
.47079 .95488 m .47818 .95856 L .47682 .9508 L F
.47079 .95488 m .47559 .9603 L .47818 .95856 L F
0 g
.46582 .94552 m
.47079 .95488 L
s
.46859 .95594 m
.47079 .95488 L
s
.52417 .86304 m .52492 .85275 L .51914 .85002 L 0 .537 .374 r
F
0 g
.51358 .84226 m
.51914 .85002 L
s
.52417 .86304 m .53249 .8603 L .52492 .85275 L 0 .537 .374 r
F
.52417 .86304 m .53769 .86947 L .53249 .8603 L F
.52417 .86304 m .53706 .87413 L .53769 .86947 L F
.52417 .86304 m .53126 .87137 L .53706 .87413 L F
0 g
.51875 .85952 m
.52417 .86304 L
s
.51898 .8539 m
.52417 .86304 L
s
.45448 .88484 m .44652 .87158 L .44822 .87791 L 0 .667 .384 r
F
0 g
.44473 .88097 m
.44822 .87791 L
s
.76815 .80657 m .76898 .79745 L .7652 .80075 L 0 1 .516 r
F
.76815 .80657 m .7778 .79863 L .76898 .79745 L F
.2882 .92133 m .27668 .91677 L .28093 .91883 L 0 .438 .229 r
F
0 g
.28076 .92033 m
.28093 .91883 L
s
.72039 .8242 m .74077 .82346 L .73742 .81788 L 0 1 .494 r
F
0 g
.74077 .82346 m
.74893 .82333 L
s
.31826 .84619 m .31017 .84185 L .31387 .84369 L 0 .153 .165 r
F
.50557 .82672 m .49897 .81605 L .4993 .81964 L 0 .72 .426 r
F
0 g
.49359 .81866 m
.4993 .81964 L
s
.42993 .7675 m .4256 .75985 L .41958 .76146 L 0 1 .511 r
F
.42993 .7675 m .43554 .76066 L .4256 .75985 L F
.42993 .7675 m .44404 .76375 L .43554 .76066 L F
.42993 .7675 m .44543 .76706 L .44404 .76375 L F
.42993 .7675 m .43937 .76867 L .44543 .76706 L F
0 g
.42146 .76442 m
.42993 .7675 L
s
.3364 .86025 m .32476 .85036 L .32834 .85246 L 0 .008 .161 r
F
.3364 .86025 m .3354 .85849 L .33063 .85502 L F
.3364 .86025 m .32777 .85293 L .32476 .85036 L F
.3364 .86025 m .33063 .85502 L .32777 .85293 L F
.3406 .86404 m .3364 .86025 L .33369 .856 L 0 0 .112 r
F
.34498 .86914 m .3364 .86025 L .3406 .86404 L F
0 g
.33369 .856 m
.33517 .85832 L
s
.36554 .75507 m .35894 .74523 L .35342 .74868 L 0 1 .485 r
F
0 g
.34701 .74704 m
.35342 .74868 L
s
.61811 .81118 m .61652 .79581 L .61396 .80657 L 0 1 .345 r
F
.61298 .83461 m .61811 .81119 L .61059 .82162 L 0 1 .328 r
F
.45448 .88484 m .45056 .86867 L .44652 .87158 L 0 .667 .384 r
F
0 g
.44016 .86546 m
.44652 .87158 L
s
.41334 .80706 m .41572 .79098 L .4067 .79045 L 0 .875 .439 r
F
0 g
.40207 .79497 m
.4067 .79045 L
s
.41334 .80706 m .4242 .79652 L .41572 .79098 L 0 .875 .439 r
F
.41334 .80706 m .42646 .80339 L .4242 .79652 L F
.41334 .80706 m .4218 .8079 L .42646 .80339 L F
0 g
.40489 .80152 m
.41334 .80706 L
s
.46655 .93668 m .46822 .92308 L .46247 .91899 L 0 .414 .346 r
F
.46655 .93668 m .47351 .9318 L .46822 .92308 L F
.46655 .93668 m .47482 .93934 L .47351 .9318 L F
.46655 .93668 m .47183 .94142 L .47482 .93934 L F
0 g
.46127 .92797 m
.46655 .93668 L
s
.2566 .81766 m .24682 .81147 L .24369 .81498 L 0 .987 .489 r
F
0 g
.23545 .81582 m
.24369 .81498 L
s
.64735 .71692 m .64337 .70993 L .64122 .71548 L 0 1 .424 r
F
.64735 .71692 m .65304 .7033 L .64337 .70993 L F
0 g
.56282 1.22424 m
.56325 1.22582 L
s
.56216 1.22178 m
.56282 1.22424 L
s
.55968 1.21358 m
.56002 1.21456 L
s
.50437 1.04931 m .50095 1.04276 L .50182 1.04329 L 0 .474 0 r
F
0 g
.50061 1.03873 m
.50182 1.04329 L
s
.31951 .73532 m .31179 .72763 L .30629 .73258 L 0 1 .527 r
F
0 g
.2967 .73335 m
.30629 .73258 L
s
.60111 .62176 m .6141 .62735 L .62516 .63009 L 0 1 .52 r
F
0 g
.6141 .62735 m
.62254 .6329 L
s
.50437 1.04931 m .50257 1.04905 L .50095 1.04276 L 0 .474 0 r
F
.50437 1.04931 m .50562 1.05799 L .50257 1.04905 L F
.50437 1.04931 m .50819 1.06404 L .50607 1.05905 L F
.50437 1.04931 m .50607 1.05905 L .50557 1.05761 L F
.50437 1.04931 m .50854 1.06313 L .50819 1.06404 L F
.50258 1.04906 m .5073 1.05983 L .50435 1.0505 L 0 0 .107 r
F
.50257 1.04905 m .5026 1.04912 L .50258 1.04906 L F
.5026 1.04912 m .5073 1.05983 L .50258 1.04906 L F
.50557 1.05761 m .50607 1.05905 L .50562 1.05799 L 0 .474 0 r
F
.50437 1.04931 m .5069 1.05681 L .50854 1.06313 L F
0 g
.50182 1.04329 m
.50437 1.04931 L
s
.50312 1.04158 m
.50437 1.04931 L
s
.56369 1.03436 m
.56418 1.04016 L
s
.45492 .59418 m
.46473 .59247 L
s
.44397 .59365 m
.45492 .59418 L
s
.41106 .7595 m
.41958 .76146 L
s
.26636 .82367 m .26451 .81582 L .2566 .81766 L 0 .919 .472 r
F
.26636 .82367 m .27325 .81654 L .26451 .81582 L F
.26636 .82367 m .27695 .81935 L .27325 .81654 L F
.26636 .82367 m .27398 .8224 L .27695 .81935 L F
0 g
.25768 .82294 m
.26636 .82367 L
s
.26367 .8262 m
.26636 .82367 L
s
.53789 .90804 m .53991 .89678 L .53451 .8918 L 0 .341 .314 r
F
0 g
.53003 .88183 m
.53451 .8918 L
s
.51635 1.06951 m .51511 1.07803 L .51494 1.07055 L 0 .785 .089 r
F
0 g
.51328 1.06058 m
.51494 1.07055 L
s
.51635 1.06951 m .51717 1.09078 L .51511 1.07803 L 0 .785 .089 r
F
.51635 1.06951 m .51975 1.10028 L .51717 1.09078 L F
.51635 1.06951 m .52116 1.0992 L .51975 1.10028 L F
.51635 1.06951 m .52046 1.08827 L .52116 1.0992 L F
.51635 1.06951 m .51839 1.07557 L .52046 1.08827 L F
0 g
.51941 1.06967 m
.52119 1.08277 L
s
.51839 1.07557 m
.51941 1.06967 L
s
.51613 1.06785 m
.51635 1.06951 L
s
.51494 1.07055 m
.51635 1.06951 L
s
.62472 1.10789 m
.62473 1.068 L
s
.62473 1.068 m
.62473 1.06706 L
s
.62473 1.06706 m
.62473 1.06693 L
s
.62473 1.06693 m
.62473 1.06612 L
s
.31826 .84619 m .30911 .8411 L .31017 .84185 L 0 .153 .165 r
F
.31826 .84619 m .3114 .84196 L .30911 .8411 L F
0 g
.30234 .83995 m
.30937 .84165 L
s
.30937 .84165 m
.31017 .84184 L
s
.31826 .84619 m .31581 .84446 L .3114 .84196 L 0 .153 .165 r
F
.31826 .84619 m .31938 .84693 L .31581 .84446 L F
0 g
.31829 .84618 m
.31943 .84568 L
s
.31826 .84619 m .32043 .84767 L .31938 .84693 L 0 .153 .165 r
F
0 g
.62883 1.35503 m
.62906 1.37259 L
s
.62844 1.32633 m
.62883 1.35503 L
s
.46247 .91899 m .4646 .90487 L .45839 .9014 L 0 .513 .361 r
F
0 g
.45507 .90394 m
.45839 .9014 L
s
.46247 .91899 m .47025 .91309 L .4646 .90487 L 0 .513 .361 r
F
.46247 .91899 m .47155 .92055 L .47025 .91309 L F
.46247 .91899 m .46822 .92308 L .47155 .92055 L F
0 g
.45684 .91079 m
.46247 .91899 L
s
.4595 .92109 m
.46247 .91899 L
s
.61972 .88071 m .61894 .8639 L .61666 .87668 L 0 1 .26 r
F
0 g
.61666 .87668 m
.61972 .88071 L
s
.61894 .8639 m
.62046 .86041 L
s
.61326 .89756 m
.61485 .89341 L
s
.61485 .89341 m
.61574 .8911 L
s
.61574 .8911 m
.61649 .88912 L
s
.61649 .88912 m
.61972 .88071 L
s
.50557 .82672 m .50511 .81736 L .49897 .81605 L 0 .72 .426 r
F
.50557 .82672 m .51363 .82271 L .50511 .81736 L F
.50557 .82672 m .51991 .82981 L .51363 .82271 L F
.50557 .82672 m .51976 .83392 L .51991 .82981 L F
.50557 .82672 m .5136 .83259 L .51976 .83392 L F
0 g
.4998 .82493 m
.50557 .82672 L
s
.4993 .81964 m
.50557 .82672 L
s
.45056 .86867 m .44227 .85609 L .44397 .86223 L 0 .728 .394 r
F
0 g
.44016 .86546 m
.44397 .86223 L
s
.2882 .92133 m .27776 .9162 L .27668 .91677 L 0 .438 .229 r
F
0 g
.27001 .91524 m
.27668 .91677 L
s
.54637 .95978 m .54474 .94198 L .54353 .94451 L 0 .195 .235 r
F
0 g
.54026 .93854 m
.54353 .94451 L
s
.31191 .72411 m .29839 .72113 L .30161 .72395 L 0 1 .52 r
F
0 g
.29941 .72606 m
.30161 .72395 L
s
.45757 .7814 m .44774 .77251 L .44944 .77646 L 0 .989 .491 r
F
0 g
.44406 .77818 m
.44944 .77646 L
s
.34452 .73916 m
.34457 .73917 L
s
.34439 .73914 m
.34452 .73916 L
s
.33847 .73809 m
.34439 .73914 L
s
.61519 .85726 m
.61894 .8639 L
s
.70291 .84607 m .71922 .83763 L .71163 .83479 L 0 1 .478 r
F
0 g
.71922 .83763 m
.7221 .84286 L
s
.71922 .83763 m
.72769 .83681 L
s
.65114 .94593 m .66457 .92136 L .65902 .92381 L 0 1 .26 r
F
0 g
.66457 .92136 m
.67127 .9147 L
s
.66457 .92136 m
.66618 .92527 L
s
.65775 .94603 m
.6593 .9424 L
s
.66007 .93668 m
.66279 .93295 L
s
.56335 1.2331 m
.56348 1.23377 L
s
.55985 1.21526 m
.56021 1.2171 L
s
.56021 1.2171 m
.56062 1.21917 L
s
.56257 1.22913 m
.56265 1.22954 L
s
.56265 1.22954 m
.56287 1.23064 L
s
.56291 1.23084 m
.56335 1.2331 L
s
.70635 1.15418 m .71359 1.12611 L .70948 1.14028 L 0 .962 .123 r
F
.70459 1.12903 m .70948 1.14028 L .71359 1.12611 L 0 1 .226 r
F
0 g
.71359 1.12611 m
.71369 1.12521 L
s
.71359 1.12611 m
.71367 1.12595 L
s
.60111 .62176 m .59353 .61407 L .59229 .61607 L 0 1 .52 r
F
.60111 .62176 m .60459 .6168 L .59353 .61407 L F
.60111 .62176 m .6181 .62245 L .60459 .6168 L F
.60111 .62176 m .62691 .62815 L .6181 .62245 L F
.60111 .62176 m .62516 .63009 L .62691 .62815 L F
0 g
.6141 .62735 m
.62516 .63009 L
s
.59043 .61898 m
.60111 .62176 L
s
.62516 .63009 m
.63322 .63687 L
s
.66358 1.1308 m .66758 1.04526 L .66377 1.06431 L 0 .907 .239 r
F
.66358 1.1308 m .67294 1.06988 L .66758 1.04526 L F
0 g
.66167 1.03999 m
.66377 1.06431 L
s
.66724 .98552 m
.66758 1.04526 L
s
.36554 .75507 m .3691 .74441 L .35894 .74523 L 0 1 .485 r
F
.36554 .75507 m .37849 .74701 L .3691 .74441 L F
.36554 .75507 m .38083 .7513 L .37849 .74701 L F
.36554 .75507 m .37527 .75475 L .38083 .7513 L F
0 g
.36034 .75833 m
.36554 .75507 L
s
.35619 .75247 m
.36554 .75507 L
s
.4067 .79045 m .39592 .7813 L .39822 .7863 L 0 .926 .45 r
F
0 g
.39361 .78947 m
.39822 .7863 L
s
.45757 .7814 m .4538 .77117 L .44774 .77251 L 0 .989 .491 r
F
.45757 .7814 m .46358 .77335 L .4538 .77117 L F
.45757 .7814 m .47174 .7783 L .46358 .77335 L F
.45757 .7814 m .47281 .78272 L .47174 .7783 L F
.45757 .7814 m .46673 .78404 L .47281 .78272 L F
0 g
.44944 .77646 m
.45757 .7814 L
s
.72917 .81415 m .74639 .818 L .75014 .81444 L 0 1 .5 r
F
.72917 .81415 m .73742 .81788 L .74639 .818 L F
0 g
.74639 .818 m
.74893 .82333 L
s
.53789 .90804 m .54647 .90757 L .53991 .89678 L 0 .341 .314 r
F
.53789 .90804 m .55054 .91973 L .54647 .90757 L F
.53789 .90804 m .54939 .92511 L .55054 .91973 L F
.53789 .90804 m .54396 .92009 L .54939 .92511 L F
0 g
.53285 .90145 m
.53789 .90804 L
s
.53384 .89593 m
.53789 .90804 L
s
.53426 .60269 m .52441 .59702 L .52423 .59913 L 0 1 .522 r
F
0 g
.51391 .59978 m
.52423 .59913 L
s
.53426 .60269 m .5351 .59745 L .52441 .59702 L 0 1 .522 r
F
.53426 .60269 m .54919 .60015 L .5351 .59745 L F
.53426 .60269 m .55922 .60372 L .54919 .60015 L F
.53426 .60269 m .55851 .60578 L .55922 .60372 L F
.53426 .60269 m .54781 .60534 L .55851 .60578 L F
0 g
.54781 .60534 m
.55745 .60878 L
s
.52397 .60221 m
.53426 .60269 L
s
.52423 .59913 m
.53426 .60269 L
s
.4924 .81005 m
.49897 .81605 L
s
.45056 .86867 m .44664 .85298 L .44227 .85609 L 0 .728 .394 r
F
0 g
.43559 .85032 m
.44227 .85609 L
s
.29289 .83467 m
.29541 .83274 L
s
.31951 .73532 m .32237 .72409 L .31179 .72763 L 0 1 .527 r
F
.31951 .73532 m .33244 .72375 L .32237 .72409 L F
.31951 .73532 m .33525 .72684 L .33244 .72375 L F
.31951 .73532 m .3297 .7318 L .33525 .72684 L F
0 g
.3143 .74027 m
.31951 .73532 L
s
.30949 .73565 m
.31951 .73532 L
s
.45839 .9014 m .46114 .88777 L .45448 .88484 L 0 .597 .374 r
F
.45839 .9014 m .46708 .89523 L .46114 .88777 L F
.45839 .9014 m .46833 .90223 L .46708 .89523 L F
.45839 .9014 m .4646 .90487 L .46833 .90223 L F
0 g
.45247 .89396 m
.45839 .9014 L
s
.65745 .94513 m
.65775 .94603 L
s
.54743 .9758 m
.548 .97792 L
s
.548 .97792 m
.5495 .98354 L
s
.54145 .93014 m
.54414 .93369 L
s
.55076 .99009 m
.55197 .99635 L
s
.65877 .69054 m .6761 .67595 L .66452 .67852 L 0 1 .45 r
F
0 g
.6761 .67595 m
.6828 .67745 L
s
.6761 .67595 m
.68672 .67079 L
s
.56799 .6104 m .58135 .6145 L .59229 .61607 L 0 1 .521 r
F
0 g
.58135 .6145 m
.59043 .61898 L
s
.39608 .75272 m .38453 .74813 L .38688 .75104 L 0 1 .526 r
F
0 g
.38164 .75476 m
.38688 .75104 L
s
.56799 .6104 m .55922 .60372 L .55851 .60578 L 0 1 .521 r
F
0 g
.54781 .60534 m
.55851 .60578 L
s
.56799 .6104 m .57017 .60529 L .55922 .60372 L 0 1 .521 r
F
.56799 .6104 m .58405 .60944 L .57017 .60529 L F
.56799 .6104 m .59353 .61407 L .58405 .60944 L F
.56799 .6104 m .59229 .61607 L .59353 .61407 L F
0 g
.55851 .60578 m
.56799 .6104 L
s
.55745 .60878 m
.56799 .6104 L
s
.59229 .61607 m
.60111 .62176 L
s
.58135 .6145 m
.59229 .61607 L
s
.33701 .73947 m
.34209 .73468 L
s
.33701 .73947 m
.34439 .73914 L
s
.35901 .74253 m .34648 .73905 L .34928 .74205 L 0 1 .53 r
F
0 g
.3488 .74253 m
.34928 .74205 L
s
.72917 .81415 m .75014 .81444 L .74656 .80869 L 0 1 .5 r
F
0 g
.75014 .81444 m
.75853 .81479 L
s
.45448 .88484 m .45767 .87112 L .45056 .86867 L 0 .667 .384 r
F
.45448 .88484 m .46394 .87806 L .45767 .87112 L F
.45448 .88484 m .4652 .88487 L .46394 .87806 L F
.45448 .88484 m .46114 .88777 L .4652 .88487 L F
0 g
.44822 .87791 m
.45448 .88484 L
s
.45077 .88749 m
.45448 .88484 L
s
.29864 .92586 m .29367 .92261 L .2882 .92133 L 0 .498 .229 r
F
.29864 .92586 m .30082 .92468 L .29367 .92261 L F
.29864 .92586 m .30485 .92616 L .30082 .92468 L F
.29864 .92586 m .3039 .92667 L .30485 .92616 L F
0 g
.29153 .9238 m
.29864 .92586 L
s
.29789 .92669 m
.29864 .92586 L
s
.44664 .85298 m .438 .84107 L .43971 .84701 L 0 .783 .403 r
F
0 g
.43559 .85032 m
.43971 .84701 L
s
.60688 .77313 m .62527 .76304 L .62738 .75599 L 0 1 .396 r
F
0 g
.62359 .77253 m
.63046 .76498 L
s
.60688 .77313 m .6165 .77038 L .62527 .76304 L 0 1 .396 r
F
0 g
.62527 .76304 m
.62757 .7639 L
s
.4067 .79045 m .40128 .77771 L .39592 .7813 L 0 .926 .45 r
F
0 g
.38752 .77715 m
.39592 .7813 L
s
.49203 1.0197 m .48704 1.00395 L .4884 1.00954 L 0 .01 .156 r
F
0 g
.48691 1.00871 m
.4884 1.00954 L
s
.60242 .79238 m .62211 .77415 L .6165 .77038 L 0 1 .381 r
F
0 g
.61858 .79298 m
.62489 .78429 L
s
.60242 .79238 m .62002 .78192 L .62211 .77415 L 0 1 .381 r
F
0 g
.62211 .77415 m
.62359 .77253 L
s
.27776 .9162 m .26607 .91137 L .27032 .91357 L 0 .429 .235 r
F
0 g
.27001 .91524 m
.27032 .91357 L
s
.60688 .77313 m .62738 .75599 L .62143 .75275 L 0 1 .396 r
F
0 g
.61713 .77081 m
.62211 .77415 L
s
.62418 .76395 m
.62527 .76304 L
s
.62738 .75599 m
.63605 .74752 L
s
.35894 .74523 m .34647 .73951 L .34925 .74313 L 0 1 .493 r
F
0 g
.35348 .74647 m
.35609 .74461 L
s
.34623 .74511 m
.34925 .74313 L
s
.60242 .79238 m .61158 .78973 L .62002 .78192 L 0 1 .381 r
F
0 g
.61853 .7833 m
.62002 .78192 L
s
.62002 .78192 m
.62391 .78381 L
s
.57709 1.05953 m
.57775 1.07657 L
s
.57838 1.09299 m
.57962 1.12537 L
s
.57962 1.12537 m
.58139 1.17127 L
s
.57705 1.05852 m
.57709 1.05953 L
s
.54465 1.10069 m
.54494 1.10531 L
s
.32935 .85344 m
.33207 .85607 L
s
.32834 .85246 m
.32935 .85344 L
s
.50693 1.05684 m
.50908 1.05882 L
s
.5069 1.05681 m
.50693 1.05684 L
s
.70459 1.12903 m .71094 1.09429 L .70687 1.10875 L 0 1 .226 r
F
.70002 1.07958 m .70687 1.10875 L .71094 1.09429 L 0 1 .267 r
F
0 g
.71094 1.09429 m
.71478 1.0931 L
s
.71094 1.09429 m
.71234 1.06809 L
s
.65304 .7033 m .64876 .69665 L .6466 .70186 L 0 1 .438 r
F
.65304 .7033 m .65877 .69054 L .64876 .69665 L F
.31191 .72411 m .30415 .71669 L .29839 .72113 L 0 1 .52 r
F
0 g
.28855 .72186 m
.29839 .72113 L
s
.44664 .85298 m .44271 .83783 L .438 .84107 L 0 .783 .403 r
F
0 g
.431 .83564 m
.438 .84107 L
s
.39608 .75272 m .39054 .74527 L .38453 .74813 L 0 1 .526 r
F
0 g
.37893 .74783 m
.38453 .74813 L
s
.39608 .75272 m .40093 .74436 L .39054 .74527 L 0 1 .526 r
F
.39608 .75272 m .41016 .74605 L .40093 .74436 L F
.39608 .75272 m .41205 .74921 L .41016 .74605 L F
.39608 .75272 m .406 .75206 L .41205 .74921 L F
0 g
.39041 .75528 m
.39608 .75272 L
s
.38688 .75104 m
.39608 .75272 L
s
.65898 .64598 m
.66988 .65104 L
s
.65093 .6392 m
.65898 .64598 L
s
.71163 .83479 m .7283 .8275 L .72039 .8242 L 0 1 .487 r
F
0 g
.7283 .8275 m
.73142 .8329 L
s
.7283 .8275 m
.73703 .82718 L
s
.56156 1.14287 m
.56233 1.1479 L
s
.61136 .7555 m .63056 .74586 L .63268 .7394 L 0 1 .411 r
F
.61136 .7555 m .62143 .75275 L .63056 .74586 L F
0 g
.63056 .74586 m
.63605 .74752 L
s
.48232 .79726 m .47423 .78851 L .47504 .79181 L 0 .892 .467 r
F
0 g
.46912 .792 m
.47504 .79181 L
s
.45056 .86867 m .45419 .855 L .44664 .85298 L 0 .728 .394 r
F
.45056 .86867 m .46081 .86145 L .45419 .855 L F
.45056 .86867 m .46206 .86803 L .46081 .86145 L F
.45056 .86867 m .45767 .87112 L .46206 .86803 L F
0 g
.44397 .86223 m
.45056 .86867 L
s
.44652 .87158 m
.45056 .86867 L
s
.31179 .72763 m .29826 .72497 L .30147 .72801 L 0 1 .527 r
F
0 g
.30644 .72818 m
.30694 .72781 L
s
.30069 .72888 m
.30147 .72801 L
s
.52492 .85275 m .51953 .84003 L .51937 .84407 L 0 .648 .392 r
F
0 g
.51358 .84226 m
.51937 .84407 L
s
.4067 .79045 m .41075 .77794 L .40128 .77771 L 0 .926 .45 r
F
.4067 .79045 m .41927 .78209 L .41075 .77794 L F
.4067 .79045 m .42111 .78739 L .41927 .78209 L F
.4067 .79045 m .41572 .79097 L .42111 .78739 L F
0 g
.39822 .7863 m
.4067 .79045 L
s
.59698 .81873 m .61652 .79581 L .61158 .78973 L 0 1 .364 r
F
.59698 .81873 m .61396 .80657 L .61652 .79581 L F
0 g
.6141 .80673 m
.61811 .81118 L
s
.61652 .79581 m
.61858 .79298 L
s
.53991 .89677 m .53611 .88095 L .53548 .88538 L 0 .477 .338 r
F
0 g
.53428 .8846 m
.53548 .88538 L
s
.53126 .87137 m
.53631 .87377 L
s
.27776 .9162 m .26731 .91053 L .26607 .91137 L 0 .429 .235 r
F
0 g
.25926 .9099 m
.26607 .91137 L
s
.61298 .83461 m .61059 .82162 L .60866 .83093 L 0 1 .328 r
F
0 g
.60576 .84577 m
.60806 .84221 L
s
.61136 .7555 m .63268 .7394 L .6264 .73655 L 0 1 .411 r
F
0 g
.62302 .75362 m
.62738 .75599 L
s
.63268 .7394 m
.64169 .73159 L
s
.73799 .80457 m .75578 .80921 L .75955 .80579 L 0 1 .505 r
F
.73799 .80457 m .74656 .80869 L .75578 .80921 L F
0 g
.75578 .80921 m
.75853 .81479 L
s
.43937 .76867 m
.44774 .77251 L
s
.49203 1.0197 m .48899 1.00565 L .48704 1.00395 L 0 .01 .156 r
F
0 g
.48313 .99489 m
.48704 1.00395 L
s
.48232 .79726 m .48064 .7887 L .47423 .78851 L 0 .892 .467 r
F
.48232 .79726 m .49003 .79228 L .48064 .7887 L F
.48232 .79726 m .49733 .79774 L .49003 .79228 L F
.48232 .79726 m .49766 .80144 L .49733 .79774 L F
.48232 .79726 m .49122 .80123 L .49766 .80144 L F
0 g
.47626 .7967 m
.48232 .79726 L
s
.47504 .79181 m
.48232 .79726 L
s
.51839 1.07557 m
.51869 1.07737 L
s
.67499 .88954 m .68557 .87137 L .67753 .87631 L 0 1 .419 r
F
0 g
.67513 .87262 m
.67566 .87093 L
s
.67566 .87093 m
.67638 .86858 L
s
.68557 .87137 m .68649 .86101 L .68313 .8665 L 0 1 .449 r
F
.68557 .87137 m .69422 .85818 L .68649 .86101 L F
0 g
.68313 .8665 m
.68557 .87137 L
s
.35901 .74253 m .35233 .73496 L .34648 .73905 L 0 1 .53 r
F
0 g
.34439 .73914 m
.34648 .73905 L
s
.35901 .74253 m .36295 .73251 L .35233 .73496 L 0 1 .53 r
F
.35901 .74253 m .37271 .73299 L .36295 .73251 L F
.35901 .74253 m .37508 .73609 L .37271 .73299 L F
.35901 .74253 m .36919 .74018 L .37508 .73609 L F
0 g
.35234 .7422 m
.35901 .74253 L
s
.35668 .74419 m
.35901 .74253 L
s
.31938 .84693 m
.32043 .84767 L
s
.32043 .84767 m
.32475 .85036 L
s
.54637 .95978 m .54976 .95234 L .54474 .94198 L 0 .195 .235 r
F
0 g
.54145 .93014 m
.54474 .94198 L
s
.44271 .83783 m .43373 .82658 L .43544 .83231 L 0 .833 .412 r
F
0 g
.431 .83564 m
.43544 .83231 L
s
.5541 1.01114 m
.55505 1.01604 L
s
.55322 1.00656 m
.5541 1.01114 L
s
.6538 .95697 m
.65441 .9558 L
s
.49805 1.03665 m
.49822 1.03698 L
s
.49805 1.03665 m
.50095 1.04276 L
s
.67499 .88954 m .67753 .87631 L .67342 .8839 L 0 1 .419 r
F
0 g
.67342 .8839 m
.67408 .88627 L
s
.67408 .88627 m
.67499 .88954 L
s
.67753 .87631 m
.68557 .87137 L
s
.66698 .90541 m .67499 .88955 L .66801 .89459 L 0 1 .381 r
F
0 g
.67034 .89291 m
.67347 .89064 L
s
.67347 .89064 m
.67499 .88955 L
s
.44774 .77251 m
.4538 .77117 L
s
.31191 .72411 m .3151 .71357 L .30415 .71669 L 0 1 .52 r
F
.31191 .72411 m .32545 .71373 L .3151 .71357 L F
.31191 .72411 m .32827 .71706 L .32545 .71373 L F
.31191 .72411 m .32245 .72151 L .32827 .71706 L F
0 g
.30161 .72395 m
.31191 .72411 L
s
.30814 .72691 m
.31191 .72411 L
s
.2566 .81766 m .25503 .80909 L .24682 .81147 L 0 .987 .489 r
F
0 g
.24369 .81498 m
.24682 .81147 L
s
.2566 .81766 m .264 .80945 L .25503 .80909 L 0 .987 .489 r
F
.2566 .81766 m .2677 .8123 L .264 .80945 L F
.2566 .81766 m .26451 .81582 L .2677 .8123 L F
0 g
.24769 .81729 m
.2566 .81766 L
s
.25368 .82071 m
.2566 .81766 L
s
.40128 .77771 m .39013 .76927 L .39245 .774 L 0 .973 .459 r
F
0 g
.38752 .77715 m
.39245 .774 L
s
.35894 .74523 m .3523 .73581 L .34647 .73951 L 0 1 .493 r
F
0 g
.34457 .73917 m
.34647 .73951 L
s
.52492 .85275 m .52567 .84213 L .51953 .84003 L 0 .648 .392 r
F
0 g
.5136 .83259 m
.51953 .84003 L
s
.52492 .85275 m .53371 .84897 L .52567 .84213 L 0 .648 .392 r
F
.52492 .85275 m .53928 .85767 L .53371 .84897 L F
.52492 .85275 m .53865 .86241 L .53928 .85767 L F
.52492 .85275 m .53249 .8603 L .53865 .86241 L F
0 g
.51914 .85002 m
.52492 .85275 L
s
.51937 .84407 m
.52492 .85275 L
s
.44664 .85298 m .45071 .83946 L .44271 .83783 L 0 .783 .403 r
F
.44664 .85298 m .45766 .84544 L .45071 .83946 L F
.44664 .85298 m .45892 .85177 L .45766 .84544 L F
.44664 .85298 m .45419 .855 L .45892 .85177 L F
0 g
.43971 .84701 m
.44664 .85298 L
s
.44227 .85609 m
.44664 .85298 L
s
.69422 .85818 m .69492 .8481 L .69154 .85312 L 0 1 .466 r
F
.69422 .85818 m .70291 .84607 L .69492 .8481 L F
0 g
.69154 .85312 m
.69422 .85818 L
s
.68649 .86101 m
.69422 .85818 L
s
.59698 .81873 m .60559 .81639 L .61396 .80657 L 0 1 .364 r
F
0 g
.61185 .80905 m
.61396 .80657 L
s
.61264 .81877 m
.61811 .81119 L
s
.61396 .80657 m
.6141 .80673 L
s
.61494 .87965 m
.61666 .87668 L
s
.61475 .87997 m
.61494 .87965 L
s
.61423 .88088 m
.61475 .87997 L
s
.61287 .88322 m
.61423 .88088 L
s
.60976 .88857 m
.61287 .88322 L
s
.68168 1.21382 m .6903 1.19834 L .68618 1.21186 L 0 .144 .107 r
F
.68498 1.23787 m .6903 1.19834 L .69416 1.1915 L 0 0 .09 r
F
.68498 1.23787 m .68618 1.21186 L .6903 1.19834 L F
0 g
.6903 1.19834 m
.69196 1.18295 L
s
.6903 1.19834 m
.69109 1.19694 L
s
.63764 1.01713 m
.63779 1.01536 L
s
.4895 .59388 m
.49981 .59321 L
s
.47872 .59235 m
.4895 .59388 L
s
.61587 .73922 m .63588 .73009 L .63801 .72412 L 0 1 .425 r
F
.61587 .73922 m .6264 .73655 L .63588 .73009 L F
0 g
.63588 .73009 m
.64169 .73159 L
s
.46673 .78404 m
.47423 .78851 L
s
.73799 .80457 m .75955 .80579 L .75573 .79987 L 0 1 .505 r
F
0 g
.75955 .80579 m
.76815 .80657 L
s
.44271 .83783 m .43877 .82324 L .43373 .82658 L 0 .833 .412 r
F
0 g
.42641 .82149 m
.43373 .82658 L
s
.30911 .8411 m .30095 .8364 L .30464 .83872 L 0 .387 .232 r
F
0 g
.64135 1.01356 m
.64157 1.01209 L
s
.64296 1.00311 m
.64488 .99067 L
s
.54637 .95978 m .55526 .96876 L .54976 .95234 L 0 .195 .235 r
F
.54637 .95978 m .55813 .98413 L .55526 .96876 L F
.54637 .95978 m .55642 .98815 L .55813 .98413 L F
.54637 .95978 m .55137 .97767 L .55642 .98815 L F
0 g
.54171 .94581 m
.54637 .95978 L
s
.54353 .94451 m
.54637 .95978 L
s
.5495 .98354 m
.55076 .99009 L
s
.54962 .9824 m
.5497 .98263 L
s
.54743 .9758 m
.54962 .9824 L
s
.31179 .72763 m .30404 .71999 L .29826 .72497 L 0 1 .527 r
F
0 g
.28841 .7258 m
.29826 .72497 L
s
.69521 1.19586 m .7032 1.17288 L .69909 1.18787 L 0 0 .051 r
F
.69618 1.19681 m .70631 1.15848 L .70635 1.15418 L 0 .751 .066 r
F
.69618 1.19681 m .7032 1.17288 L .70631 1.15848 L F
0 g
.70631 1.15848 m
.70938 1.15238 L
s
.70354 1.17129 m
.70631 1.15848 L
s
.26731 .91053 m .25545 .90568 L .2597 .90799 L 0 .444 .256 r
F
0 g
.25926 .9099 m
.2597 .90799 L
s
.64334 .97388 m .65636 .94179 L .65114 .94593 L 0 1 .195 r
F
0 g
.65014 .96406 m
.6538 .95697 L
s
.64824 .96773 m
.65014 .96406 L
s
.65636 .94179 m
.65745 .94513 L
s
.65636 .94179 m
.66007 .93668 L
s
.65105 .96737 m
.65387 .95683 L
s
.64949 .97321 m
.65105 .96737 L
s
.64944 .97339 m
.64949 .97321 L
s
.49203 1.0197 m .49296 1.01351 L .48899 1.00565 L 0 .01 .156 r
F
.49203 1.0197 m .4966 1.02371 L .49296 1.01351 L F
.49203 1.0197 m .49747 1.02942 L .4966 1.02371 L F
.49203 1.0197 m .4955 1.02769 L .49747 1.02942 L F
0 g
.49046 1.01662 m
.49203 1.0197 L
s
.4884 1.00954 m
.49203 1.0197 L
s
.48899 1.00565 m .48363 .98798 L .48499 .99471 L 0 .161 .234 r
F
0 g
.48313 .99489 m
.48499 .99471 L
s
.53991 .89677 m .54185 .88484 L .53611 .88095 L 0 .477 .338 r
F
0 g
.53126 .87137 m
.53611 .88095 L
s
.53451 .8918 m
.53991 .89677 L
s
.53991 .89677 m
.53991 .89678 L
s
.53548 .88538 m
.53991 .89677 L
s
.72039 .8242 m .73742 .81788 L .72917 .81415 L 0 1 .494 r
F
0 g
.73742 .81788 m
.74639 .818 L
s
.73742 .81788 m
.74077 .82346 L
s
.35894 .74523 m .3629 .7345 L .3523 .73581 L 0 1 .493 r
F
.35894 .74523 m .37263 .73661 L .3629 .7345 L F
.35894 .74523 m .37498 .74072 L .37263 .73661 L F
.35894 .74523 m .3691 .74441 L .37498 .74072 L F
0 g
.35342 .74868 m
.35894 .74523 L
s
.34925 .74313 m
.35894 .74523 L
s
.61587 .73922 m .63801 .72412 L .6314 .72155 L 0 1 .425 r
F
0 g
.62956 .73799 m
.63268 .7394 L
s
.63801 .72412 m
.64735 .71692 L
s
.66698 .90541 m .66801 .89459 L .6649 .90126 L 0 1 .381 r
F
.65902 .92381 m .66698 .90541 L .66025 .91207 L 0 1 .328 r
F
.66452 .67852 m .68232 .6649 L .6703 .66711 L 0 1 .461 r
F
0 g
.68232 .6649 m
.68815 .66621 L
s
.28344 .82873 m
.28619 .8262 L
s
.68498 1.23787 m .69416 1.1915 L .69521 1.19586 L 0 0 .09 r
F
0 g
.69416 1.1915 m
.69647 1.17946 L
s
.69109 1.19694 m
.69416 1.1915 L
s
.4256 .75985 m .41488 .75387 L .41676 .75694 L 0 1 .515 r
F
0 g
.41106 .7595 m
.41676 .75694 L
s
.50511 .81736 m .49815 .80696 L .49848 .81062 L 0 .81 .439 r
F
0 g
.4924 .81005 m
.49848 .81062 L
s
.62234 .92243 m
.62241 .92268 L
s
.61984 .91271 m
.62234 .92243 L
s
.62177 .94812 m .62243 .92277 L .61989 .94267 L 0 1 .171 r
F
.60801 .96545 m .61989 .94267 L .62243 .92277 L 0 1 .254 r
F
0 g
.62243 .92277 m
.62403 .916 L
s
.62241 .92268 m
.62243 .92277 L
s
.30911 .8411 m .29998 .835 L .30095 .8364 L 0 .387 .232 r
F
.30911 .8411 m .30237 .83545 L .29998 .835 L F
0 g
.29289 .83467 m
.30007 .83621 L
s
.30007 .83621 m
.30095 .8364 L
s
.30911 .8411 m .30686 .83784 L .30237 .83545 L 0 .387 .232 r
F
.30911 .8411 m .31044 .84056 L .30686 .83784 L F
.30911 .8411 m .3114 .84196 L .31044 .84056 L F
0 g
.30911 .8411 m
.31017 .84185 L
s
.30464 .83872 m
.30911 .8411 L
s
.70291 .84607 m .70338 .83616 L .69999 .84083 L 0 1 .478 r
F
.70291 .84607 m .71163 .83479 L .70338 .83616 L F
0 g
.69999 .84083 m
.70291 .84607 L
s
.69492 .8481 m
.70291 .84607 L
s
.2882 .92133 m .28346 .91751 L .27776 .9162 L 0 .438 .229 r
F
.2882 .92133 m .29077 .92002 L .28346 .91751 L F
.2882 .92133 m .29479 .92205 L .29077 .92002 L F
.2882 .92133 m .29367 .92261 L .29479 .92205 L F
0 g
.28093 .91883 m
.2882 .92133 L
s
.28729 .92185 m
.2882 .92133 L
s
.40128 .77771 m .39583 .76564 L .39013 .76927 L 0 .973 .459 r
F
0 g
.38141 .76561 m
.39013 .76927 L
s
.53991 .89677 m .54887 .89447 L .54185 .88484 L 0 .477 .338 r
F
.53991 .89677 m .55333 .90591 L .54887 .89447 L F
.53991 .89677 m .55223 .91149 L .55333 .90591 L F
.53991 .89677 m .54647 .90757 L .55223 .91149 L F
0 g
.53991 .89677 m
.53991 .89677 L
s
.62691 .62815 m
.63796 .63205 L
s
.6181 .62245 m
.62691 .62815 L
s
.65877 .69054 m .65417 .68414 L .652 .68906 L 0 1 .45 r
F
.65877 .69054 m .66452 .67852 L .65417 .68414 L F
.48899 1.00565 m .48595 .98843 L .48363 .98798 L 0 .161 .234 r
F
0 g
.47936 .97839 m
.48363 .98798 L
s
.43877 .82324 m .42944 .81266 L .43116 .81816 L 0 .88 .421 r
F
0 g
.42641 .82149 m
.43116 .81816 L
s
.44271 .83783 m .44721 .82453 L .43877 .82324 L 0 .833 .412 r
F
.44271 .83783 m .4545 .83006 L .44721 .82453 L F
.44271 .83783 m .45577 .83613 L .4545 .83006 L F
.44271 .83783 m .45071 .83946 L .45577 .83613 L F
0 g
.43544 .83231 m
.44271 .83783 L
s
.438 .84107 m
.44271 .83783 L
s
.70002 1.07958 m .70219 1.10244 L .70687 1.10875 L 0 1 .267 r
F
.69009 1.1223 m .70002 1.07958 L .69544 1.07461 L 0 1 .249 r
F
.69009 1.1223 m .70219 1.10244 L .70002 1.07958 L F
0 g
.70002 1.07958 m
.70145 1.05339 L
s
.55446 1.1958 m
.55514 1.20034 L
s
.55514 1.20034 m
.55548 1.2026 L
s
.55548 1.2026 m
.55649 1.20936 L
s
.31179 .72763 m .31501 .71638 L .30404 .71999 L 0 1 .527 r
F
0 g
.29839 .72113 m
.30415 .71669 L
s
.29826 .72497 m
.30404 .71999 L
s
.31179 .72763 m .32538 .716 L .31501 .71638 L 0 1 .527 r
F
.31179 .72763 m .3282 .7191 L .32538 .716 L F
.31179 .72763 m .32237 .72409 L .3282 .7191 L F
0 g
.30629 .73258 m
.31179 .72763 L
s
.30147 .72801 m
.31179 .72763 L
s
.59286 .84122 m .60866 .83093 L .61059 .82162 L 0 1 .348 r
F
0 g
.61059 .82162 m
.61264 .81877 L
s
.26731 .91053 m .25687 .90447 L .25545 .90568 L 0 .444 .256 r
F
0 g
.2485 .90433 m
.25545 .90568 L
s
.50511 .81736 m .50465 .80786 L .49815 .80696 L 0 .81 .439 r
F
.50511 .81736 m .51366 .81272 L .50465 .80786 L F
.50511 .81736 m .5203 .81948 L .51366 .81272 L F
.50511 .81736 m .52015 .82362 L .5203 .81948 L F
.50511 .81736 m .51363 .82271 L .52015 .82362 L F
0 g
.49897 .81605 m
.50511 .81736 L
s
.49848 .81062 m
.50511 .81736 L
s
.60242 .79238 m .6165 .77038 L .60688 .77313 L 0 1 .381 r
F
0 g
.61161 .78977 m
.61652 .79581 L
s
.6116 .78975 m
.61161 .78977 L
s
.61158 .78973 m
.61853 .7833 L
s
.6165 .77038 m
.62418 .76395 L
s
.6165 .77038 m
.61713 .77081 L
s
.74683 .79538 m .7652 .80075 L .76898 .79745 L 0 1 .509 r
F
.74683 .79538 m .75573 .79987 L .7652 .80075 L F
0 g
.7652 .80075 m
.76815 .80657 L
s
.4256 .75985 m .42127 .75195 L .41488 .75387 L 0 1 .515 r
F
.4256 .75985 m .43169 .75246 L .42127 .75195 L F
.4256 .75985 m .44057 .75537 L .43169 .75246 L F
.4256 .75985 m .44196 .75874 L .44057 .75537 L F
.4256 .75985 m .43554 .76066 L .44196 .75874 L F
0 g
.41958 .76146 m
.4256 .75985 L
s
.41676 .75694 m
.4256 .75985 L
s
.34498 .86914 m .34363 .86858 L .3364 .86025 L 0 0 .112 r
F
.34498 .86914 m .35457 .88498 L .35143 .8792 L F
.34498 .86914 m .35178 .88064 L .35457 .88498 L F
.34498 .86914 m .35047 .87771 L .34363 .86858 L F
.33911 .86256 m .3467 .87121 L .34354 .86634 L 0 .008 .161 r
F
.3364 .86025 m .34123 .86539 L .33911 .86256 L F
.34123 .86539 m .3467 .87121 L .33911 .86256 L F
.35047 .87771 m .35143 .8792 L .34363 .86858 L 0 0 .112 r
F
0 g
.33724 .85862 m
.34187 .86491 L
s
.40128 .77771 m .40577 .76553 L .39583 .76564 L 0 .973 .459 r
F
.40128 .77771 m .41463 .76925 L .40577 .76553 L F
.40128 .77771 m .41649 .77431 L .41463 .76925 L F
.40128 .77771 m .41075 .77794 L .41649 .77431 L F
0 g
.39592 .7813 m
.40128 .77771 L
s
.39245 .774 m
.40128 .77771 L
s
.59698 .81873 m .61158 .78973 L .60242 .79238 L 0 1 .364 r
F
0 g
.61158 .78973 m
.6116 .78975 L
s
.60559 .81639 m
.61185 .80905 L
s
.54396 .92009 m
.54774 .92358 L
s
.48595 .98843 m .48022 .96994 L .48158 .97736 L 0 .255 .285 r
F
0 g
.47936 .97839 m
.48158 .97736 L
s
.62041 .72409 m .64122 .71548 L .64337 .70993 L 0 1 .437 r
F
.62041 .72409 m .6314 .72155 L .64122 .71548 L F
0 g
.64122 .71548 m
.64735 .71692 L
s
.43877 .82324 m .43481 .80925 L .42944 .81266 L 0 .88 .421 r
F
0 g
.4218 .8079 m
.42944 .81266 L
s
.57196 1.24685 m
.57221 1.2476 L
s
.5718 1.24639 m
.57196 1.24685 L
s
.57152 1.24556 m
.5718 1.24639 L
s
.57151 1.24551 m
.57152 1.24556 L
s
.57067 1.24305 m
.57151 1.24551 L
s
.57019 1.24354 m
.57067 1.24305 L
s
.60688 .77313 m .62143 .75275 L .61136 .7555 L 0 1 .396 r
F
0 g
.62143 .75275 m
.62302 .75362 L
s
.62143 .75275 m
.63056 .74586 L
s
.406 .75206 m
.41488 .75387 L
s
.49122 .80123 m
.49815 .80696 L
s
.48595 .98843 m .48292 .96934 L .48022 .96994 L 0 .255 .285 r
F
0 g
.47559 .9603 m
.48022 .96994 L
s
.52441 .59702 m
.5351 .59745 L
s
.51394 .59448 m
.52441 .59702 L
s
.62576 .97378 m
.62583 .97391 L
s
.62583 .97391 m
.62593 .97412 L
s
.62593 .97412 m
.6266 .97556 L
s
.6266 .97556 m
.62668 .97572 L
s
.62341 1.00691 m
.62394 1.00185 L
s
.62394 1.00185 m
.62439 .99759 L
s
.62439 .99759 m
.62668 .97573 L
s
.34508 .73463 m .33949 .73068 L .34229 .73418 L 0 1 .5 r
F
.34508 .73463 m .33947 .73145 L .34228 .7345 L 0 1 .529 r
F
.35233 .73496 m .34555 .73311 L .34508 .73463 L F
.34555 .73311 m .33949 .73068 L .34505 .73462 L 0 1 .5 r
F
.34555 .73311 m .34505 .73462 L .34508 .73463 L F
.34555 .73311 m .34564 .72672 L .33949 .73068 L F
.35233 .73496 m .34818 .73018 L .34555 .73311 L 0 1 .529 r
F
.3523 .73581 m .34818 .73018 L .34555 .73311 L 0 1 .5 r
F
.35233 .73496 m .35668 .72469 L .35324 .72549 L 0 1 .529 r
F
.35233 .73496 m .36678 .72515 L .35668 .72469 L F
.35233 .73496 m .36915 .7283 L .36678 .72515 L F
.35233 .73496 m .36295 .73251 L .36915 .7283 L F
.3523 .73581 m .35668 .72493 L .35324 .72549 L 0 1 .5 r
F
.34818 .73018 m .35324 .72549 L .34564 .72672 L F
.35233 .73496 m .35324 .72549 L .35221 .72644 L 0 1 .529 r
F
.35233 .73496 m .35221 .72573 L .34818 .73018 L F
.3523 .73581 m .35324 .72549 L .34818 .73018 L 0 1 .5 r
F
.35221 .72644 m .35324 .72549 L .35221 .72573 L 0 1 .529 r
F
.34818 .73018 m .34564 .72672 L .34555 .73309 L 0 1 .5 r
F
.34818 .73018 m .35221 .72573 L .34563 .72724 L 0 1 .529 r
F
.34818 .73018 m .34555 .73309 L .34555 .73311 L 0 1 .5 r
F
.34818 .73018 m .34698 .7288 L .34555 .73311 L 0 1 .529 r
F
.34555 .73311 m .34563 .72724 L .33947 .73145 L F
.34698 .7288 m .34563 .72724 L .34555 .73311 L F
.34555 .73311 m .33947 .73145 L .34508 .73463 L F
.3523 .73581 m .34555 .73311 L .34508 .73463 L 0 1 .5 r
F
0 g
.34508 .73463 m
.34533 .73467 L
s
.3319 .72983 m
.33949 .73068 L
s
.34648 .73905 m
.35134 .73566 L
s
.34209 .73468 m
.34228 .7345 L
s
.69618 1.19681 m .69909 1.18787 L .7032 1.17288 L 0 .751 .066 r
F
0 g
.7032 1.17288 m
.70354 1.17129 L
s
.34228 .7345 m
.3441 .73459 L
s
.3441 .73459 m
.34508 .73463 L
s
.3297 .7318 m
.33947 .73145 L
s
.71163 .83479 m .71188 .825 L .70848 .82938 L 0 1 .487 r
F
.71163 .83479 m .72039 .8242 L .71188 .825 L F
0 g
.70338 .83616 m
.71163 .83479 L
s
.48292 .96934 m .47682 .9508 L .47818 .95856 L 0 .322 .315 r
F
0 g
.47559 .9603 m
.47818 .95856 L
s
.74683 .79538 m .76898 .79745 L .76492 .79136 L 0 1 .509 r
F
0 g
.76898 .79745 m
.7778 .79863 L
s
.59286 .84122 m .60106 .83933 L .60866 .83093 L 0 1 .348 r
F
0 g
.60779 .83188 m
.60866 .83093 L
s
.60779 .83188 m
.60779 .83188 L
s
.60692 .83284 m
.60779 .83188 L
s
.60866 .83093 m
.61298 .83461 L
s
.60806 .84221 m
.61298 .83461 L
s
.48292 .96934 m .4799 .94934 L .47682 .9508 L 0 .322 .315 r
F
0 g
.47183 .94142 m
.47682 .9508 L
s
.59353 .61407 m
.60459 .6168 L
s
.58405 .60944 m
.59353 .61407 L
s
.54976 .95234 m .54766 .93243 L .54651 .9368 L 0 .298 .279 r
F
0 g
.54976 .95234 m
.54976 .95234 L
s
.54414 .93369 m
.54651 .9368 L
s
.32777 .85293 m .31581 .84446 L .31939 .84694 L 0 .217 .213 r
F
.25687 .90447 m .24483 .89974 L .24908 .90214 L 0 .467 .299 r
F
0 g
.2485 .90433 m
.24908 .90214 L
s
.39054 .74527 m .37863 .74068 L .38099 .74369 L 0 1 .526 r
F
0 g
.37691 .74658 m
.38099 .74369 L
s
.4799 .94934 m .47351 .9318 L .47482 .93934 L 0 .435 .335 r
F
0 g
.47183 .94142 m
.47482 .93934 L
s
.69009 1.1223 m .69544 1.07461 L .69148 1.09086 L 0 1 .249 r
F
0 g
.69544 1.07461 m
.70002 1.07958 L
s
.69544 1.07461 m
.69599 1.0385 L
s
.62041 .72409 m .64337 .70993 L .63642 .70754 L 0 1 .437 r
F
0 g
.63744 .7239 m
.63801 .72412 L
s
.64337 .70993 m
.65304 .7033 L
s
.54185 .88484 m .53769 .86947 L .53706 .87413 L 0 .593 .357 r
F
0 g
.53631 .87377 m
.53706 .87413 L
s
.4799 .94934 m .47699 .92991 L .47351 .9318 L 0 .435 .335 r
F
0 g
.46822 .92308 m
.47351 .9318 L
s
.43877 .82324 m .44371 .81021 L .43481 .80925 L 0 .88 .421 r
F
0 g
.42944 .81266 m
.43481 .80925 L
s
.43877 .82324 m .45134 .8153 L .44371 .81021 L 0 .88 .421 r
F
.43877 .82324 m .45261 .82113 L .45134 .8153 L F
.43877 .82324 m .44721 .82453 L .45261 .82113 L F
0 g
.43116 .81816 m
.43877 .82324 L
s
.43373 .82658 m
.43877 .82324 L
s
.72917 .81415 m .74656 .80869 L .73799 .80457 L 0 1 .5 r
F
0 g
.74656 .80869 m
.75578 .80921 L
s
.74656 .80869 m
.75014 .81444 L
s
.54837 1.11781 m .54973 1.11032 L .5538 1.14008 L 0 .823 .189 r
F
0 g
.54973 1.11032 m
.55036 1.11496 L
s
.55161 1.09567 m
.55275 1.11875 L
s
.54779 1.08396 m
.54973 1.11032 L
s
.47699 .92991 m .47025 .91309 L .47155 .92055 L 0 .534 .349 r
F
0 g
.46822 .92308 m
.47155 .92055 L
s
.55922 .60372 m
.57017 .60529 L
s
.54919 .60015 m
.55922 .60372 L
s
.52864 1.09376 m
.53015 1.1044 L
s
.39583 .76564 m .38432 .75787 L .38665 .76236 L 0 1 .468 r
F
0 g
.38141 .76561 m
.38665 .76236 L
s
.56368 1.23373 m
.56376 1.23372 L
s
.56348 1.23377 m
.56368 1.23373 L
s
.47699 .92991 m .47409 .91067 L .47025 .91309 L 0 .534 .349 r
F
0 g
.4646 .90487 m
.47025 .91309 L
s
.65902 .92381 m .66025 .91207 L .65717 .91983 L 0 1 .328 r
F
.65114 .94593 m .65902 .92381 L .65256 .93266 L 0 1 .26 r
F
.52567 .84213 m .51991 .82981 L .51976 .83392 L 0 .744 .407 r
F
0 g
.5136 .83259 m
.51976 .83392 L
s
.52145 1.08466 m .52116 1.0992 L .52046 1.08827 L 0 .843 .102 r
F
0 g
.51869 1.07737 m
.52046 1.08827 L
s
.52145 1.08466 m .5236 1.11529 L .52116 1.0992 L 0 .843 .102 r
F
.52145 1.08466 m .52617 1.1258 L .5236 1.11529 L F
.52145 1.08466 m .52716 1.12211 L .52617 1.1258 L F
.52145 1.08466 m .52592 1.10674 L .52716 1.12211 L F
.52145 1.08466 m .52348 1.09073 L .52592 1.10674 L F
0 g
.52408 1.08225 m
.5262 1.09756 L
s
.52119 1.08277 m
.52145 1.08466 L
s
.52046 1.08827 m
.52145 1.08466 L
s
.52348 1.09073 m
.52408 1.08225 L
s
.70459 1.12903 m .70562 1.14156 L .70948 1.14028 L 0 1 .226 r
F
0 g
.70904 1.14043 m
.70924 1.14037 L
s
.70924 1.14037 m
.70948 1.14028 L
s
.61136 .7555 m .6264 .73655 L .61587 .73922 L 0 1 .411 r
F
0 g
.6264 .73655 m
.62956 .73799 L
s
.6264 .73655 m
.63588 .73009 L
s
.62688 1.01572 m
.62786 1.00636 L
s
.62786 1.00636 m
.62837 1.00138 L
s
.62335 1.04958 m
.62688 1.01572 L
s
.47409 .91067 m .46708 .89523 L .46833 .90223 L 0 .62 .362 r
F
0 g
.4646 .90487 m
.46833 .90223 L
s
.45379 .77117 m .44404 .76375 L .44543 .76706 L 0 1 .499 r
F
0 g
.43937 .76867 m
.44543 .76706 L
s
.48899 1.00565 m .49043 .99579 L .48595 .98843 L 0 .161 .234 r
F
.48899 1.00565 m .49444 1.00676 L .49043 .99579 L F
.48899 1.00565 m .4953 1.014 L .49444 1.00676 L F
.48899 1.00565 m .49296 1.01351 L .4953 1.014 L F
0 g
.48704 1.00395 m
.48899 1.00565 L
s
.48499 .99471 m
.48899 1.00565 L
s
.31044 .84056 m
.3114 .84196 L
s
.3114 .84196 m
.31581 .84446 L
s
.43481 .80925 m .4242 .79652 L .42646 .80339 L 0 .928 .431 r
F
0 g
.4218 .8079 m
.42646 .80339 L
s
.71343 .7564 m .71181 .75444 L .70883 .76083 L 0 .882 .138 r
F
.71343 .7564 m .72116 .74128 L .71181 .75444 L F
.70575 .77299 m .71343 .7564 L .70438 .77087 L 0 .857 .124 r
F
.47409 .91067 m .4713 .89266 L .46708 .89523 L 0 .62 .362 r
F
0 g
.46114 .88777 m
.46708 .89523 L
s
.67673 .87392 m
.67753 .87631 L
s
.67622 .87242 m
.67673 .87392 L
s
.67577 .87107 m
.67622 .87242 L
s
.67569 .87082 m
.67577 .87107 L
s
.25687 .90447 m .24642 .89813 L .24483 .89974 L 0 .467 .299 r
F
0 g
.23774 .89857 m
.24483 .89974 L
s
.56644 1.11517 m
.56647 1.1152 L
s
.56647 1.1152 m
.56768 1.11683 L
s
.6774 .86817 m
.68313 .8665 L
s
.67689 .86832 m
.6774 .86817 L
s
.67642 .86845 m
.67689 .86832 L
s
.59286 .84122 m .60559 .81639 L .59698 .81873 L 0 1 .348 r
F
0 g
.60106 .83933 m
.60692 .83284 L
s
.60559 .81639 m
.61059 .82162 L
s
.67244 .88441 m
.67342 .8839 L
s
.66511 .88819 m
.67017 .88558 L
s
.67107 .88511 m
.67244 .88441 L
s
.67139 1.24849 m .68168 1.21382 L .68 1.23352 L 0 .233 .136 r
F
.27776 .9162 m .27325 .91161 L .26731 .91053 L 0 .429 .235 r
F
.27776 .9162 m .28074 .91425 L .27325 .91161 L F
.27776 .9162 m .28475 .91667 L .28074 .91425 L F
.27776 .9162 m .28346 .91751 L .28475 .91667 L F
0 g
.27032 .91357 m
.27776 .9162 L
s
.27668 .91677 m
.27776 .9162 L
s
.60497 .85764 m
.60586 .85872 L
s
.60742 .86061 m
.60789 .86119 L
s
.60781 .86132 m
.60789 .86119 L
s
.68316 .85486 m
.68649 .86101 L
s
.72116 .74128 m .71929 .73935 L .7163 .74523 L 0 .907 .153 r
F
.72116 .74128 m .72893 .72737 L .71929 .73935 L F
0 g
.71504 .7499 m
.72116 .74128 L
s
.4713 .89266 m .46394 .87806 L .4652 .88487 L 0 .693 .373 r
F
0 g
.46114 .88777 m
.4652 .88487 L
s
.70575 .77299 m .70438 .77087 L .70142 .77788 L 0 .857 .124 r
F
.69813 .79138 m .70575 .77299 L .69699 .78895 L 0 .834 .111 r
F
0 g
.70486 .77461 m
.70575 .77299 L
s
.7052 .77362 m
.70575 .77299 L
s
.39054 .74527 m .38498 .73757 L .37863 .74068 L 0 1 .526 r
F
0 g
.37484 .74048 m
.37863 .74068 L
s
.39054 .74527 m .39584 .73645 L .38498 .73757 L 0 1 .526 r
F
.39054 .74527 m .40543 .73803 L .39584 .73645 L F
.39054 .74527 m .40732 .74126 L .40543 .73803 L F
.39054 .74527 m .40093 .74436 L .40732 .74126 L F
0 g
.38453 .74813 m
.39054 .74527 L
s
.38099 .74369 m
.39054 .74527 L
s
.45379 .77117 m .45071 .76265 L .44404 .76375 L 0 1 .499 r
F
.45379 .77117 m .46101 .76448 L .45071 .76265 L F
.45379 .77117 m .4694 .7686 L .46101 .76448 L F
.45379 .77117 m .47028 .77225 L .4694 .7686 L F
.45379 .77117 m .46358 .77335 L .47028 .77225 L F
0 g
.44543 .76706 m
.45379 .77117 L
s
.66056 1.28751 m .66496 1.22921 L .66956 1.23266 L 0 .306 .164 r
F
0 g
.66496 1.22921 m
.66879 1.23208 L
s
.66054 1.26177 m
.6606 1.2604 L
s
.66496 1.22921 m
.66636 1.20995 L
s
.29998 .835 m .29173 .83017 L .29542 .83274 L 0 .511 .347 r
F
.52567 .84213 m .52642 .83137 L .51991 .82981 L 0 .744 .407 r
F
.52567 .84213 m .53495 .83758 L .52642 .83137 L F
.52567 .84213 m .54087 .84581 L .53495 .83758 L F
.52567 .84213 m .54024 .85055 L .54087 .84581 L F
.52567 .84213 m .53371 .84897 L .54024 .85055 L F
0 g
.51953 .84003 m
.52567 .84213 L
s
.51976 .83392 m
.52567 .84213 L
s
.4713 .89266 m .46852 .87519 L .46394 .87806 L 0 .693 .373 r
F
0 g
.45767 .87112 m
.46394 .87806 L
s
.27398 .8224 m
.27695 .81935 L
s
.51363 .82271 m
.51991 .82981 L
s
.65094 .9036 m .66801 .89459 L .66511 .8882 L 0 1 .393 r
F
.65094 .9036 m .6649 .90126 L .66801 .89459 L F
0 g
.66801 .89459 m
.67034 .89291 L
s
.66452 .67852 m .65961 .67228 L .65743 .67695 L 0 1 .461 r
F
.66452 .67852 m .6703 .66711 L .65961 .67228 L F
.32777 .85293 m .31912 .84533 L .31581 .84446 L 0 .217 .213 r
F
.54185 .88484 m .54378 .87241 L .53769 .86947 L 0 .593 .357 r
F
0 g
.53249 .8603 m
.53769 .86947 L
s
.54976 .95234 m .553 .93998 L .54766 .93243 L 0 .298 .279 r
F
0 g
.54474 .94198 m
.54976 .95234 L
s
.54396 .92009 m
.54766 .93243 L
s
.72039 .8242 m .72041 .81446 L .71699 .81861 L 0 1 .494 r
F
.72039 .8242 m .72917 .81415 L .72041 .81446 L F
0 g
.68316 .85486 m
.69154 .85312 L
s
.62497 .70991 m .6466 .70186 L .64876 .69665 L 0 1 .449 r
F
.62497 .70991 m .63642 .70754 L .6466 .70186 L F
0 g
.6466 .70186 m
.65304 .7033 L
s
.50257 1.04905 m .49877 1.0363 L .49964 1.03977 L 0 0 .107 r
F
0 g
.49822 1.03698 m
.49964 1.03977 L
s
.64824 .96773 m
.64885 .9706 L
s
.64935 .97298 m
.64944 .97339 L
s
.64885 .9706 m
.64935 .97298 L
s
.39583 .76564 m .39036 .75415 L .38432 .75787 L 0 1 .468 r
F
0 g
.37527 .75475 m
.38432 .75787 L
s
.48064 .7887 m .47174 .7783 L .47281 .78272 L 0 .962 .476 r
F
0 g
.47281 .78272 m
.48064 .7887 L
s
.48063 .7887 m
.48064 .7887 L
s
.47423 .78851 m
.48063 .7887 L
s
.46673 .78404 m
.47281 .78272 L
s
.48064 .7887 m .47844 .77731 L .47174 .7783 L 0 .962 .476 r
F
.48064 .7887 m .48846 .78041 L .47844 .77731 L F
.48064 .7887 m .49632 .78641 L .48846 .78041 L F
.48064 .7887 m .49675 .7913 L .49632 .78641 L F
.48064 .7887 m .49003 .79228 L .49675 .7913 L F
0 g
.48064 .7887 m
.48064 .7887 L
s
.54185 .88484 m .55128 .881 L .54378 .87241 L 0 .593 .357 r
F
.54185 .88484 m .55608 .89174 L .55128 .881 L F
.54185 .88484 m .55498 .89744 L .55608 .89174 L F
.54185 .88484 m .54887 .89447 L .55498 .89744 L F
0 g
.53611 .88095 m
.54185 .88484 L
s
.53706 .87413 m
.54185 .88484 L
s
.54111 1.10842 m
.54124 1.11087 L
s
.3364 .86025 m .34354 .86634 L .3354 .85849 L 0 .008 .161 r
F
.3364 .86025 m .34363 .86858 L .3467 .87121 L F
.67294 1.06988 m .68564 1.12065 L .68603 1.07305 L 0 .913 .25 r
F
0 g
.68603 1.07305 m
.69148 1.09086 L
s
.3523 .73581 m .36675 .72657 L .35668 .72493 L 0 1 .5 r
F
.3523 .73581 m .3691 .73054 L .36675 .72657 L F
.3523 .73581 m .3629 .7345 L .3691 .73054 L F
0 g
.34647 .73951 m
.3523 .73581 L
s
.34533 .73467 m
.3523 .73581 L
s
.46852 .87519 m .46081 .86145 L .46206 .86803 L 0 .758 .383 r
F
0 g
.45767 .87112 m
.46206 .86803 L
s
.56809 1.0574 m
.56838 1.07488 L
s
.43481 .80925 m .4296 .79178 L .4242 .79652 L 0 .928 .431 r
F
0 g
.41572 .79098 m
.4242 .79652 L
s
.69618 1.19681 m .70635 1.15418 L .70337 1.16435 L 0 .751 .066 r
F
0 g
.70635 1.15418 m
.70948 1.14028 L
s
.60106 .83933 m
.60576 .84577 L
s
.65094 .9036 m .65759 .90512 L .6649 .90126 L 0 1 .393 r
F
0 g
.6649 .90126 m
.66698 .90541 L
s
.29998 .835 m .29083 .82834 L .29173 .83017 L 0 .511 .347 r
F
.29998 .835 m .29334 .82848 L .29083 .82834 L F
0 g
.28344 .82873 m
.29069 .82999 L
s
.29069 .82999 m
.29172 .83017 L
s
.29998 .835 m .2979 .83075 L .29334 .82848 L 0 .511 .347 r
F
.29998 .835 m .30149 .83363 L .2979 .83075 L F
.29998 .835 m .30237 .83545 L .30149 .83363 L F
0 g
.29998 .835 m
.30095 .8364 L
s
.29542 .83274 m
.29998 .835 L
s
.69133 .84204 m
.69492 .8481 L
s
.24642 .89813 m .2342 .89361 L .23845 .89608 L 0 .498 .34 r
F
0 g
.23774 .89857 m
.23845 .89608 L
s
.43481 .80925 m .43909 .79232 L .4296 .79178 L 0 .928 .431 r
F
0 g
.4242 .79652 m
.4296 .79178 L
s
.43481 .80925 m .44747 .79819 L .43909 .79232 L 0 .928 .431 r
F
.43481 .80925 m .44914 .80547 L .44747 .79819 L F
.43481 .80925 m .44371 .81021 L .44914 .80547 L F
0 g
.42646 .80339 m
.43481 .80925 L
s
.39583 .76564 m .40076 .75367 L .39036 .75415 L 0 1 .468 r
F
.39583 .76564 m .40998 .75696 L .40076 .75367 L F
.39583 .76564 m .41184 .76181 L .40998 .75696 L F
.39583 .76564 m .40577 .76553 L .41184 .76181 L F
0 g
.39013 .76927 m
.39583 .76564 L
s
.38665 .76236 m
.39583 .76564 L
s
.48595 .98843 m .4879 .97598 L .48292 .96934 L 0 .255 .285 r
F
.48595 .98843 m .49229 .98708 L .4879 .97598 L F
.48595 .98843 m .49315 .99522 L .49229 .98708 L F
.48595 .98843 m .49043 .99579 L .49315 .99522 L F
0 g
.48158 .97736 m
.48595 .98843 L
s
.48363 .98798 m
.48595 .98843 L
s
.43554 .76066 m
.44404 .76375 L
s
.4955 1.02769 m
.49606 1.02818 L
s
.46852 .87519 m .46572 .85833 L .46081 .86145 L 0 .758 .383 r
F
0 g
.45419 .855 m
.46081 .86145 L
s
.61587 .73922 m .6314 .72155 L .62041 .72409 L 0 1 .425 r
F
0 g
.6314 .72155 m
.63744 .7239 L
s
.6314 .72155 m
.64122 .71548 L
s
.62011 .94332 m
.62177 .94812 L
s
.61612 .97634 m
.6178 .96795 L
s
.62084 .95276 m
.62177 .94812 L
s
.69813 .79138 m .69699 .78895 L .69405 .7967 L 0 .834 .111 r
F
.69056 .81199 m .69813 .79138 L .68966 .80902 L 0 .815 .1 r
F
0 g
.69614 .79552 m
.69813 .79138 L
s
.69675 .79318 m
.69813 .79138 L
s
.60976 .88857 m
.61326 .89756 L
s
.54647 .90757 m
.55131 .91087 L
s
.73799 .80457 m .75573 .79987 L .74683 .79538 L 0 1 .505 r
F
0 g
.75573 .79987 m
.7652 .80075 L
s
.75573 .79987 m
.75955 .80579 L
s
.62497 .70991 m .64876 .69665 L .64147 .69438 L 0 1 .449 r
F
0 g
.64876 .69665 m
.65877 .69054 L
s
.48292 .96934 m .48537 .95516 L .4799 .94934 L 0 .322 .315 r
F
0 g
.47682 .9508 m
.4799 .94934 L
s
.48292 .96934 m .49013 .96596 L .48537 .95516 L 0 .322 .315 r
F
.48292 .96934 m .49099 .97454 L .49013 .96596 L F
.48292 .96934 m .4879 .97598 L .49099 .97454 L F
0 g
.47818 .95856 m
.48292 .96934 L
s
.48022 .96994 m
.48292 .96934 L
s
.4799 .94934 m .48295 .93493 L .47699 .92991 L 0 .435 .335 r
F
.4799 .94934 m .48805 .94495 L .48295 .93493 L F
.4799 .94934 m .48887 .95328 L .48805 .94495 L F
.4799 .94934 m .48537 .95515 L .48887 .95328 L F
0 g
.47482 .93934 m
.4799 .94934 L
s
.47699 .92991 m .48053 .91492 L .47409 .91067 L 0 .534 .349 r
F
0 g
.47025 .91309 m
.47409 .91067 L
s
.47699 .92991 m .48598 .92429 L .48053 .91492 L 0 .534 .349 r
F
.47699 .92991 m .48681 .93253 L .48598 .92429 L F
.47699 .92991 m .48295 .93493 L .48681 .93253 L F
0 g
.47155 .92055 m
.47699 .92991 L
s
.47351 .9318 m
.47699 .92991 L
s
.69133 .84204 m
.69999 .84083 L
s
.67294 1.06988 m .68181 1.14419 L .68564 1.12065 L 0 .913 .25 r
F
.67294 1.06988 m .67634 1.12224 L .68181 1.14419 L F
.66358 1.1308 m .67634 1.12224 L .67294 1.06988 L 0 .907 .239 r
F
0 g
.66758 1.04526 m
.67294 1.06988 L
s
.67294 1.06988 m
.67341 1.02282 L
s
.24642 .89813 m .23597 .8916 L .2342 .89361 L 0 .498 .34 r
F
0 g
.22696 .89268 m
.2342 .89361 L
s
.47409 .91067 m .4782 .89624 L .4713 .89266 L 0 .62 .362 r
F
.47409 .91067 m .48398 .90468 L .4782 .89624 L F
.47409 .91067 m .48477 .91236 L .48398 .90468 L F
.47409 .91067 m .48053 .91492 L .48477 .91236 L F
0 g
.46833 .90223 m
.47409 .91067 L
s
.46572 .85833 m .45766 .84544 L .45892 .85177 L 0 .817 .392 r
F
0 g
.45419 .855 m
.45892 .85177 L
s
.50465 .80786 m .49733 .79774 L .49766 .80144 L 0 .888 .45 r
F
0 g
.49122 .80123 m
.49766 .80144 L
s
.52348 1.09073 m
.52378 1.09274 L
s
.69009 1.1223 m .70084 1.13387 L .70219 1.10244 L 0 1 .249 r
F
0 g
.70219 1.10244 m
.70687 1.10875 L
s
.57162 1.25472 m
.572 1.2564 L
s
.57064 1.25044 m
.57162 1.25472 L
s
.572 1.2564 m
.57272 1.25953 L
s
.55412 1.00744 m .55384 .99061 L .55211 .98988 L 0 .084 .173 r
F
0 g
.5497 .98263 m
.55211 .98988 L
s
.64381 .92349 m .66025 .91207 L .65759 .90512 L 0 1 .368 r
F
.64381 .92349 m .65717 .91983 L .66025 .91207 L F
0 g
.66025 .91207 m
.66698 .90541 L
s
.4713 .89266 m .47588 .87816 L .46852 .87519 L 0 .693 .373 r
F
.4713 .89266 m .482 .88595 L .47588 .87816 L F
.4713 .89266 m .48279 .89337 L .482 .88595 L F
.4713 .89266 m .4782 .89624 L .48279 .89337 L F
0 g
.4652 .88487 m
.4713 .89266 L
s
.46708 .89523 m
.4713 .89266 L
s
.50257 1.04905 m .50078 1.04089 L .49877 1.0363 L 0 0 .107 r
F
0 g
.4955 1.02769 m
.49877 1.0363 L
s
.50257 1.04905 m .50435 1.0505 L .50078 1.04089 L 0 0 .107 r
F
.50257 1.04905 m .50765 1.06263 L .5073 1.05983 L F
.50257 1.04905 m .50562 1.05799 L .50765 1.06263 L F
0 g
.49964 1.03977 m
.50257 1.04905 L
s
.51073 1.0688 m .50819 1.06404 L .50854 1.06313 L 0 .507 .001 r
F
0 g
.5069 1.05681 m
.50854 1.06313 L
s
.51073 1.0688 m .51024 1.07261 L .50819 1.06404 L 0 .507 .001 r
F
.51073 1.0688 m .51333 1.08315 L .51024 1.07261 L F
.51073 1.0688 m .51553 1.08885 L .51333 1.08315 L F
.51073 1.0688 m .51536 1.08588 L .51553 1.08885 L F
.51073 1.0688 m .5133 1.07728 L .51536 1.08588 L F
0 g
.50908 1.05882 m
.51073 1.0688 L
s
.50854 1.06313 m
.51073 1.0688 L
s
.50465 .80786 m .50419 .79828 L .49733 .79774 L 0 .888 .45 r
F
.50465 .80786 m .51368 .80272 L .50419 .79828 L F
.50465 .80786 m .5207 .80915 L .51368 .80272 L F
.50465 .80786 m .52054 .81328 L .5207 .80915 L F
.50465 .80786 m .51366 .81272 L .52054 .81328 L F
0 g
.49815 .80696 m
.50465 .80786 L
s
.49766 .80144 m
.50465 .80786 L
s
.62486 .97831 m
.62576 .97378 L
s
.62429 .9812 m
.62486 .97831 L
s
.62407 .98229 m
.62429 .9812 L
s
.62399 .9827 m
.62407 .98229 L
s
.62013 1.00213 m
.62399 .9827 L
s
.46572 .85833 m .46292 .84214 L .45766 .84544 L 0 .817 .392 r
F
0 g
.45071 .83946 m
.45766 .84544 L
s
.54976 .95234 m .55897 .95446 L .553 .93998 L 0 .298 .279 r
F
.54976 .95234 m .56225 .97009 L .55897 .95446 L F
.54976 .95234 m .56063 .97639 L .56225 .97009 L F
.54976 .95234 m .55527 .96876 L .56063 .97639 L F
0 g
.54651 .9368 m
.54976 .95234 L
s
.60688 .77313 m .60255 .76285 L .60089 .7699 L 0 1 .396 r
F
.60688 .77313 m .61136 .7555 L .60255 .76285 L F
.60242 .79238 m .60688 .77313 L .59841 .78095 L 0 1 .381 r
F
0 g
.60684 .77311 m
.60688 .77313 L
s
.26731 .91053 m .26305 .90518 L .25687 .90447 L 0 .444 .256 r
F
.26731 .91053 m .27071 .90773 L .26305 .90518 L F
.26731 .91053 m .27472 .91041 L .27071 .90773 L F
.26731 .91053 m .27325 .91161 L .27472 .91041 L F
0 g
.2597 .90799 m
.26731 .91053 L
s
.26607 .91137 m
.26731 .91053 L
s
.553 .93998 m .55054 .91973 L .54939 .92511 L 0 .427 .303 r
F
0 g
.54774 .92358 m
.54939 .92511 L
s
.54378 .87241 m .53928 .85767 L .53865 .86241 L 0 .694 .373 r
F
0 g
.53249 .8603 m
.53865 .86241 L
s
.60242 .79238 m .59841 .78095 L .59676 .78862 L 0 1 .381 r
F
.59698 .81873 m .60242 .79238 L .59402 .80221 L 0 1 .364 r
F
0 g
.57475 1.07123 m
.57483 1.07551 L
s
.57498 1.08425 m
.57531 1.10254 L
s
.34564 .72672 m .33248 .72211 L .33529 .72551 L 0 1 .505 r
F
0 g
.33454 .72606 m
.33529 .72551 L
s
.72917 .81415 m .72897 .80444 L .72554 .80839 L 0 1 .5 r
F
.72917 .81415 m .73799 .80457 L .72897 .80444 L F
.42127 .75195 m .41016 .74605 L .41205 .74921 L 0 1 .517 r
F
0 g
.406 .75206 m
.41205 .74921 L
s
.6021 .85835 m
.6035 .85667 L
s
.6018 .85871 m
.6021 .85835 L
s
.59656 .86503 m
.6018 .85871 L
s
.46852 .87519 m .47355 .86076 L .46572 .85833 L 0 .758 .383 r
F
.46852 .87519 m .48002 .86793 L .47355 .86076 L F
.46852 .87519 m .48081 .87505 L .48002 .86793 L F
.46852 .87519 m .47588 .87816 L .48081 .87505 L F
0 g
.46206 .86803 m
.46852 .87519 L
s
.46394 .87806 m
.46852 .87519 L
s
.4296 .79177 m .41927 .78209 L .42111 .78739 L 0 .983 .442 r
F
0 g
.41572 .79097 m
.42111 .78739 L
s
.39036 .75415 m .37849 .74701 L .38083 .7513 L 0 1 .476 r
F
0 g
.37527 .75475 m
.38083 .7513 L
s
.31912 .84533 m .30686 .83784 L .31044 .84056 L 0 .357 .317 r
F
.68498 1.23787 m .68389 1.2288 L .68618 1.21186 L 0 0 .09 r
F
0 g
.68168 1.21382 m
.68618 1.21186 L
s
.53722 1.10855 m
.53743 1.11423 L
s
.66054 1.26177 m
.6606 1.26171 L
s
.23597 .8916 m .22356 .88736 L .22781 .88987 L 0 .571 .374 r
F
0 g
.22696 .89268 m
.22781 .88987 L
s
.46358 .77335 m
.47174 .7783 L
s
.65094 .9036 m .66511 .8882 L .65811 .88633 L 0 1 .393 r
F
0 g
.66511 .8882 m
.66801 .89459 L
s
.64381 .92349 m .65013 .92472 L .65717 .91983 L 0 1 .368 r
F
0 g
.65603 .92062 m
.65717 .91983 L
s
.65717 .91983 m
.65902 .92381 L
s
.65406 .9306 m
.65902 .92381 L
s
.61136 .7555 m .6067 .74613 L .60504 .75266 L 0 1 .411 r
F
.61136 .7555 m .61587 .73922 L .6067 .74613 L F
0 g
.56069 1.23391 m
.56108 1.23619 L
s
.56108 1.23619 m
.56141 1.23817 L
s
.34563 .72724 m .33244 .72375 L .33525 .72684 L 0 1 .528 r
F
0 g
.33949 .73068 m
.34488 .72721 L
s
.3297 .7318 m
.33525 .72684 L
s
.47174 .7783 m
.47844 .77731 L
s
.46292 .84214 m .4545 .83006 L .45577 .83613 L 0 .871 .402 r
F
0 g
.45071 .83946 m
.45577 .83613 L
s
.49003 .79228 m
.49733 .79774 L
s
.62955 .69656 m .652 .68906 L .65417 .68414 L 0 1 .46 r
F
.62955 .69656 m .64147 .69438 L .652 .68906 L F
0 g
.652 .68906 m
.65877 .69054 L
s
.30149 .83363 m
.30237 .83545 L
s
.30237 .83545 m
.30686 .83784 L
s
.69098 .82673 m .70848 .82938 L .71188 .825 L 0 1 .474 r
F
.69098 .82673 m .69953 .83012 L .70848 .82938 L F
0 g
.70848 .82938 m
.71163 .83479 L
s
.42127 .75195 m .41691 .74386 L .41016 .74605 L 0 1 .517 r
F
.42127 .75195 m .42783 .74409 L .41691 .74386 L F
.42127 .75195 m .43709 .74684 L .42783 .74409 L F
.42127 .75195 m .43848 .75027 L .43709 .74684 L F
.42127 .75195 m .43169 .75246 L .43848 .75027 L F
0 g
.41488 .75387 m
.42127 .75195 L
s
.41205 .74921 m
.42127 .75195 L
s
.65114 .94593 m .65256 .93266 L .6495 .94201 L 0 1 .26 r
F
.64334 .97388 m .65114 .94593 L .64494 .95787 L 0 1 .195 r
F
.46572 .85833 m .47121 .84408 L .46292 .84214 L 0 .817 .392 r
F
.46572 .85833 m .47803 .85065 L .47121 .84408 L F
.46572 .85833 m .47883 .85747 L .47803 .85065 L F
.46572 .85833 m .47355 .86076 L .47883 .85747 L F
0 g
.45892 .85177 m
.46572 .85833 L
s
.46081 .86145 m
.46572 .85833 L
s
.26451 .81582 m
.2677 .8123 L
s
.61061 .9286 m
.61094 .92762 L
s
.62041 .72409 m .63642 .70754 L .62497 .70991 L 0 1 .437 r
F
0 g
.63642 .70754 m
.64337 .70993 L
s
.63642 .70754 m
.6466 .70186 L
s
.69056 .81199 m .68966 .80902 L .68674 .8177 L 0 .815 .1 r
F
0 g
.68795 .81588 m
.69056 .81199 L
s
.68736 .81965 m
.69056 .81199 L
s
.553 .93998 m .55623 .92505 L .55054 .91973 L 0 .427 .303 r
F
0 g
.54647 .90757 m
.55054 .91973 L
s
.29083 .82834 m .2825 .82348 L .28619 .8262 L 0 .702 .42 r
F
.60801 .96545 m .61371 .96099 L .61989 .94267 L 0 1 .254 r
F
0 g
.61371 .96099 m
.61537 .95607 L
s
.61537 .95607 m
.61711 .95091 L
s
.61711 .95091 m
.61778 .94892 L
s
.61778 .94892 m
.61803 .94819 L
s
.61803 .94819 m
.61989 .94267 L
s
.61881 .96288 m
.6193 .96047 L
s
.6178 .96795 m
.61881 .96288 L
s
.61989 .94267 m
.62011 .94332 L
s
.51511 1.07803 m
.51676 1.08825 L
s
.51676 1.08825 m
.51694 1.08935 L
s
.5133 1.07728 m
.51511 1.07803 L
s
.52642 .83137 m .5203 .81948 L .52015 .82362 L 0 .828 .42 r
F
0 g
.51363 .82271 m
.52015 .82362 L
s
.55137 .97767 m
.55295 .98095 L
s
.54378 .87241 m .54572 .85986 L .53928 .85767 L 0 .694 .373 r
F
0 g
.53371 .84897 m
.53928 .85767 L
s
.54378 .87241 m .55369 .86755 L .54572 .85986 L 0 .694 .373 r
F
.54378 .87241 m .55884 .87757 L .55369 .86755 L F
.54378 .87241 m .55774 .88322 L .55884 .87757 L F
.54378 .87241 m .55128 .881 L .55774 .88322 L F
0 g
.53769 .86947 m
.54378 .87241 L
s
.53865 .86241 m
.54378 .87241 L
s
.54837 1.11781 m .55391 1.20734 L .55014 1.1591 L 0 .823 .189 r
F
.54837 1.11781 m .55808 1.2381 L .55391 1.20734 L F
.54837 1.11781 m .55981 1.2302 L .55808 1.2381 L F
.54837 1.11781 m .55795 1.1879 L .55981 1.2302 L F
.54837 1.11781 m .5538 1.14008 L .55795 1.1879 L F
0 g
.55275 1.11875 m
.55292 1.12207 L
s
.54465 1.10069 m
.54837 1.11781 L
s
.55036 1.11496 m
.55117 1.12084 L
s
.4296 .79177 m .42534 .77827 L .41927 .78209 L 0 .983 .442 r
F
0 g
.41075 .77794 m
.41927 .78209 L
s
.23597 .8916 m .22551 .88495 L .22356 .88736 L 0 .571 .374 r
F
0 g
.21618 .8867 m
.22356 .88736 L
s
.49733 .79774 m
.50419 .79828 L
s
.46292 .84214 m .46011 .82662 L .4545 .83006 L 0 .871 .402 r
F
0 g
.44721 .82453 m
.4545 .83006 L
s
.32243 .92903 m .31089 .92803 L .31492 .92904 L 0 0 .007 r
F
0 g
.31413 .92987 m
.31492 .92904 L
s
.59698 .81873 m .59402 .80221 L .59201 .81265 L 0 1 .364 r
F
.59286 .84122 m .59698 .81873 L .58935 .82713 L 0 1 .348 r
F
.4296 .79177 m .43531 .77847 L .42534 .77827 L 0 .983 .442 r
F
.4296 .79177 m .44383 .78286 L .43531 .77847 L F
.4296 .79177 m .44519 .7885 L .44383 .78286 L F
.4296 .79177 m .43909 .79232 L .44519 .7885 L F
0 g
.42111 .78739 m
.4296 .79177 L
s
.74683 .79538 m .76492 .79136 L .7557 .78652 L 0 1 .509 r
F
0 g
.76492 .79136 m
.76898 .79745 L
s
.38498 .73757 m .37271 .73299 L .37508 .73609 L 0 1 .526 r
F
0 g
.37312 .73746 m
.37508 .73609 L
s
.31912 .84533 m .31046 .83748 L .30686 .83784 L 0 .357 .317 r
F
.39036 .75415 m .38487 .74316 L .37849 .74701 L 0 1 .476 r
F
0 g
.3691 .74441 m
.37849 .74701 L
s
.69098 .82673 m .71188 .825 L .70776 .81894 L 0 1 .474 r
F
0 g
.71188 .825 m
.72039 .8242 L
s
.54887 .89447 m
.55465 .89728 L
s
.52642 .83137 m .52717 .82062 L .5203 .81948 L 0 .828 .42 r
F
.52642 .83137 m .53618 .82627 L .52717 .82062 L F
.52642 .83137 m .54247 .83404 L .53618 .82627 L F
.52642 .83137 m .54183 .83873 L .54247 .83404 L F
.52642 .83137 m .53495 .83758 L .54183 .83873 L F
0 g
.51991 .82981 m
.52642 .83137 L
s
.52015 .82362 m
.52642 .83137 L
s
.34564 .72672 m .33896 .71787 L .33248 .72211 L 0 1 .505 r
F
0 g
.32519 .72167 m
.33248 .72211 L
s
.32777 .85293 m .32715 .84899 L .31912 .84533 L 0 .217 .213 r
F
.32777 .85293 m .33559 .85502 L .32715 .84899 L F
.32777 .85293 m .33877 .8594 L .33559 .85502 L F
.32777 .85293 m .3354 .85849 L .33877 .8594 L F
.64381 .92349 m .65759 .90512 L .65094 .9036 L 0 1 .368 r
F
0 g
.65759 .90512 m
.6649 .90126 L
s
.65759 .90512 m
.66025 .91207 L
s
.39036 .75415 m .39573 .74231 L .38487 .74316 L 0 1 .476 r
F
.39036 .75415 m .4053 .74517 L .39573 .74231 L F
.39036 .75415 m .40717 .74983 L .4053 .74517 L F
0 g
.40528 .74516 m
.41016 .74605 L
s
.39036 .75415 m .40076 .75367 L .40717 .74983 L 0 1 .476 r
F
0 g
.38432 .75787 m
.39036 .75415 L
s
.38083 .7513 m
.39036 .75415 L
s
.29083 .82834 m .28168 .82136 L .2825 .82348 L 0 .702 .42 r
F
.29083 .82834 m .28429 .82125 L .28168 .82136 L F
0 g
.27398 .8224 m
.2812 .82332 L
s
.2812 .82332 m
.28249 .82348 L
s
.29083 .82834 m .28894 .82339 L .28429 .82125 L 0 .702 .42 r
F
.29083 .82834 m .29253 .82636 L .28894 .82339 L F
.29083 .82834 m .29334 .82848 L .29253 .82636 L F
0 g
.29083 .82834 m
.29173 .83017 L
s
.28619 .8262 m
.29083 .82834 L
s
.69457 1.17587 m .70562 1.14156 L .70459 1.12903 L 0 1 .179 r
F
.69457 1.17587 m .70337 1.16435 L .70562 1.14156 L F
0 g
.70562 1.14156 m
.70904 1.14043 L
s
.61587 .73922 m .61089 .73057 L .60921 .73666 L 0 1 .425 r
F
.61587 .73922 m .62041 .72409 L .61089 .73057 L F
.62955 .69656 m .65417 .68414 L .64654 .68193 L 0 1 .46 r
F
0 g
.65417 .68414 m
.66452 .67852 L
s
.46292 .84214 m .46887 .82812 L .46011 .82662 L 0 .871 .402 r
F
.46292 .84214 m .47604 .83413 L .46887 .82812 L F
.46292 .84214 m .47684 .84065 L .47604 .83413 L F
.46292 .84214 m .47121 .84408 L .47684 .84065 L F
0 g
.45577 .83613 m
.46292 .84214 L
s
.45766 .84544 m
.46292 .84214 L
s
.64268 .99676 m
.64515 .98992 L
s
.64515 .98992 m
.64616 .9871 L
s
.56461 1.2224 m
.5647 1.22386 L
s
.56436 1.21859 m
.56461 1.2224 L
s
.56337 1.20334 m
.56436 1.21859 L
s
.5632 1.2007 m
.56337 1.20334 L
s
.56294 1.19671 m
.5632 1.2007 L
s
.66056 1.28751 m .66956 1.23266 L .67139 1.2485 L 0 .306 .164 r
F
0 g
.66879 1.23208 m
.66956 1.23266 L
s
.51366 .81272 m
.5203 .81948 L
s
.25687 .90447 m .25284 .8984 L .24642 .89813 L 0 .467 .299 r
F
.25687 .90447 m .26068 .90073 L .25284 .8984 L F
.25687 .90447 m .26469 .90358 L .26068 .90073 L F
.25687 .90447 m .26305 .90518 L .26469 .90358 L F
0 g
.24908 .90214 m
.25687 .90447 L
s
.25545 .90568 m
.25687 .90447 L
s
.34564 .72672 m .35043 .71563 L .33896 .71787 L 0 1 .505 r
F
.34564 .72672 m .36084 .71684 L .35043 .71563 L F
.34564 .72672 m .35668 .72293 L .36084 .71684 L F
.35775 .72136 m .3621 .7189 L .36084 .71684 L F
.35668 .72293 m .3621 .7189 L .35775 .72136 L F
.37382 .72167 m .36519 .71869 L .36321 .72039 L 0 1 .525 r
F
.37941 .72969 m .37382 .72167 L .36678 .72515 L F
.37381 .72238 m .36519 .71869 L .3632 .72069 L 0 1 .495 r
F
.36519 .71869 m .36084 .71684 L .3621 .7189 L F
.36519 .71869 m .36341 .71881 L .36321 .72039 L 0 1 .525 r
F
.3635 .71811 m .3621 .7189 L .36321 .72039 L F
.35668 .72293 m .35668 .72469 L .36321 .72039 L 0 1 .528 r
F
.34564 .72672 m .35324 .72549 L .35668 .72293 L 0 1 .505 r
F
.34563 .72724 m .35324 .72549 L .35668 .72293 L 0 1 .528 r
F
.35324 .72549 m .35668 .72469 L .35668 .72293 L F
.35668 .72293 m .35668 .72493 L .3632 .72069 L 0 1 .505 r
F
.35324 .72549 m .35668 .72493 L .35668 .72293 L F
.36519 .71869 m .3621 .7189 L .3632 .72069 L 0 1 .495 r
F
.36519 .71869 m .3635 .71811 L .36341 .71881 L 0 1 .525 r
F
.3635 .71811 m .36083 .71719 L .3621 .7189 L F
.34563 .72724 m .35668 .72293 L .36083 .71719 L 0 1 .528 r
F
.35668 .72293 m .36321 .72039 L .3621 .7189 L F
.35668 .72293 m .3621 .7189 L .36083 .71719 L F
.35668 .72293 m .3632 .72069 L .3621 .7189 L 0 1 .505 r
F
0 g
.34506 .72709 m
.34564 .72672 L
s
.34209 .72631 m
.34564 .72672 L
s
.68498 1.23787 m .69521 1.19586 L .69295 1.21275 L 0 0 .09 r
F
0 g
.69521 1.19586 m
.69739 1.19137 L
s
.73799 .80457 m .73755 .79485 L .73411 .79864 L 0 1 .505 r
F
.73799 .80457 m .74683 .79538 L .73755 .79485 L F
.69457 1.17587 m .70459 1.12903 L .70084 1.13387 L 0 1 .179 r
F
0 g
.70352 1.16286 m
.70562 1.14156 L
s
.70459 1.12903 m
.70687 1.10875 L
s
.70085 1.13356 m
.70219 1.10244 L
s
.46011 .82662 m .45134 .8153 L .45261 .82113 L 0 .922 .411 r
F
0 g
.44721 .82453 m
.45261 .82113 L
s
.34563 .72724 m .33891 .71944 L .33244 .72375 L 0 1 .528 r
F
0 g
.32237 .72409 m
.33244 .72375 L
s
.33525 .72684 m
.34561 .72724 L
s
.34563 .72724 m .3504 .71679 L .33891 .71944 L 0 1 .528 r
F
.34563 .72724 m .36083 .71719 L .3504 .71679 L F
0 g
.33947 .73145 m
.34563 .72724 L
s
.34561 .72724 m
.34563 .72724 L
s
.45071 .76265 m .44057 .75537 L .44196 .75874 L 0 1 .503 r
F
0 g
.43554 .76066 m
.44196 .75874 L
s
.55623 .92505 m .55333 .90591 L .55223 .91149 L 0 .555 .323 r
F
0 g
.55131 .91087 m
.55223 .91149 L
s
.57341 1.11371 m
.57353 1.11586 L
s
.5709 1.07076 m
.5711 1.07415 L
s
.57111 1.07428 m
.57113 1.07466 L
s
.63675 .94702 m .65256 .93266 L .65013 .92472 L 0 1 .341 r
F
.63675 .94702 m .6495 .94201 L .65256 .93266 L F
0 g
.65256 .93266 m
.65406 .9306 L
s
.50078 1.04089 m .4966 1.02371 L .49747 1.02942 L 0 .028 .159 r
F
0 g
.49606 1.02818 m
.49747 1.02942 L
s
.69884 .81524 m .71699 .81861 L .72041 .81446 L 0 1 .482 r
F
.69884 .81524 m .70776 .81894 L .71699 .81861 L F
0 g
.71699 .81861 m
.72039 .8242 L
s
.38498 .73757 m .37941 .72969 L .37271 .73299 L 0 1 .526 r
F
0 g
.3658 .73265 m
.37271 .73299 L
s
.38498 .73757 m .39074 .72838 L .37941 .72969 L 0 1 .526 r
F
.38498 .73757 m .40068 .72987 L .39074 .72838 L F
.38498 .73757 m .40258 .73315 L .40068 .72987 L F
.38498 .73757 m .39584 .73645 L .40258 .73315 L F
0 g
.37863 .74068 m
.38498 .73757 L
s
.37508 .73609 m
.38498 .73757 L
s
.52648 1.09957 m .52716 1.12211 L .52592 1.10674 L 0 .881 .113 r
F
0 g
.52378 1.09274 m
.52592 1.10674 L
s
.52648 1.09957 m .52998 1.14217 L .52716 1.12211 L 0 .881 .113 r
F
.52648 1.09957 m .53249 1.15349 L .52998 1.14217 L F
.52648 1.09957 m .53305 1.14616 L .53249 1.15349 L F
.52648 1.09957 m .53127 1.12519 L .53305 1.14616 L F
0 g
.53304 1.10304 m
.53319 1.11165 L
s
.52648 1.09957 m .52847 1.10529 L .53127 1.12519 L 0 .881 .113 r
F
0 g
.5262 1.09756 m
.52648 1.09957 L
s
.52592 1.10674 m
.52648 1.09957 L
s
.52847 1.10529 m
.52864 1.09376 L
s
.60479 .92441 m
.60479 .92441 L
s
.69618 1.19681 m .69608 1.19815 L .69909 1.18787 L 0 .751 .066 r
F
.42534 .77827 m .41463 .76925 L .41649 .77431 L 0 1 .45 r
F
0 g
.41075 .77794 m
.41649 .77431 L
s
.45071 .76265 m .44762 .75398 L .44057 .75537 L 0 1 .503 r
F
.45071 .76265 m .45843 .75552 L .44762 .75398 L F
.45071 .76265 m .46721 .75943 L .45843 .75552 L F
.45071 .76265 m .46809 .76311 L .46721 .75943 L F
.45071 .76265 m .46101 .76448 L .46809 .76311 L F
0 g
.44404 .76375 m
.45071 .76265 L
s
.44196 .75874 m
.45071 .76265 L
s
.46011 .82662 m .4573 .81175 L .45134 .8153 L 0 .922 .411 r
F
0 g
.44371 .81021 m
.45134 .8153 L
s
.59656 .86503 m
.59659 .8651 L
s
.553 .93998 m .56267 .93758 L .55623 .92505 L 0 .427 .303 r
F
.553 .93998 m .5663 .9525 L .56267 .93758 L F
.553 .93998 m .56468 .95985 L .5663 .9525 L F
.553 .93998 m .55897 .95446 L .56468 .95985 L F
0 g
.54766 .93243 m
.553 .93998 L
s
.54939 .92511 m
.553 .93998 L
s
.32243 .92903 m .31242 .93105 L .31089 .92803 L 0 0 .007 r
F
0 g
.3039 .92667 m
.31089 .92803 L
s
.5787 .79652 m .59676 .78862 L .59841 .78095 L 0 1 .39 r
F
0 g
.59609 .79978 m
.60242 .79238 L
s
.5787 .79652 m .58832 .79529 L .59676 .78862 L 0 1 .39 r
F
0 g
.59676 .78862 m
.60242 .79238 L
s
.5787 .79652 m .59841 .78095 L .59209 .7763 L 0 1 .39 r
F
0 g
.58832 .79529 m
.59485 .79014 L
s
.59485 .79014 m
.59676 .78862 L
s
.59841 .78095 m
.60688 .77313 L
s
.54572 .85986 m .54087 .84581 L .54024 .85055 L 0 .784 .388 r
F
0 g
.53371 .84897 m
.54024 .85055 L
s
.66056 1.28751 m .65873 1.26529 L .66063 1.24037 L 0 .306 .164 r
F
0 g
.65623 1.23535 m
.66063 1.24037 L
s
.55623 .92505 m .55931 .90983 L .55333 .90591 L 0 .555 .323 r
F
0 g
.55622 .92505 m
.55623 .92505 L
s
.55054 .91973 m
.55622 .92505 L
s
.54887 .89447 m
.55333 .90591 L
s
.55223 .91149 m
.55623 .92505 L
s
.55412 1.00744 m .55881 1.00874 L .55384 .99061 L 0 .084 .173 r
F
0 g
.55137 .97767 m
.55384 .99061 L
s
.46011 .82662 m .46652 .81285 L .4573 .81175 L 0 .922 .411 r
F
0 g
.45134 .8153 m
.4573 .81175 L
s
.46011 .82662 m .47404 .81835 L .46652 .81285 L 0 .922 .411 r
F
.46011 .82662 m .47484 .82457 L .47404 .81835 L F
.46011 .82662 m .46887 .82812 L .47484 .82457 L F
0 g
.4545 .83006 m
.46011 .82662 L
s
.45261 .82113 m
.46011 .82662 L
s
.59286 .84122 m .58935 .82713 L .58783 .836 L 0 1 .348 r
F
.68315 .83898 m .69953 .83012 L .69098 .82673 L 0 1 .465 r
F
0 g
.69953 .83012 m
.70338 .83616 L
s
.69953 .83012 m
.70848 .82938 L
s
.69884 .81524 m .72041 .81446 L .71602 .80836 L 0 1 .482 r
F
0 g
.72041 .81446 m
.72917 .81415 L
s
.5133 1.07728 m
.51346 1.07794 L
s
.31046 .83748 m .29791 .83075 L .30149 .83363 L 0 .49 .389 r
F
.58199 .77777 m .60089 .7699 L .60255 .76285 L 0 1 .403 r
F
.58199 .77777 m .59209 .7763 L .60089 .7699 L F
0 g
.60089 .7699 m
.60684 .77311 L
s
.57468 .82179 m .59402 .80221 L .58832 .7953 L 0 1 .374 r
F
0 g
.59228 .82391 m
.59698 .81873 L
s
.57468 .82179 m .59201 .81265 L .59402 .80221 L 0 1 .374 r
F
0 g
.59252 .81328 m
.59698 .81873 L
s
.59402 .80221 m
.59609 .79978 L
s
.38487 .74316 m .37263 .73661 L .37498 .74072 L 0 1 .483 r
F
0 g
.3691 .74441 m
.37498 .74072 L
s
.62497 .70991 m .64147 .69438 L .62955 .69656 L 0 1 .449 r
F
0 g
.64147 .69438 m
.64876 .69665 L
s
.64147 .69438 m
.652 .68906 L
s
.60227 .89065 m
.60283 .89163 L
s
.5962 .90414 m
.59774 .90123 L
s
.59973 .89748 m
.60283 .89163 L
s
.62041 .72409 m .61509 .71599 L .61341 .72171 L 0 1 .437 r
F
.62041 .72409 m .62497 .70991 L .61509 .71599 L F
.63415 .6839 m .65743 .67695 L .65961 .67228 L 0 1 .469 r
F
.63415 .6839 m .64654 .68193 L .65743 .67695 L F
0 g
.65743 .67695 m
.66452 .67852 L
s
.59304 1.37727 m
.59308 1.37966 L
s
.55412 1.00744 m .56577 1.0501 L .56374 1.03233 L 0 .084 .173 r
F
.55412 1.00744 m .56354 1.05006 L .56577 1.0501 L F
.55412 1.00744 m .55854 1.03172 L .56354 1.05006 L F
0 g
.55211 .98988 m
.55412 1.00744 L
s
.55197 .99635 m
.55412 1.00744 L
s
.50078 1.04089 m .499 1.02658 L .4966 1.02371 L 0 .028 .159 r
F
0 g
.49296 1.01351 m
.4966 1.02371 L
s
.58199 .77777 m .60255 .76285 L .59587 .75877 L 0 1 .403 r
F
0 g
.60255 .76285 m
.61136 .7555 L
s
.43169 .75246 m
.44057 .75537 L
s
.50562 1.05799 m
.50567 1.0581 L
s
.50562 1.05799 m
.50607 1.05905 L
s
.50607 1.05905 m
.50819 1.06404 L
s
.57468 .82179 m .58373 .82104 L .59201 .81265 L 0 1 .374 r
F
0 g
.58952 .81517 m
.59201 .81265 L
s
.59201 .81265 m
.59252 .81328 L
s
.33896 .71787 m .32545 .71373 L .32827 .71706 L 0 1 .509 r
F
0 g
.32713 .71793 m
.32827 .71706 L
s
.54572 .85986 m .54767 .84743 L .54087 .84581 L 0 .784 .388 r
F
0 g
.53495 .83758 m
.54087 .84581 L
s
.54572 .85986 m .5561 .85435 L .54767 .84743 L 0 .784 .388 r
F
.54572 .85986 m .5616 .86368 L .5561 .85435 L F
.54572 .85986 m .5605 .86919 L .5616 .86368 L F
.54572 .85986 m .55369 .86755 L .5605 .86919 L F
0 g
.53928 .85767 m
.54572 .85986 L
s
.54024 .85055 m
.54572 .85986 L
s
.42534 .77827 m .42107 .76535 L .41463 .76925 L 0 1 .45 r
F
0 g
.40577 .76553 m
.41463 .76925 L
s
.42534 .77827 m .43152 .76523 L .42107 .76535 L 0 1 .45 r
F
.42534 .77827 m .44041 .76918 L .43152 .76523 L F
.42534 .77827 m .44178 .77458 L .44041 .76918 L F
.42534 .77827 m .43531 .77847 L .44178 .77458 L F
0 g
.41927 .78209 m
.42534 .77827 L
s
.41649 .77431 m
.42534 .77827 L
s
.32243 .92903 m .31853 .93612 L .31242 .93105 L 0 0 .007 r
F
.32243 .92903 m .32609 .93612 L .31853 .93612 L F
.32243 .92903 m .33001 .93103 L .32609 .93612 L F
.32243 .92903 m .32843 .928 L .33001 .93103 L F
.63675 .94702 m .65013 .92472 L .64381 .92349 L 0 1 .341 r
F
0 g
.65013 .92472 m
.65256 .93266 L
s
.6495 .94202 m
.64951 .94202 L
s
.64951 .94202 m
.65114 .94593 L
s
.64653 .95481 m
.64654 .95479 L
s
.65013 .92472 m
.65603 .92062 L
s
.29253 .82636 m
.29334 .82848 L
s
.29334 .82848 m
.2979 .83075 L
s
.47844 .77731 m .4694 .7686 L .47028 .77225 L 0 1 .484 r
F
0 g
.46358 .77335 m
.47028 .77225 L
s
.50419 .79828 m .49632 .78641 L .49675 .7913 L 0 .955 .459 r
F
.50419 .79828 m .50358 .7857 L .49632 .78641 L F
0 g
.49003 .79228 m
.49675 .7913 L
s
.50419 .79828 m .51372 .78964 L .50358 .7857 L 0 .955 .459 r
F
.50419 .79828 m .52118 .79664 L .51372 .78964 L F
.50419 .79828 m .52097 .80202 L .52118 .79664 L F
.50419 .79828 m .51368 .80272 L .52097 .80202 L F
0 g
.49675 .7913 m
.50419 .79828 L
s
.65811 .88632 m .66759 .86652 L .65925 .8708 L 0 1 .418 r
F
.66759 .86652 m .66723 .85451 L .66424 .86036 L 0 1 .438 r
F
.66759 .86652 m .67535 .85215 L .66723 .85451 L F
.24642 .89813 m .24262 .89139 L .23597 .8916 L 0 .498 .34 r
F
.24642 .89813 m .25065 .89344 L .24262 .89139 L F
.24642 .89813 m .25467 .89639 L .25065 .89344 L F
.24642 .89813 m .25284 .8984 L .25467 .89639 L F
0 g
.23845 .89608 m
.24642 .89813 L
s
.24483 .89974 m
.24642 .89813 L
s
.28168 .82136 m .27326 .81654 L .27695 .81935 L 0 .838 .459 r
F
.63675 .94702 m .64273 .94818 L .6495 .94201 L 0 1 .341 r
F
0 g
.64821 .94319 m
.6495 .94201 L
s
.64654 .95479 m
.65114 .94593 L
s
.6495 .94201 m
.6495 .94202 L
s
.4573 .81175 m .44747 .79819 L .44914 .80547 L 0 .973 .421 r
F
0 g
.44371 .81021 m
.44914 .80547 L
s
.47844 .77731 m .47664 .76794 L .4694 .7686 L 0 1 .484 r
F
.47844 .77731 m .48718 .7707 L .47664 .76794 L F
.47844 .77731 m .49537 .77577 L .48718 .7707 L F
.47844 .77731 m .49572 .77976 L .49537 .77577 L F
.47844 .77731 m .48846 .78041 L .49572 .77976 L F
0 g
.47028 .77225 m
.47844 .77731 L
s
.65811 .88632 m .65925 .8708 L .6556 .87887 L 0 1 .418 r
F
.65094 .9036 m .65811 .88633 L .65078 .89018 L 0 1 .393 r
F
.58529 .76039 m .60504 .75266 L .6067 .74613 L 0 1 .416 r
F
.58529 .76039 m .59587 .75877 L .60504 .75266 L F
0 g
.60504 .75266 m
.61136 .7555 L
s
.68199 .83717 m
.68199 .83717 L
s
.6816 .83939 m
.68164 .83929 L
s
.68164 .83929 m
.68167 .83921 L
s
.68167 .83921 m
.68225 .83759 L
s
.4903 .92188 m .48398 .90468 L .48477 .91236 L 0 .65 .349 r
F
0 g
.48053 .91492 m
.48415 .92114 L
s
.4903 .92188 m .48868 .90206 L .48398 .90468 L 0 .65 .349 r
F
0 g
.48053 .91492 m
.48477 .91236 L
s
.4782 .89624 m
.48398 .90468 L
s
.48868 .90206 m .482 .88595 L .48279 .89337 L 0 .725 .36 r
F
0 g
.4782 .89624 m
.48279 .89337 L
s
.55931 .90983 m .55608 .89174 L .55498 .89744 L 0 .662 .34 r
F
0 g
.55465 .89728 m
.55498 .89744 L
s
.74683 .79538 m .74617 .78562 L .74272 .78927 L 0 1 .509 r
F
.74683 .79538 m .7557 .78652 L .74617 .78562 L F
.48868 .90206 m .48705 .88295 L .482 .88595 L 0 .725 .36 r
F
0 g
.47588 .87816 m
.482 .88595 L
s
.492 .94319 m .48598 .92429 L .48681 .93253 L 0 .563 .337 r
F
0 g
.48295 .93493 m
.48613 .94118 L
s
.492 .94319 m .4903 .92189 L .48598 .92429 L 0 .563 .337 r
F
0 g
.48295 .93493 m
.48681 .93253 L
s
.48415 .92114 m
.48598 .92429 L
s
.70673 .80435 m .72554 .80839 L .72897 .80444 L 0 1 .489 r
F
.70673 .80435 m .71602 .80836 L .72554 .80839 L F
0 g
.72554 .80839 m
.72917 .81415 L
s
.31046 .83748 m .30178 .82948 L .29791 .83075 L 0 .49 .389 r
F
0 g
.52847 1.10529 m
.52857 1.10605 L
s
.57164 .84299 m .58935 .82713 L .58372 .82105 L 0 1 .359 r
F
.57164 .84299 m .58783 .836 L .58935 .82713 L F
0 g
.58845 .83664 m
.59286 .84122 L
s
.58858 .84635 m
.59286 .84122 L
s
.58935 .82713 m
.59228 .82391 L
s
.48705 .88295 m .48002 .86793 L .48081 .87505 L 0 .793 .371 r
F
0 g
.47588 .87816 m
.48081 .87505 L
s
.31912 .84533 m .31887 .83975 L .31046 .83748 L 0 .357 .317 r
F
.31912 .84533 m .32761 .84454 L .31887 .83975 L F
.31912 .84533 m .3308 .84866 L .32761 .84454 L F
.31912 .84533 m .32715 .84899 L .3308 .84866 L F
0 g
.31044 .84056 m
.31912 .84533 L
s
.31581 .84446 m
.31912 .84533 L
s
.67535 .85215 m .67474 .84071 L .67173 .84608 L 0 1 .453 r
F
.499 1.02658 m .49444 1.00676 L .4953 1.014 L 0 .177 .237 r
F
0 g
.49296 1.01351 m
.4953 1.014 L
s
.33891 .71944 m .32538 .716 L .3282 .7191 L 0 1 .527 r
F
0 g
.33248 .72211 m
.33667 .71937 L
s
.32237 .72409 m
.3282 .7191 L
s
.55623 .92505 m .5662 .92067 L .55931 .90983 L 0 .555 .323 r
F
.55623 .92505 m .57022 .93427 L .5662 .92067 L F
.55623 .92505 m .56868 .94154 L .57022 .93427 L F
.55623 .92505 m .56267 .93758 L .56868 .94154 L F
0 g
.55623 .92505 m
.55623 .92505 L
s
.63415 .6839 m .65961 .67228 L .65164 .67008 L 0 1 .469 r
F
0 g
.65961 .67228 m
.6703 .66711 L
s
.28168 .82136 m .27251 .81419 L .27326 .81654 L 0 .838 .459 r
F
.28168 .82136 m .27522 .81386 L .27251 .81419 L F
0 g
.26451 .81582 m
.27155 .8164 L
s
.27155 .8164 m
.27325 .81654 L
s
.28168 .82136 m .27996 .81588 L .27522 .81386 L 0 .838 .459 r
F
.28168 .82136 m .28355 .8189 L .27996 .81588 L F
.28168 .82136 m .28429 .82125 L .28355 .8189 L F
0 g
.28168 .82136 m
.2825 .82348 L
s
.27695 .81935 m
.28168 .82136 L
s
.58529 .76039 m .6067 .74613 L .59968 .74249 L 0 1 .416 r
F
0 g
.6067 .74613 m
.61587 .73922 L
s
.38487 .74316 m .37935 .73259 L .37263 .73661 L 0 1 .483 r
F
0 g
.3629 .7345 m
.37263 .73661 L
s
.48705 .88295 m .48542 .86464 L .48002 .86793 L 0 .793 .371 r
F
0 g
.47355 .86076 m
.48002 .86793 L
s
.4573 .81175 m .45358 .79319 L .44747 .79819 L 0 .973 .421 r
F
0 g
.43909 .79232 m
.44747 .79819 L
s
.4573 .81175 m .46342 .79381 L .45358 .79319 L 0 .973 .421 r
F
.4573 .81175 m .4716 .8001 L .46342 .79381 L F
.4573 .81175 m .47265 .80786 L .4716 .8001 L F
.4573 .81175 m .46652 .81285 L .47265 .80786 L F
0 g
.44914 .80547 m
.4573 .81175 L
s
.49369 .96478 m .48805 .94495 L .48887 .95328 L 0 .463 .323 r
F
0 g
.48537 .95516 m
.48797 .96106 L
s
.49369 .96478 m .492 .94319 L .48805 .94495 L 0 .463 .323 r
F
0 g
.48537 .95515 m
.48887 .95328 L
s
.48613 .94118 m
.48805 .94495 L
s
.52717 .82062 m .5207 .80915 L .52054 .81328 L 0 .902 .432 r
F
0 g
.51366 .81272 m
.52054 .81328 L
s
.41691 .74386 m .40543 .73803 L .40732 .74126 L 0 1 .518 r
F
0 g
.40157 .74405 m
.40732 .74126 L
s
.50078 1.04089 m .50308 1.03614 L .499 1.02658 L 0 .028 .159 r
F
.50078 1.04089 m .50641 1.04765 L .50308 1.03614 L F
.50078 1.04089 m .50677 1.05342 L .50641 1.04765 L F
.50078 1.04089 m .50435 1.0505 L .50677 1.05342 L F
0 g
.49877 1.0363 m
.50078 1.04089 L
s
.49747 1.02942 m
.50078 1.04089 L
s
.38487 .74316 m .39068 .73136 L .37935 .73259 L 0 1 .483 r
F
.38487 .74316 m .40061 .73381 L .39068 .73136 L F
.38487 .74316 m .40249 .7383 L .40061 .73381 L F
.38487 .74316 m .39573 .74231 L .40249 .7383 L F
0 g
.37849 .74701 m
.38487 .74316 L
s
.37498 .74072 m
.38487 .74316 L
s
.57468 .82179 m .58832 .7953 L .5787 .79653 L 0 1 .374 r
F
0 g
.58373 .82104 m
.58952 .81517 L
s
.58832 .7953 m
.59402 .80221 L
s
.69098 .82673 m .70776 .81894 L .69884 .81524 L 0 1 .474 r
F
0 g
.70776 .81894 m
.71188 .825 L
s
.70776 .81894 m
.71699 .81861 L
s
.499 1.02658 m .49723 1.00804 L .49444 1.00676 L 0 .177 .237 r
F
0 g
.49043 .99579 m
.49444 1.00676 L
s
.55931 .90983 m .5624 .89451 L .55608 .89174 L 0 .662 .34 r
F
0 g
.55128 .881 m
.55608 .89174 L
s
.52717 .82062 m .52793 .80993 L .5207 .80915 L 0 .902 .432 r
F
.52717 .82062 m .53742 .81511 L .52793 .80993 L F
.52717 .82062 m .54407 .82245 L .53742 .81511 L F
.52717 .82062 m .54343 .82707 L .54407 .82245 L F
.52717 .82062 m .53618 .82627 L .54343 .82707 L F
0 g
.5203 .81948 m
.52717 .82062 L
s
.52054 .81328 m
.52717 .82062 L
s
.44747 .79819 m
.45358 .79319 L
s
.65094 .9036 m .65078 .89018 L .64801 .89719 L 0 1 .393 r
F
.64381 .92349 m .65094 .9036 L .64388 .90848 L 0 1 .368 r
F
.31242 .93105 m .30082 .92468 L .30485 .92616 L 0 0 0 r
F
0 g
.3039 .92667 m
.30418 .92652 L
s
.48542 .86464 m .47803 .85065 L .47883 .85747 L 0 .855 .381 r
F
0 g
.47355 .86076 m
.47883 .85747 L
s
.57164 .84299 m .58024 .84279 L .58783 .836 L 0 1 .359 r
F
0 g
.58573 .83788 m
.58783 .836 L
s
.58783 .836 m
.58845 .83664 L
s
.5787 .79652 m .59209 .7763 L .58199 .77777 L 0 1 .39 r
F
0 g
.59209 .7763 m
.59841 .78095 L
s
.59209 .7763 m
.60089 .7699 L
s
.49546 .987 m .49013 .96596 L .49099 .97454 L 0 .347 .306 r
F
0 g
.4879 .97598 m
.49012 .98161 L
s
.49546 .987 m .49369 .96478 L .49013 .96596 L 0 .347 .306 r
F
0 g
.4879 .97598 m
.49099 .97454 L
s
.48797 .96106 m
.49013 .96596 L
s
.56294 1.2378 m
.56353 1.23986 L
s
.56361 1.24015 m
.56435 1.24273 L
s
.56294 1.2378 m
.5637 1.24227 L
s
.56383 1.24302 m
.56385 1.24315 L
s
.56385 1.24315 m
.5647 1.24814 L
s
.33896 .71787 m .33225 .70922 L .32545 .71373 L 0 1 .509 r
F
0 g
.3151 .71357 m
.32545 .71373 L
s
.46101 .76448 m
.4694 .7686 L
s
.70673 .80435 m .72897 .80444 L .72431 .79826 L 0 1 .489 r
F
0 g
.72897 .80444 m
.73799 .80457 L
s
.49723 1.00804 m .49229 .98708 L .49315 .99522 L 0 .267 .28 r
F
0 g
.49043 .99579 m
.49315 .99522 L
s
.55899 1.04385 m .56015 1.04167 L .55786 1.03058 L 0 0 .072 r
F
0 g
.55786 1.03058 m
.55791 1.03115 L
s
.55791 1.03115 m
.55797 1.03194 L
s
.55505 1.01604 m
.55786 1.03058 L
s
.49723 1.00804 m .49546 .987 L .49229 .98708 L 0 .267 .28 r
F
0 g
.49012 .98161 m
.49229 .98708 L
s
.42107 .76535 m .40998 .75696 L .41184 .76181 L 0 1 .459 r
F
0 g
.40577 .76553 m
.41184 .76181 L
s
.48542 .86464 m .48379 .84715 L .47803 .85065 L 0 .855 .381 r
F
0 g
.47121 .84408 m
.47803 .85065 L
s
.41691 .74386 m .41255 .73561 L .40543 .73803 L 0 1 .518 r
F
.41691 .74386 m .42396 .7356 L .41255 .73561 L F
.41691 .74386 m .43359 .7382 L .42396 .7356 L F
.41691 .74386 m .43499 .74167 L .43359 .7382 L F
.41691 .74386 m .42783 .74409 L .43499 .74167 L F
0 g
.41016 .74605 m
.41691 .74386 L
s
.40732 .74126 m
.41691 .74386 L
s
.62497 .70991 m .61931 .70226 L .61762 .70765 L 0 1 .449 r
F
.62497 .70991 m .62955 .69656 L .61931 .70226 L F
0 g
.55527 .96876 m
.55834 .97314 L
s
.58862 .74418 m .60921 .73666 L .61089 .73057 L 0 1 .428 r
F
.58862 .74418 m .59968 .74249 L .60921 .73666 L F
0 g
.60921 .73666 m
.61587 .73922 L
s
.57164 .84299 m .58372 .82105 L .57468 .82179 L 0 1 .359 r
F
0 g
.58372 .82105 m
.58935 .82713 L
s
.68199 .83717 m
.68315 .83898 L
s
.68199 .83717 m
.68199 .83717 L
s
.68164 .83929 m
.68315 .83898 L
s
.68156 .8393 m
.68164 .83929 L
s
.68061 .8395 m
.68156 .8393 L
s
.40215 .73749 m
.40543 .73803 L
s
.33896 .71787 m .34416 .70654 L .33225 .70922 L 0 1 .509 r
F
.33896 .71787 m .35491 .70736 L .34416 .70654 L F
.33896 .71787 m .35728 .71112 L .35491 .70736 L F
.33896 .71787 m .35043 .71563 L .35728 .71112 L F
0 g
.33009 .7172 m
.33896 .71787 L
s
.33722 .71901 m
.33896 .71787 L
s
.54466 1.1288 m .5462 1.12574 L .55014 1.1591 L 0 .867 .18 r
F
0 g
.54494 1.10531 m
.5462 1.12574 L
s
.23597 .8916 m .2324 .88425 L .22551 .88495 L 0 .571 .374 r
F
0 g
.22356 .88736 m
.22551 .88495 L
s
.23597 .8916 m .24061 .88597 L .2324 .88425 L 0 .571 .374 r
F
.23597 .8916 m .24463 .88898 L .24061 .88597 L F
.23597 .8916 m .24262 .89139 L .24463 .88898 L F
0 g
.22781 .88987 m
.23597 .8916 L
s
.2342 .89361 m
.23597 .8916 L
s
.37941 .72969 m .36678 .72515 L .36915 .7283 L 0 1 .525 r
F
0 g
.36817 .72897 m
.36915 .7283 L
s
.51368 .80272 m
.5207 .80915 L
s
.48705 .88295 m .49343 .8674 L .48542 .86464 L 0 .793 .371 r
F
.48705 .88295 m .49969 .87531 L .49343 .8674 L F
.48705 .88295 m .50001 .8831 L .49969 .87531 L F
.48705 .88295 m .49459 .88638 L .50001 .8831 L F
.48868 .90206 m .49459 .88638 L .48705 .88295 L 0 .725 .36 r
F
0 g
.48081 .87505 m
.48705 .88295 L
s
.482 .88595 m
.48705 .88295 L
s
.48868 .90206 m .50049 .89508 L .49459 .88638 L 0 .725 .36 r
F
.48868 .90206 m .50081 .90325 L .50049 .89508 L F
.48868 .90206 m .49574 .90624 L .50081 .90325 L F
.4903 .92188 m .49574 .90624 L .48868 .90206 L 0 .65 .349 r
F
0 g
.48279 .89337 m
.48868 .90206 L
s
.48398 .90468 m
.48868 .90206 L
s
.55931 .90983 m .56974 .90393 L .5624 .89451 L 0 .662 .34 r
F
.55931 .90983 m .57409 .91635 L .56974 .90393 L F
.55931 .90983 m .57254 .92348 L .57409 .91635 L F
.55931 .90983 m .5662 .92067 L .57254 .92348 L F
0 g
.55498 .89744 m
.55931 .90983 L
s
.55333 .90591 m
.55931 .90983 L
s
.48379 .84715 m .47604 .83413 L .47684 .84065 L 0 .913 .391 r
F
0 g
.47121 .84408 m
.47684 .84065 L
s
.58199 .77777 m .59587 .75877 L .58529 .76039 L 0 1 .403 r
F
0 g
.59587 .75877 m
.60255 .76285 L
s
.59587 .75877 m
.60504 .75266 L
s
.35702 .72471 m
.36678 .72515 L
s
.54767 .84743 m .54247 .83404 L .54183 .83873 L 0 .863 .402 r
F
0 g
.53495 .83758 m
.54183 .83873 L
s
.62955 .69656 m .64654 .68193 L .63415 .6839 L 0 1 .46 r
F
0 g
.64654 .68193 m
.65417 .68414 L
s
.64654 .68193 m
.65743 .67695 L
s
.68878 .7828 m .70883 .76083 L .71181 .75444 L 0 1 .255 r
F
0 g
.70114 .78139 m
.70486 .77461 L
s
.70261 .77653 m
.7052 .77362 L
s
.7055 .76909 m
.71343 .7564 L
s
.68878 .7828 m .69899 .77296 L .70883 .76083 L 0 1 .255 r
F
0 g
.70883 .76083 m
.71343 .7564 L
s
.5624 .89451 m .55884 .87757 L .55774 .88322 L 0 .757 .356 r
F
0 g
.55128 .881 m
.55774 .88322 L
s
.35668 .72493 m
.3632 .72069 L
s
.68878 .7828 m .71181 .75444 L .70614 .75639 L 0 1 .255 r
F
0 g
.71181 .75444 m
.71504 .7499 L
s
.58876 .86623 m .58555 .84999 L .58404 .85978 L 0 1 .334 r
F
.58469 .89422 m .58876 .86623 L .58177 .87529 L 0 1 .322 r
F
.33891 .71944 m .33218 .7116 L .32538 .716 L 0 1 .527 r
F
0 g
.31501 .71638 m
.32538 .716 L
s
.30178 .82948 m .28894 .82339 L .29253 .82636 L 0 .651 .433 r
F
.68803 .79351 m .70142 .77788 L .70438 .77087 L 0 1 .238 r
F
.68802 .79352 m .68803 .79351 L .68803 .79351 L F
.68803 .79351 m .70142 .77788 L .68803 .79351 L F
.688 .79359 m .70142 .77788 L .68802 .79352 L F
.6875 .79505 m .6875 .79505 L .68777 .79386 L F
.68777 .79472 m .70142 .77788 L .688 .79359 L F
.68806 .79157 m .70438 .77087 L .69899 .77296 L F
.68786 .79311 m .70438 .77087 L .68806 .79157 L F
.68777 .79386 m .68777 .79386 L .68786 .79311 L F
.68777 .79386 m .70438 .77087 L .68786 .79311 L F
.68867 .78312 m .69899 .77296 L .68878 .7828 L F
.68186 .79384 m .68796 .79161 L .68867 .78312 L 0 1 .48 r
F
.68796 .79161 m .68805 .79157 L .68867 .78312 L F
.68805 .79157 m .68777 .79386 L .68806 .79157 L 0 1 .238 r
F
.68805 .79157 m .68777 .79386 L .68831 .79148 L 0 1 .48 r
F
.68186 .79384 m .68777 .79386 L .68805 .79157 L F
.68186 .79384 m .6875 .79505 L .68777 .79386 L F
.68726 .79611 m .69188 .79108 L .6875 .79505 L 0 1 .238 r
F
.68722 .80001 m .69699 .78895 L .69188 .79108 L 0 1 .223 r
F
.66125 .82996 m .68215 .82794 L .6775 .82121 L 0 1 .453 r
F
.68215 .82794 m .68228 .82793 L .68219 .8278 L F
.68215 .82794 m .68219 .8278 L .6775 .82121 L F
.68755 .80366 m .69405 .7967 L .69699 .78895 L 0 1 .223 r
F
.68459 .81628 m .68537 .81782 L .68557 .81622 L 0 1 .463 r
F
.68505 .82034 m .68674 .8177 L .68557 .81622 L 0 1 .211 r
F
.68537 .81782 m .6855 .81806 L .68557 .81622 L 0 1 .463 r
F
.68557 .81622 m .68674 .8177 L .68966 .80902 L 0 1 .211 r
F
.66809 .81724 m .68382 .82012 L .68459 .81628 L 0 1 .463 r
F
.68382 .82012 m .68505 .82034 L .68459 .81628 L F
.68505 .82034 m .685 .82077 L .68674 .8177 L 0 1 .211 r
F
.68505 .82034 m .68682 .82066 L .68537 .81782 L 0 1 .463 r
F
.68505 .82034 m .68537 .81782 L .68459 .81628 L F
.65443 .84358 m .67173 .84608 L .67474 .84071 L 0 1 .44 r
F
.65443 .84358 m .66304 .84732 L .67173 .84608 L F
.65443 .84358 m .67474 .84071 L .67025 .8338 L F
.66125 .82996 m .67926 .83293 L .68228 .82793 L 0 1 .453 r
F
.66125 .82996 m .67025 .8338 L .67926 .83293 L F
.6688 .8458 m .67782 .83343 L .685 .82077 L 0 1 .211 r
F
.66809 .81724 m .6775 .82121 L .68368 .82085 L 0 1 .463 r
F
.66809 .81724 m .68368 .82085 L .68375 .82048 L F
.66809 .81724 m .68514 .82076 L .68518 .82037 L F
.66809 .81724 m .68459 .81628 L .68478 .80937 L F
.68557 .81622 m .68573 .81595 L .6858 .81068 L 0 1 .211 r
F
.68573 .81595 m .68966 .80902 L .68581 .81067 L F
.68573 .81595 m .68581 .81067 L .6858 .81068 L F
.67496 .80525 m .68478 .80937 L .68583 .80934 L 0 1 .472 r
F
.68459 .81628 m .68572 .81059 L .68478 .80937 L 0 1 .463 r
F
.66125 .82996 m .6775 .82121 L .66809 .81724 L 0 1 .453 r
F
.67541 .8226 m .68483 .81109 L .68595 .80934 L 0 1 .223 r
F
.68596 .80933 m .68595 .80934 L .68597 .80932 L F
.67541 .8226 m .68595 .80934 L .68596 .80933 L F
.68586 .80742 m .68583 .80934 L .68595 .80934 L 0 1 .472 r
F
.68597 .80931 m .68597 .80932 L .68599 .80929 L 0 1 .223 r
F
.68637 .80738 m .68599 .80929 L .69405 .7967 L F
.68628 .8075 m .68595 .80934 L .69441 .80912 L 0 1 .472 r
F
.68586 .80742 m .68595 .80934 L .68628 .8075 L F
.67496 .80525 m .68583 .80934 L .68586 .80742 L F
.68557 .81622 m .6858 .81068 L .68579 .81068 L 0 1 .211 r
F
.68459 .81628 m .68557 .81622 L .68572 .81059 L 0 1 .463 r
F
.68557 .81622 m .68579 .81068 L .68572 .81059 L F
.68557 .81622 m .68579 .81068 L .68483 .81109 L 0 1 .211 r
F
.68557 .81622 m .68985 .81597 L .68579 .81068 L 0 1 .463 r
F
.67541 .8226 m .68597 .80932 L .68597 .80931 L 0 1 .223 r
F
.68691 .80467 m .68689 .80665 L .68755 .80366 L F
.67496 .80525 m .68628 .8075 L .68673 .80495 L 0 1 .472 r
F
.68673 .80495 m .68637 .80738 L .68691 .80467 L 0 1 .223 r
F
.66809 .81724 m .68478 .80937 L .67496 .80525 L 0 1 .463 r
F
.67541 .8226 m .68628 .80749 L .68673 .80495 L 0 1 .223 r
F
.68628 .80749 m .68637 .80738 L .68673 .80495 L F
.68689 .80665 m .69405 .7967 L .68755 .80366 L F
.68694 .80463 m .69699 .78895 L .68722 .80001 L F
.6876 .79999 m .69746 .80467 L .69209 .79813 L 0 1 .472 r
F
.68712 .80019 m .68691 .80467 L .68722 .80001 L 0 1 .223 r
F
.67496 .80525 m .68673 .80495 L .68712 .80019 L 0 1 .472 r
F
.67541 .8226 m .68673 .80495 L .68712 .80019 L 0 1 .223 r
F
.68673 .80495 m .68691 .80467 L .68712 .80019 L F
.68691 .80467 m .68697 .80413 L .68722 .80001 L F
.68712 .80019 m .68673 .80495 L .6876 .79999 L 0 1 .472 r
F
.68691 .80467 m .68694 .80463 L .68697 .80413 L 0 1 .223 r
F
.68637 .80738 m .68689 .80665 L .68691 .80467 L F
.68673 .80495 m .69746 .80467 L .6876 .79999 L 0 1 .472 r
F
.68673 .80495 m .69441 .80912 L .69746 .80467 L F
.68628 .8075 m .69441 .80912 L .68673 .80495 L F
.68628 .8075 m .68599 .80929 L .68637 .80738 L 0 1 .223 r
F
.67541 .8226 m .68596 .80932 L .68628 .8075 L F
.68596 .80932 m .68599 .80929 L .68628 .8075 L F
.68375 .82048 m .68368 .82085 L .68514 .82076 L 0 1 .463 r
F
.68518 .82037 m .68514 .82076 L .68682 .82066 L F
.6688 .8458 m .685 .82077 L .68505 .82034 L 0 1 .211 r
F
.6688 .8458 m .68505 .82034 L .68557 .81622 L F
.6688 .8458 m .68557 .81622 L .68483 .81109 L F
.68557 .81622 m .68682 .82066 L .68985 .81597 L 0 1 .463 r
F
.6855 .81806 m .68682 .82066 L .68557 .81622 L F
.67496 .80525 m .68712 .80019 L .68186 .79384 L 0 1 .472 r
F
.67541 .8226 m .68712 .80019 L .68207 .80175 L 0 1 .223 r
F
.68712 .80019 m .69188 .79108 L .68726 .79611 L F
.68712 .80019 m .68726 .79611 L .68186 .79384 L 0 1 .472 r
F
.68712 .80019 m .68726 .79611 L .68207 .80175 L 0 1 .223 r
F
.68712 .80019 m .69209 .79813 L .68726 .79611 L 0 1 .472 r
F
.68752 .79505 m .69209 .79813 L .70203 .79816 L 0 1 .48 r
F
.6875 .79505 m .68752 .79506 L .68752 .79505 L F
.68752 .79506 m .69209 .79813 L .68752 .79505 L F
.68186 .79384 m .68726 .79611 L .6875 .79505 L F
.68726 .79611 m .69209 .79813 L .6875 .79505 L F
.6875 .79505 m .69188 .79108 L .70142 .77788 L 0 1 .238 r
F
.68207 .80175 m .68726 .79611 L .6875 .79505 L F
.68207 .80175 m .68777 .79386 L .68805 .79157 L F
.67496 .80525 m .68186 .79384 L .67219 .79408 L 0 1 .472 r
F
.68186 .79384 m .6788 .7829 L .67615 .78731 L 0 1 .48 r
F
.68186 .79384 m .68866 .78314 L .6788 .7829 L F
.68866 .78314 m .68866 .78312 L .6788 .7829 L F
.68867 .78312 m .68869 .78294 L .6788 .7829 L F
.68878 .7828 m .68901 .78221 L .68998 .77228 L 0 1 .255 r
F
.68901 .78221 m .69553 .76545 L .69003 .77222 L F
.68901 .78221 m .69003 .77222 L .68998 .77228 L F
.68878 .7828 m .70614 .75639 L .69553 .76545 L F
.69553 .76545 m .69207 .76067 L .69094 .76355 L 0 1 .274 r
F
.69093 .76366 m .69094 .76355 L .6909 .76361 L 0 1 .491 r
F
.69055 .76705 m .6909 .76361 L .68943 .76588 L F
.6905 .76699 m .69094 .76355 L .68947 .76731 L 0 1 .274 r
F
.69553 .76545 m .69094 .76355 L .6905 .76699 L F
.69574 .77245 m .6921 .76177 L .69094 .76355 L 0 1 .491 r
F
.69574 .77245 m .69094 .76355 L .69093 .76366 L F
.69574 .77245 m .6909 .76361 L .69055 .76705 L F
.68879 .78294 m .69574 .77245 L .68998 .77228 L 0 1 .486 r
F
.68871 .78268 m .68998 .77228 L .68544 .77215 L F
.68878 .7828 m .68998 .77228 L .68995 .77252 L 0 1 .255 r
F
.68878 .7828 m .68997 .77228 L .68871 .78268 L F
.68879 .78294 m .68998 .77228 L .68871 .78268 L 0 1 .486 r
F
.68995 .77252 m .68998 .77228 L .68997 .77228 L 0 1 .255 r
F
.68869 .78283 m .68544 .77215 L .68278 .7764 L 0 1 .486 r
F
.68869 .78283 m .68544 .77215 L .68869 .78283 L F
.68871 .78268 m .68544 .77215 L .68869 .78284 L F
.68871 .78268 m .68997 .77228 L .68559 .77767 L 0 1 .255 r
F
.68869 .78284 m .68869 .78283 L .68869 .78283 L 0 1 .486 r
F
.68869 .78284 m .68869 .78283 L .68869 .78284 L 0 1 .255 r
F
.68878 .7828 m .68871 .78269 L .68869 .78284 L F
.68879 .78294 m .68871 .78268 L .68869 .78284 L 0 1 .486 r
F
.68869 .78284 m .68559 .77767 L .68301 .78485 L 0 1 .255 r
F
.68869 .78283 m .68559 .77767 L .68869 .78284 L F
.68871 .78269 m .68559 .77767 L .68869 .78284 L F
.68866 .78314 m .68867 .78312 L .68866 .78312 L 0 1 .48 r
F
.68867 .78312 m .68878 .7828 L .68869 .78294 L 0 1 .238 r
F
.68867 .78312 m .68879 .78294 L .68869 .78294 L 0 1 .48 r
F
.68867 .78312 m .68869 .78294 L .68869 .78294 L 0 1 .238 r
F
.68207 .80175 m .68867 .78312 L .67915 .7961 L F
.68867 .78312 m .68869 .78294 L .67915 .7961 L F
.68207 .80175 m .68805 .79157 L .68867 .78312 L F
.68805 .79157 m .69899 .77296 L .68867 .78312 L F
.68867 .78312 m .68805 .79157 L .68879 .78294 L 0 1 .48 r
F
.68805 .79157 m .69942 .7874 L .6891 .78307 L F
.68805 .79157 m .6891 .78307 L .68879 .78294 L F
.69015 .78325 m .69942 .7874 L .70969 .78769 L 0 1 .486 r
F
.68879 .78294 m .6901 .78349 L .69015 .78325 L F
.6901 .78349 m .69942 .7874 L .69015 .78325 L F
.6875 .79505 m .68777 .79472 L .68777 .79386 L 0 1 .238 r
F
.68777 .79472 m .688 .79359 L .68777 .79386 L F
.68831 .79148 m .70509 .79392 L .69942 .7874 L 0 1 .48 r
F
.68777 .79386 m .688 .79359 L .68802 .79352 L 0 1 .238 r
F
.68777 .79386 m .70509 .79392 L .68831 .79148 L 0 1 .48 r
F
.69032 .78244 m .71275 .78362 L .70679 .77709 L 0 1 .486 r
F
.68879 .78294 m .69021 .78298 L .69032 .78244 L F
.69021 .78298 m .71275 .78362 L .69032 .78244 L F
.69021 .78298 m .70969 .78769 L .71275 .78362 L F
.68879 .78294 m .69015 .78325 L .69021 .78298 L F
.69015 .78325 m .70969 .78769 L .69021 .78298 L F
.68207 .80175 m .6875 .79505 L .68777 .79386 L 0 1 .238 r
F
.6875 .79505 m .68762 .79508 L .68777 .79386 L 0 1 .48 r
F
.68777 .79386 m .70203 .79816 L .70509 .79392 L F
.68762 .79508 m .70203 .79816 L .68777 .79386 L F
0 g
.69899 .77296 m
.70438 .77087 L
s
.70438 .77087 m
.7055 .76909 L
s
.70142 .77788 m
.70261 .77653 L
s
.69385 .80028 m
.69488 .79814 L
s
.48846 .78041 m
.49632 .78641 L
s
.49632 .78641 m
.50358 .7857 L
s
.48542 .86464 m .49227 .84931 L .48379 .84715 L 0 .855 .381 r
F
.48542 .86464 m .49888 .85649 L .49227 .84931 L F
.48542 .86464 m .4992 .8639 L .49888 .85649 L F
.48542 .86464 m .49343 .8674 L .4992 .8639 L F
0 g
.47883 .85747 m
.48542 .86464 L
s
.48002 .86793 m
.48542 .86464 L
s
.58862 .74418 m .61089 .73057 L .6035 .72727 L 0 1 .428 r
F
0 g
.60015 .74273 m
.6067 .74613 L
s
.61089 .73057 m
.62041 .72409 L
s
.5207 .80915 m
.52793 .80993 L
s
.4903 .92188 m .50129 .91577 L .49574 .90624 L 0 .65 .349 r
F
.4903 .92188 m .50161 .9243 L .50129 .91577 L F
.4903 .92188 m .4969 .92691 L .50161 .9243 L F
0 g
.48477 .91236 m
.4903 .92188 L
s
.492 .94319 m .4969 .92692 L .4903 .92189 L 0 .563 .337 r
F
0 g
.48598 .92429 m
.4903 .92189 L
s
.33891 .71944 m .3441 .70883 L .33218 .7116 L 0 1 .527 r
F
0 g
.32545 .71373 m
.33225 .70922 L
s
.32538 .716 m
.33218 .7116 L
s
.33891 .71944 m .35486 .70916 L .3441 .70883 L 0 1 .527 r
F
.33891 .71944 m .35725 .71238 L .35486 .70916 L F
.33891 .71944 m .3504 .71679 L .35725 .71238 L F
0 g
.33244 .72375 m
.33891 .71944 L
s
.3282 .7191 m
.33891 .71944 L
s
.69553 .76545 m .7163 .74523 L .71929 .73935 L 0 1 .274 r
F
.69553 .76545 m .70614 .75639 L .7163 .74523 L F
0 g
.7163 .74523 m
.72116 .74128 L
s
.70051 .77913 m
.70142 .77788 L
s
.42107 .76535 m .41677 .75298 L .40998 .75696 L 0 1 .459 r
F
0 g
.40076 .75367 m
.40998 .75696 L
s
.42107 .76535 m .42772 .75252 L .41677 .75298 L 0 1 .459 r
F
.42107 .76535 m .43697 .75606 L .42772 .75252 L F
.42107 .76535 m .43835 .76125 L .43697 .75606 L F
.42107 .76535 m .43152 .76523 L .43835 .76125 L F
0 g
.41463 .76925 m
.42107 .76535 L
s
.41184 .76181 m
.42107 .76535 L
s
.48379 .84715 m .48215 .83047 L .47604 .83413 L 0 .913 .391 r
F
0 g
.46887 .82812 m
.47604 .83413 L
s
.5608 1.23496 m
.56141 1.23818 L
s
.54767 .84743 m .54962 .83522 L .54247 .83404 L 0 .863 .402 r
F
.54767 .84743 m .55852 .84149 L .54962 .83522 L F
.54767 .84743 m .5635 .85006 L .55852 .84149 L F
.5635 .85006 m .56174 .84628 L .55852 .84149 L F
.54965 .84164 m .55853 .8425 L .5596 .8417 L 0 1 .369 r
F
.57164 .84299 m .56708 .82859 L .56599 .8369 L 0 1 .359 r
F
.55508 .83223 m .56708 .82859 L .5609 .82214 L 0 1 .369 r
F
.5549 .83233 m .55519 .83244 L .55508 .83223 L 0 .934 .415 r
F
.55519 .83244 m .5552 .83245 L .55508 .83223 L F
.55131 .82454 m .5609 .82214 L .55156 .82186 L 0 1 .369 r
F
.54962 .83522 m .55711 .83606 L .5549 .83233 L 0 .934 .415 r
F
.55711 .83606 m .56708 .82859 L .55508 .83223 L 0 1 .369 r
F
.55884 .83898 m .56019 .84125 L .56599 .8369 L F
.55711 .83606 m .56599 .8369 L .56708 .82859 L F
.54962 .83522 m .55851 .83907 L .55711 .83606 L 0 .934 .415 r
F
.54962 .83522 m .55852 .84149 L .5597 .84162 L F
.5587 .83948 m .5597 .84162 L .56019 .84125 L 0 1 .369 r
F
.55839 .83911 m .56019 .84125 L .55884 .83898 L F
.55851 .83907 m .5597 .84162 L .56604 .84233 L 0 .934 .415 r
F
.54962 .83522 m .5597 .84162 L .55851 .83907 L F
.55839 .83911 m .5596 .8417 L .5597 .84162 L 0 1 .369 r
F
.55839 .83911 m .5597 .84162 L .5587 .83948 L F
.54965 .84164 m .55851 .83907 L .55711 .83606 L F
.55851 .83907 m .56599 .8369 L .55711 .83606 L F
.55711 .83606 m .56604 .84233 L .56715 .83718 L 0 .934 .415 r
F
.55851 .83907 m .56604 .84233 L .55711 .83606 L F
.55711 .83606 m .56715 .83718 L .5549 .83233 L F
.54962 .83522 m .55122 .82546 L .54407 .82245 L F
.54962 .83522 m .54407 .82245 L .54343 .82707 L F
.55122 .82546 m .55508 .83223 L .55131 .82454 L 0 1 .369 r
F
.55508 .83223 m .5609 .82214 L .55131 .82454 L F
.54962 .83522 m .56095 .82902 L .55157 .82329 L 0 .934 .415 r
F
.54965 .84164 m .55122 .82546 L .54409 .82745 L 0 1 .369 r
F
.55122 .82546 m .55156 .82186 L .54991 .8231 L F
.55122 .82546 m .54991 .8231 L .54407 .82245 L 0 .934 .415 r
F
.55122 .82546 m .54991 .8231 L .54409 .82745 L 0 1 .369 r
F
.55122 .82546 m .54994 .82311 L .54991 .8231 L 0 .934 .415 r
F
.55122 .82546 m .55157 .82329 L .54994 .82311 L F
.54965 .84164 m .55498 .8324 L .55122 .82546 L 0 1 .369 r
F
.55498 .8324 m .55508 .83223 L .55122 .82546 L F
.54965 .84164 m .55711 .83606 L .55508 .83223 L F
.55508 .83223 m .56715 .83718 L .56095 .82902 L 0 .934 .415 r
F
.5552 .83245 m .56715 .83718 L .55508 .83223 L F
.54965 .84164 m .5596 .8417 L .55839 .83911 L 0 1 .369 r
F
.5655 .87951 m .5686 .86503 L .5616 .86368 L 0 .842 .372 r
F
.56901 .86314 m .58024 .84279 L .57164 .84299 L 0 1 .347 r
F
.5655 .87951 m .57236 .87517 L .5686 .86503 L 0 .842 .372 r
F
.57236 .87517 m .57162 .8725 L .5686 .86503 L F
.57263 .87501 m .5699 .86618 L .56988 .86616 L F
.57192 .87326 m .56988 .86616 L .5686 .86503 L F
.57263 .87501 m .56988 .86616 L .57192 .87326 L F
.5686 .86503 m .56523 .85321 L .56326 .85554 L 0 .919 .387 r
F
.56491 .85198 m .56437 .84991 L .5643 .85053 L 0 1 .347 r
F
.56491 .85198 m .5643 .85053 L .56429 .85061 L F
.56523 .85321 m .56429 .85061 L .56326 .85554 L 0 .919 .387 r
F
.56486 .85219 m .56429 .85061 L .56329 .85895 L 0 1 .347 r
F
.56491 .85198 m .56429 .85061 L .56486 .85219 L F
.56523 .85321 m .56429 .85059 L .56429 .85061 L 0 .919 .387 r
F
.56523 .85321 m .56437 .8502 L .56429 .85059 L F
.56523 .85321 m .56901 .86314 L .56437 .84991 L 0 1 .347 r
F
.56901 .86314 m .57164 .84299 L .56502 .8493 L F
.56901 .86314 m .56502 .8493 L .56437 .84991 L F
.56523 .85321 m .57172 .85112 L .56437 .8502 L 0 .919 .387 r
F
.5686 .86503 m .56898 .86333 L .56523 .85321 L F
.56898 .86333 m .56901 .86314 L .56523 .85321 L 0 1 .347 r
F
.56928 .86411 m .58024 .84279 L .56901 .86314 L F
.5686 .86503 m .56943 .86451 L .56898 .86333 L 0 .919 .387 r
F
.5694 .86456 m .56943 .86451 L .56928 .86411 L 0 1 .347 r
F
.56943 .86451 m .58024 .84279 L .56928 .86411 L F
.56943 .86451 m .58555 .84999 L .58024 .84279 L F
.5686 .86503 m .56966 .86516 L .56943 .86451 L 0 .919 .387 r
F
.5694 .86456 m .56944 .86453 L .56943 .86451 L 0 1 .347 r
F
.56944 .86453 m .58555 .84999 L .56943 .86451 L F
.5696 .86521 m .56966 .86516 L .5694 .86456 L F
.56966 .86516 m .58555 .84999 L .56949 .86448 L F
.56966 .86516 m .56949 .86448 L .5694 .86456 L F
.5686 .86503 m .56977 .86565 L .56966 .86516 L 0 .919 .387 r
F
.56966 .86516 m .58404 .85978 L .58555 .84999 L 0 1 .347 r
F
.56977 .86565 m .56981 .86566 L .56966 .86516 L 0 .919 .387 r
F
.56998 .86625 m .57678 .86672 L .56981 .86566 L 0 1 .347 r
F
.57322 .87463 m .58177 .87529 L .57678 .86672 L 0 1 .334 r
F
.5624 .89451 m .57328 .88777 L .5655 .87951 L 0 .757 .356 r
F
.57601 .8811 m .58177 .87529 L .57322 .87463 L 0 1 .334 r
F
.58469 .89422 m .58177 .87529 L .58027 .88618 L 0 1 .322 r
F
.5624 .89451 m .57797 .89908 L .57328 .88777 L 0 .757 .356 r
F
.57563 .88147 m .58027 .88618 L .58177 .87529 L 0 1 .334 r
F
.57535 .88142 m .57739 .88724 L .57563 .88147 L 0 .842 .372 r
F
.5655 .87951 m .57643 .88662 L .57535 .88142 L F
.57643 .88662 m .57739 .88724 L .57535 .88142 L F
.5655 .87951 m .57535 .88142 L .57322 .87463 L F
.57535 .88142 m .57563 .88147 L .57322 .87463 L F
.57263 .87501 m .57322 .87463 L .57073 .86885 L F
.57236 .87517 m .57263 .87501 L .57162 .8725 L F
.5655 .87951 m .57328 .88777 L .57781 .88865 L F
.57739 .88724 m .57781 .88865 L .58027 .88618 L 0 1 .334 r
F
.57739 .88724 m .57781 .88865 L .5803 .88913 L 0 .842 .372 r
F
.5655 .87951 m .57781 .88865 L .57739 .88724 L F
.5656 .89158 m .57334 .89316 L .57781 .88865 L 0 1 .334 r
F
.5656 .89158 m .57781 .88865 L .57739 .88724 L F
.5656 .89158 m .57322 .87463 L .56861 .86616 L F
.57322 .87463 m .57371 .87355 L .57219 .87135 L F
.57322 .87463 m .57219 .87135 L .57165 .87056 L F
.57371 .87355 m .57678 .86672 L .57222 .8664 L F
.57322 .87463 m .57106 .86904 L .57073 .86885 L 0 .842 .372 r
F
.57371 .87355 m .57222 .8664 L .56998 .86625 L 0 1 .334 r
F
.57073 .86885 m .57106 .86904 L .5699 .86618 L 0 .842 .372 r
F
.57106 .86904 m .56998 .86625 L .5699 .86618 L F
.57165 .87056 m .56998 .86625 L .56861 .86616 L 0 1 .334 r
F
.57371 .87355 m .56998 .86625 L .57165 .87056 L F
.57106 .86904 m .57684 .87235 L .56998 .86625 L 0 .842 .372 r
F
.57322 .87463 m .57684 .87235 L .57106 .86904 L F
.57322 .87463 m .57165 .87056 L .56861 .86616 L 0 1 .334 r
F
.5656 .89158 m .57739 .88724 L .57563 .88147 L F
.57739 .88724 m .58027 .88618 L .57563 .88147 L F
.57563 .88147 m .5803 .88913 L .58185 .88268 L 0 .842 .372 r
F
.57739 .88724 m .5803 .88913 L .57563 .88147 L F
.57322 .87463 m .58185 .88268 L .57684 .87235 L F
.57563 .88147 m .57601 .8811 L .57322 .87463 L 0 1 .334 r
F
.57563 .88147 m .58185 .88268 L .57322 .87463 L 0 .842 .372 r
F
.5656 .89158 m .57563 .88147 L .57322 .87463 L 0 1 .334 r
F
.56981 .86566 m .57684 .87235 L .58419 .87328 L 0 .919 .387 r
F
.5686 .86503 m .56998 .86625 L .56981 .86566 L F
.56998 .86625 m .57684 .87235 L .56981 .86566 L F
.56981 .86566 m .57678 .86672 L .58404 .85978 L 0 1 .347 r
F
.56861 .86616 m .56998 .86625 L .56981 .86566 L F
.56861 .86616 m .56981 .86566 L .56966 .86516 L F
.56981 .86566 m .58404 .85978 L .56966 .86516 L F
.56981 .86566 m .58419 .87328 L .56966 .86516 L 0 .919 .387 r
F
.56966 .86516 m .58419 .87328 L .58575 .8672 L F
.56943 .86451 m .58575 .8672 L .5804 .8577 L F
.56966 .86516 m .58575 .8672 L .56943 .86451 L F
.56898 .86333 m .5804 .8577 L .57172 .85112 L F
.56943 .86451 m .5804 .8577 L .56898 .86333 L F
.56898 .86333 m .57172 .85112 L .56523 .85321 L F
.56895 .86357 m .56898 .86333 L .56523 .85321 L 0 1 .347 r
F
.56861 .86616 m .56895 .86357 L .56523 .85321 L F
.56861 .86616 m .5694 .86456 L .56901 .86314 L F
.56861 .86616 m .5696 .86521 L .5694 .86456 L F
.56861 .86616 m .56491 .85198 L .56329 .85895 L F
.5635 .85006 m .56407 .85015 L .56174 .84628 L 0 .863 .402 r
F
.54767 .84743 m .56326 .85554 L .56429 .85061 L F
.56407 .85015 m .56429 .85061 L .56437 .84991 L 0 1 .357 r
F
.56407 .85015 m .56429 .85061 L .56437 .8502 L 0 .863 .402 r
F
.54767 .84743 m .56429 .85061 L .56407 .85015 L F
.54767 .84743 m .5561 .85435 L .56326 .85554 L F
.54775 .86296 m .56329 .85895 L .56429 .85061 L 0 1 .357 r
F
.54775 .86296 m .56429 .85061 L .56407 .85015 L F
.54775 .86296 m .56407 .85015 L .55853 .8425 L F
.56407 .85015 m .56437 .84991 L .56308 .84827 L F
.56407 .85015 m .5637 .84944 L .56174 .84628 L 0 .863 .402 r
F
.56414 .85016 m .56379 .84933 L .56174 .84628 L F
.56407 .85015 m .56308 .84827 L .55853 .8425 L 0 1 .357 r
F
.56407 .85015 m .56414 .85016 L .5637 .84944 L 0 .863 .402 r
F
.56414 .85016 m .56437 .8502 L .56379 .84933 L F
0 g
.54087 .84581 m
.54767 .84743 L
s
.54183 .83873 m
.54767 .84743 L
s
.58024 .84279 m
.58555 .84999 L
s
.58404 .85978 m
.58491 .86098 L
s
.58491 .86098 m
.58876 .86623 L
s
.58555 .84999 m
.58858 .84635 L
s
.58024 .84279 m
.58573 .83788 L
s
.31242 .93105 m .30257 .92715 L .30082 .92468 L 0 0 0 r
F
0 g
.29367 .92261 m
.30082 .92468 L
s
.45358 .79319 m .44383 .78286 L .44519 .7885 L 0 1 .432 r
F
0 g
.43909 .79232 m
.44519 .7885 L
s
.69618 1.19681 m .70337 1.16435 L .69932 1.18229 L 0 .751 .066 r
F
.69457 1.17587 m .69932 1.18229 L .70337 1.16435 L 0 1 .179 r
F
0 g
.70337 1.16435 m
.70352 1.16286 L
s
.70337 1.16435 m
.70635 1.15418 L
s
.71465 .79397 m .73411 .79864 L .73755 .79485 L 0 1 .495 r
F
.71465 .79397 m .72431 .79826 L .73411 .79864 L F
0 g
.73411 .79864 m
.73799 .80457 L
s
.69553 .76545 m .71929 .73935 L .71334 .74112 L 0 1 .274 r
F
0 g
.70614 .75639 m
.71308 .74877 L
s
.71308 .74877 m
.7163 .74523 L
s
.69899 .77296 m
.70138 .77001 L
s
.70138 .77001 m
.70544 .76501 L
s
.70544 .76501 m
.70795 .76191 L
s
.70795 .76191 m
.70883 .76083 L
s
.70614 .75639 m
.71181 .75444 L
s
.71929 .73935 m
.72893 .72737 L
s
.28355 .8189 m
.28429 .82125 L
s
.28429 .82125 m
.28894 .82339 L
s
.63937 .87838 m .65925 .8708 L .65585 .862 L 0 1 .407 r
F
.63937 .87838 m .6556 .87887 L .65925 .8708 L F
0 g
.65925 .8708 m
.66759 .86652 L
s
.63937 .87838 m .64708 .88212 L .6556 .87887 L 0 1 .407 r
F
0 g
.64708 .88212 m
.6556 .87887 L
s
.6556 .87887 m
.65811 .88632 L
s
.64334 .97388 m .64494 .95787 L .64192 .96966 L 0 1 .195 r
F
.6357 1.01149 m .64334 .97388 L .63744 .9902 L 0 1 .165 r
F
0 g
.64157 1.01209 m
.64187 1.01014 L
s
.64187 1.01014 m
.64296 1.00311 L
s
.37935 .73259 m .36675 .72657 L .3691 .73054 L 0 1 .489 r
F
0 g
.37271 .73299 m
.37521 .73176 L
s
.3629 .7345 m
.3691 .73054 L
s
.27251 .81419 m .264 .80945 L .2677 .8123 L 0 .934 .482 r
F
0 g
.53618 .82627 m
.54343 .82707 L
s
.53618 .82627 m
.54247 .83404 L
s
.492 .94319 m .5021 .93759 L .4969 .92692 L 0 .563 .337 r
F
.492 .94319 m .50244 .94679 L .5021 .93759 L F
.492 .94319 m .4981 .94919 L .50244 .94679 L F
.49369 .96478 m .4981 .94919 L .492 .94319 L 0 .463 .323 r
F
0 g
.48681 .93253 m
.492 .94319 L
s
.48805 .94495 m
.492 .94319 L
s
.64765 .85831 m .66424 .86036 L .66723 .85451 L 0 1 .426 r
F
.64765 .85831 m .65585 .86199 L .66424 .86036 L F
0 g
.66424 .86036 m
.66759 .86652 L
s
.65585 .86199 m
.66424 .86036 L
s
.5624 .89451 m .5655 .87951 L .55884 .87757 L 0 .757 .356 r
F
0 g
.55369 .86755 m
.55884 .87757 L
s
.48379 .84715 m .49111 .83211 L .48215 .83047 L 0 .913 .391 r
F
.48379 .84715 m .49807 .83862 L .49111 .83211 L F
.48379 .84715 m .4984 .84566 L .49807 .83862 L F
.48379 .84715 m .49227 .84931 L .4984 .84566 L F
0 g
.47684 .84065 m
.48379 .84715 L
s
.47803 .85065 m
.48379 .84715 L
s
.53139 1.11321 m .53305 1.14616 L .53127 1.12519 L 0 .9 .133 r
F
0 g
.52857 1.10605 m
.53127 1.12519 L
s
.53139 1.11321 m .53621 1.17071 L .53305 1.14616 L 0 .9 .133 r
F
.53139 1.11321 m .53866 1.18235 L .53621 1.17071 L F
.53139 1.11321 m .53875 1.17008 L .53866 1.18235 L F
.53139 1.11321 m .53645 1.14231 L .53875 1.17008 L F
.53139 1.11321 m .5333 1.11805 L .53645 1.14231 L F
0 g
.53304 1.10304 m
.53561 1.12069 L
s
.53015 1.1044 m
.53139 1.11321 L
s
.53127 1.12519 m
.53139 1.11321 L
s
.53319 1.11165 m
.5333 1.11805 L
s
.69884 .81524 m .71602 .80836 L .70673 .80435 L 0 1 .482 r
F
0 g
.71602 .80836 m
.72554 .80839 L
s
.71602 .80836 m
.72041 .81446 L
s
.37941 .72969 m .38562 .7202 L .37382 .72167 L 0 1 .525 r
F
.37941 .72969 m .39592 .72159 L .38562 .7202 L F
.37941 .72969 m .39783 .72491 L .39592 .72159 L F
.37941 .72969 m .39074 .72838 L .39783 .72491 L F
0 g
.37639 .73118 m
.37941 .72969 L
s
.37086 .72853 m
.37941 .72969 L
s
.55881 1.00874 m .55813 .98413 L .55642 .98815 L 0 .26 .245 r
F
0 g
.55295 .98095 m
.55642 .98815 L
s
.68686 .82085 m
.68714 .82016 L
s
.6331 .89557 m .65078 .89018 L .64708 .88212 L 0 1 .386 r
F
.6331 .89557 m .64801 .89719 L .65078 .89018 L F
0 g
.65078 .89018 m
.65811 .88633 L
s
.62976 .97576 m .64494 .95787 L .64273 .94818 L 0 1 .313 r
F
.62976 .97576 m .64192 .96966 L .64494 .95787 L F
0 g
.64494 .95787 m
.64653 .95481 L
s
.44762 .75398 m .43709 .74684 L .43848 .75027 L 0 1 .506 r
F
0 g
.43169 .75246 m
.43848 .75027 L
s
.64381 .92349 m .64388 .90848 L .64113 .91652 L 0 1 .368 r
F
.63675 .94702 m .64381 .92349 L .63703 .92963 L 0 1 .341 r
F
.64765 .85831 m .66723 .85451 L .66304 .84732 L 0 1 .426 r
F
0 g
.66723 .85451 m
.67535 .85215 L
s
.69098 .82673 m .68985 .81597 L .68682 .82066 L 0 1 .474 r
F
0 g
.68401 .82766 m
.68408 .8275 L
s
.68408 .8275 m
.68686 .82085 L
s
.69098 .82673 m .69884 .81524 L .68985 .81597 L 0 1 .474 r
F
0 g
.68682 .82066 m
.69098 .82673 L
s
.68526 .82752 m
.69098 .82673 L
s
.68417 .82767 m
.68526 .82752 L
s
.684 .82769 m
.68417 .82767 L
s
.68228 .82793 m
.684 .82769 L
s
.48215 .83047 m .47404 .81835 L .47484 .82457 L 0 .966 .4 r
F
0 g
.46887 .82812 m
.47484 .82457 L
s
.45358 .79319 m .45055 .77883 L .44383 .78286 L 0 1 .432 r
F
0 g
.43531 .77847 m
.44383 .78286 L
s
.45358 .79319 m .46089 .77909 L .45055 .77883 L 0 1 .432 r
F
.45358 .79319 m .46929 .78379 L .46089 .77909 L F
.45358 .79319 m .47016 .78978 L .46929 .78379 L F
.45358 .79319 m .46342 .79381 L .47016 .78978 L F
0 g
.44519 .7885 m
.45358 .79319 L
s
.54247 .83404 m
.54696 .83478 L
s
.5624 .89451 m .57642 .9059 L .57797 .89908 L 0 .757 .356 r
F
.5624 .89451 m .56974 .90393 L .57642 .9059 L F
0 g
.55608 .89174 m
.5624 .89451 L
s
.55774 .88322 m
.5624 .89451 L
s
.30178 .82948 m .29309 .82139 L .28894 .82339 L 0 .651 .433 r
F
.58529 .76039 m .59968 .74249 L .58862 .74418 L 0 1 .416 r
F
0 g
.59968 .74249 m
.60015 .74273 L
s
.59968 .74249 m
.60921 .73666 L
s
.6331 .89557 m .64044 .89951 L .64801 .89719 L 0 1 .386 r
F
0 g
.64801 .89719 m
.65094 .9036 L
s
.499 1.02658 m .50182 1.01701 L .49723 1.00804 L 0 .177 .237 r
F
.499 1.02658 m .50553 1.02963 L .50182 1.01701 L F
.499 1.02658 m .50589 1.03746 L .50553 1.02963 L F
.499 1.02658 m .50308 1.03614 L .50589 1.03746 L F
0 g
.4953 1.014 m
.499 1.02658 L
s
.4966 1.02371 m
.499 1.02658 L
s
.55899 1.04385 m .56949 1.11044 L .56512 1.0758 L 0 0 .072 r
F
0 g
.55745 1.03079 m
.55899 1.04385 L
s
.55797 1.03194 m
.55899 1.04385 L
s
.56503 1.05008 m
.56718 1.07522 L
s
.56867 1.09201 m
.56868 1.09274 L
s
.56858 1.09163 m
.56868 1.09274 L
s
.31046 .83748 m .31057 .83066 L .30178 .82948 L 0 .49 .389 r
F
.31046 .83748 m .3196 .83453 L .31057 .83066 L F
.31046 .83748 m .3228 .83849 L .3196 .83453 L F
.31046 .83748 m .31887 .83975 L .3228 .83849 L F
0 g
.30149 .83363 m
.31046 .83748 L
s
.30686 .83784 m
.31046 .83748 L
s
.59196 .72897 m .61341 .72171 L .61509 .71599 L 0 1 .44 r
F
.59196 .72897 m .6035 .72727 L .61341 .72171 L F
0 g
.61341 .72171 m
.62041 .72409 L
s
.71465 .79397 m .73755 .79485 L .73263 .78858 L 0 1 .495 r
F
0 g
.73755 .79485 m
.74683 .79538 L
s
.27251 .81419 m .26333 .80691 L .264 .80945 L 0 .934 .482 r
F
.27251 .81419 m .26614 .80638 L .26333 .80691 L F
0 g
.25503 .80909 m
.26154 .80935 L
s
.26154 .80935 m
.264 .80945 L
s
.27251 .81419 m .27096 .80827 L .26614 .80638 L 0 .934 .482 r
F
.27251 .81419 m .27456 .81132 L .27096 .80827 L F
.27251 .81419 m .27522 .81386 L .27456 .81132 L F
0 g
.27251 .81419 m
.27326 .81654 L
s
.2677 .8123 m
.27251 .81419 L
s
.69309 .7982 m
.69313 .79813 L
s
.69268 .79885 m
.69309 .7982 L
s
.58244 .86131 m
.58404 .85978 L
s
.58177 .87529 m
.58334 .87326 L
s
.58334 .87326 m
.5834 .87318 L
s
.58462 .8716 m
.58876 .86623 L
s
.44762 .75398 m .44451 .74521 L .43709 .74684 L 0 1 .506 r
F
.44762 .75398 m .45583 .74648 L .44451 .74521 L F
.44762 .75398 m .465 .7502 L .45583 .74648 L F
.44762 .75398 m .46588 .7539 L .465 .7502 L F
.44762 .75398 m .45843 .75552 L .46588 .7539 L F
0 g
.44057 .75537 m
.44762 .75398 L
s
.43848 .75027 m
.44762 .75398 L
s
.57468 .82179 m .5787 .79653 L .5704 .80492 L 0 1 .374 r
F
.5787 .79652 m .57352 .78445 L .57235 .79188 L 0 1 .39 r
F
.5787 .79652 m .58199 .77777 L .57352 .78445 L F
0 g
.55897 .95446 m
.56334 .95858 L
s
.62976 .97576 m .64273 .94818 L .63675 .94702 L 0 1 .313 r
F
0 g
.64273 .94818 m
.64821 .94319 L
s
.64273 .94818 m
.64494 .95787 L
s
.64198 .96982 m
.64206 .97006 L
s
.64206 .97006 m
.64334 .97388 L
s
.63947 .98459 m
.63979 .98368 L
s
.49369 .96478 m .50294 .96071 L .4981 .94919 L 0 .463 .323 r
F
.49369 .96478 m .50327 .97006 L .50294 .96071 L F
.49369 .96478 m .4993 .9718 L .50327 .97006 L F
0 g
.48887 .95328 m
.49369 .96478 L
s
.49546 .987 m .4993 .9718 L .49369 .96478 L 0 .347 .306 r
F
0 g
.49013 .96596 m
.49369 .96478 L
s
.58168 1.11354 m
.58179 1.1155 L
s
.69457 1.17587 m .70084 1.13387 L .69685 1.15295 L 0 1 .179 r
F
.69009 1.1223 m .69685 1.15295 L .70084 1.13387 L 0 1 .249 r
F
0 g
.70084 1.13387 m
.70459 1.12903 L
s
.70084 1.13387 m
.70085 1.13356 L
s
.67474 .84071 m
.68001 .83962 L
s
.67173 .84608 m
.67535 .85215 L
s
.48215 .83047 m .48051 .81456 L .47404 .81835 L 0 .966 .4 r
F
0 g
.46652 .81285 m
.47404 .81835 L
s
.54466 1.1288 m .54929 1.20597 L .54597 1.16294 L 0 .867 .18 r
F
0 g
.54837 1.11781 m
.54892 1.13056 L
s
.54466 1.1288 m .55331 1.24028 L .54929 1.20597 L 0 .867 .18 r
F
.54466 1.1288 m .5553 1.24243 L .55331 1.24028 L F
.54466 1.1288 m .55391 1.20734 L .5553 1.24243 L F
.54466 1.1288 m .55014 1.1591 L .55391 1.20734 L F
0 g
.55292 1.12207 m
.5538 1.14008 L
s
.55117 1.12084 m
.5538 1.14008 L
s
.54111 1.10842 m
.54466 1.1288 L
s
.5462 1.12574 m
.54725 1.13465 L
s
.48215 .83047 m .48994 .81574 L .48051 .81456 L 0 .966 .4 r
F
0 g
.47404 .81835 m
.48051 .81456 L
s
.48215 .83047 m .49726 .82165 L .48994 .81574 L 0 .966 .4 r
F
.48215 .83047 m .49759 .82833 L .49726 .82165 L F
.48215 .83047 m .49111 .83211 L .49759 .82833 L F
0 g
.47604 .83413 m
.48215 .83047 L
s
.47484 .82457 m
.48215 .83047 L
s
.57468 .82179 m .5704 .80492 L .56896 .81488 L 0 1 .374 r
F
.57164 .84299 m .57468 .82179 L .56708 .82859 L 0 1 .359 r
F
0 g
.26333 .80691 m
.264 .80945 L
s
.58199 .77777 m .57646 .76679 L .57528 .7737 L 0 1 .403 r
F
.58199 .77777 m .58529 .76039 L .57646 .76679 L F
.62955 .69656 m .62356 .68924 L .62186 .69436 L 0 1 .46 r
F
.62955 .69656 m .63415 .6839 L .62356 .68924 L F
.5655 .87951 m .5616 .86368 L .5605 .86919 L 0 .842 .372 r
F
0 g
.5605 .86919 m
.5655 .87951 L
s
.55884 .87757 m
.5655 .87951 L
s
.55369 .86755 m
.5605 .86919 L
s
.59492 .90101 m
.5962 .90414 L
s
.37935 .73259 m .37381 .72238 L .36675 .72657 L 0 1 .489 r
F
0 g
.36678 .72515 m
.37274 .72221 L
s
.35668 .72493 m
.36675 .72657 L
s
.49546 .987 m .50379 .98429 L .4993 .9718 L 0 .347 .306 r
F
.49546 .987 m .50413 .99391 L .50379 .98429 L F
.49546 .987 m .50056 .99507 L .50413 .99391 L F
.49723 1.00804 m .50056 .99507 L .49546 .987 L 0 .267 .28 r
F
0 g
.49099 .97454 m
.49546 .987 L
s
.49229 .98708 m
.49546 .987 L
s
.55941 .85995 m
.5616 .86368 L
s
.37935 .73259 m .38561 .72077 L .37381 .72238 L 0 1 .489 r
F
.37935 .73259 m .3959 .72282 L .38561 .72077 L F
.37935 .73259 m .39778 .72717 L .3959 .72282 L F
.37935 .73259 m .39068 .73136 L .39778 .72717 L F
0 g
.37263 .73661 m
.37935 .73259 L
s
.3691 .73054 m
.37935 .73259 L
s
.67369 .83909 m
.67474 .84071 L
s
.51024 1.07261 m .5073 1.05983 L .50765 1.06263 L 0 0 .105 r
F
0 g
.50567 1.0581 m
.50765 1.06263 L
s
.62687 .91494 m .64388 .90848 L .64044 .89951 L 0 1 .365 r
F
.62687 .91494 m .64113 .91652 L .64388 .90848 L F
0 g
.64388 .90848 m
.65094 .9036 L
s
.5333 1.11805 m
.53405 1.12385 L
s
.53405 1.12385 m
.53553 1.13527 L
s
.49723 1.00804 m .50466 1.00792 L .50056 .99507 L 0 .267 .28 r
F
.49723 1.00804 m .50501 1.01697 L .50466 1.00792 L F
.49723 1.00804 m .50182 1.01701 L .50501 1.01697 L F
0 g
.49315 .99522 m
.49723 1.00804 L
s
.49444 1.00676 m
.49723 1.00804 L
s
.59196 .72897 m .61509 .71599 L .60735 .71295 L 0 1 .44 r
F
0 g
.60484 .72787 m
.61089 .73057 L
s
.61509 .71599 m
.62497 .70991 L
s
.42783 .74409 m
.43709 .74684 L
s
.30257 .92715 m .29077 .92002 L .29479 .92205 L 0 .115 .159 r
F
0 g
.29367 .92261 m
.29443 .92223 L
s
.6331 .89557 m .64708 .88212 L .63937 .87838 L 0 1 .386 r
F
0 g
.64708 .88212 m
.65078 .89018 L
s
.41677 .75298 m .4053 .74517 L .40717 .74983 L 0 1 .466 r
F
0 g
.40076 .75367 m
.40717 .74983 L
s
.56267 .93758 m
.56825 .94126 L
s
.47664 .76794 m .46721 .75943 L .46809 .76311 L 0 1 .49 r
F
0 g
.46101 .76448 m
.46809 .76311 L
s
.55881 1.00874 m .56344 .99652 L .55813 .98413 L 0 .26 .245 r
F
0 g
.55526 .96876 m
.55813 .98413 L
s
.63937 .87838 m .65585 .862 L .64765 .85831 L 0 1 .407 r
F
0 g
.65585 .862 m
.65925 .8708 L
s
.51717 1.09078 m .51553 1.08885 L .51536 1.08588 L 0 .546 .018 r
F
0 g
.51536 1.08588 m
.51579 1.08703 L
s
.51346 1.07794 m
.51536 1.08588 L
s
.51165 1.07643 m .51579 1.0898 L .51596 1.08809 L 0 0 .105 r
F
.51024 1.07261 m .5126 1.07994 L .51165 1.07643 L F
.5126 1.07994 m .51579 1.0898 L .51165 1.07643 L F
.51717 1.09078 m .51791 1.09942 L .51553 1.08885 L 0 .546 .018 r
F
.51791 1.09942 m .51799 1.10041 L .51733 1.09731 L F
.51791 1.09942 m .51733 1.09731 L .51553 1.08885 L F
.51717 1.09078 m .5211 1.11289 L .51799 1.10041 L F
.51717 1.09078 m .52292 1.11781 L .5211 1.11289 L F
.51717 1.09078 m .52221 1.11187 L .52292 1.11781 L F
.51717 1.09078 m .51975 1.10028 L .52221 1.11187 L F
0 g
.51694 1.08935 m
.51717 1.09078 L
s
.51579 1.08703 m
.51717 1.09078 L
s
.68579 .81068 m
.68581 .81067 L
s
.68581 .81067 m
.68912 .80925 L
s
.67926 .83293 m
.68113 .83583 L
s
.67983 .84431 m
.6816 .83939 L
s
.68083 .83914 m
.68199 .83717 L
s
.68363 .82858 m
.684 .82769 L
s
.684 .82769 m
.68401 .82766 L
s
.52793 .80993 m .52118 .79664 L .52097 .80202 L 0 .966 .442 r
F
0 g
.51368 .80272 m
.52097 .80202 L
s
.52793 .80993 m .52892 .79607 L .52118 .79664 L 0 .966 .442 r
F
.52793 .80993 m .53664 .80271 L .52892 .79607 L F
.55157 .82186 m .546 .80519 L .54528 .8135 L 0 1 .383 r
F
.52793 .80993 m .54518 .81456 L .54519 .81451 L 0 .966 .442 r
F
.54466 .81373 m .54519 .81451 L .54528 .8135 L 0 1 .391 r
F
.54143 .80897 m .54528 .8135 L .546 .80519 L F
.52793 .80993 m .54469 .81437 L .54143 .80897 L 0 .966 .442 r
F
.54469 .81437 m .54519 .81451 L .54143 .80897 L F
.5371 .80179 m .546 .80519 L .53904 .79791 L 0 1 .391 r
F
.53664 .80271 m .54143 .80897 L .5371 .80179 L F
.54143 .80897 m .546 .80519 L .5371 .80179 L F
.53664 .80271 m .54242 .8089 L .53792 .80166 L 0 .966 .442 r
F
.53633 .80297 m .53831 .80489 L .53664 .80271 L F
.53831 .80489 m .54242 .8089 L .53664 .80271 L F
.52793 .80993 m .54143 .80897 L .53633 .80297 L F
.54143 .80897 m .54242 .8089 L .53633 .80297 L F
.52793 .80993 m .53742 .8151 L .54518 .81456 L F
.52795 .82012 m .54143 .80897 L .53664 .80271 L 0 1 .391 r
F
.52795 .82012 m .54528 .8135 L .54143 .80897 L F
.55157 .82186 m .54528 .8135 L .54782 .81759 L 0 1 .383 r
F
.54143 .80897 m .54519 .81451 L .54602 .80865 L 0 .966 .442 r
F
.52795 .82012 m .54518 .81459 L .54519 .81451 L 0 1 .391 r
F
.52795 .82012 m .54519 .81451 L .54466 .81373 L F
.53792 .80166 m .54602 .80865 L .53905 .80072 L 0 .966 .442 r
F
.54242 .8089 m .54602 .80865 L .53792 .80166 L F
.54782 .81759 m .54528 .8135 L .54519 .81451 L 0 1 .383 r
F
.54782 .81759 m .54519 .81451 L .54532 .81475 L F
.55157 .82328 m .54602 .80865 L .54519 .81451 L 0 .998 .427 r
F
.54532 .81475 m .54519 .81451 L .54518 .81456 L F
.55157 .82328 m .54519 .81451 L .54532 .81475 L F
.54532 .81475 m .54519 .81451 L .54518 .81459 L 0 1 .383 r
F
.52795 .82012 m .53664 .80271 L .52893 .79761 L 0 1 .391 r
F
.53664 .80271 m .53904 .79791 L .5325 .79772 L F
.53664 .80271 m .5325 .79772 L .5325 .79772 L 0 .966 .442 r
F
.53596 .80213 m .5325 .79772 L .52892 .79607 L F
.53664 .80271 m .5325 .79772 L .53596 .80213 L F
.53138 .79606 m .54713 .7928 L .54781 .7857 L 0 1 .404 r
F
.53141 .7961 m .54713 .7928 L .53138 .79606 L F
.52892 .79607 m .53184 .79681 L .53138 .79606 L 0 1 .454 r
F
.53184 .79681 m .53189 .79682 L .53138 .79606 L F
.53069 .79495 m .54781 .7857 L .54035 .78042 L 0 1 .404 r
F
.52892 .79607 m .53134 .79606 L .53057 .79509 L 0 1 .454 r
F
.53134 .79606 m .53138 .79606 L .53107 .7957 L F
.53134 .79606 m .53107 .7957 L .53057 .79509 L F
.52914 .79302 m .54035 .78042 L .52972 .78049 L 0 1 .404 r
F
.52913 .79324 m .53062 .79506 L .52914 .79302 L F
.53062 .79506 m .54035 .78042 L .52914 .79302 L F
.52913 .79324 m .54039 .78925 L .52973 .78496 L 0 1 .454 r
F
.52892 .79607 m .53062 .79506 L .52913 .79324 L F
.53062 .79506 m .54039 .78925 L .52913 .79324 L F
.5325 .79771 m .53904 .79791 L .53189 .79682 L 0 1 .404 r
F
.53189 .79682 m .53905 .80072 L .54717 .80068 L 0 1 .454 r
F
.52892 .79607 m .5325 .79771 L .53189 .79682 L F
.5325 .79771 m .53905 .80072 L .53189 .79682 L F
.53189 .79682 m .53904 .79791 L .54713 .7928 L 0 1 .404 r
F
.52893 .79761 m .5325 .79771 L .53189 .79682 L F
.52893 .79761 m .53062 .79506 L .52913 .79324 L F
.52893 .79761 m .53138 .79606 L .53069 .79495 L F
.53138 .79606 m .54781 .7857 L .53069 .79495 L F
.53182 .79684 m .53189 .79682 L .53126 .79613 L F
.53189 .79682 m .54713 .7928 L .53141 .7961 L F
.53189 .79682 m .53141 .7961 L .53126 .79613 L F
.53138 .79606 m .54717 .80068 L .54786 .79599 L 0 1 .454 r
F
.53189 .79682 m .54717 .80068 L .53138 .79606 L F
.53057 .79509 m .54786 .79599 L .54039 .78925 L F
.53138 .79606 m .54786 .79599 L .53057 .79509 L F
.53126 .79613 m .53141 .7961 L .53138 .79606 L 0 1 .404 r
F
.52893 .79761 m .53182 .79684 L .53126 .79613 L F
.53664 .80271 m .5325 .79772 L .52893 .79761 L 0 1 .391 r
F
.53664 .80271 m .53905 .80072 L .5325 .79772 L 0 .966 .442 r
F
0 g
.52097 .80202 m
.52793 .80993 L
s
.56123 1.21201 m
.56192 1.21919 L
s
.56192 1.21919 m
.56192 1.21921 L
s
.56192 1.21921 m
.56193 1.21936 L
s
.56193 1.21936 m
.56194 1.21942 L
s
.56194 1.21942 m
.56194 1.21949 L
s
.55981 1.19725 m
.56002 1.19941 L
s
.56002 1.19941 m
.56123 1.21201 L
s
.55977 1.19683 m
.55981 1.19725 L
s
.47664 .76794 m .47483 .75852 L .46721 .75943 L 0 1 .49 r
F
.47664 .76794 m .4859 .76098 L .47483 .75852 L F
.47664 .76794 m .49447 .76582 L .4859 .76098 L F
.47664 .76794 m .49483 .7698 L .49447 .76582 L F
.47664 .76794 m .48718 .7707 L .49483 .7698 L F
0 g
.4694 .7686 m
.47664 .76794 L
s
.46809 .76311 m
.47664 .76794 L
s
.32843 .928 m
.33001 .93103 L
s
.67561 .86231 m .67517 .85722 L .6723 .8685 L 0 .795 .086 r
F
.66826 .89376 m .67561 .86231 L .66803 .88678 L 0 .795 .084 r
F
0 g
.61585 .97464 m
.61612 .97634 L
s
.61497 .96901 m
.61585 .97464 L
s
.61371 .96099 m
.61497 .96901 L
s
.5616 .86368 m
.56764 .86484 L
s
.48051 .81456 m .4716 .8001 L .47265 .80786 L 0 1 .411 r
F
0 g
.46652 .81285 m
.47265 .80786 L
s
.7226 .78401 m .74272 .78927 L .74617 .78562 L 0 1 .5 r
F
.7226 .78401 m .73263 .78858 L .74272 .78927 L F
0 g
.74272 .78927 m
.74683 .79538 L
s
.58529 .76039 m .57941 .7503 L .57823 .75676 L 0 1 .416 r
F
.58529 .76039 m .58862 .74418 L .57941 .7503 L F
0 g
.50435 1.0505 m
.50488 1.05114 L
s
.69884 .81524 m .69746 .80467 L .69441 .80912 L 0 1 .482 r
F
.69884 .81524 m .70673 .80435 L .69746 .80467 L F
0 g
.69441 .80912 m
.69884 .81524 L
s
.68985 .81597 m
.69884 .81524 L
s
.45055 .77883 m .44041 .76918 L .44178 .77458 L 0 1 .441 r
F
0 g
.43531 .77847 m
.44178 .77458 L
s
.56698 .83797 m
.57164 .84299 L
s
.56437 .84991 m
.57164 .84299 L
s
.67804 .83305 m
.67926 .83293 L
s
.63415 .6839 m .65164 .67008 L .63878 .67184 L 0 1 .469 r
F
0 g
.65164 .67008 m
.65961 .67228 L
s
.62687 .91494 m .63384 .9193 L .64113 .91652 L 0 1 .365 r
F
0 g
.64113 .91652 m
.64381 .92349 L
s
.29309 .82139 m .27996 .81588 L .28356 .8189 L 0 .775 .46 r
F
.70673 .80435 m .72431 .79826 L .71465 .79397 L 0 1 .489 r
F
0 g
.72431 .79826 m
.73411 .79864 L
s
.72431 .79826 m
.72897 .80444 L
s
.54343 .82707 m
.54449 .82846 L
s
.62687 .91494 m .64044 .89951 L .6331 .89557 L 0 1 .365 r
F
0 g
.64044 .89951 m
.64388 .90848 L
s
.64044 .89951 m
.64801 .89719 L
s
.52116 1.0992 m
.52312 1.11213 L
s
.51975 1.10028 m
.52116 1.0992 L
s
.48051 .81456 m .47834 .79477 L .4716 .8001 L 0 1 .411 r
F
0 g
.46342 .79381 m
.4716 .8001 L
s
.48051 .81456 m .4884 .79544 L .47834 .79477 L 0 1 .411 r
F
.48051 .81456 m .49627 .80214 L .4884 .79544 L F
.48051 .81456 m .4967 .81042 L .49627 .80214 L F
.48051 .81456 m .48994 .81574 L .4967 .81042 L F
0 g
.47265 .80786 m
.48051 .81456 L
s
.50358 .78569 m .49537 .77577 L .49572 .77976 L 0 1 .469 r
F
0 g
.48846 .78041 m
.49572 .77976 L
s
.50358 .78569 m .50309 .77547 L .49537 .77577 L 0 1 .469 r
F
.50358 .78569 m .51375 .77906 L .50309 .77547 L F
.50358 .78569 m .52163 .78501 L .51375 .77906 L F
.50358 .78569 m .52146 .78934 L .52163 .78501 L F
.50358 .78569 m .51372 .78963 L .52146 .78934 L F
0 g
.49572 .77976 m
.50358 .78569 L
s
.58862 .74418 m .6035 .72727 L .59196 .72897 L 0 1 .428 r
F
0 g
.6035 .72727 m
.60484 .72787 L
s
.6035 .72727 m
.61341 .72171 L
s
.67139 1.24849 m .68 1.23352 L .67588 1.24888 L 0 .233 .136 r
F
.67481 1.28789 m .68 1.23352 L .68389 1.2288 L 0 .123 .117 r
F
.67481 1.28789 m .67588 1.24888 L .68 1.23352 L F
0 g
.68 1.23352 m
.68168 1.21382 L
s
.68 1.23352 m
.68109 1.23219 L
s
.41677 .75298 m .41246 .74108 L .4053 .74517 L 0 1 .466 r
F
0 g
.39573 .74231 m
.4053 .74517 L
s
.41677 .75298 m .42389 .74029 L .41246 .74108 L 0 1 .466 r
F
.41677 .75298 m .43352 .74345 L .42389 .74029 L F
.41677 .75298 m .4349 .74844 L .43352 .74345 L F
.41677 .75298 m .42772 .75252 L .4349 .74844 L F
0 g
.40998 .75696 m
.41677 .75298 L
s
.40717 .74983 m
.41677 .75298 L
s
.64765 .85831 m .66304 .84732 L .65443 .84358 L 0 1 .426 r
F
0 g
.66304 .84732 m
.67173 .84608 L
s
.66304 .84732 m
.66723 .85451 L
s
.58032 .87279 m
.58177 .87529 L
s
.41255 .73561 m .40068 .72987 L .40258 .73315 L 0 1 .519 r
F
0 g
.40072 .73406 m
.40258 .73315 L
s
.68383 .82283 m
.6849 .82094 L
s
.6849 .82094 m
.685 .82077 L
s
.50596 .89176 m .49969 .87531 L .50001 .8831 L 0 .835 .358 r
F
0 g
.49459 .88638 m
.49891 .89275 L
s
.50596 .89176 m .50551 .87167 L .49969 .87531 L 0 .835 .358 r
F
0 g
.49459 .88638 m
.50001 .8831 L
s
.49343 .8674 m
.49969 .87531 L
s
.55157 .82186 m .5704 .80492 L .56402 .79765 L 0 1 .383 r
F
0 g
.56708 .82859 m
.57079 .82527 L
s
.57079 .82527 m
.57468 .82179 L
s
.57002 .81615 m
.57468 .82179 L
s
.55157 .82186 m .56896 .81488 L .5704 .80492 L 0 1 .383 r
F
0 g
.5704 .80492 m
.5787 .79653 L
s
.27456 .81132 m
.27522 .81386 L
s
.27522 .81386 m
.27996 .81588 L
s
.50551 .87167 m .49888 .85649 L .4992 .8639 L 0 .9 .369 r
F
0 g
.49343 .8674 m
.4992 .8639 L
s
.55157 .82186 m .5609 .82214 L .56896 .81488 L 0 1 .383 r
F
0 g
.5609 .82214 m
.56621 .81736 L
s
.56621 .81736 m
.56896 .81488 L
s
.56896 .81488 m
.57002 .81615 L
s
.45055 .77883 m .4475 .76508 L .44041 .76918 L 0 1 .441 r
F
0 g
.43152 .76523 m
.44041 .76918 L
s
.45055 .77883 m .45834 .76501 L .4475 .76508 L 0 1 .441 r
F
.45055 .77883 m .46713 .76926 L .45834 .76501 L F
.45055 .77883 m .468 .77499 L .46713 .76926 L F
.45055 .77883 m .46089 .77909 L .468 .77499 L F
0 g
.44383 .78286 m
.45055 .77883 L
s
.44178 .77458 m
.45055 .77883 L
s
.62976 .97576 m .63542 .97734 L .64192 .96966 L 0 1 .313 r
F
0 g
.64043 .97142 m
.64192 .96966 L
s
.63979 .98368 m
.64334 .97388 L
s
.64192 .96966 m
.64198 .96982 L
s
.30257 .92715 m .29275 .9215 L .29077 .92002 L 0 .115 .159 r
F
0 g
.28346 .91751 m
.29077 .92002 L
s
.64105 1.01073 m
.64135 1.01356 L
s
.64076 1.00796 m
.64105 1.01073 L
s
.64057 1.00619 m
.64076 1.00796 L
s
.55408 .79792 m .57235 .79188 L .57352 .78445 L 0 1 .397 r
F
.55408 .79792 m .56402 .79765 L .57235 .79188 L F
0 g
.57235 .79188 m
.5787 .79652 L
s
.68219 .8278 m
.68228 .82793 L
s
.6775 .82121 m
.67911 .82347 L
s
.68153 .82688 m
.68219 .8278 L
s
.56974 .90393 m
.57642 .9059 L
s
.50551 .87167 m .50506 .85262 L .49888 .85649 L 0 .9 .369 r
F
0 g
.49227 .84931 m
.49888 .85649 L
s
.62828 1.06572 m .64028 1.00343 L .6357 1.01149 L 0 1 .179 r
F
0 g
.64028 1.00343 m
.64057 1.00619 L
s
.64028 1.00343 m
.64268 .99676 L
s
.63399 1.0608 m
.63423 1.0474 L
s
.59531 .71463 m .61762 .70765 L .61931 .70226 L 0 1 .45 r
F
.59531 .71463 m .60735 .71295 L .61762 .70765 L F
0 g
.61762 .70765 m
.62497 .70991 L
s
.50641 .91291 m .50049 .89508 L .50081 .90325 L 0 .765 .347 r
F
0 g
.49574 .90624 m
.49966 .91298 L
s
.50641 .91291 m .50596 .89176 L .50049 .89508 L 0 .765 .347 r
F
0 g
.49574 .90624 m
.50081 .90325 L
s
.49891 .89275 m
.50049 .89508 L
s
.56221 1.14366 m
.56452 1.14648 L
s
.56127 1.14251 m
.56221 1.14366 L
s
.56452 1.14648 m
.56482 1.14685 L
s
.56236 1.16409 m
.56322 1.18096 L
s
.56167 1.15043 m
.56236 1.16409 L
s
.56127 1.14251 m
.56167 1.15043 L
s
.51024 1.07261 m .50974 1.06643 L .5073 1.05983 L 0 0 .105 r
F
0 g
.50435 1.0505 m
.5073 1.05983 L
s
.51024 1.07261 m .51336 1.07806 L .50974 1.06643 L 0 0 .105 r
F
.51024 1.07261 m .51596 1.08809 L .51336 1.07806 L F
.51024 1.07261 m .51333 1.08315 L .51579 1.0898 L F
0 g
.50765 1.06263 m
.51024 1.07261 L
s
.5361 1.12407 m .53875 1.17008 L .53645 1.14231 L 0 .901 .153 r
F
0 g
.53722 1.10855 m
.53724 1.10866 L
s
.5361 1.12407 m .54224 1.19925 L .53875 1.17008 L 0 .901 .153 r
F
.5361 1.12407 m .54458 1.21014 L .54224 1.19925 L F
.5361 1.12407 m .5442 1.19142 L .54458 1.21014 L F
.5361 1.12407 m .54137 1.15595 L .5442 1.19142 L F
0 g
.54124 1.11087 m
.54148 1.11577 L
s
.53724 1.10866 m
.54007 1.12702 L
s
.5361 1.12407 m .53791 1.12726 L .54137 1.15595 L 0 .901 .153 r
F
0 g
.53743 1.11423 m
.53791 1.12726 L
s
.53561 1.12069 m
.5361 1.12407 L
s
.53553 1.13527 m
.53645 1.14231 L
s
.5361 1.12407 m
.53645 1.14231 L
s
.31242 .93105 m .30897 .93195 L .30257 .92715 L 0 0 0 r
F
.31242 .93105 m .3166 .93688 L .30897 .93195 L F
.31242 .93105 m .32034 .93863 L .3166 .93688 L F
.31242 .93105 m .31853 .93612 L .32034 .93863 L F
0 g
.31089 .92803 m
.31242 .93105 L
s
.30485 .92616 m
.31242 .93105 L
s
.4716 .8001 m
.47834 .79477 L
s
.54055 1.13009 m .54224 1.13066 L .54597 1.16294 L 0 .89 .169 r
F
0 g
.54148 1.11577 m
.54224 1.13066 L
s
.5609 .82214 m
.56708 .82859 L
s
.7226 .78401 m .74617 .78562 L .74098 .77925 L 0 1 .5 r
F
0 g
.74617 .78562 m
.7557 .78652 L
s
.55408 .79792 m .57352 .78445 L .56658 .77932 L 0 1 .397 r
F
0 g
.56402 .79765 m
.57235 .79188 L
s
.57352 .78445 m
.58199 .77777 L
s
.45843 .75552 m
.46721 .75943 L
s
.50506 .85262 m .49807 .83862 L .4984 .84566 L 0 .96 .379 r
F
0 g
.49227 .84931 m
.4984 .84566 L
s
.56344 .99652 m .56225 .97009 L .56063 .97639 L 0 .387 .273 r
F
0 g
.55834 .97314 m
.56063 .97639 L
s
.5388 .81664 m
.54407 .82245 L
s
.41255 .73561 m .40817 .72724 L .40068 .72987 L 0 1 .519 r
F
.41255 .73561 m .42008 .72702 L .40817 .72724 L F
.41255 .73561 m .43008 .72948 L .42008 .72702 L F
.41255 .73561 m .43149 .73298 L .43008 .72948 L F
.41255 .73561 m .42396 .7356 L .43149 .73298 L F
0 g
.40543 .73803 m
.41255 .73561 L
s
.40258 .73315 m
.41255 .73561 L
s
.5596 .8417 m
.5597 .84162 L
s
.29309 .82139 m .28438 .81326 L .27996 .81588 L 0 .775 .46 r
F
0 g
.39472 .72898 m
.40068 .72987 L
s
.50506 .85262 m .50461 .83458 L .49807 .83862 L 0 .96 .379 r
F
0 g
.49111 .83211 m
.49807 .83862 L
s
.56043 1.23666 m
.56088 1.23976 L
s
.56251 1.251 m
.56277 1.25274 L
s
.56277 1.25274 m
.56375 1.2595 L
s
.30178 .82948 m .30225 .82168 L .29309 .82139 L 0 .651 .433 r
F
.30178 .82948 m .31156 .8248 L .30225 .82168 L F
.30178 .82948 m .31478 .82866 L .31156 .8248 L F
.30178 .82948 m .31057 .83066 L .31478 .82866 L F
0 g
.29253 .82636 m
.30178 .82948 L
s
.29791 .83075 m
.30178 .82948 L
s
.3504 .71679 m
.35101 .71681 L
s
.50685 .93502 m .50129 .91577 L .50161 .9243 L 0 .688 .337 r
F
0 g
.4969 .92692 m
.50036 .93401 L
s
.50685 .93502 m .50641 .91291 L .50129 .91577 L 0 .688 .337 r
F
0 g
.4969 .92691 m
.50161 .9243 L
s
.49966 .91298 m
.50129 .91577 L
s
.58078 .88712 m
.58469 .89422 L
s
.53791 1.12726 m
.53854 1.13241 L
s
.53854 1.13241 m
.53855 1.13251 L
s
.53855 1.13251 m
.53905 1.13671 L
s
.54055 1.13009 m .5442 1.19142 L .54137 1.15595 L 0 .89 .169 r
F
.54055 1.13009 m .54798 1.22442 L .5442 1.19142 L F
.54055 1.13009 m .55017 1.23256 L .54798 1.22442 L F
.54055 1.13009 m .54929 1.20597 L .55017 1.23256 L F
0 g
.54932 1.13988 m
.55014 1.1591 L
s
.54055 1.13009 m .54597 1.16294 L .54929 1.20597 L 0 .89 .169 r
F
0 g
.54725 1.13465 m
.55014 1.1591 L
s
.54466 1.1288 m
.54597 1.16294 L
s
.54055 1.13009 m
.54137 1.15595 L
s
.53905 1.13671 m
.54137 1.15595 L
s
.54007 1.12702 m
.54055 1.13009 L
s
.54224 1.13066 m
.54388 1.14487 L
s
.54388 1.14487 m
.54597 1.16294 L
s
.54892 1.13056 m
.54932 1.13988 L
s
.54994 .82311 m
.55157 .82329 L
s
.54991 .8231 m
.54994 .82311 L
s
.54407 .82245 m
.54991 .8231 L
s
.55615 .77992 m .57528 .7737 L .57646 .76679 L 0 1 .409 r
F
.55615 .77992 m .56658 .77932 L .57528 .7737 L F
0 g
.57528 .7737 m
.58199 .77777 L
s
.65643 1.26088 m
.65873 1.26529 L
s
.56115 1.24384 m
.56168 1.24794 L
s
.56168 1.24794 m
.56198 1.25035 L
s
.55956 1.23136 m
.5597 1.23246 L
s
.5597 1.23246 m
.56064 1.23986 L
s
.56064 1.23986 m
.56115 1.24384 L
s
.50551 .87167 m .51363 .85486 L .50506 .85262 L 0 .9 .369 r
F
.50551 .87167 m .51995 .86262 L .51363 .85486 L F
.50551 .87167 m .5198 .87073 L .51995 .86262 L F
.50551 .87167 m .51361 .87461 L .5198 .87073 L F
.50596 .89176 m .51361 .87461 L .50551 .87167 L 0 .835 .358 r
F
0 g
.4992 .8639 m
.50551 .87167 L
s
.49969 .87531 m
.50551 .87167 L
s
.58862 .74418 m .58238 .73481 L .58119 .74089 L 0 1 .428 r
F
.58862 .74418 m .59196 .72897 L .58238 .73481 L F
.50506 .85262 m .51366 .83622 L .50461 .83458 L 0 .96 .379 r
F
.50506 .85262 m .52033 .84318 L .51366 .83622 L F
.50506 .85262 m .52018 .85081 L .52033 .84318 L F
.50506 .85262 m .51363 .85486 L .52018 .85081 L F
0 g
.4984 .84566 m
.50506 .85262 L
s
.49888 .85649 m
.50506 .85262 L
s
.57781 .88865 m
.57844 .88877 L
s
.57487 .89161 m
.57797 .89908 L
s
.68617 1.25092 m .69295 1.21275 L .69608 1.19815 L 0 0 .013 r
F
.68617 1.25092 m .69608 1.19815 L .69618 1.19681 L F
0 g
.6934 1.21066 m
.69503 1.20304 L
s
.69608 1.19815 m
.69909 1.18787 L
s
.55157 .82186 m .56402 .79765 L .55408 .79793 L 0 1 .383 r
F
0 g
.56402 .79765 m
.5704 .80492 L
s
.56344 .99652 m .56783 .97823 L .56225 .97009 L 0 .387 .273 r
F
0 g
.55897 .95446 m
.56225 .97009 L
s
.55813 .98413 m
.56343 .99652 L
s
.56063 .97639 m
.56343 .99647 L
s
.63937 .87838 m .63912 .86155 L .63596 .86956 L 0 1 .407 r
F
.63937 .87838 m .64765 .85831 L .63912 .86155 L F
.6331 .89557 m .63937 .87838 L .63178 .88068 L 0 1 .386 r
F
0 g
.56379 .84933 m
.56437 .8502 L
s
.56308 .84827 m
.56379 .84933 L
s
.56174 .84628 m
.56308 .84827 L
s
.55897 .84216 m
.56174 .84628 L
s
.63675 .94702 m .63703 .92963 L .6343 .93907 L 0 1 .341 r
F
.62067 .93714 m .63703 .92963 L .63384 .9193 L 0 1 .344 r
F
.62067 .93714 m .6343 .93907 L .63703 .92963 L F
0 g
.63703 .92963 m
.64381 .92349 L
s
.63702 .92962 m
.63703 .92963 L
s
.67481 1.28789 m .68389 1.2288 L .68498 1.23787 L 0 .123 .117 r
F
0 g
.68389 1.2288 m
.68618 1.21186 L
s
.68109 1.23219 m
.68389 1.2288 L
s
.65443 .84358 m .67025 .8338 L .66125 .82996 L 0 1 .44 r
F
0 g
.67025 .8338 m
.67453 .83339 L
s
.67025 .8338 m
.67264 .83748 L
s
.62976 .97576 m .63675 .94702 L .63023 .95467 L 0 1 .313 r
F
.59531 .71463 m .61931 .70226 L .61121 .69941 L 0 1 .45 r
F
0 g
.60998 .71399 m
.61509 .71599 L
s
.61931 .70226 m
.62955 .69656 L
s
.6861 .82071 m
.68682 .82066 L
s
.68539 .82075 m
.6861 .82071 L
s
.68514 .82076 m
.68539 .82075 L
s
.685 .82077 m
.68514 .82076 L
s
.6775 .82121 m
.68023 .82105 L
s
.50461 .83458 m .49726 .82165 L .49759 .82833 L 0 1 .389 r
F
0 g
.49111 .83211 m
.49759 .82833 L
s
.63415 .6839 m .62783 .67683 L .62612 .68172 L 0 1 .469 r
F
.63415 .6839 m .63878 .67184 L .62783 .67683 L F
0 g
.48718 .7707 m
.49537 .77577 L
s
.50596 .89176 m .51957 .88327 L .51361 .87461 L 0 .835 .358 r
F
.50596 .89176 m .51942 .89188 L .51957 .88327 L F
.50596 .89176 m .51358 .89552 L .51942 .89188 L F
.50641 .91291 m .51358 .89552 L .50596 .89176 L 0 .765 .347 r
F
0 g
.50001 .8831 m
.50596 .89176 L
s
.50049 .89508 m
.50596 .89176 L
s
.69009 1.1223 m .69224 1.14799 L .69685 1.15295 L 0 1 .249 r
F
.6805 1.18311 m .69009 1.1223 L .68564 1.12065 L 0 1 .228 r
F
.6805 1.18311 m .69224 1.14799 L .69009 1.1223 L F
0 g
.69009 1.1223 m
.69148 1.09086 L
s
.52118 .79664 m
.52892 .79607 L
s
.51372 .78964 m
.52118 .79664 L
s
.59608 .92234 m
.59782 .9268 L
s
.59267 .93731 m
.59317 .93628 L
s
.59317 .93628 m
.59782 .9268 L
s
.59147 .93975 m
.59267 .93731 L
s
.62067 .93714 m .63384 .9193 L .62687 .91494 L 0 1 .344 r
F
0 g
.63384 .9193 m
.64113 .91652 L
s
.63384 .9193 m
.63702 .92962 L
s
.55615 .77992 m .57646 .76679 L .56915 .76223 L 0 1 .409 r
F
0 g
.57646 .76679 m
.58529 .76039 L
s
.57734 .88913 m
.57781 .88865 L
s
.5656 .89158 m .56861 .86616 L .56167 .87313 L 0 1 .334 r
F
0 g
.56479 .86098 m
.56861 .86616 L
s
.56308 .84827 m
.56356 .84889 L
s
.56356 .84889 m
.56437 .84991 L
s
.50461 .83458 m .50416 .81748 L .49726 .82165 L 0 1 .389 r
F
0 g
.48994 .81574 m
.49726 .82165 L
s
.50461 .83458 m .51368 .81862 L .50416 .81748 L 0 1 .389 r
F
.50461 .83458 m .52072 .82487 L .51368 .81862 L F
.50461 .83458 m .52056 .83206 L .52072 .82487 L F
.50461 .83458 m .51366 .83622 L .52056 .83206 L F
0 g
.49807 .83862 m
.50461 .83458 L
s
.49759 .82833 m
.50461 .83458 L
s
.64765 .85831 m .64603 .8452 L .64344 .85111 L 0 1 .426 r
F
.64765 .85831 m .65443 .84358 L .64603 .8452 L F
.54775 .86296 m .55853 .8425 L .54965 .84164 L 0 1 .357 r
F
0 g
.55853 .8425 m
.56308 .84827 L
s
.55853 .8425 m
.5596 .8417 L
s
.70673 .80435 m .70509 .79392 L .70203 .79816 L 0 1 .489 r
F
.70673 .80435 m .71465 .79397 L .70509 .79392 L F
0 g
.70203 .79816 m
.70673 .80435 L
s
.69746 .80467 m
.70673 .80435 L
s
.56783 .97823 m .5663 .9525 L .56468 .95985 L 0 .528 .292 r
F
0 g
.56334 .95858 m
.56468 .95985 L
s
.6331 .89557 m .63178 .88068 L .62939 .88751 L 0 1 .386 r
F
.62687 .91494 m .6331 .89557 L .6258 .89834 L 0 1 .365 r
F
.66224 .87186 m .68238 .83158 L .67782 .83343 L 0 1 .202 r
F
.66224 .87186 m .67948 .8414 L .68238 .83158 L F
0 g
.68238 .83158 m
.68363 .82858 L
s
.68265 .82492 m
.68383 .82283 L
s
.49726 .82165 m
.50416 .81748 L
s
.47834 .79477 m .46929 .78379 L .47016 .78978 L 0 1 .422 r
F
0 g
.46342 .79381 m
.47016 .78978 L
s
.56783 .97823 m .5722 .95754 L .5663 .9525 L 0 .528 .292 r
F
0 g
.56267 .93758 m
.5663 .9525 L
s
.29275 .9215 m .28074 .91425 L .28475 .91667 L 0 .223 .198 r
F
0 g
.28346 .91751 m
.28475 .91667 L
s
.50732 .95896 m .5021 .93759 L .50244 .94679 L 0 .599 .325 r
F
0 g
.4981 .94919 m
.50113 .95641 L
s
.50732 .95896 m .50685 .93502 L .5021 .93759 L 0 .599 .325 r
F
0 g
.4981 .94919 m
.50244 .94679 L
s
.50036 .93401 m
.5021 .93759 L
s
.5722 .95754 m .57022 .93427 L .56868 .94154 L 0 .647 .309 r
F
0 g
.56825 .94126 m
.56868 .94154 L
s
.5722 .95754 m .57638 .93754 L .57022 .93427 L 0 .647 .309 r
F
0 g
.5662 .92067 m
.57022 .93427 L
s
.5663 .9525 m
.57218 .95753 L
s
.57218 .95753 m
.5722 .95754 L
s
.56868 .94154 m
.5722 .95754 L
s
.57638 .93754 m .57409 .91635 L .57254 .92348 L 0 .749 .325 r
F
0 g
.57254 .92348 m
.57638 .93754 L
s
.57022 .93427 m
.57638 .93754 L
s
.56974 .90393 m
.57409 .91635 L
s
.5662 .92067 m
.57254 .92348 L
s
.55408 .79792 m .56658 .77932 L .55615 .77992 L 0 1 .397 r
F
0 g
.56658 .77932 m
.57352 .78445 L
s
.56658 .77932 m
.57528 .7737 L
s
.57409 .91635 m
.57974 .91806 L
s
.47834 .79477 m .47657 .77951 L .46929 .78379 L 0 1 .422 r
F
.47834 .79477 m .48714 .7798 L .47657 .77951 L F
.47834 .79477 m .49534 .78479 L .48714 .7798 L F
.47834 .79477 m .49569 .79116 L .49534 .78479 L F
.47834 .79477 m .4884 .79543 L .49569 .79116 L F
0 g
.47016 .78978 m
.47834 .79477 L
s
.46089 .77909 m
.46929 .78379 L
s
.36519 .71869 m .36825 .71246 L .36084 .71684 L 0 1 .495 r
F
.37382 .72167 m .37165 .71853 L .36519 .71869 L 0 1 .525 r
F
.37381 .72238 m .37165 .71853 L .36519 .71869 L 0 1 .495 r
F
.37165 .71853 m .36825 .71246 L .36519 .71869 L F
.36519 .71869 m .36822 .71357 L .36083 .71719 L 0 1 .525 r
F
.37165 .71853 m .36822 .71357 L .36519 .71869 L F
0 g
.35101 .71681 m
.36083 .71719 L
s
.35193 .7158 m
.36084 .71684 L
s
.37165 .71853 m .38052 .71048 L .36825 .71246 L 0 1 .495 r
F
.37382 .72167 m .376 .71849 L .37165 .71853 L 0 1 .525 r
F
.376 .71849 m .39116 .71217 L .38052 .71048 L 0 1 .495 r
F
.38076 .71829 m .39116 .71217 L .376 .71849 L F
.38189 .71762 m .39306 .71639 L .39116 .71217 L F
.38582 .71751 m .39306 .71639 L .38189 .71762 L F
.38906 .71764 m .39306 .71639 L .38076 .71829 L F
.37382 .72167 m .38562 .7202 L .39123 .71747 L 0 1 .525 r
F
.37381 .72238 m .38561 .72077 L .39123 .71747 L 0 1 .495 r
F
.38906 .71764 m .39123 .71747 L .39306 .71639 L F
.37382 .72167 m .39123 .71747 L .38906 .71764 L 0 1 .525 r
F
.37381 .72238 m .39123 .71747 L .38906 .71764 L 0 1 .495 r
F
.38906 .71764 m .39123 .71747 L .39306 .71658 L 0 1 .525 r
F
.40378 .7185 m .39116 .71217 L .39306 .71639 L 0 1 .485 r
F
.39614 .71721 m .39114 .71322 L .39306 .71658 L 0 1 .52 r
F
.40817 .72724 m .39592 .72159 L .39783 .72491 L F
.40817 .72724 m .40424 .71968 L .39592 .72159 L F
.40813 .7296 m .40424 .71968 L .3959 .72282 L 0 1 .479 r
F
.40424 .71968 m .40378 .7185 L .40232 .7193 L F
.40424 .71968 m .40232 .7193 L .39592 .72159 L 0 1 .52 r
F
.40424 .71968 m .40232 .7193 L .3959 .72282 L 0 1 .479 r
F
.40424 .71968 m .40377 .71878 L .40232 .7193 L 0 1 .52 r
F
.40377 .71878 m .39996 .7171 L .39614 .71721 L F
.39996 .7171 m .39114 .71322 L .39614 .71721 L F
.38076 .71829 m .38582 .71751 L .38189 .71762 L 0 1 .495 r
F
.37382 .72167 m .38906 .71764 L .38076 .71829 L 0 1 .525 r
F
.37381 .72238 m .38906 .71764 L .38076 .71829 L 0 1 .495 r
F
.38076 .71829 m .39306 .71658 L .39114 .71322 L 0 1 .525 r
F
.38906 .71764 m .39306 .71658 L .38076 .71829 L F
.376 .71849 m .39114 .71322 L .38049 .71194 L F
.37382 .72167 m .38076 .71829 L .376 .71849 L F
.38076 .71829 m .39114 .71322 L .376 .71849 L F
.37381 .72238 m .38076 .71829 L .376 .71849 L 0 1 .495 r
F
.37381 .72238 m .376 .71849 L .37165 .71853 L F
.376 .71849 m .38052 .71048 L .37165 .71853 L F
.37165 .71853 m .38049 .71194 L .36822 .71357 L 0 1 .525 r
F
.376 .71849 m .38049 .71194 L .37165 .71853 L F
0 g
.3632 .72069 m
.37381 .72238 L
s
.59196 .72897 m .60735 .71295 L .59531 .71463 L 0 1 .44 r
F
0 g
.60735 .71295 m
.60998 .71399 L
s
.60735 .71295 m
.61762 .70765 L
s
.68666 .81182 m
.68985 .81597 L
s
.6862 .81121 m
.68666 .81182 L
s
.68618 .81119 m
.6862 .81121 L
s
.68579 .81068 m
.68618 .81119 L
s
.68572 .81059 m
.68579 .81068 L
s
.68541 .81019 m
.68572 .81059 L
s
.71465 .79397 m .73263 .78858 L .7226 .78401 L 0 1 .495 r
F
0 g
.73263 .78858 m
.74272 .78927 L
s
.73263 .78858 m
.73755 .79485 L
s
.63884 1.20716 m
.63885 1.20768 L
s
.57642 .9059 m
.57933 .91463 L
s
.50641 .91291 m .51919 .90518 L .51358 .89552 L 0 .765 .347 r
F
.50641 .91291 m .51904 .9143 L .51919 .90518 L F
.50641 .91291 m .51356 .91761 L .51904 .9143 L F
.50685 .93502 m .51356 .91761 L .50641 .91291 L 0 .688 .337 r
F
0 g
.50081 .90325 m
.50641 .91291 L
s
.50129 .91577 m
.50641 .91291 L
s
.54775 .86296 m .55617 .86455 L .56329 .85895 L 0 1 .357 r
F
0 g
.56329 .85895 m
.56479 .86098 L
s
.55157 .82186 m .55408 .79793 L .546 .80519 L 0 1 .383 r
F
0 g
.55063 .82079 m
.55157 .82186 L
s
.54986 .82314 m
.54991 .8231 L
s
.54991 .8231 m
.54993 .82308 L
s
.54993 .82308 m
.5509 .82236 L
s
.55115 .82217 m
.55156 .82186 L
s
.41246 .74108 m .40061 .73381 L .40249 .7383 L 0 1 .473 r
F
0 g
.39573 .74231 m
.40249 .7383 L
s
.36675 .72657 m
.37381 .72238 L
s
.55822 .76307 m .57823 .75676 L .57941 .7503 L 0 1 .42 r
F
.55822 .76307 m .56915 .76223 L .57823 .75676 L F
0 g
.57823 .75676 m
.58529 .76039 L
s
.4475 .76508 m .43697 .75606 L .43835 .76125 L 0 1 .449 r
F
0 g
.43152 .76523 m
.43835 .76125 L
s
.57797 .89908 m
.58033 .89946 L
s
.44451 .74521 m .43359 .7382 L .43499 .74167 L 0 1 .509 r
F
0 g
.4316 .74282 m
.43499 .74167 L
s
.55881 1.00874 m .56883 1.01715 L .56344 .99652 L 0 .26 .245 r
F
0 g
.56343 .99652 m
.56344 .99652 L
s
.55881 1.00874 m .57126 1.03792 L .56883 1.01715 L 0 .26 .245 r
F
.55881 1.00874 m .56908 1.04489 L .57126 1.03792 L F
.55881 1.00874 m .56374 1.03233 L .56908 1.04489 L F
0 g
.55384 .99061 m
.55881 1.00874 L
s
.55642 .98815 m
.55881 1.00874 L
s
.28438 .81326 m .27096 .80827 L .27457 .81132 L 0 .869 .478 r
F
.54965 .84164 m .54409 .82745 L .54347 .8352 L 0 1 .369 r
F
.54775 .86296 m .54965 .84164 L .54253 .84723 L 0 1 .357 r
F
.50416 .81748 m .49627 .80214 L .4967 .81042 L 0 1 .401 r
F
.50416 .81748 m .50357 .79637 L .49627 .80214 L F
0 g
.48994 .81574 m
.4967 .81042 L
s
.50416 .81748 m .51372 .79695 L .50357 .79637 L 0 1 .401 r
F
.50416 .81748 m .52118 .80401 L .51372 .79695 L F
.50416 .81748 m .52098 .81285 L .52118 .80401 L F
.50416 .81748 m .51368 .81862 L .52098 .81285 L F
0 g
.4967 .81042 m
.50416 .81748 L
s
.60882 1.10084 m .62165 1.02371 L .62012 1.00214 L 0 1 .215 r
F
0 g
.62012 1.00214 m
.62163 1.02338 L
s
.62163 1.02338 m
.62165 1.02371 L
s
.61694 1.08664 m
.61711 1.10684 L
s
.61794 1.08189 m
.61819 1.09296 L
s
.56539 1.14755 m .57313 1.31377 L .56821 1.23201 L 0 .64 .21 r
F
.57403 1.34244 m .57313 1.3286 L .57618 1.33817 L 0 .963 .104 r
F
.57582 1.37618 m .57518 1.36284 L .57865 1.38043 L 0 .953 .097 r
F
.57868 1.38841 m .57211 1.27284 L .57847 1.38878 L 0 0 .094 r
F
.57868 1.38841 m .57548 1.32507 L .57211 1.27284 L F
.58025 1.40736 m .57582 1.37618 L .58229 1.40905 L 0 .953 .097 r
F
.57847 1.38878 m .57211 1.27284 L .57778 1.38973 L 0 0 .094 r
F
.5789 1.40637 m .57582 1.37618 L .57937 1.40675 L 0 .953 .097 r
F
.57937 1.40675 m .57582 1.37618 L .58025 1.40736 L F
.57778 1.38973 m .57211 1.27284 L .5773 1.39034 L 0 0 .094 r
F
.57867 1.40605 m .57582 1.37618 L .5789 1.40637 L 0 .953 .097 r
F
.5773 1.39034 m .57211 1.27284 L .57693 1.39091 L 0 0 .094 r
F
.57693 1.39091 m .57211 1.27284 L .57658 1.39164 L F
.57658 1.39164 m .57211 1.27284 L .57334 1.31692 L F
.56539 1.14755 m .5776 1.31996 L .57313 1.31377 L 0 .64 .21 r
F
0 g
.56482 1.14685 m
.56539 1.14755 L
s
.56539 1.14755 m
.56624 1.17299 L
s
.57598 1.13966 m
.57644 1.1657 L
s
.546 .80519 m
.55408 .79793 L
s
.55408 .79792 m .54781 .7857 L .54713 .7928 L 0 1 .397 r
F
.55408 .79792 m .55615 .77992 L .54781 .7857 L F
0 g
.54713 .7928 m
.54815 .79356 L
s
.54815 .79356 m
.55408 .79792 L
s
.62067 .93714 m .62729 .94229 L .6343 .93907 L 0 1 .344 r
F
0 g
.6343 .93907 m
.63675 .94702 L
s
.55857 1.03185 m
.5594 1.03489 L
s
.5594 1.03489 m
.56042 1.03863 L
s
.56042 1.03863 m
.5608 1.04001 L
s
.5608 1.04001 m
.56096 1.04059 L
s
.55854 1.03172 m
.55857 1.03185 L
s
.55854 1.03172 m
.55899 1.03452 L
s
.55899 1.03452 m
.5597 1.03892 L
s
.5597 1.03892 m
.56015 1.04167 L
s
.65443 .84358 m .65252 .83119 L .64992 .83667 L 0 1 .44 r
F
.65443 .84358 m .66125 .82996 L .65252 .83119 L F
.58476 .90018 m .58185 .88268 L .5803 .88913 L 0 .924 .358 r
F
0 g
.5803 .88913 m
.58098 .89083 L
s
.58033 .89946 m
.58083 .89955 L
s
.58083 .89955 m
.58096 .89957 L
s
.57844 .88877 m
.5803 .88913 L
s
.58083 .89955 m
.58094 .89941 L
s
.58094 .89941 m
.58319 .8963 L
s
.58394 .89526 m
.58469 .89422 L
s
.58047 .90005 m
.58083 .89955 L
s
.4475 .76508 m .44444 .75189 L .43697 .75606 L 0 1 .449 r
F
0 g
.42772 .75252 m
.43697 .75606 L
s
.4475 .76508 m .45579 .7515 L .44444 .75189 L 0 1 .449 r
F
.4475 .76508 m .46496 .75534 L .45579 .7515 L F
.4475 .76508 m .46583 .76084 L .46496 .75534 L F
.4475 .76508 m .45834 .76501 L .46583 .76084 L F
0 g
.44041 .76918 m
.4475 .76508 L
s
.43835 .76125 m
.4475 .76508 L
s
.54532 .81475 m
.54597 .81563 L
s
.55157 .82328 m .55415 .80807 L .54602 .80865 L 0 .998 .427 r
F
0 g
.54975 .82322 m
.54986 .82314 L
s
.55157 .82328 m .56415 .81323 L .55415 .80807 L 0 .998 .427 r
F
.55157 .82328 m .57055 .82197 L .56415 .81323 L F
.55157 .82328 m .56909 .82845 L .57055 .82197 L F
.55157 .82328 m .56095 .82901 L .56909 .82845 L F
0 g
.54597 .81563 m
.55157 .82328 L
s
.51979 1.1005 m
.52027 1.10274 L
s
.51975 1.10028 m
.51979 1.1005 L
s
.44451 .74521 m .4414 .73636 L .43359 .7382 L 0 1 .509 r
F
.44451 .74521 m .45323 .73738 L .4414 .73636 L F
.44451 .74521 m .46279 .74093 L .45323 .73738 L F
.44451 .74521 m .46368 .74464 L .46279 .74093 L F
.44451 .74521 m .45583 .74648 L .46368 .74464 L F
0 g
.43709 .74684 m
.44451 .74521 L
s
.43499 .74167 m
.44451 .74521 L
s
.29275 .9215 m .28295 .91483 L .28074 .91425 L 0 .223 .198 r
F
0 g
.27325 .91161 m
.28074 .91425 L
s
.56553 1.09153 m
.56639 1.10164 L
s
.59869 .70102 m .62186 .69436 L .62356 .68924 L 0 1 .46 r
F
.59869 .70102 m .61121 .69941 L .62186 .69436 L F
0 g
.62186 .69436 m
.62955 .69656 L
s
.26614 .80638 m
.27096 .80827 L
s
.55822 .76307 m .57941 .7503 L .57174 .7462 L 0 1 .42 r
F
0 g
.57941 .7503 m
.58862 .74418 L
s
.52647 .85811 m .52033 .84318 L .52018 .85081 L 0 1 .368 r
F
0 g
.51363 .85486 m
.52018 .85081 L
s
.57172 .85112 m .56715 .83718 L .56604 .84233 L 0 .988 .4 r
F
0 g
.5597 .84162 m
.56604 .84233 L
s
.57172 .85112 m .57484 .8378 L .56715 .83718 L 0 .988 .4 r
F
.57172 .85112 m .58398 .84379 L .57484 .8378 L F
.57172 .85112 m .58966 .85259 L .58398 .84379 L F
.57172 .85112 m .5881 .85833 L .58966 .85259 L F
.57172 .85112 m .5804 .8577 L .5881 .85833 L F
0 g
.56437 .8502 m
.57172 .85112 L
s
.56604 .84233 m
.57172 .85112 L
s
.54586 .88598 m .55617 .86455 L .54775 .86296 L 0 1 .345 r
F
.54586 .88598 m .56167 .87313 L .55617 .86455 L F
0 g
.55617 .86455 m
.56329 .85895 L
s
.52647 .85811 m .52721 .83852 L .52033 .84318 L 0 1 .368 r
F
0 g
.51366 .83622 m
.52033 .84318 L
s
.52018 .85081 m
.5235 .85466 L
s
.61375 .88286 m .63178 .88068 L .62735 .87175 L 0 1 .385 r
F
.61375 .88286 m .62939 .88751 L .63178 .88068 L F
0 g
.63178 .88068 m
.63937 .87838 L
s
.59196 .72897 m .58537 .7202 L .58417 .72595 L 0 1 .44 r
F
.59196 .72897 m .59531 .71463 L .58537 .7202 L F
.58476 .90018 m .58897 .88325 L .58185 .88268 L 0 .924 .358 r
F
0 g
.57684 .87235 m
.58185 .88268 L
s
.52574 .87899 m .51995 .86262 L .5198 .87073 L 0 .953 .357 r
F
0 g
.51361 .87461 m
.5198 .87073 L
s
.52574 .87899 m .52647 .85811 L .51995 .86262 L 0 .953 .357 r
F
0 g
.51363 .85486 m
.51995 .86262 L
s
.62687 .91494 m .6258 .89834 L .62342 .90596 L 0 1 .365 r
F
.62067 .93714 m .62687 .91494 L .61985 .91815 L 0 1 .344 r
F
.52721 .83852 m .52072 .82487 L .52056 .83206 L 0 1 .379 r
F
0 g
.51366 .83622 m
.52056 .83206 L
s
.52721 .83852 m .52795 .82013 L .52072 .82487 L 0 1 .379 r
F
0 g
.52056 .83206 m
.52294 .83437 L
s
.52721 .83852 m .53744 .821 L .52795 .82013 L 0 1 .379 r
F
.52721 .83852 m .54409 .82745 L .53744 .821 L F
0 g
.54515 .83696 m
.54965 .84164 L
s
.52721 .83852 m .54347 .8352 L .54409 .82745 L 0 1 .379 r
F
0 g
.54409 .82745 m
.54975 .82322 L
s
.52721 .83852 m .53623 .83994 L .54347 .8352 L 0 1 .379 r
F
0 g
.54347 .8352 m
.54515 .83696 L
s
.52647 .85811 m .53623 .83994 L .52721 .83852 L 0 1 .368 r
F
0 g
.52294 .83437 m
.52721 .83852 L
s
.52033 .84318 m
.52721 .83852 L
s
.50778 .98334 m .50294 .96071 L .50327 .97006 L 0 .499 .312 r
F
0 g
.4993 .9718 m
.50173 .97855 L
s
.50778 .98334 m .50732 .95896 L .50294 .96071 L 0 .499 .312 r
F
0 g
.4993 .9718 m
.50327 .97006 L
s
.50113 .95641 m
.50294 .96071 L
s
.53744 .821 m
.54409 .82745 L
s
.41246 .74108 m .40813 .7296 L .40061 .73381 L 0 1 .473 r
F
0 g
.39068 .73136 m
.40061 .73381 L
s
.40068 .72987 m
.40553 .72816 L
s
.41246 .74108 m .42006 .7285 L .40813 .7296 L 0 1 .473 r
F
.41246 .74108 m .43006 .73128 L .42006 .7285 L F
.41246 .74108 m .43144 .7361 L .43006 .73128 L F
.41246 .74108 m .42389 .74029 L .43144 .7361 L F
0 g
.4053 .74517 m
.41246 .74108 L
s
.40249 .7383 m
.41246 .74108 L
s
.61375 .88286 m .62166 .88844 L .62939 .88751 L 0 1 .385 r
F
0 g
.62939 .88751 m
.6331 .89557 L
s
.52647 .85811 m .54253 .84723 L .53623 .83994 L 0 1 .368 r
F
0 g
.53623 .83994 m
.54347 .8352 L
s
.61905 .86665 m .63596 .86956 L .63912 .86155 L 0 1 .403 r
F
.61905 .86665 m .62735 .87175 L .63596 .86956 L F
0 g
.63596 .86956 m
.63937 .87838 L
s
.62735 .87175 m
.63596 .86956 L
s
.4884 .79544 m
.49627 .80214 L
s
.51368 .81862 m
.52072 .82487 L
s
.66224 .87186 m .67088 .85863 L .67948 .8414 L 0 1 .202 r
F
0 g
.67833 .84371 m
.67948 .8414 L
s
.67371 .86586 m
.67561 .86231 L
s
.67288 .87111 m
.67561 .86231 L
s
.67647 .85361 m
.67669 .853 L
s
.67948 .8414 m
.68083 .83914 L
s
.67669 .853 m
.67983 .84431 L
s
.68498 1.23787 m .69295 1.21275 L .68888 1.23098 L 0 0 .09 r
F
.68617 1.25092 m .68888 1.23098 L .69295 1.21275 L 0 0 .013 r
F
0 g
.69295 1.21275 m
.6934 1.21066 L
s
.69295 1.21275 m
.69521 1.19586 L
s
.66056 1.28751 m .67139 1.2485 L .66954 1.27355 L 0 .306 .164 r
F
0 g
.66631 1.28823 m
.66692 1.27762 L
s
.65873 1.26529 m
.66063 1.24037 L
s
.55615 .77992 m .56915 .76223 L .55822 .76307 L 0 1 .409 r
F
0 g
.56915 .76223 m
.57646 .76679 L
s
.56915 .76223 m
.57823 .75676 L
s
.52647 .85811 m .54191 .85554 L .54253 .84723 L 0 1 .368 r
F
.52647 .85811 m .53502 .8602 L .54191 .85554 L F
.52574 .87899 m .53502 .8602 L .52647 .85811 L 0 .953 .357 r
F
0 g
.5235 .85466 m
.52647 .85811 L
s
.51995 .86262 m
.52647 .85811 L
s
.52795 .82012 m .53744 .82099 L .54518 .81459 L 0 1 .391 r
F
0 g
.53744 .82099 m
.54518 .81459 L
s
.54518 .81459 m
.54532 .81475 L
s
.6868 .80931 m
.69441 .80912 L
s
.68637 .80933 m
.6868 .80931 L
s
.68595 .80934 m
.68637 .80933 L
s
.50685 .93502 m .51881 .92834 L .51356 .91761 L 0 .688 .337 r
F
.50685 .93502 m .51866 .93794 L .51881 .92834 L F
.50685 .93502 m .51353 .9408 L .51866 .93794 L F
0 g
.50161 .9243 m
.50685 .93502 L
s
.50732 .95896 m .51353 .94081 L .50685 .93502 L 0 .599 .325 r
F
0 g
.5021 .93759 m
.50685 .93502 L
s
.54775 .86296 m .54253 .84723 L .54191 .85554 L 0 1 .357 r
F
0 g
.53623 .83994 m
.54253 .84723 L
s
.54253 .84723 m
.54965 .84164 L
s
.56459 1.22265 m
.5647 1.22386 L
s
.56299 1.20491 m
.56459 1.22265 L
s
.56279 1.20279 m
.56299 1.20491 L
s
.56265 1.20116 m
.56279 1.20279 L
s
.5626 .91954 m .57334 .89316 L .5656 .89158 L 0 1 .322 r
F
.5626 .91954 m .57801 .90344 L .57334 .89316 L F
0 g
.57334 .89316 m
.57734 .88913 L
s
.61905 .86665 m .63912 .86155 L .63487 .85202 L 0 1 .403 r
F
0 g
.63912 .86155 m
.64765 .85831 L
s
.5656 .89158 m .56167 .87313 L .5606 .88299 L 0 1 .334 r
F
.54586 .88598 m .5606 .88299 L .56167 .87313 L 0 1 .345 r
F
0 g
.55617 .86455 m
.56167 .87313 L
s
.56167 .87313 m
.56861 .86616 L
s
.58476 .90018 m .59938 .90906 L .60136 .90153 L 0 .924 .358 r
F
.58476 .90018 m .59226 .90848 L .59938 .90906 L F
0 g
.58096 .89957 m
.58476 .90018 L
s
.58098 .89083 m
.58476 .90018 L
s
.52072 .82487 m
.52795 .82013 L
s
.49627 .80214 m
.50357 .79637 L
s
.52795 .82012 m .52118 .80401 L .52098 .81285 L 0 1 .391 r
F
0 g
.51368 .81862 m
.52098 .81285 L
s
.52795 .82012 m .52893 .79761 L .52118 .80401 L 0 1 .391 r
F
0 g
.52098 .81285 m
.52362 .8156 L
s
.52362 .8156 m
.52795 .82012 L
s
.56015 1.04167 m
.56147 1.05074 L
s
.54586 .88598 m .54775 .86296 L .54097 .86846 L 0 1 .345 r
F
0 g
.54191 .85554 m
.54775 .86296 L
s
.50974 1.06643 m .50641 1.04765 L .50677 1.05342 L 0 .045 .165 r
F
0 g
.50488 1.05114 m
.50677 1.05342 L
s
.60848 .90062 m .6258 .89834 L .62166 .88844 L 0 1 .367 r
F
.60848 .90062 m .62342 .90596 L .6258 .89834 L F
0 g
.6258 .89834 m
.6331 .89557 L
s
.54172 .80071 m
.546 .80519 L
s
.52574 .87899 m .54097 .86846 L .53502 .8602 L 0 .953 .357 r
F
0 g
.53502 .8602 m
.54191 .85554 L
s
.36273 .89372 m .35143 .8792 L .35457 .88498 L 0 .272 .307 r
F
0 g
.35178 .88064 m
.35457 .88498 L
s
.55615 .77992 m .5495 .7687 L .54882 .77537 L 0 1 .409 r
F
.55615 .77992 m .55822 .76307 L .5495 .7687 L F
0 g
.54781 .7857 m
.55615 .77992 L
s
.4296 .73712 m
.43359 .7382 L
s
.28438 .81326 m .27565 .80512 L .27096 .80827 L 0 .869 .478 r
F
.52501 .90126 m .51957 .88327 L .51942 .89188 L 0 .885 .346 r
F
0 g
.51358 .89552 m
.51942 .89188 L
s
.52501 .90126 m .52574 .87899 L .51957 .88327 L 0 .885 .346 r
F
0 g
.51361 .87461 m
.51957 .88327 L
s
.29309 .82139 m .2939 .81279 L .28438 .81326 L 0 .775 .46 r
F
.29309 .82139 m .3035 .81528 L .2939 .81279 L F
.29309 .82139 m .30673 .81906 L .3035 .81528 L F
.29309 .82139 m .30225 .82168 L .30673 .81906 L F
0 g
.28356 .8189 m
.29309 .82139 L
s
.28894 .82339 m
.29309 .82139 L
s
.58897 .88325 m .58575 .8672 L .58419 .87328 L 0 1 .374 r
F
0 g
.57684 .87235 m
.58419 .87328 L
s
.60848 .90062 m .62166 .88844 L .61375 .88286 L 0 1 .367 r
F
0 g
.62166 .88844 m
.6258 .89834 L
s
.62166 .88844 m
.62939 .88751 L
s
.61375 .88286 m .62735 .87175 L .61904 .86666 L 0 1 .385 r
F
0 g
.62735 .87175 m
.63178 .88068 L
s
.47483 .75852 m .465 .7502 L .46588 .7539 L 0 1 .494 r
F
0 g
.46301 .75452 m
.46588 .7539 L
s
.58897 .88325 m .59319 .86744 L .58575 .8672 L 0 1 .374 r
F
0 g
.58185 .88268 m
.58897 .88325 L
s
.58419 .87328 m
.58897 .88325 L
s
.36273 .89372 m .35517 .8789 L .35143 .8792 L 0 .272 .307 r
F
0 g
.34363 .86858 m
.35143 .8792 L
s
.6805 1.18311 m .68564 1.12065 L .68181 1.14419 L 0 1 .228 r
F
0 g
.68564 1.12065 m
.69009 1.1223 L
s
.68564 1.12065 m
.68603 1.07305 L
s
.47483 .75852 m .47302 .74907 L .465 .7502 L 0 1 .494 r
F
.47483 .75852 m .48335 .7522 L .47302 .74907 L F
.48335 .7522 m .48374 .7519 L .48241 .75155 L F
.48335 .7522 m .48241 .75155 L .47302 .74907 L F
.47214 .74448 m .48334 .73696 L .47121 .73756 L 0 1 .448 r
F
.47979 .74936 m .48461 .75063 L .49305 .74622 L F
.47302 .74907 m .47979 .74936 L .47819 .74826 L 0 1 .498 r
F
.48295 .7517 m .48134 .75064 L .47302 .74907 L 0 1 .494 r
F
.47819 .74826 m .49305 .74622 L .4927 .74067 L 0 1 .448 r
F
.48 .74951 m .48461 .75063 L .47979 .74936 L F
.48174 .75072 m .48461 .75063 L .47959 .74941 L F
.48374 .7519 m .48461 .75063 L .48174 .75072 L 0 1 .44 r
F
.48374 .7519 m .49358 .75473 L .48461 .75063 L F
.47483 .75852 m .49071 .75629 L .48374 .7519 L 0 1 .494 r
F
.47483 .75852 m .49394 .75985 L .49381 .7584 L F
.49071 .75629 m .49381 .7584 L .49358 .75473 L 0 1 .44 r
F
.49071 .75629 m .49381 .7584 L .49358 .75588 L 0 1 .494 r
F
.47483 .75852 m .49381 .7584 L .49071 .75629 L F
.47483 .75852 m .4859 .76098 L .49394 .75985 L F
.47479 .76493 m .49394 .76052 L .49381 .7584 L 0 1 .44 r
F
.47479 .76493 m .49381 .7584 L .49071 .75629 L F
.47479 .76493 m .49071 .75629 L .48374 .7519 L F
.49071 .75629 m .49358 .75473 L .48374 .7519 L F
.48374 .7519 m .49358 .75588 L .48461 .75126 L 0 1 .494 r
F
.49071 .75629 m .49358 .75588 L .48374 .7519 L F
.47979 .74936 m .48461 .75126 L .49304 .74994 L 0 1 .498 r
F
.47302 .74907 m .48174 .75072 L .47979 .74936 L F
.48174 .75072 m .48461 .75126 L .47979 .74936 L F
.47301 .75097 m .47979 .74936 L .47819 .74826 L 0 1 .448 r
F
.47979 .74936 m .47999 .74931 L .47819 .74826 L F
.47999 .74931 m .49305 .74622 L .47819 .74826 L F
.47602 .74687 m .4927 .74067 L .48334 .73696 L F
.47594 .74693 m .47611 .74692 L .47602 .74687 L 0 1 .498 r
F
.47616 .74696 m .4927 .74067 L .47602 .74687 L 0 1 .448 r
F
.47819 .74826 m .4927 .74067 L .47616 .74696 L F
.47819 .74826 m .49268 .74599 L .47611 .74692 L 0 1 .498 r
F
.47602 .74687 m .48334 .73696 L .4723 .74437 L 0 1 .448 r
F
.47602 .74687 m .4723 .74437 L .47214 .74448 L F
.47302 .74907 m .46279 .74093 L .46368 .74464 L 0 1 .498 r
F
.47302 .74907 m .47214 .74452 L .46279 .74093 L F
.47301 .75097 m .47214 .74452 L .46278 .74197 L 0 1 .448 r
F
.47214 .74452 m .47121 .73756 L .46563 .74048 L F
.47214 .74452 m .46563 .74048 L .46279 .74093 L 0 1 .498 r
F
.47214 .74452 m .46563 .74048 L .46278 .74197 L 0 1 .448 r
F
.47214 .74452 m .4712 .73961 L .46563 .74048 L 0 1 .498 r
F
.47214 .74452 m .48331 .74156 L .4712 .73961 L F
.47302 .74907 m .47602 .74687 L .47214 .74452 L F
.47254 .74476 m .47602 .74687 L .47214 .74448 L 0 1 .448 r
F
.47602 .74687 m .48331 .74156 L .47214 .74452 L 0 1 .498 r
F
.47589 .74706 m .47602 .74687 L .47254 .74476 L 0 1 .448 r
F
.47819 .74826 m .47611 .74692 L .4761 .74692 L 0 1 .498 r
F
.47733 .74775 m .4761 .74692 L .47594 .74693 L F
.47819 .74826 m .4761 .74692 L .47733 .74775 L F
.47302 .74907 m .47819 .74826 L .47594 .74693 L F
.47792 .7484 m .47819 .74826 L .47589 .74706 L 0 1 .448 r
F
.47819 .74826 m .47616 .74696 L .47589 .74706 L F
.47589 .74706 m .47616 .74696 L .47602 .74687 L F
.47602 .74687 m .49268 .74599 L .48331 .74156 L 0 1 .498 r
F
.47611 .74692 m .49268 .74599 L .47602 .74687 L F
.47819 .74826 m .49304 .74994 L .49268 .74599 L F
.47979 .74936 m .49304 .74994 L .47819 .74826 L F
.47959 .74941 m .48 .74951 L .47979 .74936 L 0 1 .448 r
F
.47301 .75097 m .48174 .75072 L .47959 .74941 L F
.48341 .75173 m .48174 .75072 L .48134 .75064 L 0 1 .494 r
F
.48374 .7519 m .48174 .75072 L .48341 .75173 L F
.48374 .7519 m .48134 .75064 L .48295 .7517 L F
.47301 .75097 m .47792 .7484 L .47589 .74706 L 0 1 .448 r
F
.47301 .75097 m .47589 .74706 L .47214 .74448 L F
.47479 .76493 m .48374 .7519 L .47301 .75097 L 0 1 .44 r
F
.48374 .7519 m .48174 .75072 L .47301 .75097 L F
.48374 .7519 m .48461 .75126 L .48174 .75072 L 0 1 .494 r
F
0 g
.46588 .7539 m
.47391 .75804 L
s
.46721 .75943 m
.47399 .75862 L
s
.5804 .8577 m
.58575 .8672 L
s
.52574 .87899 m .54035 .87739 L .54097 .86846 L 0 .953 .357 r
F
.52574 .87899 m .53382 .8819 L .54035 .87739 L F
.52501 .90126 m .53382 .8819 L .52574 .87899 L 0 .885 .346 r
F
0 g
.5198 .87073 m
.52574 .87899 L
s
.51957 .88327 m
.52574 .87899 L
s
.62603 .84731 m .64344 .85111 L .64603 .8452 L 0 1 .421 r
F
.62603 .84731 m .63487 .85201 L .64344 .85111 L F
0 g
.64344 .85111 m
.64765 .85831 L
s
.63487 .85201 m
.64344 .85111 L
s
.56095 .82902 m
.56715 .83718 L
s
.52892 .79607 m .52163 .78501 L .52146 .78934 L 0 1 .454 r
F
0 g
.51372 .78963 m
.52146 .78934 L
s
.52892 .79607 m .52913 .79324 L .52163 .78501 L 0 1 .454 r
F
.52893 .79761 m .52913 .79324 L .52163 .78559 L 0 1 .404 r
F
.52913 .79324 m .52972 .78049 L .52256 .78501 L F
.52913 .79324 m .52256 .78501 L .52163 .78501 L 0 1 .454 r
F
.52913 .79324 m .52256 .78501 L .52163 .78559 L 0 1 .404 r
F
.52913 .79324 m .52973 .78496 L .52256 .78501 L 0 1 .454 r
F
0 g
.52146 .78934 m
.52687 .79422 L
s
.60848 .90062 m .616 .90694 L .62342 .90596 L 0 1 .367 r
F
0 g
.616 .90694 m
.62342 .90596 L
s
.62342 .90596 m
.62687 .91494 L
s
.69457 1.17587 m .69554 1.18726 L .69932 1.18229 L 0 1 .179 r
F
0 g
.69858 1.18326 m
.69892 1.18281 L
s
.69892 1.18281 m
.69932 1.18229 L
s
.60687 .96102 m
.60801 .96545 L
s
.71465 .79397 m .71275 .78362 L .70969 .78769 L 0 1 .495 r
F
.71465 .79397 m .7226 .78401 L .71275 .78362 L F
0 g
.70969 .78769 m
.71465 .79397 L
s
.70509 .79392 m
.71465 .79397 L
s
.60207 .98487 m
.60416 .97804 L
s
.6079 .96581 m
.60801 .96545 L
s
.59869 .70102 m .62356 .68924 L .61509 .68653 L 0 1 .46 r
F
0 g
.61591 .70106 m
.61931 .70226 L
s
.62356 .68924 m
.63415 .6839 L
s
.56715 .83718 m
.57484 .8378 L
s
.30257 .92715 m .29945 .92553 L .29275 .9215 L 0 .115 .159 r
F
.30257 .92715 m .311 .93347 L .30729 .93067 L F
.30257 .92715 m .30729 .93067 L .29945 .92553 L F
.30257 .92715 m .30897 .93195 L .311 .93347 L F
0 g
.30082 .92468 m
.30257 .92715 L
s
.29479 .92205 m
.30257 .92715 L
s
.5603 .74721 m .58119 .74089 L .58238 .73481 L 0 1 .431 r
F
.5603 .74721 m .57174 .7462 L .58119 .74089 L F
0 g
.58119 .74089 m
.58862 .74418 L
s
.54548 .79384 m
.54713 .7928 L
s
.47657 .77951 m .46713 .76926 L .468 .77499 L 0 1 .431 r
F
0 g
.46089 .77909 m
.468 .77499 L
s
.47657 .77951 m .47479 .76493 L .46713 .76926 L 0 1 .431 r
F
.47657 .77951 m .48588 .76489 L .47479 .76493 L F
.47657 .77951 m .49446 .76941 L .48588 .76489 L F
.47657 .77951 m .49481 .77547 L .49446 .76941 L F
.47657 .77951 m .48714 .7798 L .49481 .77547 L F
0 g
.46929 .78379 m
.47657 .77951 L
s
.468 .77499 m
.47657 .77951 L
s
.58064 .9257 m .57801 .90344 L .57651 .91559 L 0 1 .309 r
F
.5626 .91954 m .57651 .91559 L .57801 .90344 L 0 1 .322 r
F
0 g
.57334 .89316 m
.57801 .90344 L
s
.57801 .90344 m
.58047 .90005 L
s
.62286 1.01202 m .63542 .97734 L .62976 .97576 L 0 1 .288 r
F
0 g
.62289 1.01186 m
.62341 1.00691 L
s
.62286 1.01202 m .63744 .9902 L .63542 .97734 L 0 1 .288 r
F
0 g
.63542 .97734 m
.64043 .97142 L
s
.63542 .97734 m
.63732 .98943 L
s
.50309 .77547 m .49447 .76582 L .49483 .7698 L 0 1 .476 r
F
.50309 .77547 m .50264 .76629 L .49447 .76582 L F
.50308 .78017 m .50264 .76629 L .49446 .76941 L 0 1 .422 r
F
.50264 .76629 m .50259 .76478 L .50158 .76535 L F
.50264 .76629 m .50158 .76535 L .49447 .76582 L 0 1 .476 r
F
.50264 .76629 m .50158 .76535 L .49446 .76941 L 0 1 .422 r
F
.50264 .76629 m .50259 .76529 L .50158 .76535 L 0 1 .476 r
F
0 g
.49537 .77577 m
.49943 .77561 L
s
.49449 .76984 m
.49478 .7698 L
s
.50264 .76629 m .51378 .76467 L .50259 .76478 L 0 1 .422 r
F
.50309 .77547 m .50892 .77171 L .50264 .76629 L 0 1 .476 r
F
.52972 .78049 m .52204 .76937 L .52188 .77575 L 0 1 .415 r
F
.50892 .77171 m .52204 .76937 L .51378 .76467 L 0 1 .422 r
F
.51238 .77488 m .52204 .76937 L .50892 .77171 L F
.51238 .77488 m .52188 .77575 L .52204 .76937 L F
.50309 .77547 m .51487 .7774 L .51238 .77488 L 0 1 .476 r
F
.50309 .77547 m .51375 .77906 L .51636 .77889 L F
.51487 .7774 m .51636 .77889 L .52188 .77575 L 0 1 .422 r
F
.51487 .7774 m .51636 .77889 L .52188 .77855 L 0 1 .476 r
F
.50309 .77547 m .51636 .77889 L .51487 .7774 L F
.50308 .78017 m .51375 .78038 L .51636 .77889 L 0 1 .422 r
F
.50308 .78017 m .51636 .77889 L .51487 .7774 L F
.50308 .78017 m .51487 .7774 L .51238 .77488 L F
.51487 .7774 m .52188 .77575 L .51238 .77488 L F
.51238 .77488 m .52188 .77855 L .52205 .77426 L 0 1 .476 r
F
.51487 .7774 m .52188 .77855 L .51238 .77488 L F
.50892 .77171 m .52205 .77426 L .51378 .76857 L F
.50309 .77547 m .51238 .77488 L .50892 .77171 L F
.51238 .77488 m .52205 .77426 L .50892 .77171 L F
.50308 .78017 m .51238 .77488 L .50892 .77171 L 0 1 .422 r
F
.50308 .78017 m .50892 .77171 L .50264 .76629 L F
.50892 .77171 m .51378 .76467 L .50264 .76629 L F
.50264 .76629 m .51378 .76857 L .50259 .76529 L 0 1 .476 r
F
.50892 .77171 m .51378 .76857 L .50264 .76629 L F
0 g
.69209 .79813 m
.69746 .80467 L
s
.66125 .82996 m .65905 .81811 L .65644 .82324 L 0 1 .453 r
F
.66125 .82996 m .66809 .81724 L .65905 .81811 L F
.54586 .88598 m .54097 .86846 L .54035 .87739 L 0 1 .345 r
F
0 g
.53502 .8602 m
.54097 .86846 L
s
.54097 .86846 m
.54775 .86296 L
s
.50357 .79637 m .49534 .78479 L .49569 .79116 L 0 1 .413 r
F
.50357 .79637 m .50308 .78017 L .49534 .78479 L F
0 g
.4884 .79543 m
.49569 .79116 L
s
.50357 .79637 m .51375 .78038 L .50308 .78017 L 0 1 .413 r
F
.50357 .79637 m .52163 .78559 L .51375 .78038 L F
.50357 .79637 m .52146 .79233 L .52163 .78559 L F
.50357 .79637 m .51372 .79695 L .52146 .79233 L F
0 g
.49569 .79116 m
.50357 .79637 L
s
.28295 .91483 m .27071 .90773 L .27472 .91041 L 0 .31 .222 r
F
0 g
.27325 .91161 m
.27472 .91041 L
s
.5626 .91954 m .5656 .89158 L .55899 .89846 L 0 1 .322 r
F
0 g
.56279 .88675 m
.5656 .89158 L
s
.54586 .88598 m .55382 .8885 L .5606 .88299 L 0 1 .345 r
F
0 g
.5606 .88299 m
.56279 .88675 L
s
.51567 1.08947 m
.51733 1.09731 L
s
.62603 .84731 m .64603 .8452 L .64102 .83738 L 0 1 .421 r
F
0 g
.64603 .8452 m
.65443 .84358 L
s
.50827 1.00844 m .50379 .98429 L .50413 .99391 L 0 .38 .296 r
F
0 g
.50056 .99507 m
.50264 1.00159 L
s
.50827 1.00844 m .50778 .98335 L .50379 .98429 L 0 .38 .296 r
F
0 g
.50056 .99507 m
.50413 .99391 L
s
.50173 .97855 m
.50379 .98429 L
s
.69553 .76545 m .71334 .74112 L .70232 .74943 L 0 1 .274 r
F
0 g
.71334 .74112 m
.71929 .73935 L
s
.35517 .8789 m .34354 .86634 L .3467 .87121 L 0 .303 .327 r
F
0 g
.34363 .86858 m
.3467 .87121 L
s
.61375 .88286 m .61131 .86758 L .60931 .87392 L 0 1 .385 r
F
.61375 .88286 m .61904 .86666 L .61131 .86758 L F
.60848 .90062 m .61375 .88286 L .60633 .88383 L 0 1 .367 r
F
0 g
.60931 .87392 m
.61375 .88286 L
s
.61453 .96299 m .62729 .94229 L .62067 .93714 L 0 1 .322 r
F
0 g
.62729 .94229 m
.63005 .95389 L
s
.62729 .94229 m
.6343 .93907 L
s
.45834 .76501 m
.46713 .76926 L
s
.52118 .80401 m
.52893 .79761 L
s
.51372 .79695 m
.52118 .80401 L
s
.36825 .71246 m .35491 .70736 L .35728 .71112 L 0 1 .499 r
F
0 g
.35663 .71155 m
.35728 .71112 L
s
.50974 1.06643 m .50925 1.05207 L .50641 1.04765 L 0 .045 .165 r
F
0 g
.50308 1.03614 m
.50641 1.04765 L
s
.52893 .79761 m .52163 .78559 L .52146 .79233 L 0 1 .404 r
F
0 g
.52296 .79339 m
.52893 .79761 L
s
.52146 .79233 m
.52296 .79339 L
s
.51333 1.08315 m
.51389 1.08465 L
s
.7226 .78401 m .74098 .77925 L .73058 .7744 L 0 1 .5 r
F
0 g
.74098 .77925 m
.74617 .78562 L
s
.52501 .90126 m .53942 .89128 L .53382 .8819 L 0 .885 .346 r
F
0 g
.53382 .8819 m
.54035 .87739 L
s
.59531 .71463 m .61121 .69941 L .59869 .70102 L 0 1 .45 r
F
0 g
.61121 .69941 m
.61591 .70106 L
s
.61121 .69941 m
.62186 .69436 L
s
.39783 .72491 m
.40092 .72561 L
s
.39698 .72533 m
.39783 .72491 L
s
.51372 .79695 m
.52146 .79233 L
s
.61905 .86665 m .63487 .85202 L .62603 .84731 L 0 1 .403 r
F
0 g
.63487 .85202 m
.63912 .86155 L
s
.59319 .86744 m .58966 .85259 L .5881 .85833 L 0 1 .39 r
F
0 g
.5804 .8577 m
.5881 .85833 L
s
.59319 .86744 m .60622 .85847 L .59743 .85265 L 0 1 .39 r
F
0 g
.58575 .8672 m
.59319 .86744 L
s
.5881 .85833 m
.59319 .86744 L
s
.52428 .92494 m .51919 .90518 L .51904 .9143 L 0 .812 .335 r
F
0 g
.51356 .91761 m
.51904 .9143 L
s
.52428 .92494 m .52501 .90126 L .51919 .90518 L 0 .812 .335 r
F
0 g
.51358 .89552 m
.51919 .90518 L
s
.60848 .90062 m .60633 .88383 L .60434 .89072 L 0 1 .367 r
F
0 g
.60779 .89896 m
.60848 .90062 L
s
.60434 .89072 m
.60779 .89896 L
s
.60633 .88383 m
.61375 .88286 L
s
.5969 .89047 m
.60434 .89072 L
s
.60776 .90071 m
.60776 .90071 L
s
.60776 .90071 m
.60848 .90062 L
s
.5722 .95754 m .57846 .97164 L .58464 .97495 L 0 .647 .309 r
F
0 g
.5722 .95754 m
.5722 .95754 L
s
.56783 .97823 m .57846 .97164 L .5722 .95754 L 0 .528 .292 r
F
0 g
.5722 .95754 m
.5722 .95754 L
s
.61131 .86758 m
.61904 .86666 L
s
.61905 .86665 m .61742 .84949 L .61478 .85712 L 0 1 .403 r
F
.61905 .86665 m .62603 .84731 L .61742 .84949 L F
.5603 .74721 m .58238 .73481 L .57433 .73109 L 0 1 .431 r
F
0 g
.58238 .73481 m
.59196 .72897 L
s
.50732 .95896 m .51843 .95299 L .51353 .94081 L 0 .599 .325 r
F
.50732 .95896 m .51827 .96344 L .51843 .95299 L F
.50732 .95896 m .5135 .966 L .51827 .96344 L F
.50778 .98334 m .5135 .966 L .50732 .95896 L 0 .499 .312 r
F
0 g
.50244 .94679 m
.50732 .95896 L
s
.50294 .96071 m
.50732 .95896 L
s
.60155 .87386 m
.60825 .87391 L
s
.60825 .87391 m
.60931 .87392 L
s
.60155 .87386 m
.60633 .88383 L
s
.62067 .93714 m .61985 .91815 L .61749 .92679 L 0 1 .344 r
F
0 g
.616 .90694 m
.61985 .91815 L
s
.61985 .91815 m
.62687 .91494 L
s
.55822 .76307 m .57174 .7462 L .5603 .74721 L 0 1 .42 r
F
0 g
.57174 .7462 m
.57941 .7503 L
s
.57174 .7462 m
.58119 .74089 L
s
.54602 .80865 m
.55415 .80807 L
s
.53905 .80072 m
.54602 .80865 L
s
.58796 .9281 m
.58875 .93072 L
s
.58875 .93072 m
.59147 .93975 L
s
.55822 .76307 m .5512 .75269 L .55052 .75898 L 0 1 .42 r
F
.55822 .76307 m .5603 .74721 L .5512 .75269 L F
.35517 .8789 m .34756 .86603 L .34354 .86634 L 0 .303 .327 r
F
0 g
.3354 .85849 m
.34354 .86634 L
s
.36822 .71357 m .35486 .70916 L .35725 .71238 L 0 1 .525 r
F
0 g
.3504 .71679 m
.35725 .71238 L
s
.36084 .71684 m
.36665 .7134 L
s
.54397 .91086 m .55382 .8885 L .54586 .88598 L 0 .947 .334 r
F
.54397 .91086 m .55899 .89846 L .55382 .8885 L F
0 g
.55382 .8885 m
.5606 .88299 L
s
.6357 1.01149 m .63744 .9902 L .63447 1.00582 L 0 1 .165 r
F
.62286 1.01202 m .63447 1.00582 L .63744 .9902 L 0 1 .288 r
F
0 g
.63732 .98943 m
.63744 .9902 L
s
.63744 .9902 m
.63947 .98459 L
s
.54397 .91086 m .54586 .88598 L .53942 .89128 L 0 .947 .334 r
F
0 g
.54035 .87739 m
.54586 .88598 L
s
.60324 .92027 m .60136 .90153 L .59938 .90906 L 0 1 .349 r
F
0 g
.60136 .90153 m
.60776 .90071 L
s
.59226 .90848 m
.59938 .90906 L
s
.5969 .89047 m
.60136 .90153 L
s
.52501 .90126 m .5388 .90088 L .53942 .89128 L 0 .885 .346 r
F
.52501 .90126 m .53262 .90516 L .5388 .90088 L F
.52428 .92494 m .53262 .90516 L .52501 .90126 L 0 .812 .335 r
F
0 g
.51942 .89188 m
.52501 .90126 L
s
.51919 .90518 m
.52501 .90126 L
s
.57484 .8378 m .57055 .82197 L .56909 .82845 L 0 1 .415 r
F
0 g
.56095 .82901 m
.56909 .82845 L
s
.57484 .8378 m .57896 .82115 L .57055 .82197 L 0 1 .415 r
F
.57484 .8378 m .5887 .82654 L .57896 .82115 L F
.57484 .8378 m .59446 .8359 L .5887 .82654 L F
.57484 .8378 m .59239 .84298 L .59446 .8359 L F
.57484 .8378 m .58398 .84379 L .59239 .84298 L F
0 g
.56909 .82845 m
.57484 .8378 L
s
.48714 .7798 m
.49534 .78479 L
s
.28295 .91483 m .27315 .90753 L .27071 .90773 L 0 .31 .222 r
F
0 g
.26305 .90518 m
.27071 .90773 L
s
.63175 .83285 m .64992 .83667 L .65252 .83119 L 0 1 .434 r
F
.63175 .83285 m .64102 .83738 L .64992 .83667 L F
0 g
.64992 .83667 m
.65443 .84358 L
s
.45583 .74648 m
.46294 .74937 L
s
.46294 .74937 m
.465 .7502 L
s
.6968 1.15289 m
.69685 1.15295 L
s
.69676 1.15285 m
.6968 1.15289 L
s
.62976 .97576 m .63023 .95467 L .62753 .96604 L 0 1 .313 r
F
.61453 .96299 m .62753 .96604 L .63023 .95467 L 0 1 .322 r
F
0 g
.63023 .95467 m
.63675 .94702 L
s
.63005 .95389 m
.63023 .95467 L
s
.44444 .75189 m .43352 .74345 L .4349 .74844 L 0 1 .457 r
F
0 g
.42772 .75252 m
.4349 .74844 L
s
.52972 .78049 m .54882 .77537 L .5495 .7687 L 0 1 .415 r
F
.52972 .78049 m .54035 .78042 L .54882 .77537 L F
0 g
.54882 .77537 m
.55615 .77992 L
s
.54035 .78042 m
.54781 .7857 L
s
.54035 .78042 m
.54882 .77537 L
s
.39214 .71703 m
.39306 .71658 L
s
.39123 .71747 m
.39214 .71703 L
s
.3864 .7203 m
.39592 .72159 L
s
.59531 .71463 m .58837 .70633 L .58717 .71179 L 0 1 .45 r
F
.59531 .71463 m .59869 .70102 L .58837 .70633 L F
0 g
.58765 .92805 m
.589 .92827 L
s
.58955 .93499 m
.5915 .94214 L
s
.58912 .93344 m
.58955 .93499 L
s
.58765 .92805 m
.58912 .93344 L
s
.40424 .71968 m .4162 .71708 L .40378 .7185 L 0 1 .479 r
F
.40817 .72724 m .41336 .72149 L .40424 .71968 L 0 1 .52 r
F
.41336 .72149 m .42658 .71952 L .4162 .71708 L 0 1 .479 r
F
.42043 .72288 m .42658 .71952 L .41336 .72149 L F
.42062 .72277 m .42797 .72418 L .42658 .71952 L F
.43828 .72695 m .42658 .71952 L .42797 .72418 L 0 1 .47 r
F
.4291 .72457 m .42656 .7207 L .42797 .72422 L 0 1 .512 r
F
.4414 .73636 m .43008 .72948 L .43149 .73298 L 0 1 .51 r
F
.4414 .73636 m .43874 .72879 L .43008 .72948 L F
.44137 .7392 m .43874 .72879 L .43006 .73128 L 0 1 .464 r
F
.43874 .72879 m .43828 .72695 L .43649 .72789 L F
.43874 .72879 m .43649 .72789 L .43008 .72948 L 0 1 .51 r
F
.43874 .72879 m .43649 .72789 L .43006 .73128 L 0 1 .464 r
F
.43874 .72879 m .43827 .72745 L .43649 .72789 L 0 1 .51 r
F
.43827 .72745 m .43571 .72597 L .4291 .72457 L 0 1 .512 r
F
.43571 .72597 m .42656 .7207 L .4291 .72457 L F
.42043 .72288 m .42401 .72349 L .42062 .72277 L 0 1 .479 r
F
.42401 .72349 m .42797 .72418 L .42062 .72277 L F
.40817 .72724 m .42763 .72427 L .42043 .72288 L 0 1 .52 r
F
.40817 .72724 m .42008 .72702 L .42776 .72429 L F
.42763 .72427 m .42776 .72429 L .42797 .72418 L 0 1 .479 r
F
.42763 .72427 m .42776 .72429 L .42797 .72422 L 0 1 .52 r
F
.40817 .72724 m .42776 .72429 L .42763 .72427 L F
.40813 .7296 m .42006 .7285 L .42776 .72429 L 0 1 .479 r
F
.40813 .7296 m .42776 .72429 L .42763 .72427 L F
.40813 .7296 m .42763 .72427 L .42043 .72288 L F
.42763 .72427 m .42797 .72418 L .42043 .72288 L F
.42043 .72288 m .42797 .72422 L .42656 .7207 L 0 1 .52 r
F
.42763 .72427 m .42797 .72422 L .42043 .72288 L F
.41336 .72149 m .42656 .7207 L .41618 .71836 L F
.40817 .72724 m .42043 .72288 L .41336 .72149 L F
.42043 .72288 m .42656 .7207 L .41336 .72149 L F
.40813 .7296 m .42043 .72288 L .41336 .72149 L 0 1 .479 r
F
.40813 .7296 m .41336 .72149 L .40424 .71968 L F
.41336 .72149 m .4162 .71708 L .40424 .71968 L F
.40424 .71968 m .41618 .71836 L .40377 .71878 L 0 1 .52 r
F
.41336 .72149 m .41618 .71836 L .40424 .71968 L F
.56344 .99652 m .57366 .99545 L .56783 .97823 L 0 .387 .273 r
F
.56344 .99652 m .5765 1.01569 L .57366 .99545 L F
.56344 .99652 m .57444 1.0254 L .5765 1.01569 L F
.56344 .99652 m .56883 1.01715 L .57444 1.0254 L F
0 g
.56343 .99647 m
.56344 .99652 L
s
.50876 1.03196 m .50466 1.00792 L .50501 1.01697 L 0 .282 .274 r
F
0 g
.50182 1.01701 m
.50351 1.02276 L
s
.50876 1.03196 m .50827 1.00844 L .50466 1.00792 L 0 .282 .274 r
F
0 g
.50182 1.01701 m
.50501 1.01697 L
s
.50264 1.00159 m
.50466 1.00792 L
s
.60622 .85847 m
.61131 .86758 L
s
.50925 1.05207 m .50553 1.02963 L .50589 1.03746 L 0 .195 .238 r
F
0 g
.50308 1.03614 m
.50589 1.03746 L
s
.69209 .79813 m
.70203 .79816 L
s
.61453 .96299 m .62067 .93714 L .61394 .94069 L 0 1 .322 r
F
0 g
.61749 .92679 m
.62067 .93714 L
s
.38561 .72077 m
.39064 .71781 L
s
.39064 .71781 m
.39123 .71747 L
s
.40813 .7296 m .3959 .72282 L .39778 .72717 L 0 1 .479 r
F
0 g
.39778 .72717 m
.40813 .7296 L
s
.38561 .72077 m
.3959 .72282 L
s
.40061 .73381 m
.40813 .7296 L
s
.39068 .73136 m
.39778 .72717 L
s
.65574 .90148 m .67517 .85722 L .67088 .85863 L 0 1 .197 r
F
.65574 .90148 m .6723 .8685 L .67517 .85722 L F
0 g
.67507 .85024 m
.67548 .84941 L
s
.67239 .86833 m
.67371 .86586 L
s
.67517 .85722 m
.67647 .85361 L
s
.67404 .85759 m
.67517 .85722 L
s
.465 .7502 m
.47115 .74933 L
s
.56783 .97823 m .58163 .99009 L .57846 .97164 L 0 .528 .292 r
F
.56783 .97823 m .57958 1.00055 L .58163 .99009 L F
.56783 .97823 m .57366 .99545 L .57958 1.00055 L F
0 g
.56468 .95985 m
.56783 .97823 L
s
.56225 .97009 m
.56783 .97823 L
s
.44444 .75189 m .44137 .7392 L .43352 .74345 L 0 1 .457 r
F
0 g
.42389 .74029 m
.43352 .74345 L
s
.44444 .75189 m .45322 .73852 L .44137 .7392 L 0 1 .457 r
F
.44444 .75189 m .46278 .74197 L .45322 .73852 L F
.44444 .75189 m .46365 .74726 L .46278 .74197 L F
0 g
.46324 .74475 m
.46368 .74464 L
s
.44444 .75189 m .45579 .7515 L .46365 .74726 L 0 1 .457 r
F
0 g
.43697 .75606 m
.44444 .75189 L
s
.4349 .74844 m
.44444 .75189 L
s
.59035 .85259 m
.59743 .85265 L
s
.58966 .85259 m
.59035 .85259 L
s
.58398 .84379 m
.58966 .85259 L
s
.68617 1.25092 m .69618 1.19681 L .6933 1.21304 L 0 0 .013 r
F
0 g
.69618 1.19681 m
.69932 1.18229 L
s
.6688 .8458 m .68483 .81109 L .67541 .8226 L 0 1 .211 r
F
0 g
.67548 .84941 m
.67833 .84371 L
s
.68483 .81109 m
.68579 .81068 L
s
.68483 .81109 m
.68595 .80934 L
s
.54397 .91086 m .53942 .89128 L .5388 .90088 L 0 .947 .334 r
F
0 g
.53942 .89128 m
.54586 .88598 L
s
.53382 .8819 m
.53942 .89128 L
s
.61036 .9277 m
.61533 .92706 L
s
.61533 .92706 m
.61657 .9269 L
s
.61657 .9269 m
.61749 .92679 L
s
.50925 1.05207 m .50876 1.03196 L .50553 1.02963 L 0 .195 .238 r
F
0 g
.50351 1.02276 m
.50553 1.02963 L
s
.60208 .68805 m .62612 .68172 L .62783 .67683 L 0 1 .468 r
F
.60208 .68805 m .61509 .68653 L .62612 .68172 L F
0 g
.62612 .68172 m
.63415 .6839 L
s
.66826 .89376 m .66803 .88678 L .66519 .8999 L 0 .795 .084 r
F
.59802 .94216 m .60324 .92027 L .59642 .9209 L 0 .953 .33 r
F
0 g
.59938 .90906 m
.60324 .92027 L
s
.51636 .77889 m
.51767 .77881 L
s
.51474 .77981 m
.52163 .78501 L
s
.52256 .78501 m
.52267 .785 L
s
.52163 .78501 m
.52256 .78501 L
s
.63175 .83285 m .65252 .83119 L .6472 .82376 L 0 1 .434 r
F
0 g
.65252 .83119 m
.66125 .82996 L
s
.48765 .76197 m
.49447 .76582 L
s
.36825 .71246 m .36266 .70279 L .35491 .70736 L 0 1 .499 r
F
0 g
.34416 .70654 m
.35491 .70736 L
s
.36825 .71246 m .3754 .70046 L .36266 .70279 L 0 1 .499 r
F
.36825 .71246 m .38641 .7018 L .3754 .70046 L F
.36825 .71246 m .38832 .70592 L .38641 .7018 L F
.36825 .71246 m .38052 .71048 L .38832 .70592 L F
0 g
.36286 .7118 m
.36825 .71246 L
s
.36703 .71318 m
.36825 .71246 L
s
.59802 .94216 m .59642 .9209 L .59445 .92917 L 0 .953 .33 r
F
0 g
.59226 .90848 m
.59642 .9209 L
s
.59642 .9209 m
.60324 .92027 L
s
.589 .92827 m
.59445 .92917 L
s
.55999 1.2329 m
.56118 1.24311 L
s
.55972 1.2306 m
.55999 1.2329 L
s
.56118 1.24311 m
.56166 1.24719 L
s
.56166 1.24719 m
.56241 1.2536 L
s
.56017 1.2339 m
.56225 1.251 L
s
.55975 1.23047 m
.56017 1.2339 L
s
.52972 .78049 m .5495 .7687 L .54166 .76396 L 0 1 .415 r
F
0 g
.5495 .7687 m
.55822 .76307 L
s
.59743 .85264 m .59446 .8359 L .59239 .84298 L 0 1 .406 r
F
0 g
.58398 .84379 m
.59239 .84298 L
s
.59743 .85264 m .60302 .83455 L .59446 .8359 L 0 1 .406 r
F
.59743 .85264 m .61238 .83982 L .60302 .83455 L F
.59743 .85264 m .61742 .84949 L .61238 .83982 L F
.59743 .85264 m .61478 .85712 L .61742 .84949 L F
0 g
.59239 .84298 m
.59743 .85264 L
s
.60622 .85846 m
.61478 .85712 L
s
.61478 .85712 m
.61905 .86665 L
s
.62603 .84731 m .64102 .83738 L .63175 .83285 L 0 1 .421 r
F
0 g
.64102 .83738 m
.64603 .8452 L
s
.64102 .83738 m
.64992 .83667 L
s
.52972 .78049 m .53052 .76432 L .52204 .76937 L 0 1 .415 r
F
.52972 .78049 m .54166 .76396 L .53052 .76432 L F
0 g
.52199 .77582 m
.52972 .78049 L
s
.52163 .78559 m
.52237 .78512 L
s
.52237 .78512 m
.52256 .78501 L
s
.52256 .78501 m
.52972 .78049 L
s
.66809 .81724 m .66561 .80578 L .66298 .81063 L 0 1 .463 r
F
.66809 .81724 m .67496 .80525 L .66561 .80578 L F
0 g
.49447 .76582 m
.50158 .76535 L
s
.51375 .78038 m
.52163 .78559 L
s
.5626 .91954 m .55899 .89846 L .55792 .90924 L 0 1 .322 r
F
.54397 .91086 m .55792 .90924 L .55899 .89846 L 0 .947 .334 r
F
0 g
.55382 .8885 m
.55899 .89846 L
s
.55899 .89846 m
.5656 .89158 L
s
.34756 .86603 m .33559 .85502 L .33877 .8594 L 0 .353 .36 r
F
0 g
.3354 .85849 m
.33877 .8594 L
s
.50308 .78017 m .49446 .76941 L .49481 .77547 L 0 1 .422 r
F
0 g
.49481 .77547 m
.50308 .78017 L
s
.49534 .78479 m
.50308 .78017 L
s
.48714 .7798 m
.49481 .77547 L
s
.5626 .91954 m .56991 .92249 L .57651 .91559 L 0 1 .322 r
F
0 g
.57651 .91559 m
.5785 .92046 L
s
.61742 .84949 m
.62603 .84731 L
s
.62603 .84731 m .62316 .83374 L .62101 .83948 L 0 1 .421 r
F
.62603 .84731 m .63175 .83285 L .62316 .83374 L F
0 g
.56216 1.23847 m
.56232 1.24004 L
s
.55902 1.20689 m
.55943 1.21101 L
s
.56073 1.22405 m
.56083 1.2251 L
s
.56083 1.2251 m
.56084 1.22517 L
s
.56084 1.22517 m
.56087 1.22547 L
s
.56087 1.22547 m
.56088 1.22558 L
s
.56088 1.22558 m
.56216 1.23847 L
s
.55943 1.21101 m
.56073 1.22405 L
s
.55902 1.20689 m
.56141 1.22521 L
s
.56141 1.22521 m
.56141 1.22525 L
s
.56141 1.22525 m
.56143 1.22543 L
s
.56143 1.22543 m
.56144 1.22551 L
s
.56144 1.22551 m
.56146 1.2256 L
s
.56239 .73221 m .58417 .72595 L .58537 .7202 L 0 1 .441 r
F
.56239 .73221 m .57433 .73109 L .58417 .72595 L F
0 g
.58417 .72595 m
.59196 .72897 L
s
.56101 1.24166 m
.56149 1.2448 L
s
.56267 1.25247 m
.56375 1.2595 L
s
.50974 1.06643 m .51339 1.06375 L .50925 1.05207 L 0 .045 .165 r
F
.50974 1.06643 m .51638 1.07683 L .51339 1.06375 L F
.50974 1.06643 m .51621 1.08253 L .51638 1.07683 L F
.50974 1.06643 m .51336 1.07806 L .51621 1.08253 L F
0 g
.5073 1.05983 m
.50974 1.06643 L
s
.50677 1.05342 m
.50974 1.06643 L
s
.67481 1.28789 m .67364 1.27217 L .67588 1.24888 L 0 .123 .117 r
F
0 g
.67139 1.24849 m
.67588 1.24888 L
s
.52355 .94998 m .51881 .92834 L .51866 .93794 L 0 .733 .324 r
F
0 g
.51353 .9408 m
.51866 .93794 L
s
.52355 .94998 m .52428 .92494 L .51881 .92834 L 0 .733 .324 r
F
0 g
.51356 .91761 m
.51881 .92834 L
s
.52428 .92494 m .53788 .9158 L .53262 .90516 L 0 .812 .335 r
F
0 g
.53262 .90516 m
.5388 .90088 L
s
.66358 1.1308 m .67626 1.18969 L .67634 1.12224 L 0 .907 .239 r
F
0 g
.67634 1.12224 m
.68181 1.14419 L
s
.51375 .78038 m
.51636 .77889 L
s
.36822 .71357 m .3626 .70541 L .35486 .70916 L 0 1 .525 r
F
0 g
.3441 .70883 m
.35486 .70916 L
s
.36822 .71357 m .37533 .70362 L .3626 .70541 L 0 1 .525 r
F
0 g
.35491 .70736 m
.36266 .70279 L
s
.36822 .71357 m .38635 .70481 L .37533 .70362 L 0 1 .525 r
F
.36822 .71357 m .38827 .70818 L .38635 .70481 L F
.36822 .71357 m .38049 .71194 L .38827 .70818 L F
0 g
.35725 .71238 m
.36822 .71357 L
s
.36083 .71719 m
.36822 .71357 L
s
.28438 .81326 m .28554 .80398 L .27565 .80512 L 0 .869 .478 r
F
0 g
.27096 .80827 m
.27565 .80512 L
s
.28438 .81326 m .29542 .80591 L .28554 .80398 L 0 .869 .478 r
F
.28438 .81326 m .29865 .80964 L .29542 .80591 L F
.28438 .81326 m .2939 .81279 L .29865 .80964 L F
0 g
.27457 .81132 m
.28438 .81326 L
s
.27996 .81588 m
.28438 .81326 L
s
.39592 .72159 m
.40232 .7193 L
s
.7226 .78401 m .72045 .7737 L .71737 .77763 L 0 1 .5 r
F
.7226 .78401 m .73058 .7744 L .72045 .7737 L F
0 g
.71275 .78362 m
.7226 .78401 L
s
.69942 .7874 m
.70509 .79392 L
s
.57661 .96119 m .58064 .9257 L .57427 .93486 L 0 1 .298 r
F
0 g
.5785 .92046 m
.58064 .9257 L
s
.27315 .90753 m .26068 .90073 L .26469 .90358 L 0 .375 .281 r
F
0 g
.26305 .90518 m
.26469 .90358 L
s
.47479 .76493 m .46496 .75534 L .46583 .76084 L 0 1 .44 r
F
.47479 .76493 m .47301 .75097 L .46496 .75534 L F
0 g
.45834 .76501 m
.46583 .76084 L
s
.47479 .76493 m .48588 .76489 L .49394 .76052 L 0 1 .44 r
F
0 g
.46583 .76084 m
.47479 .76493 L
s
.46713 .76926 m
.47479 .76493 L
s
.6805 1.18311 m .69097 1.18684 L .69224 1.14799 L 0 1 .228 r
F
0 g
.69224 1.14799 m
.69676 1.15285 L
s
.50778 .98334 m .51803 .9793 L .5135 .966 L 0 .499 .312 r
F
.50778 .98334 m .51787 .98999 L .51803 .9793 L F
.50778 .98334 m .51348 .99172 L .51787 .98999 L F
0 g
.50327 .97006 m
.50778 .98334 L
s
.50827 1.00844 m .51348 .99173 L .50778 .98335 L 0 .38 .296 r
F
0 g
.50379 .98429 m
.50778 .98335 L
s
.61238 .83982 m
.61742 .84949 L
s
.35486 .70916 m
.3626 .70541 L
s
.58535 1.29861 m
.58535 1.29861 L
s
.55415 .80807 m .54786 .79599 L .54717 .80068 L 0 1 .44 r
F
0 g
.53905 .80072 m
.54717 .80068 L
s
.55415 .80807 m .55626 .79605 L .54786 .79599 L 0 1 .44 r
F
.55415 .80807 m .56677 .80083 L .55626 .79605 L F
.55415 .80807 m .57375 .80823 L .56677 .80083 L F
.55415 .80807 m .57255 .8133 L .57375 .80823 L F
.55415 .80807 m .56415 .81323 L .57255 .8133 L F
0 g
.54717 .80068 m
.55415 .80807 L
s
.62828 1.06572 m .6326 1.05757 L .6382 1.03519 L 0 1 .179 r
F
0 g
.63722 1.03909 m
.6382 1.03519 L
s
.63666 1.04133 m
.63722 1.03909 L
s
.63749 .81932 m .65644 .82324 L .65905 .81811 L 0 1 .446 r
F
.63749 .81932 m .6472 .82376 L .65644 .82324 L F
0 g
.65644 .82324 m
.66125 .82996 L
s
.34756 .86603 m .3399 .85433 L .33559 .85502 L 0 .353 .36 r
F
0 g
.32715 .84899 m
.33559 .85502 L
s
.5603 .74721 m .55291 .73753 L .55223 .74349 L 0 1 .431 r
F
.5603 .74721 m .56239 .73221 L .55291 .73753 L F
.5603 .74721 m .57433 .73109 L .56239 .73221 L F
0 g
.57433 .73109 m
.58417 .72595 L
s
.57433 .73109 m
.58238 .73481 L
s
.62286 1.01202 m .62976 .97576 L .62351 .98508 L 0 1 .288 r
F
0 g
.62165 1.02371 m
.62288 1.01201 L
s
.29275 .9215 m .28994 .91804 L .28295 .91483 L 0 .223 .198 r
F
.29275 .9215 m .29801 .9229 L .28994 .91804 L F
.29275 .9215 m .30172 .92614 L .29801 .9229 L F
.29275 .9215 m .29945 .92553 L .30172 .92614 L F
0 g
.28475 .91667 m
.29275 .9215 L
s
.52428 .92494 m .53726 .9261 L .53788 .9158 L 0 .812 .335 r
F
.52428 .92494 m .53143 .93002 L .53726 .9261 L F
.52355 .94998 m .53143 .93002 L .52428 .92494 L 0 .733 .324 r
F
0 g
.51881 .92834 m
.52428 .92494 L
s
.51904 .9143 m
.52428 .92494 L
s
.60208 .68805 m .62783 .67683 L .619 .67421 L 0 1 .468 r
F
0 g
.62337 .68918 m
.62356 .68924 L
s
.62783 .67683 m
.63878 .67184 L
s
.3959 .72282 m
.40232 .7193 L
s
.40232 .7193 m
.4034 .7187 L
s
.53052 .76432 m .55052 .75898 L .5512 .75269 L 0 1 .425 r
F
.53052 .76432 m .54166 .76396 L .55052 .75898 L F
0 g
.55052 .75898 m
.55822 .76307 L
s
.54166 .76396 m
.5495 .7687 L
s
.54166 .76396 m
.55052 .75898 L
s
.6346 1.00638 m
.6348 1.00731 L
s
.6348 1.00731 m
.63563 1.01118 L
s
.62828 1.06572 m .6357 1.01149 L .63009 1.03378 L 0 1 .179 r
F
0 g
.63563 1.01118 m
.6357 1.01149 L
s
.63521 1.06132 m
.63699 1.04004 L
s
.63513 1.06223 m
.63521 1.06132 L
s
.63356 1.08108 m
.63507 1.06296 L
s
.63507 1.06296 m
.63511 1.06258 L
s
.63511 1.06258 m
.63513 1.06223 L
s
.63314 1.0709 m
.63509 1.04761 L
s
.6326 1.05757 m
.63666 1.04133 L
s
.43149 .73298 m
.43343 .73364 L
s
.43359 .7382 m
.43835 .73708 L
s
.43063 .73328 m
.43149 .73298 L
s
.56239 .73221 m .58537 .7202 L .57694 .71678 L 0 1 .441 r
F
0 g
.58537 .7202 m
.59531 .71463 L
s
.57055 .82197 m
.57896 .82115 L
s
.56415 .81323 m
.57055 .82197 L
s
.56415 .81323 m
.56415 .81323 L
s
.45579 .7515 m
.46496 .75534 L
s
.27315 .90753 m .26334 .89987 L .26068 .90073 L 0 .375 .281 r
F
0 g
.25284 .8984 m
.26068 .90073 L
s
.61453 .96299 m .61394 .94069 L .61159 .95059 L 0 1 .322 r
F
.59802 .94216 m .61159 .95059 L .61394 .94069 L 0 .953 .33 r
F
0 g
.61394 .94069 m
.62067 .93714 L
s
.61036 .9277 m
.61394 .94069 L
s
.61453 .96299 m .6208 .96962 L .62753 .96604 L 0 1 .322 r
F
0 g
.62753 .96604 m
.62976 .97576 L
s
.65227 1.13192 m .65615 1.22589 L .66155 1.24697 L 0 .933 .228 r
F
.65514 1.26673 m .65835 1.11475 L .65492 1.16344 L 0 .952 .227 r
F
0 g
.64766 1.06601 m
.65492 1.16344 L
s
.65514 1.26673 m .66358 1.13082 L .65835 1.11475 L 0 .952 .227 r
F
0 g
.65679 .98448 m
.65835 1.11475 L
s
.54397 .91086 m .55148 .91455 L .55792 .90924 L 0 .947 .334 r
F
0 g
.55792 .90924 m
.56165 .91746 L
s
.59869 .70102 m .61509 .68653 L .60208 .68805 L 0 1 .46 r
F
0 g
.61509 .68653 m
.62337 .68918 L
s
.61509 .68653 m
.62612 .68172 L
s
.5915 .94214 m
.5927 .94214 L
s
.43874 .72879 m .45065 .72599 L .43828 .72695 L 0 1 .464 r
F
.4414 .73636 m .44653 .73185 L .43874 .72879 L 0 1 .51 r
F
.44653 .73185 m .46059 .7291 L .45065 .72599 L 0 1 .464 r
F
.4515 .73387 m .46059 .7291 L .44653 .73185 L F
.4515 .73387 m .46147 .73419 L .46059 .7291 L F
.4414 .73636 m .45561 .73565 L .4515 .73387 L 0 1 .51 r
F
.4414 .73636 m .45323 .73738 L .4573 .73638 L F
.45561 .73565 m .4573 .73638 L .46147 .73419 L 0 1 .464 r
F
.45561 .73565 m .4573 .73638 L .46146 .73536 L 0 1 .51 r
F
.4414 .73636 m .4573 .73638 L .45561 .73565 L F
.44137 .7392 m .45322 .73852 L .4573 .73638 L 0 1 .464 r
F
.44137 .7392 m .4573 .73638 L .45561 .73565 L F
.44137 .7392 m .45561 .73565 L .4515 .73387 L F
.45561 .73565 m .46147 .73419 L .4515 .73387 L F
.4515 .73387 m .46146 .73536 L .46057 .73164 L 0 1 .51 r
F
.45561 .73565 m .46146 .73536 L .4515 .73387 L F
.44653 .73185 m .46057 .73164 L .45062 .72825 L F
.4414 .73636 m .4515 .73387 L .44653 .73185 L F
.4515 .73387 m .46057 .73164 L .44653 .73185 L F
.44137 .7392 m .4515 .73387 L .44653 .73185 L 0 1 .464 r
F
.44137 .7392 m .44653 .73185 L .43874 .72879 L F
.44653 .73185 m .45065 .72599 L .43874 .72879 L F
.43874 .72879 m .45062 .72825 L .43827 .72745 L 0 1 .51 r
F
.44653 .73185 m .45062 .72825 L .43874 .72879 L F
0 g
.48588 .76489 m
.49446 .76941 L
s
.54209 .9377 m .54397 .91086 L .53788 .9158 L 0 .87 .323 r
F
.54209 .9377 m .55148 .91455 L .54397 .91086 L F
0 g
.5388 .90088 m
.54397 .91086 L
s
.49446 .76941 m
.50158 .76535 L
s
.65574 .90148 m .664 .88743 L .6723 .8685 L 0 1 .197 r
F
0 g
.67209 .86898 m
.6723 .8685 L
s
.66669 .89691 m
.66826 .89376 L
s
.67019 .8798 m
.67288 .87111 L
s
.6723 .8685 m
.67239 .86833 L
s
.66938 .88241 m
.67019 .8798 L
s
.60303 .83455 m .61238 .83982 L .62101 .83948 L 0 1 .422 r
F
.63749 .81932 m .65905 .81811 L .65341 .81096 L 0 1 .446 r
F
0 g
.65905 .81811 m
.66809 .81724 L
s
.63175 .83285 m .62857 .82002 L .6264 .82541 L 0 1 .434 r
F
.63175 .83285 m .63749 .81932 L .62857 .82002 L F
.63175 .83285 m .6472 .82376 L .63749 .81932 L F
0 g
.6472 .82376 m
.65252 .83119 L
s
.6472 .82376 m
.65644 .82324 L
s
.59802 .94216 m .60476 .95122 L .61159 .95059 L 0 .953 .33 r
F
0 g
.5927 .94214 m
.59802 .94216 L
s
.59445 .92917 m
.59802 .94216 L
s
.60303 .83455 m .62101 .83948 L .62316 .83374 L 0 1 .422 r
F
0 g
.62101 .83948 m
.62603 .84731 L
s
.61238 .83982 m
.62101 .83948 L
s
.53052 .76432 m .5512 .75269 L .54298 .7484 L 0 1 .425 r
F
0 g
.5512 .75269 m
.5603 .74721 L
s
.55961 .9503 m .56991 .92249 L .5626 .91954 L 0 .941 .311 r
F
.55961 .9503 m .57427 .93486 L .56991 .92249 L F
0 g
.56991 .92249 m
.57651 .91559 L
s
.53052 .76432 m .52246 .75398 L .52229 .76004 L 0 1 .425 r
F
.53052 .76432 m .53133 .74899 L .52246 .75398 L F
.53052 .76432 m .54298 .7484 L .53133 .74899 L F
0 g
.52204 .76937 m
.53052 .76432 L
s
.52973 .78496 m .52205 .77426 L .52188 .77855 L 0 1 .462 r
F
0 g
.51767 .77881 m
.52188 .77855 L
s
.52973 .78496 m .53055 .77402 L .52205 .77426 L 0 1 .462 r
F
.52973 .78496 m .54173 .77799 L .53055 .77402 L F
.52973 .78496 m .54959 .78442 L .54173 .77799 L F
.52973 .78496 m .5489 .78902 L .54959 .78442 L F
.52973 .78496 m .54039 .78925 L .5489 .78902 L F
0 g
.52267 .785 m
.52973 .78496 L
s
.52188 .77855 m
.52973 .78496 L
s
.59446 .8359 m
.60302 .83455 L
s
.5887 .82654 m
.59446 .8359 L
s
.54209 .9377 m .53788 .9158 L .53726 .9261 L 0 .87 .323 r
F
0 g
.53788 .9158 m
.54397 .91086 L
s
.53262 .90516 m
.53788 .9158 L
s
.69942 .7874 m
.70969 .78769 L
s
.55947 1.22248 m
.56075 1.23444 L
s
.56075 1.23444 m
.56232 1.2492 L
s
.59869 .70102 m .59138 .69311 L .59018 .69832 L 0 1 .46 r
F
.59869 .70102 m .60208 .68805 L .59138 .69311 L F
.54209 .9377 m .55632 .92614 L .55148 .91455 L 0 .87 .323 r
F
0 g
.55148 .91455 m
.55792 .90924 L
s
.66224 .87186 m .67782 .83343 L .6688 .8458 L 0 1 .202 r
F
0 g
.67117 .87108 m
.67209 .86898 L
s
.67782 .83343 m
.68265 .82492 L
s
.67782 .83343 m
.68238 .83158 L
s
.31853 .93612 m
.32034 .93863 L
s
.31853 .93612 m
.32609 .93612 L
s
.55961 .9503 m .5626 .91954 L .55632 .92614 L 0 .941 .311 r
F
0 g
.56165 .91746 m
.5626 .91954 L
s
.67496 .80525 m .67219 .79408 L .66955 .79869 L 0 1 .472 r
F
0 g
.62399 1.07304 m
.62415 1.07871 L
s
.62341 1.05152 m
.62355 1.05666 L
s
.62369 1.06186 m
.62399 1.07304 L
s
.62339 1.05095 m
.62341 1.05152 L
s
.62338 1.05055 m
.62339 1.05095 L
s
.62335 1.04958 m
.62338 1.05055 L
s
.57621 1.16182 m
.57637 1.16195 L
s
.3399 .85433 m .32761 .84454 L .3308 .84866 L 0 .461 .393 r
F
0 g
.32715 .84899 m
.3308 .84866 L
s
.50827 1.00844 m .51763 1.00628 L .51348 .99173 L 0 .38 .296 r
F
.50827 1.00844 m .51747 1.01729 L .51763 1.00628 L F
.50827 1.00844 m .51345 1.01821 L .51747 1.01729 L F
.50876 1.03196 m .51345 1.01821 L .50827 1.00844 L 0 .282 .274 r
F
0 g
.50466 1.00792 m
.50827 1.00844 L
s
.50413 .99391 m
.50827 1.00844 L
s
.60303 .83455 m .59896 .82109 L .59727 .82652 L 0 1 .422 r
F
.60303 .83455 m .6076 .82075 L .59896 .82109 L F
.60303 .83455 m .61742 .82572 L .6076 .82075 L F
.60303 .83455 m .62316 .83374 L .61742 .82572 L F
0 g
.62316 .83374 m
.63175 .83285 L
s
.56343 1.07711 m
.56475 1.08613 L
s
.5628 1.07278 m
.56343 1.07711 L
s
.42783 .72427 m
.42797 .72422 L
s
.42776 .72429 m
.42783 .72427 L
s
.42193 .72747 m
.42877 .72916 L
s
.42877 .72916 m
.43008 .72948 L
s
.50259 .76478 m .49358 .75473 L .49381 .7584 L 0 1 .432 r
F
.50259 .76478 m .49381 .7584 L .49883 .76293 L F
.50259 .76529 m .49358 .75588 L .49381 .7584 L 0 1 .481 r
F
.49883 .76293 m .49381 .7584 L .49394 .75985 L F
.50259 .76529 m .49381 .7584 L .49883 .76293 L F
.49883 .76293 m .49381 .7584 L .49394 .76052 L 0 1 .432 r
F
0 g
.50158 .76535 m
.50158 .76535 L
s
.50158 .76535 m
.50216 .76502 L
s
.50259 .76478 m .5021 .7501 L .49358 .75473 L 0 1 .432 r
F
.50259 .76478 m .5138 .74971 L .5021 .7501 L F
.50259 .76478 m .52246 .75398 L .5138 .74971 L F
0 g
.52331 .76057 m
.53052 .76432 L
s
.50259 .76478 m .52229 .76004 L .52246 .75398 L 0 1 .432 r
F
.50259 .76478 m .51378 .76467 L .52229 .76004 L F
0 g
.51378 .76467 m
.52204 .76937 L
s
.50227 .76496 m
.50259 .76478 L
s
.50166 .76432 m
.50259 .76478 L
s
.52279 .97736 m .51843 .95299 L .51827 .96344 L 0 .642 .313 r
F
0 g
.5135 .966 m
.51827 .96344 L
s
.52279 .97736 m .52355 .94999 L .51843 .95299 L 0 .642 .313 r
F
0 g
.51353 .94081 m
.51843 .95299 L
s
.57896 .82114 m .57375 .80823 L .57255 .8133 L 0 1 .429 r
F
0 g
.56415 .81323 m
.57255 .8133 L
s
.57896 .82114 m .58233 .8082 L .57375 .80823 L 0 1 .429 r
F
.57896 .82114 m .59256 .81324 L .58233 .8082 L F
.57896 .82114 m .59896 .82109 L .59256 .81324 L F
.57896 .82114 m .59727 .82652 L .59896 .82109 L F
.57896 .82114 m .5887 .82654 L .59727 .82652 L F
0 g
.59727 .82652 m
.60303 .83455 L
s
.57255 .8133 m
.57896 .82114 L
s
.36273 .89372 m .36333 .88429 L .35517 .8789 L 0 .272 .307 r
F
.36273 .89372 m .37154 .89307 L .36333 .88429 L F
.36273 .89372 m .37429 .89935 L .37154 .89307 L F
.36273 .89372 m .3705 .89961 L .37429 .89935 L F
0 g
.35457 .88498 m
.36273 .89372 L
s
.5236 1.11529 m .52292 1.11781 L .52221 1.11187 L 0 .592 .041 r
F
0 g
.52027 1.10274 m
.52221 1.11187 L
s
.5236 1.11529 m .52548 1.13095 L .52292 1.11781 L 0 .592 .041 r
F
.52548 1.13095 m .52887 1.14812 L .52577 1.13333 L F
.5236 1.11529 m .52758 1.14008 L .52548 1.13095 L F
.52758 1.14008 m .52887 1.14812 L .52548 1.13095 L F
.51911 1.10321 m .52467 1.12229 L .52246 1.11161 L 0 0 .1 r
F
.51879 1.10242 m .51939 1.10443 L .51911 1.10321 L F
.51939 1.10443 m .52467 1.12229 L .51911 1.10321 L F
.51799 1.10041 m .51941 1.10507 L .51879 1.10242 L F
.51941 1.10507 m .52467 1.12229 L .51879 1.10242 L F
.52548 1.13095 m .52577 1.13333 L .52479 1.12798 L 0 .592 .041 r
F
.52548 1.13095 m .52479 1.12798 L .52292 1.11781 L F
.5236 1.11529 m .53027 1.15155 L .52887 1.14812 L F
.5236 1.11529 m .52902 1.14133 L .53027 1.15155 L F
.5236 1.11529 m .52617 1.1258 L .52902 1.14133 L F
0 g
.52716 1.12211 m
.52943 1.13829 L
s
.52617 1.1258 m
.52716 1.12211 L
s
.52282 1.11337 m
.5236 1.11529 L
s
.52312 1.11213 m
.5236 1.11529 L
s
.46368 .74464 m
.46831 .74684 L
s
.44137 .7392 m .43006 .73128 L .43144 .7361 L 0 1 .464 r
F
0 g
.43144 .7361 m
.44137 .7392 L
s
.43352 .74345 m
.44137 .7392 L
s
.42389 .74029 m
.43144 .7361 L
s
.50259 .76529 m .50209 .75517 L .49358 .75588 L 0 1 .481 r
F
0 g
.49883 .76293 m
.49907 .76308 L
s
.49907 .76308 m
.49922 .76317 L
s
.49846 .76275 m
.49883 .76293 L
s
.49394 .76052 m
.4984 .76272 L
s
.4984 .76272 m
.49846 .76275 L
s
.48588 .76489 m
.49394 .76052 L
s
.50259 .76529 m .51381 .75818 L .50209 .75517 L 0 1 .481 r
F
.50259 .76529 m .52247 .76363 L .51381 .75818 L F
0 g
.51378 .76467 m
.51445 .7643 L
s
.51933 .76165 m
.52229 .76004 L
s
.52229 .76004 m
.52331 .76057 L
s
.50259 .76529 m .5223 .76787 L .52247 .76363 L 0 1 .481 r
F
.50259 .76529 m .51378 .76857 L .5223 .76787 L F
0 g
.50158 .76535 m
.50259 .76529 L
s
.49922 .76317 m
.50259 .76529 L
s
.5887 .82654 m
.59727 .82652 L
s
.52355 .94998 m .53633 .94206 L .53143 .93002 L 0 .733 .324 r
F
0 g
.53143 .93002 m
.53726 .9261 L
s
.26334 .89987 m .25065 .89344 L .25467 .89639 L 0 .423 .335 r
F
0 g
.25284 .8984 m
.25467 .89639 L
s
.63324 1.08549 m
.63328 1.09068 L
s
.63324 1.08531 m
.63324 1.08549 L
s
.63328 1.09068 m
.63332 1.09768 L
s
.5645 .71797 m .58717 .71179 L .58837 .70633 L 0 1 .451 r
F
.5645 .71797 m .57694 .71678 L .58717 .71179 L F
0 g
.58717 .71179 m
.59531 .71463 L
s
.60476 .95122 m
.61159 .95059 L
s
.57846 .97164 m
.57846 .97168 L
s
.54039 .78925 m
.54786 .79599 L
s
.62928 1.12799 m
.62949 1.13535 L
s
.42006 .7285 m
.42703 .72469 L
s
.42703 .72469 m
.42776 .72429 L
s
.42006 .7285 m
.43006 .73128 L
s
.50925 1.05207 m .51342 1.04292 L .50876 1.03196 L 0 .195 .238 r
F
.50925 1.05207 m .5168 1.05758 L .51342 1.04292 L F
.50925 1.05207 m .51663 1.06613 L .5168 1.05758 L F
.50925 1.05207 m .51339 1.06375 L .51663 1.06613 L F
0 g
.50589 1.03746 m
.50925 1.05207 L
s
.50641 1.04765 m
.50925 1.05207 L
s
.64326 .80655 m .66298 .81063 L .66561 .80578 L 0 1 .457 r
F
.64326 .80655 m .65341 .81096 L .66298 .81063 L F
0 g
.66298 .81063 m
.66809 .81724 L
s
.35517 .8789 m .35612 .87051 L .34756 .86603 L 0 .303 .327 r
F
.35517 .8789 m .36464 .87823 L .35612 .87051 L F
.35517 .8789 m .36741 .88402 L .36464 .87823 L F
.35517 .8789 m .36333 .88429 L .36741 .88402 L F
0 g
.3467 .87121 m
.35517 .8789 L
s
.35143 .8792 m
.35517 .8789 L
s
.43008 .72948 m
.43649 .72789 L
s
.62836 1.13319 m
.62837 1.15972 L
s
.62845 1.3602 m
.62846 1.36363 L
s
.60083 .97802 m
.60207 .98487 L
s
.53133 .74899 m .55223 .74349 L .55291 .73753 L 0 1 .435 r
F
.53133 .74899 m .54298 .7484 L .55223 .74349 L F
0 g
.55223 .74349 m
.5603 .74721 L
s
.54298 .7484 m
.5512 .75269 L
s
.54298 .7484 m
.55223 .74349 L
s
.5624 1.2128 m
.56245 1.21364 L
s
.56229 1.21107 m
.5624 1.2128 L
s
.5621 1.20827 m
.56229 1.21107 L
s
.64847 1.1241 m
.65227 1.13192 L
s
.65226 1.12773 m
.65227 1.13192 L
s
.3399 .85433 m .33222 .84333 L .32761 .84454 L 0 .461 .393 r
F
0 g
.31887 .83975 m
.32761 .84454 L
s
.62286 1.01202 m .62823 1.01519 L .63447 1.00582 L 0 1 .288 r
F
0 g
.63272 1.00845 m
.63292 1.00815 L
s
.63292 1.00815 m
.63447 1.00582 L
s
.63338 1.02071 m
.6357 1.01149 L
s
.63447 1.00582 m
.6346 1.00638 L
s
.56239 .73221 m .55463 .72312 L .55394 .7288 L 0 1 .441 r
F
.56239 .73221 m .5645 .71797 L .55463 .72312 L F
.56239 .73221 m .57694 .71678 L .5645 .71797 L F
0 g
.57694 .71678 m
.58717 .71179 L
s
.57694 .71678 m
.58537 .7202 L
s
.39306 .71658 m
.39614 .71721 L
s
.60843 .99353 m .6208 .96962 L .61453 .96299 L 0 1 .302 r
F
.60843 .99353 m .62351 .98508 L .6208 .96962 L F
0 g
.6208 .96962 m
.62753 .96604 L
s
.6208 .96962 m
.62296 .98197 L
s
.50876 1.03196 m .51722 1.03323 L .51345 1.01821 L 0 .282 .274 r
F
.50876 1.03196 m .51705 1.04348 L .51722 1.03323 L F
.50876 1.03196 m .51342 1.04292 L .51705 1.04348 L F
0 g
.50501 1.01697 m
.50876 1.03196 L
s
.50553 1.02963 m
.50876 1.03196 L
s
.47301 .75097 m .46278 .74197 L .46365 .74726 L 0 1 .448 r
F
0 g
.46365 .74726 m
.47301 .75097 L
s
.46496 .75534 m
.47301 .75097 L
s
.45579 .7515 m
.46365 .74726 L
s
.52355 .94998 m .53572 .95305 L .53633 .94206 L 0 .733 .324 r
F
.52355 .94998 m .53023 .95644 L .53572 .95305 L F
0 g
.51866 .93794 m
.52355 .94998 L
s
.52279 .97736 m .53023 .95645 L .52355 .94999 L 0 .642 .313 r
F
0 g
.51843 .95299 m
.52355 .94999 L
s
.61362 1.00139 m
.61366 1.00163 L
s
.61317 1.0029 m
.61317 1.0029 L
s
.61358 1.00152 m
.61362 1.00139 L
s
.26334 .89987 m .25353 .89199 L .25065 .89344 L 0 .423 .335 r
F
0 g
.24262 .89139 m
.25065 .89344 L
s
.28295 .91483 m .28045 .90997 L .27315 .90753 L 0 .31 .222 r
F
.28295 .91483 m .28873 .9144 L .28045 .90997 L F
.28295 .91483 m .29244 .91787 L .28873 .9144 L F
.28295 .91483 m .28994 .91804 L .29244 .91787 L F
0 g
.27472 .91041 m
.28295 .91483 L
s
.28074 .91425 m
.28295 .91483 L
s
.67481 1.28789 m .68498 1.23787 L .68279 1.26113 L 0 .123 .117 r
F
.68483 1.23905 m .69554 1.18726 L .69457 1.17587 L 0 1 .129 r
F
.68483 1.23905 m .6933 1.21304 L .69554 1.18726 L F
0 g
.69554 1.18726 m
.69858 1.18326 L
s
.60843 .99353 m .61453 .96299 L .60807 .9666 L 0 1 .302 r
F
0 g
.6144 .96306 m
.61453 .96299 L
s
.61159 .95059 m
.61453 .96299 L
s
.68498 1.23787 m
.68503 1.2378 L
s
.68493 1.2384 m
.68498 1.23787 L
s
.67364 1.27217 m
.67588 1.24888 L
s
.57661 .96119 m .57427 .93486 L .57278 .94842 L 0 1 .298 r
F
.55961 .9503 m .57278 .94842 L .57427 .93486 L 0 .941 .311 r
F
0 g
.56991 .92249 m
.57427 .93486 L
s
.57427 .93486 m
.58064 .9257 L
s
.5986 1.24763 m
.59867 1.25243 L
s
.60011 1.35426 m
.60039 1.37409 L
s
.59839 1.23304 m
.5986 1.24763 L
s
.59826 1.22374 m
.59839 1.23304 L
s
.59821 1.21988 m
.59826 1.22374 L
s
.59817 1.2173 m
.59821 1.21988 L
s
.59801 1.20591 m
.59817 1.2173 L
s
.59769 1.18349 m
.59801 1.20591 L
s
.59695 1.1311 m
.59769 1.18349 L
s
.59776 1.35258 m
.5978 1.36345 L
s
.5973 1.22576 m
.59745 1.26783 L
s
.59726 1.2141 m
.5973 1.22576 L
s
.59721 1.20049 m
.59726 1.2141 L
s
.59695 1.1311 m
.59721 1.20049 L
s
.5978 1.36345 m
.59784 1.37444 L
s
.56191 1.24975 m
.56253 1.25473 L
s
.6076 .82075 m .61742 .82572 L .6264 .82541 L 0 1 .435 r
F
0 g
.61742 .82572 m
.62316 .83374 L
s
.6076 .82075 m .6264 .82541 L .62857 .82002 L 0 1 .435 r
F
0 g
.6264 .82541 m
.63175 .83285 L
s
.61742 .82572 m
.6264 .82541 L
s
.63749 .81932 m .634 .80706 L .63182 .81216 L 0 1 .446 r
F
.63749 .81932 m .64326 .80655 L .634 .80706 L F
.63749 .81932 m .65341 .81096 L .64326 .80655 L F
0 g
.65341 .81096 m
.65905 .81811 L
s
.65341 .81096 m
.66298 .81063 L
s
.61271 1.02819 m
.61271 1.02819 L
s
.61271 1.02819 m
.61334 1.02447 L
s
.55961 .9503 m .55632 .92614 L .55525 .93791 L 0 .941 .311 r
F
.54209 .9377 m .55525 .93791 L .55632 .92614 L 0 .87 .323 r
F
0 g
.55632 .92614 m
.5626 .91954 L
s
.55148 .91455 m
.55632 .92614 L
s
.43006 .73128 m
.43649 .72789 L
s
.43649 .72789 m
.43768 .72727 L
s
.51799 1.10041 m .51596 1.08809 L .51579 1.0898 L 0 0 .1 r
F
0 g
.51389 1.08465 m
.51579 1.0898 L
s
.5645 .71797 m .58837 .70633 L .57957 .70315 L 0 1 .451 r
F
0 g
.58837 .70633 m
.59869 .70102 L
s
.58765 .99341 m .5866 .96524 L .58464 .97495 L 0 .758 .296 r
F
0 g
.5866 .96524 m
.59252 .96648 L
s
.57846 .97164 m
.58464 .97495 L
s
.58489 .95751 m
.5866 .96524 L
s
.64326 .80655 m .66561 .80578 L .65964 .79884 L 0 1 .457 r
F
0 g
.66561 .80578 m
.67496 .80525 L
s
.4545 .73785 m
.46279 .74093 L
s
.40378 .7185 m .39941 .70771 L .39116 .71217 L 0 1 .485 r
F
.40378 .7185 m .41233 .706 L .39941 .70771 L F
.40378 .7185 m .42308 .7081 L .41233 .706 L F
.40378 .7185 m .42448 .71263 L .42308 .7081 L F
.40378 .7185 m .4162 .71708 L .42448 .71263 L F
0 g
.40261 .71827 m
.40378 .7185 L
s
.40349 .71866 m
.40378 .7185 L
s
.51378 .76857 m
.52205 .77426 L
s
.40377 .71878 m .39937 .71026 L .39114 .71322 L 0 1 .52 r
F
0 g
.38276 .71084 m
.39116 .71217 L
s
.38049 .71194 m
.39114 .71322 L
s
.40377 .71878 m .41227 .70966 L .39937 .71026 L 0 1 .52 r
F
.40377 .71878 m .42303 .71187 L .41227 .70966 L F
.40377 .71878 m .42444 .7154 L .42303 .71187 L F
.40377 .71878 m .41618 .71836 L .42444 .7154 L F
0 g
.39614 .71721 m
.40377 .71878 L
s
.40232 .7193 m
.40377 .71878 L
s
.48563 .7511 m
.49358 .75473 L
s
.53133 .74899 m .55291 .73753 L .54431 .73363 L 0 1 .435 r
F
0 g
.55291 .73753 m
.56239 .73221 L
s
.57661 .96119 m .58322 .96463 L .58959 .95543 L 0 1 .298 r
F
0 g
.58959 .95543 m
.5913 .96189 L
s
.68483 1.23905 m .69457 1.17587 L .69097 1.18684 L 0 1 .129 r
F
0 g
.69143 1.18543 m
.69457 1.17587 L
s
.69351 1.21065 m
.69554 1.18726 L
s
.69457 1.17587 m
.69685 1.15295 L
s
.69102 1.1854 m
.69224 1.14799 L
s
.53133 .74899 m .52288 .73931 L .52271 .7451 L 0 1 .435 r
F
.53133 .74899 m .53214 .7344 L .52288 .73931 L F
.53133 .74899 m .54431 .73363 L .53214 .7344 L F
0 g
.52246 .75398 m
.53133 .74899 L
s
.66761 1.28512 m
.67062 1.27791 L
s
.66631 1.28823 m
.66761 1.28512 L
s
.46279 .74093 m
.46563 .74048 L
s
.55626 .79605 m .54959 .78442 L .5489 .78902 L 0 1 .45 r
F
0 g
.54039 .78925 m
.5489 .78902 L
s
.55626 .79605 m .55837 .78434 L .54959 .78442 L 0 1 .45 r
F
.55626 .79605 m .56939 .78882 L .55837 .78434 L F
.55626 .79605 m .57676 .79586 L .56939 .78882 L F
.55626 .79605 m .57555 .80076 L .57676 .79586 L F
.55626 .79605 m .56677 .80083 L .57555 .80076 L F
0 g
.54786 .79599 m
.55626 .79605 L
s
.5489 .78902 m
.55626 .79605 L
s
.68617 1.25092 m .68596 1.24737 L .68888 1.23098 L 0 0 .013 r
F
0 g
.68553 1.2369 m
.68888 1.23098 L
s
.45322 .73852 m
.4573 .73638 L
s
.45322 .73852 m
.46278 .74197 L
s
.34756 .86603 m .34887 .8578 L .3399 .85433 L 0 .353 .36 r
F
.34756 .86603 m .35771 .86446 L .34887 .8578 L F
.34756 .86603 m .36049 .86984 L .35771 .86446 L F
.34756 .86603 m .35612 .87051 L .36049 .86984 L F
0 g
.33877 .8594 m
.34756 .86603 L
s
.34354 .86634 m
.34756 .86603 L
s
.56677 .80083 m
.57375 .80823 L
s
.48461 .75126 m
.49358 .75588 L
s
.6076 .82075 m .6032 .80797 L .6015 .81314 L 0 1 .435 r
F
.6076 .82075 m .6122 .80766 L .6032 .80797 L F
.6076 .82075 m .62248 .81242 L .6122 .80766 L F
.6076 .82075 m .62857 .82002 L .62248 .81242 L F
0 g
.59896 .82109 m
.6076 .82075 L
s
.62857 .82002 m
.63749 .81932 L
s
.60208 .68805 m .619 .67421 L .60548 .67563 L 0 1 .468 r
F
0 g
.619 .67421 m
.62783 .67683 L
s
.33222 .84333 m .3196 .83453 L .3228 .83849 L 0 .582 .421 r
F
0 g
.31887 .83975 m
.3228 .83849 L
s
.25353 .89199 m .24061 .88597 L .24463 .88898 L 0 .497 .377 r
F
0 g
.24262 .89139 m
.24463 .88898 L
s
.69574 .77245 m .71737 .77763 L .72045 .7737 L 0 1 .491 r
F
.69574 .77245 m .70679 .77709 L .71737 .77763 L F
0 g
.71737 .77763 m
.7226 .78401 L
s
.56374 1.03233 m
.56551 1.03651 L
s
.54209 .9377 m .54915 .94287 L .55525 .93791 L 0 .87 .323 r
F
.54021 .96651 m .54209 .9377 L .53633 .94206 L 0 .787 .312 r
F
.54021 .96651 m .54915 .94287 L .54209 .9377 L F
0 g
.53726 .9261 m
.54209 .9377 L
s
.46278 .74197 m
.46563 .74048 L
s
.5021 .7501 m .5138 .74971 L .52271 .7451 L 0 1 .441 r
F
0 g
.5138 .74971 m
.52246 .75398 L
s
.5021 .7501 m .4927 .74067 L .49305 .74622 L 0 1 .441 r
F
0 g
.48461 .75126 m
.48551 .75112 L
s
.5021 .7501 m .5016 .73605 L .4927 .74067 L 0 1 .441 r
F
0 g
.49272 .7464 m
.49305 .74622 L
s
.48551 .75112 m
.48592 .75105 L
s
.5021 .7501 m .51383 .73543 L .5016 .73605 L 0 1 .441 r
F
.5021 .7501 m .52288 .73931 L .51383 .73543 L F
0 g
.52357 .74548 m
.53133 .74899 L
s
.5021 .7501 m .52271 .7451 L .52288 .73931 L 0 1 .441 r
F
0 g
.52271 .7451 m
.52357 .74548 L
s
.49305 .74622 m
.5021 .7501 L
s
.49358 .75473 m
.5021 .7501 L
s
.5138 .74971 m
.52271 .7451 L
s
.52203 1.00546 m .51803 .9793 L .51787 .98999 L 0 .541 .301 r
F
0 g
.51348 .99172 m
.51787 .98999 L
s
.52203 1.00546 m .52279 .97736 L .51803 .9793 L 0 .541 .301 r
F
0 g
.5135 .966 m
.51803 .9793 L
s
.54021 .96651 m .53633 .94206 L .53572 .95305 L 0 .787 .312 r
F
0 g
.53633 .94206 m
.54209 .9377 L
s
.53143 .93002 m
.53633 .94206 L
s
.51336 1.07806 m
.51379 1.07872 L
s
.60208 .68805 m .59441 .68044 L .5932 .68545 L 0 1 .468 r
F
.60208 .68805 m .60548 .67563 L .59441 .68044 L F
.64931 .93556 m .66803 .88678 L .664 .88743 L 0 1 .194 r
F
.64931 .93556 m .66519 .8999 L .66803 .88678 L F
0 g
.66803 .88678 m
.66938 .88241 L
s
.58224 1.02326 m .58765 .99341 L .58163 .99009 L 0 .641 .28 r
F
.58791 1.01535 m .59284 .96769 L .58677 .98068 L 0 1 .274 r
F
0 g
.59209 .9693 m
.59284 .96769 L
s
.5913 .96189 m
.59284 .96769 L
s
.58233 .8082 m .59256 .81324 L .6015 .81314 L 0 1 .44 r
F
0 g
.59256 .81324 m
.59896 .82109 L
s
.60843 .99353 m .60807 .9666 L .60573 .97804 L 0 1 .302 r
F
0 g
.60476 .95122 m
.60807 .9666 L
s
.60807 .9666 m
.6144 .96306 L
s
.58233 .8082 m .57676 .79586 L .57555 .80076 L 0 1 .44 r
F
0 g
.56677 .80083 m
.57555 .80076 L
s
.58233 .8082 m .58571 .79576 L .57676 .79586 L 0 1 .44 r
F
.58233 .8082 m .59643 .80052 L .58571 .79576 L F
.58233 .8082 m .6032 .80797 L .59643 .80052 L F
.58233 .8082 m .6015 .81314 L .6032 .80797 L F
0 g
.57555 .80076 m
.58233 .8082 L
s
.57375 .80823 m
.58233 .8082 L
s
.6015 .81314 m
.6076 .82075 L
s
.59256 .81324 m
.6015 .81314 L
s
.64905 .79442 m .66955 .79869 L .67219 .79408 L 0 1 .466 r
F
.64905 .79442 m .65964 .79884 L .66955 .79869 L F
0 g
.66955 .79869 m
.67496 .80525 L
s
.51799 1.10041 m .51881 1.09741 L .51596 1.08809 L 0 0 .1 r
F
0 g
.51336 1.07806 m
.51596 1.08809 L
s
.51799 1.10041 m .52246 1.11161 L .51881 1.09741 L 0 0 .1 r
F
.51799 1.10041 m .52397 1.12228 L .52467 1.12229 L F
.51799 1.10041 m .5211 1.11289 L .52397 1.12228 L F
0 g
.51579 1.0898 m
.51799 1.10041 L
s
.51733 1.09731 m
.51799 1.10041 L
s
.25353 .89199 m .24371 .884 L .24061 .88597 L 0 .497 .377 r
F
0 g
.2324 .88425 m
.24061 .88597 L
s
.56512 1.0758 m .56577 1.0501 L .56354 1.05006 L 0 .178 .202 r
F
0 g
.56096 1.04059 m
.56354 1.05006 L
s
.62286 1.01202 m .62351 .98508 L .62084 .9991 L 0 1 .288 r
F
.60843 .99353 m .62084 .9991 L .62351 .98508 L 0 1 .302 r
F
0 g
.62296 .98197 m
.62351 .98508 L
s
.62351 .98508 m
.62976 .97576 L
s
.56661 .70437 m .59018 .69832 L .59138 .69311 L 0 1 .459 r
F
.56661 .70437 m .57957 .70315 L .59018 .69832 L F
0 g
.59018 .69832 m
.59869 .70102 L
s
.53023 .95644 m
.53572 .95305 L
s
.52279 .97736 m .53477 .97038 L .53023 .95645 L 0 .642 .313 r
F
.66056 1.28751 m .66954 1.27355 L .66521 1.29109 L 0 .306 .164 r
F
.66077 1.33005 m .66883 1.16464 L .66471 1.18012 L 0 1 .185 r
F
.66077 1.33005 m .67122 1.21014 L .66883 1.16464 L F
.66417 1.34846 m .66954 1.27355 L .67364 1.27217 L 0 .239 .159 r
F
.66417 1.34846 m .66521 1.29109 L .66954 1.27355 L F
.66417 1.34846 m .66289 1.32313 L .66521 1.29109 L F
.66077 1.33005 m .67056 1.29216 L .67122 1.21014 L 0 1 .185 r
F
.66358 1.1308 m .67269 1.22701 L .67626 1.18969 L 0 .907 .239 r
F
.66358 1.1308 m .66721 1.20144 L .67269 1.22701 L F
0 g
.66358 1.1308 m
.66377 1.06431 L
s
.66077 1.33005 m .66471 1.18012 L .66155 1.24697 L 0 1 .185 r
F
.65514 1.26673 m .66721 1.20146 L .66358 1.13082 L 0 .952 .227 r
F
0 g
.66458 1.15028 m
.66458 1.15033 L
s
.65835 1.11475 m
.66358 1.13082 L
s
.53214 .7344 m .55394 .7288 L .55463 .72312 L 0 1 .444 r
F
.53214 .7344 m .54431 .73363 L .55394 .7288 L F
0 g
.55394 .7288 m
.56239 .73221 L
s
.54431 .73363 m
.55291 .73753 L
s
.54431 .73363 m
.55394 .7288 L
s
.65574 .90148 m .67088 .85863 L .66224 .87186 L 0 1 .197 r
F
0 g
.66553 .89922 m
.66669 .89691 L
s
.67088 .85863 m
.67507 .85024 L
s
.67088 .85863 m
.67404 .85759 L
s
.66744 .87958 m
.67117 .87108 L
s
.33222 .84333 m .3245 .83277 L .3196 .83453 L 0 .582 .421 r
F
0 g
.31057 .83066 m
.3196 .83453 L
s
.27315 .90753 m .27094 .90157 L .26334 .89987 L 0 .375 .281 r
F
.27315 .90753 m .27945 .90554 L .27094 .90157 L F
.27315 .90753 m .28317 .90912 L .27945 .90554 L F
.27315 .90753 m .28045 .90997 L .28317 .90912 L F
0 g
.26469 .90358 m
.27315 .90753 L
s
.27071 .90773 m
.27315 .90753 L
s
.69574 .77245 m .72045 .7737 L .71418 .76714 L 0 1 .491 r
F
0 g
.72045 .7737 m
.73058 .7744 L
s
.5645 .71797 m .55636 .70937 L .55566 .71479 L 0 1 .451 r
F
.5645 .71797 m .56661 .70437 L .55636 .70937 L F
.5645 .71797 m .57957 .70315 L .56661 .70437 L F
0 g
.57957 .70315 m
.59018 .69832 L
s
.57957 .70315 m
.58837 .70633 L
s
.54021 .96651 m .55365 .95631 L .54915 .94287 L 0 .787 .312 r
F
0 g
.54915 .94287 m
.55525 .93791 L
s
.30897 .93195 m
.311 .93347 L
s
.30905 .932 m
.3166 .93688 L
s
.6122 .80766 m .63182 .81216 L .634 .80706 L 0 1 .446 r
F
.6122 .80766 m .62248 .81242 L .63182 .81216 L F
0 g
.63182 .81216 m
.63749 .81932 L
s
.62248 .81242 m
.63182 .81216 L
s
.62248 .81242 m
.62857 .82002 L
s
.53055 .77402 m .52247 .76363 L .5223 .76787 L 0 1 .469 r
F
0 g
.51378 .76857 m
.5223 .76787 L
s
.53055 .77402 m .53137 .76323 L .52247 .76363 L 0 1 .469 r
F
.53055 .77402 m .54307 .76694 L .53137 .76323 L F
.53055 .77402 m .55133 .77311 L .54307 .76694 L F
.53055 .77402 m .55063 .7776 L .55133 .77311 L F
.53055 .77402 m .54173 .77799 L .55063 .7776 L F
0 g
.52205 .77426 m
.53055 .77402 L
s
.5223 .76787 m
.53055 .77402 L
s
.43828 .72695 m .43518 .7151 L .42658 .71952 L 0 1 .47 r
F
0 g
.42797 .72422 m
.42841 .72435 L
s
.43828 .72695 m .44806 .71388 L .43518 .7151 L 0 1 .47 r
F
0 g
.42841 .72435 m
.42921 .72461 L
s
.43828 .72695 m .45839 .71666 L .44806 .71388 L 0 1 .47 r
F
.43828 .72695 m .45927 .72159 L .45839 .71666 L F
.43828 .72695 m .45065 .72599 L .45927 .72159 L F
0 g
.43664 .72651 m
.43828 .72695 L
s
.43782 .72719 m
.43828 .72695 L
s
.64326 .80655 m .63945 .79474 L .63727 .7996 L 0 1 .457 r
F
.64326 .80655 m .64905 .79442 L .63945 .79474 L F
.64326 .80655 m .65964 .79884 L .64905 .79442 L F
0 g
.65964 .79884 m
.66561 .80578 L
s
.65964 .79884 m
.66955 .79869 L
s
.55961 .9503 m .56649 .95505 L .57278 .94842 L 0 .941 .311 r
F
.43827 .72745 m .43514 .7185 L .42656 .7207 L 0 1 .512 r
F
.43827 .72745 m .448 .71909 L .43514 .7185 L F
.43827 .72745 m .45834 .72234 L .448 .71909 L F
.43827 .72745 m .45923 .72606 L .45834 .72234 L F
.43827 .72745 m .45062 .72825 L .45923 .72606 L F
0 g
.42921 .72461 m
.43827 .72745 L
s
.43649 .72789 m
.43827 .72745 L
s
.52279 .97736 m .53413 .98249 L .53477 .97038 L 0 .642 .313 r
F
.52279 .97736 m .52899 .98548 L .53413 .98249 L F
.52203 1.00546 m .52899 .98548 L .52279 .97736 L 0 .541 .301 r
F
0 g
.51803 .9793 m
.52279 .97736 L
s
.51827 .96344 m
.52279 .97736 L
s
.47121 .73756 m .46059 .7291 L .46147 .73419 L 0 1 .456 r
F
0 g
.4573 .73638 m
.45849 .73609 L
s
.47121 .73756 m .46941 .72464 L .46059 .7291 L 0 1 .456 r
F
0 g
.45849 .73609 m
.45879 .73601 L
s
.46121 .73433 m
.46147 .73419 L
s
.47121 .73756 m .48205 .7238 L .46941 .72464 L 0 1 .456 r
F
.47121 .73756 m .49181 .72717 L .48205 .7238 L F
.47121 .73756 m .49217 .73251 L .49181 .72717 L F
.47121 .73756 m .48334 .73696 L .49217 .73251 L F
0 g
.46563 .74048 m
.47121 .73756 L
s
.46147 .73419 m
.47121 .73756 L
s
.52617 1.1258 m
.52675 1.12896 L
s
.56883 1.01715 m
.57241 1.02241 L
s
.3399 .85433 m .3416 .84583 L .33222 .84333 L 0 .461 .393 r
F
.3399 .85433 m .35075 .85152 L .3416 .84583 L F
.3399 .85433 m .35354 .8566 L .35075 .85152 L F
.3399 .85433 m .34887 .8578 L .35354 .8566 L F
0 g
.3308 .84866 m
.3399 .85433 L
s
.33559 .85502 m
.3399 .85433 L
s
.64905 .79442 m .67219 .79408 L .6659 .78728 L 0 1 .466 r
F
0 g
.67219 .79408 m
.68077 .79387 L
s
.41835 .71759 m
.42658 .71952 L
s
.68879 .78294 m .70679 .77709 L .69574 .77245 L 0 1 .486 r
F
0 g
.70679 .77709 m
.71737 .77763 L
s
.70679 .77709 m
.71275 .78362 L
s
.54173 .77799 m
.54959 .78442 L
s
.53214 .7344 m .55463 .72312 L .54564 .71954 L 0 1 .444 r
F
0 g
.55463 .72312 m
.5645 .71797 L
s
.53214 .7344 m .5233 .7253 L .52313 .73083 L 0 1 .444 r
F
.53214 .7344 m .53295 .72046 L .5233 .7253 L F
.53214 .7344 m .54564 .71954 L .53295 .72046 L F
0 g
.52288 .73931 m
.53214 .7344 L
s
.56661 .70437 m .59138 .69311 L .5822 .69012 L 0 1 .459 r
F
0 g
.59138 .69311 m
.60208 .68805 L
s
.58224 1.02326 m .58163 .99009 L .57958 1.00055 L 0 .641 .28 r
F
0 g
.57846 .97168 m
.58163 .99009 L
s
.48334 .73696 m
.4927 .74067 L
s
.39941 .70771 m .38641 .7018 L .38832 .70592 L 0 1 .49 r
F
0 g
.38731 .7065 m
.38832 .70592 L
s
.6122 .80766 m .634 .80706 L .62757 .79978 L 0 1 .446 r
F
0 g
.634 .80706 m
.64326 .80655 L
s
.41618 .71836 m
.42656 .7207 L
s
.50209 .75517 m .49268 .74599 L .49304 .74994 L 0 1 .486 r
F
.50209 .75517 m .50159 .74511 L .49268 .74599 L F
0 g
.48592 .75105 m
.49304 .74994 L
s
.50209 .75517 m .51383 .74789 L .50159 .74511 L 0 1 .486 r
F
.50209 .75517 m .5229 .75312 L .51383 .74789 L F
.50209 .75517 m .52273 .75731 L .5229 .75312 L F
.50209 .75517 m .51381 .75818 L .52273 .75731 L F
0 g
.49358 .75588 m
.50209 .75517 L
s
.49304 .74994 m
.50209 .75517 L
s
.59919 .97802 m
.60573 .97804 L
s
.6122 .80766 m .60745 .79542 L .60575 .80038 L 0 1 .446 r
F
.6122 .80766 m .61681 .79517 L .60745 .79542 L F
.6122 .80766 m .62757 .79978 L .61681 .79517 L F
0 g
.6032 .80797 m
.6122 .80766 L
s
.4712 .73961 m .46057 .73164 L .46146 .73536 L 0 1 .501 r
F
0 g
.45879 .73601 m
.46146 .73536 L
s
.4712 .73961 m .46937 .73014 L .46057 .73164 L 0 1 .501 r
F
.4712 .73961 m .48201 .73188 L .46937 .73014 L F
.4712 .73961 m .49178 .73614 L .48201 .73188 L F
.4712 .73961 m .49214 .74007 L .49178 .73614 L F
.4712 .73961 m .48331 .74156 L .49214 .74007 L F
0 g
.46563 .74048 m
.4712 .73961 L
s
.46146 .73536 m
.4712 .73961 L
s
.3245 .83277 m .31156 .8248 L .31478 .82866 L 0 .691 .443 r
F
0 g
.31057 .83066 m
.31478 .82866 L
s
.5726 1.00112 m .58322 .96463 L .57661 .96119 L 0 .935 .288 r
F
.5726 1.00112 m .58677 .98068 L .58322 .96463 L F
0 g
.58322 .96463 m
.58959 .95543 L
s
.57546 .997 m
.57881 .99989 L
s
.58163 .99009 m
.58718 .99315 L
s
.57881 .99989 m
.57958 1.00055 L
s
.5858 .98208 m
.58707 .98987 L
s
.55663 .98398 m .55961 .9503 L .55365 .95631 L 0 .853 .301 r
F
.55663 .98398 m .56649 .95505 L .55961 .9503 L F
0 g
.55525 .93791 m
.55961 .9503 L
s
.69553 .76545 m .70232 .74943 L .69207 .76067 L 0 1 .274 r
F
0 g
.69356 .76606 m
.69553 .76545 L
s
.68997 .77228 m
.68998 .77228 L
s
.68998 .77228 m
.69003 .77222 L
s
.694 .76734 m
.69553 .76545 L
s
.68868 .78295 m
.68869 .78294 L
s
.68869 .78294 m
.68869 .78294 L
s
.68869 .78294 m
.68869 .78294 L
s
.68869 .78294 m
.68869 .78294 L
s
.68869 .78294 m
.68873 .78288 L
s
.68869 .78284 m
.68879 .78294 L
s
.68869 .78284 m
.68869 .78284 L
s
.68869 .78294 m
.68879 .78294 L
s
.68868 .78294 m
.68869 .78294 L
s
.68841 .78294 m
.68868 .78294 L
s
.52123 1.03442 m .51763 1.00628 L .51747 1.01729 L 0 .421 .287 r
F
0 g
.51345 1.01821 m
.51747 1.01729 L
s
.52123 1.03442 m .52203 1.00546 L .51763 1.00628 L 0 .421 .287 r
F
0 g
.51348 .99173 m
.51763 1.00628 L
s
.5016 .73605 m .51383 .73543 L .52313 .73083 L 0 1 .449 r
F
0 g
.51383 .73543 m
.52288 .73931 L
s
.39941 .70771 m .39503 .69721 L .38641 .7018 L 0 1 .49 r
F
0 g
.3754 .70046 m
.38641 .7018 L
s
.39941 .70771 m .40844 .6952 L .39503 .69721 L 0 1 .49 r
F
.39941 .70771 m .41957 .697 L .40844 .6952 L F
.39941 .70771 m .42098 .70141 L .41957 .697 L F
.39941 .70771 m .41233 .706 L .42098 .70141 L F
0 g
.39116 .71217 m
.39941 .70771 L
s
.38832 .70592 m
.39941 .70771 L
s
.5016 .73605 m .49181 .72717 L .49217 .73251 L 0 1 .449 r
F
.5016 .73605 m .50111 .72256 L .49181 .72717 L F
0 g
.48813 .73454 m
.49217 .73251 L
s
.5016 .73605 m .51386 .72175 L .50111 .72256 L 0 1 .449 r
F
.5016 .73605 m .5233 .7253 L .51386 .72175 L F
0 g
.52386 .73112 m
.53214 .7344 L
s
.5016 .73605 m .52313 .73083 L .5233 .7253 L 0 1 .449 r
F
0 g
.52313 .73083 m
.52386 .73112 L
s
.49217 .73251 m
.5016 .73605 L
s
.4927 .74067 m
.5016 .73605 L
s
.51383 .73543 m
.52313 .73083 L
s
.45461 .72723 m
.46059 .7291 L
s
.5726 1.00112 m .57661 .96119 L .57054 .96991 L 0 .935 .288 r
F
0 g
.57278 .94842 m
.57661 .96119 L
s
.61609 1.05905 m .62823 1.01519 L .62286 1.01202 L 0 1 .268 r
F
.61609 1.05905 m .63009 1.03378 L .62823 1.01519 L F
0 g
.62823 1.01519 m
.63272 1.00845 L
s
.62823 1.01519 m
.63007 1.03362 L
s
.55663 .98398 m .57054 .96991 L .56649 .95505 L 0 .853 .301 r
F
0 g
.56649 .95505 m
.57278 .94842 L
s
.64931 .93556 m .65719 .92077 L .66519 .8999 L 0 1 .194 r
F
0 g
.663 .90561 m
.66519 .8999 L
s
.66519 .8999 m
.66553 .89922 L
s
.26334 .89987 m .26143 .89301 L .25353 .89199 L 0 .423 .335 r
F
.26334 .89987 m .27017 .8965 L .26143 .89301 L F
.26334 .89987 m .27388 .90014 L .27017 .8965 L F
.26334 .89987 m .27094 .90157 L .27388 .90014 L F
0 g
.25467 .89639 m
.26334 .89987 L
s
.26068 .90073 m
.26334 .89987 L
s
.39937 .71026 m .38635 .70481 L .38827 .70818 L 0 1 .521 r
F
0 g
.38049 .71194 m
.38827 .70818 L
s
.68207 .80175 m .67915 .7961 L .67659 .80393 L 0 1 .238 r
F
.67541 .8226 m .68207 .80175 L .67276 .81624 L 0 1 .223 r
F
0 g
.67625 .81081 m
.68207 .80175 L
s
.65486 .78281 m .67615 .78731 L .6788 .7829 L 0 1 .473 r
F
.65486 .78281 m .6659 .78728 L .67615 .78731 L F
0 g
.67615 .78731 m
.68127 .79317 L
s
.55837 .78434 m .55133 .77311 L .55063 .7776 L 0 1 .458 r
F
0 g
.54173 .77799 m
.55063 .7776 L
s
.55837 .78434 m .5605 .77291 L .55133 .77311 L 0 1 .458 r
F
.55837 .78434 m .57203 .77715 L .5605 .77291 L F
.55837 .78434 m .57978 .78389 L .57203 .77715 L F
.55837 .78434 m .57857 .78863 L .57978 .78389 L F
.55837 .78434 m .56939 .78882 L .57857 .78863 L F
0 g
.54959 .78442 m
.55837 .78434 L
s
.55063 .7776 m
.55837 .78434 L
s
.56939 .78882 m
.57676 .79586 L
s
.58571 .79576 m .59643 .80052 L .60575 .80038 L 0 1 .45 r
F
0 g
.59643 .80052 m
.6032 .80797 L
s
.56198 1.25035 m
.56227 1.25266 L
s
.56227 1.25266 m
.56251 1.25462 L
s
.3245 .83277 m .31676 .82252 L .31156 .8248 L 0 .691 .443 r
F
0 g
.30225 .82168 m
.31156 .8248 L
s
.51381 .75818 m
.52247 .76363 L
s
.66589 1.1757 m
.66589 1.1757 L
s
.67085 1.25578 m
.67139 1.2485 L
s
.53295 .72046 m .54564 .71954 L .55566 .71479 L 0 1 .453 r
F
0 g
.54564 .71954 m
.55463 .72312 L
s
.53295 .72046 m .55566 .71479 L .55636 .70937 L 0 1 .453 r
F
0 g
.55566 .71479 m
.5645 .71797 L
s
.54564 .71954 m
.55566 .71479 L
s
.55663 .98398 m .55365 .95631 L .55259 .96909 L 0 .853 .301 r
F
.54021 .96651 m .55259 .96909 L .55365 .95631 L 0 .787 .312 r
F
0 g
.54915 .94287 m
.55365 .95631 L
s
.55365 .95631 m
.55961 .9503 L
s
.58571 .79576 m .57978 .78389 L .57857 .78863 L 0 1 .45 r
F
0 g
.56939 .78882 m
.57857 .78863 L
s
.58571 .79576 m .5891 .78374 L .57978 .78389 L 0 1 .45 r
F
.58571 .79576 m .60032 .78829 L .5891 .78374 L F
.58571 .79576 m .60745 .79542 L .60032 .78829 L F
.58571 .79576 m .60575 .80038 L .60745 .79542 L F
0 g
.57857 .78863 m
.58571 .79576 L
s
.57676 .79586 m
.58571 .79576 L
s
.60575 .80038 m
.6122 .80766 L
s
.59643 .80052 m
.60575 .80038 L
s
.61681 .79517 m .63727 .7996 L .63945 .79474 L 0 1 .456 r
F
.61681 .79517 m .62757 .79978 L .63727 .7996 L F
0 g
.63727 .7996 m
.64326 .80655 L
s
.62757 .79978 m
.63727 .7996 L
s
.62757 .79978 m
.634 .80706 L
s
.53824 .99846 m .53477 .97038 L .53413 .98249 L 0 .693 .301 r
F
.53824 .99846 m .54021 .96651 L .53477 .97038 L F
0 g
.53023 .95645 m
.53477 .97038 L
s
.56512 1.0758 m .57105 1.07413 L .56577 1.0501 L 0 .178 .202 r
F
0 g
.56374 1.03233 m
.56577 1.0501 L
s
.33222 .84333 m .33429 .83438 L .3245 .83277 L 0 .582 .421 r
F
.33222 .84333 m .34377 .83924 L .33429 .83438 L F
.33222 .84333 m .34656 .84408 L .34377 .83924 L F
.33222 .84333 m .3416 .84583 L .34656 .84408 L F
0 g
.3228 .83849 m
.33222 .84333 L
s
.32761 .84454 m
.33222 .84333 L
s
.56873 .69135 m .5932 .68545 L .59441 .68044 L 0 1 .467 r
F
.56873 .69135 m .5822 .69012 L .5932 .68545 L F
0 g
.5932 .68545 m
.60208 .68805 L
s
.45062 .72825 m
.46057 .73164 L
s
.60843 .99353 m .61437 1.00274 L .62084 .9991 L 0 1 .302 r
F
0 g
.61437 1.00274 m
.6167 1.00143 L
s
.6167 1.00143 m
.62084 .9991 L
s
.64905 .79442 m .64492 .78295 L .64273 .78761 L 0 1 .466 r
F
.64905 .79442 m .65486 .78281 L .64492 .78295 L F
.64905 .79442 m .6659 .78728 L .65486 .78281 L F
0 g
.6659 .78728 m
.67615 .78731 L
s
.6659 .78728 m
.67219 .79408 L
s
.39937 .71026 m .39494 .7017 L .38635 .70481 L 0 1 .521 r
F
0 g
.37533 .70362 m
.38635 .70481 L
s
.39937 .71026 m .40834 .70093 L .39494 .7017 L 0 1 .521 r
F
0 g
.38641 .7018 m
.39503 .69721 L
s
.39937 .71026 m .41948 .70301 L .40834 .70093 L 0 1 .521 r
F
.39937 .71026 m .4209 .70656 L .41948 .70301 L F
.39937 .71026 m .41227 .70966 L .4209 .70656 L F
0 g
.39114 .71322 m
.39937 .71026 L
s
.38827 .70818 m
.39937 .71026 L
s
.56661 .70437 m .55809 .69619 L .5574 .70139 L 0 1 .459 r
F
.56661 .70437 m .56873 .69135 L .55809 .69619 L F
.56661 .70437 m .5822 .69012 L .56873 .69135 L F
0 g
.5822 .69012 m
.5932 .68545 L
s
.5822 .69012 m
.59138 .69311 L
s
.54021 .96651 m .54682 .97346 L .55259 .96909 L 0 .787 .312 r
F
0 g
.53572 .95305 m
.54021 .96651 L
s
.53824 .99846 m .54682 .97347 L .54021 .96651 L 0 .693 .301 r
F
0 g
.53477 .97038 m
.54021 .96651 L
s
.29945 .92553 m
.30172 .92614 L
s
.29945 .92553 m
.30729 .93067 L
s
.48331 .74156 m
.49268 .74599 L
s
.65486 .78281 m .6788 .7829 L .67219 .77619 L 0 1 .473 r
F
0 g
.6788 .7829 m
.68371 .78292 L
s
.52203 1.00546 m .53316 1.00096 L .52899 .98548 L 0 .541 .301 r
F
0 g
.52899 .98548 m
.53413 .98249 L
s
.51881 1.09741 m .51638 1.07683 L .51621 1.08253 L 0 .062 .169 r
F
0 g
.51379 1.07872 m
.51621 1.08253 L
s
.43518 .7151 m .42308 .7081 L .42448 .71263 L 0 1 .476 r
F
0 g
.42354 .71314 m
.42448 .71263 L
s
.69574 .77245 m .71418 .76714 L .70272 .76231 L 0 1 .491 r
F
0 g
.71418 .76714 m
.72045 .7737 L
s
.60238 1.02974 m .60843 .99353 L .60223 .99649 L 0 .899 .284 r
F
0 g
.60688 .99427 m
.60843 .99353 L
s
.60688 .99427 m
.60688 .99427 L
s
.60573 .97804 m
.60843 .99353 L
s
.67541 .8226 m .67276 .81624 L .67021 .82484 L 0 1 .223 r
F
.6688 .8458 m .67541 .8226 L .66641 .83844 L 0 1 .211 r
F
.52203 1.00546 m .53252 1.01347 L .53316 1.00096 L 0 .541 .301 r
F
.52203 1.00546 m .52774 1.0154 L .53252 1.01347 L F
0 g
.51787 .98999 m
.52203 1.00546 L
s
.52123 1.03442 m .52774 1.0154 L .52203 1.00546 L 0 .421 .287 r
F
0 g
.51763 1.00628 m
.52203 1.00546 L
s
.46941 .72464 m .45839 .71666 L .45927 .72159 L 0 1 .463 r
F
.46941 .72464 m .4676 .71217 L .45839 .71666 L F
0 g
.45801 .72223 m
.45927 .72159 L
s
.46941 .72464 m .48077 .71111 L .4676 .71217 L 0 1 .463 r
F
.46941 .72464 m .49092 .71417 L .48077 .71111 L F
.46941 .72464 m .49128 .71932 L .49092 .71417 L F
.46941 .72464 m .48205 .7238 L .49128 .71932 L F
0 g
.46059 .7291 m
.46941 .72464 L
s
.45927 .72159 m
.46941 .72464 L
s
.52339 1.12036 m
.52479 1.12798 L
s
.43518 .7151 m .43207 .70361 L .42308 .7081 L 0 1 .476 r
F
.43518 .7151 m .44546 .70214 L .43207 .70361 L F
.43518 .7151 m .45618 .70462 L .44546 .70214 L F
.43518 .7151 m .45707 .70939 L .45618 .70462 L F
.43518 .7151 m .44806 .71388 L .45707 .70939 L F
0 g
.42658 .71952 m
.43518 .7151 L
s
.42448 .71263 m
.43518 .7151 L
s
.53295 .72046 m .52372 .71185 L .52355 .71716 L 0 1 .453 r
F
.53295 .72046 m .53376 .70709 L .52372 .71185 L F
.53295 .72046 m .54698 .70606 L .53376 .70709 L F
.53295 .72046 m .55636 .70937 L .54698 .70606 L F
0 g
.55636 .70937 m
.56661 .70437 L
s
.5233 .7253 m
.53295 .72046 L
s
.61681 .79517 m .63945 .79474 L .63267 .78771 L 0 1 .456 r
F
0 g
.63945 .79474 m
.64905 .79442 L
s
.61609 1.05905 m .62286 1.01202 L .61686 1.02278 L 0 1 .268 r
F
0 g
.62084 .9991 m
.62286 1.01202 L
s
.38635 .70481 m
.39494 .7017 L
s
.56244 1.22464 m .57196 1.35046 L .56633 1.27318 L 0 0 .1 r
F
0 g
.55945 1.22198 m
.56223 1.24486 L
s
.56244 1.22464 m .56719 1.29741 L .57286 1.37008 L 0 0 .1 r
F
.56244 1.22464 m .56277 1.23566 L .56719 1.29741 L F
0 g
.56244 1.22464 m
.56287 1.22999 L
s
.56245 1.21364 m
.56339 1.22804 L
s
.56339 1.22804 m
.56341 1.22829 L
s
.56232 1.2492 m
.56305 1.25598 L
s
.56146 1.2256 m
.56277 1.23566 L
s
.56253 1.24217 m
.5627 1.24384 L
s
.56232 1.24004 m
.56253 1.24217 L
s
.56269 1.25459 m
.56286 1.25602 L
s
.56225 1.251 m
.56269 1.25459 L
s
.56194 1.21949 m
.56244 1.22464 L
s
.68617 1.25092 m .6933 1.21304 L .68933 1.23615 L 0 0 .013 r
F
.68483 1.23905 m .68933 1.23615 L .6933 1.21304 L 0 1 .129 r
F
0 g
.6933 1.21304 m
.69351 1.21065 L
s
.6933 1.21304 m
.69618 1.19681 L
s
.57681 1.0521 m .5765 1.01569 L .57444 1.0254 L 0 .508 .266 r
F
0 g
.57241 1.02241 m
.57444 1.0254 L
s
.57681 1.0521 m .58224 1.02326 L .5765 1.01569 L 0 .508 .266 r
F
0 g
.57414 .9989 m
.5765 1.01569 L
s
.31676 .82252 m .3035 .81528 L .30673 .81906 L 0 .783 .459 r
F
0 g
.30225 .82168 m
.30673 .81906 L
s
.52043 1.06126 m .51722 1.03323 L .51705 1.04348 L 0 .299 .268 r
F
0 g
.51342 1.04292 m
.51705 1.04348 L
s
.52043 1.06126 m .52123 1.03442 L .51722 1.03323 L 0 .299 .268 r
F
0 g
.51345 1.01821 m
.51722 1.03323 L
s
.25353 .89199 m .2519 .88437 L .24371 .884 L 0 .497 .377 r
F
0 g
.24061 .88597 m
.24371 .884 L
s
.25353 .89199 m .26087 .88739 L .2519 .88437 L 0 .497 .377 r
F
.25353 .89199 m .26459 .89104 L .26087 .88739 L F
.25353 .89199 m .26143 .89301 L .26459 .89104 L F
0 g
.24463 .88898 m
.25353 .89199 L
s
.25065 .89344 m
.25353 .89199 L
s
.48205 .7238 m
.49181 .72717 L
s
.61681 .79517 m .61173 .78336 L .61002 .78813 L 0 1 .456 r
F
.61681 .79517 m .62144 .78318 L .61173 .78336 L F
.61681 .79517 m .63267 .78771 L .62144 .78318 L F
0 g
.60745 .79542 m
.61681 .79517 L
s
.56873 .69135 m .59441 .68044 L .58485 .67761 L 0 1 .467 r
F
0 g
.59441 .68044 m
.60548 .67563 L
s
.41889 .70728 m
.42308 .7081 L
s
.53137 .76323 m .5229 .75312 L .52273 .75731 L 0 1 .475 r
F
0 g
.51381 .75818 m
.52273 .75731 L
s
.53137 .76323 m .53219 .75259 L .5229 .75312 L 0 1 .475 r
F
.53137 .76323 m .54442 .75609 L .53219 .75259 L F
.53137 .76323 m .55307 .76202 L .54442 .75609 L F
.53137 .76323 m .55237 .76643 L .55307 .76202 L F
.53137 .76323 m .54307 .76694 L .55237 .76643 L F
0 g
.52247 .76363 m
.53137 .76323 L
s
.52273 .75731 m
.53137 .76323 L
s
.58791 1.01535 m .58677 .98068 L .5849 .9987 L 0 1 .274 r
F
.5726 1.00112 m .5849 .9987 L .58677 .98068 L 0 .935 .288 r
F
0 g
.58322 .96463 m
.58677 .98068 L
s
.58677 .98068 m
.59209 .9693 L
s
.6905 .76699 m
.69055 .76705 L
s
.69574 .77245 m .70272 .76231 L .6921 .76177 L 0 1 .491 r
F
0 g
.69055 .76705 m
.69574 .77245 L
s
.69003 .77222 m
.69255 .76912 L
s
.68998 .77228 m
.69574 .77245 L
s
.52161 1.11455 m
.52193 1.11558 L
s
.5211 1.11289 m
.52161 1.11455 L
s
.61437 1.00274 m
.61531 1.01028 L
s
.51881 1.09741 m .51962 1.08334 L .51638 1.07683 L 0 .062 .169 r
F
0 g
.51339 1.06375 m
.51638 1.07683 L
s
.5726 1.00112 m .57054 .96991 L .56906 .985 L 0 .935 .288 r
F
.55663 .98398 m .56906 .985 L .57054 .96991 L 0 .853 .301 r
F
0 g
.56649 .95505 m
.57054 .96991 L
s
.57054 .96991 m
.57661 .96119 L
s
.54307 .76694 m
.55133 .77311 L
s
.67071 1.27316 m
.67139 1.27293 L
s
.50111 .72256 m .51386 .72175 L .52355 .71716 L 0 1 .457 r
F
0 g
.51386 .72175 m
.5233 .7253 L
s
.54682 .97346 m
.55259 .96909 L
s
.43514 .7185 m .42303 .71187 L .42444 .7154 L 0 1 .514 r
F
0 g
.41618 .71836 m
.42444 .7154 L
s
.64931 .93556 m .664 .88743 L .65574 .90148 L 0 1 .194 r
F
0 g
.65719 .92077 m
.663 .90561 L
s
.664 .88743 m
.66744 .87958 L
s
.664 .88743 m
.66803 .88678 L
s
.53824 .99846 m .55095 .98944 L .54682 .97347 L 0 .693 .301 r
F
.50111 .72256 m .49092 .71417 L .49128 .71932 L 0 1 .457 r
F
.50111 .72256 m .50061 .70958 L .49092 .71417 L F
.50111 .72256 m .51389 .70859 L .50061 .70958 L F
.50111 .72256 m .52372 .71185 L .51389 .70859 L F
0 g
.52417 .71738 m
.53295 .72046 L
s
.50111 .72256 m .52355 .71716 L .52372 .71185 L 0 1 .457 r
F
0 g
.52355 .71716 m
.52417 .71738 L
s
.49128 .71932 m
.50111 .72256 L
s
.49181 .72717 m
.50111 .72256 L
s
.51386 .72175 m
.52355 .71716 L
s
.5961 1.07389 m .60062 1.04211 L .59635 1.0311 L 0 .775 .269 r
F
.59636 1.09431 m .60062 1.04211 L .5965 1.04271 L 0 1 .25 r
F
.60062 1.04211 m .60227 1.02189 L .59994 1.03029 L F
.60062 1.04211 m .59994 1.03029 L .59635 1.0311 L 0 .775 .269 r
F
.60062 1.04211 m .59994 1.03029 L .5965 1.04271 L 0 1 .25 r
F
.60062 1.04211 m .60238 1.02974 L .59994 1.03029 L 0 .775 .269 r
F
.60238 1.02974 m .60223 .99649 L .59991 1.00966 L 0 .899 .284 r
F
0 g
.59919 .97802 m
.60223 .99649 L
s
.60223 .99649 m
.60688 .99427 L
s
.56241 1.2536 m
.56277 1.25704 L
s
.56277 1.25704 m
.56281 1.25744 L
s
.56281 1.25744 m
.56317 1.26077 L
s
.6607 .77165 m .68278 .7764 L .68544 .77215 L 0 1 .48 r
F
.6607 .77165 m .67219 .77619 L .68278 .7764 L F
0 g
.68278 .7764 m
.68513 .77896 L
s
.31676 .82252 m .309 .81251 L .3035 .81528 L 0 .783 .459 r
F
0 g
.2939 .81279 m
.3035 .81528 L
s
.63346 1.07868 m
.63356 1.08108 L
s
.63263 1.05844 m
.63346 1.07868 L
s
.63262 1.05819 m
.63263 1.05844 L
s
.63262 1.05802 m
.63262 1.05819 L
s
.6326 1.05759 m
.63262 1.05802 L
s
.3245 .83277 m .32696 .82334 L .31676 .82252 L 0 .691 .443 r
F
.3245 .83277 m .33675 .82745 L .32696 .82334 L F
.3245 .83277 m .33956 .83211 L .33675 .82745 L F
.3245 .83277 m .33429 .83438 L .33956 .83211 L F
0 g
.31478 .82866 m
.3245 .83277 L
s
.3196 .83453 m
.3245 .83277 L
s
.43514 .7185 m .43199 .70952 L .42303 .71187 L 0 1 .514 r
F
.43514 .7185 m .44537 .70993 L .43199 .70952 L F
.43514 .7185 m .4561 .71303 L .44537 .70993 L F
.43514 .7185 m .457 .71675 L .4561 .71303 L F
.43514 .7185 m .448 .71909 L .457 .71675 L F
0 g
.42656 .7207 m
.43514 .7185 L
s
.42444 .7154 m
.43514 .7185 L
s
.57105 1.07413 m .57126 1.03792 L .56908 1.04489 L 0 .333 .247 r
F
0 g
.56551 1.03651 m
.56908 1.04489 L
s
.62828 1.06572 m .63009 1.03378 L .6272 1.05549 L 0 1 .179 r
F
.61609 1.05905 m .6272 1.05549 L .63009 1.03378 L 0 1 .268 r
F
0 g
.63007 1.03362 m
.63009 1.03378 L
s
.63009 1.03378 m
.63338 1.02071 L
s
.45688 .71626 m
.45839 .71666 L
s
.51962 1.08334 m .5168 1.05758 L .51663 1.06613 L 0 .214 .237 r
F
0 g
.51339 1.06375 m
.51663 1.06613 L
s
.51962 1.08334 m .52043 1.06126 L .5168 1.05758 L 0 .214 .237 r
F
0 g
.51342 1.04292 m
.5168 1.05758 L
s
.57105 1.07413 m .57681 1.0521 L .57126 1.03792 L 0 .333 .247 r
F
0 g
.56883 1.01715 m
.57126 1.03792 L
s
.5891 .78374 m .60032 .78829 L .61002 .78813 L 0 1 .459 r
F
0 g
.60032 .78829 m
.60745 .79542 L
s
.28994 .91804 m
.29244 .91787 L
s
.28994 .91804 m
.29801 .9229 L
s
.62144 .78318 m .64273 .78761 L .64492 .78295 L 0 1 .464 r
F
.62144 .78318 m .63267 .78771 L .64273 .78761 L F
0 g
.64273 .78761 m
.64905 .79442 L
s
.63267 .78771 m
.64273 .78761 L
s
.63267 .78771 m
.63945 .79474 L
s
.53376 .70709 m .54698 .70606 L .5574 .70139 L 0 1 .461 r
F
0 g
.54698 .70606 m
.55636 .70937 L
s
.53376 .70709 m .5574 .70139 L .55809 .69619 L 0 1 .461 r
F
0 g
.5574 .70139 m
.56661 .70437 L
s
.54698 .70606 m
.5574 .70139 L
s
.50159 .74511 m .49178 .73614 L .49214 .74007 L 0 1 .491 r
F
.50159 .74511 m .50108 .73511 L .49178 .73614 L F
0 g
.48331 .74156 m
.49214 .74007 L
s
.50159 .74511 m .51386 .73769 L .50108 .73511 L 0 1 .491 r
F
.50159 .74511 m .52333 .74273 L .51386 .73769 L F
.50159 .74511 m .52316 .74688 L .52333 .74273 L F
.50159 .74511 m .51383 .74789 L .52316 .74688 L F
0 g
.49268 .74599 m
.50159 .74511 L
s
.49214 .74007 m
.50159 .74511 L
s
.65486 .78281 m .65042 .77161 L .64822 .7761 L 0 1 .473 r
F
.65486 .78281 m .6607 .77165 L .65042 .77161 L F
.65486 .78281 m .67219 .77619 L .6607 .77165 L F
0 g
.67219 .77619 m
.68278 .7764 L
s
.67219 .77619 m
.6788 .7829 L
s
.41227 .70966 m
.42303 .71187 L
s
.5891 .78374 m .58281 .77226 L .58159 .77687 L 0 1 .459 r
F
.5891 .78374 m .59251 .7721 L .58281 .77226 L F
.5891 .78374 m .60423 .77649 L .59251 .7721 L F
.5891 .78374 m .61173 .78336 L .60423 .77649 L F
.5891 .78374 m .61002 .78813 L .61173 .78336 L F
0 g
.57978 .78389 m
.5891 .78374 L
s
.61002 .78813 m
.61681 .79517 L
s
.60032 .78829 m
.61002 .78813 L
s
.5605 .77291 m .55307 .76202 L .55237 .76643 L 0 1 .466 r
F
0 g
.54307 .76694 m
.55237 .76643 L
s
.5605 .77291 m .56263 .76173 L .55307 .76202 L 0 1 .466 r
F
.5605 .77291 m .57468 .76577 L .56263 .76173 L F
.5605 .77291 m .58281 .77226 L .57468 .76577 L F
.5605 .77291 m .58159 .77687 L .58281 .77226 L F
.5605 .77291 m .57203 .77715 L .58159 .77687 L F
0 g
.58159 .77687 m
.5891 .78374 L
s
.55133 .77311 m
.5605 .77291 L
s
.55237 .76643 m
.5605 .77291 L
s
.57203 .77715 m
.57978 .78389 L
s
.46937 .73014 m .45834 .72234 L .45923 .72606 L 0 1 .504 r
F
.46937 .73014 m .46754 .72069 L .45834 .72234 L F
0 g
.45062 .72825 m
.45923 .72606 L
s
.46937 .73014 m .48071 .72223 L .46754 .72069 L 0 1 .504 r
F
.46937 .73014 m .49087 .72633 L .48071 .72223 L F
0 g
.48321 .72324 m
.49128 .71932 L
s
.46937 .73014 m .49124 .73025 L .49087 .72633 L 0 1 .504 r
F
.46937 .73014 m .48201 .73188 L .49124 .73025 L F
0 g
.46057 .73164 m
.46937 .73014 L
s
.45923 .72606 m
.46937 .73014 L
s
.68483 1.23905 m .69097 1.18684 L .68711 1.21304 L 0 1 .129 r
F
.6805 1.18311 m .68711 1.21304 L .69097 1.18684 L 0 1 .228 r
F
0 g
.69097 1.18684 m
.69143 1.18543 L
s
.69097 1.18684 m
.69102 1.1854 L
s
.56873 .69135 m .55983 .68351 L .55914 .68852 L 0 1 .467 r
F
.56873 .69135 m .57086 .67883 L .55983 .68351 L F
.56873 .69135 m .58485 .67761 L .57086 .67883 L F
0 g
.58485 .67761 m
.59441 .68044 L
s
.6688 .8458 m .66641 .83844 L .66388 .84798 L 0 1 .211 r
F
.66224 .87186 m .6688 .8458 L .66011 .86314 L 0 1 .202 r
F
0 g
.57203 .77715 m
.58159 .77687 L
s
.6607 .77165 m .68544 .77215 L .6785 .7655 L 0 1 .48 r
F
0 g
.68544 .77215 m
.68998 .77228 L
s
.59379 1.01947 m
.59758 1.01129 L
s
.59758 1.01129 m
.59848 1.00936 L
s
.52998 1.14217 m .53027 1.15155 L .52902 1.14133 L 0 .748 .067 r
F
0 g
.52675 1.12896 m
.52902 1.14133 L
s
.52998 1.14217 m .53316 1.16944 L .53027 1.15155 L 0 .748 .067 r
F
.53316 1.16944 m .53306 1.16894 L .53027 1.15155 L F
.5332 1.16986 m .53313 1.16947 L .53299 1.16858 L F
.53306 1.16894 m .53299 1.16858 L .53027 1.15155 L F
.5332 1.16986 m .53299 1.16858 L .53306 1.16894 L F
.52577 1.13333 m .52887 1.14812 L .52927 1.14972 L 0 0 .09 r
F
.53324 1.17019 m .53284 1.16812 L .53027 1.15155 L 0 .748 .067 r
F
.52777 1.14216 m .52927 1.14972 L .53213 1.16133 L 0 0 .09 r
F
.52577 1.13333 m .52927 1.14972 L .52777 1.14216 L F
.53316 1.16944 m .53656 1.18989 L .53349 1.17235 L 0 .748 .067 r
F
.52998 1.14217 m .53524 1.18036 L .53316 1.16944 L F
.53524 1.18036 m .53656 1.18989 L .53316 1.16944 L F
.52998 1.14217 m .53751 1.19069 L .53656 1.18989 L F
.52789 1.14191 m .53213 1.16133 L .53337 1.16411 L 0 0 .09 r
F
.52708 1.13866 m .52837 1.14444 L .52789 1.14191 L F
.52837 1.14444 m .53213 1.16133 L .52789 1.14191 L F
.52577 1.13333 m .52777 1.14216 L .52708 1.13866 L F
.52777 1.14216 m .53213 1.16133 L .52708 1.13866 L F
.53316 1.16944 m .5332 1.16986 L .53306 1.16894 L 0 .748 .067 r
F
.5332 1.16986 m .53324 1.17019 L .53313 1.16947 L F
.52658 1.13607 m .53337 1.16411 L .53156 1.15297 L 0 0 .09 r
F
.52577 1.13333 m .52708 1.13866 L .52658 1.13607 L F
.52708 1.13866 m .53337 1.16411 L .52658 1.13607 L F
.5261 1.13365 m .53156 1.15297 L .52792 1.13541 L F
.52577 1.13333 m .52658 1.13607 L .5261 1.13365 L F
.52658 1.13607 m .53156 1.15297 L .5261 1.13365 L F
.53324 1.17019 m .53349 1.17235 L .53284 1.16812 L 0 .748 .067 r
F
.52998 1.14217 m .53572 1.17425 L .53751 1.19069 L F
.52998 1.14217 m .53249 1.15349 L .53572 1.17425 L F
0 g
.52943 1.13829 m
.52998 1.14217 L
s
.52917 1.14146 m
.52998 1.14217 L
s
.53249 1.15349 m
.53305 1.14616 L
s
.53305 1.14616 m
.53389 1.15268 L
s
.53389 1.15268 m
.53563 1.16617 L
s
.56512 1.0758 m .57482 1.13488 L .57752 1.13253 L 0 .178 .202 r
F
0 g
.57587 1.13396 m
.57598 1.13966 L
s
.56512 1.0758 m .56949 1.11044 L .57482 1.13488 L 0 .178 .202 r
F
0 g
.57458 1.13378 m
.57644 1.1657 L
s
.56678 1.10623 m
.56711 1.11007 L
s
.56639 1.10164 m
.56678 1.10623 L
s
.56147 1.05074 m
.56512 1.0758 L
s
.56354 1.05006 m
.56512 1.0758 L
s
.62144 .78318 m .64492 .78295 L .6378 .7761 L 0 1 .464 r
F
0 g
.64492 .78295 m
.65486 .78281 L
s
.309 .81251 m .29542 .80591 L .29865 .80964 L 0 .861 .471 r
F
0 g
.2939 .81279 m
.29865 .80964 L
s
.59891 1.00945 m
.59991 1.00966 L
s
.59848 1.00936 m
.59891 1.00945 L
s
.51383 .74789 m
.5229 .75312 L
s
.51881 1.09741 m .5238 1.09779 L .51962 1.08334 L 0 .062 .169 r
F
.51881 1.09741 m .52642 1.11276 L .5238 1.09779 L F
.51881 1.09741 m .52572 1.11821 L .52642 1.11276 L F
.51881 1.09741 m .52246 1.11161 L .52572 1.11821 L F
0 g
.51596 1.08809 m
.51881 1.09741 L
s
.51621 1.08253 m
.51881 1.09741 L
s
.53376 .70709 m .52415 .6989 L .52398 .70402 L 0 1 .461 r
F
.53376 .70709 m .53458 .69422 L .52415 .6989 L F
.53376 .70709 m .54832 .69311 L .53458 .69422 L F
.53376 .70709 m .55809 .69619 L .54832 .69311 L F
0 g
.52372 .71185 m
.53376 .70709 L
s
.55809 .69619 m
.56873 .69135 L
s
.56318 1.24138 m
.5632 1.24172 L
s
.56277 1.23566 m
.56318 1.24138 L
s
.52123 1.03442 m .53153 1.03256 L .52774 1.0154 L 0 .421 .287 r
F
.52123 1.03442 m .53086 1.04549 L .53153 1.03256 L F
.52123 1.03442 m .52643 1.04628 L .53086 1.04549 L F
.52043 1.06126 m .52643 1.04628 L .52123 1.03442 L 0 .299 .268 r
F
0 g
.51747 1.01729 m
.52123 1.03442 L
s
.51722 1.03323 m
.52123 1.03442 L
s
.53628 1.03164 m .53316 1.00096 L .53252 1.01347 L 0 .59 .29 r
F
.53628 1.03164 m .53824 .99846 L .53316 1.00096 L F
0 g
.52899 .98548 m
.53316 1.00096 L
s
.4676 .71217 m .45618 .70462 L .45707 .70939 L 0 1 .469 r
F
.4676 .71217 m .46578 .70009 L .45618 .70462 L F
0 g
.45209 .71187 m
.45707 .70939 L
s
.4676 .71217 m .47948 .69883 L .46578 .70009 L 0 1 .469 r
F
.4676 .71217 m .49002 .70161 L .47948 .69883 L F
.4676 .71217 m .49038 .70659 L .49002 .70161 L F
.4676 .71217 m .48077 .71111 L .49038 .70659 L F
0 g
.45839 .71666 m
.4676 .71217 L
s
.45707 .70939 m
.4676 .71217 L
s
.66417 1.34846 m .67364 1.27217 L .6748 1.2879 L 0 .239 .159 r
F
0 g
.67139 1.27293 m
.67364 1.27217 L
s
.62144 .78318 m .61602 .77173 L .6143 .77634 L 0 1 .464 r
F
.62144 .78318 m .6261 .77163 L .61602 .77173 L F
.62144 .78318 m .6378 .7761 L .6261 .77163 L F
0 g
.61173 .78336 m
.62144 .78318 L
s
.43207 .70361 m .41957 .697 L .42098 .70141 L 0 1 .482 r
F
0 g
.41835 .7028 m
.42098 .70141 L
s
.48077 .71111 m
.49092 .71417 L
s
.43207 .70361 m .42894 .69242 L .41957 .697 L 0 1 .482 r
F
.43207 .70361 m .44285 .69071 L .42894 .69242 L F
.43207 .70361 m .45396 .69292 L .44285 .69071 L F
.43207 .70361 m .45485 .69756 L .45396 .69292 L F
.43207 .70361 m .44546 .70214 L .45485 .69756 L F
0 g
.42308 .7081 m
.43207 .70361 L
s
.42098 .70141 m
.43207 .70361 L
s
.52774 1.0154 m
.53252 1.01347 L
s
.55663 .98398 m .56309 .99104 L .56906 .985 L 0 .853 .301 r
F
0 g
.55259 .96909 m
.55663 .98398 L
s
.55351 1.02212 m .55663 .98399 L .55095 .98944 L 0 .754 .29 r
F
.55351 1.02212 m .56309 .99105 L .55663 .98399 L F
0 g
.448 .71909 m
.45834 .72234 L
s
.31676 .82252 m .31961 .81262 L .309 .81251 L 0 .783 .459 r
F
.31676 .82252 m .32971 .81608 L .31961 .81262 L F
.31676 .82252 m .33253 .82058 L .32971 .81608 L F
.31676 .82252 m .32696 .82334 L .33253 .82058 L F
0 g
.30673 .81906 m
.31676 .82252 L
s
.31156 .8248 m
.31676 .82252 L
s
.58224 1.02326 m .59393 1.04652 L .59635 1.0311 L 0 .641 .28 r
F
.58224 1.02326 m .58787 1.04314 L .59393 1.04652 L F
.57681 1.0521 m .58787 1.04314 L .58224 1.02326 L 0 .508 .266 r
F
0 g
.57958 1.00055 m
.58224 1.02326 L
s
.5765 1.01569 m
.58224 1.02326 L
s
.28045 .90997 m
.28317 .90912 L
s
.28045 .90997 m
.28873 .9144 L
s
.53824 .99846 m .54984 1.00378 L .55095 .98944 L 0 .693 .301 r
F
.53824 .99846 m .54439 1.00765 L .54984 1.00378 L F
.53628 1.03164 m .54439 1.00765 L .53824 .99846 L 0 .59 .29 r
F
0 g
.53413 .98249 m
.53824 .99846 L
s
.53316 1.00096 m
.53824 .99846 L
s
.66056 1.28751 m
.66116 1.28797 L
s
.65866 1.31734 m
.66056 1.28751 L
s
.309 .81251 m .30122 .80271 L .29542 .80591 L 0 .861 .471 r
F
0 g
.28554 .80398 m
.29542 .80591 L
s
.56309 .99104 m
.56906 .985 L
s
.48201 .73188 m
.49178 .73614 L
s
.50061 .70958 m .51389 .70859 L .52398 .70402 L 0 1 .464 r
F
0 g
.51389 .70859 m
.52372 .71185 L
s
.66657 .76087 m .68943 .76588 L .69094 .76355 L 0 1 .486 r
F
.66657 .76087 m .6785 .7655 L .68943 .76588 L F
.66715 .78444 m .68947 .76731 L .69094 .76355 L 0 1 .368 r
F
.66657 .76087 m .69096 .76173 L .68484 .75514 L 0 1 .486 r
F
.69096 .76173 m .69096 .7635 L .69207 .76067 L 0 1 .368 r
F
.66657 .76087 m .69094 .76355 L .69096 .76173 L 0 1 .486 r
F
.66715 .78444 m .69096 .76173 L .68499 .76053 L 0 1 .368 r
F
.69096 .76173 m .69207 .76067 L .69087 .76065 L F
.69096 .76173 m .69087 .76065 L .68484 .75514 L 0 1 .486 r
F
.69096 .76173 m .69087 .76065 L .68499 .76053 L 0 1 .368 r
F
.69096 .76173 m .69096 .76073 L .69087 .76065 L 0 1 .486 r
F
.69096 .76173 m .6921 .76177 L .69096 .76073 L F
.69096 .76173 m .69094 .76355 L .69096 .7635 L 0 1 .368 r
F
.66715 .78444 m .69094 .76355 L .69096 .76173 L F
.69096 .76173 m .69094 .76355 L .6921 .76177 L 0 1 .486 r
F
0 g
.6921 .76177 m
.70272 .76231 L
s
.68443 .77118 m
.68544 .77215 L
s
.40844 .6952 m
.41957 .697 L
s
.50061 .70958 m .49002 .70161 L .49038 .70659 L 0 1 .464 r
F
.50061 .70958 m .50011 .69703 L .49002 .70161 L F
0 g
.48077 .71111 m
.49038 .70659 L
s
.50061 .70958 m .51392 .6959 L .50011 .69703 L 0 1 .464 r
F
.50061 .70958 m .52415 .6989 L .51392 .6959 L F
0 g
.52449 .70418 m
.53376 .70709 L
s
.50061 .70958 m .52398 .70402 L .52415 .6989 L 0 1 .464 r
F
0 g
.52398 .70402 m
.52449 .70418 L
s
.49038 .70659 m
.50061 .70958 L
s
.49092 .71417 m
.50061 .70958 L
s
.51389 .70859 m
.52398 .70402 L
s
.55351 1.02212 m .55095 .98944 L .54984 1.00378 L 0 .754 .29 r
F
0 g
.54682 .97347 m
.55095 .98944 L
s
.55095 .98944 m
.55663 .98399 L
s
.6261 .77163 m .64822 .7761 L .65042 .77161 L 0 1 .472 r
F
.6261 .77163 m .6378 .7761 L .64822 .7761 L F
0 g
.64822 .7761 m
.65486 .78281 L
s
.6378 .7761 m
.64822 .7761 L
s
.6378 .7761 m
.64492 .78295 L
s
.66146 .80321 m .68559 .77767 L .67882 .77748 L 0 1 .354 r
F
0 g
.68375 .78976 m
.68868 .78295 L
s
.68462 .78428 m
.68869 .78284 L
s
.68674 .77627 m
.68997 .77228 L
s
.66146 .80321 m .68301 .78485 L .68559 .77767 L 0 1 .354 r
F
0 g
.68559 .77767 m
.68674 .77627 L
s
.68034 .79447 m
.68375 .78976 L
s
.67827 .80326 m
.68207 .80175 L
s
.38272 .90767 m .37154 .89307 L .37429 .89935 L 0 .407 .366 r
F
0 g
.3705 .89961 m
.37429 .89935 L
s
.66146 .80321 m .67269 .79578 L .68301 .78485 L 0 1 .354 r
F
0 g
.68301 .78485 m
.68462 .78428 L
s
.53219 .75259 m .52333 .74273 L .52316 .74688 L 0 1 .481 r
F
0 g
.51383 .74789 m
.52316 .74688 L
s
.53219 .75259 m .53302 .7421 L .52333 .74273 L 0 1 .481 r
F
.53219 .75259 m .54577 .7454 L .53302 .7421 L F
.53219 .75259 m .55482 .75113 L .54577 .7454 L F
.53219 .75259 m .55412 .75546 L .55482 .75113 L F
.53219 .75259 m .54442 .75609 L .55412 .75546 L F
0 g
.5229 .75312 m
.53219 .75259 L
s
.52316 .74688 m
.53219 .75259 L
s
.59763 1.03862 m
.59969 1.03119 L
s
.59969 1.03119 m
.59994 1.03029 L
s
.59994 1.03029 m
.60008 1.02981 L
s
.60008 1.02981 m
.60168 1.02403 L
s
.67634 1.32011 m .68596 1.24737 L .68617 1.25092 L 0 0 .082 r
F
.67634 1.32011 m .68279 1.26113 L .68596 1.24737 L F
0 g
.68596 1.24737 m
.68778 1.23715 L
s
.6834 1.25849 m
.68596 1.24737 L
s
.69207 .76067 m
.70232 .74943 L
s
.66715 .78444 m .67882 .77748 L .68947 .76731 L 0 1 .368 r
F
0 g
.68947 .76731 m
.6905 .76699 L
s
.54442 .75609 m
.55307 .76202 L
s
.61609 1.05905 m .61686 1.02278 L .61423 1.04034 L 0 1 .268 r
F
.60238 1.02974 m .61423 1.04034 L .61686 1.02278 L 0 .899 .284 r
F
0 g
.61686 1.02278 m
.62286 1.01202 L
s
.61531 1.01028 m
.61686 1.02278 L
s
.60899 1.03565 m
.60985 1.04529 L
s
.60985 1.04529 m
.61114 1.03757 L
s
.65888 1.31378 m
.66095 1.31141 L
s
.6607 .77165 m .65594 .76066 L .65373 .765 L 0 1 .48 r
F
.6607 .77165 m .66657 .76087 L .65594 .76066 L F
.6607 .77165 m .6785 .7655 L .66657 .76087 L F
0 g
.6576 .76869 m
.6607 .77165 L
s
.6785 .7655 m
.68012 .76705 L
s
.6785 .7655 m
.68121 .76559 L
s
.59251 .7721 m .60423 .77649 L .6143 .77634 L 0 1 .467 r
F
0 g
.60423 .77649 m
.61173 .78336 L
s
.69087 .76065 m
.69207 .76067 L
s
.38272 .90767 m .37616 .89159 L .37154 .89307 L 0 .407 .366 r
F
0 g
.36333 .88429 m
.37154 .89307 L
s
.56215 1.20852 m .56355 1.18763 L .56821 1.23201 L 0 .863 .2 r
F
0 g
.56341 1.22829 m
.56404 1.23808 L
s
.56287 1.22999 m
.56349 1.23778 L
s
.56624 1.17299 m
.56735 1.20641 L
s
.56322 1.18096 m
.56355 1.18763 L
s
.5726 1.00112 m .57882 1.00748 L .5849 .9987 L 0 .935 .288 r
F
0 g
.57882 1.00748 m
.5849 .9987 L
s
.5849 .9987 m
.58791 1.01535 L
s
.56906 .985 m
.5726 1.00112 L
s
.41957 .697 m
.42894 .69242 L
s
.53458 .69422 m .54832 .69311 L .55914 .68852 L 0 1 .468 r
F
0 g
.54832 .69311 m
.55809 .69619 L
s
.6558 .82356 m .67915 .7961 L .67269 .79578 L 0 1 .34 r
F
.6558 .82356 m .67659 .80393 L .67915 .7961 L F
0 g
.67399 .81433 m
.67625 .81081 L
s
.66866 .83448 m
.67135 .82974 L
s
.67135 .82974 m
.67541 .8226 L
s
.67198 .82408 m
.67541 .8226 L
s
.67915 .7961 m
.68034 .79447 L
s
.53458 .69422 m .55914 .68852 L .55983 .68351 L 0 1 .468 r
F
0 g
.55914 .68852 m
.56873 .69135 L
s
.54832 .69311 m
.55914 .68852 L
s
.44546 .70214 m
.45618 .70462 L
s
.61961 1.07393 m
.61963 1.07428 L
s
.55351 1.02212 m .56678 1.00936 L .56309 .99105 L 0 .754 .29 r
F
.6558 .82356 m .6666 .81568 L .67659 .80393 L 0 1 .34 r
F
0 g
.67652 .80401 m
.67659 .80393 L
s
.67659 .80393 m
.67827 .80326 L
s
.52043 1.06126 m .52984 1.06411 L .52643 1.04628 L 0 .299 .268 r
F
.52043 1.06126 m .52916 1.07601 L .52984 1.06411 L F
.52043 1.06126 m .52512 1.07477 L .52916 1.07601 L F
.51962 1.08334 m .52512 1.07477 L .52043 1.06126 L 0 .214 .237 r
F
0 g
.5168 1.05758 m
.52043 1.06126 L
s
.51705 1.04348 m
.52043 1.06126 L
s
.69096 .76073 m
.6921 .76177 L
s
.69087 .76065 m
.69096 .76073 L
s
.59251 .7721 m .6143 .77634 L .61602 .77173 L 0 1 .467 r
F
0 g
.6143 .77634 m
.62144 .78318 L
s
.60423 .77649 m
.6143 .77634 L
s
.37616 .89159 m .36464 .87823 L .36741 .88402 L 0 .466 .381 r
F
0 g
.36333 .88429 m
.36741 .88402 L
s
.61877 1.08545 m
.61963 1.07428 L
s
.56307 1.24754 m .57286 1.37008 L .56719 1.29741 L 0 0 .082 r
F
.56307 1.24754 m .56313 1.25235 L .56731 1.30242 L F
0 g
.56349 1.23778 m
.56486 1.25483 L
s
.56404 1.23808 m
.56508 1.254 L
s
.56223 1.24486 m
.56313 1.25235 L
s
.5627 1.24384 m
.56307 1.24754 L
s
.56317 1.26077 m
.5652 1.28 L
s
.5652 1.28 m
.56527 1.28066 L
s
.5632 1.24172 m
.5639 1.25141 L
s
.56342 1.26153 m
.56343 1.26169 L
s
.56343 1.26169 m
.56389 1.26623 L
s
.56286 1.25602 m
.56342 1.26153 L
s
.56389 1.26623 m
.56465 1.27383 L
s
.56424 1.26901 m
.56434 1.27007 L
s
.56389 1.26513 m
.56424 1.26901 L
s
.56305 1.25598 m
.56389 1.26513 L
s
.56307 1.24754 m
.56444 1.26421 L
s
.59251 .7721 m .58585 .76095 L .58463 .76544 L 0 1 .467 r
F
.59251 .7721 m .59593 .76079 L .58585 .76095 L F
.59251 .7721 m .60815 .76507 L .59593 .76079 L F
.59251 .7721 m .61602 .77173 L .60815 .76507 L F
0 g
.58281 .77226 m
.59251 .7721 L
s
.43199 .70952 m .41948 .70301 L .4209 .70656 L 0 1 .515 r
F
0 g
.41227 .70966 m
.4209 .70656 L
s
.51962 1.08334 m .52814 1.09205 L .52512 1.07477 L 0 .214 .237 r
F
.51962 1.08334 m .52745 1.10155 L .52814 1.09205 L F
.51962 1.08334 m .5238 1.09779 L .52745 1.10155 L F
0 g
.51663 1.06613 m
.51962 1.08334 L
s
.51638 1.07683 m
.51962 1.08334 L
s
.6261 .77163 m .65042 .77161 L .64295 .76491 L 0 1 .472 r
F
0 g
.65042 .77161 m
.6607 .77165 L
s
.66224 .87186 m .66011 .86314 L .6576 .87382 L 0 1 .202 r
F
.65574 .90148 m .66224 .87186 L .65386 .89091 L 0 1 .197 r
F
.37616 .89159 m .36958 .87666 L .36464 .87823 L 0 .466 .381 r
F
0 g
.35612 .87051 m
.36464 .87823 L
s
.27094 .90157 m
.27388 .90014 L
s
.27094 .90157 m
.27945 .90554 L
s
.65017 .84579 m .67276 .81624 L .6666 .81568 L 0 1 .326 r
F
.65017 .84579 m .67021 .82484 L .67276 .81624 L F
0 g
.66808 .83551 m
.66866 .83448 L
s
.67037 .82477 m
.67198 .82408 L
s
.67276 .81624 m
.67399 .81433 L
s
.43199 .70952 m .42883 .70053 L .41948 .70301 L 0 1 .515 r
F
.43199 .70952 m .44274 .70077 L .42883 .70053 L F
.43199 .70952 m .45386 .70374 L .44274 .70077 L F
.43199 .70952 m .45476 .70746 L .45386 .70374 L F
.43199 .70952 m .44537 .70993 L .45476 .70746 L F
0 g
.42303 .71187 m
.43199 .70952 L
s
.4209 .70656 m
.43199 .70952 L
s
.56263 .76173 m .55482 .75113 L .55412 .75546 L 0 1 .473 r
F
0 g
.54442 .75609 m
.55412 .75546 L
s
.56263 .76173 m .56477 .75079 L .55482 .75113 L 0 1 .473 r
F
.56263 .76173 m .57734 .75467 L .56477 .75079 L F
.56263 .76173 m .58585 .76095 L .57734 .75467 L F
.56263 .76173 m .58463 .76544 L .58585 .76095 L F
.56263 .76173 m .57468 .76577 L .58463 .76544 L F
0 g
.58463 .76544 m
.59251 .7721 L
s
.55307 .76202 m
.56263 .76173 L
s
.55412 .75546 m
.56263 .76173 L
s
.57468 .76577 m
.58281 .77226 L
s
.57468 .76577 m
.58463 .76544 L
s
.56395 1.26219 m
.5648 1.27233 L
s
.56313 1.25235 m
.56395 1.26219 L
s
.53458 .69422 m .52457 .6864 L .5244 .69135 L 0 1 .468 r
F
.53458 .69422 m .53541 .6818 L .52457 .6864 L F
.53458 .69422 m .54967 .68062 L .53541 .6818 L F
.53458 .69422 m .55983 .68351 L .54967 .68062 L F
0 g
.52415 .6989 m
.53458 .69422 L
s
.55983 .68351 m
.57086 .67883 L
s
.50108 .73511 m .49087 .72633 L .49124 .73025 L 0 1 .495 r
F
.50108 .73511 m .50058 .72518 L .49087 .72633 L F
0 g
.48201 .73188 m
.49124 .73025 L
s
.50108 .73511 m .51389 .72758 L .50058 .72518 L 0 1 .495 r
F
.50108 .73511 m .52376 .73246 L .51389 .72758 L F
.50108 .73511 m .52359 .73655 L .52376 .73246 L F
.50108 .73511 m .51386 .73769 L .52359 .73655 L F
0 g
.49178 .73614 m
.50108 .73511 L
s
.49124 .73025 m
.50108 .73511 L
s
.54967 .68062 m
.55983 .68351 L
s
.309 .81251 m .31223 .80216 L .30122 .80271 L 0 .861 .471 r
F
0 g
.29542 .80591 m
.30122 .80271 L
s
.309 .81251 m .32265 .80503 L .31223 .80216 L 0 .861 .471 r
F
.309 .81251 m .32548 .80941 L .32265 .80503 L F
.309 .81251 m .31961 .81262 L .32548 .80941 L F
0 g
.29865 .80964 m
.309 .81251 L
s
.3035 .81528 m
.309 .81251 L
s
.53249 1.15349 m
.5331 1.1574 L
s
.6261 .77163 m .62032 .76046 L .6186 .76493 L 0 1 .472 r
F
.6261 .77163 m .63077 .76045 L .62032 .76046 L F
.6261 .77163 m .64295 .76491 L .63077 .76045 L F
0 g
.61602 .77173 m
.6261 .77163 L
s
.67481 1.28789 m .68279 1.26113 L .67874 1.28315 L 0 .123 .117 r
F
.67634 1.32011 m .67874 1.28315 L .68279 1.26113 L 0 0 .082 r
F
0 g
.68279 1.26113 m
.68487 1.23902 L
s
.68279 1.26113 m
.6834 1.25849 L
s
.52577 1.13333 m .52467 1.12229 L .52397 1.12228 L 0 0 .09 r
F
0 g
.52193 1.11558 m
.52397 1.12228 L
s
.65017 .84579 m .66056 .83749 L .67021 .82484 L 0 1 .326 r
F
0 g
.66998 .82515 m
.67021 .82484 L
s
.67021 .82484 m
.67037 .82477 L
s
.66768 .8362 m
.66808 .83551 L
s
.40834 .70093 m
.41948 .70301 L
s
.36958 .87666 m .35771 .86446 L .36049 .86984 L 0 .537 .398 r
F
0 g
.35612 .87051 m
.36049 .86984 L
s
.46578 .70009 m .45396 .69292 L .45485 .69756 L 0 1 .475 r
F
.46578 .70009 m .46396 .68835 L .45396 .69292 L F
0 g
.44631 .70172 m
.45485 .69756 L
s
.46578 .70009 m .47818 .68691 L .46396 .68835 L 0 1 .475 r
F
.46578 .70009 m .48912 .68944 L .47818 .68691 L F
.46578 .70009 m .48948 .69427 L .48912 .68944 L F
.46578 .70009 m .47948 .69883 L .48948 .69427 L F
0 g
.45618 .70462 m
.46578 .70009 L
s
.45485 .69756 m
.46578 .70009 L
s
.46754 .72069 m .4561 .71303 L .457 .71675 L 0 1 .506 r
F
.46754 .72069 m .4657 .71126 L .4561 .71303 L F
0 g
.448 .71909 m
.457 .71675 L
s
.46754 .72069 m .4794 .71262 L .4657 .71126 L 0 1 .506 r
F
.46754 .72069 m .48996 .71657 L .4794 .71262 L F
.46754 .72069 m .49033 .72047 L .48996 .71657 L F
.46754 .72069 m .48071 .72223 L .49033 .72047 L F
0 g
.45834 .72234 m
.46754 .72069 L
s
.457 .71675 m
.46754 .72069 L
s
.53628 1.03164 m .54817 1.02583 L .54439 1.00765 L 0 .59 .29 r
F
0 g
.54439 1.00765 m
.54984 1.00378 L
s
.56842 1.04768 m .5726 1.00112 L .56678 1.00936 L 0 .828 .279 r
F
.56842 1.04768 m .57882 1.00749 L .5726 1.00112 L F
0 g
.47948 .69883 m
.49002 .70161 L
s
.51386 .73769 m
.52333 .74273 L
s
.57681 1.0521 m .59028 1.06998 L .58787 1.04314 L 0 .508 .266 r
F
.57681 1.0521 m .58785 1.08584 L .59028 1.06998 L F
.57681 1.0521 m .58206 1.07813 L .58785 1.08584 L F
.58278 1.07325 m .59379 1.01948 L .58791 1.01536 L 0 .922 .267 r
F
.5961 1.07389 m .59635 1.0311 L .59393 1.04652 L 0 .775 .269 r
F
.58278 1.07325 m .5965 1.04271 L .59379 1.01948 L 0 .922 .267 r
F
0 g
.59473 1.01745 m
.59635 1.0311 L
s
.36958 .87666 m .36297 .86267 L .35771 .86446 L 0 .537 .398 r
F
0 g
.34887 .8578 m
.35771 .86446 L
s
.50011 .69703 m .51392 .6959 L .5244 .69135 L 0 1 .471 r
F
0 g
.51392 .6959 m
.52415 .6989 L
s
.56849 1.12631 m .57065 1.12395 L .5678 1.10715 L 0 0 .084 r
F
0 g
.5678 1.10715 m
.56786 1.10873 L
s
.56802 1.11321 m
.56849 1.12631 L
s
.56786 1.10873 m
.56795 1.11113 L
s
.56795 1.11113 m
.56802 1.11321 L
s
.56475 1.08613 m
.5678 1.10715 L
s
.56711 1.11007 m
.56849 1.12631 L
s
.41948 .70301 m
.42883 .70053 L
s
.53422 1.06603 m .53153 1.03256 L .53086 1.04549 L 0 .468 .278 r
F
0 g
.52643 1.04628 m
.53086 1.04549 L
s
.53422 1.06603 m .53628 1.03165 L .53153 1.03256 L 0 .468 .278 r
F
0 g
.52774 1.0154 m
.53153 1.03256 L
s
.56842 1.04768 m .58204 1.02834 L .57882 1.00749 L 0 .828 .279 r
F
0 g
.57552 1.0376 m
.5768 1.05208 L
s
.5727 1.04161 m
.5768 1.0521 L
s
.50011 .69703 m .48912 .68944 L .48948 .69427 L 0 1 .471 r
F
.50011 .69703 m .49961 .68488 L .48912 .68944 L F
0 g
.47948 .69883 m
.48948 .69427 L
s
.50011 .69703 m .51395 .68362 L .49961 .68488 L 0 1 .471 r
F
.50011 .69703 m .52457 .6864 L .51395 .68362 L F
0 g
.52483 .69147 m
.53458 .69422 L
s
.50011 .69703 m .5244 .69135 L .52457 .6864 L 0 1 .471 r
F
0 g
.5244 .69135 m
.52483 .69147 L
s
.48948 .69427 m
.50011 .69703 L
s
.49002 .70161 m
.50011 .69703 L
s
.51392 .6959 m
.5244 .69135 L
s
.6272 1.05549 m
.62744 1.05771 L
s
.62744 1.05771 m
.62791 1.0622 L
s
.62791 1.0622 m
.62828 1.06572 L
s
.62093 1.1529 m .62828 1.06573 L .62287 1.09624 L 0 1 .208 r
F
0 g
.62505 1.08393 m
.62828 1.06573 L
s
.62471 1.182 m
.62472 1.15192 L
s
.63077 .76045 m .65373 .765 L .65594 .76066 L 0 1 .478 r
F
.63077 .76045 m .64295 .76491 L .65373 .765 L F
0 g
.65373 .765 m
.6576 .76869 L
s
.64295 .76491 m
.65042 .77161 L
s
.64295 .76491 m
.65373 .765 L
s
.6805 1.18311 m .6826 1.21146 L .68711 1.21304 L 0 1 .228 r
F
.67148 1.2765 m .6805 1.18311 L .67626 1.18969 L 0 1 .199 r
F
.66511 1.3905 m .67419 1.29511 L .67509 1.29958 L 0 0 .106 r
F
.66511 1.3905 m .67048 1.31356 L .67419 1.29511 L F
.66511 1.3905 m .66638 1.34283 L .67048 1.31356 L F
.66417 1.34846 m .6748 1.2879 L .67254 1.31999 L 0 .239 .159 r
F
.66511 1.3905 m .67509 1.29958 L .67283 1.33222 L 0 0 .106 r
F
.66511 1.3905 m .66407 1.37586 L .66638 1.34283 L F
.66417 1.34846 m .67254 1.31999 L .66833 1.34713 L 0 .239 .159 r
F
.66511 1.3905 m .67283 1.33222 L .66889 1.37166 L 0 0 .106 r
F
.66667 1.39904 m .66833 1.34713 L .67254 1.31999 L 0 .101 .125 r
F
.66594 1.39948 m .66833 1.34713 L .66667 1.39904 L F
.66594 1.39948 m .66561 1.38659 L .66833 1.34713 L F
.66643 1.3901 m .67385 1.25932 L .67056 1.29216 L 0 .865 .088 r
F
.66675 1.3906 m .67385 1.25932 L .66643 1.3901 L F
.66675 1.3906 m .67494 1.27901 L .67385 1.25932 L F
.67148 1.2765 m .6826 1.21146 L .6805 1.18311 L 0 1 .199 r
F
0 g
.6805 1.18311 m
.68181 1.14419 L
s
.60238 1.02974 m .60802 1.04334 L .61423 1.04034 L 0 .899 .284 r
F
0 g
.59991 1.00966 m
.60238 1.02974 L
s
.60011 1.03025 m
.60238 1.02974 L
s
.59994 1.03029 m
.60011 1.03025 L
s
.59749 1.03084 m
.59994 1.03029 L
s
.59635 1.0311 m
.59749 1.03084 L
s
.64459 .87028 m .66641 .83844 L .66056 .83749 L 0 1 .313 r
F
.64459 .87028 m .66388 .84798 L .66641 .83844 L F
0 g
.66641 .83844 m
.66768 .8362 L
s
.58278 1.07325 m .58791 1.01536 L .58204 1.02834 L 0 .922 .267 r
F
0 g
.6251 1.0593 m
.6272 1.05549 L
s
.62307 1.06298 m
.6251 1.0593 L
s
.6212 1.06636 m
.62307 1.06298 L
s
.26143 .89301 m
.26459 .89104 L
s
.26143 .89301 m
.27017 .8965 L
s
.66289 1.32313 m
.66302 1.32134 L
s
.66657 .76087 m .66148 .75003 L .65927 .75424 L 0 1 .486 r
F
.66657 .76087 m .67246 .75042 L .66148 .75003 L F
.66657 .76087 m .68484 .75514 L .67246 .75042 L F
0 g
.66341 .75801 m
.66657 .76087 L
s
.68484 .75514 m
.69087 .76065 L
s
.5768 1.05208 m
.57681 1.0521 L
s
.57105 1.07413 m .58206 1.07814 L .57681 1.0521 L 0 .333 .247 r
F
0 g
.5768 1.0521 m
.57681 1.0521 L
s
.52577 1.13333 m .52792 1.13541 L .52467 1.12229 L 0 0 .09 r
F
0 g
.52479 1.12798 m
.52577 1.13333 L
s
.52397 1.12228 m
.52577 1.13333 L
s
.52246 1.11161 m
.52268 1.11206 L
s
.52246 1.11161 m
.5231 1.11471 L
s
.5231 1.11471 m
.52467 1.12229 L
s
.36297 .86267 m .35075 .85152 L .35354 .8566 L 0 .613 .414 r
F
0 g
.34887 .8578 m
.35354 .8566 L
s
.44537 .70993 m
.4561 .71303 L
s
.59593 .76079 m .60815 .76507 L .6186 .76493 L 0 1 .474 r
F
0 g
.60815 .76507 m
.61602 .77173 L
s
.48071 .72223 m
.49087 .72633 L
s
.38272 .90767 m .38511 .89592 L .37616 .89159 L 0 .407 .366 r
F
.38272 .90767 m .39359 .90427 L .38511 .89592 L F
.38272 .90767 m .39591 .91105 L .39359 .90427 L F
.38272 .90767 m .39124 .9125 L .39591 .91105 L F
0 g
.37429 .89935 m
.38272 .90767 L
s
.59593 .76079 m .6186 .76493 L .62032 .76046 L 0 1 .474 r
F
0 g
.6186 .76493 m
.6261 .77163 L
s
.60815 .76507 m
.6186 .76493 L
s
.68483 1.23905 m .68569 1.24736 L .68933 1.23615 L 0 1 .129 r
F
0 g
.68866 1.2382 m
.68933 1.23615 L
s
.68802 1.24017 m
.68866 1.2382 L
s
.68888 1.23822 m
.68933 1.23615 L
s
.57061 1.30299 m
.5716 1.3082 L
s
.44285 .69071 m
.45396 .69292 L
s
.64459 .87028 m .65455 .86161 L .66388 .84798 L 0 1 .313 r
F
0 g
.65899 .85513 m
.66155 .85139 L
s
.66155 .85139 m
.66346 .84859 L
s
.66346 .84859 m
.66388 .84798 L
s
.66143 .86049 m
.6688 .8458 L
s
.66015 .86306 m
.66143 .86049 L
s
.66388 .84798 m
.6688 .8458 L
s
.45396 .69292 m
.46396 .68835 L
s
.53302 .7421 m .52376 .73246 L .52359 .73655 L 0 1 .486 r
F
0 g
.51386 .73769 m
.52359 .73655 L
s
.53302 .7421 m .53385 .73174 L .52376 .73246 L 0 1 .486 r
F
.53302 .7421 m .54713 .73488 L .53385 .73174 L F
.53302 .7421 m .55657 .74043 L .54713 .73488 L F
.53302 .7421 m .55587 .74469 L .55657 .74043 L F
.53302 .7421 m .54577 .7454 L .55587 .74469 L F
0 g
.52333 .74273 m
.53302 .7421 L
s
.52359 .73655 m
.53302 .7421 L
s
.54577 .7454 m
.55482 .75113 L
s
.36297 .86267 m .35633 .84944 L .35075 .85152 L 0 .613 .414 r
F
0 g
.3416 .84583 m
.35075 .85152 L
s
.63077 .76045 m .65594 .76066 L .64812 .75406 L 0 1 .478 r
F
0 g
.65594 .76066 m
.66657 .76087 L
s
.59593 .76079 m .5889 .74991 L .58768 .75429 L 0 1 .474 r
F
.59593 .76079 m .59937 .74977 L .5889 .74991 L F
.59593 .76079 m .61209 .75396 L .59937 .74977 L F
.59593 .76079 m .62032 .76046 L .61209 .75396 L F
0 g
.58585 .76095 m
.59593 .76079 L
s
.53628 1.03164 m .54706 1.04088 L .54817 1.02583 L 0 .59 .29 r
F
.53628 1.03164 m .54195 1.04337 L .54706 1.04088 L F
0 g
.53252 1.01347 m
.53628 1.03164 L
s
.53422 1.06603 m .54195 1.04338 L .53628 1.03165 L 0 .468 .278 r
F
0 g
.53153 1.03256 m
.53628 1.03165 L
s
.56842 1.04768 m .56678 1.00936 L .56523 1.02674 L 0 .828 .279 r
F
.55351 1.02212 m .56523 1.02674 L .56678 1.00936 L 0 .754 .29 r
F
0 g
.56309 .99105 m
.56678 1.00936 L
s
.56678 1.00936 m
.5726 1.00112 L
s
.37616 .89159 m .37896 .88036 L .36958 .87666 L 0 .466 .381 r
F
.37616 .89159 m .38777 .88796 L .37896 .88036 L F
.37616 .89159 m .3901 .89437 L .38777 .88796 L F
.37616 .89159 m .38511 .89592 L .3901 .89437 L F
0 g
.36741 .88402 m
.37616 .89159 L
s
.37154 .89307 m
.37616 .89159 L
s
.61423 1.04034 m
.61609 1.05905 L
s
.60802 1.04334 m
.61353 1.04068 L
s
.61353 1.04068 m
.61423 1.04034 L
s
.57105 1.07413 m .58149 1.12085 L .58408 1.10765 L 0 .333 .247 r
F
0 g
.58185 1.11903 m
.58289 1.18666 L
s
.57105 1.07413 m .57589 1.10639 L .58149 1.12085 L 0 .333 .247 r
F
0 g
.56919 1.04658 m
.57105 1.07413 L
s
.56577 1.0501 m
.57105 1.07413 L
s
.52457 .6864 m
.53541 .6818 L
s
.51395 .68362 m
.52457 .6864 L
s
.56477 .75079 m .57734 .75467 L .58768 .75429 L 0 1 .479 r
F
0 g
.57734 .75467 m
.58585 .76095 L
s
.63077 .76045 m .62465 .7495 L .62292 .75385 L 0 1 .478 r
F
.63077 .76045 m .63546 .74959 L .62465 .7495 L F
.63077 .76045 m .64812 .75406 L .63546 .74959 L F
0 g
.62032 .76046 m
.63077 .76045 L
s
.2519 .88437 m
.26087 .88739 L
s
.56477 .75079 m .55657 .74043 L .55587 .74469 L 0 1 .479 r
F
0 g
.54577 .7454 m
.55587 .74469 L
s
.56477 .75079 m .56692 .74005 L .55657 .74043 L 0 1 .479 r
F
.56477 .75079 m .58001 .7438 L .56692 .74005 L F
.56477 .75079 m .5889 .74991 L .58001 .7438 L F
.56477 .75079 m .58768 .75429 L .5889 .74991 L F
0 g
.55587 .74469 m
.56477 .75079 L
s
.55482 .75113 m
.56477 .75079 L
s
.58768 .75429 m
.59593 .76079 L
s
.57734 .75467 m
.58768 .75429 L
s
.66146 .80321 m .67882 .77748 L .66715 .78444 L 0 1 .354 r
F
0 g
.67882 .77748 m
.68559 .77767 L
s
.67882 .77748 m
.68947 .76731 L
s
.35633 .84944 m .34377 .83924 L .34656 .84408 L 0 .69 .429 r
F
0 g
.3416 .84583 m
.34656 .84408 L
s
.36958 .87666 m .37278 .86569 L .36297 .86267 L 0 .537 .398 r
F
.36958 .87666 m .38193 .87253 L .37278 .86569 L F
.36958 .87666 m .38427 .8786 L .38193 .87253 L F
.36958 .87666 m .37896 .88036 L .38427 .8786 L F
0 g
.36049 .86984 m
.36958 .87666 L
s
.36464 .87823 m
.36958 .87666 L
s
.6558 .82356 m .67269 .79578 L .66146 .80321 L 0 1 .34 r
F
0 g
.67269 .79578 m
.68301 .78485 L
s
.67269 .79578 m
.67915 .7961 L
s
.48912 .68944 m
.49961 .68488 L
s
.47818 .68691 m
.48912 .68944 L
s
.66715 .78444 m .68499 .76053 L .67288 .76702 L 0 1 .368 r
F
0 g
.68499 .76053 m
.69087 .76065 L
s
.63905 .8975 m .66011 .86314 L .65455 .86161 L 0 1 .301 r
F
0 g
.65833 .86265 m
.65969 .86303 L
s
.65969 .86303 m
.66003 .86312 L
s
.63905 .8975 m .6576 .87382 L .66011 .86314 L 0 1 .301 r
F
0 g
.66011 .86314 m
.66015 .86306 L
s
.66003 .86312 m
.66011 .86314 L
s
.67634 1.32011 m .68617 1.25092 L .68344 1.27601 L 0 0 .082 r
F
0 g
.68617 1.25092 m
.68888 1.23822 L
s
.50058 .72518 m .48996 .71657 L .49033 .72047 L 0 1 .498 r
F
.50058 .72518 m .50007 .71532 L .48996 .71657 L F
0 g
.48071 .72223 m
.49033 .72047 L
s
.50058 .72518 m .51392 .71756 L .50007 .71532 L 0 1 .498 r
F
.50058 .72518 m .52419 .72228 L .51392 .71756 L F
.50058 .72518 m .52402 .72634 L .52419 .72228 L F
.50058 .72518 m .51389 .72758 L .52402 .72634 L F
0 g
.49087 .72633 m
.50058 .72518 L
s
.49033 .72047 m
.50058 .72518 L
s
.65574 .90148 m .65386 .89091 L .65137 .903 L 0 1 .197 r
F
.64931 .93556 m .65574 .90148 L .64767 .92246 L 0 1 .194 r
F
.55351 1.02212 m .55953 1.03222 L .56523 1.02674 L 0 .754 .29 r
F
.55039 1.06247 m .55351 1.02212 L .54817 1.02583 L 0 .648 .28 r
F
.55039 1.06247 m .55953 1.03222 L .55351 1.02212 L F
0 g
.54984 1.00378 m
.55351 1.02212 L
s
.55039 1.06247 m .54817 1.02583 L .54706 1.04088 L 0 .648 .28 r
F
0 g
.54817 1.02583 m
.55351 1.02212 L
s
.54439 1.00765 m
.54817 1.02583 L
s
.63546 .74959 m .65927 .75424 L .66148 .75003 L 0 1 .484 r
F
.63546 .74959 m .64812 .75406 L .65927 .75424 L F
0 g
.65927 .75424 m
.66341 .75801 L
s
.64812 .75406 m
.65594 .76066 L
s
.64812 .75406 m
.65927 .75424 L
s
.35633 .84944 m .34966 .83682 L .34377 .83924 L 0 .69 .429 r
F
0 g
.33429 .83438 m
.34377 .83924 L
s
.65017 .84579 m .6666 .81568 L .6558 .82356 L 0 1 .326 r
F
0 g
.6666 .81568 m
.67652 .80401 L
s
.6666 .81568 m
.67276 .81624 L
s
.5238 1.09779 m
.52491 1.09893 L
s
.4657 .71126 m .45386 .70374 L .45476 .70746 L 0 1 .508 r
F
.4657 .71126 m .46385 .70185 L .45386 .70374 L F
0 g
.44537 .70993 m
.45476 .70746 L
s
.4657 .71126 m .47809 .70305 L .46385 .70185 L 0 1 .508 r
F
.4657 .71126 m .48905 .70686 L .47809 .70305 L F
.4657 .71126 m .48942 .71074 L .48905 .70686 L F
.4657 .71126 m .4794 .71262 L .48942 .71074 L F
0 g
.4561 .71303 m
.4657 .71126 L
s
.45476 .70746 m
.4657 .71126 L
s
.51389 .72758 m
.52376 .73246 L
s
.53215 1.09754 m .52984 1.06411 L .52916 1.07601 L 0 .328 .262 r
F
0 g
.52512 1.07477 m
.52916 1.07601 L
s
.53215 1.09754 m .53422 1.06603 L .52984 1.06411 L 0 .328 .262 r
F
0 g
.52643 1.04628 m
.52984 1.06411 L
s
.6869 1.21296 m
.68711 1.21304 L
s
.68674 1.21291 m
.6869 1.21296 L
s
.36297 .86267 m .36658 .85177 L .35633 .84944 L 0 .613 .414 r
F
.36297 .86267 m .37606 .85785 L .36658 .85177 L F
.36297 .86267 m .37841 .86363 L .37606 .85785 L F
.36297 .86267 m .37278 .86569 L .37841 .86363 L F
0 g
.35354 .8566 m
.36297 .86267 L
s
.35771 .86446 m
.36297 .86267 L
s
.59937 .74977 m .61209 .75396 L .62292 .75385 L 0 1 .48 r
F
0 g
.61209 .75396 m
.62032 .76046 L
s
.63905 .8975 m .6486 .88853 L .6576 .87382 L 0 1 .301 r
F
0 g
.65427 .87926 m
.65699 .87482 L
s
.65699 .87482 m
.6576 .87382 L
s
.6576 .87382 m
.66224 .87186 L
s
.65524 .88777 m
.66224 .87186 L
s
.65425 .89002 m
.65524 .88777 L
s
.53621 1.17071 m .53751 1.19069 L .53572 1.17425 L 0 .902 .093 r
F
0 g
.53572 1.17425 m
.53613 1.17136 L
s
.5331 1.1574 m
.53572 1.17425 L
s
.53621 1.17071 m .54066 1.21413 L .53751 1.19069 L 0 .902 .093 r
F
.54066 1.21413 m .54098 1.2173 L .54026 1.21178 L F
.54066 1.21413 m .54026 1.21178 L .53751 1.19069 L F
.54098 1.2173 m .54083 1.21633 L .54015 1.21111 L F
.54026 1.21178 m .54015 1.21111 L .53751 1.19069 L F
.54098 1.2173 m .54015 1.21111 L .54026 1.21178 L F
.53349 1.17235 m .53656 1.18989 L .53675 1.19086 L 0 0 .073 r
F
.54066 1.21413 m .54411 1.23919 L .54111 1.21852 L 0 .902 .093 r
F
.53621 1.17071 m .5426 1.22609 L .54066 1.21413 L F
.5426 1.22609 m .54411 1.23919 L .54066 1.21413 L F
.53506 1.18079 m .53675 1.19086 L .53755 1.19495 L 0 0 .073 r
F
.5366 1.18916 m .53755 1.19495 L .5402 1.20859 L F
.53506 1.18079 m .53755 1.19495 L .5366 1.18916 L F
.53349 1.17235 m .53675 1.19086 L .53506 1.18079 L F
.53621 1.17071 m .5446 1.2355 L .54411 1.23919 L 0 .902 .093 r
F
.53454 1.17772 m .5402 1.20859 L .54198 1.21594 L 0 0 .073 r
F
.53349 1.17235 m .53506 1.18079 L .53454 1.17772 L F
.53506 1.18079 m .5402 1.20859 L .53454 1.17772 L F
.53416 1.1754 m .54198 1.21594 L .5406 1.2048 L F
.53349 1.17235 m .53454 1.17772 L .53416 1.1754 L F
.53454 1.17772 m .54198 1.21594 L .53416 1.1754 L F
.54098 1.2173 m .54111 1.21852 L .54083 1.21633 L 0 .902 .093 r
F
.53621 1.17071 m .54224 1.21004 L .5446 1.2355 L F
.53621 1.17071 m .53866 1.18235 L .54224 1.21004 L F
0 g
.53563 1.16617 m
.53621 1.17071 L
s
.53613 1.17136 m
.53621 1.17071 L
s
.53866 1.18235 m
.53875 1.17008 L
s
.53875 1.17008 m
.54131 1.19146 L
s
.54131 1.19146 m
.54172 1.19484 L
s
.59937 .74977 m .62292 .75385 L .62465 .7495 L 0 1 .48 r
F
0 g
.62292 .75385 m
.63077 .76045 L
s
.61209 .75396 m
.62292 .75385 L
s
.58278 1.07325 m .58204 1.02834 L .58009 1.04986 L 0 .922 .267 r
F
.56842 1.04768 m .58009 1.04986 L .58204 1.02834 L 0 .828 .279 r
F
0 g
.58204 1.02834 m
.58791 1.01536 L
s
.57882 1.00749 m
.58204 1.02834 L
s
.34966 .83682 m .33675 .82745 L .33956 .83211 L 0 .763 .442 r
F
0 g
.33429 .83438 m
.33956 .83211 L
s
.63546 .74959 m .66148 .75003 L .65331 .7435 L 0 1 .484 r
F
0 g
.66148 .75003 m
.67246 .75042 L
s
.57612 1.33776 m
.57618 1.33817 L
s
.5716 1.3082 m
.57161 1.30823 L
s
.60916 1.12372 m .62287 1.09624 L .6212 1.06638 L 0 .952 .255 r
F
0 g
.6212 1.06638 m
.62232 1.08633 L
s
.62232 1.08633 m
.62279 1.09483 L
s
.64459 .87028 m .66056 .83749 L .65017 .84579 L 0 1 .313 r
F
0 g
.66056 .83749 m
.66998 .82515 L
s
.66056 .83749 m
.66641 .83844 L
s
.60916 1.12372 m .61609 1.05906 L .61023 1.0707 L 0 .952 .255 r
F
0 g
.61413 1.06295 m
.61609 1.05906 L
s
.61338 1.06442 m
.61413 1.06295 L
s
.5898 1.12185 m .5961 1.07389 L .59028 1.06998 L 0 .642 .257 r
F
.59636 1.09431 m .5965 1.04271 L .59422 1.0697 L 0 1 .25 r
F
.5898 1.12185 m .59028 1.06998 L .58785 1.08584 L 0 .642 .257 r
F
.58278 1.07325 m .59422 1.0697 L .5965 1.04271 L 0 .922 .267 r
F
0 g
.59379 1.01948 m
.5965 1.04271 L
s
.5965 1.04271 m
.59763 1.03862 L
s
.59937 .74977 m .59197 .73911 L .59074 .7434 L 0 1 .48 r
F
.59937 .74977 m .60282 .739 L .59197 .73911 L F
.59937 .74977 m .61604 .74314 L .60282 .739 L F
.59937 .74977 m .62465 .7495 L .61604 .74314 L F
0 g
.5889 .74991 m
.59937 .74977 L
s
.44274 .70077 m
.45386 .70374 L
s
.56523 1.02674 m
.56627 1.03358 L
s
.54195 1.04337 m
.54706 1.04088 L
s
.53422 1.06603 m .54535 1.06394 L .54195 1.04338 L 0 .468 .278 r
F
0 g
.4794 .71262 m
.48996 .71657 L
s
.67148 1.2765 m .67626 1.18969 L .67269 1.22701 L 0 1 .199 r
F
0 g
.67626 1.18969 m
.6805 1.18311 L
s
.67626 1.18969 m
.67634 1.12224 L
s
.52792 1.13541 m .52642 1.11276 L .52572 1.11821 L 0 .074 .17 r
F
0 g
.52268 1.11206 m
.52572 1.11821 L
s
.53385 .73174 m .52419 .72228 L .52402 .72634 L 0 1 .49 r
F
0 g
.51389 .72758 m
.52402 .72634 L
s
.53385 .73174 m .53468 .72149 L .52419 .72228 L 0 1 .49 r
F
.53385 .73174 m .5485 .7245 L .53468 .72149 L F
.53385 .73174 m .55834 .72991 L .5485 .7245 L F
.53385 .73174 m .55763 .7341 L .55834 .72991 L F
.53385 .73174 m .54713 .73488 L .55763 .7341 L F
0 g
.52376 .73246 m
.53385 .73174 L
s
.52402 .72634 m
.53385 .73174 L
s
.54713 .73488 m
.55657 .74043 L
s
.34966 .83682 m .34297 .82469 L .33675 .82745 L 0 .763 .442 r
F
0 g
.32696 .82334 m
.33675 .82745 L
s
.45386 .70374 m
.46385 .70185 L
s
.63546 .74959 m .62899 .73882 L .62725 .74306 L 0 1 .484 r
F
.63546 .74959 m .64017 .73901 L .62899 .73882 L F
.63546 .74959 m .65331 .7435 L .64017 .73901 L F
0 g
.63051 .74566 m
.63546 .74959 L
s
.65331 .7435 m
.66148 .75003 L
s
.62465 .7495 m
.63546 .74959 L
s
.52927 1.14972 m
.52978 1.15181 L
s
.52887 1.14812 m
.52927 1.14972 L
s
.35633 .84944 m .36036 .83846 L .34966 .83682 L 0 .69 .429 r
F
.35633 .84944 m .37018 .84384 L .36036 .83846 L F
.35633 .84944 m .37253 .84937 L .37018 .84384 L F
.35633 .84944 m .36658 .85177 L .37253 .84937 L F
0 g
.34656 .84408 m
.35633 .84944 L
s
.35075 .85152 m
.35633 .84944 L
s
.56692 .74005 m .58001 .7438 L .59074 .7434 L 0 1 .484 r
F
0 g
.58001 .7438 m
.5889 .74991 L
s
.55039 1.06247 m .5629 1.05379 L .55953 1.03222 L 0 .648 .28 r
F
0 g
.55953 1.03222 m
.56523 1.02674 L
s
.56692 .74005 m .55834 .72991 L .55763 .7341 L 0 1 .484 r
F
0 g
.54713 .73488 m
.55763 .7341 L
s
.56692 .74005 m .56908 .7295 L .55834 .72991 L 0 1 .484 r
F
.56692 .74005 m .58269 .73315 L .56908 .7295 L F
.56692 .74005 m .59197 .73911 L .58269 .73315 L F
.56692 .74005 m .59074 .7434 L .59197 .73911 L F
0 g
.55763 .7341 m
.56692 .74005 L
s
.55657 .74043 m
.56692 .74005 L
s
.59074 .7434 m
.59937 .74977 L
s
.58001 .7438 m
.59074 .7434 L
s
.67148 1.2765 m .68146 1.2606 L .6826 1.21146 L 0 1 .199 r
F
0 g
.6826 1.21146 m
.68674 1.21291 L
s
.62786 1.17104 m
.62845 1.15812 L
s
.62845 1.15812 m
.62895 1.14703 L
s
.62895 1.14703 m
.63001 1.1238 L
s
.56905 1.3785 m .56215 1.20852 L .56908 1.37851 L 0 .863 .2 r
F
0 g
.56434 1.27007 m
.5649 1.27616 L
s
.56905 1.3785 m .56451 1.29052 L .56215 1.20852 L 0 .863 .2 r
F
.56908 1.37851 m .56215 1.20852 L .57137 1.37903 L F
.57524 1.39809 m .57286 1.37008 L .57514 1.39862 L 0 0 .1 r
F
.57137 1.37903 m .56215 1.20852 L .57434 1.37968 L 0 .863 .2 r
F
.57434 1.37968 m .56215 1.20852 L .57313 1.31377 L F
0 g
.57323 1.31882 m
.5735 1.3206 L
s
.56735 1.20641 m
.5674 1.20781 L
s
.56215 1.20852 m .56821 1.23201 L .57313 1.31377 L 0 .863 .2 r
F
0 g
.56355 1.18763 m
.56821 1.23201 L
s
.5674 1.20781 m
.56821 1.23201 L
s
.55795 1.1879 m
.56215 1.20852 L
s
.52792 1.13541 m .53005 1.12223 L .52642 1.11276 L 0 .074 .17 r
F
0 g
.5238 1.09779 m
.52642 1.11276 L
s
.53005 1.12223 m .52814 1.09205 L .52745 1.10155 L 0 .233 .235 r
F
0 g
.52491 1.09893 m
.52745 1.10155 L
s
.53005 1.12223 m .53215 1.09754 L .52814 1.09205 L 0 .233 .235 r
F
0 g
.52512 1.07477 m
.52814 1.09205 L
s
.53422 1.06603 m .54418 1.07963 L .54535 1.06394 L 0 .468 .278 r
F
.53422 1.06603 m .5394 1.08051 L .54418 1.07963 L F
.53215 1.09754 m .5394 1.08051 L .53422 1.06603 L 0 .328 .262 r
F
0 g
.53086 1.04549 m
.53422 1.06603 L
s
.52984 1.06411 m
.53422 1.06603 L
s
.63356 .92803 m .65386 .89091 L .6486 .88853 L 0 1 .29 r
F
.63356 .92803 m .65137 .903 L .65386 .89091 L F
0 g
.65386 .89091 m
.65425 .89002 L
s
.56949 1.11044 m
.57178 1.12095 L
s
.57178 1.12095 m
.57207 1.12228 L
s
.56949 1.11044 m
.56984 1.11455 L
s
.56984 1.11455 m
.57065 1.12395 L
s
.34297 .82469 m .32971 .81608 L .33253 .82058 L 0 .83 .453 r
F
0 g
.32696 .82334 m
.33253 .82058 L
s
.67634 1.32011 m .67596 1.30846 L .67874 1.28315 L 0 0 .082 r
F
0 g
.67481 1.28789 m
.67874 1.28315 L
s
.63905 .8975 m .65455 .86161 L .64459 .87028 L 0 1 .301 r
F
0 g
.65326 .89063 m
.65386 .89091 L
s
.65176 .88996 m
.65326 .89063 L
s
.65123 .88972 m
.65176 .88996 L
s
.65455 .86161 m
.65833 .86265 L
s
.65455 .86161 m
.65899 .85513 L
s
.65215 .88272 m
.65427 .87926 L
s
.50007 .71532 m .48905 .70686 L .48942 .71074 L 0 1 .501 r
F
.50007 .71532 m .49956 .70552 L .48905 .70686 L F
0 g
.4794 .71262 m
.48942 .71074 L
s
.50007 .71532 m .51395 .70762 L .49956 .70552 L 0 1 .501 r
F
.50007 .71532 m .52462 .71221 L .51395 .70762 L F
.50007 .71532 m .52445 .71623 L .52462 .71221 L F
.50007 .71532 m .51392 .71756 L .52445 .71623 L F
0 g
.48996 .71657 m
.50007 .71532 L
s
.48942 .71074 m
.50007 .71532 L
s
.60282 .739 m .61604 .74314 L .62725 .74306 L 0 1 .485 r
F
0 g
.61604 .74314 m
.62465 .7495 L
s
.34966 .83682 m .35411 .82568 L .34297 .82469 L 0 .763 .442 r
F
.34966 .83682 m .36427 .8304 L .35411 .82568 L F
.34966 .83682 m .36663 .83571 L .36427 .8304 L F
.34966 .83682 m .36036 .83846 L .36663 .83571 L F
0 g
.33956 .83211 m
.34966 .83682 L
s
.34377 .83924 m
.34966 .83682 L
s
.34297 .82469 m .33625 .81297 L .32971 .81608 L 0 .83 .453 r
F
0 g
.31961 .81262 m
.32971 .81608 L
s
.60282 .739 m .62725 .74306 L .62899 .73882 L 0 1 .485 r
F
0 g
.62725 .74306 m
.63051 .74566 L
s
.61604 .74314 m
.62725 .74306 L
s
.51392 .71756 m
.52419 .72228 L
s
.53866 1.18235 m
.53917 1.18634 L
s
.55391 1.20734 m
.55399 1.20936 L
s
.67634 1.32011 m .68344 1.27601 L .67955 1.30614 L 0 0 .082 r
F
.66776 1.39912 m .67083 1.36115 L .66789 1.39844 L 0 0 .051 r
F
.66776 1.39912 m .67283 1.33222 L .67392 1.32033 L F
.66776 1.39912 m .67392 1.32033 L .67209 1.3445 L F
.66776 1.39912 m .67458 1.31313 L .67135 1.35475 L F
.67083 1.36115 m .67001 1.37203 L .66789 1.39844 L F
.66789 1.39844 m .67001 1.37203 L .66879 1.38679 L F
.66851 1.3897 m .66865 1.38844 L .66835 1.39184 L 0 .101 .125 r
F
.66789 1.39844 m .66879 1.38679 L .66789 1.3979 L 0 0 .051 r
F
.66899 1.38546 m .66858 1.39085 L .66808 1.39547 L 0 .101 .125 r
F
.66831 1.39261 m .66808 1.39547 L .66781 1.3979 L F
.66879 1.38679 m .66808 1.39547 L .66789 1.3979 L 0 0 .051 r
F
.66899 1.38546 m .66808 1.39547 L .66831 1.39261 L 0 .101 .125 r
F
.67209 1.3445 m .67392 1.32033 L .67458 1.31313 L 0 0 .051 r
F
.66733 1.40001 m .67283 1.33222 L .66776 1.39912 L F
.66733 1.40001 m .66889 1.37166 L .67283 1.33222 L F
.66662 1.40148 m .66889 1.37166 L .66733 1.40001 L F
.66716 1.39874 m .67254 1.31999 L .67458 1.31313 L 0 .101 .125 r
F
.66716 1.39874 m .67458 1.31313 L .67094 1.35997 L F
.66716 1.39874 m .67094 1.35997 L .66754 1.39835 L F
.67083 1.36115 m .67135 1.35475 L .67001 1.37203 L 0 0 .051 r
F
.67094 1.35997 m .67001 1.37203 L .66754 1.39835 L 0 .101 .125 r
F
.66851 1.3897 m .67001 1.37203 L .66865 1.38844 L F
.66754 1.39835 m .6692 1.38063 L .66851 1.3897 L F
.6692 1.38063 m .67001 1.37203 L .66851 1.3897 L F
.66879 1.38679 m .67576 1.29656 L .66808 1.39547 L 0 0 .051 r
F
.67094 1.35997 m .67458 1.31313 L .67596 1.30847 L 0 .101 .125 r
F
.67135 1.35475 m .67458 1.31313 L .67576 1.30021 L 0 0 .051 r
F
.67094 1.35997 m .67596 1.30847 L .67001 1.37203 L 0 .101 .125 r
F
.66879 1.38679 m .67576 1.30021 L .67576 1.29656 L 0 0 .051 r
F
.66797 1.39684 m .67633 1.32013 L .67456 1.34635 L 0 .101 .125 r
F
.66808 1.39547 m .67633 1.32013 L .66797 1.39684 L F
.66899 1.38546 m .67633 1.32013 L .66858 1.39085 L F
.66899 1.38546 m .67596 1.30847 L .67633 1.32013 L F
.67548 1.32711 m .67955 1.30614 L .67971 1.30488 L 0 .757 .071 r
F
.68277 1.2803 m .67971 1.30488 L .68344 1.27601 L F
.67548 1.32711 m .67971 1.30488 L .68277 1.2803 L F
.66968 1.38561 m .67456 1.34635 L .67368 1.35935 L 0 .101 .125 r
F
.66797 1.39684 m .67456 1.34635 L .66968 1.38561 L F
.66789 1.3979 m .66808 1.39547 L .668 1.39651 L 0 0 .051 r
F
.66781 1.3979 m .66808 1.39547 L .66797 1.39684 L 0 .101 .125 r
F
.668 1.39651 m .66808 1.39547 L .66801 1.39633 L 0 0 .051 r
F
.6679 1.39779 m .67368 1.35935 L .66835 1.3972 L 0 .101 .125 r
F
.66789 1.3979 m .668 1.39651 L .6679 1.39779 L 0 0 .051 r
F
.66781 1.3979 m .66797 1.39684 L .6679 1.39779 L 0 .101 .125 r
F
.66797 1.39684 m .67368 1.35935 L .6679 1.39779 L F
.6679 1.39779 m .66801 1.39633 L .6679 1.39775 L 0 0 .051 r
F
.668 1.39651 m .66801 1.39633 L .6679 1.39779 L F
.6679 1.39775 m .67304 1.33243 L .66795 1.39733 L F
.66801 1.39633 m .67304 1.33243 L .6679 1.39775 L F
.66801 1.39633 m .67576 1.29656 L .67304 1.33243 L F
.66808 1.39547 m .67576 1.29656 L .66801 1.39633 L F
.66754 1.39835 m .66851 1.3897 L .66781 1.3979 L 0 .101 .125 r
F
.66851 1.3897 m .66835 1.39184 L .66781 1.3979 L F
.66865 1.38844 m .66899 1.38546 L .66831 1.39261 L F
.66865 1.38844 m .66831 1.39261 L .66781 1.3979 L F
.67135 1.35475 m .67576 1.30021 L .67001 1.37203 L 0 0 .051 r
F
.66865 1.38844 m .66929 1.38145 L .66899 1.38546 L 0 .101 .125 r
F
.66929 1.38145 m .67596 1.30847 L .66899 1.38546 L F
.67001 1.37203 m .67596 1.30847 L .66865 1.38844 L F
.67001 1.37203 m .67576 1.30021 L .66879 1.38679 L 0 0 .051 r
F
.67548 1.32711 m .68569 1.24736 L .68483 1.23905 L 0 .757 .071 r
F
.67548 1.32711 m .68344 1.27601 L .68569 1.24736 L F
0 g
.68569 1.24736 m
.68802 1.24017 L
s
.58206 1.07813 m
.58635 1.08384 L
s
.58635 1.08384 m
.58785 1.08584 L
s
.59125 1.07062 m
.59449 1.0728 L
s
.60282 .739 m .59505 .72852 L .59382 .73273 L 0 1 .485 r
F
.60282 .739 m .60628 .72844 L .59505 .72852 L F
.60282 .739 m .62001 .73255 L .60628 .72844 L F
.60282 .739 m .62899 .73882 L .62001 .73255 L F
0 g
.59197 .73911 m
.60282 .739 L
s
.63356 .92803 m .64269 .9189 L .65137 .903 L 0 1 .29 r
F
0 g
.65017 .90521 m
.65055 .90451 L
s
.65055 .90451 m
.65137 .903 L
s
.65137 .903 m
.65574 .90148 L
s
.64911 .91873 m
.65574 .90148 L
s
.57065 1.12395 m
.57199 1.13695 L
s
.62899 .73882 m
.64017 .73901 L
s
.52792 1.13541 m .53421 1.14039 L .53005 1.12223 L 0 .074 .17 r
F
.52792 1.13541 m .53644 1.15772 L .53421 1.14039 L F
.52792 1.13541 m .53522 1.16257 L .53644 1.15772 L F
.52792 1.13541 m .53156 1.15297 L .53522 1.16257 L F
0 g
.52467 1.12229 m
.52792 1.13541 L
s
.52572 1.11821 m
.52792 1.13541 L
s
.5312 1.15755 m
.53263 1.16677 L
s
.33625 .81297 m .32265 .80503 L .32548 .80941 L 0 .89 .462 r
F
0 g
.31961 .81262 m
.32548 .80941 L
s
.62001 .73255 m
.62899 .73882 L
s
.60916 1.12372 m .61023 1.0707 L .60752 1.09364 L 0 .952 .255 r
F
0 g
.60802 1.04335 m
.61023 1.0707 L
s
.61023 1.0707 m
.61338 1.06442 L
s
.64931 .93556 m .64767 .92246 L .64521 .93632 L 0 1 .194 r
F
.53468 .72149 m .52462 .71221 L .52445 .71623 L 0 1 .494 r
F
0 g
.51392 .71756 m
.52445 .71623 L
s
.53468 .72149 m .53552 .71136 L .52462 .71221 L 0 1 .494 r
F
.53468 .72149 m .54987 .71426 L .53552 .71136 L F
.53468 .72149 m .56011 .71953 L .54987 .71426 L F
.53468 .72149 m .5594 .72366 L .56011 .71953 L F
.53468 .72149 m .5485 .7245 L .5594 .72366 L F
0 g
.52419 .72228 m
.53468 .72149 L
s
.52445 .71623 m
.53468 .72149 L
s
.5485 .7245 m
.55834 .72991 L
s
.66715 .78444 m .66214 .77724 L .65998 .78436 L 0 1 .368 r
F
.66715 .78444 m .67288 .76702 L .66214 .77724 L F
.66146 .80321 m .66715 .78444 L .65675 .79543 L 0 1 .354 r
F
0 g
.48905 .70686 m
.49956 .70552 L
s
.47809 .70305 m
.48905 .70686 L
s
.56908 .7295 m .58269 .73315 L .59382 .73273 L 0 1 .489 r
F
0 g
.58269 .73315 m
.59197 .73911 L
s
.56842 1.04768 m .57425 1.05818 L .58009 1.04986 L 0 .828 .279 r
F
.56424 1.09839 m .56842 1.04768 L .5629 1.05379 L 0 .715 .27 r
F
.56424 1.09839 m .57425 1.05818 L .56842 1.04768 L F
0 g
.56627 1.03358 m
.56842 1.04768 L
s
.57437 1.1895 m
.57558 1.21041 L
s
.67548 1.32711 m .68483 1.23905 L .68146 1.2606 L 0 .757 .071 r
F
0 g
.68158 1.25984 m
.68483 1.23905 L
s
.68344 1.27601 m
.68373 1.27232 L
s
.68373 1.27232 m
.68569 1.24736 L
s
.67596 1.30846 m
.67874 1.28315 L
s
.68154 1.25709 m
.6826 1.21146 L
s
.68344 1.27601 m
.68617 1.25092 L
s
.68483 1.23905 m
.68711 1.21304 L
s
.66146 .80321 m .65675 .79543 L .6546 .80307 L 0 1 .354 r
F
.6558 .82356 m .66146 .80321 L .65139 .81502 L 0 1 .34 r
F
.34297 .82469 m .34784 .81333 L .33625 .81297 L 0 .83 .453 r
F
.34297 .82469 m .35834 .81745 L .34784 .81333 L F
.34297 .82469 m .36071 .82258 L .35834 .81745 L F
.34297 .82469 m .35411 .82568 L .36071 .82258 L F
0 g
.33253 .82058 m
.34297 .82469 L
s
.33675 .82745 m
.34297 .82469 L
s
.67402 1.31501 m
.67509 1.29958 L
s
.56908 .7295 m .56011 .71953 L .5594 .72366 L 0 1 .489 r
F
0 g
.5485 .7245 m
.5594 .72366 L
s
.56908 .7295 m .57125 .71911 L .56011 .71953 L 0 1 .489 r
F
.56908 .7295 m .58538 .72268 L .57125 .71911 L F
.56908 .7295 m .59505 .72852 L .58538 .72268 L F
.56908 .7295 m .59382 .73273 L .59505 .72852 L F
0 g
.5594 .72366 m
.56908 .7295 L
s
.55834 .72991 m
.56908 .7295 L
s
.59382 .73273 m
.60282 .739 L
s
.58269 .73315 m
.59382 .73273 L
s
.54712 1.10476 m .54535 1.06394 L .54418 1.07963 L 0 .523 .269 r
F
.54712 1.10476 m .55039 1.06248 L .54535 1.06394 L F
0 g
.54195 1.04338 m
.54535 1.06394 L
s
.60259 1.09605 m
.60297 1.09467 L
s
.33625 .81297 m .32952 .80159 L .32265 .80503 L 0 .89 .462 r
F
0 g
.31223 .80216 m
.32265 .80503 L
s
.40448 .91959 m .39359 .90427 L .39591 .91105 L 0 .533 .375 r
F
0 g
.39124 .9125 m
.39591 .91105 L
s
.65866 1.31734 m
.66086 1.32035 L
s
.66265 1.32279 m
.66289 1.32313 L
s
.6558 .82356 m .65139 .81502 L .64925 .82329 L 0 1 .34 r
F
.65017 .84579 m .6558 .82356 L .64606 .83626 L 0 1 .326 r
F
.53215 1.09754 m .54242 1.10211 L .5394 1.08051 L 0 .328 .262 r
F
.53215 1.09754 m .54124 1.1164 L .54242 1.10211 L F
.53215 1.09754 m .53683 1.11442 L .54124 1.1164 L F
.53005 1.12223 m .53683 1.11442 L .53215 1.09754 L 0 .233 .235 r
F
0 g
.52814 1.09205 m
.53215 1.09754 L
s
.52916 1.07601 m
.53215 1.09754 L
s
.63356 .92803 m .6486 .88853 L .63905 .8975 L 0 1 .29 r
F
0 g
.6479 .92185 m
.64843 .92049 L
s
.64843 .92049 m
.64911 .91873 L
s
.6486 .88853 m
.65123 .88972 L
s
.6486 .88853 m
.65215 .88272 L
s
.40448 .91959 m .39903 .90219 L .39359 .90427 L 0 .533 .375 r
F
0 g
.38511 .89592 m
.39359 .90427 L
s
.56424 1.09839 m .5629 1.05379 L .56134 1.07249 L 0 .715 .27 r
F
.55039 1.06247 m .56134 1.07249 L .5629 1.05379 L 0 .648 .28 r
F
0 g
.55953 1.03222 m
.5629 1.05379 L
s
.5629 1.05379 m
.56842 1.04768 L
s
.39903 .90219 m .38777 .88796 L .3901 .89437 L 0 .592 .388 r
F
0 g
.38511 .89592 m
.3901 .89437 L
s
.55039 1.06247 m .55598 1.07622 L .56134 1.07249 L 0 .648 .28 r
F
0 g
.54706 1.04088 m
.55039 1.06247 L
s
.54712 1.10476 m .55597 1.07622 L .55039 1.06248 L 0 .523 .269 r
F
0 g
.54535 1.06394 m
.55039 1.06248 L
s
.66077 1.33005 m .66721 1.35664 L .67056 1.29216 L 0 1 .185 r
F
.65514 1.26673 m .6676 1.30568 L .66721 1.20146 L 0 .952 .227 r
F
0 g
.66721 1.20146 m
.66739 1.24962 L
s
.66721 1.20144 m
.67269 1.22701 L
s
.5394 1.08051 m
.54418 1.07963 L
s
.39903 .90219 m .39355 .8857 L .38777 .88796 L 0 .592 .388 r
F
0 g
.37896 .88036 m
.38777 .88796 L
s
.59426 1.37841 m
.59431 1.38132 L
s
.62848 1.13251 m
.63052 1.12088 L
s
.62828 1.13366 m
.62848 1.13251 L
s
.62776 1.13666 m
.62828 1.13366 L
s
.62637 1.14454 m
.62776 1.13666 L
s
.53005 1.12223 m .53945 1.13521 L .53683 1.11442 L 0 .233 .235 r
F
.53005 1.12223 m .53825 1.14599 L .53945 1.13521 L F
.53005 1.12223 m .53421 1.14039 L .53825 1.14599 L F
0 g
.52745 1.10155 m
.53005 1.12223 L
s
.52642 1.11276 m
.53005 1.12223 L
s
.65017 .84579 m .64606 .83626 L .64394 .84528 L 0 1 .326 r
F
.64459 .87028 m .65017 .84579 L .64077 .85948 L 0 1 .313 r
F
0 g
.60595 1.37633 m
.60596 1.37669 L
s
.60193 1.37526 m
.60194 1.37676 L
s
.62811 .96261 m .64767 .92246 L .64269 .9189 L 0 1 .28 r
F
0 g
.64399 .91983 m
.64611 .92135 L
s
.62811 .96261 m .64521 .93632 L .64767 .92246 L 0 1 .28 r
F
0 g
.64767 .92246 m
.6479 .92185 L
s
.64611 .92135 m
.64767 .92246 L
s
.39355 .8857 m .38193 .87253 L .38427 .8786 L 0 .653 .4 r
F
0 g
.37896 .88036 m
.38427 .8786 L
s
.33625 .81297 m .34154 .80137 L .32952 .80159 L 0 .89 .462 r
F
0 g
.32265 .80503 m
.32952 .80159 L
s
.33625 .81297 m .35238 .80493 L .34154 .80137 L 0 .89 .462 r
F
.33625 .81297 m .35477 .80989 L .35238 .80493 L F
.33625 .81297 m .34784 .81333 L .35477 .80989 L F
0 g
.32548 .80941 m
.33625 .81297 L
s
.32971 .81608 m
.33625 .81297 L
s
.56424 1.09839 m .57717 1.08401 L .57425 1.05818 L 0 .715 .27 r
F
0 g
.57425 1.05818 m
.58009 1.04986 L
s
.59505 .72852 m
.60628 .72844 L
s
.58538 .72268 m
.59505 .72852 L
s
.57661 1.10824 m
.57796 1.11173 L
s
.57589 1.10639 m
.57661 1.10824 L
s
.62093 1.1529 m .62287 1.09624 L .61998 1.12898 L 0 1 .208 r
F
.60916 1.12372 m .61998 1.12898 L .62287 1.09624 L 0 .952 .255 r
F
0 g
.62279 1.09483 m
.62287 1.09624 L
s
.62287 1.09624 m
.62505 1.08393 L
s
.61457 1.12635 m
.61461 1.12761 L
s
.61461 1.12761 m
.61491 1.13524 L
s
.61491 1.13524 m
.61556 1.12683 L
s
.52462 .71221 m
.53552 .71136 L
s
.51395 .70762 m
.52462 .71221 L
s
.58278 1.07325 m .58833 1.08285 L .59422 1.0697 L 0 .922 .267 r
F
.53349 1.17235 m .53337 1.16411 L .53213 1.16133 L 0 0 .073 r
F
0 g
.53213 1.16133 m
.53221 1.16196 L
s
.52978 1.15181 m
.53213 1.16133 L
s
.39355 .8857 m .38805 .87006 L .38193 .87253 L 0 .653 .4 r
F
0 g
.37278 .86569 m
.38193 .87253 L
s
.56011 .71953 m
.57125 .71911 L
s
.54987 .71426 m
.56011 .71953 L
s
.54224 1.19925 m .5446 1.2355 L .54224 1.21004 L 0 .992 .113 r
F
.54224 1.19925 m .54802 1.26632 L .5446 1.2355 L F
.54802 1.26632 m .54752 1.26288 L .5446 1.2355 L F
.54802 1.26632 m .55146 1.29629 L .54855 1.27251 L F
.54224 1.19925 m .54983 1.27906 L .54802 1.26632 L F
.54983 1.27906 m .55146 1.29629 L .54802 1.26632 L F
.54224 1.19925 m .55144 1.28511 L .55146 1.29629 L F
.5435 1.23453 m .54813 1.26605 L .55047 1.2812 L 0 0 .04 r
F
.54157 1.22159 m .54415 1.23909 L .5435 1.23453 L F
.54415 1.23909 m .54813 1.26605 L .5435 1.23453 L F
.54111 1.21852 m .5418 1.22319 L .54157 1.22159 L F
.5418 1.22319 m .54813 1.26605 L .54157 1.22159 L F
.54802 1.26632 m .54855 1.27251 L .54752 1.26288 L 0 .992 .113 r
F
.54224 1.19925 m .54851 1.24675 L .55144 1.28511 L F
0 g
.54929 1.20597 m
.54955 1.21378 L
s
.54224 1.19925 m .54458 1.21014 L .54851 1.24675 L 0 .992 .113 r
F
0 g
.54172 1.19484 m
.54224 1.19925 L
s
.5442 1.19142 m
.54678 1.21398 L
s
.54678 1.21398 m
.54749 1.22018 L
s
.54447 1.20453 m
.54452 1.20723 L
s
.54452 1.20723 m
.54458 1.21014 L
s
.5442 1.19142 m
.54447 1.20453 L
s
.54224 1.21004 m
.54224 1.19925 L
s
.38805 .87006 m .37606 .85785 L .37841 .86363 L 0 .713 .412 r
F
0 g
.37278 .86569 m
.37841 .86363 L
s
.40448 .91959 m .40863 .90621 L .39903 .90219 L 0 .533 .375 r
F
.40448 .91959 m .41725 .91478 L .40863 .90621 L F
.40448 .91959 m .41911 .92216 L .41725 .91478 L F
.40448 .91959 m .41363 .92422 L .41911 .92216 L F
0 g
.39591 .91105 m
.40448 .91959 L
s
.53349 1.17235 m .53699 1.18269 L .53337 1.16411 L 0 0 .073 r
F
.53349 1.17235 m .5406 1.2048 L .53699 1.18269 L F
0 g
.53221 1.16196 m
.53349 1.17235 L
s
.53263 1.16677 m
.53349 1.17235 L
s
.53917 1.18634 m
.54224 1.21004 L
s
.38805 .87006 m .38253 .85515 L .37606 .85785 L 0 .713 .412 r
F
0 g
.36658 .85177 m
.37606 .85785 L
s
.39903 .90219 m .40362 .88911 L .39355 .8857 L 0 .592 .388 r
F
.39903 .90219 m .41259 .89695 L .40362 .88911 L F
.39903 .90219 m .41446 .90397 L .41259 .89695 L F
.39903 .90219 m .40863 .90621 L .41446 .90397 L F
0 g
.3901 .89437 m
.39903 .90219 L
s
.39359 .90427 m
.39903 .90219 L
s
.64459 .87028 m .64077 .85948 L .63866 .86939 L 0 1 .313 r
F
.63905 .8975 m .64459 .87028 L .63551 .88505 L 0 1 .301 r
F
0 g
.62926 1.37847 m
.62928 1.37605 L
s
.57614 1.33801 m
.57618 1.33817 L
s
.57342 1.32951 m
.57396 1.33119 L
s
.60452 1.12975 m
.60678 1.11458 L
s
.60678 1.11458 m
.60678 1.11458 L
s
.60678 1.11458 m
.60815 1.10532 L
s
.62811 .96261 m .63684 .95352 L .64521 .93632 L 0 1 .28 r
F
0 g
.64521 .93632 m
.64931 .93556 L
s
.57361 1.3397 m
.57403 1.34244 L
s
.57379 1.34973 m
.57439 1.35537 L
s
.57439 1.35537 m
.57489 1.36007 L
s
.57489 1.36007 m
.57518 1.36284 L
s
.39355 .8857 m .39859 .87285 L .38805 .87006 L 0 .653 .4 r
F
.39355 .8857 m .40792 .87997 L .39859 .87285 L F
.39355 .8857 m .40979 .88666 L .40792 .87997 L F
.39355 .8857 m .40362 .88911 L .40979 .88666 L F
0 g
.38427 .8786 m
.39355 .8857 L
s
.38777 .88796 m
.39355 .8857 L
s
.63186 .81787 m .65675 .79543 L .64898 .79342 L 0 1 .38 r
F
.63186 .81787 m .6546 .80307 L .65675 .79543 L F
0 g
.65675 .79543 m
.66715 .78444 L
s
.65262 .81356 m
.66146 .80321 L
s
.63186 .81787 m .64395 .81268 L .6546 .80307 L 0 1 .38 r
F
0 g
.65416 .80347 m
.6546 .80307 L
s
.65149 .8149 m
.65262 .81356 L
s
.6546 .80307 m
.66146 .80321 L
s
.38253 .85515 m .37018 .84384 L .37253 .84937 L 0 .773 .423 r
F
0 g
.36658 .85177 m
.37253 .84937 L
s
.53156 1.15297 m
.53258 1.15566 L
s
.53156 1.15297 m
.53193 1.15523 L
s
.53193 1.15523 m
.53337 1.16411 L
s
.63643 .79841 m .65998 .78436 L .66214 .77724 L 0 1 .392 r
F
.63643 .79841 m .64898 .79342 L .65998 .78436 L F
0 g
.65998 .78436 m
.66715 .78444 L
s
.55598 1.07622 m
.56134 1.07249 L
s
.54712 1.10476 m .55895 1.10137 L .55597 1.07622 L 0 .523 .269 r
F
0 g
.62039 1.15725 m
.62085 1.15113 L
s
.6198 1.16491 m
.62039 1.15725 L
s
.57605 1.17636 m .58311 1.16499 L .57752 1.13253 L 0 .261 .219 r
F
.57766 1.13923 m .58278 1.07325 L .57717 1.08401 L 0 .797 .26 r
F
.57766 1.13923 m .58833 1.08285 L .58278 1.07325 L F
0 g
.58009 1.04986 m
.58278 1.07325 L
s
.62623 1.36843 m
.62624 1.37308 L
s
.63643 .79841 m .66214 .77724 L .65404 .77546 L 0 1 .392 r
F
0 g
.66214 .77724 m
.67288 .76702 L
s
.62811 .96261 m .64269 .9189 L .63356 .92803 L 0 1 .28 r
F
0 g
.63684 .95352 m
.64521 .93632 L
s
.64269 .9189 m
.65017 .90521 L
s
.64269 .9189 m
.64399 .91983 L
s
.62732 .83882 m .65139 .81502 L .64395 .81268 L 0 1 .368 r
F
.62732 .83882 m .64925 .82329 L .65139 .81502 L F
0 g
.64734 .83459 m
.6558 .82356 L
s
.65139 .81502 m
.65149 .8149 L
s
.65002 .81459 m
.65139 .81502 L
s
.62732 .83882 m .63896 .83349 L .64925 .82329 L 0 1 .368 r
F
0 g
.64866 .82387 m
.64925 .82329 L
s
.64644 .83576 m
.64734 .83459 L
s
.64925 .82329 m
.6558 .82356 L
s
.60297 1.09467 m
.60683 1.09379 L
s
.60683 1.09379 m
.60683 1.09379 L
s
.60683 1.09379 m
.60752 1.09364 L
s
.38253 .85515 m .37699 .84088 L .37018 .84384 L 0 .773 .423 r
F
0 g
.36036 .83846 m
.37018 .84384 L
s
.58311 1.16499 m .58408 1.10765 L .58149 1.12085 L 0 .474 .245 r
F
.58311 1.16499 m .5898 1.12185 L .58408 1.10765 L F
0 g
.58396 1.10594 m
.58408 1.10765 L
s
.55808 1.2381 m .55981 1.2302 L .56451 1.29052 L 0 .954 .185 r
F
0 g
.56215 1.20852 m
.56311 1.24182 L
s
.55795 1.1879 m
.55981 1.2302 L
s
.38805 .87006 m .39353 .85733 L .38253 .85515 L 0 .713 .412 r
F
.38805 .87006 m .40322 .86377 L .39353 .85733 L F
.38805 .87006 m .4051 .87016 L .40322 .86377 L F
.38805 .87006 m .39859 .87285 L .4051 .87016 L F
0 g
.37841 .86363 m
.38805 .87006 L
s
.38193 .87253 m
.38805 .87006 L
s
.62281 .86153 m .64606 .83626 L .63896 .83349 L 0 1 .355 r
F
.62281 .86153 m .64394 .84528 L .64606 .83626 L F
0 g
.64606 .83626 m
.64644 .83576 L
s
.64238 .83483 m
.64606 .83626 L
s
.54381 1.1432 m .54242 1.10211 L .54124 1.1164 L 0 .376 .256 r
F
0 g
.53683 1.11442 m
.54124 1.1164 L
s
.54381 1.1432 m .54712 1.10476 L .54242 1.10211 L 0 .376 .256 r
F
0 g
.5394 1.08051 m
.54242 1.10211 L
s
.62281 .86153 m .63399 .85611 L .64394 .84528 L 0 1 .355 r
F
0 g
.64318 .8461 m
.64394 .84528 L
s
.6421 .85754 m
.65017 .84579 L
s
.64145 .85849 m
.6421 .85754 L
s
.64394 .84528 m
.65017 .84579 L
s
.57605 1.17636 m .57752 1.13253 L .57482 1.13488 L 0 .261 .219 r
F
0 g
.57207 1.12228 m
.57482 1.13488 L
s
.57766 1.13923 m .59081 1.11384 L .58833 1.08285 L 0 .797 .26 r
F
0 g
.58951 1.11635 m
.5898 1.12184 L
s
.58843 1.11844 m
.5898 1.12185 L
s
.58833 1.08285 m
.59422 1.0697 L
s
.37699 .84088 m .36427 .8304 L .36663 .83571 L 0 .829 .433 r
F
0 g
.36036 .83846 m
.36663 .83571 L
s
.6186 1.38114 m
.61861 1.37722 L
s
.63905 .8975 m .63551 .88505 L .63342 .89602 L 0 1 .301 r
F
.63356 .92803 m .63905 .8975 L .6303 .91344 L 0 1 .29 r
F
0 g
.63671 .89689 m
.63905 .8975 L
s
.38253 .85515 m .38846 .84248 L .37699 .84088 L 0 .773 .423 r
F
.38253 .85515 m .39851 .84827 L .38846 .84248 L F
.38253 .85515 m .4004 .85439 L .39851 .84827 L F
.38253 .85515 m .39353 .85733 L .4004 .85439 L F
0 g
.37253 .84937 m
.38253 .85515 L
s
.37606 .85785 m
.38253 .85515 L
s
.37699 .84088 m .37143 .82718 L .36427 .8304 L 0 .829 .433 r
F
0 g
.35411 .82568 m
.36427 .8304 L
s
.5898 1.12185 m .60077 1.15819 L .60346 1.13112 L 0 .642 .257 r
F
.5898 1.12185 m .59489 1.15418 L .60077 1.15819 L F
.58311 1.16499 m .59489 1.15419 L .5898 1.12185 L 0 .474 .245 r
F
.58311 1.16499 m .59659 1.19876 L .59489 1.15419 L F
.59052 1.18258 m .60151 1.09997 L .59636 1.09431 L 0 .903 .248 r
F
.60235 1.20585 m .60346 1.13112 L .60077 1.15819 L 0 .797 .246 r
F
.59052 1.18258 m .60353 1.13635 L .60151 1.09997 L 0 .903 .248 r
F
0 g
.60151 1.09997 m
.60259 1.09605 L
s
.60169 1.09934 m
.60303 1.12335 L
s
.60303 1.12335 m
.60346 1.13112 L
s
.61833 .8863 m .64077 .85948 L .63399 .85611 L 0 1 .343 r
F
.61833 .8863 m .63866 .86939 L .64077 .85948 L F
0 g
.63936 .86949 m
.64459 .87028 L
s
.64077 .85948 m
.64145 .85849 L
s
.59052 1.18258 m .59636 1.09431 L .59081 1.11384 L 0 .903 .248 r
F
0 g
.59422 1.0697 m
.59636 1.09431 L
s
.57433 1.18913 m
.57552 1.20066 L
s
.57247 1.17101 m
.57433 1.18913 L
s
.57227 1.169 m
.57247 1.17101 L
s
.53421 1.14039 m
.53519 1.14175 L
s
.57766 1.13923 m .57717 1.08401 L .57522 1.10805 L 0 .797 .26 r
F
.56424 1.09839 m .57522 1.10805 L .57717 1.08401 L 0 .715 .27 r
F
0 g
.57425 1.05818 m
.57717 1.08401 L
s
.57717 1.08401 m
.58278 1.07325 L
s
.58139 1.17127 m
.58289 1.21031 L
s
.61833 .8863 m .62906 .88088 L .63866 .86939 L 0 1 .343 r
F
0 g
.63773 .8705 m
.63866 .86939 L
s
.63689 .8828 m
.64459 .87028 L
s
.63651 .88342 m
.63689 .8828 L
s
.63866 .86939 m
.63936 .86949 L
s
.37143 .82718 m .35834 .81745 L .36071 .82258 L 0 .882 .442 r
F
0 g
.35411 .82568 m
.36071 .82258 L
s
.66719 1.39149 m .67494 1.27901 L .66675 1.3906 L 0 .865 .088 r
F
0 g
.66739 1.24962 m
.66747 1.26992 L
s
.66667 1.39904 m .67254 1.31999 L .66716 1.39874 L 0 .101 .125 r
F
.66719 1.39149 m .67304 1.33243 L .67494 1.27901 L 0 .865 .088 r
F
0 g
.67061 1.28513 m
.67114 1.21979 L
s
.67444 1.29305 m
.6748 1.2879 L
s
.63186 .81787 m .64898 .79342 L .63643 .79841 L 0 1 .38 r
F
0 g
.64898 .79342 m
.65675 .79543 L
s
.64898 .79342 m
.65998 .78436 L
s
.62732 .83882 m .64395 .81268 L .63186 .81787 L 0 1 .368 r
F
0 g
.64395 .81268 m
.65002 .81459 L
s
.64395 .81268 m
.65416 .80347 L
s
.54712 1.10476 m .55732 1.12119 L .55895 1.10137 L 0 .523 .269 r
F
.54712 1.10476 m .55224 1.12263 L .55732 1.12119 L F
.54381 1.1432 m .55224 1.12263 L .54712 1.10476 L 0 .376 .256 r
F
0 g
.54418 1.07963 m
.54712 1.10476 L
s
.54242 1.10211 m
.54712 1.10476 L
s
.67361 1.31639 m
.67427 1.31417 L
s
.67427 1.31417 m
.67444 1.31361 L
s
.67491 1.31203 m
.67596 1.30847 L
s
.67478 1.31245 m
.67491 1.31203 L
s
.37699 .84088 m .38337 .82821 L .37143 .82718 L 0 .829 .433 r
F
.37699 .84088 m .39378 .83339 L .38337 .82821 L F
.37699 .84088 m .39568 .83927 L .39378 .83339 L F
.37699 .84088 m .38846 .84248 L .39568 .83927 L F
0 g
.36663 .83571 m
.37699 .84088 L
s
.37018 .84384 m
.37699 .84088 L
s
.63643 .79841 m .65404 .77546 L .64102 .78022 L 0 1 .392 r
F
0 g
.65404 .77546 m
.66214 .77724 L
s
.53675 1.19086 m
.53755 1.19495 L
s
.53656 1.18989 m
.53675 1.19086 L
s
.62281 .86153 m .63896 .83349 L .62732 .83882 L 0 1 .355 r
F
0 g
.63896 .83349 m
.64238 .83483 L
s
.63896 .83349 m
.64866 .82387 L
s
.639 .8586 m
.64077 .85948 L
s
.63585 .85703 m
.639 .8586 L
s
.37143 .82718 m .36584 .81397 L .35834 .81745 L 0 .882 .442 r
F
0 g
.34784 .81333 m
.35834 .81745 L
s
.56395 1.37574 m .55808 1.2381 L .56396 1.37574 L 0 .954 .185 r
F
.56395 1.37574 m .55983 1.29987 L .55808 1.2381 L F
.56396 1.37574 m .55808 1.2381 L .56548 1.37657 L F
.56548 1.37657 m .55808 1.2381 L .5668 1.37743 L F
.5668 1.37743 m .55808 1.2381 L .56898 1.37848 L F
.56898 1.37848 m .55808 1.2381 L .56451 1.29052 L F
0 g
.55391 1.20734 m
.55808 1.2381 L
s
.54798 1.22442 m .55144 1.28511 L .54851 1.24675 L 0 1 .14 r
F
.54798 1.22442 m .55574 1.3333 L .55144 1.28511 L F
.54798 1.22442 m .55853 1.35887 L .55574 1.3333 L F
.54798 1.22442 m .55795 1.33563 L .55853 1.35887 L F
.54798 1.22442 m .55442 1.27984 L .55795 1.33563 L F
0 g
.54458 1.21014 m
.54459 1.21024 L
s
.54798 1.22442 m .55017 1.23256 L .55442 1.27984 L 0 1 .14 r
F
0 g
.54929 1.20597 m
.55241 1.23262 L
s
.54955 1.21378 m
.55017 1.23256 L
s
.54749 1.22018 m
.54798 1.22442 L
s
.67548 1.32711 m .68146 1.2606 L .67778 1.29801 L 0 .757 .071 r
F
.67148 1.2765 m .67778 1.29801 L .68146 1.2606 L 0 1 .199 r
F
0 g
.68146 1.2606 m
.68158 1.25984 L
s
.68146 1.2606 m
.68154 1.25709 L
s
.61388 .91351 m .63551 .88505 L .62906 .88088 L 0 1 .331 r
F
.61388 .91351 m .63342 .89602 L .63551 .88505 L F
0 g
.63551 .88505 m
.63651 .88342 L
s
.53699 1.18269 m .53644 1.15772 L .53522 1.16257 L 0 .081 .168 r
F
0 g
.53258 1.15566 m
.53522 1.16257 L
s
.5978 1.38089 m
.59788 1.3857 L
s
.57403 1.34244 m
.57468 1.34776 L
s
.57801 1.3752 m
.57865 1.38043 L
s
.61833 .8863 m .63399 .85611 L .62281 .86153 L 0 1 .343 r
F
0 g
.63097 .88211 m
.63551 .88505 L
s
.62991 .88142 m
.63097 .88211 L
s
.63399 .85611 m
.63585 .85703 L
s
.63399 .85611 m
.64318 .8461 L
s
.54044 1.17153 m .53945 1.13521 L .53825 1.14599 L 0 .252 .233 r
F
0 g
.53519 1.14175 m
.53825 1.14599 L
s
.54044 1.17153 m .54381 1.1432 L .53945 1.13521 L 0 .252 .233 r
F
0 g
.53683 1.11442 m
.53945 1.13521 L
s
.36584 .81397 m .35238 .80493 L .35477 .80989 L 0 .932 .45 r
F
0 g
.34784 .81333 m
.35477 .80989 L
s
.62387 1.30666 m .62669 1.26999 L .63075 1.17987 L 0 .995 .099 r
F
0 g
.62669 1.26999 m
.6282 1.2365 L
s
.62927 1.21277 m
.63075 1.17987 L
s
.6282 1.2365 m
.62927 1.21277 L
s
.62842 1.28136 m
.62845 1.3602 L
s
.6284 1.23205 m
.62841 1.25239 L
s
.62841 1.25239 m
.62841 1.25773 L
s
.62841 1.25773 m
.62842 1.27194 L
s
.62842 1.27194 m
.62842 1.28136 L
s
.37143 .82718 m .37826 .81445 L .36584 .81397 L 0 .882 .442 r
F
.37143 .82718 m .38903 .81907 L .37826 .81445 L F
.37143 .82718 m .39094 .82473 L .38903 .81907 L F
.37143 .82718 m .38337 .82821 L .39094 .82473 L F
0 g
.36071 .82258 m
.37143 .82718 L
s
.36427 .8304 m
.37143 .82718 L
s
.55984 1.15276 m .55895 1.10137 L .55732 1.12119 L 0 .586 .261 r
F
.55984 1.15276 m .56423 1.0984 L .55895 1.10137 L F
0 g
.55597 1.07622 m
.55895 1.10137 L
s
.56424 1.09839 m .56967 1.11423 L .57522 1.10805 L 0 .715 .27 r
F
0 g
.56134 1.07249 m
.56424 1.09839 L
s
.55984 1.15276 m .56967 1.11424 L .56423 1.0984 L 0 .586 .261 r
F
0 g
.55895 1.10137 m
.56423 1.0984 L
s
.42772 .93116 m .41725 .91478 L .41911 .92216 L 0 .624 .371 r
F
0 g
.41363 .92422 m
.41911 .92216 L
s
.61388 .91351 m .62417 .90822 L .63342 .89602 L 0 1 .331 r
F
0 g
.6323 .89751 m
.63342 .89602 L
s
.63174 .91083 m
.63905 .8975 L
s
.63164 .911 m
.63174 .91083 L
s
.63342 .89602 m
.63671 .89689 L
s
.53699 1.18269 m .54044 1.17153 L .53644 1.15772 L 0 .081 .168 r
F
0 g
.53421 1.14039 m
.53644 1.15772 L
s
.5898 1.12184 m
.5898 1.12185 L
s
.5898 1.12185 m
.5898 1.12185 L
s
.42772 .93116 m .42344 .91219 L .41725 .91478 L 0 .624 .371 r
F
0 g
.40863 .90621 m
.41725 .91478 L
s
.63356 .92803 m .6303 .91344 L .62823 .9257 L 0 1 .29 r
F
.62811 .96261 m .63356 .92803 L .62513 .94526 L 0 1 .28 r
F
0 g
.63271 .92766 m
.63356 .92803 L
s
.60916 1.12372 m .61408 1.14084 L .61998 1.12898 L 0 .952 .255 r
F
0 g
.61408 1.14084 m
.61782 1.13331 L
s
.61782 1.13331 m
.61948 1.12998 L
s
.61948 1.12998 m
.61998 1.12898 L
s
.60752 1.09364 m
.60916 1.12372 L
s
.6271 1.41924 m .6288 1.3868 L .63374 1.39679 L 0 .535 .196 r
F
.62434 1.41931 m .6288 1.3868 L .6271 1.41924 L F
0 g
.6288 1.3868 m
.62907 1.38192 L
s
.42344 .91219 m .41259 .89695 L .41446 .90397 L 0 .681 .383 r
F
0 g
.40863 .90621 m
.41446 .90397 L
s
.36584 .81397 m .36024 .80119 L .35238 .80493 L 0 .932 .45 r
F
0 g
.34154 .80137 m
.35238 .80493 L
s
.55017 1.23256 m
.55071 1.23856 L
s
.55071 1.23856 m
.55135 1.24565 L
s
.55135 1.24565 m
.55216 1.25474 L
s
.42344 .91219 m .41914 .89414 L .41259 .89695 L 0 .681 .383 r
F
0 g
.40362 .88911 m
.41259 .89695 L
s
.60497 1.12916 m
.60916 1.12372 L
s
.60452 1.12975 m
.60497 1.12916 L
s
.60346 1.13112 m
.60452 1.12975 L
s
.41914 .89414 m .40792 .87997 L .40979 .88666 L 0 .736 .393 r
F
0 g
.40362 .88911 m
.40979 .88666 L
s
.61388 .91351 m .62906 .88088 L .61833 .8863 L 0 1 .331 r
F
0 g
.62906 .88088 m
.62991 .88142 L
s
.62906 .88088 m
.63773 .8705 L
s
.55331 1.24028 m .5553 1.24243 L .55983 1.29987 L 0 .996 .166 r
F
0 g
.55399 1.20936 m
.5553 1.24243 L
s
.41914 .89414 m .41483 .87695 L .40792 .87997 L 0 .736 .393 r
F
0 g
.39859 .87285 m
.40792 .87997 L
s
.36584 .81397 m .37313 .80116 L .36024 .80119 L 0 .932 .45 r
F
0 g
.35238 .80493 m
.36024 .80119 L
s
.36584 .81397 m .38427 .80525 L .37313 .80116 L 0 .932 .45 r
F
.36584 .81397 m .38618 .81072 L .38427 .80525 L F
.36584 .81397 m .37826 .81445 L .38618 .81072 L F
0 g
.35477 .80989 m
.36584 .81397 L
s
.35834 .81745 m
.36584 .81397 L
s
.55331 1.24028 m .55795 1.33563 L .55442 1.27984 L 0 .996 .166 r
F
.56085 1.37282 m .55331 1.24028 L .56128 1.37322 L F
.56085 1.37282 m .55795 1.33563 L .55331 1.24028 L F
.56128 1.37322 m .55331 1.24028 L .56231 1.3745 L F
.56231 1.3745 m .55331 1.24028 L .56395 1.37573 L F
.56395 1.37573 m .55331 1.24028 L .55983 1.29987 L F
0 g
.5553 1.24243 m
.55742 1.26934 L
s
.55216 1.25474 m
.55442 1.27984 L
s
.55241 1.23262 m
.55331 1.24028 L
s
.55331 1.24028 m
.55442 1.27984 L
s
.55981 1.2302 m
.56341 1.27643 L
s
.61399 1.35767 m .61673 1.20515 L .61143 1.35635 L 0 1 .21 r
F
.61399 1.35767 m .61797 1.28817 L .61673 1.20515 L F
.61411 1.28934 m .6251 1.15182 L .62093 1.1529 L 0 1 .225 r
F
0 g
.62045 1.1625 m
.62061 1.1544 L
s
.61411 1.28934 m .62631 1.20507 L .6251 1.15182 L 0 1 .225 r
F
0 g
.62351 1.22439 m
.62379 1.25356 L
s
.61782 1.19087 m
.618 1.21159 L
s
.62204 1.23455 m
.62209 1.23819 L
s
.6251 1.15182 m
.62637 1.14454 L
s
.61957 1.16792 m
.6198 1.16491 L
s
.6251 1.15182 m
.62572 1.1792 L
s
.62572 1.1792 m
.62617 1.19916 L
s
.60946 .94364 m .6303 .91344 L .62417 .90822 L 0 1 .319 r
F
0 g
.62434 .90836 m
.62451 .90851 L
s
.60946 .94364 m .62823 .9257 L .6303 .91344 L 0 1 .319 r
F
0 g
.62951 .92626 m
.63271 .92766 L
s
.62829 .92573 m
.62951 .92626 L
s
.6303 .91344 m
.63164 .911 L
s
.62451 .90851 m
.6303 .91344 L
s
.41483 .87695 m .40322 .86377 L .4051 .87016 L 0 .789 .404 r
F
0 g
.39859 .87285 m
.4051 .87016 L
s
.58361 1.38472 m
.5846 1.39283 L
s
.5846 1.39283 m
.58513 1.39713 L
s
.58513 1.39713 m
.58532 1.39872 L
s
.42772 .93116 m .43358 .91613 L .42344 .91219 L 0 .624 .371 r
F
.42772 .93116 m .44223 .92514 L .43358 .91613 L F
.42772 .93116 m .44361 .93321 L .44223 .92514 L F
.42772 .93116 m .43737 .93579 L .44361 .93321 L F
0 g
.41911 .92216 m
.42772 .93116 L
s
.63186 .81787 m .62571 .80804 L .62402 .81589 L 0 1 .38 r
F
.63186 .81787 m .63643 .79841 L .62571 .80804 L F
.62732 .83882 m .63186 .81787 L .6215 .82809 L 0 1 .368 r
F
0 g
.62588 .81636 m
.63186 .81787 L
s
.63643 .79841 m .62995 .78931 L .62825 .79665 L 0 1 .392 r
F
.63643 .79841 m .64102 .78022 L .62995 .78931 L F
0 g
.56967 1.11423 m
.57522 1.10805 L
s
.41483 .87695 m .4105 .86054 L .40322 .86377 L 0 .789 .404 r
F
0 g
.39353 .85733 m
.40322 .86377 L
s
.42344 .91219 m .42977 .89743 L .41914 .89414 L 0 .681 .383 r
F
.42344 .91219 m .4388 .90566 L .42977 .89743 L F
.42344 .91219 m .44017 .91333 L .4388 .90566 L F
.42344 .91219 m .43358 .91613 L .44017 .91333 L F
0 g
.41446 .90397 m
.42344 .91219 L
s
.41725 .91478 m
.42344 .91219 L
s
.54381 1.1432 m .55485 1.14953 L .55224 1.12263 L 0 .376 .256 r
F
0 g
.55224 1.12263 m
.55732 1.12119 L
s
.59052 1.18258 m .59081 1.11384 L .58854 1.14577 L 0 .903 .248 r
F
.57766 1.13923 m .58854 1.14577 L .59081 1.11384 L 0 .797 .26 r
F
0 g
.59081 1.11384 m
.59636 1.09431 L
s
.58833 1.08285 m
.59081 1.11384 L
s
.62732 .83882 m .6215 .82809 L .61982 .83652 L 0 1 .368 r
F
.62281 .86153 m .62732 .83882 L .61731 .84967 L 0 1 .355 r
F
0 g
.62429 .83789 m
.62732 .83882 L
s
.53699 1.18269 m .54457 1.19493 L .54044 1.17153 L 0 .081 .168 r
F
.53699 1.18269 m .54638 1.21525 L .54457 1.19493 L F
.53699 1.18269 m .54464 1.21881 L .54638 1.21525 L F
.53699 1.18269 m .5406 1.2048 L .54464 1.21881 L F
0 g
.53337 1.16411 m
.53699 1.18269 L
s
.53522 1.16257 m
.53699 1.18269 L
s
.53909 1.20288 m
.54015 1.21111 L
s
.54015 1.21111 m
.54083 1.21633 L
s
.58613 1.37039 m .5835 1.22617 L .58737 1.37094 L 0 1 .183 r
F
0 g
.58289 1.21031 m
.5835 1.22617 L
s
.58289 1.18666 m
.5835 1.22617 L
s
.41914 .89414 m .42595 .87962 L .41483 .87695 L 0 .736 .393 r
F
.41914 .89414 m .43535 .88711 L .42595 .87962 L F
.41914 .89414 m .43673 .89442 L .43535 .88711 L F
.41914 .89414 m .42977 .89743 L .43673 .89442 L F
0 g
.40979 .88666 m
.41914 .89414 L
s
.41259 .89695 m
.41914 .89414 L
s
.4105 .86054 m .39851 .84827 L .4004 .85439 L 0 .841 .413 r
F
0 g
.39353 .85733 m
.4004 .85439 L
s
.54381 1.1432 m .55319 1.16748 L .55485 1.14953 L 0 .376 .256 r
F
.54381 1.1432 m .54845 1.16475 L .55319 1.16748 L F
.54044 1.17153 m .54845 1.16475 L .54381 1.1432 L 0 .252 .233 r
F
0 g
.53945 1.13521 m
.54381 1.1432 L
s
.54124 1.1164 m
.54381 1.1432 L
s
.67548 1.32711 m .67613 1.32814 L .67955 1.30614 L 0 .757 .071 r
F
0 g
.67823 1.31464 m
.67955 1.30614 L
s
.67646 1.32602 m
.67823 1.31464 L
s
.67613 1.32814 m
.67646 1.32602 L
s
.60946 .94364 m .61931 .93864 L .62823 .9257 L 0 1 .319 r
F
0 g
.62688 .92765 m
.62719 .9272 L
s
.62719 .9272 m
.62801 .92602 L
s
.62801 .92602 m
.62823 .9257 L
s
.62662 .9422 m
.62684 .94177 L
s
.62684 .94177 m
.63356 .92803 L
s
.62823 .9257 m
.62829 .92573 L
s
.55984 1.15276 m .57223 1.14579 L .56967 1.11424 L 0 .586 .261 r
F
.4105 .86054 m .40616 .84482 L .39851 .84827 L 0 .841 .413 r
F
0 g
.38846 .84248 m
.39851 .84827 L
s
.62281 .86153 m .61731 .84967 L .61565 .85878 L 0 1 .355 r
F
.61833 .8863 m .62281 .86153 L .61315 .87304 L 0 1 .343 r
F
0 g
.62148 .86102 m
.62281 .86153 L
s
.41483 .87695 m .42212 .86262 L .4105 .86054 L 0 .789 .404 r
F
.41483 .87695 m .43189 .86942 L .42212 .86262 L F
.41483 .87695 m .43328 .8764 L .43189 .86942 L F
.41483 .87695 m .42595 .87962 L .43328 .8764 L F
0 g
.4051 .87016 m
.41483 .87695 L
s
.40792 .87997 m
.41483 .87695 L
s
.60946 .94364 m .62417 .90822 L .61388 .91351 L 0 1 .319 r
F
0 g
.62417 .90822 m
.6323 .89751 L
s
.62417 .90822 m
.62434 .90836 L
s
.62897 1.3761 m
.62898 1.37804 L
s
.61411 1.28934 m .62093 1.1529 L .61574 1.18826 L 0 1 .225 r
F
0 g
.61771 1.17479 m
.6183 1.17077 L
s
.6183 1.17077 m
.61924 1.16436 L
s
.61924 1.16436 m
.62093 1.1529 L
s
.61998 1.12898 m
.62093 1.1529 L
s
.63093 1.41885 m .63374 1.39679 L .63538 1.41819 L 0 .535 .196 r
F
.6271 1.41924 m .63374 1.39679 L .63093 1.41885 L F
0 g
.63374 1.39679 m
.63424 1.387 L
s
.6288 1.3868 m
.63374 1.39679 L
s
.40616 .84482 m .39378 .83339 L .39568 .83927 L 0 .889 .422 r
F
0 g
.38846 .84248 m
.39568 .83927 L
s
.4105 .86054 m .41827 .84635 L .40616 .84482 L 0 .841 .413 r
F
.4105 .86054 m .42842 .85251 L .41827 .84635 L F
.4105 .86054 m .42981 .85918 L .42842 .85251 L F
.4105 .86054 m .42212 .86262 L .42981 .85918 L F
0 g
.4004 .85439 m
.4105 .86054 L
s
.40322 .86377 m
.4105 .86054 L
s
.59515 1.29699 m .60234 1.20586 L .59659 1.19876 L 0 .627 .24 r
F
.60253 1.2194 m .60353 1.13635 L .60105 1.1796 L 0 1 .228 r
F
.59052 1.18258 m .60105 1.1796 L .60353 1.13635 L 0 .903 .248 r
F
0 g
.60151 1.09997 m
.60353 1.13635 L
s
.60353 1.13635 m
.60452 1.12975 L
s
.66769 1.34733 m
.66824 1.34716 L
s
.65926 1.40976 m .66022 1.3894 L .66407 1.37586 L 0 .169 .151 r
F
.65531 1.4117 m .66022 1.3894 L .65755 1.41061 L 0 .242 .166 r
F
.65383 1.41256 m .66022 1.3894 L .65531 1.4117 L F
.65755 1.41061 m .66022 1.3894 L .65926 1.40976 L 0 .169 .151 r
F
.65475 1.40538 m .66417 1.34846 L .66197 1.38979 L 0 .338 .187 r
F
0 g
.66143 1.36506 m
.66148 1.36394 L
s
.65424 1.40563 m .66417 1.34846 L .65475 1.40538 L 0 .338 .187 r
F
0 g
.66417 1.34846 m
.66515 1.34815 L
s
.40616 .84482 m .40179 .82973 L .39378 .83339 L 0 .889 .422 r
F
0 g
.38337 .82821 m
.39378 .83339 L
s
.62811 .96261 m .62513 .94526 L .62307 .95908 L 0 1 .28 r
F
0 g
.62333 1.41933 m
.62396 1.4075 L
s
.54111 1.21852 m .54198 1.21594 L .5402 1.20859 L 0 0 .04 r
F
0 g
.5402 1.20859 m
.54064 1.2134 L
s
.53755 1.19495 m
.5402 1.20859 L
s
.61833 .8863 m .61315 .87304 L .6115 .88295 L 0 1 .343 r
F
0 g
.61734 .88581 m
.61807 .88617 L
s
.61388 .91351 m .61833 .8863 L .60902 .89851 L 0 1 .331 r
F
0 g
.61807 .88617 m
.61833 .8863 L
s
.54044 1.17153 m .55067 1.19045 L .54845 1.16475 L 0 .252 .233 r
F
.54044 1.17153 m .54897 1.20309 L .55067 1.19045 L F
.54044 1.17153 m .54457 1.19493 L .54897 1.20309 L F
0 g
.53825 1.14599 m
.54044 1.17153 L
s
.53644 1.15772 m
.54044 1.17153 L
s
.60046 .82748 m .62402 .81589 L .62571 .80804 L 0 1 .388 r
F
0 g
.62277 .82684 m
.63186 .81787 L
s
.60046 .82748 m .61322 .82422 L .62402 .81589 L 0 1 .388 r
F
0 g
.62402 .81589 m
.62588 .81636 L
s
.60046 .82748 m .62571 .80804 L .61707 .80462 L 0 1 .388 r
F
0 g
.62315 .81656 m
.62402 .81589 L
s
.62249 .82712 m
.62277 .82684 L
s
.62571 .80804 m
.63643 .79841 L
s
.59711 .84842 m .6215 .82809 L .61322 .82422 L 0 1 .376 r
F
.59711 .84842 m .61982 .83652 L .6215 .82809 L F
0 g
.61857 .84831 m
.61863 .84825 L
s
.61863 .84825 m
.62732 .83882 L
s
.6215 .82809 m
.62249 .82712 L
s
.61406 .82461 m
.6215 .82809 L
s
.57605 1.17636 m .58791 1.21114 L .58311 1.16499 L 0 .261 .219 r
F
.57605 1.17636 m .58922 1.25351 L .58791 1.21114 L F
.57605 1.17636 m .58612 1.26337 L .58922 1.25351 L F
.57605 1.17636 m .58045 1.23001 L .58612 1.26337 L F
0 g
.57482 1.13488 m
.57605 1.17636 L
s
.57199 1.13695 m
.57605 1.17636 L
s
.57627 1.2223 m
.57685 1.23243 L
s
.60382 .8079 m .62825 .79665 L .62995 .78931 L 0 1 .398 r
F
.60382 .8079 m .61707 .80462 L .62825 .79665 L F
0 g
.62825 .79665 m
.63643 .79841 L
s
.59711 .84842 m .60938 .84523 L .61982 .83652 L 0 1 .376 r
F
0 g
.61879 .83738 m
.61982 .83652 L
s
.61982 .83652 m
.62429 .83789 L
s
.60508 .97726 m .62513 .94526 L .61931 .93864 L 0 1 .308 r
F
.60508 .97726 m .62307 .95908 L .62513 .94526 L F
0 g
.62325 .9592 m
.62811 .96261 L
s
.62513 .94526 m
.62662 .9422 L
s
.60382 .8079 m .62995 .78931 L .62095 .78623 L 0 1 .398 r
F
0 g
.61891 .80534 m
.62571 .80804 L
s
.62995 .78931 m
.64102 .78022 L
s
.54111 1.21852 m .54598 1.24267 L .54198 1.21594 L 0 0 .04 r
F
.54111 1.21852 m .54955 1.27113 L .54598 1.24267 L F
.54111 1.21852 m .55047 1.2812 L .54955 1.27113 L F
.54111 1.21852 m .54411 1.23919 L .54813 1.26605 L F
0 g
.54535 1.21735 m
.54851 1.24675 L
s
.54064 1.2134 m
.54111 1.21852 L
s
.54083 1.21633 m
.54111 1.21852 L
s
.54798 1.22442 m
.54851 1.24675 L
s
.40179 .82973 m .38903 .81907 L .39094 .82473 L 0 .936 .431 r
F
0 g
.38337 .82821 m
.39094 .82473 L
s
.40616 .84482 m .4144 .83074 L .40179 .82973 L 0 .889 .422 r
F
.40616 .84482 m .42493 .8363 L .4144 .83074 L F
.40616 .84482 m .42632 .8427 L .42493 .8363 L F
.40616 .84482 m .41827 .84635 L .42632 .8427 L F
0 g
.39568 .83927 m
.40616 .84482 L
s
.39851 .84827 m
.40616 .84482 L
s
.59378 .87091 m .61731 .84967 L .60938 .84523 L 0 1 .365 r
F
.59378 .87091 m .61565 .85878 L .61731 .84967 L F
0 g
.61608 .85894 m
.62148 .86102 L
s
.61571 .8588 m
.61608 .85894 L
s
.61731 .84967 m
.61857 .84831 L
s
.59378 .87091 m .60557 .86788 L .61565 .85878 L 0 1 .365 r
F
0 g
.61445 .85986 m
.61565 .85878 L
s
.61471 .87119 m
.62281 .86153 L
s
.61565 .85878 m
.61571 .8588 L
s
.40179 .82973 m .39741 .81521 L .38903 .81907 L 0 .936 .431 r
F
0 g
.37826 .81445 m
.38903 .81907 L
s
.57815 1.3779 m
.57865 1.38043 L
s
.57518 1.36284 m
.57537 1.3638 L
s
.6662 1.38967 m .67056 1.29216 L .66721 1.35664 L 0 .865 .088 r
F
.66643 1.3901 m .67056 1.29216 L .6662 1.38967 L F
0 g
.67056 1.29216 m
.67061 1.28513 L
s
.67056 1.29216 m
.67196 1.27814 L
s
.60508 .97726 m .61931 .93864 L .60946 .94364 L 0 1 .308 r
F
0 g
.61931 .93864 m
.62513 .94526 L
s
.61931 .93864 m
.62688 .92765 L
s
.59047 .89523 m .61315 .87304 L .60557 .86788 L 0 1 .354 r
F
.59047 .89523 m .6115 .88295 L .61315 .87304 L F
0 g
.61166 .88302 m
.61734 .88581 L
s
.61315 .87304 m
.61471 .87119 L
s
.40179 .82973 m .41052 .81573 L .39741 .81521 L 0 .936 .431 r
F
.40179 .82973 m .42142 .82074 L .41052 .81573 L F
.40179 .82973 m .42283 .82689 L .42142 .82074 L F
.40179 .82973 m .4144 .83074 L .42283 .82689 L F
0 g
.39094 .82473 m
.40179 .82973 L
s
.39378 .83339 m
.40179 .82973 L
s
.58311 1.16499 m .59371 1.22576 L .59659 1.19876 L 0 .474 .245 r
F
.58311 1.16499 m .58791 1.21114 L .59371 1.22576 L F
0 g
.58226 1.14199 m
.58311 1.16499 L
s
.57879 1.1399 m
.58311 1.16499 L
s
.61388 .91351 m .60902 .89851 L .60738 .90936 L 0 1 .331 r
F
.60946 .94364 m .61388 .91351 L .60492 .92646 L 0 1 .319 r
F
.39741 .81521 m .38427 .80525 L .38618 .81072 L 0 .979 .439 r
F
0 g
.37826 .81445 m
.38618 .81072 L
s
.60508 .97726 m .61449 .9728 L .62307 .95908 L 0 1 .308 r
F
0 g
.61449 .9728 m
.62307 .95908 L
s
.62307 .95908 m
.62325 .9592 L
s
.45215 .94272 m .44223 .92514 L .44361 .93321 L 0 .701 .364 r
F
0 g
.43737 .93579 m
.44361 .93321 L
s
.45215 .94272 m .4491 .92197 L .44223 .92514 L 0 .701 .364 r
F
0 g
.43358 .91613 m
.44223 .92514 L
s
.59711 .84842 m .61322 .82422 L .60046 .82748 L 0 1 .376 r
F
0 g
.60965 .84538 m
.61731 .84967 L
s
.60952 .8453 m
.60965 .84538 L
s
.61322 .82422 m
.62315 .81656 L
s
.61322 .82422 m
.61406 .82461 L
s
.4491 .92197 m .4388 .90566 L .44017 .91333 L 0 .756 .374 r
F
0 g
.43358 .91613 m
.44017 .91333 L
s
.64092 1.40815 m .64268 1.37288 L .64237 1.40804 L 0 .494 .203 r
F
0 g
.641 1.36705 m
.64268 1.37288 L
s
.59047 .89523 m .60179 .89245 L .6115 .88295 L 0 1 .354 r
F
0 g
.61013 .88429 m
.6115 .88295 L
s
.61089 .89606 m
.61833 .8863 L
s
.6115 .88295 m
.61166 .88302 L
s
.60046 .82748 m .61707 .80462 L .60382 .8079 L 0 1 .388 r
F
0 g
.61707 .80462 m
.61891 .80534 L
s
.61707 .80462 m
.62825 .79665 L
s
.4491 .92197 m .44604 .90226 L .4388 .90566 L 0 .756 .374 r
F
0 g
.42977 .89743 m
.4388 .90566 L
s
.55536 1.20211 m .55485 1.14953 L .55319 1.16748 L 0 .432 .251 r
F
.55536 1.20211 m .55984 1.15276 L .55485 1.14953 L F
0 g
.55224 1.12263 m
.55485 1.14953 L
s
.59378 .87091 m .60938 .84523 L .59711 .84842 L 0 1 .365 r
F
0 g
.60938 .84523 m
.60952 .8453 L
s
.60938 .84523 m
.61879 .83738 L
s
.54719 1.25981 m
.54752 1.26288 L
s
.44604 .90226 m .43535 .88711 L .43673 .89442 L 0 .808 .384 r
F
0 g
.42977 .89743 m
.43673 .89442 L
s
.39741 .81521 m .39302 .80118 L .38427 .80525 L 0 .979 .439 r
F
0 g
.37313 .80116 m
.38427 .80525 L
s
.60382 .8079 m .62095 .78623 L .60721 .78948 L 0 1 .398 r
F
0 g
.62095 .78623 m
.62995 .78931 L
s
.67148 1.2765 m .67349 1.30492 L .67778 1.29801 L 0 1 .199 r
F
0 g
.67148 1.2765 m
.67269 1.22701 L
s
.66077 1.33005 m .66298 1.37318 L .66721 1.35664 L 0 1 .185 r
F
.6662 1.38967 m .66721 1.35664 L .66603 1.38916 L 0 .865 .088 r
F
.6661 1.38205 m .67148 1.27652 L .6676 1.30568 L 0 1 .129 r
F
.66748 1.38331 m .67148 1.27652 L .6661 1.38205 L F
.66748 1.38331 m .67348 1.30494 L .67148 1.27652 L F
0 g
.6733 1.32517 m
.67405 1.30401 L
s
.44604 .90226 m .44297 .88351 L .43535 .88711 L 0 .808 .384 r
F
0 g
.42595 .87962 m
.43535 .88711 L
s
.5406 1.2048 m
.54133 1.20734 L
s
.54133 1.20734 m
.54161 1.2083 L
s
.54161 1.2083 m
.54203 1.20974 L
s
.5406 1.2048 m
.54078 1.20622 L
s
.54078 1.20622 m
.54198 1.21594 L
s
.54845 1.16475 m
.55319 1.16748 L
s
.57766 1.13923 m .58289 1.15672 L .58854 1.14577 L 0 .797 .26 r
F
0 g
.57522 1.10805 m
.57766 1.13923 L
s
.57229 1.21292 m .57766 1.13924 L .57223 1.14579 L 0 .659 .254 r
F
.57229 1.21292 m .58289 1.15673 L .57766 1.13924 L F
0 g
.57558 1.21041 m
.57627 1.2223 L
s
.57537 1.14201 m
.57766 1.13924 L
s
.61076 1.41881 m .60776 1.40993 L .61746 1.4173 L 0 .683 .187 r
F
.60121 1.41719 m .60776 1.40993 L .60683 1.41837 L 0 .794 .178 r
F
.60121 1.41719 m .59596 1.40409 L .60776 1.40993 L F
0 g
.60683 1.41837 m
.60776 1.40993 L
s
.59047 .89523 m .60557 .86788 L .59378 .87091 L 0 1 .354 r
F
0 g
.60557 .86788 m
.61445 .85986 L
s
.60557 .86788 m
.61315 .87304 L
s
.44297 .88351 m .43189 .86942 L .43328 .8764 L 0 .858 .394 r
F
0 g
.42595 .87962 m
.43328 .8764 L
s
.58718 .92165 m .60902 .89851 L .60179 .89245 L 0 1 .343 r
F
.58718 .92165 m .60738 .90936 L .60902 .89851 L F
0 g
.60902 .89851 m
.61089 .89606 L
s
.60765 .90953 m
.61388 .91351 L
s
.39741 .81521 m .40662 .80124 L .39302 .80118 L 0 .979 .439 r
F
0 g
.38427 .80525 m
.39302 .80118 L
s
.39741 .81521 m .41791 .80574 L .40662 .80124 L 0 .979 .439 r
F
.39741 .81521 m .41932 .81167 L .41791 .80574 L F
.39741 .81521 m .41052 .81573 L .41932 .81167 L F
0 g
.38903 .81907 m
.39741 .81521 L
s
.38618 .81072 m
.39741 .81521 L
s
.44297 .88351 m .43989 .86563 L .43189 .86942 L 0 .858 .394 r
F
0 g
.42212 .86262 m
.43189 .86942 L
s
.67548 1.32711 m
.67778 1.29801 L
s
.67407 1.30397 m
.67573 1.30132 L
s
.67733 1.29874 m
.67751 1.29845 L
s
.67694 1.29937 m
.67733 1.29874 L
s
.67573 1.30132 m
.67694 1.29937 L
s
.67751 1.29845 m
.67778 1.29801 L
s
.67349 1.30492 m
.67407 1.30397 L
s
.59886 1.41672 m .59596 1.40409 L .60121 1.41719 L 0 .794 .178 r
F
0 g
.59596 1.40409 m
.59886 1.41672 L
s
.57658 1.39164 m .57334 1.31692 L .5764 1.39202 L 0 0 .094 r
F
0 g
.57334 1.31692 m
.57451 1.34561 L
s
.57451 1.34561 m
.57451 1.34575 L
s
.57451 1.34575 m
.57452 1.34582 L
s
.57491 1.3688 m
.57572 1.3754 L
s
.57489 1.36869 m
.57491 1.3688 L
s
.57317 1.3158 m
.57334 1.31692 L
s
.57384 1.35225 m
.57402 1.35502 L
s
.4491 .92197 m .45709 .90541 L .44604 .90226 L 0 .756 .374 r
F
.4491 .92197 m .46605 .91406 L .45709 .90541 L F
.4491 .92197 m .46692 .92243 L .46605 .91406 L F
.4491 .92197 m .45965 .92582 L .46692 .92243 L F
.45215 .94272 m .45965 .92582 L .4491 .92197 L 0 .701 .364 r
F
0 g
.44017 .91333 m
.4491 .92197 L
s
.44223 .92514 m
.4491 .92197 L
s
.66172 1.40783 m .66407 1.37586 L .66511 1.3905 L 0 .169 .151 r
F
.65926 1.40976 m .66407 1.37586 L .66172 1.40783 L F
0 g
.66407 1.37586 m
.66473 1.36632 L
s
.6624 1.38172 m
.66407 1.37586 L
s
.45215 .94272 m .46822 .93534 L .45965 .92582 L 0 .701 .364 r
F
.45215 .94272 m .46909 .94418 L .46822 .93534 L F
.45215 .94272 m .46219 .94734 L .46909 .94418 L F
0 g
.44361 .93321 m
.45215 .94272 L
s
.54198 1.21594 m
.54462 1.23356 L
s
.44604 .90226 m .45453 .88602 L .44297 .88351 L 0 .808 .384 r
F
.44604 .90226 m .46388 .89387 L .45453 .88602 L F
.44604 .90226 m .46475 .90182 L .46388 .89387 L F
.44604 .90226 m .45709 .90541 L .46475 .90182 L F
0 g
.43673 .89442 m
.44604 .90226 L
s
.4388 .90566 m
.44604 .90226 L
s
.43989 .86563 m .42842 .85251 L .42981 .85918 L 0 .905 .403 r
F
0 g
.42212 .86262 m
.42981 .85918 L
s
.58718 .92165 m .59802 .91928 L .60738 .90936 L 0 1 .343 r
F
0 g
.60581 .91102 m
.60738 .90936 L
s
.60738 .90936 m
.60765 .90953 L
s
.60712 .92328 m
.61388 .91351 L
s
.58781 1.41274 m .58864 1.39652 L .59358 1.41191 L 0 .92 .162 r
F
.58631 1.41216 m .58864 1.39652 L .58781 1.41274 L F
.58631 1.41216 m .58585 1.40305 L .58864 1.39652 L F
0 g
.58814 1.39771 m
.58864 1.39652 L
s
.5863 1.3833 m
.58864 1.39652 L
s
.58289 1.15672 m
.58854 1.14577 L
s
.55984 1.15276 m .57018 1.17209 L .57223 1.14579 L 0 .586 .261 r
F
.55984 1.15276 m .56486 1.17508 L .57018 1.17209 L F
.55536 1.20211 m .56486 1.17508 L .55984 1.15276 L 0 .432 .251 r
F
0 g
.55732 1.12119 m
.55984 1.15276 L
s
.55485 1.14953 m
.55984 1.15276 L
s
.57229 1.21292 m .57223 1.14579 L .57018 1.17209 L 0 .659 .254 r
F
0 g
.56967 1.11424 m
.57223 1.14579 L
s
.57223 1.14579 m
.57537 1.14201 L
s
.58718 .92165 m .60179 .89245 L .59047 .89523 L 0 1 .343 r
F
0 g
.60179 .89245 m
.60902 .89851 L
s
.60179 .89245 m
.61013 .88429 L
s
.44297 .88351 m .45196 .86756 L .43989 .86563 L 0 .858 .394 r
F
.44297 .88351 m .46169 .87469 L .45196 .86756 L F
.44297 .88351 m .46257 .88225 L .46169 .87469 L F
.44297 .88351 m .45453 .88602 L .46257 .88225 L F
0 g
.43328 .8764 m
.44297 .88351 L
s
.43535 .88711 m
.44297 .88351 L
s
.43989 .86563 m .4368 .84855 L .42842 .85251 L 0 .905 .403 r
F
0 g
.41827 .84635 m
.42842 .85251 L
s
.66795 1.39733 m .67304 1.33243 L .66937 1.3846 L 0 0 .051 r
F
.66796 1.39369 m .67304 1.33243 L .66719 1.39149 L 0 .865 .088 r
F
.66796 1.39369 m .66937 1.3846 L .67304 1.33243 L F
0 g
.67304 1.33243 m
.6733 1.32517 L
s
.67304 1.33243 m
.67536 1.30191 L
s
.60946 .94364 m .60492 .92646 L .60328 .93842 L 0 1 .319 r
F
.60508 .97726 m .60946 .94364 L .60084 .95735 L 0 1 .308 r
F
.60046 .82748 m .59296 .81624 L .59176 .82407 L 0 1 .388 r
F
.60046 .82748 m .60382 .8079 L .59296 .81624 L F
.59711 .84842 m .60046 .82748 L .58997 .8362 L 0 1 .376 r
F
0 g
.60026 .82741 m
.60046 .82748 L
s
.61076 1.41881 m .61746 1.4173 L .61635 1.4191 L 0 .683 .187 r
F
0 g
.60776 1.40993 m
.61076 1.41881 L
s
.61733 1.41917 m .61746 1.4173 L .61794 1.41919 L 0 .658 .198 r
F
.61635 1.4191 m .61746 1.4173 L .61733 1.41917 L F
0 g
.61746 1.4173 m
.61821 1.40647 L
s
.61746 1.4173 m
.61794 1.41919 L
s
.59711 .84842 m .58997 .8362 L .58877 .84455 L 0 1 .376 r
F
.59378 .87091 m .59711 .84842 L .58699 .85753 L 0 1 .365 r
F
.4368 .84855 m .42493 .8363 L .42632 .8427 L 0 .95 .412 r
F
0 g
.41827 .84635 m
.42632 .8427 L
s
.60382 .8079 m .59597 .79746 L .59477 .80484 L 0 1 .398 r
F
.60382 .8079 m .60721 .78948 L .59597 .79746 L F
.43989 .86563 m .44938 .84995 L .4368 .84855 L 0 .905 .403 r
F
.43989 .86563 m .4595 .8564 L .44938 .84995 L F
.43989 .86563 m .46038 .86361 L .4595 .8564 L F
.43989 .86563 m .45196 .86756 L .46038 .86361 L F
0 g
.42981 .85918 m
.43989 .86563 L
s
.43189 .86942 m
.43989 .86563 L
s
.62297 1.38296 m
.62525 1.40773 L
s
.54514 1.24608 m
.54701 1.2586 L
s
.54411 1.23919 m
.54514 1.24608 L
s
.58391 .95055 m .60492 .92646 L .59802 .91928 L 0 1 .332 r
F
.58391 .95055 m .60328 .93842 L .60492 .92646 L F
0 g
.60492 .92646 m
.60712 .92328 L
s
.60342 .95326 m
.60946 .94364 L
s
.60368 .93876 m
.60946 .94364 L
s
.65956 1.38289 m .66077 1.33005 L .65752 1.38089 L 0 1 .126 r
F
.66253 1.38555 m .66077 1.33005 L .65956 1.38289 L F
.66253 1.38555 m .66298 1.37318 L .66077 1.33005 L F
.65514 1.26673 m .66438 1.37401 L .6676 1.30568 L 0 .952 .227 r
F
0 g
.66747 1.26992 m
.66754 1.28944 L
s
.66754 1.28944 m
.66758 1.3007 L
s
.65514 1.26673 m .65898 1.357 L .66438 1.37401 L 0 .952 .227 r
F
.65337 1.37586 m .65514 1.26673 L .65085 1.29405 L 0 1 .199 r
F
.65816 1.378 m .65514 1.26673 L .65337 1.37586 L F
.65816 1.378 m .65898 1.357 L .65514 1.26673 L F
0 g
.65734 1.37764 m
.65736 1.38078 L
s
.65492 1.16344 m
.65514 1.26673 L
s
.4368 .84855 m .43369 .83218 L .42493 .8363 L 0 .95 .412 r
F
0 g
.4144 .83074 m
.42493 .8363 L
s
.6008 1.3817 m
.60219 1.39935 L
s
.59957 1.3821 m
.60024 1.39757 L
s
.59378 .87091 m .58699 .85753 L .5858 .86648 L 0 1 .365 r
F
.59047 .89523 m .59378 .87091 L .58403 .88043 L 0 1 .354 r
F
0 g
.54457 1.19493 m
.54533 1.19633 L
s
.67115 1.39354 m .67613 1.32815 L .67138 1.39147 L 0 0 .055 r
F
.67115 1.39354 m .67368 1.35935 L .67613 1.32815 L F
.66835 1.3972 m .67368 1.35935 L .6702 1.39546 L 0 .101 .125 r
F
.6702 1.39546 m .67368 1.35935 L .67115 1.39354 L 0 0 .055 r
F
.67138 1.39147 m .67613 1.32815 L .67548 1.32713 L F
0 g
.67582 1.32767 m
.67582 1.32765 L
s
.63417 1.4083 m .63541 1.38619 L .63844 1.4082 L 0 .638 .208 r
F
.63025 1.40817 m .63541 1.38619 L .63417 1.4083 L F
.63025 1.40817 m .63045 1.38963 L .63541 1.38619 L F
0 g
.63541 1.38619 m
.63844 1.4082 L
s
.63541 1.38619 m
.63623 1.37574 L
s
.4368 .84855 m .44679 .83309 L .43369 .83218 L 0 .95 .412 r
F
.4368 .84855 m .4573 .83894 L .44679 .83309 L F
.4368 .84855 m .45818 .84583 L .4573 .83894 L F
.4368 .84855 m .44938 .84995 L .45818 .84583 L F
0 g
.42632 .8427 m
.4368 .84855 L
s
.42842 .85251 m
.4368 .84855 L
s
.58391 .95055 m .59802 .91928 L .58718 .92165 L 0 1 .332 r
F
0 g
.59802 .91928 m
.60492 .92646 L
s
.59802 .91928 m
.60581 .91102 L
s
.43369 .83218 m .42142 .82074 L .42283 .82689 L 0 .992 .42 r
F
0 g
.4144 .83074 m
.42283 .82689 L
s
.57229 1.21292 m .58506 1.19743 L .58289 1.15673 L 0 .659 .254 r
F
.58391 .95055 m .59429 .94875 L .60328 .93842 L 0 1 .332 r
F
0 g
.60149 .94048 m
.60328 .93842 L
s
.60328 .93842 m
.60368 .93876 L
s
.59047 .89523 m .58403 .88043 L .58285 .89007 L 0 1 .354 r
F
.58718 .92165 m .59047 .89523 L .58108 .90514 L 0 1 .343 r
F
.43369 .83218 m .43057 .81646 L .42142 .82074 L 0 .992 .42 r
F
0 g
.41052 .81573 m
.42142 .82074 L
s
.57573 1.39353 m
.57584 1.39463 L
s
.57799 1.25204 m .58117 1.24975 L .5777 1.22198 L 0 0 .088 r
F
0 g
.5777 1.22198 m
.57774 1.22608 L
s
.57774 1.22608 m
.57781 1.23286 L
s
.57781 1.23286 m
.57792 1.24522 L
s
.57628 1.20808 m
.5777 1.22198 L
s
.56563 .85344 m .58997 .8362 L .58096 .83124 L 0 1 .382 r
F
0 g
.58904 .85568 m
.59711 .84842 L
s
.58906 .84469 m
.59711 .84842 L
s
.56563 .85344 m .58877 .84455 L .58997 .8362 L 0 1 .382 r
F
0 g
.58997 .8362 m
.60046 .82748 L
s
.56563 .85344 m .57835 .85194 L .58877 .84455 L 0 1 .382 r
F
0 g
.58737 .84555 m
.58877 .84455 L
s
.58877 .84455 m
.58906 .84469 L
s
.56773 .83298 m .59176 .82407 L .59296 .81624 L 0 1 .392 r
F
.56773 .83298 m .58096 .83124 L .59176 .82407 L F
0 g
.59176 .82407 m
.60026 .82741 L
s
.56773 .83298 m .59296 .81624 L .58358 .8118 L 0 1 .392 r
F
0 g
.59296 .81624 m
.60382 .8079 L
s
.43369 .83218 m .44419 .81691 L .43057 .81646 L 0 .992 .42 r
F
.43369 .83218 m .45509 .82221 L .44419 .81691 L F
.43369 .83218 m .45597 .82882 L .45509 .82221 L F
.43369 .83218 m .44679 .83309 L .45597 .82882 L F
0 g
.42493 .8363 m
.43369 .83218 L
s
.42283 .82689 m
.43369 .83218 L
s
.62939 1.40814 m .63045 1.38963 L .63025 1.40817 L 0 .638 .208 r
F
0 g
.62939 1.40814 m
.63045 1.38963 L
s
.62858 1.37917 m
.63045 1.38963 L
s
.56354 .87526 m .58699 .85753 L .57835 .85194 L 0 1 .371 r
F
.56354 .87526 m .5858 .86648 L .58699 .85753 L F
0 g
.58619 .8667 m
.59378 .87091 L
s
.58637 .87814 m
.59378 .87091 L
s
.58699 .85753 m
.58904 .85568 L
s
.66795 1.39733 m .66937 1.3846 L .66829 1.39637 L 0 0 .051 r
F
.66836 1.39483 m .66937 1.3846 L .66796 1.39369 L 0 .865 .088 r
F
.67017 1.38604 m .67348 1.30494 L .66748 1.38331 L 0 1 .129 r
F
.67017 1.38604 m .67237 1.36917 L .67348 1.30494 L F
0 g
.67333 1.31355 m
.67348 1.30494 L
s
.58455 1.41093 m .58585 1.40305 L .58631 1.41216 L 0 .963 .104 r
F
0 g
.58532 1.39872 m
.58585 1.40305 L
s
.58585 1.40305 m
.58814 1.39771 L
s
.59246 1.41455 m .59358 1.41191 L .59403 1.41518 L 0 .92 .162 r
F
.58781 1.41274 m .59358 1.41191 L .59246 1.41455 L F
0 g
.59358 1.41191 m
.59596 1.40409 L
s
.59358 1.41191 m
.59403 1.41518 L
s
.56898 1.37848 m .56451 1.29052 L .56905 1.3785 L 0 .954 .185 r
F
0 g
.56311 1.24182 m
.56451 1.29052 L
s
.56341 1.27643 m
.56451 1.29052 L
s
.56985 .81371 m .59477 .80484 L .59597 .79746 L 0 1 .402 r
F
.56985 .81371 m .58358 .8118 L .59477 .80484 L F
0 g
.59477 .80484 m
.60382 .8079 L
s
.56354 .87526 m .57576 .87408 L .5858 .86648 L 0 1 .371 r
F
0 g
.58424 .86766 m
.5858 .86648 L
s
.5858 .86648 m
.58619 .8667 L
s
.66662 1.40148 m
.66682 1.39895 L
s
.47567 .93141 m .46605 .91406 L .46692 .92243 L 0 .829 .365 r
F
0 g
.45965 .92582 m
.46671 .93367 L
s
.47567 .93141 m .47389 .90992 L .46605 .91406 L 0 .829 .365 r
F
0 g
.45965 .92582 m
.46692 .92243 L
s
.45709 .90541 m
.46605 .91406 L
s
.56985 .81371 m .59597 .79746 L .58622 .79345 L 0 1 .402 r
F
0 g
.59597 .79746 m
.60721 .78948 L
s
.47389 .90992 m .46388 .89387 L .46475 .90182 L 0 .879 .375 r
F
0 g
.45709 .90541 m
.46475 .90182 L
s
.47745 .95414 m .46822 .93534 L .46909 .94418 L 0 .776 .355 r
F
.47745 .95414 m .47567 .93141 L .46822 .93534 L F
0 g
.46219 .94734 m
.46909 .94418 L
s
.46671 .93367 m
.46822 .93534 L
s
.47389 .90992 m .4721 .88956 L .46388 .89387 L 0 .879 .375 r
F
0 g
.45453 .88602 m
.46388 .89387 L
s
.43057 .81646 m .41791 .80574 L .41932 .81167 L 0 1 .428 r
F
0 g
.41052 .81573 m
.41932 .81167 L
s
.55075 1.23581 m .55067 1.19045 L .54897 1.20309 L 0 .273 .23 r
F
0 g
.54533 1.19633 m
.54897 1.20309 L
s
.55075 1.23581 m .55536 1.20211 L .55067 1.19045 L 0 .273 .23 r
F
0 g
.54845 1.16475 m
.55067 1.19045 L
s
.54598 1.24267 m .54638 1.21525 L .54464 1.21881 L 0 .078 .161 r
F
0 g
.54203 1.20974 m
.54464 1.21881 L
s
.56146 .89863 m .58403 .88043 L .57576 .87408 L 0 1 .361 r
F
.56146 .89863 m .58285 .89007 L .58403 .88043 L F
0 g
.58374 .90234 m
.59047 .89523 L
s
.58336 .89042 m
.59047 .89523 L
s
.58403 .88043 m
.58637 .87814 L
s
.4721 .88956 m .46169 .87469 L .46257 .88225 L 0 .927 .384 r
F
0 g
.45453 .88602 m
.46257 .88225 L
s
.62387 1.30666 m .62631 1.20507 L .62371 1.27845 L 0 .995 .099 r
F
0 g
.6247 1.25049 m
.62471 1.21614 L
s
.61411 1.28934 m .62371 1.27845 L .62631 1.20507 L 0 1 .225 r
F
0 g
.62617 1.19916 m
.62631 1.20507 L
s
.62631 1.20507 m
.62786 1.17104 L
s
.62266 1.27963 m
.62305 1.30745 L
s
.4721 .88956 m .47031 .87023 L .46169 .87469 L 0 .927 .384 r
F
0 g
.45196 .86756 m
.46169 .87469 L
s
.56563 .85344 m .58096 .83124 L .56773 .83298 L 0 1 .382 r
F
0 g
.58096 .83124 m
.58997 .8362 L
s
.58096 .83124 m
.59176 .82407 L
s
.56354 .87526 m .57835 .85194 L .56563 .85344 L 0 1 .371 r
F
0 g
.57835 .85194 m
.58737 .84555 L
s
.57835 .85194 m
.58699 .85753 L
s
.56146 .89863 m .57318 .89788 L .58285 .89007 L 0 1 .361 r
F
0 g
.5811 .89148 m
.58285 .89007 L
s
.58285 .89007 m
.58336 .89042 L
s
.43057 .81646 m .42744 .80132 L .41791 .80574 L 0 1 .428 r
F
0 g
.40662 .80124 m
.41791 .80574 L
s
.5791 1.38791 m .57548 1.32507 L .57868 1.38841 L 0 0 .122 r
F
0 g
.57512 1.31652 m
.57548 1.32507 L
s
.57491 1.31623 m
.57548 1.32507 L
s
.5753 1.38064 m
.57627 1.39122 L
s
.58718 .92165 m .58108 .90514 L .57991 .91559 L 0 1 .343 r
F
.58391 .95055 m .58718 .92165 L .57815 .93197 L 0 1 .332 r
F
.60508 .97726 m .60084 .95735 L .59922 .97064 L 0 1 .308 r
F
.58066 .98234 m .60084 .95735 L .59429 .94875 L 0 1 .321 r
F
.58066 .98234 m .59922 .97064 L .60084 .95735 L F
0 g
.60084 .95735 m
.60342 .95326 L
s
.43057 .81646 m .44158 .80135 L .42744 .80132 L 0 1 .428 r
F
0 g
.41791 .80574 m
.42744 .80132 L
s
.43057 .81646 m .45286 .80615 L .44158 .80135 L 0 1 .428 r
F
.43057 .81646 m .45375 .81249 L .45286 .80615 L F
.43057 .81646 m .44419 .81691 L .45375 .81249 L F
0 g
.42142 .82074 m
.43057 .81646 L
s
.41932 .81167 m
.43057 .81646 L
s
.56773 .83298 m .58358 .8118 L .56985 .81371 L 0 1 .392 r
F
0 g
.58358 .8118 m
.59296 .81624 L
s
.58358 .8118 m
.59477 .80484 L
s
.67112 1.38975 m .67548 1.32713 L .67237 1.36917 L 0 0 .055 r
F
.67138 1.39147 m .67548 1.32713 L .67112 1.38975 L F
0 g
.67292 1.33738 m
.67333 1.31355 L
s
.67256 1.35781 m
.67292 1.33738 L
s
.6725 1.36134 m
.67256 1.35781 L
s
.67417 1.3448 m
.67548 1.32713 L
s
.47031 .87023 m .4595 .8564 L .46038 .86361 L 0 .972 .393 r
F
0 g
.45196 .86756 m
.46038 .86361 L
s
.47389 .90992 m .48396 .89177 L .4721 .88956 L 0 .879 .375 r
F
.47389 .90992 m .49312 .89988 L .48396 .89177 L F
.47389 .90992 m .49347 .90848 L .49312 .89988 L F
.47389 .90992 m .48523 .91278 L .49347 .90848 L F
.47567 .93141 m .48523 .91278 L .47389 .90992 L 0 .829 .365 r
F
0 g
.46475 .90182 m
.47389 .90992 L
s
.46605 .91406 m
.47389 .90992 L
s
.56146 .89863 m .57576 .87408 L .56354 .87526 L 0 1 .361 r
F
0 g
.57576 .87408 m
.58424 .86766 L
s
.57576 .87408 m
.58403 .88043 L
s
.59977 .97127 m
.60508 .97726 L
s
.61411 1.28934 m .61574 1.18826 L .61297 1.23483 L 0 1 .225 r
F
0 g
.61408 1.14084 m
.61574 1.18826 L
s
.61574 1.18826 m
.61771 1.17479 L
s
.4721 .88956 m .48268 .87186 L .47031 .87023 L 0 .927 .384 r
F
.4721 .88956 m .49224 .87918 L .48268 .87186 L F
.4721 .88956 m .49259 .88732 L .49224 .87918 L F
.4721 .88956 m .48396 .89177 L .49259 .88732 L F
0 g
.46257 .88225 m
.4721 .88956 L
s
.46388 .89387 m
.4721 .88956 L
s
.47567 .93141 m .494 .92176 L .48523 .91278 L 0 .829 .365 r
F
.47567 .93141 m .49435 .93088 L .494 .92176 L F
.47567 .93141 m .48649 .93501 L .49435 .93088 L F
.47745 .95414 m .48649 .93501 L .47567 .93141 L 0 .776 .355 r
F
0 g
.46692 .92243 m
.47567 .93141 L
s
.46822 .93534 m
.47567 .93141 L
s
.58066 .98234 m .59429 .94875 L .58391 .95055 L 0 1 .321 r
F
0 g
.59429 .94875 m
.60084 .95735 L
s
.59429 .94875 m
.60149 .94048 L
s
.47031 .87023 m .4685 .85183 L .4595 .8564 L 0 .972 .393 r
F
0 g
.44938 .84995 m
.4595 .8564 L
s
.54598 1.24267 m .55075 1.23581 L .54638 1.21525 L 0 .078 .161 r
F
0 g
.54457 1.19493 m
.54638 1.21525 L
s
.55939 .92379 m .58108 .90514 L .57318 .89788 L 0 1 .35 r
F
0 g
.58115 .92854 m
.58718 .92165 L
s
.55939 .92379 m .57991 .91559 L .58108 .90514 L 0 1 .35 r
F
0 g
.58108 .90514 m
.58374 .90234 L
s
.58057 .91614 m
.58718 .92165 L
s
.55536 1.20211 m .56707 1.20982 L .56486 1.17508 L 0 .432 .251 r
F
0 g
.56486 1.17508 m
.57018 1.17209 L
s
.56985 .81371 m .58622 .79345 L .57197 .79548 L 0 1 .402 r
F
0 g
.58622 .79345 m
.59597 .79746 L
s
.59052 1.18258 m .59546 1.19958 L .60105 1.1796 L 0 .903 .248 r
F
0 g
.60105 1.1796 m
.60253 1.2194 L
s
.58854 1.14577 m
.59052 1.18258 L
s
.47031 .87023 m .4814 .85293 L .4685 .85183 L 0 .972 .393 r
F
.47031 .87023 m .49135 .85956 L .4814 .85293 L F
.47031 .87023 m .49171 .86728 L .49135 .85956 L F
.47031 .87023 m .48268 .87186 L .49171 .86728 L F
0 g
.46038 .86361 m
.47031 .87023 L
s
.46169 .87469 m
.47031 .87023 L
s
.47745 .95414 m .49488 .94498 L .48649 .93501 L 0 .776 .355 r
F
.47745 .95414 m .49523 .95466 L .49488 .94498 L F
.47745 .95414 m .48775 .95859 L .49523 .95466 L F
0 g
.46909 .94418 m
.47745 .95414 L
s
.4685 .85183 m .4573 .83894 L .45818 .84583 L 0 1 .402 r
F
0 g
.44938 .84995 m
.45818 .84583 L
s
.55939 .92379 m .57318 .89788 L .56146 .89863 L 0 1 .35 r
F
0 g
.57318 .89788 m
.58108 .90514 L
s
.57318 .89788 m
.5811 .89148 L
s
.55939 .92379 m .57062 .92359 L .57991 .91559 L 0 1 .35 r
F
0 g
.57797 .91726 m
.57991 .91559 L
s
.57991 .91559 m
.58057 .91614 L
s
.56563 .85344 m .55728 .84038 L .55659 .84849 L 0 1 .382 r
F
.56563 .85344 m .56773 .83298 L .55728 .84038 L F
.56354 .87526 m .56563 .85344 L .55556 .86104 L 0 1 .371 r
F
.4685 .85183 m .46669 .83425 L .4573 .83894 L 0 1 .402 r
F
0 g
.44679 .83309 m
.4573 .83894 L
s
.56773 .83298 m .55901 .82089 L .55832 .82855 L 0 1 .392 r
F
.56773 .83298 m .56985 .81371 L .55901 .82089 L F
.4685 .85183 m .48011 .8349 L .46669 .83425 L 0 1 .402 r
F
.4685 .85183 m .49046 .8409 L .48011 .8349 L F
.4685 .85183 m .49081 .84826 L .49046 .8409 L F
.4685 .85183 m .4814 .85293 L .49081 .84826 L F
0 g
.4595 .8564 m
.4685 .85183 L
s
.45818 .84583 m
.4685 .85183 L
s
.58066 .98234 m .59058 .98135 L .59922 .97064 L 0 1 .321 r
F
0 g
.59058 .98135 m
.59922 .97064 L
s
.59922 .97064 m
.59977 .97127 L
s
.56354 .87526 m .55556 .86104 L .55488 .86967 L 0 1 .371 r
F
.56146 .89863 m .56354 .87526 L .55385 .88306 L 0 1 .361 r
F
.61113 1.40421 m .61447 1.39258 L .61478 1.40585 L 0 .998 .153 r
F
0 g
.61447 1.39258 m
.61506 1.38731 L
s
.61413 1.38803 m
.61447 1.39258 L
s
.6637 1.40562 m .66511 1.3905 L .66445 1.40493 L 0 .169 .151 r
F
.66172 1.40783 m .66511 1.3905 L .6637 1.40562 L F
0 g
.66511 1.3905 m
.66565 1.38784 L
s
.56985 .81371 m .56074 .80245 L .56005 .8097 L 0 1 .402 r
F
.56985 .81371 m .57197 .79548 L .56074 .80245 L F
.46669 .83425 m .45509 .82221 L .45597 .82882 L 0 1 .411 r
F
0 g
.44679 .83309 m
.45597 .82882 L
s
.58391 .95055 m .57815 .93197 L .57699 .94335 L 0 1 .332 r
F
.55734 .95098 m .57815 .93197 L .57062 .92359 L 0 1 .34 r
F
.55734 .95098 m .57699 .94335 L .57815 .93197 L F
0 g
.57815 .93197 m
.58115 .92854 L
s
.56146 .89863 m .55385 .88306 L .55317 .89228 L 0 1 .361 r
F
.55939 .92379 m .56146 .89863 L .55215 .90662 L 0 1 .35 r
F
.58066 .98234 m .58391 .95055 L .57524 .96124 L 0 1 .321 r
F
0 g
.57863 .95707 m
.58391 .95055 L
s
.57783 .94423 m
.58391 .95055 L
s
.57521 1.39826 m
.57533 1.39971 L
s
.46669 .83425 m .46487 .81743 L .45509 .82221 L 0 1 .411 r
F
0 g
.44419 .81691 m
.45509 .82221 L
s
.46669 .83425 m .47882 .81767 L .46487 .81743 L 0 1 .411 r
F
.46669 .83425 m .48956 .82311 L .47882 .81767 L F
.46669 .83425 m .48992 .83013 L .48956 .82311 L F
.46669 .83425 m .48011 .8349 L .48992 .83013 L F
0 g
.4573 .83894 m
.46669 .83425 L
s
.45597 .82882 m
.46669 .83425 L
s
.64674 1.37786 m .64538 1.35788 L .64604 1.37767 L 0 .958 .219 r
F
.64535 1.37733 m .64538 1.35794 L .64462 1.37696 L 0 1 .187 r
F
.64604 1.37767 m .64538 1.35794 L .64535 1.37733 L F
.64704 1.3741 m .64081 1.28118 L .64605 1.37408 L 0 .69 .231 r
F
.55734 .95098 m .57062 .92359 L .55939 .92379 L 0 1 .34 r
F
0 g
.57062 .92359 m
.57815 .93197 L
s
.57062 .92359 m
.57797 .91726 L
s
.53257 .87586 m .55556 .86104 L .54635 .85477 L 0 1 .378 r
F
0 g
.55691 .8806 m
.56354 .87526 L
s
.55568 .87019 m
.56354 .87526 L
s
.53257 .87586 m .55488 .86967 L .55556 .86104 L 0 1 .378 r
F
0 g
.55556 .86104 m
.56563 .85344 L
s
.64223 1.37375 m .64082 1.2817 L .63743 1.37333 L 0 .759 .227 r
F
0 g
.64082 1.2817 m
.64223 1.37375 L
s
.64092 1.40815 m
.64268 1.37288 L
s
.64109 1.37365 m
.64111 1.37542 L
s
.64339 1.32694 m
.64605 1.37408 L
s
.64087 1.28232 m
.64339 1.32694 L
s
.64081 1.28118 m
.64087 1.28232 L
s
.53338 .85503 m .55659 .84849 L .55728 .84038 L 0 1 .387 r
F
.53338 .85503 m .54635 .85477 L .55659 .84849 L F
0 g
.55659 .84849 m
.56563 .85344 L
s
.50233 .91664 m .49312 .89988 L .49347 .90848 L 0 .955 .366 r
F
0 g
.48523 .91278 m
.49257 .9203 L
s
.50233 .91664 m .50184 .89465 L .49312 .89988 L 0 .955 .366 r
F
0 g
.48523 .91278 m
.49347 .90848 L
s
.48396 .89177 m
.49312 .89988 L
s
.53257 .87586 m .54503 .87603 L .55488 .86967 L 0 1 .378 r
F
0 g
.55301 .87088 m
.55488 .86967 L
s
.55488 .86967 m
.55568 .87019 L
s
.53338 .85503 m .55728 .84038 L .54769 .83475 L 0 1 .387 r
F
0 g
.55728 .84038 m
.56773 .83298 L
s
.50184 .89465 m .49224 .87918 L .49259 .88732 L 0 1 .375 r
F
0 g
.48396 .89177 m
.49259 .88732 L
s
.50184 .89465 m .50135 .87388 L .49224 .87918 L 0 1 .375 r
F
0 g
.48268 .87186 m
.49224 .87918 L
s
.50282 .94001 m .494 .92176 L .49435 .93088 L 0 .905 .356 r
F
0 g
.48649 .93501 m
.4934 .94322 L
s
.50282 .94001 m .50233 .91664 L .494 .92176 L 0 .905 .356 r
F
0 g
.48649 .93501 m
.49435 .93088 L
s
.49257 .9203 m
.494 .92176 L
s
.58442 1.28878 m .59052 1.1826 L .58506 1.19743 L 0 .747 .245 r
F
.58724 1.33996 m .58922 1.25351 L .58612 1.26337 L 0 .377 .228 r
F
.58442 1.28878 m .59545 1.1996 L .59052 1.1826 L 0 .747 .245 r
F
.53177 .89801 m .55385 .88306 L .54503 .87603 L 0 1 .368 r
F
0 g
.55413 .89302 m
.56146 .89863 L
s
.53177 .89801 m .55317 .89228 L .55385 .88306 L 0 1 .368 r
F
0 g
.55385 .88306 m
.55691 .8806 L
s
.5342 .83535 m .55832 .82855 L .55901 .82089 L 0 1 .397 r
F
.5342 .83535 m .54769 .83475 L .55832 .82855 L F
0 g
.55832 .82855 m
.56773 .83298 L
s
.50135 .87388 m .49135 .85956 L .49171 .86728 L 0 1 .385 r
F
0 g
.48268 .87186 m
.49171 .86728 L
s
.53257 .87586 m .54635 .85477 L .53338 .85503 L 0 1 .378 r
F
0 g
.54635 .85477 m
.55556 .86104 L
s
.54635 .85477 m
.55659 .84849 L
s
.50184 .89465 m .51385 .87494 L .50135 .87388 L 0 1 .375 r
F
.50184 .89465 m .5231 .88227 L .51385 .87494 L F
.50184 .89465 m .52294 .89097 L .5231 .88227 L F
.50184 .89465 m .51382 .89628 L .52294 .89097 L F
.50233 .91664 m .51382 .89628 L .50184 .89465 L 0 .955 .366 r
F
0 g
.49259 .88732 m
.50184 .89465 L
s
.49312 .89988 m
.50184 .89465 L
s
.53177 .89801 m .54503 .87603 L .53257 .87586 L 0 1 .368 r
F
0 g
.54503 .87603 m
.55301 .87088 L
s
.54503 .87603 m
.55385 .88306 L
s
.5342 .83535 m .55901 .82089 L .54903 .81581 L 0 1 .397 r
F
0 g
.55901 .82089 m
.56985 .81371 L
s
.53177 .89801 m .54371 .89869 L .55317 .89228 L 0 1 .368 r
F
0 g
.55113 .89366 m
.55317 .89228 L
s
.55317 .89228 m
.55413 .89302 L
s
.55356 .90541 m
.56146 .89863 L
s
.50135 .87388 m .50085 .8542 L .49135 .85956 L 0 1 .385 r
F
0 g
.4814 .85293 m
.49135 .85956 L
s
.50135 .87388 m .51388 .85479 L .50085 .8542 L 0 1 .385 r
F
.50135 .87388 m .52352 .86138 L .51388 .85479 L F
.50135 .87388 m .52336 .86959 L .52352 .86138 L F
.50135 .87388 m .51385 .87494 L .52336 .86959 L F
0 g
.49171 .86728 m
.50135 .87388 L
s
.49224 .87918 m
.50135 .87388 L
s
.59515 1.29699 m .59659 1.19876 L .59371 1.22576 L 0 .627 .24 r
F
0 g
.59659 1.19876 m
.60201 1.20545 L
s
.59648 1.19593 m
.59659 1.19876 L
s
.59546 1.19958 m
.60105 1.1796 L
s
.55734 .95098 m .56807 .95151 L .57699 .94335 L 0 1 .34 r
F
0 g
.57483 .94532 m
.57699 .94335 L
s
.57699 .94335 m
.57783 .94423 L
s
.53338 .85503 m .54769 .83475 L .5342 .83535 L 0 1 .387 r
F
0 g
.54769 .83475 m
.55728 .84038 L
s
.54769 .83475 m
.55832 .82855 L
s
.50233 .91664 m .52269 .90444 L .51382 .89628 L 0 .955 .366 r
F
.50233 .91664 m .52252 .9137 L .52269 .90444 L F
.50233 .91664 m .51379 .91893 L .52252 .9137 L F
.50282 .94001 m .51379 .91893 L .50233 .91664 L 0 .905 .356 r
F
0 g
.49347 .90848 m
.50233 .91664 L
s
.494 .92176 m
.50233 .91664 L
s
.46487 .81743 m .45286 .80615 L .45375 .81249 L 0 1 .419 r
F
0 g
.44419 .81691 m
.45375 .81249 L
s
.5033 .9649 m .49488 .94498 L .49523 .95466 L 0 .853 .346 r
F
.5033 .9649 m .50282 .94001 L .49488 .94498 L F
0 g
.48775 .95859 m
.49523 .95466 L
s
.4934 .94322 m
.49488 .94498 L
s
.55536 1.20211 m .56498 1.2338 L .56707 1.20982 L 0 .432 .251 r
F
.55536 1.20211 m .55994 1.23045 L .56498 1.2338 L F
.55075 1.23581 m .55994 1.23045 L .55536 1.20211 L 0 .273 .23 r
F
0 g
.55067 1.19045 m
.55536 1.20211 L
s
.55319 1.16748 m
.55536 1.20211 L
s
.53501 .8167 m .56005 .8097 L .56074 .80245 L 0 1 .406 r
F
.53501 .8167 m .54903 .81581 L .56005 .8097 L F
0 g
.56005 .8097 m
.56985 .81371 L
s
.56395 1.37573 m .55983 1.29987 L .56395 1.37574 L 0 .996 .166 r
F
0 g
.55808 1.2381 m
.55983 1.29987 L
s
.55742 1.26934 m
.55983 1.29987 L
s
.53097 .92164 m .54371 .89869 L .53177 .89801 L 0 1 .358 r
F
.53097 .92164 m .55215 .90662 L .54371 .89869 L F
0 g
.54371 .89869 m
.55113 .89366 L
s
.53257 .87586 m .52352 .86138 L .52336 .86959 L 0 1 .378 r
F
.53257 .87586 m .53338 .85503 L .52352 .86138 L F
0 g
.52336 .86959 m
.52464 .87046 L
s
.53177 .89801 m .53257 .87586 L .5231 .88227 L 0 1 .368 r
F
0 g
.52464 .87046 m
.53257 .87586 L
s
.59719 1.38808 m
.59722 1.38869 L
s
.55939 .92379 m .55215 .90662 L .55147 .91651 L 0 1 .35 r
F
.55734 .95098 m .55939 .92379 L .55046 .93193 L 0 1 .34 r
F
0 g
.55263 .91757 m
.55939 .92379 L
s
.51385 .87494 m
.52336 .86959 L
s
.50085 .8542 m .49046 .8409 L .49081 .84826 L 0 1 .394 r
F
.50085 .8542 m .50035 .83552 L .49046 .8409 L F
0 g
.4814 .85293 m
.49081 .84826 L
s
.48011 .8349 m
.49046 .8409 L
s
.50085 .8542 m .51391 .83568 L .50035 .83552 L 0 1 .394 r
F
.50085 .8542 m .52395 .84164 L .51391 .83568 L F
.50085 .8542 m .52378 .8494 L .52395 .84164 L F
.50085 .8542 m .51388 .85479 L .52378 .8494 L F
0 g
.49135 .85956 m
.50085 .8542 L
s
.49081 .84826 m
.50085 .8542 L
s
.46487 .81743 m .46305 .80128 L .45286 .80615 L 0 1 .419 r
F
0 g
.44158 .80135 m
.45286 .80615 L
s
.46487 .81743 m .47752 .80115 L .46305 .80128 L 0 1 .419 r
F
.46487 .81743 m .48866 .8061 L .47752 .80115 L F
.46487 .81743 m .48902 .81281 L .48866 .8061 L F
.46487 .81743 m .47882 .81767 L .48902 .81281 L F
0 g
.45509 .82221 m
.46487 .81743 L
s
.45375 .81249 m
.46487 .81743 L
s
.54598 1.24267 m .55485 1.26703 L .55075 1.23581 L 0 .078 .161 r
F
.54598 1.24267 m .55623 1.29122 L .55485 1.26703 L F
.54598 1.24267 m .55395 1.29202 L .55623 1.29122 L F
.54598 1.24267 m .54955 1.27113 L .55395 1.29202 L F
0 g
.54462 1.23356 m
.54598 1.24267 L
s
.54464 1.21881 m
.54598 1.24267 L
s
.53338 .85503 m .52395 .84164 L .52378 .8494 L 0 1 .387 r
F
.53338 .85503 m .5342 .83535 L .52395 .84164 L F
0 g
.52378 .8494 m
.52489 .85006 L
s
.52489 .85006 m
.53338 .85503 L
s
.52352 .86138 m
.53338 .85503 L
s
.53097 .92164 m .55147 .91651 L .55215 .90662 L 0 1 .358 r
F
0 g
.54371 .89869 m
.55215 .90662 L
s
.55215 .90662 m
.55356 .90541 L
s
.66511 1.38108 m .6676 1.30568 L .66438 1.37401 L 0 1 .129 r
F
.6661 1.38205 m .6676 1.30568 L .66511 1.38108 L F
0 g
.66758 1.3007 m
.6676 1.30568 L
s
.6676 1.30568 m
.67148 1.27652 L
s
.57434 1.37968 m .57313 1.31377 L .57512 1.37986 L 0 .863 .2 r
F
0 g
.57313 1.31377 m
.5739 1.33931 L
s
.57313 1.31377 m
.5733 1.314 L
s
.5733 1.314 m
.57333 1.31403 L
s
.57459 1.37974 m
.57478 1.38189 L
s
.57405 1.37962 m
.57467 1.38821 L
s
.57434 1.37968 m
.57573 1.39353 L
s
.53177 .89801 m .5231 .88227 L .52294 .89097 L 0 1 .368 r
F
0 g
.52294 .89097 m
.52443 .89216 L
s
.51382 .89628 m
.52294 .89097 L
s
.51385 .87494 m
.5231 .88227 L
s
.5231 .88227 m
.53257 .87586 L
s
.53097 .92164 m .53177 .89801 L .52269 .90444 L 0 1 .358 r
F
0 g
.52443 .89216 m
.53177 .89801 L
s
.65663 1.40458 m .66197 1.38979 L .66004 1.40329 L 0 .338 .187 r
F
.65475 1.40538 m .66197 1.38979 L .65663 1.40458 L F
.66141 1.40281 m .66197 1.38979 L .66561 1.38659 L 0 .252 .179 r
F
.66004 1.40329 m .66197 1.38979 L .66141 1.40281 L F
0 g
.66197 1.38979 m
.66221 1.38527 L
s
.66197 1.38979 m
.66384 1.38815 L
s
.53501 .8167 m .56074 .80245 L .55037 .79784 L 0 1 .406 r
F
0 g
.56074 .80245 m
.57197 .79548 L
s
.51388 .85479 m
.52378 .8494 L
s
.51388 .85479 m
.52352 .86138 L
s
.57685 1.40349 m .57656 1.39435 L .57792 1.405 L 0 .852 .08 r
F
0 g
.57719 1.39052 m
.57867 1.40605 L
s
.57672 1.40329 m .57656 1.39435 L .57685 1.40349 L 0 0 .058 r
F
0 g
.57627 1.39122 m
.57656 1.39435 L
s
.57584 1.39463 m
.5767 1.40324 L
s
.57656 1.39435 m
.57792 1.405 L
s
.5342 .83535 m .54903 .81581 L .53501 .8167 L 0 1 .397 r
F
0 g
.54903 .81581 m
.55901 .82089 L
s
.54903 .81581 m
.56005 .8097 L
s
.45286 .80615 m
.46305 .80128 L
s
.50282 .94001 m .52227 .92807 L .51379 .91893 L 0 .905 .356 r
F
.50282 .94001 m .5221 .93795 L .52227 .92807 L F
.50282 .94001 m .51376 .94308 L .5221 .93795 L F
.5033 .9649 m .51376 .94308 L .50282 .94001 L 0 .853 .346 r
F
0 g
.49488 .94498 m
.50282 .94001 L
s
.49435 .93088 m
.50282 .94001 L
s
.5342 .83535 m .52437 .82291 L .5242 .83028 L 0 1 .397 r
F
.5342 .83535 m .53501 .8167 L .52437 .82291 L F
.53097 .92164 m .54239 .92295 L .55147 .91651 L 0 1 .358 r
F
0 g
.55147 .91651 m
.55263 .91757 L
s
.57799 1.25204 m .58724 1.33996 L .58117 1.24975 L 0 0 .088 r
F
.58814 1.35811 m .57799 1.25204 L .58631 1.36071 L F
.58814 1.35811 m .58724 1.33996 L .57799 1.25204 L F
.58631 1.36071 m .57799 1.25204 L .58535 1.36232 L F
.58535 1.36232 m .57799 1.25204 L .58492 1.36347 L F
.58492 1.36347 m .57799 1.25204 L .58186 1.32076 L F
0 g
.57792 1.24522 m
.57799 1.25204 L
s
.57685 1.23243 m
.57799 1.25204 L
s
.53097 .92164 m .52269 .90444 L .52252 .9137 L 0 1 .358 r
F
0 g
.51379 .91893 m
.52252 .9137 L
s
.51382 .89628 m
.52269 .90444 L
s
.52269 .90444 m
.53177 .89801 L
s
.50035 .83552 m .48956 .82311 L .48992 .83013 L 0 1 .403 r
F
.50035 .83552 m .49985 .81771 L .48956 .82311 L F
0 g
.48011 .8349 m
.48992 .83013 L
s
.50035 .83552 m .51393 .81752 L .49985 .81771 L 0 1 .403 r
F
.50035 .83552 m .52437 .82291 L .51393 .81752 L F
0 g
.52395 .84164 m
.52713 .83969 L
s
.52713 .83969 m
.5342 .83535 L
s
.52517 .83078 m
.5342 .83535 L
s
.50035 .83552 m .5242 .83028 L .52437 .82291 L 0 1 .403 r
F
.50035 .83552 m .51391 .83568 L .5242 .83028 L F
0 g
.49046 .8409 m
.50035 .83552 L
s
.48992 .83013 m
.50035 .83552 L
s
.5242 .83028 m
.52517 .83078 L
s
.51391 .83568 m
.52395 .84164 L
s
.53017 .94694 m .54239 .92295 L .53097 .92164 L 0 .991 .348 r
F
.53017 .94694 m .55046 .93193 L .54239 .92295 L F
0 g
.54239 .92295 m
.55147 .91651 L
s
.51391 .83568 m
.5242 .83028 L
s
.55529 .98053 m .56807 .95151 L .55734 .95098 L 0 1 .33 r
F
.55529 .98053 m .57524 .96124 L .56807 .95151 L F
0 g
.56807 .95151 m
.57483 .94532 L
s
.47882 .81767 m
.48956 .82311 L
s
.53017 .94694 m .53097 .92164 L .52227 .92807 L 0 .991 .348 r
F
0 g
.52252 .9137 m
.53097 .92164 L
s
.58171 1.23746 m
.58174 1.23764 L
s
.58045 1.23001 m
.58069 1.23679 L
s
.58069 1.23679 m
.58117 1.24975 L
s
.53501 .8167 m .5248 .80508 L .52462 .8121 L 0 1 .406 r
F
.53501 .8167 m .53584 .79896 L .5248 .80508 L F
.53501 .8167 m .55037 .79784 L .53584 .79896 L F
0 g
.55037 .79784 m
.56074 .80245 L
s
.52437 .82291 m
.53501 .8167 L
s
.54855 1.27251 m .55047 1.2812 L .54813 1.26605 L 0 .597 .015 r
F
0 g
.54813 1.26605 m
.54833 1.26914 L
s
.54701 1.2586 m
.54813 1.26605 L
s
.54855 1.27251 m .55486 1.32057 L .55047 1.2812 L 0 .597 .015 r
F
.55887 1.36996 m .55574 1.3333 L .55905 1.37023 L 0 .833 .077 r
F
.55869 1.36968 m .55816 1.36322 L .55887 1.36996 L F
.55816 1.36322 m .55574 1.3333 L .55887 1.36996 L F
.55905 1.37023 m .55574 1.3333 L .55853 1.35887 L F
.5589 1.36572 m .55879 1.36464 L .55877 1.36815 L F
.55879 1.36464 m .55574 1.3333 L .55838 1.36372 L F
.55879 1.36464 m .55838 1.36372 L .55877 1.36815 L F
.55905 1.37023 m .55853 1.35887 L .55951 1.37093 L F
.5589 1.36572 m .55881 1.36469 L .55574 1.3333 L F
.55862 1.36911 m .55795 1.36078 L .55869 1.36968 L F
.55795 1.36078 m .55574 1.3333 L .55816 1.36322 L F
.55795 1.36078 m .55816 1.36322 L .55869 1.36968 L F
.55877 1.36815 m .55838 1.36372 L .55862 1.36911 L F
.55838 1.36372 m .55574 1.3333 L .55795 1.36078 L F
.55838 1.36372 m .55795 1.36078 L .55862 1.36911 L F
.54855 1.27251 m .55586 1.33574 L .55881 1.36469 L 0 .597 .015 r
F
.55558 1.33374 m .55881 1.36469 L .55623 1.33941 L F
.54984 1.28377 m .55633 1.3423 L .55558 1.33374 L F
.55633 1.3423 m .55881 1.36469 L .55558 1.33374 L F
.55574 1.3333 m .55881 1.36469 L .55586 1.33574 L 0 .833 .077 r
F
.55623 1.33941 m .55881 1.36469 L .55838 1.35816 L 0 .597 .015 r
F
.54855 1.27251 m .55047 1.28972 L .54984 1.28377 L F
.55047 1.28972 m .55881 1.36469 L .54984 1.28377 L F
.54855 1.27251 m .55146 1.29629 L .55586 1.33574 L F
.54855 1.27251 m .55838 1.35816 L .55486 1.32057 L F
0 g
.54833 1.26914 m
.54855 1.27251 L
s
.54752 1.26288 m
.54855 1.27251 L
s
.58066 .98234 m .57524 .96124 L .57408 .97371 L 0 1 .321 r
F
.55529 .98053 m .57408 .97371 L .57524 .96124 L 0 1 .33 r
F
0 g
.56807 .95151 m
.57524 .96124 L
s
.57524 .96124 m
.57863 .95707 L
s
.55734 .95098 m .55046 .93193 L .54979 .94259 L 0 1 .34 r
F
.53017 .94694 m .54979 .94259 L .55046 .93193 L 0 .991 .348 r
F
0 g
.54239 .92295 m
.55046 .93193 L
s
.55046 .93193 m
.55939 .92379 L
s
.5033 .9649 m .52186 .95331 L .51376 .94308 L 0 .853 .346 r
F
.53017 .94694 m .52227 .92807 L .5221 .93795 L 0 .991 .348 r
F
0 g
.51376 .94308 m
.5221 .93795 L
s
.51379 .91893 m
.52227 .92807 L
s
.52227 .92807 m
.53097 .92164 L
s
.5033 .9649 m .52169 .96391 L .52186 .95331 L 0 .853 .346 r
F
.5033 .9649 m .51373 .96887 L .52169 .96391 L F
0 g
.49523 .95466 m
.5033 .9649 L
s
.66464 1.40075 m .66561 1.38659 L .66594 1.39948 L 0 .252 .179 r
F
.66141 1.40281 m .66561 1.38659 L .66464 1.40075 L F
0 g
.66384 1.38815 m
.66561 1.38659 L
s
.66561 1.38659 m
.66594 1.38189 L
s
.66445 1.40493 m
.66464 1.40075 L
s
.61046 1.26782 m
.61234 1.23565 L
s
.49985 .81771 m .48866 .8061 L .48902 .81281 L 0 1 .411 r
F
.49985 .81771 m .49935 .80068 L .48866 .8061 L F
0 g
.47882 .81767 m
.48902 .81281 L
s
.49985 .81771 m .51396 .80018 L .49935 .80068 L 0 1 .411 r
F
.49985 .81771 m .5248 .80508 L .51396 .80018 L F
0 g
.52548 .81248 m
.53501 .8167 L
s
.49985 .81771 m .52462 .8121 L .5248 .80508 L 0 1 .411 r
F
.49985 .81771 m .51393 .81752 L .52462 .8121 L F
0 g
.51393 .81752 m
.52437 .82291 L
s
.48956 .82311 m
.49985 .81771 L
s
.48902 .81281 m
.49985 .81771 L
s
.52462 .8121 m
.52548 .81248 L
s
.51393 .81752 m
.52462 .8121 L
s
.55529 .98053 m .55734 .95098 L .54878 .95924 L 0 1 .33 r
F
0 g
.5512 .94416 m
.55734 .95098 L
s
.57875 1.38078 m .5776 1.31996 L .57909 1.38086 L 0 .718 .217 r
F
.57909 1.38086 m .5776 1.31996 L .57971 1.3809 L F
.57971 1.3809 m .5776 1.31996 L .58131 1.38092 L F
0 g
.5776 1.31996 m
.57875 1.38078 L
s
.57333 1.31403 m
.5776 1.31996 L
s
.55144 1.28511 m
.55357 1.30894 L
s
.55144 1.28511 m
.55145 1.28995 L
s
.60141 1.38149 m
.60191 1.38933 L
s
.53017 .94694 m .54109 .94903 L .54979 .94259 L 0 .991 .348 r
F
0 g
.54979 .94259 m
.5512 .94416 L
s
.57516 .97512 m
.58066 .98234 L
s
.65059 1.37462 m .65085 1.29405 L .64958 1.37416 L 0 1 .199 r
F
.65337 1.37586 m .65085 1.29405 L .65059 1.37462 L F
0 g
.64766 1.06601 m
.65085 1.29405 L
s
.65085 1.29405 m
.65514 1.26673 L
s
.52937 .97413 m .53017 .94694 L .52186 .95331 L 0 .938 .338 r
F
.52937 .97413 m .54109 .94903 L .53017 .94694 L F
0 g
.5221 .93795 m
.53017 .94694 L
s
.5248 .80508 m
.53584 .79896 L
s
.47752 .80115 m
.48866 .8061 L
s
.52937 .97413 m .54878 .95924 L .54109 .94903 L 0 .938 .338 r
F
0 g
.54109 .94903 m
.54979 .94259 L
s
.55529 .98053 m .56553 .98199 L .57408 .97371 L 0 1 .33 r
F
0 g
.56553 .98199 m
.57408 .97371 L
s
.57408 .97371 m
.57516 .97512 L
s
.58724 1.33996 m .59515 1.29699 L .58922 1.25351 L 0 .377 .228 r
F
.58442 1.28878 m .59728 1.25346 L .59545 1.1996 L 0 .747 .245 r
F
.52937 .97413 m .52186 .95331 L .52169 .96391 L 0 .938 .338 r
F
0 g
.52186 .95331 m
.53017 .94694 L
s
.51376 .94308 m
.52186 .95331 L
s
.48866 .8061 m
.49935 .80068 L
s
.51396 .80018 m
.5248 .80508 L
s
.51373 .96887 m
.52169 .96391 L
s
.58442 1.28878 m .58506 1.19743 L .58268 1.23443 L 0 .747 .245 r
F
0 g
.58277 1.2437 m
.58302 1.24517 L
s
.58174 1.23764 m
.58277 1.2437 L
s
.57229 1.21292 m .58268 1.23443 L .58506 1.19743 L 0 .659 .254 r
F
0 g
.58289 1.15673 m
.58506 1.19743 L
s
.58506 1.19743 m
.59052 1.1826 L
s
.58045 1.23001 m
.58171 1.23746 L
s
.55529 .98053 m .54878 .95924 L .54811 .97078 L 0 1 .33 r
F
.52937 .97413 m .54811 .97078 L .54878 .95924 L 0 .938 .338 r
F
0 g
.54109 .94903 m
.54878 .95924 L
s
.54878 .95924 m
.55734 .95098 L
s
.5761 1.39381 m .57487 1.36802 L .57604 1.39404 L 0 0 .065 r
F
.57603 1.39342 m .57487 1.36802 L .57605 1.39355 L F
.57605 1.39355 m .57487 1.36802 L .57609 1.39367 L F
.57606 1.39324 m .57487 1.36802 L .57603 1.39342 L F
0 g
.57362 1.37952 m
.57448 1.39038 L
s
.57609 1.39367 m .57487 1.36802 L .5761 1.39381 L 0 0 .065 r
F
.57604 1.39404 m .57487 1.36802 L .57567 1.39175 L F
0 g
.57487 1.36802 m
.57591 1.3902 L
s
.57468 1.36507 m
.57487 1.36802 L
s
.57408 1.37962 m
.5759 1.40163 L
s
.57452 1.34582 m
.5757 1.37491 L
s
.57448 1.39038 m
.57514 1.39862 L
s
.57509 1.37879 m
.57512 1.37986 L
s
.57497 1.37466 m
.57509 1.37879 L
s
.5739 1.33931 m
.57497 1.37466 L
s
.57467 1.38821 m
.57528 1.39667 L
s
.65752 1.38089 m
.65771 1.3778 L
s
.65887 1.35968 m
.65903 1.35718 L
s
.55075 1.23581 m .56176 1.26346 L .55994 1.23045 L 0 .273 .23 r
F
.55075 1.23581 m .55958 1.27897 L .56176 1.26346 L F
.55075 1.23581 m .55485 1.26703 L .55958 1.27897 L F
0 g
.54897 1.20309 m
.55075 1.23581 L
s
.54638 1.21525 m
.55075 1.23581 L
s
.52937 .97413 m .53979 .97717 L .54811 .97078 L 0 .938 .338 r
F
0 g
.52169 .96391 m
.52937 .97413 L
s
.54811 .97078 m
.55529 .98053 L
s
.53979 .97717 m
.54811 .97078 L
s
.58249 1.26948 m
.58339 1.28283 L
s
.58117 1.24975 m
.58249 1.26948 L
s
.56677 1.28081 m .56707 1.20982 L .56498 1.2338 L 0 .498 .245 r
F
.56677 1.28081 m .57229 1.21292 L .56707 1.20982 L F
0 g
.56486 1.17508 m
.56707 1.20982 L
s
.59641 1.38829 m
.59647 1.38985 L
s
.59719 1.38808 m
.59723 1.38868 L
s
.59735 1.35196 m .60253 1.21942 L .59728 1.25346 L 0 .861 .234 r
F
.59827 1.35228 m .60253 1.21942 L .59735 1.35196 L F
0 g
.58427 1.36476 m
.58433 1.36644 L
s
.57229 1.21292 m .57719 1.24112 L .58268 1.23443 L 0 .659 .254 r
F
.56677 1.28081 m .57719 1.24112 L .57229 1.21292 L 0 .498 .245 r
F
0 g
.56707 1.20982 m
.57229 1.21292 L
s
.57018 1.17209 m
.57229 1.21292 L
s
.66603 1.38916 m
.66628 1.38222 L
s
.66839 1.39531 m
.66931 1.38517 L
s
.66829 1.39637 m
.66839 1.39531 L
s
.66836 1.39483 m
.66931 1.38517 L
s
.6073 1.24232 m
.6078 1.26496 L
s
.6078 1.26496 m
.60857 1.30006 L
s
.55994 1.23045 m
.56498 1.2338 L
s
.54955 1.27113 m
.54964 1.27155 L
s
.54964 1.27155 m
.55036 1.27499 L
s
.55036 1.27499 m
.55107 1.27832 L
s
.54955 1.27113 m
.5496 1.27171 L
s
.5496 1.27171 m
.55047 1.2812 L
s
.62532 1.36103 m .62669 1.27004 L .62387 1.3067 L 0 1 .178 r
F
0 g
.62469 1.29601 m
.62469 1.29597 L
s
.62425 1.30171 m
.62425 1.30175 L
s
.62454 1.33178 m
.62468 1.34721 L
s
.62783 1.3625 m .62669 1.27004 L .62532 1.36103 L 0 1 .178 r
F
0 g
.62669 1.27004 m
.62783 1.3625 L
s
.5915 1.37786 m
.59154 1.37957 L
s
.60825 1.24107 m
.61297 1.23483 L
s
.6072 1.24245 m
.60825 1.24107 L
s
.55047 1.2812 m
.55297 1.30361 L
s
.57604 1.39404 m .57567 1.39175 L .57582 1.39495 L 0 0 .065 r
F
0 g
.57567 1.39175 m
.57582 1.39495 L
s
.57478 1.38189 m
.57567 1.39175 L
s
.5757 1.37491 m
.5764 1.39202 L
s
.57591 1.3902 m
.57606 1.39324 L
s
.67112 1.38975 m .67237 1.36917 L .67111 1.38778 L 0 0 .055 r
F
.67111 1.38778 m .67237 1.36917 L .67126 1.38728 L F
.67126 1.38728 m .67237 1.36917 L .67017 1.38604 L 0 1 .129 r
F
0 g
.67237 1.36917 m
.6725 1.36134 L
s
.67237 1.36917 m
.67417 1.3448 L
s
.58268 1.23443 m
.58421 1.28207 L
s
.57961 1.23816 m
.58268 1.23443 L
s
.57907 1.23882 m
.57961 1.23816 L
s
.55485 1.26703 m
.55525 1.26804 L
s
.58971 1.37366 m
.59018 1.3817 L
s
.58909 1.37289 m
.58923 1.37989 L
s
.58923 1.37989 m
.58926 1.38139 L
s
.58916 1.37318 m
.58935 1.38085 L
s
.58935 1.38085 m
.58937 1.38164 L
s
.66292 1.38596 m .66298 1.37318 L .66253 1.38555 L 0 1 .126 r
F
0 g
.66292 1.38596 m
.66298 1.37318 L
s
.66298 1.37318 m
.66349 1.3712 L
s
.56677 1.28081 m .57905 1.28827 L .57719 1.24112 L 0 .498 .245 r
F
0 g
.57719 1.24112 m
.57907 1.23882 L
s
.56028 1.36549 m
.56085 1.37282 L
s
.55795 1.33563 m
.55832 1.35029 L
s
.56097 1.32311 m .56176 1.26346 L .55958 1.27897 L 0 .293 .228 r
F
0 g
.55525 1.26804 m
.55958 1.27897 L
s
.56097 1.32311 m .56677 1.28081 L .56176 1.26346 L 0 .293 .228 r
F
0 g
.55994 1.23045 m
.56176 1.26346 L
s
.55486 1.32057 m .55623 1.29122 L .55395 1.29202 L 0 .053 .147 r
F
0 g
.55107 1.27832 m
.55395 1.29202 L
s
.62378 1.29096 m
.62387 1.30666 L
s
.61702 1.35984 m .61797 1.28817 L .6169 1.35875 L 0 0 0 r
F
.61728 1.36124 m .61797 1.28817 L .61702 1.35984 L F
.6169 1.35875 m .61797 1.28817 L .61399 1.35767 L 0 1 .21 r
F
.61411 1.28934 m .61846 1.31508 L .62371 1.27845 L 0 1 .225 r
F
0 g
.61848 1.31493 m
.6187 1.3134 L
s
.61846 1.31508 m
.61848 1.31493 L
s
.62371 1.27845 m
.62378 1.29096 L
s
.61297 1.23483 m
.61411 1.28934 L
s
.59921 1.35431 m .58724 1.33996 L .59506 1.35584 L 0 .377 .228 r
F
.59644 1.35173 m .59728 1.25346 L .59472 1.30892 L 0 .861 .234 r
F
.59735 1.35196 m .59728 1.25346 L .59644 1.35173 L F
.58442 1.28878 m .59472 1.30892 L .59728 1.25346 L 0 .747 .245 r
F
0 g
.59728 1.25346 m
.60253 1.21942 L
s
.59545 1.1996 m
.59728 1.25346 L
s
.65915 1.37845 m .65898 1.357 L .65816 1.378 L 0 1 .199 r
F
0 g
.65898 1.357 m
.65915 1.37845 L
s
.55486 1.32057 m .56097 1.32311 L .55623 1.29122 L 0 .053 .147 r
F
0 g
.55485 1.26703 m
.55623 1.29122 L
s
.64462 1.37696 m
.64528 1.36043 L
s
.66511 1.38108 m .66438 1.37401 L .66427 1.38004 L 0 1 .129 r
F
0 g
.66427 1.38004 m
.66438 1.37401 L
s
.65898 1.357 m
.66438 1.37401 L
s
.58492 1.36347 m .58186 1.32076 L .58474 1.36396 L 0 0 .088 r
F
0 g
.58409 1.35423 m
.58474 1.36396 L
s
.56677 1.28081 m .57659 1.32301 L .57905 1.28827 L 0 .498 .245 r
F
.56677 1.28081 m .5713 1.31976 L .57659 1.32301 L F
.56097 1.32311 m .5713 1.31976 L .56677 1.28081 L 0 .293 .228 r
F
0 g
.56498 1.2338 m
.56677 1.28081 L
s
.56176 1.26346 m
.56677 1.28081 L
s
.5642 1.35768 m .55486 1.32057 L .56326 1.35871 L 0 .053 .147 r
F
.5642 1.35768 m .56097 1.32311 L .55486 1.32057 L F
.56326 1.35871 m .55486 1.32057 L .56089 1.36132 L F
.56089 1.36132 m .55486 1.32057 L .55984 1.3625 L F
0 g
.56003 1.36228 m
.56028 1.36549 L
s
.55984 1.3625 m .55486 1.32057 L .55838 1.35816 L 0 .053 .147 r
F
0 g
.55395 1.29202 m
.55486 1.32057 L
s
.55297 1.30361 m
.55486 1.32057 L
s
.55852 1.35858 m
.55853 1.35887 L
s
.62336 1.35888 m .62387 1.3067 L .62237 1.35815 L 0 1 .178 r
F
0 g
.6187 1.3134 m
.61932 1.30904 L
s
.62317 1.3161 m
.6233 1.32607 L
s
.62532 1.36103 m .62387 1.3067 L .62336 1.35888 L 0 1 .178 r
F
0 g
.62376 1.35932 m
.62393 1.37156 L
s
.62119 1.29603 m
.62371 1.27845 L
s
.61932 1.30904 m
.62119 1.29603 L
s
.62237 1.35815 m
.62387 1.3067 L
s
.62468 1.36366 m
.62468 1.36033 L
s
.61199 1.35434 m .61411 1.28937 L .60877 1.31405 L 0 .846 .233 r
F
0 g
.60857 1.30006 m
.61046 1.26782 L
s
.61595 1.35555 m .61411 1.28937 L .61199 1.35434 L 0 .846 .233 r
F
.61595 1.35555 m .61845 1.31512 L .61411 1.28937 L F
0 g
.55878 1.36191 m
.55951 1.37093 L
s
.55853 1.35887 m
.55878 1.36191 L
s
.57846 1.35242 m .57905 1.28827 L .57659 1.32301 L 0 .588 .245 r
F
.58052 1.35221 m .57905 1.28827 L .57846 1.35242 L F
.58052 1.35221 m .58442 1.28878 L .57905 1.28827 L F
0 g
.57905 1.28827 m
.58143 1.2885 L
s
.57719 1.24112 m
.57905 1.28827 L
s
.58339 1.28283 m
.58379 1.28872 L
s
.58442 1.28878 m .58918 1.32424 L .59472 1.30892 L 0 .747 .245 r
F
.58461 1.352 m .58442 1.28878 L .58052 1.35221 L 0 .588 .245 r
F
0 g
.58395 1.35203 m
.58409 1.35423 L
s
.58378 1.35204 m
.58427 1.36476 L
s
.58461 1.352 m .58918 1.32424 L .58442 1.28878 L 0 .588 .245 r
F
0 g
.58421 1.28207 m
.58442 1.28878 L
s
.58143 1.2885 m
.58442 1.28878 L
s
.62475 1.36991 m
.62475 1.37006 L
s
.61907 1.35601 m .61845 1.31512 L .61595 1.35555 L 0 .846 .233 r
F
0 g
.61846 1.31566 m
.61907 1.35601 L
s
.61845 1.31512 m
.61846 1.31566 L
s
.57243 1.35428 m .56097 1.32311 L .57015 1.35529 L 0 .293 .228 r
F
.57243 1.35428 m .5713 1.31976 L .56097 1.32311 L F
.57015 1.35529 m .56097 1.32311 L .566 1.35696 L F
.566 1.35696 m .56097 1.32311 L .5642 1.35768 L F
0 g
.55623 1.29122 m
.56097 1.32311 L
s
.55958 1.27897 m
.56097 1.32311 L
s
.61199 1.35434 m .60877 1.31405 L .60848 1.35373 L 0 .846 .233 r
F
0 g
.60877 1.31405 m
.61411 1.28937 L
s
.6072 1.24247 m
.60877 1.31405 L
s
.59644 1.35173 m .59472 1.30892 L .59558 1.35169 L 0 .861 .234 r
F
0 g
.55881 1.36469 m
.5589 1.36572 L
s
.61757 1.36446 m .61757 1.36052 L .6175 1.36436 L 0 1 .194 r
F
.61762 1.36448 m .61757 1.36052 L .61757 1.36446 L F
0 g
.61757 1.36061 m
.61762 1.36448 L
s
.5713 1.31976 m
.57243 1.35428 L
s
.55984 1.3625 m .55838 1.35816 L .55914 1.36328 L 0 .053 .147 r
F
0 g
.55838 1.35816 m
.55914 1.36328 L
s
.55838 1.35816 m
.55881 1.36469 L
s
.59506 1.35584 m .58724 1.33996 L .58962 1.35772 L 0 .377 .228 r
F
0 g
.59472 1.30892 m
.59558 1.35169 L
s
.58962 1.35772 m .58724 1.33996 L .58862 1.35798 L 0 .377 .228 r
F
.58862 1.35798 m .58724 1.33996 L .58814 1.35811 L F
0 g
.58718 1.33637 m
.58724 1.33996 L
s
.58705 1.33718 m
.58724 1.33996 L
s
.57846 1.35242 m .57659 1.32301 L .57725 1.35273 L 0 .588 .245 r
F
0 g
.57659 1.32301 m
.57725 1.35273 L
s
.5713 1.31976 m
.57659 1.32301 L
s
.58983 1.35147 m .58918 1.32424 L .58461 1.352 L 0 .588 .245 r
F
0 g
.58918 1.32424 m
.58983 1.35147 L
s
.58918 1.32424 m
.59472 1.30892 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{326.25, 529.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005600024B000`400?l00000o`00003oo`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00_03oool0
0`000000oooo0?ooo`270?ooo`00]P3oool3001U:@<008dY00<000000?ooo`000000Q`3oool00;40
oooo0P000003001<:@<006DY0`00SBT01000000008dY00000000cRT2000008@0oooo002a0?ooo`03
00000000?20004`Y008004`Y0`00IBT3002=:@0600000000SBT00000003>:@00WBT000000P00dRV2
0?ooo`00[`3oool01000000001`H000l8000?203001<:@<006DY0`00SBT01000000008dY00000000
cRT2002M:@@00=8YP03oool00:h0oooo00<0000@0000000071P00P00?2000`00C2T0000000000003
001U:@<008dY00@00000002=:@0000000<hY0P00WBT4003B:@03003o603oool0oooo07d0oooo002^
0?ooo`80000000T001`H000l8000?20000000?ooo`00000006DY00000000IBT00`00SBT010000000
08dY00000000cRT2002M:@@00=8Y00<00?lH0000003oool0O@3oool00:d0oooo0`0000001P0071P0
03`P000l800000000008000000<006DY00<00000002=:@00SBT00`0000000`00cRT009dY002M:@04
003B:@03003o60000000oooo07d0oooo002]0?ooo`8000000P0071P2000l80030000000000P00000
00<006DY00<00000002=:@00XBT00P000002003>:@8009dY1000dRT00`00oaP000000?ooo`1m0?oo
o`00[@3oool20000008001`H0P00?2000`000000000800000003001U:@8000000P00XBT00`000000
0<hY003>:@02002M:@@00=8Y0P00oaP00`000000oooo0?ooo`1k0?ooo`00[03oool300000004000L
6000000003`P000l808000001000IBT2000000800:4Y00<00000003>:@00cRT00P00WBT4003B:@03
00000000oaP0000007d0oooo002/0?ooo`<0000000@001`H00000000?20003`P0P000004001U:@80
00000`00XBT2003>:@8009dY1000dRT00`0000000?lH003o601m0?ooo`00[03oool50000008003`P
0P000003001U:@<000000`00XBT2003>:@8009dY00D00000003B:@00dRT00=8Y00000002003o67d0
oooo002/0?ooo`80000000<000`H0000000000000P00?202000000<006DY0`000003002Q:@800<hY
0P00WBT0100000000=8Y003B:@00dRT200000003003o603oool0oooo07/0oooo002/0?ooo`040000
400031P000`H000000<003`P0P000003001U:@0300000000EBT0000000<00:4Y0P00cRT2002M:@80
00000P00dRT00`0000000?lH003o601m0?ooo`00[03oool01000010000`H000<60000003000l8080
04PY0`00IBT00`00000005DY00000003002Q:@800<hY0P00WBT200000003003B:@00000000000080
0?lH0P00001k0?ooo`00[03oool01000010000`H000<60000003000l808004PY0`00IBT3000000<0
0:4Y0P00cRT2002M:@80000000<00=8Y0000000000000P00oaP2000000P0oooo00<000000?ooo`3o
ool0L03oool00:/0oooo00<000000000400031P00P000002000l80<004PY0P00IBT3001i:@040000
0000XBT00:4Y002Q:@800<hY0P00WBT00`0000000?XP00000002000000800?lH0`0000070?ooo`03
0000003oool0oooo0700oooo002[0?ooo`0300000000010000`H008000000P00?2030018:@030000
0000IBT007TY008007TY1000XBT01P0000000<hY002M:@00WBT00000003j80<000000P00oaP30000
00L0oooo00@00000003o603oool00000K`3oool00:/0oooo0P000000100031P00000000T6000?202
0000008004PY0P000003001i:@@00:4Y00H00000003>:@00WBT009dY00000000nR0400000004003o
600000000000000000L0oooo00<00000003o6000oaP00P00001^0?ooo`00Z`3oool200000005000<
600091P002@H000l800000000`00B2T30000008007TY1000XBT20000008009dY00<00000003j8000
00000`0000001000oaP000000000000000060?ooo`0400000000cS400?lH003o60800000KP3oool0
0:X0oooo0`0000000`0031P002@H000T6002000000<004PY0P000003001i:@@00:4Y0P000002002M
:@<0000000@00=hP0000000000000?lH0`0000060?ooo`0400000000cS400?lH003o60800000KP3o
ool00:X0oooo0`000003000T608000000P00B2T00`00000002@P00000003001i:@@00:4Y0P000000
0`00WBT00:XY002Z:@0200000004003N800000000000003o60@000001@3oool0100000000<ha003o
6000oaP2000006h0oooo002Z0?ooo`80000000D000`H000T600091P002@H000000030018:@800000
1000NBT01`0000000:4Y002Q:@00XBT00000003o:@0000000`00ZRT01@0000000=hP003N80000000
0?lH00@000001@3oool2003><@800?lH0P0000000`00U@00oooo0?ooo`1[0?ooo`00ZP3oool20000
0005000<600091P002@H000T600000000`00B2T2000000@007TY00L00000002Q:@00XBT00:4Y0000
0000obT0000000<00:XY0`00gR06000000D0oooo0P00cS42003o60800?8P00<009D00?ooo`3oool0
J`3oool00:X0oooo0`000002000T608000000`00B2T2000000@007TY0P000002002Q:@0300000000
obT0000000<00:XY0`00gR000`0000000?lH00000003000000D0oooo0P00cS42003o60800?8P00<0
09D00?ooo`3oool0J`3oool00:T0oooo10000002000T608000000`00B2T00`00D2000000001i:@03
001i:@8000000P00XBT00`0000000?lY002Z:@03002Z:@@00=hP00<00?lH0000000000000P000005
0?ooo`800<ha0P00oaP2003b8003002E003oool0oooo06/0oooo002Y0?ooo`@000000P0091P01000
0000030P0018:@00B2T3001@80<007TY0P0000001@00JBT00000002^:@0000000?lY00@00:XY1000
gR000`00oaP0000000000002000000D0oooo0P00cS401@0000000?lH003b8000lR0009D006d0oooo
002Y0?ooo`0400002000000000000000008002@H0P00<2020018:@<0050P0`00NBT200000005001Y
:@0000000:hY002^:@0000001000ZRT4003N8003002M200000000?XY008000001@3oool2003><@03
00000000oaP00?8P00800?8P00<000000?ooo`3oool0JP3oool00:T0oooo00D00008000040000000
0000000T6003000`808000000`00D203001i:@80000000@006TY00000000[RT00:hY0P000003002Z
:@@00=hP00<009d800000000nRT00P0000050?ooo`800<ha0P000003003b80030000003oool0oooo
06X0oooo002Y0?ooo`0500002000010000000000000091P00`00<202000000<0050P00<00000001i
:@00NBT00`000003002^:@03001e:@00ZRT00:XY00800:XY0P000002003N80D000001@3oool2003>
<@8000000`00lR000`000000oooo0?ooo`1Z0?ooo`00Z@3oool00`0000P00000003o<@0300000080
030P0P000003001@8080000000P007TY0025:@0000000000002^:@00MBT00:hY001e:@@00:XY0P00
0002003N80D000001@3oool2003><@<000000P00lR000`000000oooo0?ooo`1Z0?ooo`00Z03oool0
1P000000000800000000000002@H000000<0030P0P000003001@800300000000>2000000008008DY
00D00000002^:@00MBT00:hY001e:@04002Z:@8000000P00gR000`00W@P0000000000002000000D0
oooo0P00cS43000000800?8P00<000000?ooo`3oool0JP3oool00:P0oooo00@00000000020000000
00@H0P000002000`808000001000D2000`00000003PP000000030025:@<00:hY00<007DY002Z:@00
ZRT00P00ZRT2000000800=hP00<009d80000000000000P0000050?ooo`800<ha0`000002003b8080
0000J`3oool00:P0oooo0P0000020004608000000P00<202000000<0050P00@00000000h8000@200
00000`00QBT2002^:@03001e:@00[RT0000000<00:XY00@00000003b600000000=hP1@0000050?oo
o`800<ha0`000002003b80800000J`3oool00:L0oooo0`0000020004600400000000<200030P000`
808000000`00D2000`00000003PP000000040025:@800:hY0P00MBT2000000800:XY00H00000003b
600000000=hP00000000W@P4000000@0oooo0P00cS43000000800?8P0P00001[0?ooo`00Y`3oool3
00000003000460000000000000<0030P00<003`P001@8000D2000P00D2000`00000003PP00000004
0025:@800:hY00@00000001e:@00000000000P00ZRT01P0000000?8H00000000gR000000002M20@0
0000103oool2003><@0300000000ND40000000800?8P0P00001[0?ooo`00Y`3oool3000000030004
6000000000000080030P0P00?204001@8003001M80000000000000@008DY00L00000002^:@000000
07DY00000000fR00000000800:hP2@0000040?ooo`800<ha00<00000001i@@0000000P00lR020000
06/0oooo002W0?ooo`<0000000<000@H00000000<2000P00<202000l800300000000D200000000<0
05dP1@00QBT01`0000000:hY002^:@00MBT00000003J800000000P00[R0200000003003F60000000
00000080000000<00?lP0000003oool00`3oool2003><@0500000000ND40000000000000lR000`00
001Z0?ooo`00YP3oool4000000030004600061P00000008000000P00?203000000<005dP1@00QBT2
00000003002^:@00MBT00000008000000`00[R000`0000000=HH0000000400000003003o803oool0
oooo0080oooo0`00cS43000000800?8P0P00001Z0?ooo`00YP3oool3000000060004600061P001PH
00000000ocT000000P00?20300000003001M80000000000000@008DY00@00000001e:@0000000:hY
0P00NB02000000@00:hP00<00=HH0000000000000P000002003o80@0oooo0`00cS400`00000006e1
00000002003b800300000000Y@P0oooo06T0oooo002V0?ooo`040000000000P000000004608001PH
00@00000003o>@00000003`P0P0000000`0001P00000001M8002001M800400000000QBT008DY0025
:@<000000P00[RT2001i80D00:hP00<00000003F600000000P000002003o80@0oooo0`00cS400`00
000006e100000002003b800300000000Y@P0oooo06T0oooo002V0?ooo`03000020000000000000<0
000000@00?li00000000?20003`P0`000004001M808000000P00QBT4000000<007TP1@00[R02003F
60<000000P00ob040?ooo`<00<ha00<00000001]@@0000000P00lR02000006X0oooo002V0?ooo`05
00002000000000@H0000000061P00`000002000l80<000001000GB030000008008dP00<00000002Q
<@0000000`00NB05002^80800=HH0`000002003o80@0oooo0`00cS400`00000006e100000002003b
8080000000<00:D80?ooo`3oool0I`3oool00:H0oooo00L000000000400000000000000H60000000
020H00<003`P0P00@1P4001M80@000000P00SB02000000@007TP00<00000002^8000[R000P00[R00
0`0000000=HH003F6002000000800?lP103oool01P0000000<ha003><@00000006e1000000800?8P
0P0000000`00Y@P0oooo0?ooo`1W0?ooo`00Y@3oool010000000000@000040000002000H6080020H
0P00?203001060@005dP00@00000003o6000000000000`00SB000`00000007TP001i8002001i8080
00000`00[R000`0000000=HH003F6002000000800?lP103oool00`0000000<ha003><@0200000003
0032<@00lR000?8P00800>8P00<00:D80000003oool0I`3oool00:D0oooo00D00000000040000100
0000000H6003000P608000000`00@1P00`00000005dP001M8002001Q808000001000SB000`00]R00
07TP001i8002001i808000000P00[R02000000<00=HH00@00000003o8000ob00000H0`3oool00`00
00000<ha003><@02000000030032<@00lR000?8P00800>8P00<00:D80000003oool0I`3oool00:D0
oooo00D000000000400000000000000H6003000P608000000`00@1P3000000<0064P00<00000002=
8000SB000P00SB000`00]R0007TP001i8002001i800700000000gQP00000002^800000000?8H0000
0002003F600400000000ob000?lP003o80<0oooo00<00000003><@00cS400P0000000`00`S400?8P
003b8002003R8003002U20000000oooo06L0oooo002T0?ooo`80000000@0000@0000000061P00000
0P0081P3000000<0040H00<00000000P600000001000HB04002=80D007TP00<00000003N60000000
0P00YAP2000000800=HH00@009d8003o8000ob000?lP0`3oool0100000000<ha003><@0000020032
<@800?8P0P00hR000`00Y@P000000?ooo`1W0?ooo`00Y03oool200000080000@0P000002000P6080
00000`00@1P00`00000001@H00000005001Q80@008dP00@004PP00000000NB0007TP0P00MAP20000
00800:DH00D00000003b600000000=HH002M2003003o80<0oooo00@00000003><@00cS4000000P00
`S42003b80800>8P00<00:D8000000000000I`3oool00:@0oooo0P00000200004080000000@0020H
00000000000000000`00@1P3000000D0064P00D00000002=8000SB0008dP00188003000000<007DH
00@00000002U6000YAP00:DH0P0000000`00eQP00000003o8002003o80<0oooo00<00000003><@00
cS400`00`S42003b80800>8P0P00Y@P00`000000oooo0?ooo`1U0?ooo`00X`3oool300000080000@
00<00000000P600081P00P00:1P3001060<004@H1P00HB020000008008dP0P0000000`00]R000000
001e6002001e60@00:DH00L00000002^4000eQP00000003o800000000?lP0080oooo0P000002003>
<@<00<8a00L00000003b8000hR000>8P00000000Y@P0000006L0oooo002S0?ooo`<0000000@0000@
000000000000020H0`00:1P3000000<004@H1@00HB0300000003002=8000B2000000008000001000
MAP5002U60800:h@0P000002003o8080oooo0P000002003><@<00<8a0`0000001000hR0000000000
0000001W0?ooo`00X`3oool300000004000040000000020H000000<002PH0`000003001460040000
0000HB00064P001Q808000000P00B2000`00000004PH00186002000000@007DH00<00000002U6000
YAP00P00YAP2002^408000000P00ob00100001P0oooo000000000002003><@<00<8a00@00000001]
@@0000000>8P1000001V0?ooo`00X`3oool2000000<0000@0P000002000X60<000001000A1P50000
0004000/6000B2000000002=60<004PH1@00MAP2000000<00:DH00@00000002^4000000000000P00
ob00100001P0oooo000000000002003><@<00<8a00H00000001]@@0000000>8P00000000=3T20000
06H0oooo002S0?ooo`8000000`0001001000000002PH000X6000:1P3000000<004@H0P0000001000
:1P00000001Q6000HAP20000008008dH0`00B1P01000000007DH001e6000MAP3000000<00:DH00@0
0000002^4000000000000P00ob0010000000oooo000000000002003><@<00<8a00P00000001]@@00
00000>8P00000000=3T00000002Z26H0oooo002R0?ooo`80000000<0000@0000000001000P000003
000X608002`H1000A1P3000000D0064H0P00SAP3001860H0000000@00=hH00000000YAP00:DH0P00
00001@00[Q00000000000000ob0000000080oooo0P0000001000cS400<8a0032<@00`S4300000080
0>8P0P0000000`00ZPP0oooo0?ooo`1T0?ooo`00XP3oool40000000300004000000002PH008002PH
0`00;1P00`00000004@H001460020014608000000`00HAP00`000000064H002=6003001860040000
0000]QP00;HH000000<006TH0P0000001@00TA0000000000000000000:h@0080000000@00?lP0000
003oool0oooo0P0000001000cS400<8a0032<@00`S43000000800>8P0P0000000`00ZPP0oooo0?oo
o`1T0?ooo`00X@3oool400000080000@00@000@@00000000000000000P00;1P01000000000080000
000000030014600300000000HAP0064H00<0064H00@0000000186000B1P004PH0`000005001Y60<0
094@0P000002002^400300000000ob0000000080oooo0P0000001000cS400<8a0032<@00`S430000
00800>8P00@00000000/>@000000000HI@3oool00:40oooo00D00000000020000000000000004002
0004408000000`00;1P00`000000000@000000040014600300000000HAP0064H00<0064H0`000004
001460D006TH1000TA0200000004002^400000000?lP00000080oooo0P0000001000cS400<8a0032
<@00`S43000000800>8P00@00000000/>@0000000000I@3oool00:00oooo0P000000200000P00000
00000000000000@@00000000ocT000000P00;1P3000000D004@H0P000003001Q60@000001000A1P0
0`00000006TH001Y6002001Y600300000000TA00094@0080094@00@00000002^4000[Q000?lP0P00
0000103oool0000000000000cS440032<@8000000P00hR05000006@0oooo002P0?ooo`D000000P00
11020000008002`H0`00;1050014600400000000;1P0000000000080064H00<000000025<@000000
0P00A1P00`00000004@H00146002000000<006TH0P000003002A4004001i0000[Q000:h@003o80<0
000000<00<Y:00000000cS401000`S42000000800>8P0`00dQP00`00ZPP000000?ooo`1S0?ooo`00
X03oool20000000400002000000000000004408000P@0`000003000/400300000000A1P004@H0080
04@H10000003001Q608000001000A1P200000003002f6000000006TH00@000000P00TA000`00N@00
0000002^400400000003003:BP0000000<ha00@00<8a0P000002003R80<00=8H00<00:X80000003o
ool0H`3oool009l0oooo00H00;h@0000000000P000080000000011030008408000001000;1030000
00<004@H0P000004001Q6004000X400000000000000000<0040@0P000004001I40<0000000<0094@
00000000N@0010000002003:BP0300000000cS400<8a00<00<8a0P000002003R80<00=8H00<00:X8
000000000000H`3oool009l0oooo0P000000100000P00000000440000002000840<000000`00;104
000000@004@H1000HAP2000X400300000000RAP0000000D0040@00<00000001I4000FA000P00FA03
001a200300000000N@00000000<000000P00bTX00`0000000<ha0032<@030032<@8000000P00hR03
003B6003002Z20000000000006<0oooo002O0?ooo`80000000@0000800000000000000000P002102
000000@002`@0`0000050014608000000P00HAP01000:10000000000000000050010400300000000
]QP0000000<005T@00<00000001a2000L@P00P0000001000N@000000000000000002003:BP030000
0000cS400<8a00<00<8a00@00000002j:@00^RT00>8P0`00dQP3000006<0oooo002N0?ooo`800000
0P0000P2000000@000P@0`000004000X400300000000A1P004@H008004@H0`000002001Q60<0020@
0P00000300104080000000@00:hH00000000000005T@0`000002001a20D000000P00bTX00`000000
0<ha0032<@030032<@0400000000^RT00;XY003R80<00=8H00@00000002M200000000000HP3oool0
09h0oooo1`0000030008408000001000:10400000003001460000000000000<00000100081001000
000008TH000000000003000d208000000`00C0P300000080074810000002003:BP0300000000cS40
000000<00<8a00<00000002j:@00^RT00P000002003B608000000P00W@QR0?ooo`00W@3oool30000
008000080P0000030008408000001@00:103000000@0040@0P000004000P40<000001P00=0P00`00
000004`8001<2003001<208000000P00L@P00`00H@00000000000002003:BP0300000000cS400000
00<00<8a0`00^RT2000000800=8H0P000002002M2680oooo002M0?ooo`<000000P0000P010000000
00P@0008400021020008200300000000:10002P@008002P@0`000006001040<00000100060P40000
008003@800@00000002^6000000000000`00C0P2001I0080074800<00000001i000000000P00bTX0
0`0000000<ha000000030032<@<00;XY0P000002003B608000000P00W@QR0?ooo`00W03oool40000
000300002000000000P@008000000`0020P3000000@002@@0P000004001040@000000`0060P40000
00@002@8100000000`00C0P0000000000002001I0080000000@006400000000000000<Y:0`000003
0032<@<00;XY0P000003003B6080000000<009d80?ooo`3oool0H03oool009`0oooo0`0000030000
208000000`0020P3000000@002@@1@0000000`00@100000000000004000000D000P00P000005000T
200400000000?00003`0000l00<0000000<005T00000000000000P0000001000bTX0000000000000
00030032<@<00;XY0P000003003B6080000000<009d80000003oool0H03oool009/0oooo10000002
0000208000000`0020P30004200400000000910002@@000T40@000000`00?105000000D000P000<0
000000214000PA000P000002000T200400000000[QP00000000000<003`00P0000001@00F@000000
0000000000000<Y:00<000000`00`S43002j:@<000000P00dQP200000003002M20000000oooo0600
oooo002K0?ooo`@0000000<000080000000000000`0000030004200400000000od400000000000@0
02080`00?10:00000003000060000000084@0080084@0P000003002^6003002Z2000cQ00000000<0
03`000<00000001I0000F@000P0000001000bTX000000000000000030032<@<00;XY00<00000002A
DP0000000P00dQP00`0000000<8H002M200200000600oooo002J0?ooo`X000000`0010P3000000D0
02082@000005001@40<000000`00PA001000VA000:hH002^6000[QP2002Z2003003>400000000000
0080000000<003`00000000000000P0000000`00QC400000000000030032<@@00;XY0P000002003B
60800<8H0P00W@P00`000000oooo0?ooo`1N0?ooo`00VP3oool;000000<0000810000002000P20H0
000000D003`@00000000000002`P00000005001@408006d@0P00PA0200000006002I4000[QP00:hH
00000000ZPP00<h@0P0000002000HCT0000000000000?0000000000l0000000008Da0P0000030032
<@@00;XY0P000002003B60<00<8H00<009d80000003oool0G`3oool009T0oooo2`000003000020<0
00001@0050P3000000D003080`000003001@408000000P00KA030000008009T@0P0000002@00ZPP0
0000000000000000064i00000000;3400000000l0004000000040032BP0000000<8a0032<@@00;XY
0P000002003B60<00<8H00@00000002=200000000000GP3oool009T0oooo4@000004000D20@00000
1P00<0P4001820040000000001P000000000008006d@0`0000000`00VA0000000025>@0300000007
00364000HCT0000000000000;34003`i000l0003000000040032BP0000000<8a0032<@@00;XY0P00
0002003B60<00<8H0P0000000`00S@P0oooo0?ooo`1M0?ooo`00V03ooolD0000008001@81P000003
000`208000001000B0P3000000<006d@0P000002002I40P0000000<002`a000l>@0000000`000000
1000`TX000000032<@00`S44002j:@0300000000[RT00=8H008000000P00`QP200000003002=203o
ool0oooo05d0oooo002G0?oooa@000001@002003000000<002@00P0000000`00IBT0000000000004
0018208000000`00KA0200000004002I400000000000002Z20D0000000<002`a000l>@0000000`00
00001000`TX000000032<@00`S44002j:@0500000000[RT000000?ooo`0000000P00`QP200000080
08d8GP3oool009H0oooo5`000002000800H000000`009004000000<004P80`00F@P2001]4004001i
2000000009T@002I40L0000000P002`a000l>@0000000000000<:@0000000<9:000000800<8a00@0
0000002j:@00^RT00;XY0P00[RT00`000000oooo0000000300326080000000<008d80000003oool0
G03oool009H0oooo7@000004000H00<000000`00?0020018200400000000F@P005T8001I20800000
00@007T8002I4000VA0009T@1P0000000`00;34003`i000l>@05000000800<8a00@00000002j:@00
^RT00;XY0P00[RT3000000<00<8H0P0000000`00S@P000000?ooo`1L0?ooo`00U@3ooolP000000@0
01P00`000002000l000300000000gS40000000<005T800<00000001i2000N@P00P00VA000`00P@00
0:X80000000300000003000/<@00?3T003`i0080000000<000`Y0000800000000P00`S4010000000
0;XY002j:@00^RT2002^:@0400000000SE8008eB000000800<8H00<00000002b6000S@P00P00001L
0?ooo`00U03ooolP000000@000@01@000002000l00<000000P00F@P200000005001i200000000000
00000000ZPP0100000001000;3400000000l>@00@3T4000000800<8a00@00000002j:@00^RT00;XY
0P00[RT01000000008eB002=DP000002003260800;8H0P00S@P00`000000oooo0?ooo`1J0?ooo`00
T03oool9000000<00;hi2P0000001000hQP00?lP00000000ob02003o:@8000000`00RCT5000000@0
00@00`0000000`00;00003`0000l00030000008005T80P0000001000N@P0000000000000P@060000
0003000l>@00@3T0000000H000000`00^RT3002^:@0300000000SE80000000800<8H0P00/QP2002=
20030000003oool0oooo05X0oooo002;0?ooo`8000001000odX;00000003003o@@0000000?m100L0
000000@00?lP00000000ob000?la0P00obT2003o>@0300000000ocT0000000d0000000D002`00000
00000000000000180003001I200600000000N@P0000000000000P@000:X81@0000000`00?3T0040i
0000000200000004000T>@0000000000000000<00;XY0`00[RT00`00000008eB0000000200326080
0;8H00@00000002=2000N@P00000F`3oool008L0oooo20000004003J>@T0000000<00?m100000000
oc401`0000001000ob000000003o8000oc42000000800?li400000000`00600002`0000000020000
000600180000F@P005T8001Q0000000007T80`0000000`00K@000000000000020000008003`i1`00
0003002j:@<00:hY0P0000000`00XB000<8H00326002002b60<0000000<007T80?ooo`3oool0F@3o
ool008D0oooo0P0000000`00of8000000000000300000003003J>@000000000000L0000000<00?li
00000000od400`0000000`00oc400?8a003b:@0700000003003o800000000?la008000000P00ocT5
0000008002@H0`000002001U:@03001e>@00000000000080000000<001P000000000;0000P000000
1@00B000000000000000H@0007T800T0000000<003`i0010>@0000000P000000100093T000000000
00000002002j:@<00:hY0P0000000`00XB000<8H00000002002b60040000003oool00000001i25/0
oooo00230?ooo`@00?mR0`0000000`00odX0000000000008000000<00?li0P00od4300000006003b
<@00lRT00>hY003^:@0000000?lP0`0000001000oc40000000000000oc4200000003003o>@000000
0=Y100@000000P0091P30000008006DY2`0000001`00B000000000000000H@0007T800000000P@00
1P0000000`00?3T0040i0000000300000003000T>@000000000000800;XY0`00[RT00`0000000:4P
002Q8002000000<00;8H0P000002001i25X0oooo00200?ooo`@000000`00oe82003oBPX0000000<0
0?la003o>@00ocT00P00ocT00`00od40000000000003000000<00>hY00<00?lP0000000000000P00
00001000oc40000000000000oc4200000003003o>@0000000=Y100<0000000<00008000T600091P0
0`000002001U:@<0000000<00;Xa0000000000001@0000000`00=00004P00000000500000003002A
0000000000000080000000@003`i0010>@00@3T004Q10P0000001@0093T003Q100000000^RT00000
00<00:hY0`00XB02000000<00;8H0`0000000`00N@P000000?ooo`1H0?ooo`00O@3oool9000000<0
0?m100@00?Xi003Z>@00jST00>8a100000001P00obT00?la003o<@00ocT00000003o>@P0000000@0
0>hY003f8000ob000?lY0P0000000`00ob000?la00000003000000800?li00H00000003J@@000000
0000000020000002000T608004PY0`00IBT2000000<00;Xa0P00gS440000008003@02`0000002`00
?3T0040i0010>@00B4400000000<:@00000002@i00000000^RT0000000<00:hY0`00XB000`000000
08eB00000002002b60<0000000<007T80000003oool0F03oool007/0oooo0P0000000`00og<00000
0000000500000003003o@@000000000000P000000P00obT01000oc400000000000000002003oDP03
00000000odX0000000H0000000<00?lY00000000obT00P0000000`00oc4000000000000200000080
0?li1P000002000T608004PY0`00IBT00`00TBT00000002j<@02002j<@800=ha00<0040Y002=<@00
EC400P00JCT00`00000003@00000000900000009000l>@000000040i0018@@00000004a:00000000
93T003Q1008000000`00[RT3002Q800300000000SE80000000800;8H0`00VAP00`00N@P000000000
001H0?ooo`00N@3oool4003oLa8000000P00obT4000000800?mB0P00odX700000003003o8000obT0
0?lY00<0000000<00?la0000000000000P000002003o>@H000000P0091P20018:@<006DY0P00TBT3
002j<@800=ha00<0040Y002=<@00SC400P0000000`00JCT003@00000000300000003001Y00000000
000000<0000000<003`i00000000@3T00P00B44400000003000h@@0000000:hY00800:hY1000XB02
000000800;8H1000VAP00`00N@P000000?ooo`1G0?ooo`00M`3oool0100000000?mc003oL`00og<3
003oJP0500000000of80000000000000oeX01P0000000`00mS4000000000000200000003003o:@00
0000000000<0000000<00?mB00000000odX00P00odX00`0000000?m100000005000000800?lY1@00
00001000oc40000000000000ocT300000004003f>@00000000000000008002@H00<000000018:@00
00000P000002002A:@<00;Xa0P00gS400`00@2T008da002=<@02003B<@/0000000<00=HY00000000
00000P00@3T00`00B44000000000000200000003000h@@0000000:hY00800:hY1000XB0200000080
0;8H1000VAP3000005L0oooo001I0?ooo`030000003oool0oooo01T0oooo1@000003003oJP03003o
HP00oeX00?mJ00800?mJ0P0000001@00odX0000000000000ocT00?Ha00<0000000<00?lY00000000
0000100000001@00oe800000003oBP0000000?m:00800?m10P0000000`00ocT00000000000020000
00800?lY0P0000001000oc400?li003o<@00oc4200000005003o>@000000000000000000mST00`00
0000100091P000000018:@00B2T300000080094Y0`00^S400`0000000=ha0010:@03002=<@800=8a
2P0000000`00eRT00000000000020010>@8004Q100D004a:0000000000000000000h@@03002^:@@0
0:4P00D00000002A8000TB000;8H00000003002I600400000000I@000000000005H0oooo001H0?oo
o`0400000000og/000000?ooo`8000005@3oool:000000<00?mJ0P00oe82003oBP<00?li10000000
0`00obT0000000000003000000800?mZ00D00000003oBP0000000?m:00000003003o@@03003o>@00
000000000080000000L00?lY00000000obT00?la00000000oc400?li00800?la00<00?li00000000
ocT00`0000001P00mST0000000000000000002@H0000008004PY0`000002002A:@06002j<@0001P0
0;Xa00000000gS40040Y0`00SC42003B<@0300000000QCT0000000L0000000<00=HY000000000000
0P00@3T20018@@06001<BP000000000000000000>44000000P00[RT4002Q800300000000TB00094P
008000000`00VAP20000008006D0EP3oool005L0oooo00<00000003oN`00og/00P0000000`00og/0
00000?ooo`02000000030?ooo`000000oooo00d0oooo0P0000000`00og/000000000000600000006
003oFP0000000000003oDP0000000?m:0P0000000`00ocT000000000000300000004003o:@000000
0000000000@00?mZ00P00000003oJP0000000?m:00000000od400000003o@@<00?li100000001P00
obT00?la0000000000000?la003o>@800?la0`00ocT300000004003f>@0000000000000D60800000
0P00B2T300000080094Y00H0000000006000^S400000003N<@00@2T3002=<@800=8a0P0000000`00
GCT000000000000500000005003F:@000000000000000000@3T00P00B442001<BP@000000P00[RT4
002Q80<0094P0P000004002I600400000000I@0006D0000005D0oooo001F0?ooo`0300000000og/0
0?mk0080000000D00?mk0000000000000000003oL`0200000004003oL`000000oooo000000X0oooo
0`00og/200000004003oN`0000000000003oL`@0000000<00?mB000000000000200000000`00obT0
000000000002000000@00?mZ00T00000003oJP0000000?mR00000000od400000003o@@0000000P00
ocT00`0000000?li0000000300000005003o<@0000000000003o<@00ocT00P000003003o>@@00000
00<00008000D600051P00P0000020018:@<000000P00TBT00`0000000;Xa002j<@0200000004003N
<@00SC4008da002=<@800=8a0P000002001M>@0300000000?34000000080000000<00;8i00000000
00000P0000000`00@3T000000018@@02001<BP@000000P00[RT0100000000:4P002Q8000XB03002A
800300000000TEX0000000<009TH0P0000000`00I@0000000?ooo`1D0?ooo`00EP3oool3003oN`04
00000000og/00?mk000000800?mc0P000002003oL`80000000@00?mc0000003oool000001P3oool6
003oN`0300000000og<00?mc00@0000000<00?mZ0000000000001@0000000`00od400000003o<@04
00000003003o@@0000000?mZ00@00?mZ00@00000003oHP0000000?mR0`0000003P00ocT00000003o
>@00ocT00000003o>@0000000?lY00000000oc400000003o<@0000000?li0P000002003o>@@00000
0P0000P0100051P00000003F>@0000020018:@<000000P00TBT00`0000000;Xa002j<@0200000006
003N<@00SC4008da002=<@0000000=8a0P000002001M>@<0000000<005Di001UBP00/ST010000000
1000@3T000000018@@00B442001<BP06001IBP00000006UB00000000[RT000000`00XB03002A8003
00000000TEX0000000<009TH00D00000001m4000I@0006D00000001D0?ooo`00E@3oool7003oN`<0
0?mc00<00000003oL`00og<00P000002003oL`80000000<00?mZ0000003oool00P3oool00`000000
0?mk003oN`04003oN`<00?mc00<00000003oL`0000000P00ofX6000000800?m11@0000001000ocT0
0?m100000000ofX2000000800?mZ0P00of800`0000000?mR0000000400000003003o>@0000000?li
00800?li0`0000001@00oc400?li0000000000000?li008000000P00ocT400000003000020000000
01@H00<000000P00B2T00`00KBT0000000000002002A:@0300000000^S400;Xa0080000000H00=ha
002=<@00SC4008da00000000dS420000008005di1@0000000`00IDX0000000000002000000040010
>@00000004Q10018@@8004a:00<005U:0000000000000`000003002Q80<0094P00<00000002AFP00
00000`00VAP3001m4003001U00000000000005<0oooo001E0?ooo`H00?mk1`00og<00`0000000?mc
003oL`02000000800?mZ0P0000000`3oool00000003oN`02000000<00?mk1@00og<3003oJP060000
0000of800000003oFP0000000?m:0P00od45000000800?li100000000`00ofX00000003oHP03003o
HP0300000000oeX0000000@000000`00ocT00`0000000?m100000002003o<@04003o>@0000000000
003o>@8000000P00ocT600000004000D6000>20003PP000h808004PY0P00KBT3002A:@0300000000
^S400;Xa0080000000H00=ha002=<@00SC4008da00000000dS420000008005di0P0000000`002200
00000000000300000004002A@@00000000000000008004Q10P00C4X2001IBP0400000000JE800000
000000<00:4P0`00TB020000000400216000VAP009TH002I60<007d@1000001B0?ooo`00E03oool0
100000000?mk003oN`000003003oN`X00?mc00<00000003oJP00ofX00P0000000`00ofX000000000
000200000006003oN`000000000000000000og<000000P00og<3003oJP800?mR0P00oeX2003oBP03
003o@@0000000?la00@0000000@00?li0000000000000?mc0P0000000`00ofX0000000000004003o
HP800?mJ0`0000000`00ocT00000003o>@02003o>@800?m100D00000003o<@0000000?li00000002
003o>@8000000P00ocT200000005003o>@00000000000000000051P00`00>2020000008006dY0`00
TBT200000004002j<@0000000000003N<@<008da00@00000003B<@00000000000P00GCT200000003
000880000000000000P0000000@004Q100000000C4X004a:0P00FDX00`00JE80000000000003002Q
80<0094P00@0000000216000PAP0084H0P000003001m408000000P00F@1B0?ooo`00E03oool01000
00000?mk000000000002003oN`0300000000og<00?mc00P00?mc0`00ofX8000000040?ooo`000000
0000000000800?mc00<00000003oJP0000000P00of82003oFP03003oBP000000000000D0000000<0
0?li00000000og<00P00og<00`0000000?mc003oL`0200000004003oHP0000000000003oHP800?mJ
00P00000003oFP0000000?mB00000000ocT00000003o>@800?m11P000002003o>@80000000D00?li
0000000000000000003o>@04000000<003PP0P000002001]:@<0094Y0P0000001000^S4000000000
0000gS43002=<@0400000000dS4000000000008005di0P0000001000220000000000000062T70000
00040018@@00000004a:001<BP8005U:0P00JE80100000000:4P002Q80000003002A80@0084H0P00
0004001m4080000000<005T00000003oool0D03oool005<0oooo00@00000003oN`00000000000P00
og/2000000800?mc00<00000003oL`00og<01000og<4003oJP0300000000oh<00?n300<0000000<0
oooo0000000000000P0000000`00og<0000000000002000000800?mR00<00000003oFP0000001P00
00000`00oc40000000000006003oL`L000000`00oeX00`0000000?mB0000000300000003003o>@00
00000?m100H0000000<00?li0000000000000P00ocT300000003003o>@0000000000008000000`00
>20200000003001]:@000000094Y0080094Y00<000000000600000000`000003002=<@@000000P00
GCT20000000500088000000000000000000062T00P0000001P00FE80000000000000000004Q10000
008004a:0P00FDX2001YDP0400000000XB000:4P000000<0094P1000PAP3000000<007d@0P000000
0`00F@0000000?ooo`1@0?ooo`00D`3oool2000000030?ooo`0000000?mk0080000000@00?mc0000
0000000000000P00og<0100000000?mc003oL`00og<2003oJP@00?n300<00000003oN`00og/00P00
00001000og/0000000000000og/400000003003oHP000000000000L0000000<00?li000000000000
0P000005003oL`0300000000og<00?mc00@0000000@00?mJ00000000oeX00?mJ1000oe800`000000
0?li00000003003o@@80000000@00?li0000000000000?li0P000002003o>@D0000000<0000@0000
000000000P00>2030000008006dY00D00000002A:@00TBT0000000006004000000<008da10000003
001M>@H0000000@001PY00000000000005UB1@0000000`00C4X00000001IBP03001YDP800:4P00@0
0000002A8000TB00094P1@00PAP2000000<007d@0P00IA02001I00030000003oool0oooo04h0oooo
001A0?ooo`80000000H00?mk0000000000000?mk0000003oool2000000030?ooo`0000000?mc00<0
00000P00og<2000000@00?n30`00og/0100000000?mk003oN`000002003oN`80000000L00?mc0000
0000ofX000000?ooo`000000oooo00@000000P00ocT400000003003oL`000000000000D00?mc00D0
0000003oJP0000000000003oFP0200000003003oFP00oe800?mB00800?mB0P0000000`00ocT00000
003o@@02003o@@80000000H00?li003o@@00ocT00?li003o@@000002003o>@@000000P0001020000
008003PP0`000002001]:@80000000<0094Y0000000001P00P0000000`00@2T00000002=<@02002=
<@@000000`00GCT20000000300088000000000000080000000H001PY0018@@00000005UB00000000
JEX200000003001<BP00000005U:00<006UB00<00:4P0000000000000`00TB050021608000000`00
OA03001U40<00000C`3oool00500oooo00<00000003oN`00og/00P000002003oN`80000000<00?mk
0000003oool00P0000000`3oool00000003oL`03000000800?n30P000009003oN`0300000000og<0
0?mc0080000000<00?mZ0000000000001@000002003o>@<000000P00og/01@0000000?mB00000000
og<0000000800?mc0`00ofX01P0000000?mR0000000000000?mJ000000@00?mB00<00000003oDP00
00001000od4200000005003o>@00od400?li003o>@00od400P00ocT500000080000@0P000002000h
80030018800000000000008006dY0P0000001@00TBT000000000600000000=XP0080000000<008da
003o8000SC4010000003001M>@80000000<000PP000000000000100000000`00B44005UB001IDP02
001YFP0500000000C4X00000001IBP0000000P00JE801@00KBT00000002jFP000000094P00800000
1000PAP00`00000006dH001]6002000000<006D@0P0000000`00A000oooo0?ooo`1=0?ooo`00D03o
ool3003oN`0300000000og/00?mk0080000000L00?mk0000000000000000003oN`000000oooo0080
000000<0oooo0000000000000`000002003oN`0300000000og/00?mk00@00?mk1000og<01@000000
0?mZ00000000of80000000800?mJ00<00000003oDP0000000P000004003oN`D000000P00og<3003o
JP0300000000of800?mR00@0000000<00?mB00000000oe800P00oe8200000008003o@@0000000?m1
003o@@0000000?li00000000od4200000003003o@@00ocT00?li00D000000P000100100091P003PP
000000000002001880<006dY00@000000036>@0000000:hP0P0000000`00fR00000000000003002=
<@80000000<00?8H00000000QCT00P00GCT200000003000880000000000000D0000000<004Q1001I
DP00FE800P00JEX50000008006UB0`0000000`00TB00000000000004002160<006dH0P000003001U
40<0000000<004@00000003oool0C03oool004l0oooo1`00og/0100000000?mk003oN`000003003o
N`80000000<00?mc0000000000000`0000000`3oool0000000000002000000800?mk00<00000003o
N`00og/01000og<2003oJP<00?mR0P00oeX2003oDP<000001000og/200000003003oL`0000000?mJ
00<000000`00ofX2003oHP0500000000of80000000000000oe800P000003003oDP@000000`00od42
00000004003o@@0000000000003o@@800?li1@0000000`00010002@H000T60030000008004PP0`00
KBT0100000000<Hi00000000[R02000000030010:@000000000000<008da00D000000021>@000000
00000025>@02001M>@D0000000<0000H0000000000000`0000000`00B44005UB001IDP02001YFP@0
00000P00JE8300000003002A80000000000000@0084H0`00KAP30000008006D@0`00D0P00`00A000
00000?ooo`1<0?ooo`00C`3oool>003oN`0400000000og<00000000000800?n300<000000?ooo`00
00000`0000000`00og/0000000000002003oN`0400000000og<00?mc003oL`800?mZ0`00of82003o
FP800?mB10000003003oN`@00?mc1@000002003oJPD00?mR1@000003003oDP0300000000odX00000
00@00?m10P0000001000od40000000000000od42003o>@H000000P0091P00`0000000>8i00000002
001880@0000000<00<Hi00000000[R000P000002003J80T000000P00GCT500000004000060000000
00000008:@@0000000@005UB00000000JEX006UJ100000000`00JE8000000000000200000003002j
FP000000084H00<0084H0`00KAP300000003001U400000000000008005080`00001<0?ooo`00CP3o
ool0100000000?mk003oN`00000;003oN`03003oL`00oh<00?n300800?n30`0000000`00og/00000
0?ooo`0200000003002MFP0000000000008000000P00og<00`0000000?mZ00000003003oHP03003o
FP0000000?mB00@000000P00og/2000000<00?mc00<00000003oL`00og<00P0000000`00ofX00000
00000004003oHP0300000000oeX00?mJ00@000000P00oe800`00odX0000000000004003o@@030000
0000od400?m10080000000D00?m100000000ocT00000003o@@040000008002@H1P000008003oR`<0
00002000oh/3000000H00?n31`0000000`00FE8000000000000300000008001]:@00000000000000
0000IB000000002jFP000004002160<006dH00H00000001I4000FA000000001]FP000002001@20@0
0000B`3oool004h0oooo00@00000003oN`00000000000P00og/00`0000000?mk003oN`05003oN`03
003oL`00oh<00?n300<00?n300<00000003oN`00og/0100000001P00WEX0000000000000WEX00000
003oL`80000000<00?mZ0000000000000P00of86000000800?mk0P0000000`3oool00000003oL`04
003oL`80000000H00?mZ00000000oeX00000003oHP000002003oHP800?mJ0`0000001@00oe800000
003oDP0000000?m:0080000000<00?m100000000od400`0000001000od40000000000000od450000
00P00?n;1@000003003oR`80000000<00:hP0010:@00/ST00`000003003oR`L000001P00oh<30000
00H00?n30`0000002000KBT00000001YDP00000006DP00000000^UX000000`00PAP01000000006dH
001]6000KAP3001I4080000000@006eJ00000000D0P005080`0000000`00<00000000?ooo`180?oo
o`00C@3oool0100000000?mk000000000002003oN`8000000P00og/00`0000000?mk003oN`02003o
N`0300000000oh<00?n300800?n31000og/00`0000000?mk003oN`0200000003003oN`0000000000
00<0000000@00?mZ0000000000000?mR1@000005003oN`<000000P00og<01@0000000?mc003oL`00
og<0000000800?mZ0P0000001000of80000000000000of83003oFP0600000000oeX0000000000000
oe8000000P00odX400000003003o@@000000000000L00?n;1@000004003oR`D000001`00oh/30000
00P00?n;0`000005003oP`L000001P00oh<600000004001U800000000;YJ00000080084H0P000003
001]60@005T@0`000002001@20<004@00P0000190?ooo`00C@3oool2000000040?ooo`0000000?mk
003oN`80000000<00?mk0000000000000`00og/00`0000000?n3003oP`02003oP`L00?mk00<00000
003oN`00og/01@0000000`00ofX0000000000004000000030?ooo`000000000000@00?mk00<00000
003oHP00000010000002003oL`<00?mZ0P0000001@00ofX0000000000000of80000000@00?mJ1000
0005003oR`<000001`00oh/5000000L00?n;0`000008003oR`D000000`00oh/7000000@00?n30`00
0007003oP`H000001@00oh<200000004001E800000000;iJ000000<006dH1000FA000`00000004`@
001<40030000008004@0100000170?ooo`00B`3oool200000003003oN`000000000000800?mk00L0
00000?ooo`00000000000?ooo`0000000?mk00<000000P00oh<2000000X00?mk00@00000003oL`00
og<000000P00ofX200000003003oHP00000000000080000000<00?m:00000000og/00`00og/20000
0004003oL`0000000?mR000000800?mc00D00000003oJP00ofX00?mZ00000002003oJP@000001000
oeX2000000L00?n;1P000007003oR`8000001@00oh/400000003001E60000000000000@00?n;1000
0007003oP`<000001@00oh<7000000H00?n31@000006003oP`D000000`00KAP01000000005T@001I
4000FA03001<40<000000`00A00200000003000H003oool0oooo04D0oooo001:0?ooo`0400000000
og/00?mk003oN`8000000P00og/200000003003oN`000000oooo00@0000000@00?n3000000000000
00000P00og/2000000H00?mk0`00og<00`0000000?mZ003oJP02000000800?mR00<00000003oDP00
00000P000004003oN`@00?mc1P000005003oJP0500000000of80000000000000oeX010000008003o
R`D000001`00oh/6000000D00?n;0`000007003oR`<000001@00oh<4000000L00?n30P000007003o
P`L0000000@0085R00000000oh<00?n310000006003oP`8000000`00FA04001<408000000P00A000
1@0000000300000`0000<000000004H0oooo001:0?ooo`@00?mk00@00000003oN`00og/000000`00
og/200000003003oN`0000000?n300800?n30P0000001000og/00000000000000002003oN`040000
0000og/00?mk003oN`@00?mc0`00ofX00`0000000?mR003oHP04000000800?n310000003003oL`80
000000@00?mc00000000000000000P00ofX00`0000000?mZ003oJP02000000H00?n31P000007003o
P`@000001000oh/5000000L00?n;1@000003003oR`L000001000oh<5000000<00?n31P000002003o
P`D000000`00oh<01000EEX006UR00000000PF83000000800?n30P000006003oP`@000001000C100
0`00000003`8000l2002000000<003000P0000150?ooo`00BP3oool;003oN`0500000000og/00?mk
00000000oh<00`0000001@00oh<000000000000000000?mk00<000000P00og/0100000000?mc003o
L`00og<4003oJP<00?mR00<00000003oDP0000000`00oh<4000000H00?mc20000007003oP`D00000
1P00oh<6000000L00?n31@000003003oR`D000001P00oh<2000000L00?n30`000006003oP`800000
1`00oh<500000005003oP`00EEX005EJ00000000JF800P00PF84000000@00?n31@000002003oP`80
00000`00C103000l20<000000`00<003000004<0oooo001:0?ooo`d00?mk0`0000000`00og/00000
003oP`02003oP`0300000000og/000000080000000@00?mk00000000000000000P00og<010000000
0?mZ003oJP00ofX4003oHP800?mB00@00?m:003oP`00oh<00?n30`0000000`00og<0000000000003
003oL`80000000D00?mZ0000000000000000003oR`06000000800?n32@000002003oP`P000001000
oh<5000000H00?n30`000005003oP`H000000`00oh<7000000800?n31P000002003oP`D0000000L0
0?mk00000000og/00?mk00000000EEX00000008006UR0P00PF85003oN`P000001@00oh<01@000000
03`8000l2000?0P0000000<003080P000003000L00030000003oool0oooo0400oooo00190?ooo`04
00000000og/00?mk000000P00?mk0P000002003oP`H000000`00og/5000000800?mc0P000003003o
JP<00?mR0`00oe800`00odX00000003oP`04003oJP0300000000ofX0000000<00?mc00@00000003o
R`00oh/00?n;1@000009003oR`D000001000oh<5000000P00?n31P0000000`00oh<0000000000002
000l60<000001000oh<3000000H00?n30P000006003oP`8000001`00oh<9000000030018DP00EEX0
05EJ008006UR0P00PF800`00og/0000000000006000000D00?mk0P000002003oP`80000000<003`8
000`2000<0P00P00<0P30000008001`00P0000110?ooo`00B@3oool0100000000?mk000000000002
003oN`0300000000og/00?mk00<00?mk0`00oh<2000000800?n300<00000003oN`0000000`000002
003oN`<0000000@00?mc00000000000000000P00ofX00`0000000?mR003oHP03003oDP800?m:00<0
0000003oJP00ofX00`00ofX2000000800?mc0`000006003oR`D000001000oh/5000000P00?n31@00
0004003oP`D000001P00oh<3000000H00?n310000003003oP`H000000P00oh<6000000800?n31P00
0002003oN`H0000000@005EJ00000000JF8006UR0P00PF85000000D00?mk0P000002003oN`<00000
0P00og/2000000<0030800<00000000L000070001P00000o0?ooo`00B03oool00`0000000?mk003o
N`0200000003003oN`000000000000<00?mk00<00000003oP`00oh<01@00oh<300000005003oN`00
00000?mk00000000og/00P000002003oL`0400000000og/00000003oJP8000000P00of801@000000
0?mB003oDP00oe800?m:008000001000ofX7000000D00?n;1@000007003oP`L000000`00oh<70000
00H00?n31@000006003oP`<000000P00oh<4000000H00?n30P000006003oP`<000000P00og/40000
00L00?mc200000000`00JF8000000021HP02000000D00?mc0P000002003oN`<000000P00og/20000
00<00?mk00<00308000000000000100070020000000300040000000000@000800000?@3oool004P0
oooo00@00000003oN`000000oooo0P000000103oool00000003oN`00og/2000000L00?n300@00000
003oN`00og/00?mk0P0000001000og/00000003oN`000002003oL`@0000000<00?mk00000000of80
0P000002003oDP0300000000odX00000008000000`00oh/9000000D00?n;1P000006003oP`<00000
1@00oh<5000000H00?n31`000004003oP``000000`00oh<6000000800?n30`000005003oN`D00000
0P00og<900000007001EFP0000000000001YHP000000085R00000002003oJPL000000P00og<20000
00@00?mk0P0000000`00og/0000000000002000L008000000`002006000003/0oooo00170?ooo`03
00000000og/00?mk0080000000P00?mk0000003oool00000003oN`000000oooo000000800?n300<0
0000003oP`00oh<00P00oh<3003oN`0400000000og/00?mk003oN`H000000P00ofX2000000800?mR
0P0000000`00oe80000000000004000000H00?n;10000006003oR`T000000P00oh<7000000@00?mk
1`000003003oP`D000001@00oh<8000000@00?n300@00000003oP`00oh<00?n30P000006003oN`@0
000000<00?mk000000000000100000000`00og<0000000000002000000800?mR00<003A100000000
00001@0000000`00of8000000000000800000003003oJP000000000000D00?mc0P0000000`00og/0
0000000L200500000003002AJP00000000P000X00000>@3oool004H0oooo00@00000003oN`00og/0
0?mk0P0000000`00og/0000000000002003oN`80000000@00?n300000000000000000`00oh<7003o
N`8000000P00og/00`0000000?mk00000002003oJP0300000000of800?mR008000000P00oe850000
00H00?n;0P0000000`00oh/0000000000003000000D00?n31P000005003oP`H000000`00og/70000
00D00?mk1@000005003oP`D000001P00oh<400000003001<80000000000000800?mk10000004003o
L`<000001000ofX40000008003A10P0000000`00C58000000000000:000000D00?mR00<00000003o
JP00ofX00`0000000`00og<0000000000004000000800?mk2`0000000`00FD4000000000000i0?oo
o`00AP3oool4003oN`0400000000og/00?mk000000<00?mk1@000002003oP`8000002P00og/00`00
00000?mk00000003000000<00?mR0P0000000`00oe80000000000007000000D00?n;1@000006003o
P`@0000000<00?n300000000oh<00`00oh<4000000800?n31000og/7000000<00?mk1P000004003o
N`P000001000oh<800000003003oN`000000000000<0000000<00?mc0000000000000`000002003o
JPP0000000T00?mB000d@@00@4X00000001<DP00000005eJ00000000MEX0100000001000VF800000
003oFP00oeX;00000003003oL`000000000000L00?mk2@000002001I@@030000003oool0oooo03L0
oooo00160?ooo`X00?mk0P0000000`00oh<0000000000005000000800?mk00<00000003oN`00og/0
1@00og/2000000800?mc0P000002003oHP0300000000oh/00?n;00@00?n;10000007003oR`800000
00<00?n30000000000000`000005003oP`H000001000oh<6000000@00?n310000004003oL`@00000
1@00og<8000000@00?n30P0000000`00oh<0000000000002000000@00?n30P000002003oJP<00000
0`00oeX400000003003oDP000000000000<000000P00=4400`00@4X00000001<DP06000000030025
HP000000000000L0000000<00>iJ0000000000001000ofX4003oL`0300000000og/00?mk00800000
0P00og/30000008006UR0`00OF83000003T0oooo00160?ooo`T00?mk00<00000003oP`00oh<00`00
00001@00oh<00000003oN`0000000?mk00<000000P00og/00`0000000?mk003oN`02003oN`<00?mc
1P000005003oR`<0000000<00?n;0000000000000`000005003oP`80000000<00?n3000000000000
1@00oh<5000000D00?n31@0000000`00oh<00000003oP`03003oP`D000000`00og<6000000<00?mc
1P000003003oN`@00?n30`000002003oP`8000001@00oh<6000000800?m:0P000004003j@@@00000
00@0020i000000000000041:0P00C5801000000005eJ00000000MEX400000003002IHP0000000:i1
00800:i10P0000001000aTX00000003^FP00kUX300000003003oJP000000000000@0000000<00?mk
0000000000000`0000001000XFX00000000000000002001mHP030000003oool0oooo03T0oooo0015
0?ooo`0400000000og/00?mk000000D00?mk1000oh<00`0000000?n3003oP`0300000005003oP`00
00000?mk00000000og/00`000003003oN`@00?mc00<00000003oL`0000000P000009003oR`@00000
1P00oh<4000000800?n30P000006003oP`D000001@00oh<2000000D00?n310000004003oP`03003o
HP000000000000@000000P00ofX200000004003oJP0000000000003oL`8000001000og/7000000P0
0?n30`0000000`00odX0000000000004003F>@<0000000<001PY000000000000100000001000@4X0
04aB001<DP00C582001MFP<0000000<008ER0000000000000`0000000`00[T400000000000040000
0003003^FP000000000000l0000000<0oooo00000000OF800P00OF800`000000oooo0?ooo`0h0?oo
o`00A@3oool0100000000?mk000000000003003oN`8000001`00oh<0100000000?n3003oP`00oh<4
00000003003oN`0000000?mk00800?mk00<00000003oL`00og<00P00og<4000000800?n;0`000004
003oR`8000000P00oh/5000000D00?n310000006003oP`80000000<00?mk0000000000001@00oh<5
000000@00?n31@000004003oP`D000000P00iV87000000@00?mc0P0000000`00og/0000000000004
000000@00?n30P000002003oP`L0000000@00?mB00000000000000000P0062T500000003000d@@00
@4X0041:008004aB0`00GEX01P00MEX000000025HP00QF800000002IHP80000000@002@@00000000
000001P@0P0000000`0030P0030H0000000;00000003000@200000000?mc0080000000<0oooo0000
0000OF800P00OF8k0?ooo`00A@3oool0100000000?mk000000000002003oN`<000002`00oh<01`00
00000?n3003oP`0000000?mk00000000og/00`000002003oL`800?n;0P000002003oR`L000001@00
oh/5000000D00?n310000006003oP`@000001P00oh<4000000D00?n31@000005003oP`@000000`00
_U8400000003003:HP000000000000<00>iZ1P0000000`00og/0000000000004003oP`H0000000<0
0?n3000000000000100000001P00<340000000000000000001PY000X>@H0000000@0041:001<DP00
C58004aB0P00GEX2001eFP<008ER0P00VF82000T400400000000610001P@0000008000`80`000000
1000:1P000000000000091050000008001080P0000000`00og<0000000000002002^L`800000>`3o
ool004D0oooo0P0000001P3oool00000003oN`000000oooo000000800?n30P00000;003oP`800000
00H00?n300000000og/00000003oL`000006003oR`L000001@00oh/4000000800?n30P000006003o
P`D000001000oh<6000000D00?n310000004003oP`8000001@00oh<3000000D00?n300<00:510000
000000000`000003003:HPH0000000<00?Ik0000000000000P00og/4003oP`H000001000oh<00`00
00000?mZ000`<@0300000004000H:@00:3T00000000h@@@000000P00@4X2001<DP<005eJ00@007EJ
0025HP00QF8008ER0`00VF801000910001P@000H40006103000<20X0000000@001P@000@200040P0
01081000og<0100000000:ic002^L`00000l0?ooo`00A03oool0100000000?mk000000000002003o
N`L0000000<00?n30000000000002000oh<00`0000000?n3003oP`05000000D00?n;0P0000000`00
oh/0000000000002000000800?n;0P000005003oR`@000001P00oh<00`0000000?mk003oN`020000
00@00?n30`0000000`00of80000000000005003oP`@000001@00oh<4000000X00?n31P0000020029
>@04002QDP0000000000003:HP8000000P00gW<2000000800?Ik0`00og/2000000800?n31@000004
003oP`8001`Y0`000000100062T002Pi000X>@00>445000000040010BP00000004aB001<DP8005eJ
0P00MEX30025HP8009UR0`006103000<20P0000010006102000@20D00?mc00@00?n300000000[W<0
0000?03oool004<0oooo00<00000003oN`00og/00P000002003oN`80000000D00?n30000003oool0
0000003oP`03000000<00?n300<00000003oP`00oh<01@00oh<4000000T00?n;0P000002003oP`<0
00001@00oh/4000000L00?n30`000008003oP`8000001P00oh<3000000H00?n310000005003oP`@0
00000`00oh<2000000<00?n300<0074a000000000000100000000`00_VX0000000000003003NL`80
0?Ik0P0000001000og/00000000000000002003oP`8000001P00oh<01@000000030a000000000000
01PY008002Pi0P00>444000000050010BP0000000000001<DP0000000P00GEX01000MEX008ER0025
HP00QF83002IHP8000000P0030P300000004000X6000000000000000008002@@0`006103000@20D0
0?mc0P00oh<2000003`0oooo00130?ooo`<00?mk00D00000003oN`00og/00?mk00000002003oP`80
00000P00oh<0100000000?mk00000000oh<3000000800?n300@00000003oP`00oh<00?n32@000003
003oR`@00?n310000002003oR`8000001@00oh/5000000H00?n310000005003oP`@000001@00oh<4
000000@00?n30P000005003oP`@000001000oh<4000000<00?mk1`000002002nJP<00=ic20000008
003oP`0300000000oh<0000000<000000P00:3T2000h@@<0000000D0051:0000000000000000001<
DP0200000003001MFP00000007EJ00<008ER0`00VF800`00000000`800000006000000<002@@0`00
6102000@200300000000og<00?mc00<00?mc0`00oh<m0?ooo`00@`3oool7003oN`<00?n300<00000
003oP`00oh<00`0000001@00oh<000000000000000000?n300<000000P00oh<00`00oh/000000000
0002003oR`0500000000oh/00?n;00000000oh/00P000005003oP`0400000000oh<00?n3003oR`<0
00001@00oh/4000000H00?n310000006003oP`<000001P00oh<4000000H00?n310000003003oP`80
00001000oh<3000000@00?mk0P000002003oL`8000000P00NCT01000TEX00;iZ002nJP00_VX80000
0003003oN`0000000?n300L00?n30P0000001@00oh<0000000000000000002Pi008003Q11@000000
0`00@4X000000000000200000004001MFP00000000000000008008ER00<00000002IHP00VF801@00
00001000fS400000000X6000lV83000T408001P@00<00000000@200000000`00og<0100000000?mc
003oL`000003003oP`030000003oool0oooo03T0oooo00130?ooo`H00?mk1`00oh<0100000000?n3
003oP`00oh<200000006003oP`0000000?mk00000000oh<000001@00oh/00`0000000?n;00000005
000000L00?n310000005003oR`D00?n310000005003oP`@000001P00oh<3000000@00?n30P000006
003oP`@000001000oh<4000000<00?mk0`000002003oN`<000000P00og<800000003002nJP000000
000000<0000000<00>Yk0000000000000P00og/4003oP`8000000P00oh<200000003003oP`000000
0000008002Pi00<003Q10014BP00A4X01P0000000`00C580000000000004000000040025HP000000
0000002IHP<0000000<00=Xa0000000000000P00:1P3000T400500000000610001P@0000000040P0
0P000002003oL`80000000<00?mc0000000000000P00000l0?ooo`00@P3oool0100000000?mk003o
N`000002003oN`0300000000oh<00?n300T00?n300<00000003oP`00oh<00`0000000`00oh<00000
003oR`04003oR`8000000P00oh<3000000800?n30P000006003oP`800?n;10000005003oP`040000
0000og/00?mk000000H00?n30`000006003oP`0400000000ocT00000000000H00?n300<00000003o
P`00oh<00P00oh<3000000D00?n30`000004003oN`0300000000aST0000000@00?mk0`000002003o
JP80000000<00?li000000000000100000000`00]VX0000000000002000000<00>Yk0`00og/20000
0005003oP`000000000000000000og/00P000002003oP`0500000000:3T003Q1000h@@00A4X00`00
00000`00>20000000000000300000003001MFP00000000000080000000@008ER00000000000009UR
0`0000001000<1P002PH000X60000003000T40040000000061000000000@20<000000P00og<20000
00800?mc0P0000000`00oh<000000?ooo`0j0?ooo`00@P3oool0100000000?mk003oN`000002003o
N`0400000000oh<00000000000/00?n31@000004003oR`@00?n30P0000000`00oh<0000000000002
000000L00?n300<00?n;0000000000000P000005003oP`@000001P00oh<3000000H00?n310000006
003oP`0400000000of800000000000<00?n31@000004003oN`0400000000og/00?mk003oN`<00000
0`00og/3000000800?mZ0P000002003o>@T0000000@00;IZ00000000dW<00=9c0`00jW/00`000000
0?mk003oN`0400000005000L:@0000000?mk003oN`0000000`00oh<2000h@@8004A:00<00000001@
BP00000040000002000`608002PH00@00000000T4000910000000P00610300000009003oJP000000
0000003oL`0000000?n300000000og<0000000<00?n300<000000?ooo`3oool0>03oool00480oooo
00@00000003oN`000000oooo0P0000001000oh<00000000000000002003oP`8000001`00oh<40000
00800?n;0P000008003oP`<000000P00oh<2000000800?n300<00000003oP`00oh<00`00oh/40000
00D00?n31@000005003oP`@000002`00oh<3000000@00?n30P000002003oBP0300000000og/00?mk
00800?mk00@00000003J@@00000000000P00og/4000000800?mk0`000002003oJP80000000<00?la
0000000000000P0000001@00;2T00000001]BP00000008eR00<00;IZ0`00dW<01@0000000>Yk0000
000000000?mk00H000000`00og/4003oP`0400000000A4X00000001@BP80000000<0065B00000000
ME802P0000001000VF800000000`60000002000X6005000000009100000000000000610010000000
0`00ofX000000000000400000003003oL`0000000?n300<00?n3>P3oool00480oooo00D00000003o
N`000000oooo00000002003oP`D0000000<00?mk00000000oh<00P000004003oP`0400000000oh<0
0?n3003oP`<000002000oh<2000000800?n30P0000000`00oh/00000003oP`02000000800?n30P00
oh/4000000D00?n310000006003oP`@000001@00oh<5000000@00?mk10000003003oN`8000001000
og/3000000<00?mk00@000000036>@00aST000000P00og/3000000800?mZ0P0000000`00oc400000
0000000400000005000/:@00000006e:001]BP00SF800`00]VX200000004003BL`0000000000003Z
N`D0000000<00?mk0000000000000`00og/4003oP`0400000000A4X0051:001@BP8000000`00ofX3
00000006003o>@0000000?li00000000YF8000000P00/V8200000003000X60000000000000P00000
00D00?mZ0000000000000000003oL`02000000800?mc00D00000003oP`00oh<00?n30000000i0?oo
o`00@P3oool0100000000?mk000000000003003oP`80000000P00?n30000000000000000003oP`00
00000?mk000000800?n30`000003003oP`8000000`00oh<2000000P00?n31P0000000`00oh<00000
00000006003oP`<000002`00oh<4000000D00?n30P000002003oDP0300000000og/00?mk00800?mk
10000004003oN`@000000`00og/3000000<00?mk0P000002003oN`<000000P00ofX300000003003o
<@00000001@P00@0000000D00<Xi000/:@0000000000001]BP0300000003002fJP000000000000<0
000000@00>9k0000000000000?Ik0P000006003oN`0500000000oh<0000000000000A4X00`000002
003oJP@000000P00ocT300000004002UHP0000000000002bHP80000000D002PH0000000000000000
003oJP06000000800?mZ0P0000000`00og<0000000000002003oL`<0000000<00?n30000003oool0
>03oool00440oooo00@00000003oN`00og/000001000oh<00`0000000?n3003oP`02000000800?n3
1P000002003oP`<000000`00oh<3000000800?n300<00000003oP`00oh<00`00oh<2000000800?n3
0P000002003oP`8000001@00oh<0100000000?mc003oL`000005003oP`@000001P00oh<010000000
0?n3003oP`00oh<3003oN`8000001000og/4000000@00?mk0`000005003oN`8000001000og/30000
00<00?mc0P000002003oHP@0000000<00?lY0000000000000P0000000`00bST000000000000<0000
00800>9k00<00000003fN`00mW/00`00og/300000003003oL`000000000000<000000`00ofX30000
00<00?li0P0000001@00UEX00000002UHP00YF80000000800;9R0P0000001@00of80000000000000
000000080080000000<00?mZ0000000000000P00ofX2000000800?mc00@00000003oL`00og<00?mc
0`00000j0?ooo`00@@3oool0100000000?mk003oN`000007003oP`0500000000oh<00?n3003oP`00
00001`00oh<800000004003oP`0000000000000000P00?n30P0000000`00og/00000000000050000
0003003oP`0000000000008000001@00oh<4000000H00?n300@00000003oFP00000000001000og/5
000000@00?mk0`000009003oN`8000001000og/00`0000000<Hi00000003003oL`8000000P00of85
00000003003o:@00000000000080000000<00<Xi0000000000000`0000000`00IEX0000000000004
00000003003>L`000000000000800>9k1@000006003oL`D000000`00of83003o>@<0000000@009EJ
0000000000000:ER0P0000001@00/V80000000000000000000080080000000<00008000000000000
0P00ofX01@0000000?mZ003oJP00ofX0000000L00?mc0P00oh<00`000000oooo0?ooo`0g0?ooo`00
@@3oool3003oN`0300000000oh<00?n300/00?n300<00000003oP`00oh<00P00oh<2000000800?n3
0`000002003oP`0300000000oh<0000000<00?n300<00000003oP`00oh<00`00oh<00`0000000?mk
003oN`06000000H00?n31000000:003oP`@000001000og/4000000D00?mk00<00000003oBP000000
1000og/4000000<00?mk0`000003003oL`0400000000og<00?mc003oL`8000000P00of8200000005
003o<@000000000000000000obT0100000001000bST0000000000000YCT600000004002AJP000000
0000000000L00?mk1P00og<200000003003oN`000000000000800?mk00<00000003oHP0000001000
00001@00QEX00000002EFP00UEX0000000800:ER00<00000002bHP00/V800P0000000`0000P00000
00002003000000L00?mZ1`00og<3003oP`030000003oool0oooo03H0oooo00110?ooo`<00?mk00@0
0000003oP`00000000000`00oh<00`0000000?n3003oP`04003oP`0300000000oh<00?n300H00?n3
200000001000oh<00000000000000004003oP`<00?mk0`0000000`00og<0000000000003000000<0
0?n30P0000000`00of800000003oP`05003oP`@000001000og/4000000T00?mk0`000004003oN`<0
00001@00og/2000000<00?mc0`000003003oL`80000000@00?mJ0000000000000?la0`0000000`00
obT000000000000200000004003:>@0000000000000000H00?mc0P000008003oN`8000001000og<7
000000<00?mk00@00000003o<@00000000000`00QEX3002EFP<00:ER0P00/V800`00000000080000
20020000208000002000ofX7003oL`<00?n3>@3oool00400oooo00@00000003oN`00og/00?mk0P00
00001000og/00000003oP`00oh<2000000<00?n30`000002003oP`8000001000oh<2000000800?n3
0`000002003oP`0300000000oh/0000000<00?n300<00000003oN`00og/00P00og/00`0000000?mc
003oL`07000000<00?mk0P000007003oP`<000001@00og/00`0000000?mJ00000005003oN`<00000
1@00og/3000000P00?mk0P000003003oL`0400000000cT400<Hi000000800?mc0P000002003oFP@0
00001P00og<3000000T00?mc1`00og/200000004003RN`0000000000000000D00?mc00<00?mR0000
0000og/01@00og/01000oc400000001eDP00ME820025FP0400000000UEX009EJ000000800:ER00<0
0000002bHP00/V800`0000P2000000T00?mZ1`00og<0100000000?n3003oP`00000h0?ooo`00@03o
ool01`0000000?mk003oN`0000000?n300000000og/00`0000001000og/00000003oP`00oh<20000
00800?n;0P0000000`00oh<00000003oP`07003oP`@000000P00oh<200000004003oP`0000000000
000000@00?mk0`00og<00`0000000?mR003oHP0200000003003oHP0000000?mk00@00?mk0P000004
003oP`<000001@00og/3000000D00?mk0`000005003oN`<000001000og/3000000800?mk10000000
1000og<00000000000000005003oL`@000004P00og<5000000<00?mk10000005003oL`D000001`00
og/00`00000007EB001eDP030025FP<009EJ0`00YF83002bHP03000020000000000000X00?mZ00@0
0000003oL`00og<000000`00og<200000003003oP`000000oooo03L0oooo00110?ooo`8000000`00
oh<200000003003oP`000000000000800?n300<00000003oR`00oh/00P00oh/3000000800?n30P00
0004003oP`8000000P00oh<3000000800?mk0`000004003oN`@00?mc0`00of800`0000000=Ic0000
0006003oN`0400000000of800000000000D00?mk0`000005003oN`<000002@00og/3000000@00?mk
0P000006003oN`<000004`00og<3000000H00?mc1@00000<003oL`80000000<00?9k000000000000
2P00og/00`00000007EB0025FP020025FP<009EJ0`00YF83002bHP<000000P00ofX01@00mW/00000
003oJP00ofX0000000<00?mZ00<00000003oL`00og<00P000002003oL`0300000000oh<0000003T0
oooo00110?ooo`0300000000oh<00?n300800?n300@00000003oP`00oh<000000`00oh<4003oR`80
00000P00oh/200000003003oP`0000000?n300L00?n30`000002003oN`<000000P00og/2000000<0
0?mc1000of83003FL`8000000`00og/200000003003oHP000000000000@00?mk00@00000003oFP00
000000001000og/00`0000000?mJ00000002000000<00?mk0P000006003oN`@000002@00og/:003o
L`<000001P00og<400000003003:>@000000000000D00?mc0P000008003oL`@000000`00og<20000
00800?mR0P00og/01@0000000?mk003oN`00og/0000000<00?mk00<00000001eDP00ME800`00QEX3
002EFP<00:ER0P00/V83000000<00?mZ00<00000003oJP00ofX00P000002003oJP80000000P00?mc
00000000oh<00000003oL`0000000?n3000003T0oooo00110?ooo`0300000000oh<00?n300P00?n3
00<00000003oR`00oh/01P00oh/3000000800?n30P000004003oP`8000000P00oh<3000000800?mc
0P0000001000of800000003oL`00og<4003oHP8000000P00eW<4000000<00?mk0P000004003oN`@0
00000`00og/00`0000000?mk003oN`04003oN`<000005000og/3000000H00?mc0P0000000`00oeX0
0000003o>@02000000H00?mc0`00000?003oL`80000000<00;Ic0000000000001@00og<3003oHP@0
0?mk00<00000003oN`00og/00P000002003oN`0300000000ME8008EJ008008EJ0`00UEX3002UHP03
00000000/V800;9R008000000`00ofX200000003003oJP000000000000800?mZ0P0000001000og<0
0000003oP`00oh<2000000800?n300<000000?ooo`3oool0=P3oool00400oooo0P000003003oP`03
00000000oh<00?n300@00?n300@00000003oR`00000000001000oh/2000000800?n30P0000000`00
oh<00000003oP`07003oP`<000000P00og<00`0000000?mR00000002003oL`0300000000of800?mR
00800?mR0`0000001@00eW<00000003oHP00of80000000D00?mk0`0000000`00og/0000000000002
003oN`<000004P00og/4000000H00?mk100000000`00ofX0000000000006003oL`<000004@00og<5
000000<00?mc10000006003oL`<0000000@00?mJ003bN`00lW/000000P00og/600000003003oN`00
00000000008008EJ00@00000002EFP00UEX000000P00YF8600000009003oJP0000000?mk00000000
ofX00000003oN`0000000?mZ00@000000P00oh<0100000000?mc00000000oh<i0?ooo`00@03oool2
000000800?n30P000002003oP`0300000000oh<0000000<0000000<00?n300000000oh/00P00oh/5
003oP`<000000P00oh<2000000@00?n30P000002003oN`D0000000<00?mc0000000000001000of83
000000800?mZ0P000005003oN`8000001@00og/3000000T00?mk0`000006003oN`<000000`00og<2
000000H00?mc0`00000C003oL`8000001@00og<200000004001Y@@0000000000000000`00?mc1000
0002003oFP800?9k0P0000000`00og/00000001@BP0200000003001080000000000000800?mk00<0
00000025FP0000000P00UEX00`0000000:ER002UHP0200000006002bHP000000000000000000ofX0
00000P00og/200000003003oN`0000000?mZ00<0000000L00?mc00000000oh<00000003oL`000000
0?n303T0oooo00100?ooo`800?mk0P0000001000og/00000003oP`00oh<2000000800?n;0`000002
003oR`8000001@00oh<00`0000000?n3003oP`0200000003003oR`0000000?n300800?n31@00og/0
0`0000000?mR00000002003oJP8000000`00of85000000@00?mZ1`000003003oN`P000001000og/2
000000<00?mk0`000005003oN`@000004P00og<4000000H00?mc1P000004003oL`<000001`00og<2
000000@00?mc0`000003003oFP8000000P00lW/200000003003oN`000000051:00@000000`00og/0
1000QEX0000000000000UEX5000000800;9R100000001000og/0000000000000ofX2000000800?mZ
00<00000003oL`00og<00P000003003oL`800000>03oool00400oooo00P00?mk00000000oh<00000
003oN`0000000?n3000000@00?n;00L00000003oR`00oh/00?n;00000000oh<0000000800?n30P00
0004003oP`<000000P00oh<2000000D00?mk0`000002003oJP8000000P00of8200000004003o>@00
00000000000000@00?mk1@00000C003oP`<000001P00oh<2000000800?mk0P00og<2000000H00?mc
0`000005003oL`80000000@00?mJ0000000000000?m:0P000003003oL`H000003@00og<200000080
07ER0P000004003oJP800?mJ00<00000003oDP00hW<00P0000001@00lW/000000000000000000?mc
008000000P00og/2000000<00?mk00@008EJ00000000UEX009EJ0`0000000`00og/00000002bHP03
00000005003oJP000000000000000000ofX00P000002003oJP0500000000og<00?mc003oL`000000
1000og<i0?ooo`00@03oool0100000000?n3003oP`00oh<200000003003oP`0000000?n;00L00?n;
1`000004003oP`0700000000oh<00?n3003oP`0000000?n;00000004003oN`8000000P00og<2003o
JP<00?m:1@000009003oP`<000001`00oh<3000000P00?n30`000008003oP`@000001P00oh<30000
00800?mZ0P000004003oL`D000001`00og<2000000P00?mc0P000004003oL`H000001000ofX30000
0003003oDP000000000000<0000000<00?9c0000000000000`00og<00`0000000?mk003oN`05003o
N`P0000000<00;9R0000000000000P00ofX2000000<00?mZ00@00000003oJP00ofX00?mZ2000og<i
0?ooo`00@03oool4003oP`0500000000oh<00?n300000000oh/00P000005003oR`0300000000oh/0
0?n;00<000000P00oh<2000000D00?n30P000004003oN`D00?mc0`000006003oP`0300000000oh<0
0?n300D00?n31`000004003oP`L000000`00oh<200000003003oN`000000000000<000001@00oh<4
000000P00?n31P000005003oL`0300000000og<00?mc00L00?mc0P000006003oL`80000000@006U1
00000000000000001000ofX2000000@00?mZ10000002003oDP040000000011000000003RL`800000
00<00?9c0000000000000`00og<8003oN`P0000000<00<YR00000000ofX00P00ofX00`0000000?mZ
003oJP05003oJPP00?mc>@3oool00400oooo1P00oh<300000004003oP`0000000?n;003oR`800000
1000oh/01`0000000?n3003oP`00oh<00000003oP`0000001000oh<00`0000000?n3003oP`02003o
N`80000000<00?mc00000000000010000007003oP`D000001@00oh<3000000T00?n300<00000003o
P`00oh<01P00oh<4000000D00?n30P0000000`00og<0000000000003000000L00?n32000og/01000
00000?mc000000000006003oL`H000000`00og<200000004001<>@00JD400000000000X00?mZ0`00
0003003oDP0400000000dVX00000000000800>9c00@00000003bL`00lW<000001000og<7003oN`D0
000000D00;iJ0000000000000<YR0000000;003oJPP00?mc>@3oool003l0oooo00@00000003oP`00
oh<00?n30`000002003oR`D0000000<00?n300000000oh/00P00oh/5003oP`<0000000<00?n30000
000000001@00oh<0100000000?n3003oP`00oh<4000000L00?n31@000008003oP`@000001@00oh<5
000000L00?n30`000007003oP`@000001P00og/4000000P00?mk0P0000000`00odX0000000000003
003oL`H000001P00og<2000000L00?mZ0`000004003oJPD00?mB00@00000003BJP00000000000P00
hW<00`0000000?9c003bL`05003oL`<00?mk00<00000003oN`00og/00P0000001000]UX000000000
0000_UX2000000800<YR00<00000003oJP00ofX02000ofX4003oL`0500000000og<00?mc003oL`00
0000>03oool003l0oooo00D00000003oP`00oh<00?n300000004003oR`0500000000oh/00?n;0000
0000oh<00P0000000`00oh/0000000000004003oP`8000000P00oh<00`0000000?n300000002003o
P`@000001P00oh<6000000L00?n30P000002003oP`<00?mk0P000002003oL`<000001@00oh<50000
00<00?n30P000002003oN`04003oL`0000000000000000D00?n30P000008003oN`80000000<00?mR
0000000000002000og/5000000<00?mc0P000009003oL`H00?mZ10000004003oJP<000000P00oe85
000000<00>9c0`00lW<4003oL`0300000000og/00?mk0080000000@00>XP003oN`0000000;IJ0P00
0002002nFP80000000<00<YR00000000ofX02@00ofX01@0000000?mc003oL`00og<0000000<00?mc
00<000000?ooo`3oool0=P3oool00400oooo00@00000003oP`00000000002000oh/01P0000000?n;
003oR`0000000?n3000000800?n30P000004003oP`D000000`00oh<00`0000000?n3003oP`03003o
P`D000002000oh<200000003003oJP000000000000D00?mk0P000005003oN`D00?n300<00000003o
P`00oh<01@00oh<4000000D00?n31P000008003oN`@000001000og/4000000P00?mk00<00000003o
L`00og<01@00og<4000000<00?mZ0`000005003oJP0300000000QF80000000800?mB0P0000001000
_VX00000003BJP00dVX4003RL`<00?9c1000og<200000007003oN`00jR00000000000000og<00000
002fFP0200000003002nFP000000000000800<YR00@00000003oJP00ofX000000`00ofX00`000000
0?mZ003oJP02000000800?mc0P0000000`00og<000000?ooo`0h0?ooo`00@03oool0100000000?n3
000000000002003oR`8000001`00oh/300000004003oP`0000000000000000@00?n300<00000003o
P`00oh<01@00000:003oP`D000000`00oh<4000000T00?mk0P000006003oN`H000001000oh<40000
00L00?n31@000004003oN`@000002000og/200000003003oL`000000000000L00?mk0P000003003o
L`D000002`00ofX3000000<00?mB0P000002002nJP<00=9Z1000hW<2003bL`0600000000og<00?mc
003oL`0000000?mk10000002003oL`<000000P00_UX0100000000<YR003:HP00bV82003oJP050000
0000ofX00?mZ003oJP0000000P00ofX2000000800?mc0P0000000`00og<000000?ooo`0h0?ooo`00
?`3oool00`0000000?n3003oP`0200000005003oR`000000000000000000oh/00P000008003oR`<0
000000<00?n30000000000000P000006003oP`D000001@00oh<5000000L00?mk0`000006003oN`D0
00000`00og/6000000@00?n31`000005003oP`8000002000og/200000003003oL`000000000000P0
0?mk1@000007003oN`H000001`00ofX00`0000000?mZ003oJP02003oJP<000000`00oe82000000<0
0;iZ1000dVX3003RL`0300000000lW<00?9c008000000P00og<300000003003oL`000000000000<0
0?mc00@00000002nFP00_UX00;iJ0`00bV82003oJP80000000T00?mZ00000000og/00000003oJP00
00000?mk00000000og<00`0000000`00og<000000?ooo`0g0?ooo`00?`3oool2003oP`0400000000
oh/00?n;003oR`@0000000@00?n300000000oh/00?n;0P000004003oR`0400000000oh<000000000
00<00?n;00<00000003oP`00oh<00`00oh<4000000L00?n3100000000`00oh<00?mk003oN`04003o
N`H000000`00og/200000003003oP`000000000000H00?mk0`000004003oL`<00?n30`000005003o
P`80000000@00?mc00000000000000002000og/4000000l00?mk1@000007003oN`0300000000ofX0
0?mZ0080000000<001@a0000000000001000of83003oDP800?m:00<00?8Y002UJP00_VX00P00_VX3
003BJP0300000000hW<00>9c00@0000000@000`@0000000000000>XP0P000002003oL`0300000000
og<00?mc00800?mc0`00_UX4003:HP0A0000003oool00000003oJP0000000?mk00000000ofX00000
003oN`0000000?mc00000000og/00000003oL`000000>03oool003l0oooo0P00oh<4003oR`0;0000
0000oh/00?n;00000000oh<00000003oR`0000000?n300000000oh/00P0000001000oh<000000000
0000oh/4000000X00?n310000006003oP`D000000`00og/4000000L00?mk0P000009003oN`800000
1000og<2003oP`@000001P00oh<5000000H00?mk0P000006003oN`D000002000og/2000000800?mZ
0P000006003oN`H000001000of83000000800?m:0P000002002UJP0300000000_VX0000000800=9Z
0`0000000`00hW<00000000@600300000004003Z8000hR000000000000<00?mc00<00000003oL`00
og<00P00og<3002nFP<00<YR00D000000?ooo`0000000000003oJP0200000004003oL`0000000?mk
000000800?mc00D00000003oL`00og<00?mc0000000g0?ooo`00?`3oool2000000P00?n;00<00000
003oR`00oh/0100000000`00oh<00000003oR`03003oR`0400000000oh<00?n3003oP`@000001P00
oh<0100000000?n3003oP`000005003oP`@000004000og/3000000H00?mk1P000003003oL`@00000
00<00?mZ0000000000001P00oh<7003oN`H000001@00og/2000000800?mZ0P000008003oN`D00000
1`00og/5000000800?mR0`000002003oBP0500000000QF80000000000000YFX00P0000001P00_VX0
000000000000dVX00000001aBP80000000L0010H0000000000000>XP003R800000000?mc00800000
2000og<2002nFP@00<YR0`0000000`00ofX0000000000002003oL`0500000000og<00?mc003oL`00
00000`00og<h0?ooo`00?`3oool2000000800?n;0P000007003oR`0300000000oh/00?n;00<00000
1@00oh/5000000L00?n310000009003oP`T00?mk0P000005003oN`80000000<00?n3000000000000
0P000002003oN`80000000@00?n300000000000000001P00og<3000000D00?mk1@000007003oN`D0
00001P00og/5000001T00?mk0`000002003oBPP0000000<00;iZ00000000HD400P0000000`00LDX0
0000003^JP06000000/00?mc00<00000002nFP00bV800`00bV82000000<00?mZ00@00000003oL`00
og<000001`00og<h0?ooo`00@03oool600000003003oR`000000000000800?n;00@00000003oR`00
oh/00?n;0P000002003oR`8000001000oh/0100000000?n3003oP`00oh<4000000D00?n31@000005
003oP`D000000`00og/200000004003oR`0000000000000000@00?mk0`000006003oL`<000002`00
og<6003oN`D000003@00og/4000000L00?mk1@000007003oN`H000001P00og/00`0000000?m:0000
000600000004002UJP0000000000002nJP80000000D00=iZ0000000000000>iZ003o@@0200000003
003R80000000000000/00?mc00<00000002nFP00_UX00`00bV82000000<00?mZ2`00og<h0?ooo`00
?`3oool01`0000000?n;003oR`0000000?mk00000000oh/00`0000001000oh/0000000000000oh/2
000000800?n;0P0000000`00oh<00000003oR`04003oR`0300000000oh<00?n300<000001@00oh<4
000000H00?n310000007003oN`8000002000og/9003oL`8000001P00og<400000003003oL`00og/0
0?mk00/00?mk10000007003oN`D000001P00og/2000000800?mZ00<00000003oN`00og/01@00og/2
00000003003oJP000000000000L00?mk100000001000kR00000000000000B3T3000000800<YR00L0
0000003NJP00gVX00000003o@@0000000>iZ00<0000000<00?YZ003oL`00og<01P00og<010000000
0?mc003oL`000002002nFP<00<YR00<00000003oJP00ofX00P00ofX;003oLcP0oooo000o0?ooo`@0
0?n;00D00000003oR`00oh/00?n;00000002003oR`8000001@00oh/7000000<00?n;1000000:003o
P`@000001000oh<2003ZN`P00?mk0P000006003oN`<000001P00og<5000000<00?mc1P000002003o
L`03003oN`000000000000<000001P00og/5000000L00?mk10000007003oN`@000002000og/40000
00P00?mk100000001@00WEX0000000000000]V80000000800<YR0`0000001P00od40000000000000
00000>8P000000<00?YZ1000og<00`0000000?mc003oL`0300000004003oL`0000000;iJ00000080
0<YR00<00000003oJP00ofX00P00ofX7003oL`0500000000og<00?mc003oL`000000=`3oool003l0
oooo00<00000003oR`00oh/02000oh/2000000@00?n;0P000002003oR`L0000000@00?n300000000
oh<00?n310000006003oP`0400000000dW<00000000000800?n300<00000003oP`00jW/01@000003
003oN`D000000`00og/200000004003oP`0000000000000000<00?mc0`0000000`00og<00000003o
L`04003oL`@000001@00og<6000000H00?mk1000000=003oN`D000001`00og/4000000L00?mk1@00
0007003oN`<000000P00bV800`0000000?m1003o@@0200000003003R800000000?YZ00@00?YZ0`00
og<2000000800?mc00D00000002fFP0000000000002nFP0200000003003:HP0000000?mZ00<00?mZ
1000og<0100000000?mc003oL`000003003oL`030000003oool0oooo03D0oooo000o0?ooo`030000
0000oh/00?n;008000000P00oh/0100000000?n;003oR`00oh/2000000P00?n;00<00000003oR`00
oh/00`0000001000oh<00000000000000002003oP`0300000000og/0000000D00?n310000002003o
P`8000000P00oh/2003:L`8000001P00lW/2000000H00?mc0P000007003oL`8000002000og<01000
00000?mc003oL`000004003oL`03003oN`000000000000D00?mk10000006003oN`@000001`00og/2
000000800?mZ00<00000003oN`00og/01@00og/00`0000000?mR003oHP02000000H00?mk0P000000
0`00odX0000000000007003oN`80000000H00<YR00000000od400?m100000000od4300000003003^
JP00nVX00?YZ00800?YZ00/00000003oL`00og<00000002UDP0000000?mc00000000]UX00000003o
L`03000000800<YR00D00000003oJP00ofX00?mZ00000003003oL`0300000000og<00?mc00800000
00<00?mc0000003oool0=`3oool003l0oooo0`0000001P00oh<00000003oR`0000000?n300000080
0?n;00<00000003oR`00oh/00P000008003oR`0400000000oh/00?n;003oR`D0000000@00?n30000
0000oh<00?n30P000006003oP`<000000`00oh/3003:L`0300000000lW/00?9k00D00?9k4@00og<0
0`0000000?mc003oL`06003oL`0400000000og<00?mc000000D00?mc00<00000003oN`00og/01@00
og/4000000H00?mk0P0000000`00ofX00000003oN`07003oN`@000001`00og/5000000L00?mk1000
0005003oN`@000001000od44000000800>iZ00<00000003jJP00nVX00P000002003oL`<0000000<0
0?mc0000000000000`00og<200000003003:HP0000000?mZ00800?mZ00@00000003oL`00og<00?mc
0P0000001@00og<0000000000000og<0000003P0oooo000n0?ooo`0500000000oh/00?n;003oR`00
00000P00oh/300000003003oR`0000000?n;00@000000P00oh/2000000L00?n;0P000002003oR`80
00000P00oh<4000000H00?n30P000003003oR`0400000000bW<00<Yc003:L`<000001@00lW/20000
00D00?mc0`000006003oL`0400000000oh<00000000000D00?mc10000005003oL`@000001000og/6
000000H00?mk10000007003oN`D00?mc6@00og/4003oFP03003oN`00000000000080000000@00?m1
00000000000000000`00kVX2000000800?YZ0P0000001000og<00000000000000002003oL`800000
0`00og<01@00ofX000000000000000000?mZ00<0000000L00?mc00000000og/00000003oL`000000
oooo00800000>03oool003h0oooo2000oh/00`0000000?n;00000002003oR`<0000000@00?n;0000
0000000000000P00oh/2000000L00?n;00<00000003oP`00oh<01@000006003oP`0400000000oh<0
0?n3003oP`<0000000D00?n;002^L`0000000000003oR`03000000800?9k00<00000003oR`00oh/0
0P000002003oL`8000000P00oh<2000000<00?mc0P0000001000oh<00000000000000003003oL`H0
00000`00og<6000000`00?mk10000006003oL`D000001P00og<5000000L00?mk10000005003oN`04
00000000oeX00?mJ000000800?mJ0P000006003oN`8000000P00kVX01000000008eB00000000nVX3
00000003003oJP000000000000<00?mc00<00000003oL`00og<00P00og<0100000000>IJ00000000
ofX30000000:003oL`000000000000000000og<000000?ooo`0000000?mc000003L0oooo000n0?oo
o`0500000000oh/00?n;003oR`0000002000oh/0100000000?n;003oR`00oh/200000005003oR`00
0000000000000000oh/00`000002003oR`8000000`00oh<2003oN`0300000000og/00?mk00800?n3
0P000005003oP`<000000P00oh/00`0000000:ic002^L`02000000D00>9c0P000006003jL`800000
1`00og<2000000H00?mc0`000006003oJP<000000P00ofX3003oN`<000001`00og/200000003003o
JP000000000000D00?mc0P000002003oHP0300000000og<00?mc00@00?mc0`0000000`00dST00000
003oN`06003oN`0400000000od400?m1000000<00?mk00<00000003oFP00oeX00`00oeX00`000000
0;IR00000007003oN`8000000P00kVX300000003003oJP000000000000800?mZ0P000007003oL`03
00000000iUX000000080000000<00?mk00000000og<00P000003003oL`0400000000og<00?mc0000
03L0oooo000o0?ooo`0400000000oh/00?n;000000<00?n;00<00000003oR`00oh/01P00oh/01000
00000?n;003oR`000003003oR`D0000000<00?mk00000000oh<00P0000000`00og/0000000000002
003oN`80000000<00?mc00000000oh<00`00oh<2000000800?mk10000003002^L`8000001@00hW<8
003jLa400?mc3@00ofX3003oN`0400000000ofX00000000000L00?mk10000006003oL`@000001`00
og<4000000L00?mk10000002003oN`0300000000oeX00?mJ00800?mJ1@000007003oN`80000000@0
0>iZ00000000000000000P00ofX2000000800?mZ00<00000003oL`00og<01P00og<2003VFP030000
0000og<0000000<00?mc00D00000003oL`00og<00?mc00000002003oLcP0oooo00100?ooo`800000
00<00?n300000000oh/00P0000000`00oh/000000000000<003oR`0300000000oh/00?n;00<00000
00<00?n30000000000002@000004003oP`D00?mk0`000003002MJP0300000000oh<00?n300800000
0`00hW<2000000D00?Yc0`000005003oL`<000001P00og<3000000D00?mZ0P0000000`00ofX00000
003oJP02003oJP<00?mk10000006003oNa400?mc10000007003oL`@0000000<00?mk000000000000
0P00og/00`0000000?mJ003oFP02003oFP<000003000og/4000000<00?mZ00@00000003oJP00ofX0
0?mZ2000og<01@0000000>IJ00000000og<0000000X00?mc>03oool003l0oooo00@00000003oR`00
oh/000000P00oh/300000003003oR`0000000?n;00<000002`00oh/0100000000?n;003oR`00oh/2
00000003003oP`000000000000@000000P00og/2003oP`8000001000og/4000000@009eZ0P000004
003FL`D000000P00nW<6000000800?mc0P0000001000mW/00000000000000002003oL`8000000P00
og/3000000800?mZ00<00000003oN`0000000P000004003oJP<000001P00og<4000000H00?mc1000
0007003oL`0400000000of800?mR000000L00?mc0P000004003oHP8000001000oeX300000003003o
@@00og/00?mk00<00?mk1@000007003oN`0300000000ofX00?mZ00<00?mZ2000og<0100000000>IJ
003VFP00000;003oLcP0oooo000o0?ooo`@00?n;0P000002003oR`<0000000D00?n;00000000oh<0
0000003oR`02000000<00?n;00<00000003oR`00oh/01@00oh/01@0000000?n3003oP`00oh<00000
00800?n30`000002003oN`@000001000og/00`0000000?mc003oL`03000000@009eZ1@00eW<20000
00H00>ic0P000006003jL`8000001@00ofX5000000@00?mZ1@000003003oJP80000000<00?mJ0000
000000001@00og<0100000000?m:000000000006003oL`80000000<00?mR00000000og<01@00og<0
1@0000000?mR003oHP00of80000000H00?mc00<00000003oHP00of801000of87003oFP<000001@00
og/300000003003ZHP0000000?mk00D00?mk00<00000003oJP00ofX01000ofX3003oL`0500000000
og<00?mc003oL`0000000`00iUX00`0000000?mc003oL`08003oL`030000003oool0oooo03D0oooo
000o0?ooo`0300000000oh/00?n;00D00?n;00@00000003oR`00oh/00?n;0P0000001000oh/00000
003oP`000002003oR`80000000<00?n;0000000000001000oh/:003oP`0500000000og/00000003o
N`0000001000og/4003oL`@000000`00WFX2000000D00=Ic1`00kW<8003jL`P00?mZ00<00000003o
JP00ofX01P00ofX00`0000000?mZ003oJP04003oJPD000001@00og<4000000H00?mc10000006003o
L`D000000`00og<2000000H00?mR0`000005003oFP8000001`00og/5000000H00?mk0P000004003o
JP0300000000og<00?mc00<000000P00og<00`0000000>IJ003VFP0300000003003oL`0000000?mc
00800?mc00@00000003oL`00og<00000=`3oool00400oooo00<00000003oR`00oh/02000oh/00`00
00000?n;003oR`02000000800?n;1P000002003oR`8000000`00oh<00`0000000?n3003oP`05003o
P`@000000P00og/2000000@00?mc00<00000001@DP0000000`00YFX200000003003oL`0000000000
00<00=Ic0P000005003^L`8000001P00nW<00`0000000?mZ003oJP0F003oJP03003oHP00og<00?mc
00D00?mc0P000006003oL`@000001P00og<4000000800?mc0P000002003oL`0300000000of800?mR
00D00?mR00<00000003oL`0000001@00oeX2000000@00?mk10000007003oN`8000000P00og/2003o
P`8000000P00ofX2000000800?mc00D00000003NFP0000000?mc00000003003VFPD000000P00og<0
100000000?mc003oL`00000g0?ooo`00@@3oool2000000/00?n;00D00000003oR`00oh/00?n;0000
0002003oR`<0000000D00?n;0000000000000000003oP`0300000003003oP`000000000000<00?n3
00<00000003oN`0000000P00ofX200000003003oN`0000000?mc00800?mc00@00?mk00000000D580
051B1000YFX200000005003oL`0000000<ic003>L`0000000P00og<2000000800>ic1@000003003j
L`@000001000ofX3000000L00?mZ00<00000003oJP00ofX01@00ofX2003oHP<00?mc00<00?mR0000
000000000P00of800`0000000?mc003oL`04003oL`0400000000of800?mR000000H00?mc0P000005
003oHP8000001`00of80100000000?mc003oL`000004003oFP0300000000og/0000000D00?mk1000
0006003oN`0400000000nVX00000000000H00?n300L00000003BFP0000000?mc00000000gUX00000
00800?mZ00<00000003VFP00iUX02P00000h0?ooo`00@03oool00`0000000?n;00000002003oR`80
00000P00oh/00`0000000?n;003oR`09003oR`0400000000oh<00?n3003oP`80000000<00?n30000
0000og<01@000002003oP`80000000L00?mk00000000ofX00?mZ00000000og/0000000<00?mc0P00
og/010000000051B001@DP00D585002UJP0300000000cW<00<ic00800<ic0P000005003NL`<00000
0`00kVX300000003002fL`000000000000800?mZ00<00000003BN`00dW/00`000003003oJP@00000
1@00ofX300000003003oHP00og<00?mc00800?mc10000006003oL`80000000@00?mR000000000000
00000P00og<2000000l00?mR00@00000003oL`00og<000001000oeX300000003003o>@00og/00?mk
00@00?mk10000006003oN`<000001`00oh<0100000000=9J00000000ofX2000000<00?mZ00<00000
003VFP0000002`00000f0?ooo`00@@3oool01`00oh/00000003oR`0000000?n;00000000oh/00P00
0002003oR`8000001`00oh/4003oP`0500000000oh<00?n3003oP`0000000P00oh<300000004003o
P`0000000?mc000000800?mk00<00000003oJP0000000P0000001000og<00000000000000002003o
N`0400000000D580051B000000D00:EZ1P00cW<6003NL`0300000000kVX00>iZ00@00>iZ0P000005
003jJP80000000<00=9k00000000ofX00P00ofX00`0000000>Ic00000003000000<00?mZ00<00000
003fL`0000000`000005003oL`<000001000og<2000000D00?mR0P00000:003oHP8000001P00of82
000000@00?mJ0`000002003o>@800?mk10000006003oN`8000000P00og/2003oP`8000001`00oh<2
000000800?mZ0P000003003oJP800>IJ2`00000f0?ooo`00@@3oool00`0000000?n;003oR`060000
0004003oR`0000000000000000800?n;0P000002003oR`0300000000oh<00?n300T00?n300@00000
003oP`00oh<00?n30`0000001000oh<00000000000000003003oBP@000000P00og/6000000<00:EZ
00<00000003>L`0000000`00cW<00`00gW<00000003NL`04003NL`8000000`00kVX00`0000000>iZ
003^JP04003jJP0600000000nVX00?YZ00000000ofX000000`00ofX4000000@00?mR0P0000001000
mW<0000000000000of82000000D00?mR0P0000000`00og<000000000000A003oHPH000001@00of84
003oFP<00?mB0`00ocT2003oN`80000000<00;IJ00000000og/01P00og/3000000H00?n310000002
003oP`8000000P00ofX00`0000000?mZ003oJP02003oJP03003VFP000000000000P00000=`3oool0
0400oooo00D00000003oR`00oh/00?n;00000002003oR`<0000000D00?n;0000000000000000003o
R`0300000003003oR`000000000000800?n30P000002003oP`<000000`00oh<0100000000?n3003o
P`00oh<200000003003oP`0000000?n3008000001000hW<5000000D00>ic1@000006003jL`800000
00<00=ic0000000000001P00ofX2000000800?YZ0P000006003oJP80000000<00?mZ000000000000
1`00ofX200000003003oHP000000000000T00?mR00<00000003oHP00of804000of80100000000?mc
003oL`00og<2000000D00?mR10000004003oDP80000000H00?li003oN`00og/00?mk00000000]UX2
000000L00?mk0`000006003oP`0300000000bU80000000H00?n300<00000003oJP00ofX00P00ofX0
0`00iUX000000000000600000003003oN`000000oooo03H0oooo00100?ooo`P00?n;00@00000003o
R`00oh/000000`00oh/400000003003oP`000000000000@000001000gW/3000000H00=ik0`000008
003RL`0300000000kW<00>ic00L00>ic00<00000003jL`00nW<02000nW<00`0000000?mZ003oJP08
003oJP8000002P00ofX00`0000000?mZ003oJP09003oJP0300000000of800?mR01<00?mR0`000005
003oHP8000000P00og<00`0000000?mR003oHP04003oHP0400000000og<00?mc000000@00?mB0P00
0002003o>@<00?mk0P00000;003oN`8000001P00oh<3000000D00?n300<00000003oJP00ofX00`00
ofX7000000800?mk>03oool003l0oooo00<00000003oR`00oh/03@00oh/00`0000000?n3003oP`04
00000003003^N`000000000000L00=ik0`000005003NN`<000001`00hW<2000000T00>ic2`00nW<R
003oJP/00?mR0`000006003oHP8000000`00og<2000000D00?mR0P000006003oHP0400000000og<0
0?mc000000@00?mB00@00000003oL`0000000?li10000006003oN`@000001P00og/4000000X00?n3
0P000003003oJPD000001000og/h0?ooo`00?`3oool00`0000000?n;003oR`02000000<00?n;00<0
0000003oR`00oh/01@00oh/00`00oh<00000003oN`05003oN`0300000000kW/0000000<000000P00
gW/6000000800=ik0P0000000`00oh<0000000000002000000<00>9c00<00000002EDP00UE800P00
0006003^L`<000002000nW<3000000T00?mZ00<00000003oJP00ofX02000ofX2000000X00?mZ0P00
0007003oHP8000000P00ofX3000000<00?mR0P0000001000ofX0000000000000000>003oHP040000
0000og<00?mc000000@00?mB00<00000003oL`0000000P00ocT5000000H00?mk00@00000003NHP00
000000001@00og/4000000H00?n310000002003oP`80000000<00?mZ0000000000000`000003003o
N`030000003oool0oooo03H0oooo00100?ooo`80000000@0oooo00000000oh/00?n;0P000002003o
R`0300000000oh/0000000<000001P00og/6000000D00<Ic0P000006003:L`<000001P00eW<50000
00@00>ic0P000002002fJP<000000`00nW<2000000<00=IZ0`000004003oJP80000000<00>iZ0000
000000001P00ofX200000004003oJP0000000000000000H00?mZ0`0000001000of80000000000000
0003003oHP0300000000ofX00?mZ00800?mZ0P000006003oHP8000002@00of82000000<00?mR0`00
oeX2000000@00?mB100000001000ocT00?la003oL`00og<4000000H00?mk10000005003oN`@00000
1P00oh<00`0000000?mZ00000005003oP`@0000000D00?mk00000000og/00?mk0000000h0?ooo`00
?`3oool01P0000000?n;0000003oool00000003oR`<0000000<00?n;0000000000001@00oh<40000
00H00>Yk00@00000003FL`00000000001@00aW<2000000L00<Yc2000eW<00`0000000>9c003RL`06
003RL`<000001P00kVX2000000800=IZ0P000004003oJP80000000@00>9Z003^JP00kVX00>iZ0P00
0003003oJP0300000000mV800?IR00800?IR0`000004003oJPH000001P00of8200000003003oJP00
00000?mR01400?mR00<00000003oJP0000000P000005003oFPL00?mB0P00ocT2003o<@800?mc1P00
og/4000000D00?mk10000006003oP`<000000P00oh<200000003003oP`0000000?n300800?n30`00
00000`00og/0000000000002003oN`030000003oool0oooo03H0oooo000n0?ooo`0400000000oh/0
0?n;003oR`80000000D00?n;0000000000000000003oR`02000000@00?n310000006003ZN`030000
0000oh<0000000@000000P00aW<200000004003oP`0000000000000000<00<Yc0`000006003FL`80
00002@00hW<9003^JP8000002000ofX4000000H00?mZ0P000002003fHP8000001`00of82000000X0
0?mR00<00000003oHP00of804000of801@0000000?mZ003oJP00ofX0000000H00?mJ1`00oe800`00
ocT00000003o<@03000000H00?mk00@00000003:FP00bUX000001@00og/0100000000?mR00000000
0006003oP`<000001@00oh<2000000800?n30`0000000`00og/000000?ooo`02000003T0oooo000n
0?ooo`@00?n;00@00000003oR`00oh/00?n;100000001000oh<00000000000000005003oN`@00000
0`00dW<200000003002bJP0000000:EZ00D00:EZ0P000004002bL`80000000@00?n3000000000000
00000`00eW<200000003003oN`000000000000H00>9c0P000009003^JQD00?mZ0P00000O003oHP<0
00001@00of85000000H00?mJ10000003003oDP<000000P00oc42000000L00?mk10000005003oN`@0
00001@00oh<400000004003oP`0000000000003oP`@0000000@00?mZ00000000000000000P3oool2
000003T0oooo000n0?ooo`P00?n;1@00oh<3000000D00?mk0`0000000`00dW<00000003BL`03003B
L`D000001@00YFX00`0000000;9c002bL`03002bL`8000001P00`W<200000003003:JP0000000000
00<00>9c0P000002002nJP8000001P00kVX2000000X00?mZ00<00000003oJP00ofX02000ofXF003o
HP0300000000of800?mR00D00?mR1`000005003oHP8000001P00oeX0100000000?mZ000000000003
003oDP0300000000og<0000000800?la1000000;003oN`@000001@00oh<4000000D00?n300@00000
003oP`00oh<00?n30`000002003oJP0600000000oh<0000000000000og/00000>@3oool003h0oooo
00@00000003oR`00oh/000000`00oh/00`0000000?n3003oP`02003oP`8000000P00oh<4000000@0
0?mk10000003002fHP80000000@0085J00000000000000000P00YFX4000000@00;9c0P0000070032
L`0300000000eVX00=IZ00@00=IZ0P0000001000_VX00000000000000003003^JP8000000P00bVX2
000000H00?mZ0P0000000`00gV80000000000007003oJP8000002P00of800`0000000?mR003oHP06
003oHP80000000<00>iZ0000000000001000of80100000000?mZ003oJP00ofX3000000L00?mR1P00
oeX0100000000?mZ003oJP000004003oDP0300000000og<0000000800?la00<00000003oL`00og<0
0`00og<4000000D00?mk00@00000003bFP00000000001P00oh<3000000D00?n30`000002003oJP80
00000`00ofX300000003003oN`000000oooo03P0oooo000n0?ooo`0400000000oh/00?n;00000080
0?n;0P0000000`00oh<0000000000005003oP`L000001@00og<3000000800;IR10000003001mHP@0
00000P00/W<00`0000000?lY003oJP02000000H00<9c2000eVX2000000H00>9Z0`000002003:JP80
00000`00ofX00`0000000=IZ003FJP03003NHP0300000000ofX00?mZ00800?mZ0P000002003ZHP80
00001P00of85000000D00?mR00<00000003oFP00kVX00P00kVX2000000@00?mR0P0000000`00ofX0
0000003oHP08003oHPD00?mJ0P0000000`00ofX00000003oDP03003oDP0400000000og<00000003o
<@80000000<00<h@003oL`00og<00`00og<200000003003BDP000000000000D00?mk10000003003o
P`8000000P00og/2000000@00?n3100000000`00ofX0000000000004003oJP80000000<00?mk0?oo
o`3oool0>03oool003h0oooo00@00000003oR`000000oooo0P000002003oP`<000000P00oh<20000
00@00?n3100000001000og<0000000000000og<600000003002=DP000000000000<000000`00OF85
002EJP80000000<00?mZ0000000000001000`W<3000000L00=IZ2@00hVX3000000H00?9Z1@000006
003oHP80000000@00>YR00000000000000001000of801@00000009DP0000000000000?mR00800000
1@00of8200000003003^JP000000000000L00?mR00<00000003oHP00of801`00of83000000D00?mJ
0P000003003oDP0400000000og<00?mc000000<00?la0P000005003oL`8000000`00og/4000000D0
0?mk0P0000000`00of800000003oN`04003oN`<0000000<00?mZ0000000000000`00ofX00`000000
0?mZ003oJP02003oJP800?n30P00000i0?ooo`00?P3oool0100000000?n;000000000004003oP`04
00000000oh<00?n3003oP`<000002000oh<3000000D00?mc100000001000SE800000000000000002
001IDP<000001@00UFX00`0000000;9Z002bJP03002bJP<0000000<00?mk0000000000001000eVX2
000000T00>9Z2P00lVX00`0000000?mR003oHP08003oHP8000001`00of84000000T00?mR00<00000
003oHP00of804000of82000000800?mZ00<00000003oFP00oeX00`00oeX5003oDP8000001000oc42
000000<00?mc0P000005003oN`0400000000iUX00>IJ000000H00?mk0`000005003oN`<000000P00
ofX2000000P00?mZ0`00oh<00`000000oooo0?ooo`0f0?ooo`00?@3oool01@0000000?n;003oR`00
oh/0000000P00?n31`000004003oP`0300000000oh<00?n300@000001000og<700000003001IDP00
0000000000<000000`00UFX00`0000000;9Z002bJP04002bJP8000001@00aVX00`0000000;iZ002n
JP02000000H00>9Z0P00000:003bJQD00?mR00<00000003oHP00of806@00of82000000800?mB0P00
0006003oFPH00?mB1000oc42000000800?mc0P0000000`00_U800000003oN`05003oN`@0000000<0
0?mk0000000000000P000004003oN`@0000000<00?mR0000000000000`00ofX00`0000000?mZ003o
JP06003oJP0400000000oh<00?n3000003P0oooo000m0?ooo`<00?n;0P0000001000oh<000000000
00000007003oP`<0000000@00?n300000000000000001000oh<300000004003oL`00000000000000
00@00?mZ00<00000003oL`0000000P000002001IDP0300000000MF8007ER008007ER10000006002b
JPH00<IZ0P0000001000_VX00000000000000003003RJPD000001`00lVX2000002T00?mR0P000005
003oHP0500000000of800000003oDP0000001P00oeX3000000@00?mB0P000002003o<@8000000`00
og<0100000000;iB000000000003003oN`8000001@00og/200000003003oHP0000000?mk00<00?mk
100000000`00of8000000000000<003oJP0400000000oh<00?n3000003P0oooo000m0?ooo`030000
0000oh/0000000<00?n31P000008003oP`L000001000oh<6000000800?mc0P000002003oP`8003@a
0P000004001eHP80000000<00?mZ00000000/VX00`00/VX2000000L00<IZ0P000006003FJP<00000
00<00<9Z0000000000000`00lVX200000004003:HP00dV800000000000H00?mR0P00000:003oHP03
00000000of800?mR00L00?mR0P000007003oHP8000000P00oe82000000@00?mJ0`000006003oFP03
00000000ofX0000000@00?mB0`0000000`00oc40000000000005003oL`0400000000og<00?mc003o
L`80000000<00=9B00000000og/01@00og/300000008003oN`000000000000000000of800000003o
N`000002003oHP0300000000ofX00?mZ00H00?mZ00@00000003oJP00ofX00?mZ0P000002003oP`03
0000003oool0oooo03D0oooo000m0?ooo`0300000000oh/00?n300<00?n300D00000003oP`00oh<0
0000003oR`0200000003003oP`000000000000@00?n300D00000003oP`00oh<00000003oP`020000
0003003oP`000000000000@00?n30`0000001000og<00000003oP`000002003oP`80000000@003@a
00000000000000001000MF800`00000009eZ002MJP02002MJPD000001P00aVX9003FJP8000001P00
iV8300000003003BHP000000000000<00?mR0P000002003JHP8000001P00of8200000003003oFP00
0000000000D00?mR0P000002003oFP8000001000of800`0000000?mR003oHP03000000d00?mJ1000
0004003oDP8000000P00oc42000000800?mc0P000006003oL`@0000000@00?mk0000000000000000
1@00og<00`0000000?mc00000002003oHP8000000`00of88003oJP8000000P00ofX00`0000000?n3
003oP`02003oPcL0oooo000n0?ooo`0300000000oh<00?n300H00?n300H00000003oP`00oh<00000
003oP`000002003oP`8000001000oh<00`0000000?n3003oP`03000000800?n30P000004003oP`<0
000000@00?n300000000oh<000000P00oh/00`00=340000000000003001eHP0300000000WFX009eZ
00<009eZ0P0000000`00gW<00000000000040036JP8000002000eVX:003VHP8000001P00nV820000
00800=YR0P000004003oHP80000000D008UJ00000000oeX00?mJ00000003003oHP0300000000oeX0
0?mJ00800?mJ00<00000003oFP00oeX01000oeX00`0000000?mR0000000>003oFP0400000000ob00
0?lP000000@00?mB00/00000003oJP0000000?la00000000og<00000003oL`0000000:i:0000000;
003oL`@000001000og<3000000<00?mR00@00000003oHP00of800?mR2000ofX2000000800?mZ00<0
0000003oP`00oh<00P00oh<00`000000oooo0?ooo`0d0?ooo`00?P3oool200000003003oP`000000
000000P00?n300<00000003oP`00oh<00`0000000`00oh<0000000000004003oP`0400000000oh<0
0?n3003oP`<0000000<00?n30000000000001@00oh/5000000030000:@0000000000008005UJ1000
0005002MJP0300000000]VX00;IZ00800;IZ1P000005003FJP8000002@00iV8:003jHP8000001`00
of85000000D00?mR0P0000000`00oeX00000003oFP07003oFP0300000000oeX00?mJ00L00?mJ00@0
0000003oFP00oeX00?mJ0P00oe83000000@00?mB00<00000003oJP0000000P00oc42000000800?mc
00@00000002^BP00000000000`00og<2000000D00?mc0P000002003oJP@0000000<00?mJ00000000
00002000of83003oJP0700000000ofX00?mZ003oJP0000000?n300000002003oJP0400000000oh<0
0?n3000003L0oooo000m0?ooo`0500000000oh<00?n30000003oool01@000002003oP`8000000`00
oh<01@0000000?n3003oP`0000000?n30080000000<00?n30000000000001000oh<01@0000000?n3
003oP`0000000?mc008000001`00oh/3000000030000:@0000000000008005UJ1@000004002MJPD0
0;IZ0`0000000`00[VX0000000000003003FJP0300000000og<00000008000001`00iV8:003jHP/0
0?mR00<00000003oHP00of801`00of800`0000000?mJ003oFP0@003oFP@000002@00oe84000000<0
0?la00D00000003oL`00og<00?mc00000004003oL`0400000000dU800000000000800?mc0P000005
003oJP<0000000<00?mJ0000000000002000of83003oJP<0000000@00?mZ00000000000000000P00
ofX300000003003oP`000000000003D0oooo000m0?ooo`@00?n300<00000003oP`00oh<00`000000
1000oh<00000000000000002003oP`0300000000oh<00?n300800?n300H00000003oP`00oh<00000
003oP`000002003oP`8000000`00oh<2000000800?n310000003003oR`0300000000oh/00?n;00@0
00000`00FEX00`00000008UR0029HP020029HP<000001P00]VX2000000H00<YR00@00000003oL`00
00000;IR0P000004003VHP8000002@00nV8E003oHQ400?mJ0P0000000`00odX0000000000009003o
DP<00?m:00<00000003o<@00oc400P00oc400`0000000?mc003oL`06003oL`8000000`00ofX30000
0004003oJP0000000000000000800?mJ0P000002003oFP0300000000of800?mR00H00?mR00L00000
003oJP00ofX00000003oN`0000000?mZ00<000000`00ofX0100000000?n3003oP`00oh<f0?ooo`00
?@3oool00`0000000?n3003oP`05003oP`0700000000oh<00?n300000000oh<00000003oP`020000
00800?n30P000004003oP`0300000000oh<00?n300<000000P00oh<00`0000000?n3003oP`03003o
P`H000000`00oh/5000000<005UJ1@00RF84000000D00;IZ2000bV80100000000:ER000000000004
003JHP0300000000^V800000008000001P00nV82000001@00?mR2P00oeX2000000@00?mJ00<00000
003oHP0000000P000009003oDP@00?m:1000oc45000000D00?mc1@00ofX0100000000?mJ003oFP00
oeX3000000800?mJ0P000003003oFPP00?mR0P000002003oJP0400000000og/00000003oJP800000
1000ofX3003oP`030000003oool0oooo03<0oooo000m0?ooo`0300000000oh<00?n3008000001`00
oh<0100000000?n3003oP`00oh<600000003003oP`000000000000<00?n300@00000003oP`00oh<0
0?n30`000002003oP`8000000`00oh<300000003003oR`000000000000<00?n300<00000001<DP00
C5800`0000050029HP0400000000fW<00000000000<00;IZ0P000008003:HP0300000000fV800=YR
00D00=YR1@000003003jHP8000000P00bUX2000000L00?mR0P000008003oHP8000001`00oeX20000
00800?mJ0P000003003oFP<000001`00oe83000000@00?m:0P000002003o<@8000000P00UDX01000
00000?mc003oL`00og<2000000<00?mZ0P000002003oFP<0000000<00?mB00000000oeX00P00oeX0
100000000?mJ003oFP00oeX4003oHP0400000000of800?mR003oHP8000000P00ofX3000000800?mZ
00<00000003oJP00ofX00P00ofX2003oP`030000003oool0oooo03@0oooo000n0?ooo`80000000@0
0?n;0000000000000?n30P000002003oP`0300000000oh<00?n300D00?n300<00000003oP`00oh<0
0`000002003oP`8000000`00oh<01`0000000?n3003oP`00oh<00000003oP`0000000P00oh<01000
00000?n3003oP`00oh<3000000<00?n30P000002001<DP@000001000RF800`0000000:ER002UHP02
002UHP80000000<00?mk0000000000001P00bV8:003JHP0300000000kV800>iR00@00>iR00@00000
003:FP00bUX00<YJ0`000003003oHP<0000000<00?9J0000000000001@00of800`0000000?mJ003o
FP02000000@00?mJ1P000006003oFP0300000000oe800?mB00@00?mB00@00000003oJP00ofX00000
0`00odX00`0000000?mZ00000002003o<@@000000`00ofX800000005003oFP000000000000000000
oeX00P000008003oFP<00?mR00@00000003oHP00of800?mR0`000002003oJP8000001`00ofX20000
0003003oP`000000oooo03@0oooo000m0?ooo`0600000000oh<00000003oR`0000000?n30`000000
0`00oh<0000000000003003oP`0300000000oh<00?n300D00?n300H00000003oP`00oh<00000003o
N`000002003oP`0300000000oh<00?n300<00?n300<00000003oP`00oh<00P000004003oP`030000
0000oh<00?n30080000000<00?n30000000000000`00C583000000<008UR1P00YF85000000@00<YR
0P000009003JHPP00>iR0P0000000`00bUX0000000000005003oFP0300000000C580000000800?9J
00D00000003oHP00of800?mR00000004003oFP8000001000oeX3000000P00?mJ1P00oe8010000000
0?lP000000000004003oBP8000000P00oc40100000000<X@003oJP000004003oJP8000000`00oe80
0`0000000?li003o>@0200000003003o>@0000000?mJ008000002000oeX3003oHP8000000P00of80
0`0000000?mc00000002003oJP8000001`00ofX3003oPcH0oooo000m0?ooo`<00?n300D00000003o
P`00oh<00?n300000002003oP`0400000000oh/00000003oP`H000000P00oh<2000000<00?n300<0
0000003oP`00oh<00`000002003oP`8000000`00oh<6000000<00?n30`0000000`00oh<000000000
0003001<DP@007ER0P000007002UHP0300000000_V800;iR00<00;iR00<00000002EHP0000000P00
0007003JHPX00>iR00<00000003oFP00oeX01P00oeX4000000D00?mJ0P0000000`00oeX00000003o
FP06003oFP0300000000oeX00?mJ00L00?mJ1@00oe85000000<00?m:0`000002003o<@0300000000
bQ000?mZ00D00?mZ1000oe82003o>@80000000@00?9B00000000000000000P00oeX00`0000000?mJ
003oFP06003oFP0500000000of800?mR00000000ofX00P0000000`00of80000000000003003oJP03
00000000ofX00?mZ00D00?mZ00@00000003oP`00oh<00000=@3oool003d0oooo00@00000003oP`00
oh<000001`00oh<00`0000000?n3003oP`0200000003003oP`000000000000<0000000D00?n30000
0000oh<00?n300000004003oP`0500000000oh<00?n300000000oh<010000004003oP`D000000`00
oh<2000000<004A:0P000004001eHP<000001P00YF86002nHP<0000000<009ER0000000000001000
fV82000000T00>iR2P00oeX00`0000000?mJ003oFP07003oFP0300000000oeX00?mJ00l00?mJ00<0
0000003oDP00oe800`00oe8200000003003oHP0000000?m:00<00?m:0`0000000`00oc4000000000
0002000000D00?mZ0P00oe8200000005003o>@000000000000000000lU800`00000;003oFP030000
0000of800?mR00@0000000<00?mR0000000000002`00ofX0100000000?n3003oP`00000e0?ooo`00
?P3oool00`0000000?n300000003003oP`0300000000oh<0000000<000000`00TEX2000000@007eR
0P0000001@00oh<00000003oP`0000000?n3008000001000oh<0100000000?mk003oN`00og/20000
0003003oP`000000000000<00?mk0P000002003oP`@000000`00A4X2000000@007ER10000003002U
HP8000001`00_V82000000@00<iR0P0000001000ZV800000000000000007003^HP0300000000oeX0
0?mJ02800?mJ00<00000003oFP0000000P000004003oDP0300000000odX00?m:00800?m:00@00000
002b<@0000000?la1@000003003oJP80000000D00?mB0000000000000000003>:@03000000800?9B
0P00000;003oFP80000000<00?mR00000000ofX00P000002003oHP0300000000ofX00?mZ00H00?mZ
00H00000003oJP00ofX00000003oP`00000f0?ooo`00?P3oool200000003003oR`0000000?n30080
00001@00YF800`000000095J002AFP02002AFP8000001000OF82003oP`0400000000oh<00?n3003o
P`80000000@00?n300000000000000000P00og/0100000000?mk003oN`00og/300000003003oN`00
00000?mk00800?mk0`000002003oN`0600000000A4X004A:00000000gW/000001000MF800`000000
09ER002EHP02002EHP0400000000TFX00000000000L00;iR1P00cV8200000004003RL`0000000000
000000@00>iR0P0000000`00^UX00000003oFP0J003oFP0300000000oeX00?mJ00@00?mJ00D00000
003oFP00oeX00?mJ00000005003oDP@00?m:10000003003o<@04003:400000000000003oJP@00000
00D00?la0000000000000000003VDP03000000<00?9B00<00000003oFP00oeX01@00oeX010000000
0?mJ003oFP00oeX300000003003oHP000000000000@00?mR2000ofX200000004003oJP0000000?n3
000003H0oooo000m0?ooo`0300000000oh<00?n300L000000P00YF8400000003002AFP0000000000
00<000000P00OF83000000<00?n31000og/6000000800?mk00@00000003oN`00og/00?mk1@000002
003jL`<000000`00A4X3000000<007ER1P00UF8010000000095Z002AJP000006002nHPL00<iR1000
0004003RFP0300000000^UX00;YJ00800;YJ00<00000003oFP00oeX01000oeX2000000P00?mJ0P00
0007003oFP@000000`00oeX2000000800?mJ00<00000003oDP00oe801000oe86003oBP0300000000
oc400?la00800?la00<00<X@0000000000000P00of800`0000000?la003o<@04000000800>IB0P00
0004003bDPL00?mJ0P000002003oFP<0000000<00?mR0000000000001000of84003oJP0600000000
ofX00?mZ003oJP0000000?n30P0000000`00oh<000000?ooo`0e0?ooo`00?@3oool3003oP`030000
0000]V800;IR00800;IR10000004002EFP8000000`00OE801000000006eB001]DP00KE8300000003
003oP`000000000000<00?mk00D00000003oN`00og/00?mk00000002003oN`D000000`00og<20000
0003003jL`000000000000<000000`00A4X4001YFP8000001P00UF8010000000095Z000000000004
002nHP8000001`00cV800`0000000>9J003RFP05003RFP0400000000^UX00;YJ002jFP8000000`00
oeX300000003003RFP0000000?mJ00D00?mJ0P0000000`00lU800000003oFP04003oFP<000000P00
kUX0100000000?mB003oDP00oe83000000L00?mB00<00000003oBP00odX00`00odX5003o<@030000
0000of800?mR00800?mR0P00oc4300000004003oDP0000000>IB003VDP8000001000lU87003oFP80
00000P00oeX3000000800?mR00<00000003oHP00of800P00of84003oJP8000000P00ofX300000003
003oL`000000oooo03H0oooo000m0?ooo`0300000000oh<0000000800;iJ0`000004002UFP<00000
00<009EJ0000000000000P0000001000OE800000000000000003001]DP<00?mk0P0000001@00og/0
0000003oP`0000000?mk008000000P00og/0100000000?mc003oL`00og<200000003003oL`000000
000000<00?9Z0P000002003JJP@000001000JEX3000000D009ER00<00000002^HP00[V800P00[V82
00000080085R0P000006003>HPP00>9J00@00000002jFP00000000001@00mUX2000000800>9J00@0
0000003oFP00oeX00?mJ0P000003003bDP8000000`00oeX6000000H00?mB00<00000003oDP00oe80
1000oe800`0000000?mJ00000004003oBP@00?la00<00000003oHP00of800P00of800`0000000?la
0000000200000003003FBP000000000000<00>IB00<00000003bDP00lU800P00lU84003oFP030000
0000oeX00?mJ00<000000P00oeX2000000L00?mR1000ofX2000000800?mZ0`000002003oL`030000
003oool0oooo03@0oooo000n0?ooo`0400000000_UX00;iJ002nFP<0000000<00:EJ000000000000
100000050029DP0300000000MDX00000008000000P00KE8200000003003oN`0000000?mk00800?mk
0P000002003oN`D0000000<00?mc0000000000000P00ofX600000003003>HP000000000000800000
00<00:iR0000000000001000JEX00`000000085R00000004002EHPH00:iR0P0000020021HP800000
1000cV82000000P00>9J00<00000003fFP00mUX01P00mUX3000000D00?mJ00D00000003bDP00lU80
0?9B00000005003oFP<000003P00oe80100000000?mJ003oFP000004003oBP8000000P00oc400`00
00000?mR003oHP0300000005003J80000000000000000000eTX00P000004003VDP@00?9B1000oeX2
00000004003oFP0000000?mZ000000800?mJ0P000007003oHP0800000000ofX00?mZ003oJP000000
0?n300000000ofX2000000@00?mc=P3oool003d0oooo0P0000000`00_UX0000000000004002^FP<0
00000`00VE8800000003001eBP0000000000008005e11@0000000`00og/0000000000002003oN`05
00000000og<00?mc003oL`0000000P00og<8000000800<IJ0`0000000`00YE800000000000020000
00@006UJ00<000000029FP00REX00P00UF82000000L00:iR0P0000040032FP80000000<0085J0000
000000001`00hUX:003fFP0300000000oeX00?mJ00D00?mJ00<00000003bDP0000001`00oeX00`00
00000?mB003oDP0=003oDP0300000000oeX0000000@00?m:00@00000003oHP0000000?la0P000000
1@00of800000000`600000000=XP0080000000D00?mR00000000eTX00=I:00000004003VDP@00?9B
1000oeX200000004003oFP0000000000000000<00?mJ00<00000003oHP00of801@00of8200000080
0?mZ00<00000003oP`0000000P00ofX00`0000000?mc003oL`02003oLcH0oooo000l0?ooo`030000
0000aUX00<IJ00800<IJ1@000003002QDP<0000000<009UB0000000000000P0000030025BP030000
0000LD400751008000000P00GD42000000<00?mk1@0000000`00og<000000000000400000003003o
JP000000000000800>9R1@0000000`00XDX0000000000002000000030025BP00000006UJ008006UJ
1000REX4000000L00:iR1P00`UX00`000000085J00000002000000H00>9J00<00000003fFP00mUX0
1`00mUX9003oFP0300000000oeX00?mJ00H00?mJ3`00oe80100000000?mJ003oFP000004003oBP80
00000P00oc401P0000000?mB003oDP00oe800000003J8080000000<00<I:0000000000000P00eTX0
0`0000000>IB003VDP02003VDP@00?9B0P000002003oFP0400000000og<00000003oFP8000001000
oeX7003oHP8000000`00ofX2000000<00?mZ1000og<f0?ooo`00?@3oool0100000000<IJ00000000
0003002fDPl0000000D008E:0000000000000000001a@@05000000@00?mk00@00000003oL`00og<0
00000P00og<00`0000000?mZ003oJP02000000800?mR1@0000000`00`U8000000000000800000080
06UJ00<000000029FP00REX00P00REX4000000H00:iR1`00`UX00`000000085J00000002000000<0
0>9J0P0000000`00YEX00000003fFP07003fFQ800?mJ2@00oe800`0000000?mB003oDP04003oDP80
00001000odX01@0000000?mJ00000000oc40000000@00?mB00D00=XP00000000000000000036BP02
000000<00=I:1000iU84003bDP0400000000oeX00?mJ003oFP<0000000<00?mJ0000000000001000
oeX4003oHP0300000000of800?mR00<000000P00ofX2000000<00?mZ1000og<00`000000oooo0?oo
o`0c0?ooo`00?03oool0100000000<iJ003>FP00cUX5000000<00:E:200000040029@@0300000000
QD4008E10080000000<006di0000000000000`0000001@00og/00000003oP`0000000?mc01000000
00<00<9:0000000000001`0000001000LCT000000000000000050029FP<000001000[V82000000L0
0<9J0P000004003FFP0300000000YEX00:EJ00800:EJ00<00000003fFP00mUX01000mUX00`000000
0?mJ003oFP0@003oFPP00?mB00@00000003oFP00000000001@00oe800`0000000?m:003oBP02003o
BP0500000000oeX00000003o<@0000000`00oe8200000003002j@@000000000000800<I:00@00000
003FBP00eTX00=I:1000iU84003bDP8000000P00oeX3000000800?mJ00<00000003oFP00oeX00P00
oeX4003oHP80000000@00?mR00000000oh<000000`00ofX0100000000?mZ003oJP00ofX4003oL`03
0000003oool0oooo03<0oooo000l0?ooo`0500000000cUX00<iJ003>FP0000000P00_U86000000<0
09U10P000003002A@@X0000000<006di00000000>3400P0000000`00og/0000000000002003oL`05
00000000og<00?mc003oL`0000000`00ofX00`0000000?mR003oHP04000000800<9:00<00000002^
@@0000000P0000001000VCT0000000000000OC44000000D008UJ1@00WEX200000003001UFP000000
0<9J00D00<9J1`00eUX2000000<00:EJ00<00000003fFP00mUX00P00mUX00`0000000<iB00000008
003oFP0300000000oeX00?mJ00D00?mJ0P000006003oDP0400000000oeX00?mJ000000H00?mB1000
odX01@0000000?mJ00000000oc40000000<00?mB0P000002002j@@8000000P00aTX0100000000=I:
003FBP00eTX4003VDP@00?9B0P0000000`00oeX00?mB003oDP02000000L00?mJ1000of8010000000
0?n300000000of82000000L00?mZ1000og<00`000000oooo0?ooo`0c0?ooo`00?03oool200000003
003>FP000000oooo00@000000P00ZTX60000008009E12`0000000`00QD400000001a>@0400000005
003oN`000000000000000000og<02@0000000`00of80000000000002003^DP0300000000bTX00<Y:
008000000P00]T400`0000000:Di002U>@02000000040029<@00000005TY000000@008UJ1P00WEX2
00000003001UFP0000000<9J00@00<9J2000eUX01000YEX00000000000000004003VFP0500000000
LE800000003>DP0000001@00oeX4000000D00?mJ00@00000002nDP00000000001000oe8300000003
003oFP0000000?mB00D00?mB1000odX300000003003o<@0000000?mB00800?mB0P000002002j@@<0
00000P00aTX3003FBP@00>IB00@00000003bDP00lU800?9B0`000002003oDP8000001`00oeX01000
00000?mR003oHP00of8300000003003oHP000000000000L00?mZ00@00000003oL`00og<00000=P3o
ool003d0oooo00@00000003JFP00fUX000000P00aU8600000003002Q@@0000000000008009Ti0`00
0002002=>@L0000000D008Di0000000000000000001a>@02000000800?mk0P000002003oL`030000
0000ofX00?mZ00800?mZ0P0000001000ofX0000000000000oeX6000000800=I10`0000001000_T40
000000000000kVX300000003003RJP0000000000008000001@00WEX00`000000051B001@DP020000
00<00<9J0P000008003FFP0300000000iUX00>IJ00D00>IJ0P000002003>DP0500000000oeX00?mJ
003oFP0000000`00gU82000000<00?mJ0P0000001000_U800000003oBP000004003oDP0300000000
lU80000000H00?mB00@00000003oBP00odX00?m:0P00od400`0000000?la003o<@0200000003003o
DP0000000000008000000P00^T40100000000<I:0036BP00aTX4003FBP<00>IB00L00000003bDP00
lU800?9B00000000oh<0000000<00?mB00<00000003oFP00oeX01@00oeX2000000800?mR0`000002
003oHP0300000000ofX00?mZ00D00?mZ0P0000000`00og<000000?ooo`0e0?ooo`00?P3oool00`00
00000=YJ00000002000000040036DP0000000;9:002bBP8000000P00ZT4200000005002I>@000000
000000000000TCT04P0000000`00og/0000000000007000000<00?mZ2@0000000`00og<000000000
0002003fJP0400000000kVX00>iZ000000<00>9Z00@00=9R00000000000000001@00WEX2000000@0
0;9J00@00000001YFP00JEX000001`00eUX8003VFP@000001@00oeX0100000000=iB003NDP000005
003oDP<0000000<00?m:00000000oe801000oe800`0000000?mB003oDP04003oDP8000000P00odX3
003o@@<00?la00H00000003o@@00od400000002Z@@000004002j@@<00<I:1000eTX3003VDP800000
0P00lU800`0000000?n300000004003oDPL00?mJ0P000002003oHP8000001000of83003oJP090000
0000ofX00?mZ003oJP000000oooo00000000og<0000003D0oooo000n0?ooo`0300000000iUX00>IJ
008000000P00eU8500000006002Z@@000000000000000000XCT000000P00VCT900000003001i>@00
0000000000<0000000<008U10000000072T010000002003oL`X0000000<00?mc0000000000000P00
og<0100000000?mc003oL`000003003fJP<00>iZ0`00hVX00`0000000=9R003BHP02000000D009eJ
1P00/UX01000000006UJ001YFP000006003FFPT00>IJ00<00000003oFP00oeX01P00oeX00`000000
0=iB00000006003oDP0300000000odX0000000d00?mB00@00000003oFP00000000000`00od42003o
<@07002b<@0000000?m1003o@@0000000:Y100000004002j@@<00<I:1000eTX3003VDP80000000<0
0?9B003oDP00oe800P000004003oDP<00?mJ00@00000003oFP00oeX00?mJ0`000002003oHP030000
0000of800?mR00800?mR0`00ofX2000000800?mZ00<000000?ooo`0000000P00og<00`000000oooo
0?ooo`0b0?ooo`00?`3oool0100000000>IJ003VFP000003003FDP0600000000_TX00;i:002nBP00
00000;910P000002002^>A40000000<00?mk0000000000002P0000001000og<0000000000000og<2
000000800?mc00<00000003oL`00og<01000og<3003fJP0400000000kVX00>iZ000000800>9Z0P00
0002003BHP8000000`00WEX2000000D00;9J00<00000001YFP00JEX00P000004003FFP8000002000
iUX:003oFP0300000000oe800?mB00H00?mB00<00000003oDP00oe802`00oe80100000000?mJ003o
FP000004003o@@800?la00@00000003o@@00od4000000`00ZT44002j@@<00<I:1000eTX00`000000
0>IB003VDP03000000800?mB0P000004003oDP<00?mJ0P000002003oFP<000000P00of800`000000
0?mR003oHP02003oHP<00?mZ00L000000?ooo`0000000?mc0000003oool0000000800?mc=@3oool0
0400oooo1@0000000`00eU8000000000000400000003002b@@000000000000P0000000<009Ti0000
000000004@0000000`00og/0000000000002003oL`0300000000og<00?mc00L00?mc00@00000003o
L`00og<000000P00mVX200000003003^JP000000000000/0000000<003a100000000/UX01000/UX2
000000D00<IJ00@00000002ADP00TE8000001`00iUX:003oFQL00?mB00@00000003oFP00oeX00000
0`00od43000000800?m10P000003002Z@@@00;Y10`00aTX4003FBP0300000000iU800>IB00<00000
0`00oe800`0000000?mB003oDP02003oDP<00?mJ0P000002003oFP0300000000oh/0000000L00?mR
00H00000003oJP00ofX000000?ooo`000002003oL`0400000000og<00?mc003oLcD0oooo00120?oo
o`0400000000nUX00?YJ000000<00>IB1P0000000`00_T4000000000000400000004002^>@000000
0000000000<00;8i1`0000000`00oh/0000000000004000000<00?mk2@00og<00`0000000?mc003o
L`0200000003003oL`00000000000080000000<00?n30000000000000P0000001000eVX000000000
0000aV8200000004002jHP00000000000000008003a100<00000002bFP00/UX00`00/UX70036FP04
00000000TE80095B000000H00>IJ00<00000003oFP00oeX01`00oeXA003oDP0300000000oe800?mB
00800?mB00@00000003oFP00oeX000001000od400`0000000?mB003oDP02003o@@030000000000P0
0:Y100800:Y11000^T430036BP@00=I:0P0000001000iU800000000000000008003oDP<00?mJ0`00
0002003oHP8000001`00of8200000004003oJP000000oooo000000800?mc00@00000003oL`00og<0
0?mc=@3oool004<0oooo1@0000001@00iU8000000000000000000>Y:008000001000dT4700000003
003:>@000000000000@000000P00oh/2000000800?n;00<00000003oN`00og/01@00og/3003oL`05
00000000og<00?mc00000000og<00P0000000`00og<000000000000400000004003^JP0000000000
003RJP8000000P00eVX0100000000<IR0036HP00aV82002jHP<0000000<003a10000000000001000
/UX70036FP0300000000TE80095B008000001000iUX00`0000000;YB00000007003oFP0300000000
oe800?mB00h00?mB00<00000003bDP0000000P00oe82003oBP8000001000od401@0000000?mB003o
DP0000000?m10080000000@009Di002Z@@00ZT400:Y11000^T430036BP@00=I:0P0000001000iU80
0000003oR`000008003oDP0300000000oeX00?mJ00<000000`00of800`0000000?mR003oHP05003o
HP030000003oool00000008000001`00og<00`000000oooo0?ooo`0b0?ooo`00A03oool00`000000
0?mJ003oFP02003oFP0300000000oe800?mB00L000001000lTX7000000800?n;00<00000003oR`00
oh/01@00oh/5003oN`0300000000og/0000000800?mc0P0000001000og<0000000000000og<20000
0004003oL`0000000000003fL`8000000P00kVX0100000000>9Z003RJP00hVX3003FJP<00<IR00<0
0000002jHP00^V800P000000100073400000000lBP000002002bFP8000001`00aUX2000000D00=YJ
0`0000000`00^U800000003oFP04003oFP<000001P00oe82000000H00?mB00D00000003bDP00lU80
0?9B00000004003oBP0300000000od400?m100800?m100D00000003oDP0000000000003o<@020000
0004002E>@00ZT400:Y1002Z@@@00;Y10`00aTX0100000000=I:003FBP00eTX200000004003VDP00
00000000000000P00?mB0P0000001000oeX00000003oR`000007003oHP0400000000of800?mR0000
0080oooo00<00000003oJP0000001`00og<00`000000oooo0?ooo`0b0?ooo`00AP3oool700000003
003oFP000000000000@00?mB1`000002003oR`0300000000oh/00?n;00D00?n;0P0000000`00oh/0
0?mk003oN`02003oN`0300000000og/00?mk0080000000<00?mc00000000oh/00`000002003oL`04
00000000og<00?mc000000<00?Ic0`00kVX3003RJP0400000000eVX00=IZ000000800<IR00<00000
002jHP0000001@000002000lBP@000001`00aUX7003JFP8000000P00^U802@0000000?mJ003oFP00
oeX00000003:BP00000004a100000004003oDP80000000<00?m:00000000oe800`00oe801@000000
0=YB003JDP00lU80000000D00?m:1@00od4400000004003o<@0000000?n3002E>@<00:Y11000^T43
0036BP8000000P00eTX300000003003oBP000000000000P00?mB0P000002003oFP8000001`00of82
00000005003oHP000000oooo0?ooo`0000000P00ofX4003oL`0400000000og<00?mc000003@0oooo
00190?ooo`0300000000of800?mR00800?mR0`0000001@00oeX000000000000000000?n;00800000
00<00?n;0000000000001`00oh/200000003003oR`0000000?n300<000000P00og/400000003003o
R`0000000?mk0080000000<00?mc0000000000001@00og<3003fL`0400000000kVX00>iZ00000080
0>9Z00<00000003FJP00eVX01@0000001000[V80000000000000020200000003000lBP00000003a:
0080000000<0051B00000000aUX01@00aUX7003JFP@000000`00lU801`0000000<Y:003:BP00bTX0
0000001<@@0000000P00oe83000000800?m:00<00000003oDP00oe800P00oe80100000000=YB0000
00000005003oBP@00?m100<00000003oDP0000000`0000000`0000P00?mB002E>@03002Z@@@00;Y1
0`00aTX2000000800=I:0`0000000`00odX0000000000008003oDP<0000000<00?mJ000000000000
1`00of8010000000oooo00000000ofX2000000<00?mZ1000og<00`0000000?mc0000000e0?ooo`00
B`3oool700000003003oR`000000000000X00?n;0P000002003oR`H0000000L00?n;000000000000
0000003oR`0000000?mk008000000P00og/00`0000000?mc003oL`06003oL`0300000000mW<00?Ic
0080000000<00>iZ0000000000000`0000001000bVX0000000000000^V82000000800:iR00D00000
002MFP0000000000000P<@0500000003001@DP0000000<IJ00@00<IJ00<00000003JFP00fUX01@00
fUX00`0000000?9B003bDP04003bDP0300000000bTX00<Y:008000001000oe82000000800?m:00<0
0000003oDP00oe800P00oe800`0000000=YB00000006003oBP@00?m100@00000003oDP0000000000
0P00oc43002E>@@00:Y10`00^T430036BP0400000000oh<00000003FBP<000000P00odX00`000000
0?mB003oDP02003oDP0400000000oe800?mB003oDP<000000P00oeX01@0000000?mR003oHP00of80
000000<00?mR00<000000?ooo`0000000P00ofX0100000000?mZ003oJP00ofX4003oL`<00000=@3o
ool004d0oooo00<00000003oR`00oh/00P000007003oR`0300000000oh/00?n;008000000P00oh/3
00000003003oR`000000000000D00?n;00@00000003oN`00000000000P00og/0100000000?mk003o
N`00og/3003oL`0500000000og<00?mc00000000og<00P0000000`00mW<000000000000200000004
003oR`0000000=IZ000000800<YZ00@00000002jHP00^V800;YR0`00[V82002MFP07000080000000
000000000000?4X00000000lBP03001@DP800<IJ0`000007003JFPP00?9B00<00000003:BP000000
1P00oe83000000H00?mB00<00000003oBP00odX01@00odX3003o@@<00?mB00@00000003o<@00oc40
00001000UCT2002Z@@0500000000^T400;Y1002j@@0000000P00aTX300000004003FBP0000000000
000000<00?m:1000oe82000000800?mB00<00000003oR`0000000`00oeX3003oHP8000000P00of80
0`000000oooo00000006003oJP0700000000og<00?mc0000003oool00000003oL`02000003<0oooo
001>0?ooo`0300000000oh/00?n;00D00?n;1P0000001@00oh/000000000000000000?n;00800000
1`00oh/2000000X00?mk00D00000003oL`0000000000003oL`0500000004003^L`0000000000003R
L`8000000P00eVX3003:JP<00;YR00D00000002^HP00[V800000002MFP050000008003a:0P000002
001@DP8000000P00ME800`0000000=YJ003JFP04003JFPT00?9B00<00000003oDP00oe801P00oe80
0`0000000?mB003oDP05003oDPL00?m:00<00000003o@@00od401000oe83003o<@0300000000UCT0
09Di008009Di0P00ZT401@0000000;Y1002j@@00^T40000000800<I:0`0000000`00odX000000000
0004003oBP@00?mB0P000002003oDP8000001000oeX3003oHP8000000P00of82000000L00?mZ00H0
0000003oL`00og<000000?ooo`000002003oLc@0oooo001?0?ooo`@00?n;1P0000001@00oh/00000
003oP`0000000?n;00<000001P00oh/200000003003oR`000000000000D00?mk00<00000003oN`00
00000P00og/00`0000000?mc003oL`0500000005003fL`0000000000003^L`0000000`00hW<3003F
JP0300000000bVX0000000800;YR2@00000010008340000000000000?4X200000006001@DP000000
000000000000ME8000001P00fUX00`0000000?9B003bDP06003bDQ400?mB1P00odX0100000000?mB
000000000004003oDP800?la00<00000002Q>@00UCT00`00UCT3002Z@@<00;Y100L000000036BP00
aTX00000003oR`0000000?m:008000001000odX4003oDP<0000000<00?mB0000000000001000oeX3
003oHP030000003oool0000000800?mR00<00000003oJP00ofX01@00ofX200000003003oL`000000
000000<00?mc=03oool00500oooo00<00000003oR`00oh/00`0000001@00oh/00000003oP`000000
0?n;00<000001`00oh/00`0000000?n;00000004000000@00?mk00<00000003oN`00og/00P000000
0`00og/0000000000002003oN`0400000000og<00000000000<00?Ic0P00kW<3003RL`0500000000
eVX00=IZ00000000bVX01@0000001000VF80000000000000SEX20000000500008000000000000000
0000?4X00P000002001@DP8000000P00ME800`0000000=YJ003JFP02003JFP0300000000YE800000
00L00?9B4@00oe86003oBP0400000000oe800000000000@00?mB0P00oc400`0000000:4i002E>@03
002E>@<00:Y10`00^T42000000040036BP0000000000000000800?m:00<00000003oBP00odX00P00
odX4003oDP030000003oool0000000800?mB00<00000003oFP00oeX00P00oeX01P0000000?mR003o
HP000000oooo000000800?mR1000ofX01P0000000?mZ003oJP000000oooo000000800?mc00@00000
003oL`00og<00?mc=03oool00540oooo0P0000001@00oh/000000000000000000?n;00<000001`00
oh/00`0000000?n;003oR`06000000800?n;00<00000003oN`00og/01P0000000`00og/00000003o
N`02003oN`0300000000og<00?mc00<00?Ic00<00000003^L`0000000P00hW<500000005002jJP00
00000000002ZHP0000000`00VF82002=FP04001mFP0000000000000P<@80000000@003a:00000000
0000051B0P00FDX2001eDP0400000000ODX007e:001mBP@000001`00lU8A003oDPD00?m:0`000000
0`00oc400000003oDP02003oDP0500000000oc40000000000000XCT01000UCT3002Z@@<00;Y10P00
00001000aTX00000000000000002003oBP0300000000odX00?m:00800?m:1000oe800`000000oooo
00000003003oDP@00?mJ00H00000003oHP00of8000000?ooo`000002003oHP@00?mZ0P0000000`00
ofX0000000000006003oL`030000003oool0oooo0380oooo001C0?ooo`0300000000oh/00?n;0080
00001`00oh/200000003003oR`000000000000@000000P00oh/2000000800?n;00<00000003oN`00
og/00P0000000`00og/0000000000002003oN`0400000000og/00?mk003oN`<00?mc00<00000003f
L`0000001`0000001@00bVX00000002jJP00^VX0000000800:YR0`00VF801000000008eJ00000000
OEX400000004000lBP00@4X0041:001@DP<005U:0P000003001mBP<0000000<00:EB00000000lU80
1@00lU800`0000000?mB003oDP0=003oDP8000000`00odX00`0000000?m:00000002003o<@090000
0000oe800?mB003oDP0000000?la003o:@0000000:4i00@009Di0`00ZT400`0000000;Y1002j@@02
000000040036BP0000000?n;000000L00?m:00L00000003oDP00oe800?mB0000003oool0000000<0
0?mB1000oeX200000003003oHP000000000000<00?mR1000ofX01@000000oooo00000000ofX00000
00H00?mc00<000000?ooo`3oool0<P3oool005@0oooo00<00000003oR`00oh/01@00oh/200000003
003oR`0000000?n;00@000000P00oh/2000000@00?n;00<00000003oR`0000000P00og/200000080
0?mk00<00000003oN`00og/00`00og/00`0000000?mc003oL`0300000005003oR`00000000000000
0000eW<00P000002003:JP<00;YZ0P00ZV801@00000009UR002IHP00000008eJ00@0000000<0020a
000T>@00?4X00P00@4X20000008005U:00<00000001]600000000`00ODX300000003002UDP000000
0?9B00800?9B10000006003oDP8000001@00oe800`0000000=YB00000005003oBP0400000000oc40
0000000000800?mB0`0000000`00obT00:4i002Q>@02002E>@03003oP`00UCT00:Y100800:Y100<0
0000002j@@00^T400P0000001000aTX00000003oR`000007003oBP0700000000oe800?mB003oDP00
0000oooo00000003003oDP<00?mJ00<000000?ooo`0000000P00of801@0000000?mR003oHP00of80
000000800?mZ00<000000?ooo`0000000P00ofX4003oL`0300000000og<0000003D0oooo001F0?oo
o`@00?n;00@00000003oR`0000000?n;1@000002003oR`0300000000oh/00?n;00800?n;0P000000
1000oh/0000000000000000:003oN`0300000000og/0000000<0000000D00?n;0000000000000000
003RL`02000000800=Ic0`00bVX0100000000;YZ00000000ZV8500000003001iFP000000000000D0
000000<0041:0000000000000`00FDX2000000<007e:0`000002002UDP800;9:00<00000002bBP00
/TX00P000004003oDP80000000<00>i:00000000oe801000oe85000000@00?m:0P000002003oBP05
00000000C340000000000000obT00P00XCT2002E>@03003oP`00UCT00:Y100800:Y100<00000002j
@@00^T400`0000000`00nT40000000000007003oBP8000000`00oe82000000<00?mB0`00oeX00`00
0000oooo00000006003oHP80000000@00?mZ0000003oool000000P00ofX4003oL`0300000000og<0
000003D0oooo001G0?ooo`0300000000oh/00?n;0080000000@00?n;00000000000000000P00oh/2
000000L00?n;1P000006003oN`80000000<00?mk0000000000000`0000001@00nW/0000000000000
kW<0000000<00>9c0P00eW<01@0000000<YZ003:JP0000000;YZ00D0000000@008UR00000000NEX0
07UJ0P00JEX200000004000T>@00000000000010BP8000000P00FDX00`000000074H00000002001m
BP<008U:0P00YE800`0000000;9:002bBP02002bBP<000000P00oe800`0000000=Y:003^BP02003^
BP0600000000oe800?mB003oDP0000000<9:10000004003oBP8000000P00odX00`00000004`a0000
0002003o:@800:4i0P00UCT00`00oh/009Di002Z@@02002Z@@80000000D00;Y100000000oh/00000
003j@@02000000L00?m:0P000004003oDP0500000000oe800?mB003oDP0000000P00oeX00`000000
oooo00000006003oHP050000003oool00000003oJP0000000`00ofX01@0000000?mc003oL`000000
oooo00800000=@3oool005P0oooo0P0000000`00oh/0000000000002003oR`8000001`00oh/60000
00<00?n;1000og/00`0000000?mk0000000500000003003oN`000000000000800?Yk0P00kW<3003R
L`0300000000eW<0000000@0000000D00:YZ00000000000009UR000000020029HP8007UJ00<00000
001YFP00JEX0100000000`00@4X0000000000002001IBP<000000P00ODX40029BP8000001000/TX2
00000003000`>@0000000=Y:00800=Y:00<00000003^BP00kTX00P00kTX4003o@@80000000<00?m1
00000000odX00`00odX0100000000?m:003oBP00odX300000004003o:@0031P00:4i002Q>@800000
0P00UCT00`0000000:Y1002Z@@0200000004002j@@0000000000000000800?Y100<00000003oBP00
odX01@00odX00`000000oooo00000007003oDP8000000P00oeX2000000<00?mR00H00000003oHP00
of8000000?ooo`000005003oJP0300000000og<00?mc008000000P00og<00`000000oooo0?ooo`0b
0?ooo`00FP3oool00`0000000?n;003oR`02000000H00?n;0P000002003oR`<0000000<00?n;0000
000000000`00oh/00`0000000?mk003oN`0600000003003oN`000000000000800?mk0`00nW/2003^
L`0300000000hW<0000000@0000000<00;YZ0000000000000P00ZVX2002IHP8008UR00<00000001i
FP00000010000000100093T0000000000000@4X200000004001IBP00HDX0065:001QBP8007e:1000
RDX3000000@00;9:0P0000000`00`TX00=Y:003JBP02000000@00>i:1000od40100000000?m1003o
@@000009003oBP0400000000obT00?lY000000800:4i00D00000002E>@00UCT009Di00000002002Z
@@80000000@00;Y10000003oool000000`00nT47003oBP030000003oool0000000L00?mB00<00000
0?ooo`0000000P00oeX01@0000000?mR003oHP00of80000000800?mR0P000006003oJP80000000<0
0?mc0000000000000P00og<e0?ooo`00F`3oool00`0000000?n;003oR`05003oR`80000000@00?n;
00000000000000000P00oh/2000000@00?n;100000001000og/0000000000000og/2000000H00?mk
00<00000003jN`0000000P00kW<400000003003:L`000000000000800;YZ0P00ZVX00`00000009UR
000000020029HP@0000000<005EB0000800093T00P00:3T01000@4X004A10014@@00FDX4001QBP80
00000`00RDX3000000@00;9:00L000000032BP00`TX00<9:00000000HD40000000@00>i:1000od40
1000`TX00000003o@@000009003oBP0300000000obT0000000<00:4i00D00000002E>@00UCT009Di
00000002002Z@@80000000@00;Y10000003oool000000`00nT43003oBP0700000000odX00?m:003o
BP000000oooo00000007003oDP030000003oool0000000800?mJ1000of82000000800?mR00@00000
003oJP00ofX000000P00ofX01@000000oooo00000000og<0000000800?mc00<000000?ooo`3oool0
<`3oool005d0oooo0`00oh/200000003003oR`000000oooo0080000000@00?n;0000000000000000
1000oh/00`0000000?n;00000003000000800?mk0P000006003oN`0500000000og/0000000000000
nW/00P0000000`00hW<00000003FL`02000000800<Yc0P00^VX00`0000000:YZ0000000600000003
001QFP00000005EB00<0000000@002Pi0010BP00A44004A10P000003001QBP8000001000RDX20000
00@00;9:1000`TX0100000000651001Q@@000003003^BP@00?m100@00<9:00000000000000002@00
odX2003o:@0500000000XCT00:4i002Q>@0000000`00UCT01@0000000:Y1002Z@@000000oooo0080
000000<0oooo00000000nT400P00nT43003oBP0700000000odX00?m:003oBP000000oooo00000007
003oDP030000003oool0000000800?mJ0`00of800`000000oooo00000002003oHP<00?mZ00<00000
003oJP00ofX00P000005003oL`030000003oool0oooo03<0oooo001N0?ooo`80000000<00?n;0000
000000001@000007003oR`L000001P00og/00`0000000?mk003oN`0500000005003^N`0000000>9c
003RL`0000000P00eW<2003:L`0300000000^VX0000000@0000000@0085R00000000LEX000000P00
HEX01@00EE80000000000000000002Pi0080000000<004A10000000000000`00HDX2000000@008U:
0`000003002bBP@00<9:00@00000001Q@@00HD4000000`00kTX4003o@@040032BP0000000>I:003V
BPT00?m:0P00obT01@0000000:4i002Q>@00XCT0000000<009Di00L00000002Z@@00ZT4000000?oo
o`0000000?91008000000`00nT43003oBP8000000P00odX2000000@00?mB00@00000003oDP00oe80
0?mB0P000003003oFP0600000000of800?mR0000003oool000000P00of82003oJP030000003oool0
000000800?mZ00H00000003oL`00og<00000003oL`00000f0?ooo`00H03oool5000000P00?n;00<0
0000003oR`00oh/00`000003003oR`@00?mk00<00000003oN`0000001@0000001@00nW/000000000
0000kW/0000000800>9c0P00eW<00`0000000<Yc0000000400000004002EJP000000085R0021HP80
075J00@00000001QFP00000005EB1@0000020014@@8000000`00HDX2000000<008U:0`000003002b
BP@00<9:00P00000001Q@@00HD400000003^BP0000000>i:000000<00?m100<00<9:003VBP00iTX0
0P00iTX2003oBP0300000000odX00?m:00<00?m:00<00000003o:@0000000`00XCT20000008009Di
0P0000001@00ZT4000000?ooo`0000000?91008000000`00nT43003oBP8000000`00odX00`000000
0?mB003oDP02003oDP8000000`00oe801@0000000?mJ003oFP00oeX0000000800?mR0P000003003o
HP0500000000ofX000000?ooo`0000000P00ofX2003oL`80000000<00?mc0000003oool0=@3oool0
0680oooo00@00000003oR`00000000001000oh/2000000800?n;0P000002003oR`8000000`00oh/3
003oN`H0000000<00?mk0000000000000P00nW/2003^N`0300000000hW<0000000800=Ic10000000
1000ZVX00000002EJP00UFX20021HP0400000000LEX00000001QFPD0000000@002Pi00000000A440
04A10P000003001QBP8000000`00RDX3002EBP800;9:00<000000032BP00`TX00`00`TX200000003
003B@@00kTX00>i:008000000`00od400`00`TX00>I:003VBP02003VBP<000001@00odX3000000<0
0:4i0P000002002E>@80000000@00:Y10000003oool000000P00lT40100000000?Y1003j@@00nT43
003oBP030000003oool0000000800?m:00<00000003oDP00oe800P00oe800`000000oooo00000002
003oDP@00?mJ0P000002003oHP0600000000of800?mR003oHP0000000?mZ0P000003003oJP800?mc
0P0000000`00og<000000?ooo`0e0?ooo`00H`3oool00`0000000?n;003oR`02003oR`80000000@0
0?n;00000000000000000P00oh/2000000@00?n;0`000002003oN`<0000000<00?mk000000000000
0P00og/3003jN`<0000000H00>9c0000000000000<Yc00000000^W<200000004002ZJP00UFX009EZ
002EJPD0000000D0051B00000000B580000H00008003000000040014@@000000094H00000080065:
0P0000030029BP@009E:00<00;9:00000000`TX01000`TX2000000800=9100<00>i:000000000000
0`00od400`00`TX00>I:003VBP02003VBP0300000000oc40000000@00?m:00@00000003o:@000000
00000`00XCT20000008009Di0P0000001000ZT4000000?ooo`000002003b@@0400000000nT400?Y1
003j@@<00?m:00<000000?ooo`0000000`00odX4003oDP030000003oool0000000800?mB0`00oeX0
0`000000oooo00000005003oHP050000003oool00000003oHP0000000P00ofX01`0000000?mc0000
003oool00000003oL`000000=P3oool006D0oooo1000oh/7000000@00?n;0P0000000`00oh/00000
0000000200000003003oN`000000000000H00?mk00<00000003jN`0000000`0000001@00fW<00000
00000000bW<0000000800;Yc00@00000002ZJP00000009EZ1P0000001`00D58004QB0018DP000000
000P000X>@0000000P00A44200000080065:0P00JDX30029BP@009E:0`0000040032BP0500000000
dT400=91003B@@0000000P00YD400`0000000?m1003o@@02000000@00>I:0`000002003oBP800000
00<00?lY00000000/ST00`00XCT20000008009Di0P0000001000ZT4000000?ooo`000003003b@@<0
0?Y10`00odX00`000000oooo00000003003oBP@00?mB00<000000?ooo`0000000P00oe83003oFP03
0000003oool0000000D00?mR0P000002003oHP<00?mZ0P0000001000ofX00000003oL`00og<g0?oo
o`00IP3oool2000000800?n;0`000008003oR`<000000P00oh/01@0000000?mk003oN`00og/00000
00<00?mk00D00000003oN`0000000000003jN`04000000800=Yc0`00bW<300000006002ZJP000000
07eR00000000JF8000000P00FEX00`00D58000000018DP0300000003000/>@00A44004A1008004Q1
0P00HDX3001YBP030029BP000000000000<009E:0`0000040032BP@00=9100@00000002U@@00YD40
00000P00od42000000@00>I:0`000002003oBP80000000<00?lY00000000/ST00`00XCT200000008
002E>@3oool0000000000000ZT4000000?ooo`000003003b@@<00?Y100H00000003oBP00odX00000
0?ooo`000003003oBP@00?mB0P000003003oDP0300000000oeX00?mJ008000000`00of8010000000
0?mR000000000002003oHP0300000000ofX00?mZ008000000P00ofX2003oL`030000003oool0oooo
03D0oooo001X0?ooo`8000000P00oh/2000000@00?n;200000000`00oh/00000003oN`05003oN`80
000000@00?mk0000000000000?9k0P0000001P00iW/00=Yc003JL`00fW<00000003:L`@0000000D0
095Z00000000OF800000001YHP02001IFPL0000000<002`i0014@@00B4400P00B4401000HDX006U:
001YBP00JDX3000000<009E:00<000000029:@0000001000`TX4003B@@80000000<00:E100000000
od400`000004003VBP8000000P00od401P000000050a00000000obT0010H002b>@<00:4i0P000002
002E>@80000000@00:Y10000003oool000000`00lT43003j@@0600000000odX00?m:0000003oool0
00000`00odX4003oDP8000000`00oe82000000800?mJ00@00000003oHP00of800?mR0P0000001000
oeX00?mR003oHP00of8200000003003oHP0000000?mZ00800?mZ00<00?mc0000003oool0=`3oool0
06X0oooo0P000004003oR`80000000<00?n;0000000000000P000006003oR`<00?mk00<00000003o
N`00og/00P0000000`00nW/0000000000002003bN`800>Ik00<00000003JL`0000000`0000001000
YFX0000000000000TFX2001mHP0300000000JF80000000<0000000D003a:0000000000000000000/
>@020000008004Q10P000002001YBP<000001000UDX3000000<00<9:1000dT4200000006002U@@00
00000>i100000000kS4000001000iTX2000000800?m100@00000001@<@00000000000P00/ST3002Q
>@8000000P00UCT010000000oooo00000000jST2000000<00?910`00nT42000000800?m:0P000003
003oBP0300000000oe800?mB00800?mB00P00000003oDP00oe800?mB0000003oool00000003oFP<0
0?mR00@000000?ooo`0000000?mJ0P00of82000000800?mR0`00ofX2000003T0oooo001]0?ooo`@0
0?n;0`000002003oR`8000001000oh/300000005003oN`000000000000000000og/00P000002003j
N`<00?9k20000002002UJP80095Z1P0000001P00@4X000000000000001P00000000/>@8000000P00
B4420000008006U:0`000004002EBP<000000`00`TX5003B@@8000000P00kT400`0000000>ha0000
0004003VBP0800000000od400?m1003o@@000000050a00000000obT2002b>@<00:4i0P000002002E
>@040000003oool00000003Z>@8000000`00lT43003j@@8000000`00odX0100000000?m:003oBP00
odX2000000H00?mB00D000000?ooo`3oool00000003oFP03003oHP8000000P00oeX0100000000?mR
000000000002003oHP800?mZ0`00000i0?ooo`00KP3oool8000000D00?n;2@000003003oN`800?Yk
00<00000003bN`0000000`0000001000bW<0000000000000^W<2002UJP0300000000TFX0000000@0
000000@004QB00000000@4X003a:1@0000020018@@8000000P00JDX0100000000:4Y002M:@000003
002EBP0300000000YD400:E100<00<9:1@00dT42000000800>i100<00000003^<@0000001000iTX4
003o@@0400000000obT00000003o:@800;8i0`00XCT20000008009Di00@000000?ooo`0000000>Xi
0P000003003b@@<00?Y100<000000?ooo`0000001P00odX00`000000oooo00000005003oDP030000
003oool0000000800?mJ00H00000003oHP00oe800?mB00000000oeX200000006003oDP0000000?mR
003oHP0000000?mZ0P0000000`00of80oooo0?ooo`0h0?ooo`00L`3oool00`0000000?n;003oR`06
003oR`<0000000@00?n;00000000og/00?mk0P000003003oN`P000000P00bW<2002jL`0300000000
YFX000000080000000<005eJ00000000D5800P00B58500000003000/>@0000000000008004Q10P00
0002001YBP0300000000WBT0000000<009E:0`00YD420032BP0300000000dT400=9100<00=9100P0
0000003^@@00kT400>i100000000kS400000003o>@<00>I:1000od42000000800?lY0P00/ST3002Q
>@0800000000kST00000002E>@000000oooo00000000jST2000000<00?910`00nT400`000000oooo
00000006003oBP030000003oool0000000D00?mB0`000002003oFP8000000P00oe82003oFP800000
00<00?mB003oHP00of800P0000001000oeX00000003oHP00000j0?ooo`00M03oool00`0000000?n;
003oR`02003oR`T000001000og/00`0000000?mk00000006000000800=Yk0P00bW<00`0000000;Yc
0000000400000003001MFP00D580051B00D0000000@000@Y000/>@00000000000P00B44200000080
06U:0`000003002EBP<00:E100<00<9:0000000000001@00dT44003^@@<000001000iTX4003o@@80
000000@00?lY000@6000/ST00;8i0`00XCT01`0000000>hi00000000UCT000000?ooo`0000000P00
jST0100000000?91003b@@00lT43003j@@030000003oool0000000D00?m:00@000000?ooo`3oool0
00000`00oe80100000000?mB003oDP00oe82003oFP060000003oool00000003oDP0000000?mJ0P00
00000`00oe800000003oHP0200000004003oFP00of800?mR000003/0oooo001g0?ooo`80000000<0
0?n;0000000000000P000005003oR`<00?mk0P0000001000og/0000000000000mW/200000006003Z
N`00fW/00=Yk003JN`0000000<Yc100000000`00SFX007ER001eHP07000000040004:@00;3T0030i
000`>@8004Q10P000002001YBP0300000000MD4007E100<009E:0`00YD401000000001@Y00000000
0004003B@@D00>i10P000004003VBP@00?m100@00000003o:@000000010H0P00/ST3002Q>@070000
0000kST00000002E>@000000oooo00000002003Z>@0400000000lT400?91003b@@<00?Y100<00000
0?ooo`0000001@00odX010000000oooo0?ooo`000003003oDP8000000P00oe82003oFP8000000P00
oe8200000003003o@@00oe800?mB00<0000000@00?mJ00000000of800000?03oool007T0oooo0`00
00000`00oh/0000000000005003oR`80000000@00?mk0000000000000?mk0P000002003fN`800>Yk
00D00000003JN`00fW/00000002jL`0200000003002UJP00SFX008eZ00D0000000<003A100000000
00000`0000000`00<3T004Q10018@@02001<@@8006U:0`00MD43002EBP<00:E100@00000000D:@00
000000001000dT45003^@@0600000000aT400>I:003VBP0000000>I:1000od43003o:@0300000000
/ST00;8i00<00:4i00L00000003^>@00000009Di0000003oool0000000<00>Xi0`00lT43003j@@03
0000003oool0000000D00?m:00<000000?ooo`0000001000oe82000000800?mB00D00000003oFP00
od400000003oDP0200000003003o@@0000000?mB00<0000000@00?mJ0000000000000000?@3oool0
07`0oooo0P000004003oR`H0000000<00?mk0000000000000P00og/2003fN`0500000000jW/00000
00000000dW<00P0000000`00^W<00:EZ002UJP0400000004001<BP0000000000000d@@@0000000<0
030i0018@@00B4400P00C442001YBP@007E100<009E:00000000YD400`00YD43000000@00=911@00
kT40100000000<I10036@@00iTX2000000@00?m10`00obT00`0000000;8i002b>@03002Q>@070000
0000kST00000002E>@000000oooo00000003003Z>@<00?9100<00000003j@@00nT400P000004003o
BP0500000000odX000000?ooo`0000000`00oe800`000000oooo00000002003oDP80000000D00?m1
003oDP00oe800000003o@@0200000003003o>@00000000000080000000<00?mB0?ooo`3oool0?@3o
ool00840oooo0P0000000`00oh/0000000000002000000H00?mk00D00000003fN`0000000000003R
N`0200000005003BL`00^W<00;Yc00000000YFX0100000000`00C4X004110000000400000004000`
>@00000000000000008004a100<006U:001e@@00MD400P00MD42000000@00:E100<00000000D:@00
00001000dT45003^@@0300000000aT400<I100<000001000od42003o:@040000400000000;8i002b
>@<00:4i00L00000003^>@00000009Di0000003oool0000000<00>Xi0`00lT400`0000000?Y1003j
@@02000000@00?m:00<00000003oBP00odX00P000003003oDP8000000P00oe8200000005003o@@00
00000000003o<@00od400`0000000`00odX0000000000002003oDP030000003oool0oooo03d0oooo
00230?ooo`<000000P00oh/00`0000000?mk003oN`02003oN`0500000000og/0000000000000kW/0
0P0000000`00hW/00=9c003BL`0600000007001YFP00C4X004a:00000000=44000000004:@050000
008004a10P000003001e@@0300000000XBT0000000<00:E10`000004003B@@D00>i100<00?li0036
@@00aT400`000004003o@@<00?lY00<00000002b>@00/ST00`00XCT01`0000000>hi00000000UCT0
00000?ooo`0000000`00jST3003b@@80000000<00?Y10000000000001000odX2000000800?m:1000
oe82000000800?mB0P0000000`00od4000000000000500000005003f>@0000000000003oDP000000
@03oool008H0oooo0P000002003oR`<00?mk0`0000001000nW/0000000000000kW/2003RN`H00000
00D008ER001YFP0000000000001<BP0500000003000`>@0000000000008004a10P000003001e@@03
00000000XBT0000000<00:E10`000003003B@@0300000000kT400>i100<00>i100H00?li0036@@00
aT400000003o<@000004003o@@800?lY0P000002002b>@<00:4i00@00000003^>@00000009Di0P00
0004003Z>@<00?910P0000000`00nT400?m100000004003oBP8000000P00odX4003oDP03003o@@00
oe800?mB0080000000@00?m10000000000000?la0`0000000`00mST00000003o@@0300000440oooo
002;0?ooo`L0000000<00?Yk003^N`00kW/01P000002002UJPT0000000<0030i0000000000000P00
C442000000<007E100<00000002Q:@0000001000YD42000000800=910P000005003^@@04003o>@00
aT400<I1000000800?la00@00000003o@@00od400?m10P00obT0100000000;8i002b>@00/ST4002Q
>@80000000<009Di0000000000001000jST3003b@@030000003oool0000000800?m11000odX20000
00800?m:0`00oe82003o@@0300000000oe800?la00800?m11@0000001000mST00000000000000014
0?ooo`00SP3oool0100000000?mk003oN`00og/2003jN`0300000000kW/0000000@000000P00`W<3
00000006001I@@0000000000000H:@00000000PY0P00<3T200000003001<@@000000000000@007E1
0P000004002U@@0400000000]T400;I1003B@@8000001@00kT401`00ocT00<I10036@@0000000?la
002=>@0000000P00od40100000000?lY000000000003002b>@@00:4i0P0000000`00jST000000000
0004003Z>@<00?9100<000000?ooo`0000000P00od43003oBP030000003oool0000000800?m:0`00
0002003o@@80000000<00?la0000000000001P0000000`00od400000000000140?ooo`00S`3oool0
100000000?mk003oN`00og/400000003003^N`000000000000800=ik00<000000032L`0000000`00
00001000A3T003@a0000000022T2000`>@8000000P00C442000000<007E100<00000002Q:@000000
0`00YD43002f@@0300000000ECT0000000D00>i100P00?li0036@@00aT400<I100000000oc400000
003o@@D000000`00/ST4002Q>@80000000<00>Xi0000000000001000jST3003b@@030000003oool0
000000800?m10`00odX2000000<00?m:00<000000?ooo`0000000P00od4200000003003o<@000000
000000L00000AP3oool00940oooo0`00og/5000000800>ik00<00000003NN`0000000`000002001Y
BP<000000P00<3T01000=3T00000001<@@00C442000000<007E10`000003002U@@<00;I100<00000
001E>@0000001@00kT402000ocT00<I10036@@00aT400000003o<@0000000?m11@000003002b>@@0
0:4i0P000002003Z>@0300000000jST00>Xi00800>Xi0`00lT400`000000oooo00000002003o@@<0
0?m:0P000003003oBP8000000P00od4200000003003o<@000000000000@0000000<00>i10000003o
ool0A`3oool00980oooo1P000003003oN`<0000000@00=Yc0000000000000;9Z1@0000000`00<3T0
03@i000d>@02001<@@8000000`00MD400`00000008E10025@@03002U@@<00;I100@00000001E>@00
PD4000001000kT401000ocT00<I10036@@00aT4200000003003b@@00od40000000@000000`00/ST0
1000XCT00000002Q>@00XCT2000000800>Xi00<00000003Z>@00jST00P00jST3003b@@030000003o
ool0000000800?m10`00odX2000000800?m:00<000000?ooo`0000000P00od4600000003003^@@00
0000000004X0oooo002E0?ooo`0400000000oh<00?n3003oP`<00?mk10000002003JL`L0000000D0
03@i001<@@00C440051100000003001e@@<008E10`00YD43002f@@0400000000ECT005Di000000@0
0>i100@00?li0036@@00aT400<I10P000002003b@@D000000`00/ST0100000000:4i002Q>@00XCT2
000000800>Xi00<00000003Z>@00jST00P00jST3003b@@8000000`00od400`0000000?m:003oBP02
003o@@800?m:0P000003003o@@0300000000oc40000000@00000C03oool009H0oooo00@00000003o
P`00oh<00?n31P000002003oN`L0000000<003@i001<@@00C4400P00D443001e@@<008E10`00YD43
002f@@0400000000ECT005Di000000800>i10`0000030036@@0400000000lT400?91003b@@D00000
0`00/ST0100000000:4i002Q>@00XCT2000000800>Xi00<00000003Z>@00jST00P00jST3003b@@80
00000`00od4200000003003oBP00od400?m100800?m:0P000003003o@@<00000D03oool009T0oooo
1P000002003oP`D0000000H000PY00000000000003@i00000000C442001@@@<007E10`00QD400`00
YD40000000000004002f@@0300000000ECT0000000<00>i100<00000003o>@00aT400P00aT43003b
@@@0000000<00?la00000000/ST00P00/ST0100000000:4i002Q>@00XCT2000000L00>Xi00<00000
003b@@00lT400P000003003o@@<000000P00od42003oBP05003o<@00od400?m1003o@@00obT00P00
001A0?ooo`00V`3oool2000000@00?n330000002001@@@8007E10`00QD400`00000009Da00000004
002f@@80000000<00<i1003^@@00kT400P000002003o>@800<I10`00lT43000000800?la00D00000
002b>@00/ST00;8i00000003002Q>@8000001`00jST00`0000000?91003b@@02000000<00?m10`00
0002003o@@0300000000odX00?la00@00000D`3oool009d0oooo0P000003003oP`8000000P00oh<5
000000040036800000000511001@@@8000000`00QD400`00000009Da00000004002f@@8000000P00
cT400`00kT40000000000002003o>@800<I10`00lT43000000800?la00D00000002b>@00/ST00;8i
00000003002Q>@8000001`00jST01@0000000?91003b@@00ocT0000000<00?m10`000002003o@@80
000000D00?la0000000000000?lY0000001C0?ooo`00X03oool3003oP`D0000000D000`Y00000000
00000<HP00000002001@@@8000000`00QD400`00000009Da00000004002f@@0700000000cT400<i1
003>@@0000000:E100000002003o>@800<I10P00lT40100000000?91000000000002003o<@040000
0000/ST00;8i002b>@8000000P00XCT2000000L00>Xi00<00000003b@@00ocT00P00ocT3003o@@<0
00000P00od4200000004003o<@0000000000003o:E@0oooo002Q0?ooo`<000000`00oh/010000000
00`Y000<:@00=3T20000008005110P0000030025@@<000001000]T44003>@@0300000000YD400000
00800?li0P00aT42003b@@0500000000lT40000000000000oc400P000003002b>@8000000P00XCT2
000000L00>Xi0P000003003o>@<00?m10P000003003o@@@0000000<00?lY0?ooo`3oool0D`3oool0
0:@0oooo0P0000002@00oh/00000000<:@0032T003@i00000000aR000000001@@@02000000<008E1
00@00000002E<@00UC4000000`00]T44003>@@0300000000YD40000000800?li0P00aT42003b@@05
00000000lT40000000000000oc400P000003002b>@8000000P00XCT2000000L00>Xi0P000003003o
>@<00?m10P000002003o@@80000000@00?la00000000obT00000E@3oool00:L0oooo0P0000001@00
32T003@i00000000aR0000000080051100<000000025@@00QD400P00QD400`00000009Da00000003
002f@@@00<i100<00000002U@@0000000P00ocT01`00aT400000003b@@00lT400000003b@@000000
0P00oc400`0000000<8i002b>@02002b>@8000000P00XCT2000000L00>Xi0P000003003o>@<00?m1
0P000002003o@@80000000<00?la003N60000000EP3oool00:L0oooo0P0000000`0032T003@i000h
>@020000008005110P0000030025@@0300000000UC40000000<00;I11000cT40100000000:E10000
0000ocT3000000@00?910P0000000`00oc4000000032>@03002b>@8000000P00XCT2000000L00>Xi
0P000003003o>@<00?m100D00000003o@@00od400?m100000002003o<@03003N60000000oooo05D0
oooo002X0?ooo`030000000032T00000008003Pi00<00000001@@@00D4400P0000030025@@<00000
0`00]T44003>@@0700000000YD400000003o>@0000000>h@00000004003b@@05003o<@0000000?la
00000000`ST00`00/ST2000000800:4i0P000007003Z>@8000000`00ocT3003o@@05003o>@00od40
0?m1003o@@00ob000`00001G0?ooo`00Z03oool01000000000`Y000000000002000h>@8005110P00
00030025@@0300000000UD4009E100<00;I11@00cT4200000004003V>@0000000>h@000000@00?91
00D00?la00000000oc40000@0032>@03002b>@8000000P00XCT2000000L00>Xi0P000003003o>@04
00000000od400?li003o>@<00?m100<00?lP000000000000F03oool00:P0oooo00@0000H000<:@00
000000000P00>3T2001@@@03001Q@@00000008E1008008E10`00UD43002f@@D00<i10P0000001000
iST00000003^40000004003b@@05003o<@000000050a00004000`ST00`00/ST2000000800:4i0P00
0007003Z>@8000000`00ocT0100000000?m1003o>@00ocT2003o@@0300000000ob00000005T0oooo
002Y0?ooo`8000`Y00<00000000h>@00>3T00P00D442001Q@@<008E11000UD42002f@@0300000000
cT40000000800<i100H00000003V>@00iST00000003^40000004003b@@05003o<@000000050a0000
4000`ST00`00/ST2000000800:4i0P000007003Z>@8000000`00ocT2000000800?li1@00001I0?oo
o`00Z@3oool00`00000000`Y00000002000h>@8005110P00HD430025@@@009E100<00;I100000000
00001000cT401@0000000>Hi003V>@0000000>h@008000000`00lT43003o<@0300004000`ST00;8i
00800;8i0P000002002Q>@8000001`00jST2000000<00?li0P000002003o>@D00000F@3oool00:T0
oooo100000000`00>3T00000001@@@02001Q@@<008E11000UD43000000@00<i100<00000003V>@00
iST010000003003b@@<00?la00<0000@0032>@00/ST00P00/ST2000000800:4i0P000007003Z>@80
00000`00ocT2000000800?li1000001J0?ooo`00Z@3oool400000004000h>@000000000000000080
06510P00QD44002E@@<000000`00cT40100000000>Hi003V>@00iST4000000<00?910`00oc400`00
01000<8i002b>@02002b>@0400000000HA000000002Q>@8000001`00jST2000000<00?li0P000002
003o>@80000000<00?lP0000003oool0F@3oool00:T0oooo0P0000000`0042T00000000h>@030000
008006510P00QD44002E@@0300000000;340000000@00<i100@00000003V>@00iST00>Hi0`000003
003b@@05003o<@0001P00?la00000000`ST00`00/ST010000000064@00000000XCT2000000L00>Xi
0P000002003o>@030000003oool0000000800?li0P0000000`00ob00oooo0?ooo`1I0?ooo`00ZP3o
ool010000000010Y00000000>3T30000008006510`000003002E@@<000001000cT44003V>@030000
0000ocT0000000<00?9100D00?la00006000000000000032>@03002b>@0400000000HA000000002Q
>@8000000`00jST01P0000000>Xi003Z>@00jST00?li000000800?li0`000002003o>@<00000F`3o
ool00:X0oooo00<00000000@:@0042T00P00>3T200000080065100<00000002n<@0000000`00UD43
000000@00<i11000iST200000006003>>@00lT400000003b@@0000000?la0P0000001000`ST00;8i
002b>@00/ST300000003002Q>@00lST0000000<00>Xi00@00000003Z>@00jST00>Xi1000ocT00`00
000000`@00000002003o>@800000G03oool00:X0oooo0P0000000`0042T003Pi000h>@0200000080
065100<00000002n<@0000000`00UD43000000@00<i11000iST00`0000000<hi003>>@02003b@@80
000000@00?la00000000`ST00<8i0`00/ST300000003002Q>@00lST0000000<00>Xi0P000002003Z
>@@00?li00<00000000<400000000P00ocT00`00mQP000000?ooo`1K0?ooo`00ZP3oool00`00U@P0
0000000@:@02000h>@8000000P00HD43000000@009E10P000004003>@@@00>Hi00@00000003>>@00
cST00?910`0000001000oc4000000032>@00`ST3002b>@0600000000mST00000002Q>@00lST00000
0`00jST200000003003Z>@00ocT00?li00<00?li0P000003003o>@800000G03oool00:/0oooo00@0
0000000@:@00>3T003Pi0P000002001Q@@<000001000UD42000000@00<i11000iST0100000000<hi
003>>@00lT42000000800?la00<000000032>@00`ST00`00/ST0100000000?Hi00000000XCT2003b
>@<00>Xi0P0000000`00jST00?li003o>@03003o>@0600000000obT00?li003o>@00mQP00000G@3o
ool00:/0oooo00@0000@000@:@00>3T003Pi0P000003001Q@@8000001000UD42000000@00<i11000
iST3003>>@0600000000ob000000003o8000oc4000000P00`ST3002b>@0400000000mST00000002Q
>@800?8i0`00jST200000003003Z>@00ocT00?li00<00?li0P00obT2003o>@03003f60000000oooo
05`0oooo002[0?ooo`060000400042T0000000000000@3T000000`00HD400`0000000;ha00000003
002E@@80000000@00<i100000000cT400<i11000iST3003>>@0300000000ob00000000800?la00<0
00000032>@00`ST00`00/ST0100000000?Hi00000000XCT2003b>@<00>Xi00<00000000d40000000
1@00ocT2003o:@80000000<00?HH0000003oool0G03oool00:/0oooo00H0000@000@:@0000000000
0010>@000003001Q@@0300000000_S40000000<009E10P000004003>@@@00>Hi0`00cST010000000
0?lP00000000oc42000000800<8i0`00/ST0100000000?Hi00000000XCT2003b>@<00>Xi00<00000
0014600000001@00ocT2003o:@80000000<00?HH0?ooo`3oool0G03oool00:`0oooo00D0010Y0000
0000iR0000000010>@03001Q@@0300000000_S40000000<009E100<00000002Z@@00cT400P00cT40
0`0000000>Hi003V>@02003V>@<00<hi00@00000003o800000000?la0P0000020032>@<00;8i00@0
0000003f>@00000000000P00lST01P0000000>Xi003Z>@00000004@H000000<00?li00@00000003o
>@00obT00?lY0P00001O0?ooo`00[03oool01@000000010Y000000000000040i00<0065100<00000
002n<@0000000`00UD43002Z@@03003>@@000000000000@00>Hi0`00cST01000000008di00000000
oc42000000800<8i0`00/ST0100000000?Hi003f>@000002003b>@<00>Xi00<00000001460000000
0`00ocT01P0000000?li00000000obT00000003f65l0oooo002/0?ooo`050000000042T000000000
0000@3T00`00HD400`00KD40000000000003002E@@<00:Y100<00<i10000000000001000iST3003>
>@0400000000SCT00000003o>@8000000P00`ST3002b>@0400000000mST00?Hi000000800?8i0`00
jST3000000<00?li0P0000001000obT0000000000000001O0?ooo`00[03oool400000080040i0P00
HD43001]@@<009E10`00ZT400`00000007Ti00000004003V>@<00<hi00@00000002=>@0000000?li
0P0000020032>@<00;8i00@00000003f>@00mST000000P00lST3003Z>@<000000`00ocT200000004
003o:@0000000000000005l0oooo002/0?ooo`@000000P00@3T2001Q@@<006e10`00UD43002Z@@03
00000000NCT0000000@00>Hi0`00cST01000000008di00000000ocT2000000800<8i0`00/ST01000
00000?Hi000000000002003b>@<00>Xi00<00000000h600000000`00ocT200000003003o:@000000
00000600oooo002]0?ooo`<000000P00@3T2001Q@@<006e10`00UD43002Z@@0300000000NCT00000
00@00>Hi0`00cST01000000008di00000000ocT2000000800<8i0`00/ST0100000000?Hi003f>@00
0002003b>@<00>Xi00<00000000h600000000`00ocT200000003003o:@00000000000600oooo002]
0?ooo`<000000P00@3T00`0000000651001]@@02001]@@<009E10`00ZT401000000007Ti001i>@00
0003003V>@@00<hi0P0000000`00ocT00000000000020032>@<00;8i00@00000003f>@00mST00000
0P00lST3003Z>@0300000000>1P0000000<00?li00<00000003o:@00obT00P00001P0?ooo`00[@3o
ool300000080040i0P000003001]@@<009E10`00ZT401000000007Ti001i>@000003003V>@@00<hi
0P0000000`00ocT00000000000020032>@<00;8i00@00000003f>@00mST000000`00lST2003Z>@03
00000000>1P0000000800?li0P000002003o:@030000003oool0oooo05l0oooo002]0?ooo`<00000
0P00@3T2000000<006e100<009E10000000000000`00ZT401000000007Ti001i>@000003003V>@@0
0<hi0P0000000`00ocT00000000000020032>@<00;8i00@00000003f>@00mST000000`00lST2003Z
>@0300000000>1P0000000800?li0P000002003o:@030000003oool0oooo05l0oooo002]0?ooo`03
00004000000001@Y0080040i0P000003001]@@<000000`00ZT401000000007Ti001i>@000003003V
>@@00<hi00<00000003o>@00ocT00P0000020032>@<00;8i00@00000003f>@00mST000000`00lST0
1@0000000>Xi00000000>1P0000000800?li0P000002003o:F80oooo002]0?ooo`03000040000000
01@Y0080040i0P000003001]@@<000001000ZT400`00000007Ti00000003003V>@@00<hi00<00000
003o>@00ocT00P0000020032>@<00;8i00@00000003f>@00mST000000`00lST2003Z>@0300000000
>1P0000000800?li0P000002003o:F80oooo002^0?ooo`030000000052T0040i0080040i00@00000
001]@@00KD4006e10`000004002Z@@0300000000NCT0000000800>Hi00<00000003>>@00cST00P00
cST00`0000000?li003o>@03000000050032>@00/ST00;8i002b>@0000000P00mST0100000000?8i
003b>@00lST2003Z>@0300000000>1P0000000800?li00@00000003o8000obT00000HP3oool00:h0
oooo00<00000000D:@0052T00P00@3T01000000006e1001]@@00KD43000000@00:Y100<00000001i
>@0000000P00iST00`0000000<hi003>>@02003>>@0300000000ocT00?li00<000000P00`ST3002b
>@0300000000mST0000000<00?8i0P00jST00`00000003PH00000002003o>@0400000000ob000?lY
00000680oooo002^0?ooo`030000400052T001@Y0080040i0P000002001]@@<000001000ZT420000
0004002n>@00iST00000000000@00<hi00<00000003o>@00ocT00`0000020032>@<00;8i00<00000
003f>@0000000`00lST2003Z>@80000000D00?la003o>@00ocT00000003o800200000680oooo002^
0?ooo`030000000052T001@Y0080040i0P000002001]@@<000001000ZT4200000004002n>@00iST0
0000000000@00<hi0`00ocT00`0000000?lH000000020032>@<00;8i00<00000003f>@0000000`00
lST2003Z>@0300000000oc400?la00800?li0P00ob0200000680oooo002^0?ooo`050000000052T0
01@Y00000000@3T00P000003001]@@0300000000XC40000000<00:Y100@00000002n>@00_ST00>Hi
0P000004003>>@<00?li00<00000003o600000000P00`ST3002b>@0300000000mST0000000<00?8i
0P00jST3003o<@800?li0P00ob0200000680oooo002^0?ooo`050000000052T001@Y00000000@3T0
0P000003001]@@0300000000XC40000000<00:Y100<00000002n>@00_ST00`000004003>>@<00?li
00<00000003o600000000P00`ST3002b>@0300000000mST0000000<00?8i0P00jST3003o<@800?li
0P00ob000`000000oooo0?ooo`1Q0?ooo`00[P3oool01`00000001@Y000D:@000000040i0014>@00
00000`00KD400`0000000:4a00000003002Z@@<00;hi0`000004003>>@<00?li0P0000030032>@<0
0;8i00<00000003f>@0000000`00lST2003Z>@<00?la0P00ocT2003o80030000003oool0oooo0640
oooo002_0?ooo`060000000052T0000000000000A3T000000`00KD400`0000000:4a00000003002Z
@@<00;hi0`000004003>>@03003o>@0000000?li008000000`00`ST3002b>@0300000000mST00000
00<00?8i00<00000003Z>@00oc400P00oc42003o>@03003o80000000000006<0oooo002_0?ooo`04
0000000052T000000000008004@i0`00KD43000000<00:Y10`00_ST00`0000000:4i00000004003>
>@03003o>@0000000?li008000000P00`ST01`0000000;8i002b>@00/ST00000003f>@0000000`00
lST00`0000000>Xi003o<@02003o<@800?li00<00?lP000000000000H`3oool00:l0oooo10000002
0014>@<006e100<00000002Q<@0000000`00ZT43002n>@0300000000XCT0000000@00<hi00D00?li
00000000ocT00?lH000000020032>@0700000000/ST00;8i002b>@0000000?Hi00000003003b>@03
00000000jST00?la00800?la0P00ocT00`00ob0000000?ooo`1S0?ooo`00[`3oool40000008004@i
0`00KD400`00OCT0000000000003002Z@@<00;hi00<00000002Q>@0000001000cST01@00ocT00000
003o>@00oaP0000000<00<8i0`00/ST00`0000000?Hi00000003003b>@0300000000jST00?la0080
0?la0P0000000`00ob0000000?ooo`1S0?ooo`00[`3oool40000008004@i0`00KD43001m>@<00:Y1
0`00_ST00`0000000:4i00000004003>>@<00?li0P0000030032>@<00;8i00<00000003f>@000000
0`00lST00`0000000>Xi003o<@02003o<@80000000<00?lP0000003oool0H`3oool00:l0oooo1000
00030014>@8006e10`00OCT3002Z@@<00;hi00<00000002Q>@0000001000cST3003o>@8000000`00
`ST3002b>@0300000000mST0000000<00?8i0P000003003o<@80000000<00?lP0?ooo`3oool0H`3o
ool00;00oooo100000020014>@8006e10`00OCT3002Z@@<00;hi00<00000002Q>@0000001000cST3
003o>@8000000`00`ST01P0000000;8i002b>@0000000?Hi000000<00?8i0P000003003o<@800000
00<00?lP0?ooo`3oool0H`3oool00;00oooo100000020014>@8006e10`00OCT3002Z@@<00;hi00<0
0000002Q>@0000001000cST2003o>@<000000`00`ST01P0000000;8i002b>@0000000?Hi000000<0
0?8i0P000003003o<@80000000<00?lP0?ooo`3oool0H`3oool00;00oooo00@00008000000000000
00000P00A3T2001]@@<007di0`00ZT43002n>@0400000000XCT00000002Q>@<00<hi0`00ocT20000
00<00<8i0`00/ST00`0000000?Hi00000003003b>@8000000`00oc400`0000000?lP003o801U0?oo
o`00/03oool0100000P000000000000000020014>@0300000000KD4007di008007di0`00ZT44002n
>@80000000@00:4i003>>@00cST00<hi0`00ocT2000000<00<8i0`00/ST00`0000000?Hi00000003
003b>@8000000`00oc400`0000000?lP003o801U0?ooo`00/03oool0100000P00000000@:@000002
0014>@8000000`00OCT2002Z@@0300000000_ST00;hi00800;hi0P0000001000XCT00<hi003>>@00
0003003o>@8000000`00`ST3002b>@0300000000mST0000000<00?8i0P000003003o<@0300000000
ob000?lP06D0oooo002`0?ooo`04000020000000010Y0000008004@i0P000003001m>@800:Y100<0
0000002n>@00_ST00P00_ST200000004002Q>@00cST00000000000<00?li0P0000030032>@<00;8i
00<00000003f>@0000000`00lST2000000800?la1000001U0?ooo`00/03oool200000080010Y0P00
A3T2000000<007di00<00:Y10000000000001000_ST01P0000000=hi002Q>@00000008di000000<0
0?li0P0000030032>@<00;8i00<00000003f>@0000000`00lST2000000800?la1000001U0?ooo`00
/03oool200000080010Y0P00A3T2000000<007di0`000004002n>@0600000000gST00:4i00000000
SCT000000`00ocT2000000<00<8i0`00/ST00`0000000?Hi00000003003b>@8000000P00oc440000
06D0oooo002a0?ooo`030000000042T0010Y008004@i0P000003001m>@03000000000100000000@0
0;hi00H00000003N>@00XCT00000002=>@000003003o>@8000000`00`ST3002b>@0300000000mST0
000000<00?8i0P000002003o<@@00000I@3oool00;40oooo00<00000000@:@0042T00P00A3T20000
00<007di00<000000000400000001000_ST01P0000000=hi002Q>@00000008di000000<00?li0P00
00030032>@<00;8i00<00000003f>@0000000`00lST2000000800?la0`00001V0?ooo`00/@3oool0
0`000000010Y000@:@020014>@8000000`00OCT00`000000000@00000004002n>@0600000000gST0
0:4i00000000SCT000000`00ocT2000000<00<8i0`00/ST00`0000000?Hi00000003003b>@800000
0P00oc400`0000000<8@0000001V0?ooo`00/@3oool00`000000010Y000@:@020014>@8000000`00
OCT00`000000000@00000004002n>@0300000000gST00=hi00<000000`00ocT2000000<00<8i0`00
/ST00`0000000?Hi00000003003b>@8000000P00oc400`0000000<8@0000001V0?ooo`00/@3oool0
0`000000010Y000@:@020014>@<000000P00OCT01@000000000@00000000_ST0064i00800;hi0`00
gST3000000<00?li0P0000030032>@<00;8i00<00000001a:@0000000`00lST2000000800?la00<0
0000003240000000IP3oool00;40oooo00<00000000@:@0042T00P00A3T30000008007di00@00000
00004000000000000`00_ST3003N>@<000000`00ocT2000000<00<8i0`00/ST00`0000000?Hi0000
0003003b>@8000000P00oc400`0000000<8@0000001V0?ooo`00/P3oool010000000010Y0014>@00
A3T30000008007di00@0000000004000000000000`00_ST3003N>@<000000`00ocT2000000<00<8i
0`00/ST00`0000000?Hi00000003003b>@8000000P00oc400`00`Q0000000000001V0?ooo`00/P3o
ool010000000010Y00000000A3T3000000<007di0`000003002n>@<00=hi0`000003003o>@800000
0`00`ST3002b>@0300000000mST0000000<00?8i0P000002003o<@03003240000000oooo06H0oooo
002b0?ooo`050000000042T000000014>@00B3T00P000003001m>@<000000`00_ST3003N>@<00000
0`00ocT2000000<00<8i0`00/ST00`0000000?Hi00000003003b>@8000000P00oc400`00`Q000000
0?ooo`1V0?ooo`00/P3oool01@000000010Y00000000000004Pi008000000`00OCT3000000<00;hi
0`00gST3000000<00?li0P0000030032>@<00;8i00<00000003f>@0000000`00lST2000000800?la
00<00<8@0000003oool0IP3oool00;80oooo100000020018>@0400000000OCT007di001m>@<00000
0`00_ST3003N>@<000000`00ocT2000000<00<8i0`00/ST200000004003o<@00lST00?8i003b>@80
00000P00oc400`00`Q0000000?ooo`1V0?ooo`00/P3oool00`00V@00000000000002000000030018
>@00000007di008007di0`000003002n>@<00=hi0`000002003o>@<000000`00`ST3002b>@800000
00@00?la003b>@00lST00?8i0P000002003o<@030032403oool0oooo06H0oooo002b0?ooo`03002I
000000000000008000000P00B3T3001m>@<000000`00_ST3003N>@<000000P00ocT3000000<00<8i
00<00000002b>@00/ST00P0000001000oc400?8i003b>@00lST2000000800?la00<00<8@0?ooo`3o
ool0IP3oool00;<0oooo100000020018>@<007di0`000003002n>@<00=hi0`000002003o>@<00000
0`00`ST00`0000000;8i002b>@0200000004003o<@00lST00?8i003b>@8000000P00oc400`00`Q00
oooo0?ooo`1V0?ooo`00/`3oool200000004003o:@00000004Pi0018>@<007di0`000003002n>@<0
0=hi0`000002003o>@<000000`00`ST0100000000;8i002b>@000002003o<@<00?8i0P000002003o
<@030032403oool0oooo06H0oooo002c0?ooo`80000000@00?lY00000000B3T004Pi0`00OCT3002E
>@<00;hi0`00gST3000000800?li0`0000030032>@0400000000/ST00;8i000000800?la0`00lST2
000000800?la00<00<8@0?ooo`3oool0IP3oool00;<0oooo0P0000001000obT000000018>@00B3T3
001m>@<009Di0`00_ST3003N>@<000000P00ocT3000000<00<8i00@00000002b>@00/ST000000P00
oc43003b>@0500000000ob000?la003o<@00`Q00J03oool00;<0oooo0P0000001000obT000000018
>@00B3T3001m>@<009Di0`00_ST3003N>@<000000P00ocT3000000<00<8i00<00000002b>@00/ST0
0`00oc43003b>@0500000000ob000?la00000000`Q00J03oool00;<0oooo100000020018>@<007di
0`00UCT3002n>@<00=hi0`000002003o>@<000000`00`ST00`0000000;8i002b>@03003o<@<00?8i
00D00000003o8000000000000032401X0?ooo`00/`3oool40000008004Pi0`00OCT3002E>@<00;hi
0`00gST01000XCT00000003J>@00fST4000000<00<8i00<00000002b>@00/ST00`00oc43003b>@05
00000000ob000000000000000100J03oool00;<0oooo100000020018>@<007di0`00UCT3002n>@<0
0=hi00@00:4i00000000fST00=Xi100000030032>@80000000@00;8i003o<@00oc400?la0`00lST0
0`0000000?lP00000002000006P0oooo002c0?ooo`@000000P00B3T3001m>@<009Di0P00_ST01P00
00000=hi003N>@00gST00:4i000000800=Xi100000030032>@80000000@00;8i003o<@00oc400?la
0`00lST2003o80<00000J03oool00;@0oooo0`0000020018>@<007di0`00UCT2002n>@0600000000
gST00=hi003N>@00oc4000000P00fST4000000<00<8i0P0000001000/ST00?la003o<@00oc43003b
>@800?lP0P00001Y0?ooo`00]03oool00`00000000`P000000020018>@<007di0`00UCT00`00_ST0
000000000003003N>@04002Q>@00fST00=Xi003J>@@000000`00`ST200000004002b>@00oc400?la
003o<@<00?8i00@00?lP0000000000000000J@3oool00;@0oooo00<00000000<800000000P00B3T0
0`00000007di001m>@03002E>@03002n>@000000000000<00=hi00@00:4i003J>@00fST00=Xi0P00
00000`00obT000000032>@020032>@80000000@00;8i003o<@00oc400?la0`00lST01000ob000000
00000000001Y0?ooo`00]03oool00`00V@0000`P000000020018>@<000000`00UCT00`000000064i
00000003003N>@04002Q>@00fST00=Xi003J>@80000000<00?lY00000000`ST00P00`ST200000004
002b>@00oc400?la003o<@<00?8i00@00?lP0000000000000000J@3oool00;@0oooo00<009T0000<
800032000P00B3T3000000<009Di00<00000001Q>@0000000`00gST01000XCT00=Xi003J>@00fST2
00000003003o:@0000000<8i00800<8i0P0000001000/ST00?la003o<@00oc43003b>@04003o8000
00000000000006T0oooo002d0?ooo`03002I0000320000`P008004Pi0`000003002E>@0300000000
HCT0000000<00=hi00@00:4i003J>@00fST00=Xi0P0000000`00obT000000032>@020032>@800000
00@00;8i003o<@00oc400?la0`00lST00`00ob0000000000001Z0?ooo`00]03oool00`00V@0000`P
000<80020018>@<000000`00UCT00`000000064i00000003003N>@04002Q>@00fST00=Xi003J>@80
000000<00?lY00000000`ST00P00`ST200000004002b>@00oc400?la003o<@<00?8i00<00?lP0000
00000000JP3oool00;@0oooo00<009T0000<800032000P00B3T30000008009Di0P0000000`00HCT0
0000003N>@02003N>@04002Q>@00fST00=Xi003J>@80000000<00?lY00000000`ST00P00`ST20000
0004002b>@00oc400?la003o<@<00?8i00<00?lP000000000000JP3oool00;@0oooo00<009T0000<
800032000`00B3T20000008009Di0P0000000`00HCT00000003N>@02003N>@04002Q>@00fST00=Xi
003J>@80000000<00?lY00000000`ST00P00`ST200000004002b>@00oc400?la003o<@<00?8i00<0
0?lP000000000000JP3oool00;@0oooo00<009T0000<800032000`00B3T2000000<009Di00<00000
001Q>@0000000`00gST01000XCT00=Xi003J>@00fST200000003003o:@0000000<8i00800<8i0P00
00001000/ST00?la003o<@00oc43003b>@03003o80000000000006X0oooo002e0?ooo`8000`P0`00
B3T2000000<009Di00<00000001Q>@0000000`00gST4003J>@80000000<00?lY00000000`ST00P00
`ST200000004002b>@00oc400?la003o<@<00?8i00<00?lP000000000000JP3oool00;D0oooo0P00
32030018>@8000000`00UCT00`000000064i00000003003N>@@00=Xi0P0000000`00obT000000032
>@020032>@80000000@00;8i003o<@00oc400?la0`00lST00`00ob0000000000001Z0?ooo`00]@3o
ool2000<80<004Pi0P000003002E>@0300000000HCT0000000<00=hi1000fST200000003003o:@00
00000<8i00800<8i0P0000001000/ST00?la003o<@00oc43003b>@03003o80000000000006X0oooo
002e0?ooo`8000`P0`00B3T200000003002E>@000000000@00<0064i0P0000000`00gST00=Xi003J
>@02003J>@80000000<00?lY00000000`ST00P00`ST00`0000000?Hi00000003003o<@<00?8i00<0
0?lP000000000000JP3oool00;D0oooo0P0032020018>@03003N<@000000000H0080000000@0000@
001Q>@00HCT00;880P0000001@00bST00>h@003o<@00oc400=Xi0080000000<00?lY00000000`ST0
0P00`ST00`0000000?Hi00000003003o<@0400000000lST00?8i003o80800000JP3oool00;D0oooo
00D00000000<8000mRT00?HY003N<@0500000003003o<@0001000;880080000000@00<Xi003^4000
SCT008di1@0000030032>@<000000`00oc401@0000000?8i003b>@00ob00000006/0oooo002e0?oo
o`8000000P00mRT2003N<@80000000D00;Ha00000000oc40000@002b200200000004003:>@00kQ00
08di002=>@D000000`00`ST3000000<00?la0P0000000`00lST00?lP0000001[0?ooo`00]@3oool2
000000800?HY00T00=ha0000000000000000002f<@0000000?la00004000/PP00P0000001000bST0
0>h@002=>@00SCT3000000030000600000000<8i00800<8i0`000003003o<@80000000<00?8i003o
80000000J`3oool00;D0oooo0P000002003f:@09003N<@000000000000000000]S400?lY003o<@00
01000;880080000000<00<Xi003^4000SCT00P00SCT4000000<00<8i0`000003003o<@80000000<0
0?8i003o80000000J`3oool00;D0oooo0P000002003f:@09003N<@000000000000000000]S400?lY
0000000001000;880080000000<00<Xi003^4000SCT00P0000001000YCT000000000000000030032
>@<000000`00oc4300000003003o800000P0oooo06X0oooo002f0?ooo`04003o:@00mRT00?HY003N
<@<000000P00]S400`000000000@0000400200000003003:>@0000000008008000000P00YCT01@00
U@000000002U>@0000000<8i00<000000`00oc4300000003003o800000P0oooo06X0oooo002g0?oo
o`800?HY00@00=ha00000000000000000P00]S430000000400006000000004@a000000800:Di0P00
0002001a<@0300000000/S400000008006DY00@00000003f>@00mST00?Hi100000000`00ob000008
0?ooo`1Z0?ooo`00^P3oool3000000800;Ha1@0000001000010007Ta001i<@00A34200000080074a
00<00000002b<@0000000P00IBT01P00000007da001m<@00EBT00000003o8080000000<00?lP0000
203oool0JP3oool00;X0oooo0P000000100001P0000000000000jR02003o608000000`00NC420014
<@06003:<@000000094Y00000000/S4000000P00IBT00`00000007da001m<@02001E:@05003o8000
000000000000000000P0J`3oool00;X0oooo0P0000001@0001P0000000000000jR000?lH00<00000
0`00NC4200000003003:<@000000094Y00<000000P00IBT00`00000007da001m<@03001E:@800000
00<00?lP0000203oool0JP3oool00;X0oooo0P0000000`00lQP00?HH00000002003Z800300006000
0000000000<007Ta0P0000001000bS400000002A:@00RC420000008006DY00<00000001m<@00OC40
0`00EBT3000000030000203oool0oooo06T0oooo002j0?ooo`80000000T00?8H003f600000000000
003Z8000bRT0000800000000obT00P00ob001P0000000<Xa003:<@000000094Y0029<@80000000<0
06DY00000000OC400P00OC43001E:@030010:@0061P0000006`0oooo002k0?ooo`0300000000lQP0
0?HH0080000000D00>XP003::@0000P00000003o:@02003o80<00<Xa00<00000002A:@00RC400P00
00000`00IBT00000001m<@02001m<@<005DY00<0040Y000H60000000K03oool00;/0oooo0P000000
1000mQP0000000000000jR02003::@0400000000obT00?lP003o80@00<Xa00@000000029<@000000
0:4a0P000003001m<@<005DY00<0040Y0000003oool0K03oool00;/0oooo0P0000001000mQP00000
003Z:@00jR04003::@800?lP1000bS42000000800:4a0P000003001m<@8005DY00<0040Y000X8000
0000K@3oool00;/0oooo0P0000001@00mQP00>XY003Z:@00jRT0000000<00<XY00H00:hY003o8000
bS400<Xa00000000bS42000000800:4a0P000003001m<@05001E:@00?2T002PP000X80000000K@3o
ool00;`0oooo00<00?8H003f6000jRT00P00jRT01@0000000<XY003::@00bRT0000000<00:hY1000
0002002Q<@80000000<007da001E<@00?2T00P00?2T00`00:200oooo0?ooo`1]0?ooo`00_P3oool3
003Z:@0500000000bRT00<XY003::@0000000`00[RT2000000<008Ta0`00IBT2001E<@8003`YL@3o
ool00<00oooo00<00>XY0000000000000P00bRT200000004002^:@000000oooo000000<008Ta0`00
IBT2001E<@03000l:@3oool0oooo0700oooo00320?ooo`0300000000bRT00<XY0080000000@00:hY
0000003oool000000`00RC43001U:GD0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0
oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0
oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0
oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0
oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0
oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0
oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0
oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0
oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0
oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0
oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0
oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0
oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0
oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo0000\
\>"],
  ImageRangeCache->{{{0, 325.25}, {528.938, 0}} -> {0.186172, 0.00597699, \
0.00188028, 0.00188028}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wExample = \@\(z\^7 - 2\ z\^4 - 3\ z + 8\)\%5; \)], "Input",
  FontSize->12],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.62453 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.30443 1.63518 -0.0106411 1.63518 [
[ 0 0 0 0 ]
[ 1 1.62453 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.62453 L
0 1.62453 L
closepath
clip
newpath
.4132 .54216 m .37349 .51307 L .40957 .5252 L 1 .004 .28 r
F
.4495 .56928 m .40957 .5252 L .4472 .55165 L 1 .009 .283 r
F
.4495 .56928 m .4132 .54216 L .40957 .5252 L F
.63172 .52941 m .60033 .53719 L .63605 .51283 L .394 0 .264 r
F
.66452 .51919 m .63605 .51283 L .67006 .50184 L .444 0 .283 r
F
.66452 .51919 m .63172 .52941 L .63605 .51283 L F
.59725 .55258 m .56318 .57553 L .60033 .53719 L .338 0 .249 r
F
.63172 .52941 m .59725 .55258 L .60033 .53719 L .394 0 .264 r
F
.48706 .60687 m .4472 .55165 L .48611 .58924 L 1 .016 .302 r
F
.48706 .60687 m .4495 .56928 L .4472 .55165 L F
.37843 .52938 m .33925 .51618 L .37349 .51307 L .986 .001 .289 r
F
.4132 .54216 m .37843 .52938 L .37349 .51307 L 1 .004 .28 r
F
.69533 .52069 m .67006 .50184 L .70205 .50329 L .481 0 .298 r
F
.69533 .52069 m .66452 .51919 L .67006 .50184 L F
.56141 .58964 m .52486 .62746 L .56318 .57553 L .306 0 .252 r
F
.59725 .55258 m .56141 .58964 L .56318 .57553 L .338 0 .249 r
F
.52446 .64836 m .52173 .64415 L .52487 .63278 L 1 .017 .319 r
F
.52173 .64415 m .52169 .64409 L .52177 .64383 L F
.52173 .64415 m .52177 .64383 L .52487 .63278 L F
.52181 .64283 m .48566 .69018 L .52291 .63058 L .313 0 .269 r
F
.52169 .64409 m .52168 .6441 L .52181 .64283 L F
.52168 .6441 m .48566 .69018 L .52181 .64283 L F
.52405 .66442 m .52028 .65856 L .52446 .64836 L 1 .017 .324 r
F
.52028 .65856 m .52018 .6584 L .52129 .64812 L F
.52029 .65825 m .52018 .6584 L .52163 .64517 L .312 0 .273 r
F
.52018 .6584 m .52006 .65855 L .52143 .64685 L F
.52018 .6584 m .52143 .64685 L .52163 .64517 L F
.52006 .65855 m .48665 .7023 L .52161 .6452 L F
.52006 .65855 m .52161 .6452 L .52163 .64517 L F
.52168 .6441 m .48665 .7023 L .48566 .69018 L .313 0 .269 r
F
.52169 .64409 m .48706 .60688 L .48612 .58924 L 1 .017 .319 r
F
.52173 .64415 m .52169 .64411 L .52169 .64409 L F
.52169 .64411 m .48706 .60688 L .52169 .64409 L F
.52169 .64409 m .52161 .6452 L .52168 .6441 L .313 0 .269 r
F
.52446 .64836 m .52161 .6452 L .52173 .64415 L 1 .017 .319 r
F
.52445 .64057 m .52161 .6452 L .52169 .64409 L .313 0 .269 r
F
.52161 .6452 m .48665 .7023 L .52168 .6441 L F
.52028 .65856 m .52158 .64516 L .52161 .6452 L 1 .017 .324 r
F
.52082 .65725 m .52161 .6452 L .52446 .64836 L F
.52028 .65856 m .52161 .6452 L .52082 .65725 L F
.52129 .64812 m .48706 .60688 L .52158 .64516 L F
.52018 .6584 m .48706 .60688 L .52129 .64812 L F
.52161 .6452 m .48706 .60688 L .52173 .64415 L 1 .017 .319 r
F
.52403 .65336 m .52029 .65825 L .52445 .64057 L .312 0 .273 r
F
.52029 .65825 m .52163 .64517 L .52445 .64057 L F
.52169 .64409 m .52291 .63058 L .52487 .63278 L 1 .017 .319 r
F
.52445 .64057 m .52169 .64409 L .52486 .62746 L .313 0 .269 r
F
.52169 .64409 m .52291 .63058 L .52486 .62746 L F
.52169 .64409 m .48612 .58924 L .52291 .63058 L 1 .017 .319 r
F
.4169 .55867 m .37843 .52938 L .4132 .54216 L 1 .003 .266 r
F
.45184 .5869 m .4132 .54216 L .4495 .56928 L 1 .008 .269 r
F
.45184 .5869 m .4169 .55867 L .4132 .54216 L F
.59413 .56744 m .56141 .58964 L .59725 .55258 L .321 0 .235 r
F
.62732 .5456 m .59725 .55258 L .63172 .52941 L .387 0 .253 r
F
.62732 .5456 m .59413 .56744 L .59725 .55258 L F
.6589 .53631 m .63172 .52941 L .66452 .51919 L .443 0 .277 r
F
.6589 .53631 m .62732 .5456 L .63172 .52941 L F
.48801 .62514 m .4495 .56928 L .48706 .60687 L 1 .016 .296 r
F
.48801 .62514 m .45184 .5869 L .4495 .56928 L F
.37843 .52938 m .34547 .53177 L .33925 .51618 L .986 .001 .289 r
F
.38345 .54514 m .34547 .53177 L .37843 .52938 L .973 .001 .278 r
F
.4169 .55867 m .38345 .54514 L .37843 .52938 L 1 .003 .266 r
F
.68853 .53799 m .66452 .51919 L .69533 .52069 L .481 0 .294 r
F
.68853 .53799 m .6589 .53631 L .66452 .51919 L F
.34547 .53177 m .30718 .53423 L .33925 .51618 L .931 .001 .303 r
F
.56225 .69456 m .52487 .63278 L .56408 .68264 L 1 .013 .313 r
F
.56225 .69456 m .52446 .64836 L .52487 .63278 L F
.56141 .58964 m .52445 .64057 L .52486 .62746 L .306 0 .252 r
F
.55961 .60315 m .52445 .64057 L .56141 .58964 L .286 0 .243 r
F
.59413 .56744 m .55961 .60315 L .56141 .58964 L .321 0 .235 r
F
.72374 .5328 m .70206 .50329 L .7316 .51625 L .505 0 .306 r
F
.72374 .5328 m .69534 .52069 L .70206 .50329 L F
.59096 .58162 m .55961 .60315 L .59413 .56744 L .297 0 .214 r
F
.62287 .56134 m .59413 .56744 L .62732 .5456 L .38 0 .24 r
F
.62287 .56134 m .59096 .58162 L .59413 .56744 L F
.52362 .68119 m .51913 .67411 L .52405 .66442 L 1 .018 .333 r
F
.52016 .65842 m .48764 .71486 L .48665 .7023 L .312 0 .273 r
F
.52016 .65842 m .48764 .71486 L .52016 .65842 L F
.52005 .66007 m .48764 .71486 L .52018 .6584 L F
.51965 .66624 m .51833 .67286 L .52005 .66007 L 1 .018 .333 r
F
.51913 .67411 m .51855 .6732 L .51965 .66624 L F
.51855 .6732 m .51833 .67286 L .51965 .66624 L F
.51849 .67167 m .48764 .71486 L .52005 .66007 L .312 0 .281 r
F
.51833 .67286 m .51831 .67289 L .51849 .67167 L F
.51831 .67289 m .48764 .71486 L .51849 .67167 L F
.5232 .69894 m .51654 .68835 L .52362 .68119 L 1 .02 .347 r
F
.51654 .68835 m .51683 .68702 L .52362 .68119 L F
.5161 .68764 m .5165 .68499 L .52362 .68119 L F
.51594 .68774 m .48864 .72818 L .51815 .67539 L .312 0 .294 r
F
.5165 .68499 m .51815 .67539 L .52362 .68119 L 1 .02 .347 r
F
.51744 .67951 m .51815 .67539 L .51821 .67528 L .312 0 .294 r
F
.51594 .68774 m .51815 .67539 L .51744 .67951 L F
.51605 .68757 m .51594 .68774 L .51744 .67951 L F
.51833 .67286 m .48864 .72818 L .48764 .71486 L .312 0 .281 r
F
.51855 .6732 m .51832 .67298 L .51833 .67286 L 1 .018 .333 r
F
.52362 .68119 m .51815 .67539 L .51855 .6732 L F
.51815 .67539 m .48864 .72818 L .51833 .67286 L .312 0 .281 r
F
.51815 .67539 m .48897 .64447 L .51855 .6732 L 1 .018 .333 r
F
.51913 .67411 m .52005 .66007 L .52405 .66442 L F
.5236 .66565 m .51815 .67539 L .51833 .67286 L .312 0 .281 r
F
.51833 .67286 m .48897 .64447 L .48801 .62515 L 1 .018 .333 r
F
.51832 .67298 m .48897 .64447 L .51833 .67286 L F
.5165 .68499 m .48897 .64447 L .51796 .67519 L 1 .02 .347 r
F
.5161 .68764 m .51605 .68757 L .5165 .68499 L F
.51605 .68757 m .48897 .64447 L .5165 .68499 L F
.5165 .68499 m .51796 .67519 L .51815 .67539 L F
.51633 .68716 m .51605 .68757 L .51821 .67528 L .312 0 .294 r
F
.51605 .68757 m .51744 .67951 L .51821 .67528 L F
.51729 .70919 m .51509 .70568 L .52013 .7015 L 1 .02 .371 r
F
.51509 .70568 m .5153 .70129 L .5232 .69894 L F
.5153 .70129 m .51578 .69152 L .51761 .69335 L F
.5153 .70129 m .51761 .69335 L .5232 .69894 L F
.5232 .69894 m .51578 .69152 L .51654 .68835 L 1 .02 .347 r
F
.51585 .68787 m .48965 .74283 L .48864 .72818 L .312 0 .294 r
F
.51597 .68769 m .51584 .68796 L .51585 .68787 L F
.51584 .68796 m .48965 .74283 L .51585 .68787 L F
.51791 .73105 m .51364 .72465 L .52052 .71957 L .971 .018 .407 r
F
.51364 .72465 m .51448 .71078 L .52277 .71791 L F
.52277 .71791 m .51281 .70935 L .51436 .70452 L 1 .02 .371 r
F
.51364 .72465 m .50992 .71905 L .51448 .71078 L .971 .018 .407 r
F
.50992 .71905 m .50923 .72053 L .51183 .71266 L .335 0 .354 r
F
.50797 .72321 m .49166 .78404 L .49066 .76011 L F
.50992 .71905 m .51281 .70935 L .51448 .71078 L .971 .018 .407 r
F
.5098 .71874 m .5084 .72176 L .51281 .70935 L .335 0 .354 r
F
.5084 .72176 m .49066 .76011 L .5106 .71443 L F
.5084 .72176 m .5106 .71443 L .51281 .70935 L F
.50923 .72053 m .50829 .72253 L .5098 .71874 L F
.50829 .72253 m .49066 .76011 L .5098 .71874 L F
.50923 .72053 m .51281 .70935 L .51325 .70835 L F
.51597 .68774 m .48965 .74283 L .51597 .68769 L .312 0 .294 r
F
.51578 .69152 m .48965 .74283 L .51605 .68757 L F
.51299 .70318 m .51286 .7034 L .51578 .69152 L .316 0 .316 r
F
.51286 .7034 m .48965 .74283 L .51561 .69187 L F
.51286 .7034 m .51561 .69187 L .51578 .69152 L F
.50992 .71905 m .50934 .71818 L .51281 .70935 L .971 .018 .407 r
F
.51324 .70275 m .49066 .76011 L .48965 .74283 L .316 0 .316 r
F
.51436 .70452 m .51317 .70382 L .51324 .70275 L 1 .02 .371 r
F
.51281 .70935 m .49066 .76011 L .51324 .70275 L .316 0 .316 r
F
.51281 .70935 m .49091 .69052 L .51436 .70452 L 1 .02 .371 r
F
.51509 .70568 m .51324 .70275 L .51578 .69152 L F
.51428 .69904 m .51299 .70318 L .51594 .69122 L .316 0 .316 r
F
.51364 .70208 m .51324 .70275 L .51428 .69904 L F
.51324 .70275 m .51299 .70318 L .51428 .69904 L F
.51317 .70382 m .51298 .7037 L .51324 .70275 L 1 .02 .371 r
F
.51299 .70318 m .51578 .69152 L .51594 .69122 L .316 0 .316 r
F
.51298 .7037 m .49091 .69052 L .51324 .70275 L 1 .02 .371 r
F
.51324 .70275 m .48994 .66566 L .51323 .68897 L F
.51324 .70275 m .51323 .68897 L .51578 .69152 L F
.52272 .68665 m .51325 .70835 L .51324 .70275 L .316 0 .316 r
F
.51325 .70835 m .51281 .70935 L .51324 .70275 L F
.51324 .70275 m .49091 .69052 L .48994 .66566 L 1 .02 .371 r
F
.50934 .71818 m .49091 .69052 L .51167 .70837 L .971 .018 .407 r
F
.50934 .71818 m .51167 .70837 L .51281 .70935 L F
.50992 .71905 m .49186 .72457 L .49091 .69052 L F
.52234 .7377 m .5091 .732 L .50992 .71905 L F
.50992 .71905 m .5091 .732 L .50797 .72321 L .335 0 .354 r
F
.50803 .72367 m .49166 .78404 L .50797 .72321 L F
.5091 .732 m .49999 .75918 L .50803 .72367 L F
.49999 .75918 m .49166 .78404 L .50803 .72367 L F
.5063 .73967 m .49642 .7696 L .5091 .732 L .545 0 .46 r
F
.49642 .7696 m .49166 .78404 L .49999 .75918 L F
.49642 .7696 m .49999 .75918 L .5091 .732 L F
.5063 .73967 m .49236 .90202 L .49166 .78404 L F
.5063 .73967 m .49237 .90092 L .49186 .72457 L .742 .01 .477 r
F
.5219 .75597 m .49285 .89853 L .5063 .73967 L F
.49285 .89853 m .49236 .90202 L .5063 .73967 L .545 0 .46 r
F
.49285 .89853 m .49237 .90092 L .5063 .73967 L .742 .01 .477 r
F
.5091 .732 m .4997 .72795 L .50992 .71905 L .971 .018 .407 r
F
.4997 .72795 m .49186 .72457 L .49814 .72265 L F
.4997 .72795 m .49814 .72265 L .50992 .71905 L F
.52227 .69272 m .5091 .732 L .50992 .71905 L .335 0 .354 r
F
.5219 .75597 m .51068 .74424 L .52234 .7377 L .742 .01 .477 r
F
.51068 .74424 m .5063 .73967 L .51003 .73921 L F
.51068 .74424 m .51003 .73921 L .52234 .7377 L F
.5063 .73967 m .50382 .73707 L .50486 .73711 L F
.5063 .73967 m .50486 .73711 L .50721 .73719 L F
.50382 .73707 m .50577 .73056 L .52234 .7377 L F
.50825 .73377 m .5063 .73967 L .51116 .72586 L .545 0 .46 r
F
.5063 .73967 m .5091 .732 L .51116 .72586 L F
.5063 .73967 m .50721 .73719 L .52234 .7377 L .742 .01 .477 r
F
.56041 .70648 m .52446 .64836 L .56225 .69456 L 1 .012 .317 r
F
.56041 .70648 m .52405 .66442 L .52446 .64836 L F
.55854 .71837 m .52405 .66442 L .56041 .70648 L 1 .01 .323 r
F
.55854 .71837 m .52362 .68119 L .52405 .66442 L F
.55666 .73012 m .52362 .68119 L .55854 .71837 L 1 .008 .332 r
F
.55666 .73012 m .5232 .69894 L .52362 .68119 L F
.55018 .65145 m .52227 .69272 L .55213 .64571 L .653 0 .412 r
F
.54111 .66487 m .52968 .68126 L .52227 .69272 L F
.55017 .65147 m .54197 .66338 L .54111 .66487 L F
.54197 .66338 m .52968 .68126 L .54111 .66487 L F
.52272 .68665 m .51364 .70208 L .52316 .67703 L .316 0 .316 r
F
.55405 .63757 m .52272 .68665 L .52316 .67703 L .121 0 .151 r
F
.55213 .64571 m .52272 .68665 L .55405 .63757 L 0 0 .008 r
F
.55213 .64571 m .52227 .69272 L .52272 .68665 L F
.54625 .65552 m .52134 .68621 L .5446 .65887 L 1 .917 .723 r
F
.54405 .66037 m .52968 .68126 L .54766 .65512 L .653 0 .412 r
F
.54766 .65512 m .54766 .65512 L .55017 .65147 L F
.54405 .66037 m .54766 .65512 L .54766 .65512 L F
.52227 .69272 m .51736 .70032 L .51894 .69629 L .335 0 .354 r
F
.52236 .6915 m .51894 .69629 L .52272 .68665 L F
.52227 .69272 m .51894 .69629 L .52236 .6915 L F
.54823 .65462 m .532 .678 L .54766 .65512 L 1 .81 .702 r
F
.52968 .68126 m .52189 .69258 L .52878 .68265 L .653 0 .412 r
F
.52189 .69258 m .52181 .6927 L .52878 .68265 L F
.52878 .68265 m .52181 .6927 L .52227 .69272 L F
.532 .678 m .52183 .69267 L .52968 .68125 L 1 .81 .702 r
F
.532 .678 m .52968 .68125 L .54766 .65512 L F
.54823 .65462 m .54766 .65512 L .55018 .65146 L F
.57442 .63584 m .54823 .65462 L .55018 .65146 L 0 0 0 r
F
.57101 .64183 m .54823 .65462 L .57442 .63584 L .371 0 .582 r
F
.57101 .64183 m .54881 .6541 L .54823 .65462 L F
.52183 .69267 m .53915 .66749 L .55018 .65146 L 1 .81 .702 r
F
.55018 .65145 m .54405 .66037 L .55017 .65147 L .653 0 .412 r
F
.54881 .6541 m .54655 .65535 L .54823 .65462 L .371 0 .582 r
F
.54655 .65535 m .54625 .65552 L .54667 .65532 L F
.54655 .65535 m .54667 .65532 L .54823 .65462 L F
.54667 .65532 m .5446 .65887 L .54823 .65462 L 1 .917 .723 r
F
.54625 .65552 m .5446 .65887 L .54667 .65532 L F
.52183 .69267 m .52181 .6927 L .53915 .66749 L 1 .81 .702 r
F
.52227 .69272 m .51049 .71782 L .51736 .70032 L .335 0 .354 r
F
.52181 .6927 m .50825 .73377 L .52227 .69272 L .545 0 .46 r
F
.50825 .73377 m .51116 .72586 L .52227 .69272 L F
.515 .71333 m .51342 .75231 L .5063 .73967 L F
.51729 .70919 m .52013 .7015 L .5232 .69894 L 1 .02 .371 r
F
.52181 .6927 m .52053 .7018 L .515 .71333 L .545 0 .46 r
F
.52277 .71791 m .51729 .70919 L .5232 .69894 L 1 .02 .371 r
F
.52053 .7018 m .51342 .75231 L .515 .71333 L .545 0 .46 r
F
.51342 .75231 m .51132 .76724 L .5063 .73967 L F
.51132 .76724 m .49285 .89853 L .50561 .74791 L F
.51132 .76724 m .50561 .74791 L .5063 .73967 L F
.49165 .78405 m .47856 .79722 L .49065 .76012 L .47 0 .341 r
F
.47856 .79722 m .45742 .81847 L .47624 .78543 L F
.47856 .79722 m .47624 .78543 L .49065 .76012 L F
.49204 .78241 m .47963 .79433 L .49198 .76338 L 0 0 .241 r
F
.47856 .79722 m .45996 .83557 L .45742 .81847 L .47 0 .341 r
F
.49165 .78405 m .47984 .80325 L .47856 .79722 L F
.47984 .80325 m .45996 .83557 L .47856 .79722 L F
.49223 .89762 m .45996 .83557 L .49165 .78405 L 1 .016 .22 r
F
.49232 .91492 m .47818 .88025 L .49223 .89762 L F
.47818 .88025 m .45996 .83557 L .49223 .89762 L F
.40697 .82947 m .4066 .82936 L .44306 .92614 L .128 0 .569 r
F
.40697 .82947 m .40823 .83845 L .40418 .83357 L .27 0 .224 r
F
.44736 .77001 m .41248 .83102 L .40697 .82947 L F
.44578 .91925 m .40697 .82947 L .44306 .92614 L .128 0 .569 r
F
.44736 .77001 m .40697 .82947 L .44489 .76054 L .27 0 .224 r
F
.40697 .82947 m .40657 .82929 L .4066 .82936 L .128 0 .569 r
F
.40697 .82947 m .40418 .83357 L .40657 .82929 L .27 0 .224 r
F
.40697 .82947 m .40657 .82929 L .44489 .76054 L F
.40697 .82947 m .40436 .82343 L .40657 .82929 L .128 0 .569 r
F
.40697 .82947 m .40851 .82151 L .40436 .82343 L F
.44578 .91925 m .41233 .83155 L .40697 .82947 L F
.41233 .83155 m .41233 .83153 L .41211 .83145 L F
.41233 .83155 m .41211 .83145 L .40697 .82947 L F
.44851 .91158 m .41304 .83171 L .44578 .91925 L .16 0 .576 r
F
.41248 .83102 m .41227 .83138 L .40697 .82947 L .27 0 .224 r
F
.44986 .78014 m .41304 .83171 L .44736 .77001 L .285 0 .226 r
F
.41304 .83171 m .41227 .83138 L .41233 .83153 L .16 0 .576 r
F
.41304 .83171 m .41233 .83153 L .44578 .91925 L F
.41233 .83153 m .41227 .83138 L .40831 .82995 L .128 0 .569 r
F
.41233 .83153 m .40831 .82995 L .40697 .82947 L F
.41304 .83171 m .40823 .83845 L .41227 .83138 L .285 0 .226 r
F
.41304 .83171 m .4123 .83133 L .44736 .77001 L F
.41304 .83171 m .4127 .81888 L .40851 .82151 L .16 0 .576 r
F
.44851 .91158 m .41878 .83464 L .41304 .83171 L F
.44986 .78014 m .41853 .8331 L .41304 .83171 L .285 0 .226 r
F
.41853 .8331 m .41832 .83345 L .41304 .83171 L F
.41878 .83464 m .41832 .83345 L .41304 .83171 L .16 0 .576 r
F
.41832 .83345 m .41811 .83381 L .41304 .83171 L .285 0 .226 r
F
.41832 .83345 m .4127 .81888 L .41304 .83171 L .16 0 .576 r
F
.41304 .83171 m .41227 .83138 L .4123 .83133 L .285 0 .226 r
F
.41304 .83171 m .40851 .82151 L .41227 .83138 L .16 0 .576 r
F
.41304 .83171 m .41811 .83381 L .41298 .83179 L .285 0 .226 r
F
.45127 .90277 m .42054 .83595 L .44851 .91158 L .196 0 .582 r
F
.42054 .83595 m .42042 .8359 L .44851 .91158 L F
.42001 .83479 m .41997 .83478 L .44851 .91158 L F
.41981 .83435 m .41977 .83434 L .44851 .91158 L F
.41966 .83402 m .41844 .83376 L .44851 .91158 L F
.45237 .79125 m .4251 .83518 L .41966 .83402 L .304 0 .228 r
F
.4251 .83518 m .42486 .83557 L .41966 .83402 L F
.42544 .83705 m .42541 .83697 L .42001 .83479 L .196 0 .582 r
F
.45237 .79125 m .41966 .83402 L .44986 .78014 L .304 0 .228 r
F
.41966 .83402 m .41838 .83336 L .44986 .78014 L F
.45406 .89224 m .42714 .83653 L .45127 .90277 L .239 0 .59 r
F
.42714 .83653 m .42707 .8365 L .42708 .83649 L .328 0 .228 r
F
.42716 .8365 m .42709 .83647 L .45237 .79125 L F
.45489 .80382 m .42714 .83653 L .45237 .79125 L F
.42714 .83653 m .42486 .83557 L .42511 .83621 L .239 0 .59 r
F
.42714 .83653 m .42511 .83621 L .45127 .90277 L F
.45127 .90277 m .42544 .83705 L .42001 .83479 L .196 0 .582 r
F
.42714 .83653 m .42052 .85518 L .4164 .8492 L .328 0 .228 r
F
.42729 .83636 m .42722 .83654 L .42714 .83653 L F
.42854 .83942 m .43279 .83954 L .42714 .83653 L .239 0 .59 r
F
.45406 .89224 m .43358 .84149 L .42854 .83942 L F
.43358 .84149 m .43279 .83954 L .42854 .83942 L F
.45688 .87903 m .44142 .84252 L .43676 .84055 L .288 0 .599 r
F
.42689 .83684 m .42486 .83557 L .45237 .79125 L .328 0 .228 r
F
.45688 .87903 m .43676 .84055 L .45406 .89224 L .288 0 .599 r
F
.43697 .83882 m .44108 .83996 L .43623 .83955 L .359 0 .222 r
F
.45742 .81847 m .44288 .83759 L .43816 .83763 L F
.43816 .83763 m .44152 .83938 L .43697 .83882 L F
.44288 .83759 m .44152 .83938 L .43816 .83763 L F
.44152 .83938 m .44108 .83996 L .43697 .83882 L F
.45996 .83557 m .44885 .84375 L .45742 .81847 L .397 0 .204 r
F
.44885 .84375 m .44744 .84321 L .45688 .87903 L .344 0 .613 r
F
.44885 .84375 m .4406 .84059 L .45742 .81847 L .397 0 .204 r
F
.44686 .84098 m .4406 .84059 L .45688 .87903 L .344 0 .613 r
F
.4466 .84002 m .4453 .84014 L .44686 .84098 L F
.4453 .84014 m .4406 .84059 L .44686 .84098 L F
.45974 .86186 m .44885 .84375 L .45688 .87903 L F
.45974 .86186 m .45157 .84433 L .44885 .84375 L F
.43676 .84055 m .43279 .83954 L .45406 .89224 L .288 0 .599 r
F
.45315 .84485 m .45157 .84433 L .45207 .84381 L .44 0 .158 r
F
.45829 .84653 m .45157 .84433 L .45488 .85143 L .412 .005 .634 r
F
.46165 .84763 m .45207 .84381 L .45996 .83557 L .44 0 .158 r
F
.46165 .84763 m .45488 .85143 L .46025 .85807 L .412 .005 .634 r
F
.45829 .84653 m .45488 .85143 L .46165 .84763 L F
.4683 .88028 m .47592 .88131 L .45974 .86186 L .41 0 .557 r
F
.4815 .89857 m .47592 .88131 L .4683 .88028 L F
.49232 .91492 m .482 .89379 L .46973 .86357 L 1 .016 .22 r
F
.47818 .88025 m .46973 .86357 L .45996 .83557 L F
.49232 .91492 m .46973 .86357 L .47818 .88025 L F
.49223 .8443 m .4841 .82936 L .49207 .79415 L 0 0 .241 r
F
.49238 .89416 m .48584 .84297 L .49223 .8443 L F
.48584 .84297 m .4841 .82936 L .49223 .8443 L F
.4841 .82936 m .47963 .79433 L .49207 .79415 L F
.48584 .84297 m .48383 .82399 L .48265 .81802 L F
.49238 .89416 m .48557 .83829 L .48584 .84297 L F
.48557 .83829 m .48383 .82399 L .48584 .84297 L F
.488 .79421 m .47963 .79433 L .49204 .78241 L F
.48664 .70231 m .44489 .76054 L .48566 .69019 L .318 0 .265 r
F
.46364 .73439 m .44736 .77001 L .44489 .76054 L F
.48664 .70231 m .46503 .73956 L .46364 .73439 L F
.46503 .73956 m .44736 .77001 L .46364 .73439 L F
.48763 .71487 m .44736 .77001 L .48664 .70231 L .333 0 .274 r
F
.48383 .82399 m .48094 .80032 L .48265 .81802 L 0 0 .241 r
F
.48763 .71487 m .46762 .74945 L .46624 .74417 L .333 0 .274 r
F
.48864 .72818 m .46893 .75459 L .48763 .71487 L .354 0 .286 r
F
.46893 .75459 m .44986 .78014 L .46762 .74945 L F
.46893 .75459 m .46762 .74945 L .48763 .71487 L F
.48221 .81433 m .48052 .80007 L .48213 .81395 L 0 0 .241 r
F
.48864 .72818 m .45237 .79125 L .44986 .78014 L .354 0 .286 r
F
.48964 .74284 m .45237 .79125 L .48864 .72818 L .381 0 .303 r
F
.48964 .74284 m .45489 .80382 L .45237 .79125 L F
.49065 .76012 m .45489 .80382 L .48964 .74284 L .416 0 .323 r
F
.49065 .76012 m .45742 .81847 L .45489 .80382 L F
.47963 .79433 m .46152 .65264 L .49198 .76338 L 0 0 .241 r
F
.49198 .76338 m .46152 .65264 L .49186 .72456 L F
.46686 .6589 m .46152 .65264 L .45903 .63833 L .968 0 .112 r
F
.48016 .69383 m .46252 .65501 L .46686 .6589 L F
.47597 .68689 m .46252 .65501 L .48016 .69383 L F
.46252 .65501 m .46152 .65264 L .46686 .6589 L F
.46409 .67276 m .46408 .66195 L .46152 .65264 L 0 0 .241 r
F
.47951 .79343 m .4648 .66816 L .46409 .67276 L F
.4648 .66816 m .46408 .66195 L .46409 .67276 L F
.49186 .72456 m .45903 .63833 L .49091 .69051 L .968 0 .112 r
F
.46933 .66117 m .46635 .65818 L .46667 .66417 L .52 0 0 r
F
.46408 .66195 m .43226 .61534 L .46152 .65264 L .815 0 0 r
F
.46408 .66195 m .43627 .62507 L .43226 .61534 L F
.46635 .65818 m .44671 .63847 L .46563 .66283 L .52 0 0 r
F
.46635 .65818 m .46563 .66283 L .46667 .66417 L F
.48094 .80032 m .46408 .66195 L .48022 .79754 L 0 0 .241 r
F
.47984 .79466 m .46408 .66195 L .47951 .79343 L F
.46555 .66272 m .446 .63759 L .46408 .66195 L .709 0 0 r
F
.446 .63759 m .43627 .62507 L .44463 .63616 L F
.446 .63759 m .44463 .63616 L .46408 .66195 L F
.446 .63759 m .44029 .63202 L .43627 .62507 L F
.45276 .64628 m .44029 .63202 L .446 .63759 L F
.44987 .6437 m .44029 .63202 L .45276 .64628 L F
.44671 .63847 m .44029 .63202 L .44987 .6437 L .52 0 0 r
F
.46667 .66417 m .46555 .66272 L .46408 .66195 L .709 0 0 r
F
.46555 .66272 m .46408 .66195 L .46408 .66195 L F
.46667 .66417 m .44987 .6437 L .45276 .64628 L F
.44671 .63847 m .44987 .6437 L .46667 .66417 L .52 0 0 r
F
.44518 .63692 m .44438 .63629 L .44029 .63202 L F
.44438 .63629 m .41509 .61761 L .44029 .63202 L .647 0 0 r
F
.44852 .63817 m .44353 .63561 L .44438 .63629 L .497 0 0 r
F
.44438 .63629 m .42058 .62382 L .41509 .61761 L .647 0 0 r
F
.44353 .63561 m .42058 .62382 L .44438 .63629 L .497 0 0 r
F
.45043 .6422 m .44438 .63629 L .44518 .63692 L .52 0 0 r
F
.46933 .66117 m .45324 .64512 L .45043 .6422 L F
.45324 .64512 m .44438 .63629 L .45043 .6422 L F
.49186 .72456 m .47597 .68689 L .48016 .69383 L .968 0 .112 r
F
.47979 .79393 m .46408 .66195 L .47976 .79399 L 0 0 .241 r
F
.47979 .79393 m .47976 .79399 L .48046 .79983 L F
.48052 .80007 m .47979 .79393 L .48046 .79983 L F
.48052 .80007 m .48046 .79983 L .48213 .81395 L F
.48094 .80032 m .48022 .79754 L .48265 .81802 L F
.46624 .74417 m .44986 .78014 L .44736 .77001 L .333 0 .274 r
F
.46762 .74945 m .44986 .78014 L .46624 .74417 L F
.48213 .81395 m .47984 .79466 L .47951 .79343 L 0 0 .241 r
F
.49207 .79415 m .488 .79421 L .49204 .78241 L F
.50382 .73707 m .49186 .72457 L .50577 .73056 L .742 .01 .477 r
F
.49405 .71566 m .46408 .66195 L .49239 .89327 L 0 0 .45 r
F
.48463 .82184 m .4655 .81742 L .4629 .8382 L 1 .337 .625 r
F
.51049 .71782 m .50992 .71905 L .51325 .70835 L .335 0 .354 r
F
.50992 .71905 m .51183 .71266 L .51325 .70835 L F
.51215 .7136 m .51325 .70835 L .52272 .68665 L F
.51049 .71782 m .51126 .7152 L .51215 .7136 L F
.51126 .7152 m .51325 .70835 L .51215 .7136 L F
.532 .678 m .52134 .68621 L .52181 .6927 L 1 .81 .702 r
F
.54823 .65462 m .53899 .66547 L .532 .678 L F
.53899 .66547 m .52134 .68621 L .532 .678 L F
.51364 .70208 m .51594 .69122 L .52316 .67703 L .316 0 .316 r
F
.52134 .68621 m .49405 .71567 L .493 .82933 L 1 .094 .513 r
F
.50197 .82722 m .493 .82933 L .49238 .89703 L F
.52134 .68621 m .493 .82933 L .50197 .82722 L F
.46921 .83495 m .4629 .8382 L .46474 .83858 L 1 .337 .625 r
F
.49374 .81498 m .46631 .83563 L .46921 .83495 L F
.46631 .83563 m .4629 .8382 L .46921 .83495 L F
.49374 .81498 m .48428 .81579 L .48463 .82184 L F
.48265 .81802 m .48221 .81433 L .48213 .81395 L 0 0 .241 r
F
.48428 .81579 m .4655 .81742 L .48463 .82184 L 1 .337 .625 r
F
.46474 .83858 m .4629 .8382 L .46263 .8403 L F
.49374 .81498 m .46263 .8403 L .48204 .89387 L F
.49238 .91581 m .48204 .89387 L .49229 .92216 L F
.51102 .7613 m .50701 .79051 L .51349 .75048 L 1 .094 .513 r
F
.50701 .79051 m .50317 .81847 L .50834 .7862 L F
.50317 .81847 m .49238 .89703 L .50267 .82559 L F
.50317 .81847 m .50267 .82559 L .50834 .7862 L F
.52145 .76828 m .51945 .77784 L .5219 .75598 L 1 .157 .528 r
F
.51945 .77784 m .49234 .90738 L .5172 .78006 L F
.51945 .77784 m .5172 .78006 L .5219 .75598 L F
.51945 .77784 m .49374 .81497 L .49249 .89753 L F
.49403 .89934 m .49249 .89753 L .49234 .90738 L F
.51945 .77784 m .49249 .89753 L .49403 .89934 L F
.49374 .81498 m .48204 .89387 L .49238 .91581 L 1 .337 .625 r
F
.482 .89379 m .47592 .88131 L .47531 .87958 L 1 .016 .22 r
F
.482 .89379 m .47531 .87958 L .46973 .86357 L F
.46721 .85635 m .46135 .84551 L .45996 .83557 L F
.45996 .83557 m .45157 .84433 L .44885 .84375 L .397 0 .204 r
F
.45489 .80382 m .4327 .83699 L .42729 .83636 L .328 0 .228 r
F
.4327 .83699 m .43222 .83769 L .42891 .8368 L F
.4327 .83699 m .42891 .8368 L .42729 .83636 L F
.43623 .83955 m .43243 .83738 L .45489 .80382 L .359 0 .222 r
F
.43623 .83955 m .42548 .80488 L .42118 .81076 L .288 0 .599 r
F
.43676 .84055 m .43649 .83969 L .43623 .83955 L F
.45742 .81847 m .43623 .83955 L .45489 .80382 L .359 0 .222 r
F
.44108 .83996 m .4406 .84059 L .43623 .83955 L F
.43649 .83969 m .42548 .80488 L .43623 .83955 L .288 0 .599 r
F
.43676 .84055 m .43623 .83955 L .43279 .83954 L F
.43623 .83955 m .43211 .83786 L .43243 .83738 L .359 0 .222 r
F
.43222 .83769 m .43211 .83786 L .42729 .83636 L .328 0 .228 r
F
.43279 .83954 m .43211 .83786 L .42714 .83653 L .239 0 .59 r
F
.43211 .83786 m .42722 .83655 L .42729 .83636 L .328 0 .228 r
F
.43211 .83786 m .42118 .81076 L .42714 .83653 L .239 0 .59 r
F
.43211 .83786 m .42676 .83783 L .42722 .83655 L .328 0 .228 r
F
.43211 .83786 m .42052 .85518 L .42676 .83783 L F
.43623 .83955 m .43536 .83787 L .43211 .83786 L .288 0 .599 r
F
.43536 .83787 m .42118 .81076 L .43211 .83786 L F
.43623 .83955 m .43211 .83786 L .43267 .83924 L F
.43623 .83955 m .43267 .83924 L .43279 .83954 L F
.43623 .83955 m .42052 .85518 L .43211 .83786 L .359 0 .222 r
F
.44515 .8376 m .42981 .79761 L .42548 .80488 L .344 0 .613 r
F
.4466 .84002 m .44566 .83763 L .44515 .8376 L F
.44566 .83763 m .42981 .79761 L .44515 .8376 L F
.46043 .83744 m .43418 .78908 L .43257 .79223 L .412 .005 .634 r
F
.44886 .82239 m .43257 .79223 L .42981 .79761 L F
.46043 .83744 m .43257 .79223 L .44886 .82239 L F
.46973 .86357 m .46165 .84763 L .46135 .84551 L 1 .016 .22 r
F
.46973 .86357 m .46135 .84551 L .46721 .85635 L F
.47592 .88131 m .46165 .84763 L .46973 .86357 L F
.45524 .84553 m .45207 .84381 L .46165 .84763 L .44 0 .158 r
F
.47592 .88131 m .46165 .84763 L .45974 .86186 L .41 0 .557 r
F
.46252 .85387 m .45207 .84381 L .46186 .84912 L .44 0 .158 r
F
.45867 .84175 m .42981 .79761 L .45157 .84433 L .412 .005 .634 r
F
.46263 .8403 m .44886 .82239 L .45867 .84175 L F
.44886 .82239 m .42981 .79761 L .45867 .84175 L F
.47592 .88131 m .47328 .87317 L .4699 .86711 L .41 0 .557 r
F
.47328 .87317 m .46263 .8403 L .4699 .86711 L F
.4699 .86711 m .46263 .8403 L .46165 .84763 L F
.47592 .88131 m .46252 .85387 L .46165 .84763 L 1 .016 .22 r
F
.49344 .90934 m .46252 .85388 L .48151 .89858 L 1 .006 .211 r
F
.49344 .90934 m .4651 .86916 L .46427 .86419 L F
.476 .87805 m .46427 .86419 L .46252 .85388 L F
.49344 .90934 m .46427 .86419 L .476 .87805 L F
.52145 .76828 m .51591 .77761 L .51945 .77784 L 1 .157 .528 r
F
.51591 .77761 m .49374 .81497 L .51945 .77784 L F
.52099 .77324 m .50459 .79835 L .51842 .77368 L 1 .559 .639 r
F
.52099 .77324 m .51842 .77368 L .52145 .76828 L F
.54688 .77167 m .52099 .77324 L .52145 .76828 L .441 0 0 r
F
.54485 .77244 m .52099 .77324 L .54688 .77167 L .084 0 .701 r
F
.54485 .77244 m .52387 .77275 L .52099 .77324 L F
.52387 .77275 m .52051 .7728 L .52099 .77324 L F
.52466 .77272 m .52047 .77257 L .52051 .7728 L .38 .052 .882 r
F
.54466 .77236 m .52485 .77253 L .52466 .77272 L F
.52485 .77253 m .52047 .77257 L .52466 .77272 L F
.50459 .79835 m .49374 .81497 L .50566 .79488 L 1 .559 .639 r
F
.50459 .79835 m .4949 .79563 L .49374 .81497 L F
.50701 .79051 m .50834 .7862 L .51349 .75048 L 1 .094 .513 r
F
.50459 .79835 m .50566 .79488 L .52145 .76828 L 1 .559 .639 r
F
.52099 .77324 m .50542 .7866 L .50459 .79835 L F
.50542 .7866 m .4949 .79563 L .50459 .79835 L F
.46263 .8403 m .45991 .8442 L .46165 .84763 L .412 .005 .634 r
F
.45991 .8442 m .45829 .84653 L .46165 .84763 L F
.49303 .91454 m .48151 .89858 L .49229 .92395 L 1 .006 .211 r
F
.49344 .90934 m .48151 .89858 L .49303 .91454 L F
.49226 .93178 m .4815 .89857 L .4683 .88028 L .41 0 .557 r
F
.46186 .84912 m .45524 .84553 L .46165 .84763 L .44 0 .158 r
F
.46263 .8403 m .45157 .84433 L .45829 .84653 L .412 .005 .634 r
F
.46025 .85807 m .45488 .85143 L .45974 .86186 L F
.46252 .85387 m .42886 .86806 L .45157 .84433 L .44 0 .158 r
F
.46252 .85387 m .45157 .84433 L .45315 .84485 L F
.44142 .84252 m .4406 .84059 L .43676 .84055 L .288 0 .599 r
F
.4406 .84059 m .42548 .80488 L .4356 .8369 L F
.4406 .84059 m .4356 .8369 L .43676 .84055 L F
.44885 .84375 m .44686 .84521 L .4406 .84059 L .397 0 .204 r
F
.44686 .84521 m .42468 .86153 L .4406 .84059 L F
.44885 .84375 m .4466 .84002 L .44744 .84321 L .344 0 .613 r
F
.4466 .84002 m .42548 .80488 L .4406 .84059 L F
.4406 .84059 m .4399 .84151 L .43854 .84079 L .359 0 .222 r
F
.4406 .84059 m .43854 .84079 L .43623 .83955 L F
.44885 .84375 m .44848 .84756 L .4454 .84628 L .397 0 .204 r
F
.45157 .84433 m .44848 .84756 L .44885 .84375 L F
.44885 .84375 m .44974 .84041 L .4466 .84002 L .344 0 .613 r
F
.45157 .84433 m .44974 .84041 L .44885 .84375 L F
.46263 .8403 m .46104 .83744 L .46043 .83744 L .412 .005 .634 r
F
.46104 .83744 m .43418 .78908 L .46043 .83744 L F
.44974 .84041 m .42981 .79761 L .4466 .84002 L .344 0 .613 r
F
.43623 .83955 m .4399 .84151 L .43569 .84009 L .359 0 .222 r
F
.44534 .84633 m .42886 .86806 L .42468 .86153 L .397 0 .204 r
F
.4454 .84628 m .44536 .84634 L .44534 .84633 L F
.44536 .84634 m .42886 .86806 L .44534 .84633 L F
.42722 .83654 m .42052 .85518 L .42714 .83653 L .328 0 .228 r
F
.42714 .83653 m .42708 .83649 L .42709 .83647 L F
.42714 .83653 m .42709 .83647 L .42716 .8365 L F
.42714 .83653 m .42118 .81076 L .41692 .81537 L .239 0 .59 r
F
.42714 .83653 m .41692 .81537 L .42486 .83557 L F
.42714 .83653 m .42689 .83684 L .42707 .8365 L .328 0 .228 r
F
.42541 .83697 m .42486 .83557 L .41991 .83415 L .196 0 .582 r
F
.42541 .83697 m .41991 .83415 L .42001 .83479 L F
.42689 .83684 m .4164 .8492 L .42486 .83557 L .328 0 .228 r
F
.42486 .83557 m .41692 .81537 L .41961 .83229 L .196 0 .582 r
F
.42486 .83557 m .41961 .83229 L .41991 .83415 L F
.41966 .83402 m .41832 .83345 L .41838 .83336 L .304 0 .228 r
F
.41966 .83402 m .4127 .81888 L .41832 .83345 L .196 0 .582 r
F
.41966 .83402 m .41832 .83345 L .41844 .83376 L F
.41966 .83402 m .4123 .84364 L .41832 .83345 L .304 0 .228 r
F
.42486 .83557 m .42416 .83669 L .41966 .83402 L F
.41966 .83402 m .41692 .81537 L .4127 .81888 L .196 0 .582 r
F
.42001 .83479 m .4199 .83409 L .41966 .83402 L F
.4199 .83409 m .41692 .81537 L .41966 .83402 L F
.43482 .84095 m .42468 .86153 L .42052 .85518 L .359 0 .222 r
F
.43569 .84009 m .43517 .8411 L .43482 .84095 L F
.43517 .8411 m .42468 .86153 L .43482 .84095 L F
.44848 .84756 m .42886 .86806 L .4454 .84628 L .397 0 .204 r
F
.42054 .83595 m .42001 .83479 L .42042 .8359 L .196 0 .582 r
F
.42001 .83479 m .41981 .83435 L .41997 .83478 L F
.4399 .84151 m .42468 .86153 L .43569 .84009 L .359 0 .222 r
F
.41981 .83435 m .41966 .83402 L .41977 .83434 L .196 0 .582 r
F
.41966 .83402 m .42416 .83669 L .41925 .83455 L .304 0 .228 r
F
.41925 .83455 m .4164 .8492 L .4123 .84364 L F
.42416 .83669 m .4164 .8492 L .41925 .83455 L F
.41298 .83179 m .4123 .84364 L .40823 .83845 L .285 0 .226 r
F
.41811 .83381 m .4123 .84364 L .41298 .83179 L F
.41227 .83138 m .40851 .82151 L .40697 .82947 L .128 0 .569 r
F
.41227 .83138 m .40823 .83845 L .40697 .82947 L .27 0 .224 r
F
.52134 .68621 m .51102 .7613 L .52181 .6927 L 1 .094 .513 r
F
.51102 .7613 m .51349 .75048 L .52181 .6927 L F
.52234 .7377 m .51791 .73105 L .52277 .71791 L .971 .018 .407 r
F
.51791 .73105 m .52052 .71957 L .52277 .71791 L F
.51605 .68757 m .51597 .68774 L .51597 .68769 L .312 0 .294 r
F
.51654 .68835 m .51603 .68791 L .51605 .68757 L 1 .02 .347 r
F
.51578 .69152 m .48994 .66566 L .51654 .68835 L F
.51654 .68835 m .5161 .68764 L .51683 .68702 L F
.52316 .67703 m .51578 .69152 L .51605 .68757 L .312 0 .294 r
F
.51605 .68757 m .48994 .66566 L .48897 .64447 L 1 .02 .347 r
F
.51603 .68791 m .48994 .66566 L .51605 .68757 L F
.52316 .67703 m .51633 .68716 L .5236 .66565 L .312 0 .294 r
F
.51633 .68716 m .51821 .67528 L .5236 .66565 L F
.52405 .66442 m .52005 .66007 L .52018 .6584 L 1 .017 .324 r
F
.5236 .66565 m .51833 .67286 L .52403 .65336 L .312 0 .281 r
F
.51833 .67286 m .52005 .66007 L .52403 .65336 L F
.51833 .67286 m .48801 .62515 L .52005 .66007 L 1 .018 .333 r
F
.52018 .6584 m .52016 .65842 L .52016 .65842 L .312 0 .273 r
F
.52403 .65336 m .52005 .66007 L .52018 .6584 L F
.52018 .6584 m .48801 .62515 L .48706 .60688 L 1 .017 .324 r
F
.52005 .66007 m .48801 .62515 L .52018 .6584 L F
.65321 .55321 m .62732 .5456 L .6589 .53631 L .445 0 .27 r
F
.65321 .55321 m .62287 .56134 L .62732 .5456 L F
.42064 .57455 m .38345 .54514 L .4169 .55867 L 1 .001 .247 r
F
.4542 .60447 m .4169 .55867 L .45184 .5869 L 1 .006 .248 r
F
.4542 .60447 m .42064 .57455 L .4169 .55867 L F
.48897 .64447 m .45184 .5869 L .48801 .62514 L 1 .017 .288 r
F
.48897 .64447 m .4542 .60447 L .45184 .5869 L F
.38345 .54514 m .35177 .54683 L .34547 .53177 L .973 .001 .278 r
F
.38854 .56021 m .35177 .54683 L .38345 .54514 L .956 0 .265 r
F
.42064 .57455 m .38854 .56021 L .38345 .54514 L 1 .001 .247 r
F
.34547 .53177 m .31463 .54888 L .30718 .53423 L .931 .001 .303 r
F
.35177 .54683 m .31463 .54888 L .34547 .53177 L .917 0 .296 r
F
.55961 .60315 m .52403 .65336 L .52445 .64057 L .286 0 .243 r
F
.55778 .61586 m .52403 .65336 L .55961 .60315 L .257 0 .229 r
F
.59096 .58162 m .55778 .61586 L .55961 .60315 L .297 0 .214 r
F
.68165 .55525 m .6589 .53631 L .68853 .53799 L .482 0 .29 r
F
.68165 .55525 m .65321 .55321 L .6589 .53631 L F
.71578 .54928 m .69534 .52069 L .72374 .5328 L .501 0 .302 r
F
.71578 .54928 m .68854 .53799 L .69534 .52069 L F
.58774 .59498 m .55778 .61586 L .59096 .58162 L .263 0 .184 r
F
.61835 .57654 m .59096 .58162 L .62287 .56134 L .373 0 .223 r
F
.61835 .57654 m .58774 .59498 L .59096 .58162 L F
.64745 .56989 m .62287 .56134 L .65321 .55321 L .449 0 .263 r
F
.64745 .56989 m .61835 .57654 L .62287 .56134 L F
.42445 .58956 m .38854 .56021 L .42064 .57455 L 1 0 .222 r
F
.4566 .62179 m .42064 .57455 L .4542 .60447 L 1 .003 .216 r
F
.4566 .62179 m .42445 .58956 L .42064 .57455 L F
.38854 .56021 m .35815 .56123 L .35177 .54683 L .956 0 .265 r
F
.3937 .5744 m .35815 .56123 L .38854 .56021 L .933 0 .248 r
F
.42445 .58956 m .3937 .5744 L .38854 .56021 L 1 0 .222 r
F
.48994 .66566 m .4542 .60447 L .48897 .64447 L 1 .017 .272 r
F
.48994 .66566 m .4566 .62179 L .4542 .60447 L F
.35177 .54683 m .32218 .56309 L .31463 .54888 L .917 0 .296 r
F
.35815 .56123 m .32218 .56309 L .35177 .54683 L .899 0 .288 r
F
.32218 .56309 m .31053 .56842 L .31463 .54888 L .882 0 .312 r
F
.32981 .57674 m .31824 .58202 L .32218 .56309 L .87 0 .309 r
F
.31358 .58032 m .30301 .55523 L .30604 .56711 L 0 0 .397 r
F
.31463 .54888 m .30268 .55445 L .30718 .53423 L .893 0 .315 r
F
.30268 .55445 m .29733 .54487 L .29762 .54456 L F
.30268 .55445 m .29762 .54456 L .30718 .53423 L F
.30268 .55445 m .28866 .51817 L .28024 .50123 L 0 0 .397 r
F
.30271 .55453 m .30269 .55447 L .30268 .55445 L F
.30268 .55445 m .29733 .54487 L .30604 .56711 L F
.30268 .55445 m .28633 .57948 L .27768 .5661 L .893 0 .315 r
F
.31463 .54888 m .30543 .55883 L .30308 .55427 L F
.32121 .59338 m .31088 .56952 L .31358 .58032 L 0 0 .391 r
F
.31088 .56952 m .31049 .56862 L .3106 .56905 L F
.31088 .56952 m .3106 .56905 L .31358 .58032 L F
.33755 .58972 m .3259 .59515 L .32981 .57674 L .855 0 .307 r
F
.32121 .59338 m .31297 .57342 L .31049 .56862 L 0 0 .391 r
F
.34208 .65182 m .30604 .56711 L .33552 .64318 L 0 0 .466 r
F
.34208 .65182 m .31358 .58032 L .30604 .56711 L F
.3487 .66014 m .31358 .58032 L .34208 .65182 L 0 0 .468 r
F
.3487 .66014 m .32121 .59338 L .31358 .58032 L F
.34538 .60185 m .33339 .60774 L .33755 .58972 L .835 0 .306 r
F
.32891 .60632 m .31874 .58353 L .32121 .59338 L 0 0 .378 r
F
.31822 .58235 m .3181 .58209 L .31312 .57378 L F
.31649 .57898 m .31633 .57908 L .31304 .57303 L .87 0 .309 r
F
.31633 .57908 m .31288 .57321 L .31304 .57303 L F
.31824 .58202 m .3181 .58209 L .31649 .57898 L F
.3181 .58209 m .31288 .57321 L .31312 .57378 L 0 0 .378 r
F
.31822 .58235 m .31312 .57378 L .32121 .59338 L F
.3181 .58209 m .29507 .5926 L .31649 .57898 L .87 0 .309 r
F
.31822 .58198 m .31304 .57303 L .3131 .57297 L F
.31824 .58202 m .31304 .57303 L .31822 .58198 L F
.31824 .58202 m .3131 .57297 L .32218 .56309 L F
.32218 .56309 m .3131 .57297 L .31053 .56842 L .882 0 .312 r
F
.31049 .56862 m .31042 .56846 L .31044 .56854 L 0 0 .391 r
F
.31049 .56862 m .31044 .56854 L .31358 .58032 L F
.3131 .57297 m .31304 .57303 L .31053 .56842 L .882 0 .312 r
F
.31042 .56846 m .30512 .55923 L .31358 .58032 L 0 0 .391 r
F
.31297 .57342 m .31288 .57321 L .31049 .56862 L F
.31304 .57303 m .31288 .57321 L .31046 .56853 L .882 0 .312 r
F
.31288 .57321 m .31046 .56853 L .31046 .56853 L F
.31304 .57303 m .31046 .56853 L .31053 .56842 L F
.31288 .57321 m .31045 .56851 L .31049 .56862 L 0 0 .391 r
F
.31049 .56862 m .31045 .56851 L .31042 .56846 L F
.31358 .58032 m .30511 .55918 L .30271 .55453 L 0 0 .397 r
F
.31042 .56846 m .29507 .5926 L .28633 .57948 L .882 0 .312 r
F
.31053 .56842 m .31046 .56853 L .31042 .56846 L F
.31046 .56853 m .29507 .5926 L .31042 .56846 L F
.31045 .56851 m .31045 .56851 L .31042 .56846 L 0 0 .391 r
F
.31053 .56842 m .30525 .55903 L .31463 .54888 L .882 0 .312 r
F
.31045 .56851 m .29716 .53511 L .31042 .56846 L 0 0 .391 r
F
.31288 .57321 m .29716 .53511 L .31045 .56851 L F
.31288 .57321 m .29507 .5926 L .31046 .56853 L .882 0 .312 r
F
.31042 .56846 m .30511 .55918 L .30512 .55923 L 0 0 .391 r
F
.3181 .58209 m .29716 .53511 L .31288 .57321 L 0 0 .378 r
F
.31633 .57908 m .29507 .5926 L .31288 .57321 L .87 0 .309 r
F
.3181 .58209 m .30575 .55213 L .29716 .53511 L 0 0 .378 r
F
.3181 .58209 m .30389 .6054 L .29507 .5926 L .87 0 .309 r
F
.32981 .57674 m .32107 .58641 L .3187 .58181 L F
.33339 .60774 m .33327 .60779 L .33075 .60349 L .835 0 .306 r
F
.33339 .60774 m .33075 .60349 L .33042 .60283 L F
.33668 .61915 m .32657 .59723 L .32891 .60632 L 0 0 .354 r
F
.32657 .59723 m .32585 .59569 L .32607 .59643 L F
.32657 .59723 m .32607 .59643 L .32891 .60632 L F
.35331 .61288 m .34062 .6197 L .34538 .60185 L .807 0 .305 r
F
.33668 .61915 m .32848 .60079 L .3259 .59578 L 0 0 .354 r
F
.35538 .66812 m .32121 .59338 L .3487 .66014 L 0 0 .467 r
F
.35538 .66812 m .32891 .60632 L .32121 .59338 L F
.36213 .67572 m .32891 .60632 L .35538 .66812 L 0 0 .461 r
F
.36213 .67572 m .33668 .61915 L .32891 .60632 L F
.33327 .60779 m .33299 .60793 L .3285 .6 L .835 0 .306 r
F
.33299 .60793 m .32825 .60028 L .33668 .61915 L 0 0 .312 r
F
.32585 .59569 m .32572 .59546 L .32891 .60632 L 0 0 .354 r
F
.32566 .59526 m .32061 .58691 L .32891 .60632 L F
.32848 .60079 m .32825 .60028 L .3259 .59578 L F
.32585 .59517 m .32566 .59526 L .32397 .59201 L .855 0 .307 r
F
.3259 .59515 m .32585 .59517 L .32089 .58661 L F
.32585 .59517 m .32081 .5867 L .32089 .58661 L F
.3259 .59515 m .32089 .58661 L .32981 .57674 L F
.32891 .60632 m .32061 .58691 L .31822 .58235 L 0 0 .378 r
F
.32566 .59526 m .31281 .61784 L .30389 .6054 L .855 0 .307 r
F
.33755 .58972 m .32825 .60028 L .32566 .59526 L F
.32825 .60028 m .32575 .59544 L .32587 .59572 L 0 0 .354 r
F
.32825 .60028 m .32587 .59572 L .3259 .59578 L F
.32585 .59569 m .32566 .59526 L .32572 .59546 L F
.3259 .59578 m .32575 .59543 L .32566 .59526 L F
.32825 .60028 m .31281 .61784 L .32566 .59526 L .855 0 .307 r
F
.32825 .60028 m .31442 .56933 L .32575 .59544 L 0 0 .354 r
F
.33299 .60793 m .3324 .60822 L .32825 .60028 L .835 0 .306 r
F
.3324 .60822 m .31281 .61784 L .32825 .60028 L F
.33299 .60793 m .32825 .60028 L .3285 .6 L F
.36135 .62245 m .34747 .63097 L .35331 .61288 L .767 0 .303 r
F
.34454 .63192 m .33429 .61062 L .33668 .61915 L 0 0 .312 r
F
.34454 .63192 m .33571 .61332 L .33331 .60859 L F
.36894 .68291 m .33668 .61915 L .36213 .67572 L 0 0 .449 r
F
.36894 .68291 m .34454 .63192 L .33668 .61915 L F
.36938 .62997 m .35375 .64145 L .36135 .62245 L .7 0 .295 r
F
.35247 .64463 m .34183 .62366 L .34454 .63192 L .684 0 0 r
F
.37383 .73233 m .34208 .65182 L .33552 .64318 L 0 0 .53 r
F
.34183 .62366 m .34049 .62103 L .34102 .62247 L .684 0 0 r
F
.34183 .62366 m .34102 .62247 L .34454 .63192 L F
.33401 .60743 m .33571 .61332 L .33299 .60793 L .835 0 .306 r
F
.33642 .61248 m .33571 .61332 L .33401 .60743 L F
.33999 .62004 m .33777 .61656 L .33624 .6127 L .807 0 .305 r
F
.34049 .62103 m .33999 .62004 L .33634 .61465 L .684 0 0 r
F
.33999 .62004 m .33571 .61332 L .33634 .61465 L F
.34049 .62103 m .33634 .61465 L .34454 .63192 L F
.33931 .62041 m .33571 .61332 L .33624 .6127 L .807 0 .305 r
F
.34062 .6197 m .3374 .61456 L .34538 .60185 L F
.3374 .61456 m .33624 .6127 L .33642 .61248 L F
.3374 .61456 m .33642 .61248 L .34538 .60185 L F
.35375 .64145 m .35315 .64188 L .35073 .63695 L .7 0 .295 r
F
.36047 .65726 m .34896 .63618 L .35247 .64463 L .789 0 0 r
F
.34896 .63618 m .34724 .63302 L .34809 .63492 L F
.34896 .63618 m .34809 .63492 L .35247 .64463 L F
.37753 .63501 m .35922 .65105 L .36938 .62997 L .572 0 .26 r
F
.37581 .68966 m .34454 .63192 L .36894 .68291 L 0 0 .426 r
F
.37581 .68966 m .35247 .64463 L .34454 .63192 L F
.38276 .69592 m .35247 .64463 L .37581 .68966 L 0 0 .389 r
F
.38276 .69592 m .36047 .65726 L .35247 .64463 L F
.34724 .63302 m .34714 .63283 L .34718 .63294 L .789 0 0 r
F
.33999 .62004 m .3396 .62093 L .33928 .62042 L .807 0 .305 r
F
.34051 .62106 m .34049 .62102 L .34001 .62007 L .684 0 0 r
F
.34051 .62106 m .34 .62007 L .33999 .62004 L F
.34049 .62102 m .34019 .62047 L .34 .62007 L F
.35247 .64463 m .34333 .62699 L .34051 .62106 L F
.34286 .62607 m .34192 .62725 L .33999 .62004 L .807 0 .305 r
F
.34192 .62725 m .33092 .64115 L .33889 .62259 L F
.34192 .62725 m .33889 .62259 L .33999 .62004 L F
.34724 .63302 m .34718 .63294 L .35247 .64463 L .789 0 0 r
F
.34714 .63283 m .34286 .62607 L .35247 .64463 L F
.36047 .65726 m .34945 .63871 L .34724 .63302 L F
.38966 .70151 m .36409 .66274 L .38276 .69592 L .603 0 0 r
F
.36409 .66274 m .36047 .65726 L .36205 .66 L F
.36409 .66274 m .36205 .66 L .38276 .69592 L F
.36559 .66502 m .36844 .66947 L .36047 .65726 L F
.38966 .70151 m .36844 .66947 L .36559 .66502 L F
.39663 .70638 m .36844 .66947 L .38966 .70151 L .657 0 0 r
F
.37649 .68106 m .37148 .67423 L .36844 .66947 L 1 .001 .157 r
F
.35632 .65359 m .35488 .65147 L .35616 .65317 L F
.35833 .65623 m .3576 .65507 L .36844 .66947 L F
.37148 .67423 m .35632 .65359 L .36844 .66947 L F
.36844 .66947 m .35732 .65124 L .36047 .65726 L .881 0 .024 r
F
.35732 .65124 m .35396 .64573 L .35623 .64975 L F
.35732 .65124 m .35623 .64975 L .36047 .65726 L F
.38579 .63707 m .36824 .66153 L .36541 .66231 L .299 0 .097 r
F
.35396 .64573 m .35283 .64388 L .3501 .63981 L .881 0 .024 r
F
.34714 .63283 m .34646 .63159 L .34286 .62607 L .789 0 0 r
F
.34499 .62796 m .34339 .62946 L .34336 .62544 L .767 0 .303 r
F
.34339 .62946 m .33092 .64115 L .34192 .62725 L F
.34333 .62699 m .34286 .62607 L .34051 .62106 L .684 0 0 r
F
.33327 .60779 m .3285 .6 L .32862 .59986 L .835 0 .306 r
F
.33339 .60774 m .32862 .59986 L .33755 .58972 L F
.33999 .62004 m .32856 .59752 L .33571 .61332 L .684 0 0 r
F
.33999 .62004 m .34 .62007 L .32317 .5869 L F
.32856 .59752 m .32317 .5869 L .33432 .61038 L F
.32687 .59419 m .332 .60511 L .32317 .5869 L F
.34 .62007 m .332 .60511 L .32687 .59419 L F
.33862 .61789 m .332 .60511 L .33983 .61979 L F
.33999 .62004 m .33931 .62041 L .33777 .61656 L .807 0 .305 r
F
.33862 .61789 m .33983 .61979 L .3405 .62104 L .684 0 0 r
F
.34286 .62607 m .33862 .61789 L .3405 .62104 L F
.34286 .62607 m .3405 .62104 L .34051 .62106 L F
.34339 .62946 m .34192 .62725 L .34286 .62607 L .767 0 .303 r
F
.34337 .62717 m .34286 .62607 L .34336 .62544 L F
.34339 .62946 m .34286 .62607 L .34337 .62717 L F
.34646 .63159 m .33092 .64115 L .34499 .62796 L F
.34012 .61997 m .34263 .62559 L .33999 .62004 L .807 0 .305 r
F
.35331 .61288 m .34263 .62559 L .34012 .61997 L F
.35331 .61288 m .34286 .62607 L .34263 .62559 L F
.34019 .62047 m .332 .60511 L .34 .62007 L .684 0 0 r
F
.3374 .61456 m .33999 .62004 L .33624 .6127 L .807 0 .305 r
F
.34062 .6197 m .33999 .62004 L .3374 .61456 L F
.32856 .59752 m .33432 .61038 L .33571 .61332 L .684 0 0 r
F
.33928 .62042 m .33092 .64115 L .32181 .62981 L .807 0 .305 r
F
.3396 .62093 m .33092 .64115 L .33928 .62042 L F
.33429 .61062 m .33299 .60793 L .33346 .60933 L 0 0 .312 r
F
.33429 .61062 m .33346 .60933 L .33668 .61915 L F
.33331 .60859 m .33484 .6116 L .33299 .60793 L F
.33571 .61332 m .33559 .61307 L .33331 .60859 L F
.33571 .61332 m .32181 .62981 L .33299 .60793 L .835 0 .306 r
F
.33931 .62041 m .32181 .62981 L .33571 .61332 L .807 0 .305 r
F
.33299 .60793 m .32317 .5869 L .31442 .56933 L 0 0 .312 r
F
.33559 .61307 m .32317 .5869 L .33299 .60793 L F
.332 .60511 m .30525 .54548 L .32317 .5869 L 0 0 .265 r
F
.3409 .62431 m .32456 .59 L .32045 .58018 L .738 0 0 r
F
.33768 .61551 m .332 .60511 L .3424 .62519 L .789 0 0 r
F
.34646 .63159 m .33768 .61551 L .34252 .62542 L F
.33768 .61551 m .3424 .62519 L .34252 .62542 L F
.34646 .63159 m .34252 .62542 L .34286 .62607 L F
.34646 .63159 m .34591 .6333 L .34527 .63232 L .767 0 .303 r
F
.34945 .63871 m .34012 .65145 L .34646 .63159 L F
.34724 .63302 m .3409 .62431 L .332 .60511 L .789 0 0 r
F
.33743 .61666 m .33316 .60722 L .332 .60511 L .738 0 0 r
F
.33316 .60722 m .31488 .56686 L .332 .60511 L F
.332 .60511 m .31488 .56686 L .30935 .55459 L 0 0 .265 r
F
.332 .60511 m .30935 .55459 L .31522 .56771 L F
.32688 .59336 m .32045 .58018 L .31488 .56686 L .738 0 0 r
F
.3409 .62431 m .33743 .61666 L .332 .60511 L F
.3409 .62431 m .32045 .58018 L .32688 .59336 L F
.31522 .56771 m .30935 .55459 L .30525 .54548 L 0 0 .265 r
F
.35315 .64188 m .35209 .64267 L .35028 .63757 L .7 0 .295 r
F
.35283 .64388 m .35209 .64267 L .34945 .63871 L .881 0 .024 r
F
.35396 .64573 m .35025 .64004 L .36047 .65726 L F
.35025 .64004 m .3501 .63981 L .35014 .63987 L F
.35025 .64004 m .35014 .63987 L .36047 .65726 L F
.35209 .64267 m .35123 .6433 L .3508 .64074 L .7 0 .295 r
F
.35209 .64267 m .3508 .64074 L .35028 .63757 L F
.35209 .64267 m .34945 .63871 L .34945 .63871 L .881 0 .024 r
F
.35123 .6433 m .34945 .63871 L .34945 .63871 L .7 0 .295 r
F
.3508 .64074 m .34945 .63871 L .35028 .63757 L F
.35283 .64388 m .34945 .63871 L .3501 .63981 L .881 0 .024 r
F
.35123 .6433 m .34945 .63871 L .3508 .64074 L .7 0 .295 r
F
.34945 .63871 m .34945 .63871 L .34724 .63302 L .789 0 0 r
F
.34945 .63871 m .34837 .63614 L .34724 .63302 L F
.34907 .63807 m .34678 .63239 L .34724 .63302 L F
.36135 .62245 m .34945 .63871 L .34646 .63159 L .767 0 .303 r
F
.35191 .64237 m .34907 .63807 L .34945 .63871 L .881 0 .024 r
F
.35209 .64267 m .35191 .64237 L .34945 .63871 L F
.34945 .63871 m .34907 .63807 L .34837 .63614 L .789 0 0 r
F
.34907 .63807 m .3409 .62431 L .34678 .63239 L F
.35191 .64237 m .3409 .62432 L .34907 .63807 L .881 0 .024 r
F
.37383 .73233 m .33552 .64318 L .3684 .72883 L 0 0 .53 r
F
.34527 .63232 m .34012 .65145 L .33092 .64115 L .767 0 .303 r
F
.34591 .6333 m .34012 .65145 L .34527 .63232 L F
.35123 .6433 m .34012 .65145 L .34945 .63871 L .7 0 .295 r
F
.3793 .73532 m .34208 .65182 L .37383 .73233 L 0 0 .539 r
F
.3793 .73532 m .3487 .66014 L .34208 .65182 L F
.35209 .64267 m .34931 .65973 L .34012 .65145 L .7 0 .295 r
F
.35279 .64382 m .35248 .6439 L .35209 .64267 L .881 0 .024 r
F
.36844 .66947 m .35478 .65133 L .35279 .64382 L F
.35488 .65147 m .34931 .65973 L .35209 .64267 L .7 0 .295 r
F
.35478 .65133 m .34972 .64461 L .35279 .64382 L .881 0 .024 r
F
.36938 .62997 m .35488 .65147 L .35209 .64267 L .7 0 .295 r
F
.35209 .64267 m .34972 .64461 L .3409 .62432 L .881 0 .024 r
F
.35248 .6439 m .34972 .64461 L .35209 .64267 L F
.35727 .65483 m .3576 .65507 L .35833 .65623 L 1 .001 .157 r
F
.37649 .68106 m .35862 .66608 L .35791 .66437 L F
.37649 .68106 m .35791 .66437 L .3578 .66383 L F
.37649 .68106 m .35762 .66366 L .35632 .65359 L F
.39041 .73949 m .36213 .67572 L .35538 .66812 L 0 0 .56 r
F
.39603 .74055 m .36213 .67572 L .39041 .73949 L 0 0 .573 r
F
.39603 .74055 m .36894 .68291 L .36213 .67572 L F
.395 .70434 m .37649 .68106 L .3927 .70124 L .657 0 0 r
F
.3927 .70124 m .37649 .68106 L .36844 .66947 L F
.39663 .70638 m .395 .70434 L .3927 .70124 L F
.40366 .71036 m .37649 .68106 L .39663 .70638 L .658 0 0 r
F
.38465 .69127 m .35862 .66608 L .37649 .68106 L 1 .005 .218 r
F
.36766 .68608 m .36485 .68207 L .36056 .6708 L 1 .17 .461 r
F
.36029 .66978 m .36056 .6708 L .35952 .66808 L F
.36766 .68608 m .36056 .6708 L .36029 .66978 L F
.40171 .74085 m .36894 .68291 L .39603 .74055 L 0 0 .587 r
F
.40171 .74085 m .37581 .68966 L .36894 .68291 L F
.37904 .68584 m .36766 .68608 L .35862 .66608 L 1 .005 .218 r
F
.38465 .69127 m .3708 .68704 L .37904 .68584 L F
.3708 .68704 m .36766 .68608 L .37904 .68584 L F
.38483 .73773 m .3487 .66014 L .3793 .73532 L 0 0 .549 r
F
.38483 .73773 m .35538 .66812 L .3487 .66014 L F
.39041 .73949 m .35538 .66812 L .38483 .73773 L 0 0 .56 r
F
.36485 .68207 m .36189 .67784 L .35952 .66808 L 1 .17 .461 r
F
.35745 .73199 m .34933 .83086 L .34478 .77396 L 1 .091 .465 r
F
.36766 .68608 m .35301 .79789 L .36189 .67784 L 1 .17 .461 r
F
.36824 .66153 m .35301 .79789 L .36189 .67784 L 1 .091 .465 r
F
.35301 .79789 m .34933 .83086 L .36189 .67784 L F
.36189 .67784 m .35745 .73199 L .34132 .73069 L F
.35745 .73199 m .34478 .77396 L .34132 .73069 L F
.36189 .67784 m .36115 .67975 L .35966 .67042 L F
.36115 .67975 m .34759 .71459 L .35823 .66586 L F
.34759 .71459 m .34132 .73069 L .34892 .70155 L F
.34759 .71459 m .34892 .70155 L .35823 .66586 L F
.35952 .66808 m .36189 .67784 L .35862 .66608 L 1 .17 .461 r
F
.36189 .67784 m .35826 .66573 L .35862 .66608 L F
.34787 .64425 m .34353 .65161 L .33411 .61633 L 1 .03 .241 r
F
.35472 .65499 m .35654 .66043 L .34931 .65973 L .572 0 .26 r
F
.35654 .66043 m .35762 .66366 L .34931 .65973 L F
.35721 .66049 m .35762 .66366 L .35654 .66043 L F
.3524 .66119 m .33134 .70955 L .34931 .65973 L .917 .012 .409 r
F
.3504 .67626 m .33134 .70955 L .3524 .66119 L F
.35802 .66523 m .35013 .67835 L .35756 .66378 L F
.35013 .67835 m .3504 .67626 L .35762 .66366 L F
.35762 .66366 m .3504 .67626 L .3524 .66119 L F
.36115 .67975 m .35828 .66613 L .35831 .66552 L 1 .091 .465 r
F
.35862 .66608 m .35826 .66573 L .35823 .66529 L 1 .03 .241 r
F
.36115 .67975 m .35831 .66552 L .35937 .66855 L 1 .091 .465 r
F
.35632 .65359 m .35472 .65499 L .35488 .65147 L .572 0 .26 r
F
.35472 .65499 m .34931 .65973 L .35401 .65277 L F
.35472 .65499 m .35401 .65277 L .35488 .65147 L F
.35812 .66507 m .35802 .66523 L .35762 .66366 L .917 .012 .409 r
F
.35802 .66523 m .35756 .66378 L .35762 .66366 L F
.35802 .66485 m .35769 .66418 L .35774 .66402 L 1 .03 .241 r
F
.35769 .66418 m .33411 .61633 L .35744 .66341 L F
.35769 .66418 m .35744 .66341 L .35774 .66402 L F
.34931 .65973 m .32129 .694 L .34012 .65145 L .888 .004 .376 r
F
.34931 .65973 m .33134 .70955 L .32129 .694 L F
.35823 .66529 m .35812 .66507 L .35791 .66437 L 1 .03 .241 r
F
.35812 .66507 m .34132 .73069 L .33134 .70955 L .917 .012 .409 r
F
.35862 .66608 m .35823 .66529 L .35791 .66437 L 1 .03 .241 r
F
.35867 .66416 m .35826 .66573 L .35812 .66507 L .917 .012 .409 r
F
.35826 .66573 m .34132 .73069 L .35812 .66507 L F
.35815 .66522 m .34353 .65161 L .34353 .65161 L 1 .03 .241 r
F
.36189 .67784 m .34353 .65161 L .35815 .66562 L 1 .17 .461 r
F
.35828 .66613 m .35823 .66586 L .35826 .66573 L 1 .091 .465 r
F
.35954 .67 m .35815 .66562 L .35826 .66573 L 1 .17 .461 r
F
.36189 .67784 m .35815 .66562 L .35954 .67 L F
.35013 .67835 m .33134 .70955 L .3504 .67626 L .917 .012 .409 r
F
.34978 .82137 m .34949 .82479 L .34354 .65184 L 1 .17 .461 r
F
.34434 .74644 m .34321 .73052 L .34627 .72756 L .613 .005 .512 r
F
.35762 .66366 m .33411 .61633 L .34972 .64461 L 1 .03 .241 r
F
.35774 .66402 m .33411 .61633 L .35762 .66366 L F
.34538 .60185 m .33642 .61248 L .33401 .60743 L .835 0 .306 r
F
.33484 .6116 m .33559 .61307 L .33299 .60793 L 0 0 .312 r
F
.33042 .60283 m .33075 .60349 L .32862 .59986 L .835 0 .306 r
F
.33299 .60793 m .31442 .56933 L .32825 .60028 L 0 0 .312 r
F
.33299 .60793 m .32181 .62981 L .31281 .61784 L .835 0 .306 r
F
.34972 .64461 m .32456 .59 L .3409 .62432 L .864 0 0 r
F
.34012 .65145 m .31111 .68045 L .33092 .64115 L .874 .001 .353 r
F
.34972 .64461 m .33411 .61633 L .33411 .61633 L .864 0 0 r
F
.33007 .60195 m .33411 .61633 L .32456 .59 L F
.34972 .64461 m .33411 .61633 L .33007 .60195 L F
.33411 .61634 m .32243 .56918 L .33411 .61633 L .285 0 .568 r
F
.34353 .6516 m .33851 .63199 L .33411 .61634 L F
.33851 .63199 m .32243 .56918 L .33411 .61634 L F
.34012 .65145 m .32129 .694 L .31111 .68045 L .874 .001 .353 r
F
.34353 .6516 m .33304 .58776 L .32243 .56918 L .285 0 .568 r
F
.34321 .73052 m .33304 .58776 L .34516 .71583 L .613 .005 .512 r
F
.34321 .73052 m .34516 .71583 L .34627 .72756 L F
.3457 .71175 m .33969 .65811 L .34353 .65161 L F
.34627 .72756 m .34516 .71583 L .3457 .71175 L F
.34516 .71583 m .33969 .65811 L .3457 .71175 L F
.35812 .66507 m .35797 .66465 L .35791 .66437 L 1 .03 .241 r
F
.35802 .66485 m .35774 .66402 L .35791 .66437 L F
.35791 .66437 m .35774 .66402 L .35762 .66366 L F
.3578 .66383 m .35791 .66437 L .35762 .66366 L 1 .001 .157 r
F
.35867 .66416 m .35812 .66507 L .35762 .66366 L .917 .012 .409 r
F
.35812 .66507 m .35802 .66485 L .35797 .66465 L 1 .03 .241 r
F
.35556 .65426 m .35721 .66049 L .35654 .66043 L .572 0 .26 r
F
.35556 .65426 m .35654 .66043 L .35472 .65499 L F
.34353 .65161 m .33304 .58776 L .34353 .6516 L .613 .005 .512 r
F
.33969 .65811 m .33304 .58776 L .34353 .65161 L F
.35823 .66529 m .34353 .65161 L .34787 .64425 L 1 .03 .241 r
F
.35826 .66573 m .34353 .65161 L .35823 .66529 L F
.35828 .66613 m .35826 .66573 L .35831 .66552 L 1 .091 .465 r
F
.35937 .66855 m .35831 .66552 L .35867 .66416 L F
.36189 .67784 m .34978 .82137 L .34353 .65161 L 1 .17 .461 r
F
.34978 .82137 m .34354 .65184 L .34353 .65161 L F
.34961 .82036 m .34434 .74644 L .34627 .72756 L .613 .005 .512 r
F
.35301 .79789 m .34949 .82479 L .36189 .67784 L 1 .17 .461 r
F
.36619 .68558 m .36187 .72157 L .36565 .68416 L 1 .286 .444 r
F
.36187 .72157 m .35637 .76744 L .36163 .71914 L F
.35637 .76744 m .3558 .76991 L .36163 .71914 L F
.35637 .76744 m .34949 .82479 L .3558 .76991 L F
.36187 .72157 m .36163 .71914 L .36565 .68416 L F
.36593 .68775 m .35296 .7309 L .34949 .82479 L F
.36846 .68758 m .34933 .83086 L .36766 .68609 L 1 .285 .437 r
F
.36852 .68768 m .36363 .72415 L .36846 .68758 L F
.36363 .72415 m .34933 .83086 L .36846 .68758 L F
.34747 .63097 m .3471 .6312 L .34365 .62507 L .767 0 .303 r
F
.3471 .6312 m .34336 .62544 L .34365 .62507 L F
.34747 .63097 m .34365 .62507 L .35331 .61288 L F
.34514 .75769 m .34389 .60111 L .33304 .58776 L .613 .005 .512 r
F
.34671 .75449 m .34389 .60111 L .34514 .75769 L F
.34852 .77878 m .34841 .77441 L .34733 .78843 L F
.34841 .77441 m .34389 .60111 L .34713 .77761 L F
.34841 .77441 m .34713 .77761 L .34733 .78843 L F
.34733 .78843 m .34671 .75449 L .34514 .75769 L F
.3471 .6312 m .34646 .63159 L .34499 .62796 L .767 0 .303 r
F
.35295 .73088 m .34389 .60111 L .34961 .82036 L .613 .01 .535 r
F
.3496 .85927 m .34891 .85479 L .34877 .85239 L .281 0 .554 r
F
.34577 .83103 m .33299 .78589 L .33664 .76171 L .139 0 .554 r
F
.34876 .85239 m .34813 .84499 L .33299 .78589 L .958 .103 .549 r
F
.34902 .84251 m .34577 .83103 L .34132 .73071 L .139 0 .554 r
F
.34577 .83103 m .33664 .76171 L .34132 .73071 L F
.34902 .84251 m .34705 .83232 L .34464 .82439 L F
.34577 .83103 m .34464 .82439 L .33299 .78589 L F
.34902 .84251 m .34464 .82439 L .34577 .83103 L F
.34813 .84499 m .34705 .83232 L .33299 .78589 L .958 .103 .549 r
F
.34705 .83232 m .33977 .74735 L .33299 .78589 L F
.34705 .83232 m .33883 .79 L .33299 .78589 L .139 0 .554 r
F
.34876 .85239 m .33299 .78589 L .33761 .86314 L .958 .103 .549 r
F
.33299 .78589 m .32798 .76615 L .34132 .73071 L .139 0 .554 r
F
.34132 .73071 m .3281 .76583 L .31672 .74822 L 1 .015 .354 r
F
.3281 .76583 m .32762 .76557 L .31672 .74822 L F
.32798 .76615 m .32612 .7644 L .31672 .74822 L F
.32129 .694 m .29462 .72025 L .31111 .68045 L .932 .002 .335 r
F
.32129 .694 m .30575 .73304 L .29462 .72025 L F
.33134 .70955 m .30575 .73305 L .32129 .69401 L .987 .007 .346 r
F
.33134 .70955 m .31672 .74822 L .30575 .73305 L F
.34132 .73071 m .31672 .74822 L .33134 .70955 L 1 .015 .354 r
F
.31589 .77393 m .30998 .75271 L .30419 .77937 L .829 .107 .596 r
F
.30998 .75271 m .30926 .75219 L .30925 .75216 L .86 0 .235 r
F
.30998 .75271 m .30925 .75216 L .30575 .73305 L F
.31672 .74822 m .30998 .75271 L .30575 .73305 L F
.30998 .75271 m .30072 .74614 L .30097 .7485 L .829 .107 .596 r
F
.30998 .75271 m .30097 .7485 L .30419 .77937 L F
.30419 .77937 m .29552 .74549 L .29242 .78202 L .779 .086 .594 r
F
.30097 .66797 m .28351 .7091 L .27242 .69897 L .869 0 .32 r
F
.31111 .68045 m .28351 .7091 L .30097 .66797 L .894 .001 .326 r
F
.31111 .68045 m .29462 .72025 L .28351 .7091 L F
.29242 .78202 m .2816 .73673 L .28074 .78295 L .741 .072 .593 r
F
.29552 .74549 m .29504 .74361 L .28829 .74162 L .779 .086 .594 r
F
.29504 .74361 m .28811 .73987 L .28829 .74162 L F
.29552 .74549 m .28829 .74162 L .29242 .78202 L F
.29462 .72025 m .28136 .73575 L .28351 .7091 L .821 0 .281 r
F
.28136 .73575 m .28112 .73561 L .28112 .7356 L F
.28136 .73575 m .28112 .7356 L .28351 .7091 L F
.28136 .73575 m .27565 .73237 L .27573 .73316 L .741 .072 .593 r
F
.28136 .73575 m .27573 .73316 L .28074 .78295 L F
.2816 .73673 m .28135 .73661 L .28074 .78295 L F
.28074 .78295 m .26867 .72954 L .26912 .78279 L .712 .061 .591 r
F
.24606 .78048 m .23242 .71095 L .23461 .77868 L .66 .043 .588 r
F
.23944 .67143 m .2206 .70403 L .22854 .66265 L .783 0 .312 r
F
.2206 .70403 m .22059 .70402 L .22854 .66265 L F
.22058 .70407 m .22047 .704 L .22047 .704 L F
.22058 .70407 m .22047 .704 L .22854 .66265 L F
.22058 .70407 m .21646 .70176 L .21649 .70215 L .651 .04 .586 r
F
.22058 .70407 m .21649 .70215 L .2232 .77659 L F
.23461 .77868 m .22066 .70446 L .2232 .77659 L F
.22066 .70446 m .22058 .70407 L .2206 .70443 L F
.22066 .70446 m .2206 .70443 L .2232 .77659 L F
.23461 .77868 m .22813 .70861 L .22464 .70651 L F
.22066 .70446 m .22464 .70651 L .22058 .70407 L F
.23461 .77868 m .22464 .70651 L .22066 .70446 L F
.23944 .67143 m .22815 .7076 L .22221 .70483 L .783 0 .312 r
F
.2206 .70403 m .22221 .70483 L .22058 .70407 L F
.23944 .67143 m .22221 .70483 L .2206 .70403 L F
.2204 .70439 m .21633 .70217 L .2165 .70162 L F
.22048 .70396 m .2165 .70162 L .22854 .66265 L F
.2204 .70439 m .2165 .70162 L .22048 .70396 L F
.25038 .68034 m .23227 .71021 L .23944 .67143 L .784 0 .307 r
F
.23227 .71021 m .22811 .70774 L .23944 .67143 L F
.25038 .68034 m .23989 .71354 L .2324 .71 L F
.24427 .71708 m .24435 .71647 L .24412 .71636 L .673 .048 .589 r
F
.25756 .7819 m .2517 .72135 L .24427 .71708 L F
.26138 .68946 m .25161 .71991 L .24412 .71636 L .788 0 .302 r
F
.25161 .71991 m .25157 .72001 L .24634 .71745 L F
.25161 .71991 m .24634 .71745 L .24412 .71636 L F
.2517 .72135 m .25165 .72077 L .24427 .71708 L .673 .048 .589 r
F
.26138 .68946 m .24412 .71636 L .25038 .68034 L .788 0 .302 r
F
.24412 .71636 m .2398 .71383 L .25038 .68034 L F
.27242 .69897 m .25618 .72258 L .26138 .68946 L .794 0 .297 r
F
.25618 .72258 m .2561 .72253 L .26138 .68946 L F
.2561 .72253 m .25157 .72001 L .26138 .68946 L F
.25618 .72258 m .25157 .72001 L .25162 .7205 L .689 .053 .59 r
F
.25618 .72258 m .25162 .7205 L .25756 .7819 L F
.26912 .78279 m .25627 .723 L .25756 .7819 L F
.25627 .723 m .25618 .72258 L .25619 .72296 L F
.25627 .723 m .25619 .72296 L .25756 .7819 L F
.26912 .78279 m .2636 .72691 L .26108 .72544 L F
.25627 .723 m .26108 .72544 L .25618 .72258 L F
.26912 .78279 m .26108 .72544 L .25627 .723 L F
.26867 .72954 m .26854 .72897 L .26362 .72705 L .712 .061 .591 r
F
.28351 .7091 m .26854 .72897 L .27242 .69897 L .805 0 .29 r
F
.26854 .72897 m .2654 .72718 L .26448 .72711 L .712 .061 .591 r
F
.26854 .72897 m .26448 .72711 L .26362 .72705 L F
.2636 .72691 m .26353 .72612 L .25618 .72258 L .689 .053 .59 r
F
.27242 .69897 m .26358 .72595 L .25618 .72258 L .794 0 .297 r
F
.26353 .72612 m .26346 .72544 L .26064 .72433 L .689 .053 .59 r
F
.26353 .72612 m .26064 .72433 L .25618 .72258 L F
.26854 .72897 m .26353 .72612 L .26356 .72603 L .805 0 .29 r
F
.26854 .72897 m .26356 .72603 L .27242 .69897 L F
.29089 .65605 m .27242 .69897 L .26138 .68946 L .852 0 .318 r
F
.26854 .72897 m .27209 .69695 L .26014 .69178 L .712 .061 .591 r
F
.28074 .78295 m .27574 .73322 L .27505 .73281 L F
.28074 .78295 m .27505 .73281 L .26867 .72954 L F
.28119 .73596 m .28208 .7557 L .27004 .74899 L .821 0 .281 r
F
.28134 .73578 m .28135 .73604 L .28119 .73596 L F
.28135 .73604 m .28208 .7557 L .28119 .73596 L F
.26867 .72954 m .27505 .73281 L .26854 .72897 L .712 .061 .591 r
F
.26858 .72891 m .26858 .72899 L .26854 .72897 L .805 0 .29 r
F
.28351 .7091 m .27568 .73228 L .26858 .72891 L F
.27568 .73228 m .27567 .73232 L .27452 .73177 L F
.27568 .73228 m .27452 .73177 L .26858 .72891 L F
.27574 .73322 m .27565 .73237 L .26854 .72897 L .712 .061 .591 r
F
.26867 .72954 m .26362 .72705 L .26912 .78279 L F
.27567 .73232 m .27565 .73237 L .26858 .72891 L .805 0 .29 r
F
.27565 .73237 m .27004 .74899 L .26861 .72939 L F
.27565 .73237 m .26861 .72939 L .26858 .72891 L F
.28112 .7356 m .27568 .73228 L .28351 .7091 L .821 0 .281 r
F
.28136 .73575 m .28111 .73467 L .27565 .73237 L .741 .072 .593 r
F
.30097 .66797 m .27242 .69897 L .29089 .65605 L .869 0 .32 r
F
.28111 .73467 m .27209 .69695 L .27565 .73237 L .741 .072 .593 r
F
.27565 .73237 m .27209 .69695 L .26866 .72783 L .712 .061 .591 r
F
.27565 .73237 m .26866 .72783 L .26854 .72897 L F
.28108 .73608 m .27543 .73303 L .27565 .73237 L .821 0 .281 r
F
.27759 .73362 m .27565 .73237 L .27568 .73228 L F
.28108 .73608 m .27565 .73237 L .27759 .73362 L F
.28108 .73608 m .27568 .73228 L .28112 .7356 L F
.28111 .73467 m .28413 .70095 L .27209 .69695 L .741 .072 .593 r
F
.28136 .73575 m .28144 .73482 L .28111 .73467 L F
.28144 .73482 m .28413 .70095 L .28111 .73467 L F
.26818 .7274 m .26346 .72544 L .26362 .72705 L .712 .061 .591 r
F
.26854 .72897 m .2684 .72914 L .26353 .72612 L .805 0 .29 r
F
.2684 .72914 m .25801 .74293 L .26353 .72612 L F
.26854 .72897 m .26818 .7274 L .2654 .72718 L .712 .061 .591 r
F
.26854 .72897 m .2686 .72925 L .2684 .72914 L .805 0 .29 r
F
.26858 .72899 m .2686 .72925 L .26854 .72897 L F
.2684 .72914 m .27004 .74899 L .25801 .74293 L F
.2686 .72925 m .27004 .74899 L .2684 .72914 L F
.25756 .7819 m .24412 .71636 L .24606 .78048 L .673 .048 .589 r
F
.24412 .71636 m .23976 .71395 L .2398 .71383 L .788 0 .302 r
F
.23989 .71354 m .23976 .71395 L .2324 .71 L .784 0 .307 r
F
.24606 .78048 m .23989 .71533 L .23242 .71095 L .66 .043 .588 r
F
.23989 .71533 m .23976 .71395 L .23242 .71095 L F
.23976 .71395 m .23242 .71029 L .2324 .71 L .784 0 .307 r
F
.23976 .71395 m .23645 .67899 L .2325 .71033 L .66 .043 .588 r
F
.23976 .71395 m .2325 .71033 L .23242 .71095 L F
.23976 .71395 m .23245 .71068 L .23242 .71029 L .784 0 .307 r
F
.23976 .71395 m .23404 .73207 L .23245 .71068 L F
.24412 .71636 m .24402 .71586 L .23976 .71395 L .673 .048 .589 r
F
.24402 .71586 m .23645 .67899 L .23976 .71395 L F
.24412 .71636 m .23976 .71395 L .24606 .78048 L F
.24412 .71636 m .23404 .73207 L .23976 .71395 L .788 0 .302 r
F
.25618 .72258 m .25801 .74293 L .24601 .73734 L .794 0 .297 r
F
.26358 .72595 m .25801 .74293 L .25618 .72258 L F
.25606 .72274 m .25157 .72001 L .2561 .72253 L F
.25618 .72258 m .24826 .68573 L .25157 .72001 L .689 .053 .59 r
F
.25618 .72258 m .26346 .72544 L .25605 .72198 L F
.25618 .72258 m .25606 .72274 L .2561 .72253 L .794 0 .297 r
F
.25165 .72077 m .25157 .72001 L .24434 .71649 L .673 .048 .589 r
F
.25165 .72077 m .24434 .71649 L .24427 .71708 L F
.25606 .72274 m .24601 .73734 L .25157 .72001 L .794 0 .297 r
F
.25157 .72001 m .24826 .68573 L .24445 .71568 L .673 .048 .589 r
F
.25157 .72001 m .24445 .71568 L .24434 .71649 L F
.25605 .72198 m .26014 .69178 L .24826 .68573 L .689 .053 .59 r
F
.26346 .72544 m .26014 .69178 L .25605 .72198 L F
.24412 .71636 m .25144 .72045 L .24359 .71719 L .788 0 .302 r
F
.25157 .72001 m .25144 .72045 L .24412 .71636 L F
.24412 .71636 m .24826 .68573 L .23645 .67899 L .673 .048 .589 r
F
.24435 .71647 m .24826 .68573 L .24412 .71636 L F
.23242 .71095 m .23227 .71021 L .22813 .70861 L .66 .043 .588 r
F
.23227 .71021 m .22806 .70788 L .22811 .70774 L .784 0 .307 r
F
.22815 .7076 m .22806 .70788 L .22058 .70407 L .783 0 .312 r
F
.22813 .70861 m .22806 .70788 L .22058 .70407 L .651 .04 .586 r
F
.22806 .70788 m .22472 .6717 L .22067 .70338 L F
.2206 .70403 m .22058 .70407 L .22059 .70402 L .783 0 .312 r
F
.22806 .70788 m .22067 .70338 L .22058 .70407 L .651 .04 .586 r
F
.23227 .71021 m .22806 .70788 L .22813 .70861 L .66 .043 .588 r
F
.23227 .71021 m .23217 .71038 L .22806 .70788 L .784 0 .307 r
F
.23242 .71095 m .22813 .70861 L .23461 .77868 L .66 .043 .588 r
F
.23217 .71038 m .22209 .72701 L .22806 .70788 L .784 0 .307 r
F
.22806 .70788 m .22209 .72701 L .22061 .70449 L .783 0 .312 r
F
.22806 .70788 m .22061 .70449 L .22058 .70407 L F
.23227 .71021 m .23218 .70976 L .22806 .70788 L .66 .043 .588 r
F
.23218 .70976 m .22472 .6717 L .22806 .70788 L F
.23227 .71021 m .23255 .70994 L .23218 .70976 L F
.23242 .71095 m .23249 .71035 L .23227 .71021 L F
.23249 .71035 m .23255 .70994 L .23227 .71021 L F
.23218 .70976 m .23645 .67899 L .22472 .6717 L F
.23255 .70994 m .23645 .67899 L .23218 .70976 L F
.23217 .71038 m .23404 .73207 L .22209 .72701 L .784 0 .307 r
F
.2324 .71 m .23244 .71052 L .23217 .71038 L F
.23244 .71052 m .23404 .73207 L .23217 .71038 L F
.22058 .70407 m .22209 .72701 L .21018 .72208 L .783 0 .312 r
F
.22058 .70407 m .22472 .6717 L .21305 .66398 L .651 .04 .586 r
F
.22058 .70407 m .2204 .70439 L .22047 .704 L .783 0 .312 r
F
.22058 .70407 m .21305 .66398 L .21646 .70176 L .651 .04 .586 r
F
.2204 .70439 m .21018 .72208 L .21633 .70217 L .783 0 .312 r
F
.24359 .71719 m .24601 .73734 L .23404 .73207 L .788 0 .302 r
F
.25144 .72045 m .24601 .73734 L .24359 .71719 L F
.26818 .7274 m .26014 .69178 L .26346 .72544 L .712 .061 .591 r
F
.28136 .73575 m .28137 .73579 L .28134 .73578 L .821 0 .281 r
F
.28137 .73579 m .28208 .7557 L .28134 .73578 L F
.29462 .72025 m .28806 .7388 L .28136 .73575 L F
.30575 .73304 m .29502 .74332 L .29462 .72025 L .841 0 .266 r
F
.29552 .74549 m .30083 .74721 L .29498 .74336 L .779 .086 .594 r
F
.30419 .77937 m .30096 .7485 L .29552 .74549 L F
.30096 .7485 m .30083 .74721 L .29552 .74549 L F
.30933 .75314 m .30604 .7717 L .29414 .76327 L .86 0 .235 r
F
.30955 .75299 m .30951 .75324 L .30933 .75314 L F
.30951 .75324 m .30604 .7717 L .30933 .75314 L F
.30083 .74721 m .30072 .74614 L .29498 .74336 L .779 .086 .594 r
F
.29502 .74332 m .29575 .74373 L .29498 .74336 L .841 0 .266 r
F
.30575 .73304 m .30084 .74583 L .29502 .74332 L F
.30084 .74583 m .30072 .74614 L .29502 .74332 L F
.30072 .74614 m .3006 .74644 L .29857 .74531 L F
.30072 .74614 m .29857 .74531 L .29502 .74332 L F
.30942 .75308 m .30011 .74774 L .30072 .74614 L .86 0 .235 r
F
.30926 .75219 m .30072 .74614 L .30575 .73305 L F
.30942 .75308 m .30072 .74614 L .30926 .75219 L F
.30998 .75271 m .30906 .74938 L .30072 .74614 L .829 .107 .596 r
F
.30906 .74938 m .29626 .70345 L .30072 .74614 L F
.30906 .74938 m .30072 .74614 L .30072 .74614 L F
.30072 .74614 m .30051 .74419 L .29498 .74336 L .779 .086 .594 r
F
.29504 .74361 m .29498 .74336 L .28811 .73987 L F
.29498 .74336 m .28801 .73893 L .28806 .7388 L .841 0 .266 r
F
.29498 .74336 m .28806 .7388 L .29462 .72025 L F
.28806 .7388 m .28805 .73883 L .28689 .73829 L .821 0 .281 r
F
.28806 .7388 m .28689 .73829 L .28136 .73575 L F
.28805 .73883 m .28801 .73893 L .28136 .73575 L F
.29242 .78202 m .28814 .74019 L .2816 .73673 L .741 .072 .593 r
F
.28814 .74019 m .28801 .73893 L .2816 .73673 L F
.28801 .73893 m .28413 .70095 L .28176 .73451 L F
.28801 .73893 m .28176 .73451 L .2816 .73673 L F
.29498 .74336 m .28801 .73893 L .28811 .73987 L .779 .086 .594 r
F
.29498 .74336 m .29468 .74364 L .28801 .73893 L .841 0 .266 r
F
.29468 .74364 m .28208 .7557 L .28801 .73893 L F
.2816 .73673 m .28136 .73575 L .28135 .73661 L .741 .072 .593 r
F
.28801 .73893 m .28208 .7557 L .28138 .7362 L .821 0 .281 r
F
.2816 .73673 m .28166 .73593 L .28136 .73575 L .741 .072 .593 r
F
.28166 .73593 m .28413 .70095 L .28136 .73575 L F
.28801 .73893 m .28138 .7362 L .28136 .73575 L .821 0 .281 r
F
.29498 .74336 m .29453 .7416 L .28801 .73893 L .779 .086 .594 r
F
.29453 .7416 m .28413 .70095 L .28801 .73893 L F
.29498 .74336 m .3006 .74644 L .29483 .7435 L .841 0 .266 r
F
.29575 .74373 m .3006 .74644 L .29498 .74336 L F
.30906 .74938 m .30831 .70405 L .29626 .70345 L .829 .107 .596 r
F
.30984 .75218 m .30976 .74968 L .30906 .74938 L F
.30976 .74968 m .30831 .70405 L .30906 .74938 L F
.30998 .75271 m .30997 .75226 L .30984 .75218 L F
.30997 .75226 m .30831 .70405 L .30984 .75218 L F
.29502 .74332 m .29498 .74336 L .29498 .7433 L .841 0 .266 r
F
.29502 .74332 m .29498 .7433 L .29462 .72025 L F
.29498 .74336 m .30051 .74419 L .29453 .7416 L .779 .086 .594 r
F
.29453 .7416 m .29626 .70345 L .28413 .70095 L F
.30051 .74419 m .29626 .70345 L .29453 .7416 L F
.29468 .74364 m .29414 .76326 L .28208 .7557 L .841 0 .266 r
F
.29483 .7435 m .29482 .74371 L .29468 .74364 L F
.29482 .74371 m .29414 .76326 L .29468 .74364 L F
.3006 .74644 m .29414 .76326 L .29483 .7435 L F
.28136 .73575 m .28108 .73608 L .28112 .73561 L .821 0 .281 r
F
.28108 .73608 m .27004 .74899 L .27543 .73303 L F
.30998 .75271 m .30989 .75317 L .30955 .75299 L .86 0 .235 r
F
.30989 .75317 m .30604 .7717 L .30955 .75299 L F
.31672 .74822 m .31385 .75451 L .30998 .75271 L F
.31589 .77393 m .31391 .75566 L .30998 .75271 L .829 .107 .596 r
F
.31391 .75566 m .3138 .75463 L .30998 .75271 L F
.31385 .75451 m .3138 .75463 L .30998 .75271 L .86 0 .235 r
F
.3138 .75463 m .30831 .70405 L .30998 .75271 L .829 .107 .596 r
F
.3138 .75463 m .30604 .7717 L .30998 .75271 L .86 0 .235 r
F
.30998 .75271 m .30942 .75308 L .30926 .75219 L F
.30942 .75308 m .29414 .76327 L .30011 .74774 L F
.32232 .76158 m .32204 .76135 L .31419 .75827 L .893 .141 .603 r
F
.32642 .76492 m .3138 .75463 L .31672 .74822 L .844 0 .155 r
F
.32768 .76356 m .30831 .70405 L .31391 .75566 L .893 .141 .603 r
F
.32768 .76356 m .31391 .75566 L .31419 .75827 L F
.32642 .76492 m .31419 .75827 L .31589 .77393 L F
.32775 .76379 m .31419 .75827 L .32642 .76492 L F
.3281 .76583 m .32798 .76615 L .32762 .76557 L 1 .015 .354 r
F
.33761 .86314 m .32798 .76615 L .31589 .77393 L .895 .091 .558 r
F
.32798 .76615 m .32642 .76492 L .32612 .7644 L 1 .015 .354 r
F
.32798 .76615 m .32775 .76379 L .32642 .76492 L .895 .091 .558 r
F
.32798 .76615 m .32642 .76492 L .31589 .77393 L F
.32798 .76615 m .32765 .76703 L .32642 .76492 L 1 .015 .354 r
F
.32765 .76703 m .30604 .7717 L .3138 .75463 L .844 0 .155 r
F
.32765 .76703 m .3138 .75463 L .32642 .76492 L F
.32775 .76379 m .32768 .76356 L .32204 .76135 L .893 .141 .603 r
F
.32775 .76379 m .32204 .76135 L .32232 .76158 L F
.33299 .78589 m .3284 .76654 L .32798 .76615 L .958 .103 .549 r
F
.3284 .76654 m .32775 .76379 L .32798 .76615 L F
.33299 .78589 m .32798 .76615 L .33761 .86314 L F
.33299 .78589 m .32795 .76623 L .32798 .76615 L .139 0 .554 r
F
.34891 .85479 m .34013 .79859 L .34776 .84607 L .281 0 .554 r
F
.34013 .79859 m .34016 .79862 L .34776 .84607 L F
.33879 .79 m .33879 .78999 L .34776 .84607 L F
.34961 .82036 m .34852 .77878 L .34733 .78843 L .613 .005 .512 r
F
.35169 .77935 m .33977 .74735 L .34859 .838 L 1 .447 .614 r
F
.34013 .79859 m .33879 .79 L .34016 .79862 L .281 0 .554 r
F
.33883 .79 m .3386 .78884 L .33699 .788 L .139 0 .554 r
F
.33879 .79 m .3386 .78885 L .33879 .78999 L .281 0 .554 r
F
.33883 .79 m .33699 .788 L .33299 .78589 L .139 0 .554 r
F
.36852 .68768 m .35169 .77928 L .34933 .83086 L 1 .285 .437 r
F
.35169 .77935 m .34859 .838 L .34951 .83102 L 1 .447 .614 r
F
.34106 .79637 m .34695 .80407 L .33964 .79088 L .218 0 .569 r
F
.35685 .85698 m .34695 .80407 L .34106 .79637 L F
.34695 .80407 m .34695 .80407 L .34106 .79637 L F
.36786 .85346 m .35829 .81826 L .34696 .80408 L .224 0 .626 r
F
.35829 .81826 m .35587 .81574 L .34696 .80408 L .014 0 .75 r
F
.34891 .85479 m .34776 .84607 L .34877 .85239 L .281 0 .554 r
F
.3496 .85927 m .34084 .79917 L .34013 .79859 L F
.34951 .83102 m .34859 .838 L .34903 .84251 L 1 .447 .614 r
F
.35685 .85698 m .33964 .79088 L .34961 .85927 L .218 0 .569 r
F
.36786 .85346 m .34696 .80408 L .35685 .85698 L .224 0 .626 r
F
.35587 .81574 m .33898 .79813 L .34696 .80408 L .014 0 .75 r
F
.35587 .81574 m .34696 .80408 L .34696 .80408 L F
.34695 .80407 m .34666 .80385 L .33964 .79088 L .458 0 0 r
F
.34013 .79859 m .33963 .79088 L .33863 .78903 L .281 0 .554 r
F
.34084 .79917 m .33963 .79087 L .34013 .79859 L F
.34666 .80385 m .33104 .79185 L .33964 .79088 L .458 0 0 r
F
.34666 .80385 m .33964 .79088 L .33964 .79088 L F
.33863 .78903 m .33963 .79087 L .3386 .78885 L .281 0 .554 r
F
.33963 .79088 m .33963 .79087 L .33863 .78903 L F
.34675 .80392 m .33897 .79813 L .33736 .79685 L .458 0 0 r
F
.34695 .80407 m .34678 .80394 L .34675 .80392 L F
.34678 .80394 m .33897 .79813 L .34675 .80392 L F
.33844 .79753 m .33736 .79685 L .33104 .79185 L F
.34695 .80407 m .33736 .79685 L .33844 .79753 L F
.33861 .79088 m .33104 .79185 L .32992 .79093 L .687 0 0 r
F
.33963 .79087 m .33859 .79099 L .33861 .79088 L F
.33859 .79099 m .33104 .79185 L .33861 .79088 L F
.33963 .79087 m .33963 .79087 L .3386 .78885 L F
.33963 .79087 m .32992 .79093 L .3386 .78885 L F
.33963 .79087 m .3386 .78885 L .3386 .78885 L F
.33299 .78589 m .32765 .76703 L .32795 .76623 L .139 0 .554 r
F
.33299 .78589 m .33977 .74735 L .32775 .76379 L .958 .103 .549 r
F
.33299 .78589 m .3386 .78884 L .32765 .76703 L .139 0 .554 r
F
.34916 .77254 m .3409 .74555 L .33977 .74735 L 1 .447 .614 r
F
.35169 .77935 m .34936 .77204 L .34916 .77254 L F
.34936 .77204 m .3409 .74555 L .34916 .77254 L F
.35314 .74136 m .34887 .73248 L .3409 .74554 L 1 .842 .659 r
F
.36342 .73708 m .36045 .74775 L .36202 .72305 L 1 .11 .41 r
F
.36045 .74775 m .3517 .77924 L .35657 .75269 L F
.36045 .74775 m .35657 .75269 L .36202 .72305 L F
.35979 .73909 m .35552 .7365 L .35314 .74136 L 1 .842 .659 r
F
.35552 .7365 m .34887 .73248 L .35314 .74136 L F
.36342 .73708 m .35979 .73908 L .3517 .77924 L 1 .11 .41 r
F
.35979 .73909 m .35314 .74136 L .35169 .77931 L 1 .842 .659 r
F
.35314 .74136 m .3409 .74554 L .34936 .772 L F
.35314 .74136 m .34936 .772 L .35169 .77931 L F
.37463 .69677 m .36342 .73708 L .36494 .70718 L 1 .11 .41 r
F
.37463 .69677 m .36916 .71237 L .36342 .73708 L F
.36342 .73708 m .36202 .72305 L .36494 .70718 L F
.36916 .71237 m .36055 .73692 L .36342 .73708 L F
.36055 .73692 m .35979 .73908 L .36081 .73852 L F
.36055 .73692 m .36081 .73852 L .36342 .73708 L F
.40743 .74042 m .37581 .68966 L .40171 .74085 L 0 0 .605 r
F
.38413 .70338 m .3598 .73907 L .37463 .69677 L .877 .032 .531 r
F
.37098 .71892 m .36087 .7147 L .35768 .71942 L 1 .873 .679 r
F
.36283 .6882 m .35296 .7309 L .36593 .68775 L 1 .286 .444 r
F
.36915 .66084 m .36781 .66667 L .36825 .66152 L F
.36619 .68558 m .36565 .68416 L .36825 .66152 L F
.36915 .66084 m .36283 .6882 L .36593 .68775 L F
.36533 .68904 m .35296 .73084 L .3639 .68356 L 1 .389 .482 r
F
.37559 .65434 m .36533 .68904 L .36915 .66084 L F
.36533 .68904 m .3639 .68356 L .36915 .66084 L F
.36824 .66153 m .36189 .67784 L .35867 .66416 L 1 .091 .465 r
F
.36189 .67784 m .35966 .67042 L .35867 .66416 L F
.38657 .63711 m .36915 .66084 L .36825 .66152 L 0 0 0 r
F
.39209 .6366 m .36915 .66084 L .38657 .63711 L F
.38567 .64338 m .37559 .65434 L .36915 .66084 L F
.37559 .65434 m .36156 .66841 L .36136 .66983 L 1 .389 .482 r
F
.37559 .65434 m .36136 .66983 L .35296 .73084 L F
.41043 .62894 m .38657 .63711 L .4058 .62756 L .127 0 0 r
F
.41043 .62894 m .39209 .6366 L .38657 .63711 L F
.44852 .63817 m .42614 .628 L .42058 .62382 L .497 0 0 r
F
.44891 .63824 m .42614 .628 L .44852 .63817 L .368 0 0 r
F
.44891 .63824 m .42667 .62829 L .42614 .628 L F
.46152 .65264 m .43226 .61534 L .42832 .60333 L .926 0 .077 r
F
.45168 .63831 m .42667 .62829 L .44891 .63824 L .275 0 0 r
F
.45168 .63831 m .43038 .62983 L .42667 .62829 L F
.46152 .65264 m .42832 .60333 L .45903 .63833 L .926 0 .077 r
F
.4559 .6372 m .43038 .62983 L .45168 .63831 L 0 0 .738 r
F
.43624 .63152 m .43606 .63062 L .43038 .62983 L F
.4559 .6372 m .43606 .63062 L .43624 .63152 L F
.44029 .63202 m .40968 .60942 L .43627 .62507 L .741 0 0 r
F
.44029 .63202 m .41509 .61761 L .40968 .60942 L F
.44179 .62978 m .43585 .62966 L .43606 .63062 L .303 .003 .851 r
F
.43606 .63062 m .41953 .62934 L .43038 .62983 L 0 0 .652 r
F
.43606 .63062 m .41043 .62894 L .41953 .62934 L F
.43038 .62983 m .4058 .62756 L .42667 .62829 L .299 0 0 r
F
.43038 .62983 m .41043 .62894 L .4058 .62756 L F
.43585 .62966 m .4175 .6293 L .43606 .63062 L .303 .003 .851 r
F
.41629 .62932 m .4175 .6293 L .41043 .62894 L 0 0 .652 r
F
.43606 .63062 m .4175 .6293 L .41629 .62932 L F
.42614 .628 m .40515 .62729 L .39821 .6232 L .496 0 0 r
F
.42667 .62829 m .40515 .62729 L .42614 .628 L .394 0 0 r
F
.42667 .62829 m .4058 .62756 L .40515 .62729 L F
.44179 .62978 m .42464 .62787 L .4175 .6293 L .303 .003 .851 r
F
.42464 .62787 m .4188 .62928 L .4175 .6293 L .612 .243 .865 r
F
.4175 .6293 m .39209 .6366 L .39918 .63363 L .293 0 .683 r
F
.4175 .6293 m .39918 .63363 L .41043 .62894 L F
.3985 .63476 m .40052 .6337 L .39209 .6366 L F
.4175 .6293 m .40052 .6337 L .3985 .63476 L F
.4188 .62928 m .40052 .6337 L .4175 .6293 L .612 .243 .865 r
F
.42464 .62787 m .40902 .62912 L .40052 .6337 L F
.40902 .62912 m .40269 .63257 L .40052 .6337 L 1 .963 .765 r
F
.40052 .6337 m .3756 .65434 L .39209 .6366 L .986 .45 .715 r
F
.38886 .64001 m .37653 .65333 L .38567 .64338 L 0 0 0 r
F
.37653 .65333 m .37559 .65434 L .37643 .65344 L F
.37653 .65333 m .37643 .65344 L .38567 .64338 L F
.38896 .63996 m .37559 .65434 L .38886 .64001 L F
.37878 .6517 m .38542 .64198 L .3756 .65434 L .986 .45 .715 r
F
.40052 .6337 m .38542 .64198 L .37878 .6517 L F
.39029 .63932 m .38542 .64198 L .39006 .63943 L 1 .963 .765 r
F
.39029 .63932 m .39006 .63943 L .40052 .6337 L F
.39209 .6366 m .38896 .63996 L .38886 .64001 L 0 0 0 r
F
.40515 .62729 m .38579 .63707 L .37753 .63501 L .409 0 0 r
F
.4058 .62756 m .38579 .63707 L .40515 .62729 L .275 0 0 r
F
.4058 .62756 m .38657 .63711 L .38579 .63707 L F
.39029 .63932 m .39523 .63058 L .38542 .64198 L 1 .963 .765 r
F
.40269 .63257 m .39029 .63932 L .40052 .6337 L F
.40902 .62912 m .3993 .63015 L .39029 .63932 L F
.3993 .63015 m .39523 .63058 L .39029 .63932 L F
.35295 .73088 m .34492 .60192 L .34389 .60111 L .613 .01 .535 r
F
.35727 .65483 m .35616 .65317 L .3576 .65507 L 1 .001 .157 r
F
.35632 .65359 m .35616 .65317 L .35727 .65483 L F
.35823 .65192 m .35811 .6639 L .35556 .65426 L .572 0 .26 r
F
.35632 .65359 m .35762 .66366 L .34972 .64461 L 1 .001 .157 r
F
.35721 .66049 m .35811 .6639 L .35762 .66366 L .572 0 .26 r
F
.35823 .65192 m .35867 .66416 L .35811 .6639 L F
.36249 .65825 m .35867 .66416 L .35823 .65192 L F
.36154 .66129 m .36267 .66306 L .35867 .66416 L .299 0 .097 r
F
.36154 .66129 m .35867 .66416 L .36103 .66051 L F
.35922 .65105 m .35632 .65359 L .35717 .64807 L .572 0 .26 r
F
.35632 .65359 m .35488 .65147 L .35717 .64807 L F
.35632 .65359 m .34972 .64461 L .35488 .65147 L 1 .001 .157 r
F
.35315 .64188 m .35028 .63757 L .35073 .63695 L .7 0 .295 r
F
.35375 .64145 m .35073 .63695 L .36135 .62245 L F
.36156 .6684 m .34493 .60192 L .35296 .73082 L .609 .029 .587 r
F
.35882 .72638 m .35768 .71942 L .34887 .73248 L 1 .873 .679 r
F
.37098 .71892 m .35768 .71942 L .35882 .72638 L F
.37011 .69004 m .36494 .70718 L .36852 .68768 L 1 .11 .41 r
F
.37463 .69677 m .36494 .70718 L .37011 .69004 L F
.37753 .63501 m .36249 .65825 L .35823 .65192 L .572 0 .26 r
F
.36447 .66103 m .36541 .66231 L .36267 .66306 L .299 0 .097 r
F
.38579 .63707 m .36541 .66231 L .36447 .66103 L F
.38579 .63707 m .36267 .66306 L .36154 .66129 L F
.38579 .63707 m .36154 .66129 L .37753 .63501 L F
.36154 .66129 m .36103 .66051 L .37753 .63501 L F
.35922 .65105 m .35717 .64807 L .36938 .62997 L .572 0 .26 r
F
.32397 .59201 m .3243 .59302 L .32081 .5867 L .855 0 .307 r
F
.3243 .59302 m .3222 .58954 L .32081 .5867 L F
.32566 .59526 m .32513 .59551 L .32397 .59201 L F
.3187 .58181 m .32061 .58691 L .3181 .58209 L .87 0 .309 r
F
.32107 .58641 m .32061 .58691 L .3187 .58181 L F
.32513 .59551 m .32061 .58691 L .32081 .5867 L .855 0 .307 r
F
.32566 .59526 m .30575 .55213 L .32061 .58691 L 0 0 .354 r
F
.3243 .59302 m .32513 .59551 L .3222 .58954 L .855 0 .307 r
F
.32566 .59526 m .31442 .56933 L .30575 .55213 L 0 0 .354 r
F
.32575 .59543 m .31442 .56933 L .32566 .59526 L F
.31822 .58235 m .31815 .58217 L .3181 .58209 L 0 0 .378 r
F
.31874 .58353 m .31822 .58235 L .31837 .58291 L F
.31874 .58353 m .31837 .58291 L .32121 .59338 L F
.32061 .58691 m .30389 .6054 L .3181 .58209 L .87 0 .309 r
F
.31815 .58217 m .31815 .58217 L .3181 .58209 L 0 0 .378 r
F
.31815 .58217 m .30575 .55213 L .3181 .58209 L F
.32061 .58691 m .30575 .55213 L .31822 .58235 L F
.32513 .59551 m .30389 .6054 L .32061 .58691 L .855 0 .307 r
F
.30889 .5655 m .30914 .56622 L .30525 .55903 L .882 0 .312 r
F
.30914 .56622 m .30662 .56184 L .30525 .55903 L F
.31053 .56842 m .31042 .56846 L .30889 .5655 L F
.31042 .56846 m .30998 .56866 L .30889 .5655 L F
.30543 .55883 m .30511 .55918 L .30308 .55427 L .893 0 .315 r
F
.30998 .56866 m .30511 .55918 L .30525 .55903 L .882 0 .312 r
F
.31042 .56846 m .28866 .51817 L .30511 .55918 L 0 0 .391 r
F
.30914 .56622 m .30998 .56866 L .30662 .56184 L .882 0 .312 r
F
.31042 .56846 m .29716 .53511 L .28866 .51817 L 0 0 .391 r
F
.30308 .55427 m .30511 .55918 L .30268 .55445 L .893 0 .315 r
F
.30301 .55523 m .30274 .55461 L .30282 .55491 L 0 0 .397 r
F
.30301 .55523 m .30282 .55491 L .30604 .56711 L F
.30274 .55461 m .30271 .55453 L .30272 .55457 L F
.30274 .55461 m .30272 .55457 L .30604 .56711 L F
.30271 .55453 m .30268 .55445 L .30269 .55449 L F
.30271 .55453 m .30269 .55449 L .30604 .56711 L F
.30511 .55918 m .28633 .57948 L .30268 .55445 L .893 0 .315 r
F
.30269 .55447 m .28866 .51817 L .30268 .55445 L 0 0 .397 r
F
.30511 .55918 m .28866 .51817 L .30271 .55453 L F
.30998 .56866 m .28633 .57948 L .30511 .55918 L .882 0 .312 r
F
.30268 .55445 m .28024 .50123 L .29733 .54487 L 0 0 .397 r
F
.30268 .55445 m .27768 .5661 L .29733 .54487 L .893 0 .315 r
F
.55778 .61586 m .5236 .66565 L .52403 .65336 L .257 0 .229 r
F
.55593 .62746 m .5236 .66565 L .55778 .61586 L .21 0 .204 r
F
.58774 .59498 m .55593 .62746 L .55778 .61586 L .263 0 .184 r
F
.67469 .57253 m .65321 .55321 L .68165 .55525 L .487 0 .288 r
F
.67469 .57253 m .64745 .56989 L .65321 .55321 L F
.74218 .53925 m .7316 .51625 L .74735 .5303 L .526 0 .308 r
F
.74788 .51694 m .74218 .53925 L .75677 .50124 L 1 .266 .536 r
F
.74209 .53958 m .74196 .5401 L .74717 .53085 L F
.74196 .5401 m .73367 .57249 L .74692 .53162 L F
.74196 .5401 m .74692 .53162 L .74717 .53085 L F
.72559 .58517 m .70687 .65379 L .73367 .57249 L 1 .386 .552 r
F
.74209 .53958 m .72559 .58517 L .73367 .57249 L 1 .266 .536 r
F
.74218 .53925 m .72374 .5328 L .7316 .51625 L .526 0 .308 r
F
.74218 .53925 m .73853 .54556 L .74209 .53958 L 1 .266 .536 r
F
.73853 .54556 m .72559 .58517 L .74209 .53958 L F
.74218 .53925 m .74209 .53958 L .74735 .5303 L F
.74209 .53958 m .74717 .53085 L .74735 .5303 L F
.74939 .55493 m .73853 .54556 L .74218 .53925 L .526 0 .308 r
F
.73853 .54556 m .72374 .5328 L .74218 .53925 L F
.74788 .51694 m .73853 .54556 L .74218 .53925 L 1 .266 .536 r
F
.73338 .5542 m .72374 .5328 L .73853 .54556 L .517 0 .302 r
F
.7389 .53229 m .73338 .5542 L .74788 .51694 L 1 .294 .543 r
F
.73338 .5542 m .72559 .58517 L .73853 .54556 L F
.73338 .5542 m .73853 .54556 L .74788 .51694 L F
.73338 .55421 m .73338 .5542 L .73853 .54556 L .517 0 .302 r
F
.73347 .5544 m .73338 .55421 L .73859 .54561 L F
.73338 .55421 m .73853 .54556 L .73859 .54561 L F
.73315 .55511 m .71743 .59762 L .72559 .58517 L 1 .294 .543 r
F
.73299 .55537 m .71743 .59762 L .73315 .55511 L F
.72956 .56068 m .71743 .59762 L .73329 .55457 L F
.72559 .58517 m .69971 .66285 L .70687 .65379 L 1 .386 .552 r
F
.71743 .59762 m .69971 .66285 L .72559 .58517 L 1 .397 .555 r
F
.72447 .56896 m .71578 .54928 L .72956 .56068 L .507 0 .297 r
F
.73329 .55457 m .73299 .55537 L .73315 .55511 L 1 .294 .543 r
F
.73338 .5542 m .71578 .54928 L .72374 .5328 L .517 0 .302 r
F
.73338 .5542 m .72956 .56068 L .73329 .55457 L 1 .294 .543 r
F
.74032 .56958 m .72956 .56068 L .73338 .5542 L .517 0 .302 r
F
.72956 .56068 m .71578 .54928 L .73338 .5542 L F
.7389 .53229 m .72956 .56068 L .73338 .5542 L 1 .294 .543 r
F
.72981 .54723 m .72447 .56896 L .7389 .53229 L 1 .326 .55 r
F
.72447 .56896 m .71743 .59762 L .72956 .56068 L F
.72447 .56896 m .72956 .56068 L .7389 .53229 L F
.72449 .56901 m .72447 .56896 L .72956 .56068 L .507 0 .297 r
F
.72422 .56996 m .70918 .60982 L .71743 .59762 L 1 .326 .55 r
F
.72403 .57026 m .70918 .60982 L .72422 .56996 L F
.72043 .57569 m .70918 .60982 L .72437 .56937 L F
.71743 .59762 m .69248 .67183 L .69971 .66285 L 1 .397 .555 r
F
.70918 .60982 m .69248 .67183 L .71743 .59762 L 1 .404 .557 r
F
.71543 .58354 m .70774 .56573 L .72041 .57568 L .493 0 .291 r
F
.71543 .58354 m .72041 .57568 L .72043 .57569 L F
.71515 .58469 m .70085 .62175 L .70918 .60982 L 1 .363 .557 r
F
.71475 .58533 m .70085 .62175 L .71515 .58469 L F
.71109 .59063 m .70085 .62175 L .71515 .58427 L F
.71109 .59063 m .71515 .58427 L .71543 .58354 L F
.71543 .58354 m .71475 .58533 L .71515 .58469 L F
.71543 .58354 m .70918 .60982 L .72043 .57569 L F
.71549 .58369 m .69962 .58224 L .70774 .56573 L .493 0 .291 r
F
.72191 .59855 m .71109 .59063 L .71549 .58369 L F
.71109 .59063 m .69962 .58224 L .71549 .58369 L F
.70625 .59794 m .70613 .59846 L .70647 .59762 L 1 .409 .564 r
F
.70625 .59794 m .69962 .58224 L .71102 .59058 L .476 0 .284 r
F
.70625 .59794 m .71102 .59058 L .71109 .59063 L F
.70592 .5994 m .69244 .63339 L .70085 .62175 L 1 .409 .564 r
F
.70533 .6003 m .69244 .63339 L .70592 .5994 L F
.70152 .6056 m .69244 .63339 L .70588 .59889 L F
.70152 .6056 m .70588 .59889 L .70625 .59794 L F
.70625 .59794 m .70533 .6003 L .70592 .5994 L F
.70613 .59846 m .71109 .59063 L .71134 .58988 L F
.72437 .56937 m .72403 .57026 L .72422 .56996 L 1 .326 .55 r
F
.72447 .56896 m .70774 .56573 L .71578 .54928 L .507 0 .297 r
F
.72447 .56896 m .72043 .57569 L .72437 .56937 L 1 .326 .55 r
F
.73115 .58411 m .72043 .57569 L .72447 .56896 L .507 0 .297 r
F
.72043 .57569 m .70774 .56573 L .72447 .56896 L F
.72981 .54723 m .72043 .57569 L .72447 .56896 L 1 .326 .55 r
F
.70648 .59758 m .71134 .58988 L .72062 .56168 L 1 .409 .564 r
F
.70613 .59846 m .71134 .58988 L .70648 .59758 L F
.70625 .59794 m .69142 .59891 L .69962 .58224 L .476 0 .284 r
F
.70613 .59846 m .70085 .62175 L .71109 .59063 L 1 .409 .564 r
F
.70918 .60982 m .6852 .68076 L .69248 .67183 L 1 .404 .557 r
F
.70085 .62175 m .6852 .68076 L .70918 .60982 L 1 .409 .558 r
F
.70145 .60555 m .69142 .59891 L .70625 .59794 L .476 0 .284 r
F
.69693 .61223 m .69681 .61278 L .69716 .6119 L 1 .464 .571 r
F
.69693 .61223 m .69142 .59891 L .70139 .60551 L .453 0 .277 r
F
.69693 .61223 m .70139 .60551 L .70152 .6056 L F
.69693 .61223 m .68395 .64465 L .69244 .63339 L 1 .464 .571 r
F
.69693 .61223 m .68313 .61595 L .69142 .59891 L .453 0 .277 r
F
.69162 .62075 m .68395 .64465 L .69638 .6136 L 1 .464 .571 r
F
.69162 .62075 m .69638 .6136 L .69693 .61223 L F
.68745 .62648 m .68313 .61595 L .69143 .62064 L .42 0 .267 r
F
.68745 .62648 m .69143 .62064 L .69162 .62075 L F
.68721 .62774 m .67536 .65539 L .68395 .64465 L 1 .532 .579 r
F
.68648 .6288 m .67536 .65539 L .68721 .62774 L F
.68129 .6364 m .67478 .63365 L .68745 .62648 L .42 0 .267 r
F
.68179 .6348 m .68129 .6364 L .68745 .62648 L 1 .532 .579 r
F
.68129 .6364 m .67536 .65539 L .68745 .62648 L F
.68745 .62648 m .67478 .63365 L .68313 .61595 L .42 0 .267 r
F
.68745 .62648 m .68648 .6288 L .68721 .62774 L 1 .532 .579 r
F
.68745 .62648 m .68395 .64465 L .69162 .62075 L F
.69244 .63339 m .67786 .68971 L .70085 .62175 L 1 .407 .556 r
F
.69244 .63339 m .67046 .69881 L .67786 .68971 L F
.68395 .64465 m .67046 .69881 L .69244 .63339 L 1 .397 .552 r
F
.69365 .64161 m .68129 .6364 L .68745 .62648 L .42 0 .267 r
F
.68395 .64465 m .663 .70824 L .67046 .69881 L 1 .397 .552 r
F
.67536 .65539 m .663 .70824 L .68395 .64465 L 1 .373 .541 r
F
.67786 .64086 m .67478 .63365 L .68107 .63631 L .37 0 .252 r
F
.67786 .64086 m .68107 .63631 L .68129 .6364 L F
.67747 .64312 m .66681 .6651 L .67536 .6554 L 1 .609 .587 r
F
.67569 .64561 m .66681 .6651 L .67747 .64312 L F
.67044 .65298 m .66648 .65219 L .67786 .64086 L .37 0 .252 r
F
.67128 .65018 m .67044 .65298 L .67786 .64086 L 1 .609 .587 r
F
.67044 .65298 m .66681 .6651 L .67786 .64086 L F
.67786 .64086 m .66648 .65219 L .67478 .63365 L .37 0 .252 r
F
.67786 .64086 m .67569 .64561 L .67747 .64312 L 1 .609 .587 r
F
.67786 .64086 m .67536 .6554 L .68129 .6364 L F
.6842 .65572 m .67044 .65298 L .67786 .64086 L .37 0 .252 r
F
.67536 .65539 m .6555 .71833 L .663 .70824 L 1 .373 .541 r
F
.66681 .6651 m .6555 .71834 L .67536 .6554 L 1 .33 .522 r
F
.66816 .65576 m .66648 .65219 L .67028 .65294 L .281 0 .225 r
F
.66816 .65576 m .67028 .65294 L .67044 .65298 L F
.66748 .6605 m .65815 .67296 L .66681 .6651 L 1 .683 .598 r
F
.6592 .67116 m .65815 .67296 L .66748 .6605 L F
.65813 .67228 m .64625 .64676 L .66648 .65219 L .421 0 .315 r
F
.66816 .65576 m .65813 .67228 L .66648 .65219 L .281 0 .225 r
F
.65839 .67219 m .65813 .67228 L .66816 .65576 L F
.65835 .67225 m .65835 .67225 L .65839 .67219 L F
.65835 .67225 m .65813 .67228 L .65839 .67219 L F
.67478 .63365 m .65337 .62657 L .66054 .60784 L .473 0 .297 r
F
.66648 .65219 m .65337 .62657 L .67478 .63365 L .457 0 .304 r
F
.66648 .65219 m .64625 .64676 L .65337 .62657 L F
.65813 .67228 m .63912 .67075 L .64625 .64676 L .421 0 .315 r
F
.65781 .6731 m .63912 .67075 L .65813 .67228 L .314 0 .327 r
F
.64768 .68929 m .64722 .69282 L .65781 .6731 L 1 .114 .414 r
F
.64722 .69282 m .6472 .69298 L .65772 .67349 L F
.6472 .69298 m .64063 .74355 L .65719 .67567 L F
.6472 .69298 m .65719 .67567 L .65772 .67349 L F
.63731 .8092 m .60331 .74017 L .64213 .80569 L 1 .007 .251 r
F
.63731 .8092 m .60001 .74793 L .60331 .74017 L F
.63244 .81239 m .60001 .74793 L .63731 .8092 L 1 .005 .243 r
F
.63244 .81239 m .59668 .75544 L .60001 .74793 L F
.62753 .81516 m .59668 .75544 L .63244 .81239 L 1 .003 .232 r
F
.63435 .76352 m .6266 .7835 L .62656 .78829 L .898 .006 .425 r
F
.63674 .75591 m .63172 .76817 L .63435 .76352 L F
.64063 .74356 m .63653 .75487 L .63674 .75591 L F
.63653 .75487 m .63172 .76817 L .63674 .75591 L F
.63172 .76817 m .62029 .79977 L .63435 .76352 L F
.63326 .76526 m .63326 .76526 L .64063 .74356 L .7 0 .261 r
F
.63259 .76831 m .63259 .76831 L .63326 .76527 L 0 0 0 r
F
.63326 .76526 m .63168 .76947 L .63653 .75487 L .7 0 .261 r
F
.63168 .76947 m .62029 .79977 L .62764 .77946 L F
.63168 .76947 m .62764 .77946 L .63653 .75487 L F
.62753 .81516 m .59331 .7626 L .59668 .75544 L 1 .003 .232 r
F
.62258 .81736 m .59331 .7626 L .62753 .81516 L 1 .001 .217 r
F
.62258 .81736 m .58991 .76926 L .59331 .7626 L F
.61758 .81881 m .58991 .76926 L .62258 .81736 L 1 0 .196 r
F
.61758 .81881 m .58647 .77523 L .58991 .76926 L F
.61253 .81922 m .58647 .77523 L .61758 .81881 L .973 0 .162 r
F
.61253 .81922 m .58298 .78023 L .58647 .77523 L F
.60743 .81826 m .58298 .78023 L .61253 .81922 L .906 0 .106 r
F
.63784 .83581 m .60613 .93281 L .64277 .83637 L 1 .673 .593 r
F
.63784 .83581 m .60252 .92631 L .60613 .93281 L F
.63288 .8352 m .60252 .92631 L .63784 .83581 L 1 .687 .598 r
F
.63288 .8352 m .5989 .91962 L .60252 .92631 L F
.62789 .8346 m .5989 .91962 L .63288 .8352 L 1 .703 .604 r
F
.62569 .82573 m .61783 .83383 L .62287 .8341 L 1 .633 .599 r
F
.62546 .82571 m .61783 .83383 L .62569 .82573 L F
.6361 .82048 m .62753 .81516 L .63244 .81239 L 1 .002 .195 r
F
.63661 .82161 m .63545 .82079 L .6361 .82048 L F
.63545 .82079 m .62753 .81516 L .6361 .82048 L F
.63617 .8218 m .62753 .81516 L .63661 .82161 L F
.63217 .82352 m .62789 .8346 L .63629 .82332 L 1 .631 .591 r
F
.63217 .82352 m .63629 .82332 L .63697 .82241 L F
.63692 .82256 m .62789 .8346 L .63288 .8352 L F
.63697 .82241 m .63685 .82257 L .63692 .82256 L F
.63685 .82257 m .62789 .8346 L .63692 .82256 L F
.63034 .82128 m .62258 .81736 L .62753 .81516 L 1 .001 .177 r
F
.63102 .82276 m .62942 .82173 L .63034 .82128 L F
.62942 .82173 m .62258 .81736 L .63034 .82128 L F
.63054 .82296 m .62258 .81736 L .63102 .82276 L F
.62658 .82442 m .62258 .81736 L .63054 .82296 L F
.6274 .82427 m .63054 .82296 L .63139 .82355 L F
.62658 .82442 m .63054 .82296 L .6274 .82427 L F
.62582 .82532 m .6265 .825 L .62667 .82458 L 1 .633 .599 r
F
.63145 .82369 m .62658 .82442 L .63139 .82355 L 1 .001 .177 r
F
.63145 .82369 m .6314 .82385 L .63147 .82369 L 1 .635 .595 r
F
.6314 .82385 m .62789 .8346 L .63217 .82352 L F
.63139 .82355 m .63102 .82276 L .63217 .82352 L 1 .001 .177 r
F
.63102 .82276 m .62753 .81516 L .63165 .82258 L F
.63102 .82276 m .63165 .82258 L .63217 .82352 L F
.62603 .82472 m .62549 .82358 L .62667 .82458 L 1 0 .152 r
F
.62549 .82358 m .62258 .81736 L .62601 .82342 L F
.62549 .82358 m .62601 .82342 L .62667 .82458 L F
.62068 .82526 m .62006 .82398 L .62134 .82532 L .967 0 .116 r
F
.62006 .82398 m .61758 .81881 L .62048 .82383 L F
.62006 .82398 m .62048 .82383 L .62134 .82532 L F
.62608 .8247 m .62692 .82394 L .62631 .82411 L 1 .633 .599 r
F
.62601 .82485 m .62621 .82465 L .62608 .8247 L F
.62621 .82465 m .62692 .82394 L .62608 .8247 L F
.62052 .82615 m .62113 .82584 L .62134 .82532 L 1 .616 .603 r
F
.62549 .82358 m .61758 .81881 L .62258 .81736 L 1 0 .152 r
F
.62481 .82387 m .61758 .81881 L .62549 .82358 L F
.62068 .82526 m .61253 .81922 L .61758 .81881 L .967 0 .116 r
F
.62588 .82514 m .62083 .82658 L .62582 .82532 L 1 .633 .599 r
F
.62478 .82516 m .62083 .82658 L .62588 .82514 L F
.62134 .82532 m .62083 .82658 L .62603 .82472 L F
.62052 .82615 m .62134 .82532 L .62076 .82557 L 1 .616 .603 r
F
.62052 .82615 m .61783 .83383 L .62113 .82584 L F
.62582 .82532 m .62287 .8341 L .6265 .825 L 1 .633 .599 r
F
.62083 .82658 m .61783 .83383 L .62582 .82532 L F
.63145 .82369 m .63139 .82355 L .63147 .82369 L 1 .001 .177 r
F
.63145 .82369 m .62287 .8341 L .62789 .8346 L 1 .635 .595 r
F
.62667 .82458 m .62658 .82442 L .63145 .82369 L 1 .001 .177 r
F
.63139 .82355 m .63054 .82296 L .63102 .82276 L F
.63139 .82355 m .63217 .82352 L .63224 .82365 L F
.6314 .82385 m .63217 .82352 L .63147 .82369 L 1 .635 .595 r
F
.63692 .82257 m .63288 .8352 L .63777 .82219 L 1 .631 .591 r
F
.63692 .82257 m .63777 .82219 L .63782 .82206 L F
.64808 .81921 m .64748 .81783 L .64905 .81889 L 1 .005 .219 r
F
.64748 .81783 m .64213 .80569 L .64834 .81754 L F
.64748 .81783 m .64834 .81754 L .64905 .81889 L F
.64221 .8202 m .63244 .81239 L .63731 .8092 L 1 .003 .208 r
F
.63777 .82219 m .63244 .81239 L .64221 .8202 L F
.64808 .81921 m .64783 .82004 L .64905 .81889 L 1 .614 .583 r
F
.64783 .82004 m .64277 .83637 L .64874 .81977 L F
.64783 .82004 m .64874 .81977 L .64905 .81889 L F
.64783 .82004 m .63784 .83581 L .64277 .83637 L F
.64781 .81858 m .63731 .8092 L .64213 .80569 L 1 .005 .219 r
F
.64754 .8187 m .63731 .8092 L .64781 .81858 L F
.64341 .82064 m .63731 .8092 L .64808 .81921 L F
.64247 .82108 m .63784 .83581 L .64341 .82064 L 1 .623 .587 r
F
.64252 .8209 m .64246 .82077 L .64269 .82085 L 1 .003 .208 r
F
.64246 .82077 m .64181 .8193 L .64341 .82064 L F
.64181 .8193 m .63731 .8092 L .64256 .81905 L F
.64181 .8193 m .64256 .81905 L .64341 .82064 L F
.63139 .82355 m .63224 .82365 L .63147 .82369 L 1 .001 .177 r
F
.63227 .8237 m .62753 .81516 L .63701 .82251 L 1 .002 .195 r
F
.63147 .82369 m .63217 .82352 L .63263 .82234 L 1 .635 .595 r
F
.63697 .82241 m .63661 .82161 L .63777 .82219 L 1 .002 .195 r
F
.63661 .82161 m .63244 .81239 L .63734 .8214 L F
.63661 .82161 m .63734 .8214 L .63777 .82219 L F
.6369 .82242 m .62753 .81516 L .63697 .82241 L F
.65176 .76159 m .63166 .82307 L .658 .7567 L 1 .635 .595 r
F
.63166 .82307 m .63145 .82369 L .63171 .82305 L F
.63166 .82307 m .63171 .82305 L .658 .7567 L F
.6319 .82258 m .63263 .82234 L .658 .7567 L F
.63147 .82369 m .63263 .82234 L .6319 .82258 L F
.64246 .82077 m .64341 .82064 L .64269 .82085 L 1 .003 .208 r
F
.64254 .8209 m .64341 .82064 L .67035 .74733 L 1 .623 .587 r
F
.64247 .82108 m .64341 .82064 L .64254 .8209 L F
.64341 .82064 m .63784 .83581 L .64783 .82004 L 1 .614 .583 r
F
.64269 .82085 m .64341 .82064 L .64374 .82125 L 1 .003 .208 r
F
.6428 .82153 m .64252 .8209 L .64374 .82125 L F
.64252 .8209 m .64269 .82085 L .64374 .82125 L F
.66419 .75198 m .64252 .8209 L .67035 .74733 L 1 .623 .587 r
F
.64252 .8209 m .64247 .82108 L .64254 .8209 L F
.64252 .8209 m .64254 .8209 L .67035 .74733 L F
.64808 .81921 m .64754 .8187 L .64781 .81858 L 1 .005 .219 r
F
.64808 .81921 m .64341 .82064 L .64783 .82004 L 1 .614 .583 r
F
.67367 .87732 m .64341 .82064 L .64808 .81921 L 1 .005 .219 r
F
.67035 .74733 m .64341 .82064 L .64808 .81921 L 1 .614 .583 r
F
.66724 .87635 m .6428 .82153 L .67367 .87732 L 1 .003 .208 r
F
.6428 .82153 m .64374 .82125 L .67367 .87732 L F
.658 .7567 m .63734 .82124 L .66419 .75198 L 1 .631 .591 r
F
.63734 .82124 m .63697 .82241 L .63743 .82121 L F
.63734 .82124 m .63743 .82121 L .66419 .75198 L F
.67035 .74733 m .64808 .81921 L .67646 .74266 L 1 .614 .583 r
F
.64808 .81921 m .64905 .81889 L .67646 .74266 L F
.67367 .87732 m .64808 .81921 L .68005 .87805 L 1 .005 .219 r
F
.64808 .81921 m .64905 .81889 L .68005 .87805 L F
.64252 .8209 m .63288 .8352 L .63784 .83581 L 1 .623 .587 r
F
.64252 .8209 m .63777 .82219 L .64221 .8202 L 1 .003 .208 r
F
.66419 .75198 m .63777 .82219 L .64252 .8209 L 1 .623 .587 r
F
.63777 .82219 m .63288 .8352 L .64252 .8209 L F
.66724 .87635 m .63777 .82219 L .64252 .8209 L 1 .003 .208 r
F
.66078 .87505 m .63697 .82241 L .66724 .87635 L 1 .002 .195 r
F
.63697 .82241 m .63692 .82257 L .63743 .82228 L 1 .631 .591 r
F
.63697 .82241 m .63777 .82219 L .66724 .87635 L 1 .002 .195 r
F
.63697 .82241 m .63743 .82228 L .63782 .82206 L 1 .631 .591 r
F
.63147 .82369 m .63224 .82365 L .66078 .87505 L 1 .001 .177 r
F
.65176 .76159 m .62692 .82394 L .63145 .82369 L 1 .635 .595 r
F
.62692 .82394 m .62667 .82458 L .63145 .82369 L F
.62667 .82458 m .62287 .8341 L .63145 .82369 L F
.62709 .82533 m .62667 .82458 L .63145 .82369 L 1 .001 .177 r
F
.62789 .8346 m .59526 .91277 L .5989 .91962 L 1 .703 .604 r
F
.62287 .8341 m .59526 .91277 L .62789 .8346 L 1 .721 .611 r
F
.6411 .8678 m .62076 .82544 L .64771 .87099 L .967 0 .116 r
F
.62076 .82544 m .62068 .82526 L .62078 .82543 L F
.62076 .82544 m .62078 .82543 L .64771 .87099 L F
.62116 .82536 m .62134 .82532 L .62138 .82525 L 1 .616 .603 r
F
.62076 .82557 m .62134 .82532 L .62116 .82536 L F
.62134 .82532 m .61758 .81881 L .62603 .82472 L 1 0 .152 r
F
.62082 .82542 m .62138 .82525 L .64548 .76683 L 1 .616 .603 r
F
.62076 .82557 m .62116 .82536 L .62082 .82542 L F
.62078 .82543 m .62134 .82532 L .64771 .87099 L .967 0 .116 r
F
.62068 .82526 m .62134 .82532 L .62078 .82543 L F
.62082 .82542 m .62138 .82525 L .62082 .82542 L 1 .616 .603 r
F
.62116 .82536 m .62138 .82525 L .62082 .82542 L F
.62076 .82544 m .61615 .82537 L .62068 .82526 L .967 0 .116 r
F
.62287 .8341 m .5916 .90579 L .59526 .91277 L 1 .721 .611 r
F
.61783 .83383 m .5916 .90579 L .62287 .8341 L 1 .742 .619 r
F
.61481 .82381 m .61009 .82269 L .61253 .81922 L .905 0 .062 r
F
.61367 .82452 m .61009 .82269 L .61481 .82381 L F
.62036 .82659 m .61277 .83399 L .61783 .83383 L 1 .616 .603 r
F
.62055 .82604 m .62007 .82653 L .62036 .82659 L F
.62007 .82653 m .61277 .83399 L .62036 .82659 L F
.62023 .82601 m .61277 .83399 L .62055 .82604 L F
.61634 .8257 m .61277 .83399 L .62076 .82544 L F
.61568 .82555 m .61481 .82381 L .61634 .8257 L .905 0 .062 r
F
.61481 .82381 m .61253 .81922 L .61513 .82364 L F
.61481 .82381 m .61513 .82364 L .61634 .8257 L F
.6158 .82579 m .61277 .83399 L .61634 .8257 L 1 .57 .606 r
F
.61703 .83603 m .58793 .89878 L .5916 .90579 L 1 .742 .619 r
F
.61783 .83383 m .6169 .83585 L .61703 .83603 L F
.6169 .83585 m .58793 .89878 L .61703 .83603 L F
.61125 .82603 m .61105 .82651 L .61186 .82564 L 1 .463 .607 r
F
.61105 .82651 m .60768 .83481 L .61143 .82659 L F
.61105 .82651 m .61143 .82659 L .61186 .82564 L F
.6081 .82518 m .60381 .81795 L .60825 .82516 L .746 0 0 r
F
.60714 .82718 m .6072 .82709 L .6082 .82508 L 1 .244 .604 r
F
.60381 .81795 m .60414 .81841 L .60829 .82516 L .746 0 0 r
F
.60681 .82788 m .60645 .82867 L .60829 .82516 L 1 .244 .604 r
F
.60645 .82867 m .60547 .83085 L .60627 .82924 L F
.60645 .82867 m .60627 .82924 L .60829 .82516 L F
.60681 .82788 m .60829 .82516 L .60816 .82517 L F
.61277 .83399 m .58793 .89878 L .61783 .83383 L 1 .769 .63 r
F
.61526 .82725 m .60768 .83481 L .61277 .83399 L 1 .57 .606 r
F
.61471 .82699 m .60768 .83481 L .61526 .82725 L F
.61186 .82564 m .60768 .83481 L .61518 .82647 L F
.61238 .82566 m .61518 .82647 L .6158 .82579 L F
.61186 .82564 m .61518 .82647 L .61238 .82566 L F
.61115 .82531 m .60235 .8155 L .60743 .81826 L .83 0 0 r
F
.62781 .85688 m .61137 .82572 L .63444 .86331 L F
.61137 .82572 m .61115 .82531 L .6114 .82571 L F
.61137 .82572 m .6114 .82571 L .63444 .86331 L F
.61125 .82603 m .61186 .82564 L .61186 .82564 L 1 .463 .607 r
F
.61115 .82531 m .6099 .82293 L .61186 .82564 L .83 0 0 r
F
.6099 .82293 m .60743 .81826 L .61009 .82269 L F
.6099 .82293 m .61009 .82269 L .61186 .82564 L F
.60829 .82516 m .60809 .82556 L .61137 .82572 L 1 .463 .607 r
F
.60809 .82556 m .60265 .83654 L .60952 .82802 L F
.60809 .82556 m .60952 .82802 L .61137 .82572 L F
.6081 .82518 m .59721 .81045 L .60235 .8155 L .746 0 0 r
F
.60235 .8155 m .57594 .78581 L .57946 .78389 L .811 0 .013 r
F
.57238 .78568 m .54688 .77167 L .54888 .76783 L .654 0 0 r
F
.56878 .78329 m .56638 .78202 L .57238 .78568 L .468 0 0 r
F
.56311 .78051 m .54688 .77167 L .56227 .78013 L F
.5612 .77927 m .54688 .77167 L .56311 .78051 L F
.54688 .77167 m .52145 .76828 L .54888 .76783 L .441 0 0 r
F
.56638 .78202 m .5612 .77927 L .56311 .78051 L .468 0 0 r
F
.56638 .78202 m .56227 .78013 L .57238 .78568 L F
.56878 .78329 m .54485 .77244 L .54688 .77167 L F
.55776 .77703 m .5433 .77113 L .54466 .77236 L 0 0 .714 r
F
.57238 .78568 m .54888 .76783 L .57594 .78581 L .654 0 0 r
F
.56604 .77998 m .55672 .77635 L .55776 .77703 L 0 0 .714 r
F
.55672 .77635 m .5433 .77113 L .55776 .77703 L F
.54466 .77236 m .52051 .7728 L .54485 .77244 L .38 .052 .882 r
F
.56844 .78295 m .54485 .77244 L .56878 .78329 L .297 0 0 r
F
.56729 .78244 m .54466 .77236 L .54485 .77244 L F
.56844 .78295 m .56732 .78245 L .56729 .78244 L F
.56732 .78245 m .54466 .77236 L .56729 .78244 L F
.59721 .81045 m .57238 .78568 L .57594 .78581 L .71 0 0 r
F
.59044 .80227 m .58358 .79465 L .58852 .79995 L F
.59721 .81045 m .58868 .80056 L .59044 .80227 L F
.58868 .80056 m .58358 .79465 L .59044 .80227 L F
.59721 .81045 m .58852 .79995 L .60235 .8155 L F
.59202 .80274 m .58728 .79862 L .59721 .81045 L .511 0 0 r
F
.58728 .79862 m .57238 .78568 L .5794 .79268 L F
.58728 .79862 m .5794 .79268 L .59721 .81045 L F
.58313 .79502 m .56878 .78329 L .57238 .78568 L F
.58191 .79402 m .56844 .78295 L .56878 .78329 L 0 0 .551 r
F
.58358 .79465 m .58372 .79454 L .58852 .79995 L .71 0 0 r
F
.59153 .80188 m .58172 .79384 L .58191 .79402 L 0 0 .551 r
F
.58172 .79384 m .56844 .78295 L .58191 .79402 L F
.59202 .80274 m .58296 .79516 L .58313 .79502 L .511 0 0 r
F
.58296 .79516 m .56878 .78329 L .58313 .79502 L F
.58358 .79465 m .57594 .78581 L .58372 .79454 L .71 0 0 r
F
.60481 .81991 m .6028 .81721 L .59721 .81045 L 0 0 .444 r
F
.6028 .81721 m .59202 .80274 L .59721 .81045 L F
.60913 .82651 m .60829 .82516 L .61137 .82572 L .83 0 0 r
F
.60829 .82516 m .60779 .82434 L .61137 .82572 L F
.61137 .82572 m .60265 .83654 L .60768 .83481 L 1 .463 .607 r
F
.61137 .82572 m .60779 .82434 L .61115 .82531 L .83 0 0 r
F
.60779 .82434 m .60235 .8155 L .61115 .82531 L F
.61115 .82531 m .61186 .82564 L .61186 .82564 L F
.61165 .82568 m .61186 .82564 L .61206 .82597 L F
.61115 .82531 m .61186 .82564 L .61165 .82568 L F
.61125 .82603 m .61186 .82564 L .61173 .82566 L 1 .463 .607 r
F
.6114 .82571 m .61206 .82597 L .61142 .82574 L .83 0 0 r
F
.61115 .82531 m .61165 .82568 L .6114 .82571 L F
.61165 .82568 m .61206 .82597 L .6114 .82571 L F
.61146 .82551 m .61137 .82572 L .6115 .82549 L 1 .463 .607 r
F
.61137 .82572 m .61125 .82603 L .61139 .82572 L F
.61137 .82572 m .61139 .82572 L .6115 .82549 L F
.61139 .82572 m .61191 .82553 L .61139 .82571 L F
.61125 .82603 m .61173 .82566 L .61139 .82572 L F
.61173 .82566 m .61191 .82553 L .61139 .82572 L F
.61186 .82564 m .61156 .82514 L .61252 .82523 L .905 0 .062 r
F
.61156 .82514 m .61009 .82269 L .61568 .82555 L F
.61615 .82537 m .61253 .81922 L .62068 .82526 L .967 0 .116 r
F
.61009 .82269 m .60743 .81826 L .61239 .8192 L .905 0 .062 r
F
.61009 .82269 m .61239 .8192 L .61253 .81922 L F
.62656 .78829 m .60853 .82468 L .61137 .82572 L 1 .463 .607 r
F
.60853 .82468 m .60829 .82516 L .61137 .82572 L F
.61142 .82574 m .61206 .82597 L .63444 .86331 L .83 0 0 r
F
.60381 .81795 m .60829 .82516 L .60825 .82516 L .746 0 0 r
F
.60819 .82511 m .60853 .82468 L .62656 .78829 L 1 .244 .604 r
F
.62781 .85688 m .60913 .82651 L .61137 .82572 L .83 0 0 r
F
.60818 .82511 m .6082 .82508 L .62656 .78829 L 1 .244 .604 r
F
.62029 .79977 m .6081 .82518 L .61961 .80217 L F
.62029 .79977 m .61961 .80217 L .62656 .78829 L F
.63326 .76526 m .63226 .76787 L .63168 .76947 L .7 0 .261 r
F
.63567 .75053 m .63302 .76581 L .63573 .75086 L .869 0 .256 r
F
.63259 .76831 m .63226 .76787 L .63326 .76527 L 0 0 0 r
F
.6329 .76687 m .63326 .76527 L .63326 .76527 L F
.63259 .76831 m .63326 .76527 L .6329 .76687 L F
.63302 .76581 m .63259 .76829 L .63305 .76574 L .869 0 .256 r
F
.63302 .76581 m .63305 .76574 L .63573 .75086 L F
.63297 .7662 m .63259 .76829 L .63326 .76527 L F
.63881 .70939 m .63761 .70959 L .63845 .70856 L .183 0 .395 r
F
.63881 .70939 m .63845 .70856 L .6413 .70506 L F
.63881 .70939 m .63259 .7683 L .64452 .69945 L 0 0 .228 r
F
.64463 .69906 m .64274 .70987 L .64278 .70983 L .869 0 .256 r
F
.64452 .69944 m .63567 .75053 L .64463 .69906 L F
.63326 .76526 m .63653 .75487 L .64063 .74356 L .7 0 .261 r
F
.6472 .69298 m .63326 .76525 L .64063 .74355 L 1 .114 .414 r
F
.64555 .69741 m .63326 .76525 L .6472 .69298 L F
.64463 .69906 m .63326 .76525 L .64555 .69741 L .869 0 .256 r
F
.64478 .69819 m .64322 .69913 L .64489 .69773 L .335 0 .37 r
F
.64478 .69819 m .64489 .69773 L .64514 .69752 L F
.64478 .69819 m .64452 .69944 L .64463 .69906 L .869 0 .256 r
F
.64463 .69906 m .64555 .69741 L .64573 .69645 L F
.64322 .69913 m .6441 .69757 L .64573 .69645 L .335 0 .37 r
F
.64322 .69913 m .64573 .69645 L .64514 .69752 L F
.64463 .69906 m .64573 .69645 L .64483 .69809 L .869 0 .256 r
F
.64514 .69752 m .64573 .69645 L .64573 .69645 L .335 0 .37 r
F
.64735 .69183 m .64555 .69741 L .6472 .69298 L 1 .114 .414 r
F
.64603 .69558 m .64555 .69741 L .64735 .69183 L F
.64573 .69644 m .63211 .70582 L .64768 .68929 L .314 0 .327 r
F
.64628 .6934 m .64573 .69644 L .64768 .68929 L 1 .114 .414 r
F
.64573 .69644 m .64555 .69741 L .64768 .68929 L F
.64768 .68929 m .63211 .70582 L .63912 .67075 L .314 0 .327 r
F
.64768 .68929 m .64603 .69558 L .64735 .69183 L 1 .114 .414 r
F
.64722 .69282 m .65772 .67349 L .6554 .67758 L F
.64971 .6937 m .64573 .69644 L .64768 .68929 L .314 0 .327 r
F
.64544 .69727 m .64573 .69645 L .64971 .69371 L .335 0 .37 r
F
.64514 .69752 m .64573 .69645 L .64544 .69727 L F
.64768 .68929 m .64705 .68793 L .64909 .68512 L .314 0 .327 r
F
.64705 .68793 m .63912 .67075 L .6509 .67223 L F
.64705 .68793 m .6509 .67223 L .65781 .6731 L F
.64933 .67656 m .64628 .6934 L .64768 .68929 L 1 .114 .414 r
F
.64768 .68929 m .64909 .68512 L .65781 .6731 L .314 0 .327 r
F
.64478 .69819 m .63147 .71057 L .63211 .70583 L .335 0 .37 r
F
.64452 .69944 m .64452 .69944 L .64478 .69819 L .869 0 .256 r
F
.64478 .69819 m .64463 .69906 L .64483 .69809 L F
.64892 .69569 m .64452 .69944 L .64478 .69819 L .335 0 .37 r
F
.64452 .69944 m .63147 .71057 L .64478 .69819 L F
.64467 .69862 m .64452 .69944 L .64478 .69819 L .869 0 .256 r
F
.64533 .69497 m .64467 .69862 L .64478 .69819 L F
.64849 .67653 m .64522 .6954 L .64533 .69497 L F
.64522 .6954 m .64467 .69862 L .64533 .69497 L F
.64483 .69809 m .64573 .69645 L .64933 .67656 L F
.64892 .69569 m .64478 .69819 L .64971 .69371 L .335 0 .37 r
F
.64478 .69819 m .64514 .69752 L .64971 .69371 L F
.64849 .67653 m .64478 .69819 L .64933 .67656 L .869 0 .256 r
F
.64478 .69819 m .64483 .69809 L .64933 .67656 L F
.63761 .70959 m .64244 .70122 L .64431 .69963 L .183 0 .395 r
F
.64116 .70523 m .64431 .69963 L .64892 .69569 L F
.63761 .70959 m .64431 .69963 L .64116 .70523 L F
.64328 .70867 m .64197 .70888 L .64892 .69569 L F
.64278 .70983 m .63567 .75053 L .63573 .75086 L .869 0 .256 r
F
.64274 .70987 m .63567 .75053 L .64278 .70983 L F
.63881 .70939 m .6365 .74498 L .63404 .75455 L 0 0 .228 r
F
.63279 .7664 m .6329 .76617 L .63274 .76685 L F
.6329 .76617 m .63354 .76487 L .63284 .76661 L F
.6329 .76617 m .63284 .76661 L .63274 .76685 L F
.63573 .75086 m .63297 .7662 L .63326 .76525 L .869 0 .256 r
F
.63404 .75455 m .63357 .76423 L .63279 .7664 L 0 0 .228 r
F
.63297 .7662 m .63326 .76527 L .63326 .76525 L .869 0 .256 r
F
.63357 .76423 m .63354 .76487 L .63279 .7664 L 0 0 .228 r
F
.63168 .76947 m .62377 .78994 L .62029 .79977 L .7 0 .261 r
F
.62377 .78994 m .62113 .79676 L .62096 .79738 L F
.62377 .78994 m .62096 .79738 L .62029 .79977 L F
.61634 .8257 m .61615 .82537 L .62076 .82544 L .967 0 .116 r
F
.63917 .77271 m .61634 .8257 L .62076 .82544 L 1 .616 .603 r
F
.62603 .82472 m .62481 .82387 L .62549 .82358 L 1 0 .152 r
F
.64548 .76683 m .62134 .82532 L .62603 .82472 L 1 .633 .599 r
F
.62603 .82472 m .62478 .82516 L .62588 .82514 L F
.62582 .82532 m .62667 .82458 L .62601 .82485 L F
.64548 .76683 m .62598 .82487 L .65176 .76159 L F
.62598 .82487 m .62582 .82532 L .62601 .82485 L F
.62598 .82487 m .62601 .82485 L .65176 .76159 L F
.62582 .82532 m .62546 .82571 L .62569 .82573 L F
.64771 .87099 m .62182 .82615 L .62603 .82472 L 1 0 .152 r
F
.63283 .77966 m .61594 .82541 L .63917 .77271 L 1 .57 .606 r
F
.61594 .82541 m .61656 .8252 L .63917 .77271 L F
.63917 .77271 m .62094 .82494 L .64548 .76683 L 1 .616 .603 r
F
.62094 .82494 m .62104 .82491 L .64548 .76683 L F
.64771 .87099 m .62603 .82472 L .65427 .87332 L 1 0 .152 r
F
.62601 .82485 m .62667 .82458 L .62618 .82468 L 1 .633 .599 r
F
.62603 .82472 m .62667 .82458 L .65427 .87332 L 1 0 .152 r
F
.62631 .82411 m .62692 .82394 L .65176 .76159 L 1 .633 .599 r
F
.65427 .87332 m .63145 .82369 L .66078 .87505 L 1 .001 .177 r
F
.63145 .82369 m .63147 .82369 L .66078 .87505 L F
.65427 .87332 m .62709 .82533 L .63145 .82369 L F
.63145 .82369 m .63147 .82369 L .658 .7567 L 1 .635 .595 r
F
.6555 .71834 m .63283 .77966 L .63917 .77271 L 1 .298 .541 r
F
.64807 .72959 m .63282 .77966 L .65549 .71835 L 1 .143 .504 r
F
.64807 .72959 m .62656 .78829 L .63282 .77966 L F
.64063 .74356 m .62656 .78829 L .64807 .72959 L .898 .006 .425 r
F
.64328 .70867 m .64328 .70867 L .63881 .70939 L .183 0 .395 r
F
.64328 .70867 m .63034 .83987 L .63847 .71468 L F
.64328 .70867 m .63847 .71468 L .63881 .70939 L F
.65781 .6731 m .64063 .74355 L .65815 .67296 L 1 .114 .414 r
F
.65815 .67296 m .64807 .72958 L .66681 .6651 L 1 .256 .487 r
F
.65815 .67296 m .64063 .74355 L .64807 .72958 L F
.65768 .69159 m .64328 .70867 L .64892 .69569 L 0 0 .026 r
F
.64781 .70098 m .64328 .70867 L .64329 .70866 L .629 0 .379 r
F
.65465 .69448 m .64329 .70866 L .65768 .6916 L F
.64781 .70098 m .64329 .70866 L .65465 .69448 L F
.61139 .82571 m .61191 .82553 L .63282 .77966 L 1 .463 .607 r
F
.6158 .82579 m .61186 .82564 L .61568 .82555 L .905 0 .062 r
F
.61186 .82564 m .61186 .82564 L .6158 .82579 L F
.61186 .82564 m .61252 .82523 L .61568 .82555 L F
.6158 .82579 m .61568 .82555 L .61582 .82579 L F
.61568 .82555 m .61367 .82452 L .61481 .82381 L F
.63283 .77966 m .61206 .8252 L .6158 .82579 L 1 .57 .606 r
F
.61206 .8252 m .61186 .82564 L .6158 .82579 L F
.61568 .82555 m .61634 .8257 L .61646 .82589 L .905 0 .062 r
F
.61582 .82579 m .61646 .82589 L .6411 .8678 L F
.61568 .82555 m .61646 .82589 L .61582 .82579 L F
.6158 .82579 m .61471 .82699 L .61526 .82725 L 1 .57 .606 r
F
.63444 .86331 m .61186 .82564 L .6158 .82579 L .905 0 .062 r
F
.62656 .78829 m .61146 .82551 L .63282 .77966 L 1 .463 .607 r
F
.61146 .82551 m .6115 .82549 L .63282 .77966 L F
.63444 .86331 m .6158 .82579 L .6411 .8678 L .905 0 .062 r
F
.6158 .82579 m .61582 .82579 L .6411 .8678 L F
.62076 .82544 m .62023 .82601 L .62055 .82604 L 1 .616 .603 r
F
.6411 .8678 m .61689 .82664 L .62076 .82544 L .967 0 .116 r
F
.6081 .82518 m .60818 .82511 L .62656 .78829 L 1 .244 .604 r
F
.60807 .82524 m .5976 .83941 L .60265 .83654 L F
.62029 .79977 m .60694 .8231 L .60807 .82524 L F
.60802 .82515 m .60625 .8243 L .60807 .82524 L F
.60625 .8243 m .59721 .81045 L .60599 .82245 L .746 0 0 r
F
.60625 .8243 m .60599 .82245 L .60793 .8251 L F
.60804 .82525 m .59721 .81045 L .6081 .82518 L F
.60694 .8231 m .60625 .8243 L .60802 .82515 L 1 .244 .604 r
F
.60625 .8243 m .60643 .82746 L .60807 .82524 L F
.60714 .82568 m .60625 .8243 L .60804 .82525 L .746 0 0 r
F
.60625 .8243 m .60793 .8251 L .60804 .82525 L F
.60808 .82398 m .60768 .82405 L .60782 .82378 L .777 .002 .574 r
F
.61402 .81524 m .61343 .81688 L .61402 .81524 L 0 0 0 r
F
.61714 .80601 m .61732 .80548 L .62029 .79977 L .777 .002 .574 r
F
.61402 .81523 m .61402 .81524 L .62029 .79977 L F
.61402 .81524 m .60808 .82398 L .61024 .8197 L F
.61402 .81524 m .61024 .8197 L .62029 .79977 L F
.60794 .824 m .60683 .8242 L .60732 .82595 L 0 0 .444 r
F
.60773 .82395 m .60656 .82375 L .62029 .79977 L .777 .002 .574 r
F
.60808 .82398 m .60782 .82378 L .61732 .80548 L F
.60808 .82398 m .61732 .80548 L .61714 .80601 L F
.60381 .81795 m .60235 .8155 L .60414 .81841 L .746 0 0 r
F
.60683 .8242 m .60625 .8243 L .60732 .82595 L 0 0 .444 r
F
.60652 .82628 m .60625 .8243 L .60768 .82405 L .777 .002 .574 r
F
.6194 .84323 m .61935 .84312 L .62781 .85688 L .746 0 0 r
F
.60825 .82516 m .61935 .84312 L .6194 .84323 L F
.60825 .82516 m .60829 .82516 L .61935 .84312 L F
.60714 .82718 m .6082 .82508 L .60818 .82511 L 1 .244 .604 r
F
.62887 .87731 m .61794 .84311 L .63007 .87874 L .849 0 0 r
F
.6211 .84709 m .61694 .84008 L .6231 .84959 L .746 0 0 r
F
.61694 .84008 m .6081 .82518 L .61661 .83886 L F
.61694 .84008 m .61661 .83886 L .62781 .85688 L F
.60816 .82517 m .60829 .82516 L .60853 .82468 L 1 .244 .604 r
F
.60816 .82517 m .60853 .82468 L .60819 .82511 L F
.60751 .82576 m .60804 .82525 L .60858 .82599 L .746 0 0 r
F
.60714 .82568 m .60804 .82525 L .60751 .82576 L F
.6081 .82518 m .60825 .82516 L .62781 .85688 L F
.6081 .82518 m .60714 .82718 L .60814 .82518 L 1 .244 .604 r
F
.6081 .82518 m .60814 .82518 L .60818 .82511 L F
.60858 .82599 m .60804 .82525 L .6081 .82518 L .746 0 0 r
F
.61277 .83399 m .58424 .89187 L .58793 .89878 L 1 .769 .63 r
F
.60768 .83481 m .58424 .89187 L .61277 .83399 L 1 .804 .644 r
F
.60986 .82815 m .60714 .82568 L .60858 .82599 L .746 0 0 r
F
.6211 .84709 m .60916 .82878 L .60986 .82815 L F
.60916 .82878 m .60714 .82568 L .60986 .82815 L F
.60806 .82401 m .60652 .82628 L .60768 .82405 L .777 .002 .574 r
F
.60798 .82385 m .60732 .82595 L .61729 .84124 L 0 0 .444 r
F
.60808 .82398 m .60806 .82401 L .60768 .82405 L .777 .002 .574 r
F
.60625 .8243 m .5976 .83941 L .60643 .82746 L 1 .244 .604 r
F
.60652 .82628 m .5976 .83941 L .60625 .8243 L .777 .002 .574 r
F
.60806 .82401 m .59253 .84336 L .5976 .83941 L F
.60808 .82398 m .60798 .82385 L .60808 .82401 L 0 0 .444 r
F
.60768 .82405 m .60625 .8243 L .60656 .82375 L .777 .002 .574 r
F
.60768 .82405 m .60656 .82375 L .60773 .82395 L F
.60808 .82398 m .60529 .81999 L .60608 .82148 L 0 0 .444 r
F
.60785 .82332 m .60785 .82332 L .60808 .82398 L F
.60785 .82332 m .60529 .81999 L .60698 .82241 L F
.60785 .82332 m .60698 .82241 L .60808 .82398 L F
.61402 .81523 m .60837 .82263 L .60808 .82398 L .777 .002 .574 r
F
.60805 .82305 m .60785 .82332 L .60806 .82392 L F
.60837 .82263 m .60805 .82305 L .60808 .82398 L F
.61364 .82989 m .60838 .82328 L .61416 .83151 L 0 0 .526 r
F
.60838 .82328 m .60785 .82332 L .60815 .82371 L F
.60838 .82328 m .60815 .82371 L .61416 .83153 L F
.60838 .82328 m .61416 .83153 L .61415 .8315 L F
.60798 .82385 m .61729 .84124 L .61661 .83914 L 0 0 .444 r
F
.62789 .87553 m .62511 .86662 L .62514 .8667 L .854 0 .332 r
F
.62948 .88056 m .61826 .84465 L .6351 .89843 L .684 0 0 r
F
.61364 .82989 m .61364 .82989 L .61429 .83169 L 0 0 .526 r
F
.61429 .83169 m .61364 .82989 L .61429 .83169 L .765 0 0 r
F
.61429 .83169 m .61416 .83154 L .61461 .83254 L 0 0 .444 r
F
.61416 .83154 m .60808 .82398 L .6165 .83892 L F
.61416 .83154 m .6165 .83892 L .6211 .84709 L F
.61415 .8315 m .61416 .83153 L .61429 .83169 L 0 0 .526 r
F
.61364 .82989 m .61416 .83151 L .61429 .83169 L F
.60808 .82398 m .60808 .82401 L .6211 .84709 L 0 0 .444 r
F
.61429 .83169 m .60873 .82447 L .60808 .82398 L F
.6351 .89843 m .61385 .83055 L .61429 .83169 L .765 0 0 r
F
.61385 .83055 m .61364 .82989 L .61429 .83169 L F
.61429 .83169 m .61429 .83169 L .6211 .84709 L 0 0 .444 r
F
.61429 .83169 m .61461 .83254 L .6211 .84709 L F
.61826 .84465 m .61382 .83047 L .61541 .83555 L .684 0 0 r
F
.61382 .83047 m .61364 .82988 L .61385 .83054 L F
.61382 .83047 m .61385 .83054 L .61541 .83555 L F
.61826 .84465 m .61541 .83555 L .6351 .89843 L F
.62948 .88056 m .6251 .86661 L .61826 .84465 L F
.61661 .83914 m .61729 .84124 L .6211 .84709 L 0 0 .444 r
F
.6351 .89843 m .61429 .83169 L .63587 .89919 L .765 0 0 r
F
.6279 .87555 m .62514 .8667 L .62941 .87692 L .854 0 .332 r
F
.62789 .87553 m .62514 .8667 L .6279 .87555 L F
.60798 .82385 m .60608 .82148 L .60683 .8242 L 0 0 .444 r
F
.60798 .82385 m .60683 .8242 L .60794 .824 L F
.60785 .82332 m .59253 .84336 L .60806 .82392 L .777 .002 .574 r
F
.60808 .82398 m .60805 .82305 L .60806 .82401 L F
.60812 .82361 m .59253 .84336 L .60785 .82332 L .725 0 .545 r
F
.60873 .82447 m .60785 .82332 L .60808 .82398 L 0 0 .444 r
F
.60838 .82328 m .59206 .84377 L .59253 .84336 L .725 0 .545 r
F
.61343 .81688 m .60838 .82328 L .61402 .81524 L F
.61343 .81688 m .60845 .82314 L .60838 .82328 L F
.60808 .8233 m .60785 .82332 L .60805 .82305 L F
.60836 .82327 m .60805 .82305 L .61402 .81524 L F
.60838 .82328 m .60836 .82327 L .61402 .81524 L F
.60812 .82361 m .60805 .82305 L .60836 .82327 L F
.60838 .82328 m .60827 .82314 L .60785 .82332 L 0 0 .526 r
F
.60827 .82314 m .59202 .80274 L .60771 .82314 L F
.60827 .82314 m .60771 .82314 L .60785 .82332 L F
.60845 .82314 m .60839 .82323 L .60838 .82328 L .725 0 .545 r
F
.60839 .82323 m .60839 .82323 L .60838 .82327 L 0 0 .526 r
F
.60839 .82323 m .59153 .80188 L .60829 .82316 L F
.60839 .82323 m .60829 .82316 L .60838 .82327 L F
.60838 .82328 m .60812 .82361 L .60836 .82327 L .725 0 .545 r
F
.60839 .82323 m .59206 .84377 L .60838 .82328 L F
.60839 .82323 m .60838 .82327 L .6084 .82329 L 0 0 .526 r
F
.60806 .82392 m .59253 .84336 L .60806 .82401 L .777 .002 .574 r
F
.60714 .82718 m .60681 .82788 L .6072 .82709 L 1 .244 .604 r
F
.60681 .82788 m .60265 .83654 L .60547 .83085 L F
.60928 .82873 m .59206 .84377 L .60839 .82323 L 0 0 0 r
F
.60743 .81826 m .57946 .78389 L .58298 .78023 L .906 0 .106 r
F
.60235 .8155 m .59593 .80663 L .60743 .81826 L .811 0 .013 r
F
.59593 .80663 m .57946 .78389 L .60324 .8131 L F
.59593 .80663 m .60324 .8131 L .60743 .81826 L F
.58807 .79519 m .56604 .77998 L .56655 .78062 L 0 0 .681 r
F
.57096 .78452 m .56655 .78062 L .56844 .78295 L F
.58807 .79519 m .56655 .78062 L .57096 .78452 L F
.60908 .81551 m .59153 .80188 L .60839 .82323 L 0 0 .663 r
F
.61173 .82566 m .61186 .82564 L .61191 .82553 L 1 .463 .607 r
F
.61138 .82275 m .60839 .82323 L .61364 .82988 L 0 0 .663 r
F
.60847 .82321 m .60839 .82323 L .60846 .82314 L 0 0 0 r
F
.61124 .82314 m .60846 .82314 L .61066 .82037 L F
.61138 .82275 m .61066 .82037 L .61343 .81688 L F
.61124 .82314 m .61066 .82037 L .61138 .82275 L F
.6251 .86661 m .61812 .84433 L .61826 .84465 L .684 0 0 r
F
.63007 .87874 m .61794 .84311 L .6211 .84709 L .849 0 0 r
F
.61794 .84311 m .61429 .83169 L .6211 .84709 L F
.6211 .84709 m .6231 .84959 L .62781 .85688 L .746 0 0 r
F
.61594 .82541 m .6158 .82579 L .61656 .8252 L 1 .57 .606 r
F
.6158 .82579 m .61634 .8257 L .61656 .8252 L F
.644 .90628 m .6211 .84709 L .62781 .85688 L .884 0 .028 r
F
.63587 .89919 m .6211 .84709 L .644 .90628 L .849 0 0 r
F
.62924 .86752 m .62524 .85974 L .61343 .81688 L .945 .006 .366 r
F
.62524 .85974 m .61894 .84603 L .61343 .81688 L F
.61382 .83047 m .61147 .82304 L .61364 .82988 L .684 0 0 r
F
.61147 .82304 m .61146 .82303 L .61364 .82988 L F
.61141 .82285 m .61138 .82275 L .61364 .82988 L F
.61364 .82989 m .60914 .82419 L .6091 .82418 L 0 0 .526 r
F
.61782 .84325 m .61226 .8256 L .61382 .83047 L .684 0 0 r
F
.61826 .84465 m .61812 .84433 L .61782 .84325 L F
.61938 .84835 m .61138 .82275 L .61343 .81688 L .945 .006 .366 r
F
.62113 .79676 m .61402 .81523 L .62029 .79977 L .7 0 .261 r
F
.61403 .81522 m .61402 .81523 L .61729 .80674 L 0 0 0 r
F
.61742 .80663 m .61403 .81522 L .61729 .80674 L F
.61689 .82664 m .61634 .8257 L .62076 .82544 L .967 0 .116 r
F
.62182 .82615 m .62134 .82532 L .62603 .82472 L 1 0 .152 r
F
.62094 .82494 m .62052 .82615 L .62104 .82491 L 1 .616 .603 r
F
.62924 .86752 m .61343 .81688 L .61794 .80546 L .945 .006 .366 r
F
.62618 .82468 m .62667 .82458 L .62692 .82394 L 1 .633 .599 r
F
.6266 .7835 m .62029 .79977 L .62431 .79241 L .898 .006 .425 r
F
.6266 .7835 m .62431 .79241 L .62656 .78829 L F
.62955 .85827 m .61794 .80546 L .63258 .76832 L .945 .006 .366 r
F
.65209 .91249 m .62781 .85688 L .63444 .86331 L .928 0 .072 r
F
.644 .90628 m .62781 .85688 L .65209 .91249 L .884 0 .028 r
F
.62924 .86752 m .61794 .80546 L .62955 .85827 L .945 .006 .366 r
F
.62507 .7873 m .61784 .80567 L .61742 .80663 L 0 0 0 r
F
.62567 .78586 m .61366 .81631 L .62507 .7873 L F
.63226 .76787 m .62113 .79676 L .63168 .76947 L .7 0 .261 r
F
.6261 .78471 m .61742 .80663 L .62635 .78321 L 0 0 0 r
F
.61742 .80663 m .61729 .80674 L .62635 .78321 L F
.62392 .7975 m .62129 .78663 L .62264 .78425 L 1 .154 .393 r
F
.6289 .84899 m .62316 .80196 L .62392 .7975 L F
.62316 .80196 m .62129 .78663 L .62392 .7975 L F
.63259 .76831 m .62567 .78586 L .62507 .7873 L 0 0 0 r
F
.63259 .76831 m .6261 .78471 L .63226 .76787 L F
.6261 .78471 m .62635 .78321 L .63226 .76787 L F
.6289 .84899 m .61096 .66345 L .63147 .71058 L 1 .154 .393 r
F
.62488 .78954 m .62319 .80189 L .62558 .79992 L .844 0 .037 r
F
.62264 .78425 m .6068 .66782 L .61096 .66345 L 1 .154 .393 r
F
.62129 .78663 m .6068 .66782 L .62264 .78425 L F
.61819 .69118 m .62233 .78296 L .62366 .77169 L .844 0 .037 r
F
.61819 .69118 m .6068 .66782 L .62218 .79365 L F
.61819 .69118 m .62218 .79365 L .62276 .79236 L F
.62366 .77169 m .62284 .79421 L .62488 .78954 L F
.62233 .78296 m .62284 .79421 L .62366 .77169 L F
.62284 .79421 m .62319 .80189 L .62488 .78954 L F
.6365 .74498 m .62905 .85735 L .63404 .75455 L 0 0 .228 r
F
.63765 .74049 m .63034 .83987 L .6365 .74498 L F
.63034 .83987 m .62905 .85735 L .6365 .74498 L F
.63274 .76685 m .63268 .76843 L .63259 .7683 L F
.63354 .76487 m .62905 .85735 L .63274 .76685 L F
.63543 .75907 m .63518 .76272 L .6304 .77239 L .183 0 .395 r
F
.63268 .76843 m .62905 .85735 L .63259 .76831 L 0 0 .228 r
F
.63518 .76272 m .62899 .85362 L .63036 .77444 L .183 0 .395 r
F
.63268 .76843 m .63259 .76831 L .63259 .7683 L 0 0 .228 r
F
.63518 .76272 m .63036 .77444 L .6304 .77239 L .183 0 .395 r
F
.63881 .70939 m .63543 .75907 L .63147 .71059 L F
.63543 .75907 m .6304 .77239 L .63147 .71059 L F
.62558 .79992 m .62319 .80189 L .62889 .84849 L .844 0 .037 r
F
.63761 .70959 m .63147 .71059 L .64244 .70122 L .183 0 .395 r
F
.64322 .69913 m .63714 .70279 L .6441 .69757 L .335 0 .37 r
F
.63714 .70279 m .63211 .70583 L .63704 .70243 L F
.63714 .70279 m .63704 .70243 L .6441 .69757 L F
.64254 .67404 m .63881 .70939 L .64849 .67653 L 0 0 .228 r
F
.63881 .70939 m .64452 .69945 L .64849 .67653 L F
.64161 .70803 m .63881 .70939 L .6439 .70186 L .183 0 .395 r
F
.64125 .709 m .64109 .70902 L .64161 .70803 L F
.64109 .70902 m .63881 .70939 L .64161 .70803 L F
.63912 .67074 m .62375 .6346 L .64624 .64676 L .735 0 .322 r
F
.63912 .67074 m .6177 .64976 L .62375 .6346 L F
.6321 .70581 m .6177 .64976 L .63912 .67074 L 1 .011 .347 r
F
.63336 .66359 m .63189 .72662 L .64254 .67404 L .496 0 .502 r
F
.63034 .83987 m .62899 .85362 L .63881 .70939 L .183 0 .395 r
F
.63881 .70939 m .63765 .74049 L .6365 .74498 L 0 0 .228 r
F
.63978 .71166 m .63957 .71438 L .63881 .70939 L F
.63957 .71438 m .63856 .71605 L .63881 .70939 L F
.63189 .72662 m .6315 .74292 L .63966 .71176 L .496 0 .502 r
F
.63881 .70939 m .6413 .70506 L .6439 .70186 L .183 0 .395 r
F
.64254 .67404 m .63978 .71166 L .63925 .71042 L 0 0 .228 r
F
.63885 .70899 m .63925 .71042 L .63881 .70939 L F
.64254 .67404 m .63925 .71042 L .63885 .70899 L F
.63189 .72662 m .63966 .71176 L .64254 .67404 L .496 0 .502 r
F
.6321 .70581 m .61155 .66252 L .6177 .64976 L 1 .011 .347 r
F
.63147 .71057 m .61154 .66252 L .6321 .70582 L 1 .017 .333 r
F
.63147 .71057 m .61096 .66344 L .61154 .66252 L F
.63336 .66359 m .61819 .69119 L .62358 .77169 L .496 0 .502 r
F
.6315 .74292 m .62358 .77169 L .62895 .85188 L F
.63336 .66359 m .62358 .77169 L .6315 .74292 L F
.62928 .724 m .62648 .74778 L .63451 .72163 L 1 .255 .62 r
F
.62648 .74778 m .62631 .74922 L .62684 .74743 L F
.62648 .74778 m .62684 .74743 L .63451 .72163 L F
.6315 .74292 m .62895 .85188 L .63774 .73688 L .496 0 .502 r
F
.63957 .71438 m .63765 .74049 L .63856 .71605 L 0 0 .228 r
F
.6315 .74292 m .63774 .73688 L .63966 .71176 L .496 0 .502 r
F
.6255 .72571 m .61958 .77186 L .62631 .74922 L 1 .255 .62 r
F
.6255 .72571 m .62631 .74922 L .62928 .724 L F
.61742 .80663 m .61366 .81631 L .61402 .81524 L 0 0 0 r
F
.61784 .80567 m .61366 .81631 L .61742 .80663 L F
.61366 .81631 m .61343 .81688 L .61402 .81524 L F
.61957 .77187 m .60908 .81551 L .62527 .85981 L .866 .143 .612 r
F
.62902 .86797 m .62527 .85981 L .6293 .87084 L F
.61957 .77187 m .62527 .85981 L .62902 .86797 L F
.62524 .85974 m .61938 .84835 L .61894 .84603 L .945 .006 .366 r
F
.61938 .84835 m .60928 .82873 L .61138 .82275 L F
.61147 .82304 m .61141 .82285 L .61146 .82303 L .684 0 0 r
F
.60908 .81551 m .60839 .82323 L .61138 .82275 L 0 0 .663 r
F
.61141 .82285 m .60908 .81551 L .61138 .82275 L .684 0 0 r
F
.60848 .8233 m .60839 .82323 L .60839 .82323 L 0 0 0 r
F
.60848 .8233 m .60839 .82323 L .60847 .82321 L F
.60849 .82335 m .60839 .82323 L .6084 .82329 L 0 0 .526 r
F
.60928 .82873 m .60839 .82323 L .60848 .8233 L 0 0 0 r
F
.60914 .82419 m .60849 .82335 L .6091 .82418 L 0 0 .526 r
F
.60849 .82335 m .6084 .82329 L .6091 .82418 L F
.6091 .82418 m .6084 .82329 L .60838 .82328 L F
.60928 .82873 m .60846 .82314 L .61124 .82314 L 0 0 0 r
F
.61812 .84433 m .60988 .81805 L .61782 .84325 L .684 0 0 r
F
.60988 .81805 m .60908 .81551 L .61025 .81922 L F
.60988 .81805 m .61025 .81922 L .61782 .84325 L F
.60812 .82361 m .60785 .82332 L .60785 .82332 L .725 0 .545 r
F
.60812 .82361 m .60785 .82332 L .60808 .8233 L F
.60838 .82328 m .60805 .82285 L .60805 .82286 L 0 0 .526 r
F
.6084 .82329 m .60805 .82285 L .60838 .82328 L F
.59253 .84336 m .57323 .87426 L .5976 .83941 L 1 .949 .731 r
F
.59253 .84336 m .56956 .87011 L .57323 .87426 L F
.59206 .84377 m .56956 .87011 L .59253 .84336 L 1 .923 .737 r
F
.59206 .84377 m .56922 .86977 L .56956 .87011 L F
.58869 .84673 m .56921 .86977 L .59206 .84377 L 1 .917 .77 r
F
.60719 .83056 m .58869 .84673 L .59206 .84377 L 0 0 0 r
F
.60928 .82873 m .60709 .83064 L .60719 .83056 L F
.60709 .83064 m .58869 .84673 L .60719 .83056 L F
.61226 .8256 m .60908 .81551 L .61382 .83047 L .684 0 0 r
F
.62126 .86949 m .60928 .82873 L .62511 .86662 L .854 0 .332 r
F
.62126 .86949 m .62511 .86662 L .62789 .87553 L F
.60768 .83481 m .58055 .88528 L .58424 .89187 L 1 .804 .644 r
F
.60265 .83654 m .58055 .88528 L .60768 .83481 L 1 .851 .663 r
F
.62126 .86949 m .60288 .84364 L .60928 .82873 L .854 0 .332 r
F
.61309 .86267 m .60288 .84364 L .62126 .86949 L .669 0 .178 r
F
.62265 .86991 m .61309 .86267 L .62126 .8695 L 0 0 .661 r
F
.62817 .87156 m .61997 .86673 L .62265 .86991 L F
.61997 .86673 m .61309 .86267 L .62265 .86991 L F
.63587 .89919 m .62887 .87731 L .63007 .87874 L .849 0 0 r
F
.60805 .82286 m .59153 .80188 L .59202 .80274 L 0 0 .526 r
F
.60805 .82285 m .59153 .80188 L .60805 .82286 L F
.60608 .82148 m .60625 .8243 L .60683 .8242 L 0 0 .444 r
F
.60608 .82148 m .59721 .81045 L .60625 .8243 L F
.60608 .82148 m .60355 .81774 L .60481 .81991 L F
.60529 .81999 m .60355 .81774 L .60608 .82148 L F
.64781 .70098 m .64587 .704 L .64328 .70867 L .629 0 .379 r
F
.64587 .704 m .63919 .71437 L .64173 .71084 L F
.64587 .704 m .64173 .71084 L .64328 .70867 L F
.63919 .71437 m .63451 .72163 L .64081 .71231 L F
.63919 .71437 m .64081 .71231 L .64328 .70867 L F
.64197 .70888 m .64125 .709 L .64254 .70675 L .183 0 .395 r
F
.64197 .70888 m .64254 .70675 L .64892 .69569 L F
.60355 .81774 m .59202 .80274 L .60481 .81991 L 0 0 .444 r
F
.63691 .82243 m .6369 .82242 L .63697 .82241 L 1 .002 .195 r
F
.63697 .82241 m .63617 .8218 L .63661 .82161 L F
.658 .7567 m .63217 .82352 L .63697 .82241 L 1 .631 .591 r
F
.63701 .82251 m .63691 .82243 L .63697 .82241 L 1 .002 .195 r
F
.63697 .82241 m .63782 .82206 L .66419 .75198 L 1 .631 .591 r
F
.66078 .87505 m .63227 .8237 L .63701 .82251 L 1 .002 .195 r
F
.62276 .79236 m .62218 .79365 L .62319 .80189 L .844 0 .037 r
F
.64125 .709 m .6439 .70186 L .64892 .69569 L .183 0 .395 r
F
.6554 .67758 m .65772 .67349 L .65781 .6731 L 1 .114 .414 r
F
.66681 .6651 m .64807 .72958 L .6555 .71834 L 1 .33 .522 r
F
.66502 .68275 m .64971 .6937 L .65781 .6731 L .118 0 .161 r
F
.6582 .67238 m .65781 .6731 L .65813 .67228 L F
.65821 .67247 m .65794 .67287 L .65815 .67296 L 1 .693 .612 r
F
.65794 .67287 m .65779 .67311 L .65781 .6731 L F
.65794 .67287 m .65781 .6731 L .65815 .67296 L F
.65821 .67241 m .65781 .6731 L .6582 .67238 L .118 0 .161 r
F
.65835 .67225 m .65815 .67296 L .66816 .65576 L 1 .683 .598 r
F
.65821 .67241 m .65813 .67228 L .65835 .67225 L .118 0 .161 r
F
.67478 .63365 m .66054 .60784 L .68313 .61595 L .473 0 .297 r
F
.6636 .6259 m .65821 .67241 L .67334 .61987 L 1 .693 .612 r
F
.65821 .67241 m .65815 .67296 L .65835 .67225 L F
.65821 .67241 m .65835 .67225 L .67334 .61987 L F
.65822 .67242 m .65821 .67241 L .65835 .67225 L .118 0 .161 r
F
.66502 .68275 m .65781 .6731 L .65821 .67241 L F
.64971 .6937 m .64768 .68929 L .65781 .6731 L .314 0 .327 r
F
.64933 .67656 m .64768 .68929 L .65781 .6731 L 1 .114 .414 r
F
.6636 .6259 m .64933 .67656 L .65779 .67311 L 1 .693 .612 r
F
.6636 .6259 m .65779 .67311 L .65821 .67247 L F
.65997 .66659 m .65835 .67225 L .66816 .65576 L 1 .683 .598 r
F
.66816 .65576 m .6592 .67116 L .66748 .6605 L F
.66816 .65576 m .66681 .6651 L .67044 .65298 L F
.67466 .66961 m .65835 .67225 L .66816 .65576 L .281 0 .225 r
F
.66502 .68275 m .65822 .67242 L .67466 .66961 L .118 0 .161 r
F
.65822 .67242 m .65835 .67225 L .67466 .66961 L F
.67334 .61987 m .65997 .66659 L .66816 .65576 L 1 .683 .598 r
F
.68313 .61595 m .66765 .58998 L .69142 .59891 L .481 0 .294 r
F
.68313 .61595 m .66054 .60784 L .66765 .58998 L F
.67334 .61987 m .66816 .65576 L .68294 .61124 L 1 .683 .598 r
F
.66816 .65576 m .67044 .65298 L .68294 .61124 L F
.66828 .65601 m .66816 .65576 L .67044 .65298 L .281 0 .225 r
F
.67466 .66961 m .66828 .65601 L .6842 .65572 L F
.66828 .65601 m .67044 .65298 L .6842 .65572 L F
.68294 .61124 m .67128 .65018 L .67786 .64086 L 1 .609 .587 r
F
.69162 .62075 m .68313 .61595 L .69693 .61223 L .453 0 .277 r
F
.68294 .61124 m .67786 .64086 L .69243 .6007 L 1 .609 .587 r
F
.67786 .64086 m .68129 .6364 L .69243 .6007 L F
.678 .64121 m .67786 .64086 L .68129 .6364 L .37 0 .252 r
F
.67786 .64086 m .68129 .6364 L .68129 .6364 L F
.6842 .65572 m .678 .64121 L .69365 .64161 L F
.678 .64121 m .68129 .6364 L .69365 .64161 L F
.69243 .6007 m .68179 .6348 L .68745 .62648 L 1 .532 .579 r
F
.69243 .6007 m .68745 .62648 L .70194 .58862 L F
.68745 .62648 m .69162 .62075 L .70194 .58862 L F
.68759 .62681 m .68745 .62648 L .69162 .62075 L .42 0 .267 r
F
.68775 .6272 m .68759 .62681 L .69188 .62089 L F
.68759 .62681 m .69162 .62075 L .69188 .62089 L F
.69681 .61278 m .70152 .6056 L .70181 .60469 L 1 .464 .571 r
F
.69718 .61184 m .70181 .60469 L .71133 .57553 L F
.69681 .61278 m .70181 .60469 L .69718 .61184 L F
.69681 .61278 m .69244 .63339 L .70152 .6056 L F
.70085 .62175 m .67786 .68971 L .6852 .68076 L 1 .409 .558 r
F
.70315 .62727 m .69162 .62075 L .69693 .61223 L .453 0 .277 r
F
.69195 .61974 m .69162 .62075 L .69693 .61223 L 1 .464 .571 r
F
.70194 .58862 m .69195 .61974 L .69693 .61223 L F
.69703 .61248 m .69693 .61223 L .70152 .6056 L .453 0 .277 r
F
.70194 .58862 m .69693 .61223 L .71133 .57553 L 1 .464 .571 r
F
.69693 .61223 m .69716 .6119 L .71133 .57553 L F
.70636 .5982 m .70145 .60555 L .70625 .59794 L .476 0 .284 r
F
.71257 .61292 m .70152 .6056 L .70636 .5982 L F
.70152 .6056 m .70145 .60555 L .70636 .5982 L F
.70175 .60489 m .70152 .6056 L .70625 .59794 L 1 .409 .564 r
F
.69717 .6128 m .69703 .61248 L .7017 .60572 L .453 0 .277 r
F
.69703 .61248 m .70152 .6056 L .7017 .60572 L F
.69365 .64161 m .68775 .6272 L .70315 .62727 L .42 0 .267 r
F
.68775 .6272 m .69188 .62089 L .70315 .62727 L F
.71133 .57553 m .70175 .60489 L .70625 .59794 L 1 .409 .564 r
F
.70633 .59812 m .70625 .59794 L .71109 .59063 L .476 0 .284 r
F
.71133 .57553 m .70625 .59794 L .72062 .56168 L 1 .409 .564 r
F
.70625 .59794 m .70647 .59762 L .72062 .56168 L F
.71127 .59009 m .71109 .59063 L .71543 .58354 L 1 .363 .557 r
F
.70643 .59837 m .70633 .59812 L .71122 .59072 L .476 0 .284 r
F
.70633 .59812 m .71109 .59063 L .71122 .59072 L F
.70315 .62727 m .69717 .6128 L .71257 .61292 L .453 0 .277 r
F
.69717 .6128 m .7017 .60572 L .71257 .61292 L F
.72062 .56168 m .71127 .59009 L .71543 .58354 L 1 .363 .557 r
F
.72062 .56168 m .71543 .58354 L .72981 .54723 L F
.71543 .58354 m .72043 .57569 L .72981 .54723 L F
.71547 .58364 m .71543 .58354 L .72043 .57569 L .493 0 .291 r
F
.71257 .61292 m .70643 .59837 L .72191 .59855 L .476 0 .284 r
F
.70643 .59837 m .71122 .59072 L .72191 .59855 L F
.71556 .58384 m .71547 .58364 L .72051 .57575 L .493 0 .291 r
F
.71547 .58364 m .72043 .57569 L .72051 .57575 L F
.72191 .59855 m .71556 .58384 L .73115 .58411 L F
.71556 .58384 m .72051 .57575 L .73115 .58411 L F
.72473 .56955 m .72449 .56901 L .7298 .56088 L .507 0 .297 r
F
.72449 .56901 m .72956 .56068 L .7298 .56088 L F
.73115 .58411 m .72473 .56955 L .74032 .56958 L F
.72473 .56955 m .7298 .56088 L .74032 .56958 L F
.74032 .56958 m .73347 .5544 L .74939 .55493 L .517 0 .302 r
F
.73347 .5544 m .73859 .54561 L .74939 .55493 L F
.74218 .53925 m .74735 .5303 L .75677 .50124 L 1 .266 .536 r
F
.74939 .55493 m .74218 .53925 L .75837 .54014 L .526 0 .308 r
F
.74218 .53925 m .74735 .5303 L .75837 .54014 L F
.70774 .56573 m .68854 .53799 L .71578 .54928 L .496 0 .298 r
F
.70774 .56573 m .68165 .55525 L .68854 .53799 L F
.60001 .74793 m .56408 .68264 L .60331 .74017 L 1 .009 .286 r
F
.60001 .74793 m .56225 .69456 L .56408 .68264 L F
.58447 .60732 m .55593 .62746 L .58774 .59498 L .214 0 .136 r
F
.61376 .5911 m .58774 .59498 L .61835 .57654 L .366 0 .201 r
F
.61376 .5911 m .58447 .60732 L .58774 .59498 L F
.64161 .58636 m .61835 .57654 L .64745 .56989 L .459 0 .255 r
F
.64161 .58636 m .61376 .5911 L .61835 .57654 L F
.42832 .60333 m .3937 .5744 L .42445 .58956 L .972 0 .186 r
F
.45903 .63833 m .42445 .58956 L .4566 .62179 L 1 0 .164 r
F
.45903 .63833 m .42832 .60333 L .42445 .58956 L F
.28866 .51817 m .25839 .44621 L .28024 .50123 L 0 0 .354 r
F
.28866 .51817 m .26757 .46579 L .25839 .44621 L F
.26757 .46578 m .24071 .40321 L .25839 .4462 L 0 0 .337 r
F
.3937 .5744 m .36463 .57483 L .35815 .56123 L .933 0 .248 r
F
.39895 .5875 m .36463 .57483 L .3937 .5744 L .901 0 .226 r
F
.42832 .60333 m .39895 .5875 L .3937 .5744 L .972 0 .186 r
F
.35815 .56123 m .32981 .57674 L .32218 .56309 L .899 0 .288 r
F
.36463 .57483 m .32981 .57674 L .35815 .56123 L .876 0 .279 r
F
.49091 .69051 m .4566 .62179 L .48994 .66566 L 1 .015 .235 r
F
.49091 .69051 m .45903 .63833 L .4566 .62179 L F
.55593 .62746 m .52316 .67703 L .5236 .66565 L .21 0 .204 r
F
.55405 .63757 m .52316 .67703 L .55593 .62746 L .121 0 .151 r
F
.58447 .60732 m .55405 .63757 L .55593 .62746 L .214 0 .136 r
F
.66765 .58998 m .64745 .56989 L .67469 .57253 L .496 0 .286 r
F
.66765 .58998 m .64161 .58636 L .64745 .56989 L F
.59668 .75544 m .56225 .69456 L .60001 .74793 L 1 .007 .283 r
F
.59668 .75544 m .56041 .70648 L .56225 .69456 L F
.69962 .58224 m .68165 .55525 L .70774 .56573 L .492 0 .295 r
F
.69962 .58224 m .67469 .57253 L .68165 .55525 L F
.76644 .46055 m .75677 .50124 L .776 .4423 L .992 .123 .511 r
F
.78111 .41767 m .776 .4423 L .79125 .39731 L .888 .01 .461 r
F
.78111 .41767 m .76644 .46055 L .776 .4423 L F
.25057 .42426 m .22738 .37407 L .24071 .40321 L 0 0 .309 r
F
.26757 .46578 m .25057 .42426 L .24071 .40321 L 0 0 .337 r
F
.76644 .46055 m .74788 .51694 L .75677 .50124 L .992 .123 .511 r
F
.58116 .61841 m .55405 .63757 L .58447 .60732 L .137 0 .057 r
F
.60911 .6049 m .58447 .60732 L .61376 .5911 L .362 0 .171 r
F
.60911 .6049 m .58116 .61841 L .58447 .60732 L F
.29716 .53511 m .26757 .46579 L .28866 .51817 L 0 0 .354 r
F
.6357 .60267 m .61376 .5911 L .64161 .58636 L .476 0 .248 r
F
.6357 .60267 m .60911 .6049 L .61376 .5911 L F
.43226 .61534 m .39895 .5875 L .42832 .60333 L .916 0 .136 r
F
.29716 .53511 m .27685 .48538 L .26757 .46579 L 0 0 .354 r
F
.27685 .48537 m .25057 .42426 L .26757 .46578 L 0 0 .353 r
F
.39895 .5875 m .3712 .58745 L .36463 .57483 L .901 0 .226 r
F
.40427 .59926 m .3712 .58745 L .39895 .5875 L .857 0 .195 r
F
.43226 .61534 m .40427 .59926 L .39895 .5875 L .916 0 .136 r
F
.36463 .57483 m .33755 .58972 L .32981 .57674 L .876 0 .279 r
F
.3712 .58745 m .33755 .58972 L .36463 .57483 L .846 0 .267 r
F
.79177 .38935 m .79125 .39731 L .80235 .36733 L .779 0 .379 r
F
.79177 .38935 m .78111 .41767 L .79125 .39731 L F
.58116 .61841 m .55213 .64571 L .55405 .63757 L .137 0 .057 r
F
.75675 .47839 m .74788 .51694 L .76644 .46055 L 1 .154 .522 r
F
.77086 .43761 m .76644 .46055 L .78111 .41767 L .895 .019 .476 r
F
.77086 .43761 m .75675 .47839 L .76644 .46055 L F
.75675 .47839 m .7389 .53229 L .74788 .51694 L 1 .154 .522 r
F
.66054 .60784 m .64161 .58636 L .66765 .58998 L .513 0 .287 r
F
.66054 .60784 m .6357 .60267 L .64161 .58636 L F
.23989 .40018 m .24837 .41692 L .23782 .39566 L 0 0 .34 r
F
.26053 .44518 m .24837 .41692 L .23989 .40018 L F
.25058 .42181 m .25904 .4378 L .24837 .41692 L 0 0 .378 r
F
.27061 .466 m .25904 .4378 L .25058 .42181 L F
.26983 .45824 m .26794 .45464 L .25904 .4378 L 0 0 .374 r
F
.25904 .4378 m .25728 .43451 L .24837 .41692 L 0 0 .319 r
F
.25057 .42426 m .23782 .39566 L .22933 .37829 L 0 0 .309 r
F
.26053 .44518 m .23782 .39566 L .25057 .42426 L 0 0 .34 r
F
.27061 .466 m .24837 .41692 L .26053 .44518 L 0 0 .378 r
F
.25728 .43451 m .24048 .40311 L .24837 .41692 L 0 0 .319 r
F
.26794 .45464 m .25161 .42347 L .25904 .4378 L 0 0 .374 r
F
.24837 .41692 m .24672 .41389 L .23782 .39566 L .651 0 0 r
F
.24672 .41389 m .22946 .38216 L .23782 .39566 L F
.22933 .37829 m .23782 .39566 L .22738 .37407 L 0 0 .309 r
F
.27685 .48537 m .26053 .44518 L .25057 .42426 L 0 0 .353 r
F
.59331 .7626 m .56041 .70648 L .59668 .75544 L 1 .005 .28 r
F
.59331 .7626 m .55854 .71837 L .56041 .70648 L F
.69142 .59891 m .67469 .57253 L .69962 .58224 L .487 0 .294 r
F
.69142 .59891 m .66765 .58998 L .67469 .57253 L F
.57779 .62802 m .55213 .64571 L .58116 .61841 L .013 0 0 r
F
.6044 .61774 m .58116 .61841 L .60911 .6049 L .362 0 .132 r
F
.6044 .61774 m .57779 .62802 L .58116 .61841 L F
.30575 .55213 m .27685 .48538 L .29716 .53511 L 0 0 .349 r
F
.43627 .62507 m .40427 .59926 L .43226 .61534 L .836 0 .066 r
F
.62972 .61884 m .60911 .6049 L .6357 .60267 L .509 0 .24 r
F
.62972 .61884 m .6044 .61774 L .60911 .6049 L F
.23782 .39566 m .21856 .36071 L .22738 .37407 L .686 0 0 r
F
.30575 .55213 m .28623 .50508 L .27685 .48538 L 0 0 .349 r
F
.28623 .50507 m .26053 .44518 L .27685 .48537 L 0 0 .372 r
F
.77189 .58687 m .75837 .54014 L .78195 .57464 L .554 0 .307 r
F
.77189 .58687 m .74939 .55493 L .75837 .54014 L F
.28633 .57948 m .25127 .60979 L .27768 .5661 L .866 0 .322 r
F
.40427 .59926 m .37786 .59887 L .3712 .58745 L .857 0 .195 r
F
.40968 .60942 m .37786 .59887 L .40427 .59926 L .796 0 .153 r
F
.43627 .62507 m .40968 .60942 L .40427 .59926 L .836 0 .066 r
F
.78107 .41097 m .78111 .41767 L .79177 .38935 L .782 0 .39 r
F
.78107 .41097 m .77086 .43761 L .78111 .41767 L F
.3712 .58745 m .34538 .60185 L .33755 .58972 L .846 0 .267 r
F
.37786 .59887 m .34538 .60185 L .3712 .58745 L .805 0 .252 r
F
.57779 .62802 m .55018 .65145 L .55213 .64571 L .013 0 0 r
F
.6997 .66286 m .67646 .74266 L .70686 .6538 L 1 .503 .568 r
F
.79822 .37607 m .80235 .36733 L .80912 .35291 L 0 0 0 r
F
.79822 .37607 m .79177 .38935 L .80235 .36733 L F
.74696 .49574 m .7389 .53229 L .75675 .47839 L 1 .193 .535 r
F
.74696 .49574 m .72981 .54723 L .7389 .53229 L F
.76049 .45705 m .75675 .47839 L .77086 .43761 L .904 .032 .492 r
F
.76049 .45705 m .74696 .49574 L .75675 .47839 L F
.55475 .7415 m .5232 .69894 L .55666 .73012 L .966 .005 .341 r
F
.55475 .7415 m .52277 .71791 L .5232 .69894 L F
.28623 .50507 m .27061 .466 L .26053 .44518 L 0 0 .372 r
F
.58991 .76926 m .55854 .71837 L .59331 .7626 L 1 .003 .275 r
F
.58991 .76926 m .55666 .73012 L .55854 .71837 L F
.65336 .62657 m .6357 .60267 L .66054 .60784 L .544 0 .293 r
F
.65336 .62657 m .62972 .61884 L .6357 .60267 L F
.57442 .63584 m .55018 .65146 L .57779 .62803 L 0 0 0 r
F
.59968 .62917 m .57779 .62803 L .6044 .61774 L .367 0 .078 r
F
.59968 .62917 m .57442 .63584 L .57779 .62803 L F
.31442 .56933 m .28623 .50508 L .30575 .55213 L 0 0 .337 r
F
.23782 .39566 m .22946 .38216 L .21856 .36071 L .686 0 0 r
F
.76174 .59888 m .74939 .55493 L .77189 .58687 L .543 0 .301 r
F
.76174 .59888 m .74032 .56958 L .74939 .55493 L F
.40851 .82151 m .3684 .72883 L .40436 .82343 L .034 0 .563 r
F
.40851 .82151 m .37383 .73233 L .3684 .72883 L F
.28633 .57948 m .26107 .62134 L .25127 .60979 L .866 0 .322 r
F
.29507 .5926 m .26107 .62134 L .28633 .57948 L .863 0 .321 r
F
.31442 .56933 m .2957 .52503 L .28623 .50508 L 0 0 .337 r
F
.29569 .52502 m .27061 .466 L .28623 .50507 L 0 0 .393 r
F
.62375 .6346 m .6044 .61774 L .62971 .61885 L .563 0 .233 r
F
.62375 .6346 m .59968 .62917 L .6044 .61774 L F
.77025 .43213 m .77086 .43761 L .78107 .41097 L .784 0 .403 r
F
.77025 .43213 m .76049 .45705 L .77086 .43761 L F
.40968 .60942 m .38462 .60884 L .37786 .59887 L .796 0 .153 r
F
.41509 .61761 m .38462 .60884 L .40968 .60942 L .715 0 .09 r
F
.37786 .59887 m .35331 .61288 L .34538 .60185 L .805 0 .252 r
F
.38462 .60884 m .35331 .61288 L .37786 .59887 L .749 0 .229 r
F
.6997 .66286 m .67035 .74733 L .67646 .74266 L 1 .503 .568 r
F
.69248 .67184 m .67035 .74733 L .6997 .66286 L 1 .505 .57 r
F
.73705 .51251 m .72981 .54723 L .74696 .49574 L 1 .246 .549 r
F
.73705 .51251 m .72062 .56168 L .72981 .54723 L F
.7872 .39892 m .79177 .38935 L .79822 .37607 L 0 0 0 r
F
.7872 .39892 m .78107 .41097 L .79177 .38935 L F
.74999 .4759 m .74696 .49574 L .76049 .45705 L .917 .054 .511 r
F
.74999 .4759 m .73705 .51251 L .74696 .49574 L F
.28079 .48674 m .25904 .4378 L .27061 .466 L 0 0 .422 r
F
.29569 .52502 m .28079 .48674 L .27061 .466 L 0 0 .393 r
F
.49405 .71566 m .46667 .66417 L .46408 .66195 L 0 0 .45 r
F
.59489 .63895 m .57442 .63584 L .59968 .62917 L .379 0 .001 r
F
.59489 .63895 m .57101 .64183 L .57442 .63584 L F
.4127 .81888 m .37383 .73233 L .40851 .82151 L .06 0 .573 r
F
.4127 .81888 m .3793 .73532 L .37383 .73233 L F
.58647 .77523 m .55666 .73012 L .58991 .76926 L 1 .001 .266 r
F
.58647 .77523 m .55475 .7415 L .55666 .73012 L F
.24837 .41692 m .24048 .40311 L .22946 .38216 L .651 0 0 r
F
.75151 .61066 m .74032 .56958 L .76174 .59888 L .53 0 .293 r
F
.75151 .61066 m .73115 .58411 L .74032 .56958 L F
.29507 .5926 m .27094 .63285 L .26107 .62134 L .863 0 .321 r
F
.30389 .6054 m .27094 .63285 L .29507 .5926 L .861 0 .321 r
F
.55281 .75207 m .52277 .71791 L .55475 .7415 L .884 .001 .346 r
F
.55281 .75207 m .52234 .7377 L .52277 .71791 L F
.32317 .5869 m .2957 .52503 L .31442 .56933 L 0 0 .312 r
F
.64624 .64676 m .62971 .61885 L .65336 .62657 L .605 0 .304 r
F
.64624 .64676 m .62375 .6346 L .62971 .61885 L F
.22946 .38216 m .21443 .36467 L .21856 .36071 L .791 0 0 r
F
.41509 .61761 m .39137 .61699 L .38462 .60884 L .715 0 .09 r
F
.42058 .62382 m .39137 .61699 L .41509 .61761 L .616 0 0 r
F
.7593 .45273 m .76049 .45705 L .77025 .43213 L .785 0 .418 r
F
.7593 .45273 m .74999 .4759 L .76049 .45705 L F
.6177 .64976 m .59968 .62917 L .62375 .6346 L .651 0 .222 r
F
.6177 .64976 m .59489 .63895 L .59968 .62917 L F
.38462 .60884 m .36135 .62245 L .35331 .61288 L .749 0 .229 r
F
.39137 .61699 m .36135 .62245 L .38462 .60884 L .669 0 .191 r
F
.32317 .5869 m .30525 .54548 L .2957 .52503 L 0 0 .312 r
F
.30525 .54547 m .28079 .48674 L .29569 .52502 L 0 0 .419 r
F
.69248 .67184 m .66419 .75198 L .67035 .74733 L 1 .505 .57 r
F
.6852 .68077 m .66419 .75198 L .69248 .67184 L 1 .501 .571 r
F
.72702 .52859 m .72062 .56168 L .73705 .51251 L 1 .316 .565 r
F
.72702 .52859 m .71133 .57553 L .72062 .56168 L F
.77607 .4214 m .78107 .41097 L .7872 .39892 L 0 0 0 r
F
.77607 .4214 m .77025 .43213 L .78107 .41097 L F
.73937 .49403 m .73705 .51251 L .74999 .4759 L .937 .09 .532 r
F
.73937 .49403 m .72702 .52859 L .73705 .51251 L F
.41692 .81537 m .3793 .73532 L .4127 .81888 L .088 0 .584 r
F
.41692 .81537 m .38483 .73773 L .3793 .73532 L F
.80025 .37773 m .80912 .35291 L .81135 .35403 L 0 0 0 r
F
.80025 .37773 m .79822 .37607 L .80912 .35291 L F
.49521 .68768 m .46667 .66417 L .49405 .71566 L .165 0 .733 r
F
.49521 .68768 m .46933 .66117 L .46667 .66417 L F
.56754 .64583 m .54625 .65552 L .57101 .64183 L .487 .002 .785 r
F
.59003 .64637 m .57101 .64183 L .59489 .63895 L .383 0 0 r
F
.59003 .64637 m .56754 .64583 L .57101 .64183 L F
.28079 .48674 m .26983 .45824 L .25904 .4378 L 0 0 .422 r
F
.29108 .50746 m .26983 .45824 L .28079 .48674 L 0 0 .474 r
F
.30525 .54547 m .29108 .50746 L .28079 .48674 L 0 0 .419 r
F
.47201 .65609 m .44438 .63629 L .46933 .66117 L 0 0 .641 r
F
.47201 .65609 m .44852 .63817 L .44438 .63629 L F
.54625 .65552 m .52086 .67671 L .52134 .68621 L 1 .917 .723 r
F
.54424 .65465 m .52086 .67671 L .54625 .65552 L 1 .847 .751 r
F
.56754 .64583 m .54424 .65465 L .54625 .65552 L .487 .002 .785 r
F
.56722 .64609 m .54426 .65465 L .56754 .64583 L .561 .084 .839 r
F
.54426 .65465 m .54424 .65465 L .54836 .65309 L F
.54426 .65465 m .54836 .65309 L .56754 .64583 L F
.56754 .64583 m .56696 .64605 L .56754 .64583 L .487 .002 .785 r
F
.56696 .64605 m .54424 .65465 L .56754 .64583 L F
.7412 .62217 m .73115 .58411 L .75151 .61066 L .514 0 .284 r
F
.7412 .62217 m .72191 .59855 L .73115 .58411 L F
.25356 .42719 m .26287 .44313 L .25161 .42347 L 0 0 .374 r
F
.26983 .45824 m .26287 .44313 L .25356 .42719 L F
.26495 .44722 m .27424 .46196 L .26287 .44313 L 0 0 .441 r
F
.28074 .47814 m .27424 .46196 L .26495 .44722 L F
.27648 .46648 m .28575 .47981 L .27424 .46196 L 0 0 .515 r
F
.29177 .49737 m .28575 .47981 L .27648 .46648 L F
.30293 .51568 m .29737 .49647 L .28575 .47981 L 0 0 .588 r
F
.29737 .49647 m .29553 .49388 L .28575 .47981 L 0 0 .479 r
F
.30293 .51568 m .28575 .47981 L .29177 .49737 L 0 0 .588 r
F
.29553 .49388 m .28351 .47697 L .28575 .47981 L 0 0 .479 r
F
.28575 .47981 m .28405 .47752 L .27424 .46196 L .577 0 0 r
F
.28074 .47814 m .26287 .44313 L .26983 .45824 L 0 0 .441 r
F
.29177 .49737 m .27424 .46196 L .28074 .47814 L 0 0 .515 r
F
.28405 .47752 m .2717 .4609 L .27424 .46196 L .577 0 0 r
F
.27424 .46196 m .27267 .45992 L .26287 .44313 L .659 0 0 r
F
.27267 .45992 m .26002 .44354 L .26287 .44313 L F
.26287 .44313 m .2614 .4413 L .25161 .42347 L .713 0 0 r
F
.25904 .4378 m .25161 .42347 L .2423 .40653 L 0 0 .319 r
F
.2614 .4413 m .24845 .42507 L .25161 .42347 L .713 0 0 r
F
.2423 .40653 m .25161 .42347 L .24048 .40311 L 0 0 .319 r
F
.30389 .6054 m .28088 .64439 L .27094 .63285 L .861 0 .321 r
F
.31281 .61784 m .28088 .64439 L .30389 .6054 L .86 0 .323 r
F
.22946 .38216 m .22566 .38549 L .21443 .36467 L .791 0 0 r
F
.24048 .40311 m .22566 .38549 L .22946 .38216 L .773 0 0 r
F
.42058 .62382 m .39821 .6232 L .39137 .61699 L .616 0 0 r
F
.42614 .628 m .39821 .6232 L .42058 .62382 L .496 0 0 r
F
.58298 .78023 m .55475 .7415 L .58647 .77523 L .951 0 .247 r
F
.58298 .78023 m .55281 .75207 L .55475 .7415 L F
.52086 .67671 m .49405 .71567 L .52134 .68621 L 1 .28 .6 r
F
.39137 .61699 m .36938 .62997 L .36135 .62245 L .669 0 .191 r
F
.39821 .6232 m .36938 .62997 L .39137 .61699 L .56 0 .118 r
F
.74823 .47265 m .74999 .4759 L .7593 .45273 L .786 0 .435 r
F
.74823 .47265 m .73937 .49403 L .74999 .4759 L F
.6852 .68077 m .658 .7567 L .66419 .75198 L 1 .501 .571 r
F
.67785 .68972 m .658 .7567 L .6852 .68077 L 1 .487 .571 r
F
.49634 .67146 m .46933 .66117 L .49521 .68768 L .416 .106 .795 r
F
.49634 .67146 m .47201 .65609 L .46933 .66117 L F
.61155 .66252 m .59489 .63895 L .6177 .64976 L .757 0 .196 r
F
.61155 .66252 m .59003 .64637 L .59489 .63895 L F
.42118 .81076 m .38483 .73773 L .41692 .81537 L .12 0 .597 r
F
.42118 .81076 m .39041 .73949 L .38483 .73773 L F
.31488 .56685 m .29108 .50746 L .30525 .54547 L 0 0 .453 r
F
.71688 .5438 m .71133 .57553 L .72702 .52859 L 1 .408 .582 r
F
.71688 .5438 m .70194 .58862 L .71133 .57553 L F
.76482 .44344 m .77025 .43213 L .77607 .4214 L 0 0 0 r
F
.76482 .44344 m .7593 .45273 L .77025 .43213 L F
.72863 .5113 m .72702 .52859 L .73937 .49403 L .968 .147 .557 r
F
.72863 .5113 m .71688 .5438 L .72702 .52859 L F
.55085 .76114 m .52234 .7377 L .55281 .75207 L .782 0 .331 r
F
.55085 .76114 m .5219 .75597 L .52234 .7377 L F
.52086 .67671 m .49521 .68768 L .49405 .71567 L 1 .28 .6 r
F
.52039 .66745 m .49521 .68768 L .52086 .67671 L 1 .413 .669 r
F
.54424 .65465 m .52039 .66745 L .52086 .67671 L 1 .847 .751 r
F
.79081 .62839 m .78195 .57464 L .80189 .61935 L .594 0 .307 r
F
.79081 .62839 m .77189 .58687 L .78195 .57464 L F
.78905 .40123 m .79822 .37607 L .80025 .37773 L 0 0 0 r
F
.78905 .40123 m .7872 .39892 L .79822 .37607 L F
.47226 .65558 m .44852 .63817 L .47201 .65609 L 0 0 .73 r
F
.47226 .65558 m .44891 .63824 L .44852 .63817 L F
.54406 .6545 m .52039 .66745 L .54424 .65465 L 1 .882 .765 r
F
.56721 .6461 m .54406 .6545 L .54424 .65465 L .561 .084 .839 r
F
.56308 .6476 m .54406 .6545 L .56721 .6461 L F
.56491 .64747 m .54406 .6545 L .56722 .6461 L .525 .12 .869 r
F
.54406 .6545 m .54406 .6545 L .54439 .65438 L F
.54406 .6545 m .54439 .65438 L .56722 .6461 L F
.56722 .64609 m .56308 .6476 L .56721 .6461 L .561 .084 .839 r
F
.58957 .64691 m .56754 .64583 L .59003 .64637 L .329 0 0 r
F
.58957 .64691 m .56722 .64609 L .56754 .64583 L F
.47404 .65199 m .44891 .63824 L .47226 .65558 L .008 0 .778 r
F
.47404 .65199 m .45168 .63831 L .44891 .63824 L F
.54406 .6545 m .52034 .66664 L .52039 .66745 L 1 .882 .765 r
F
.54272 .65314 m .52034 .66664 L .54406 .6545 L 1 .827 .786 r
F
.56491 .64747 m .54272 .65314 L .54406 .6545 L .525 .12 .869 r
F
.58632 .6499 m .56722 .6461 L .58957 .64691 L .335 0 0 r
F
.58632 .6499 m .56491 .64747 L .56722 .6461 L F
.40823 .83845 m .36415 .90884 L .40418 .83357 L .156 0 .152 r
F
.49644 .67026 m .47201 .65609 L .49634 .67146 L .442 .13 .794 r
F
.49644 .67026 m .47226 .65558 L .47201 .65609 L F
.49718 .66279 m .47226 .65558 L .49644 .67026 L .495 .218 .816 r
F
.49718 .66279 m .47404 .65199 L .47226 .65558 L F
.31281 .61784 m .29089 .65604 L .28088 .64439 L .86 0 .323 r
F
.32181 .62981 m .29089 .65604 L .31281 .61784 L .862 0 .328 r
F
.29108 .50746 m .28074 .47814 L .26983 .45824 L 0 0 .474 r
F
.30147 .52822 m .28074 .47814 L .29108 .50746 L 0 0 .531 r
F
.31488 .56685 m .30147 .52822 L .29108 .50746 L 0 0 .453 r
F
.24048 .40311 m .23699 .40567 L .22566 .38549 L .773 0 0 r
F
.25161 .42347 m .23699 .40567 L .24048 .40311 L .748 0 0 r
F
.7308 .63341 m .72191 .59855 L .7412 .62217 L .494 0 .273 r
F
.7308 .63341 m .71257 .61292 L .72191 .59855 L F
.52039 .66745 m .49634 .67147 L .49521 .68768 L 1 .413 .669 r
F
.52034 .66664 m .49634 .67146 L .52039 .66745 L 1 .52 .708 r
F
.52034 .66664 m .49645 .67026 L .49634 .67146 L F
.52003 .6613 m .49645 .67026 L .52034 .66664 L 1 .53 .731 r
F
.54272 .65314 m .52003 .6613 L .52034 .66664 L 1 .827 .786 r
F
.39821 .6232 m .37753 .63501 L .36938 .62997 L .56 0 .118 r
F
.40515 .62729 m .37753 .63501 L .39821 .6232 L .409 0 0 r
F
.26106 .62134 m .22854 .66265 L .25127 .60979 L .834 0 .32 r
F
.42548 .80488 m .39041 .73949 L .42118 .81076 L .154 0 .612 r
F
.42548 .80488 m .39603 .74055 L .39041 .73949 L F
.67785 .68972 m .65176 .76159 L .658 .7567 L 1 .487 .571 r
F
.67045 .69882 m .65176 .76159 L .67785 .68972 L 1 .457 .568 r
F
.73703 .49174 m .73937 .49403 L .74823 .47265 L .787 0 .455 r
F
.73703 .49174 m .72863 .5113 L .73937 .49403 L F
.54069 .6503 m .52003 .6613 L .54272 .65314 L .929 .734 .819 r
F
.56137 .64781 m .56052 .64859 L .56491 .64747 L .491 .191 .895 r
F
.58131 .65143 m .56491 .64747 L .57751 .6489 L .242 0 0 r
F
.58131 .65143 m .57751 .6489 L .58632 .6499 L F
.60034 .66625 m .59184 .65634 L .6068 .66782 L .685 0 0 r
F
.59184 .65634 m .58632 .6499 L .59547 .65791 L F
.59184 .65634 m .59547 .65791 L .6068 .66782 L F
.60034 .66625 m .58131 .65143 L .58632 .6499 L F
.59375 .6584 m .58131 .65143 L .60034 .66625 L .382 0 0 r
F
.59375 .6584 m .58561 .65428 L .58289 .65247 L F
.58416 .65302 m .58289 .65247 L .58131 .65143 L F
.59375 .6584 m .58289 .65247 L .58416 .65302 L F
.58131 .65143 m .56137 .64781 L .56491 .64747 L .242 0 0 r
F
.57624 .64954 m .56137 .64781 L .5648 .64843 L .003 0 .745 r
F
.57624 .64954 m .5648 .64843 L .58131 .65143 L F
.58561 .65428 m .57624 .64954 L .58131 .65143 L .382 0 0 r
F
.6068 .66782 m .58632 .6499 L .58957 .64691 L .786 0 .127 r
F
.58825 .6507 m .57624 .64954 L .59375 .6584 L .162 .001 .84 r
F
.58713 .64915 m .57624 .64954 L .58825 .6507 L F
.57624 .64954 m .56226 .64698 L .56137 .64781 L .003 0 .745 r
F
.56226 .64698 m .55779 .64616 L .56137 .64781 L F
.56137 .64781 m .54272 .65314 L .56052 .64859 L .491 .191 .895 r
F
.56137 .64781 m .54069 .6503 L .54272 .65314 L F
.47675 .64671 m .45168 .63831 L .47404 .65199 L .19 .005 .846 r
F
.47675 .64671 m .4559 .6372 L .45168 .63831 L F
.52003 .6613 m .49718 .66279 L .49645 .67026 L 1 .53 .731 r
F
.49829 .6539 m .47404 .65199 L .49718 .66279 L .542 .318 .839 r
F
.49829 .6539 m .47675 .64671 L .47404 .65199 L F
.61096 .66344 m .59003 .64637 L .61154 .66252 L .757 0 .154 r
F
.61096 .66344 m .58957 .64691 L .59003 .64637 L F
.57946 .78389 m .55281 .75207 L .58298 .78023 L .883 0 .208 r
F
.57946 .78389 m .55085 .76114 L .55281 .75207 L F
.51955 .6542 m .49718 .66279 L .52003 .6613 L .917 .567 .778 r
F
.54069 .6503 m .51955 .6542 L .52003 .6613 L .929 .734 .819 r
F
.6068 .66782 m .58957 .64691 L .61096 .66345 L .786 0 .127 r
F
.77966 .63712 m .77189 .58687 L .79081 .62839 L .585 0 .3 r
F
.77966 .63712 m .76174 .59888 L .77189 .58687 L F
.51955 .6542 m .4983 .6539 L .49718 .66279 L .917 .567 .778 r
F
.70661 .55795 m .70194 .58862 L .71688 .5438 L 1 .523 .601 r
F
.70661 .55795 m .69243 .6007 L .70194 .58862 L F
.71775 .52752 m .71688 .5438 L .72863 .5113 L 1 .235 .586 r
F
.71775 .52752 m .70661 .55795 L .71688 .5438 L F
.75345 .46494 m .7593 .45273 L .76482 .44344 L 0 0 0 r
F
.75345 .46494 m .74823 .47265 L .7593 .45273 L F
.77775 .42453 m .7872 .39892 L .78905 .40123 L F
.77775 .42453 m .77607 .4214 L .7872 .39892 L F
.32456 .58999 m .30147 .52822 L .31488 .56685 L 0 0 .497 r
F
.40743 .74042 m .38276 .69592 L .37581 .68966 L 0 0 .605 r
F
.40823 .83845 m .36983 .90826 L .36415 .90884 L .156 0 .152 r
F
.4123 .84364 m .36983 .90826 L .40823 .83845 L .156 0 .142 r
F
.47947 .64167 m .4559 .6372 L .47675 .64671 L .346 .09 .88 r
F
.49941 .64679 m .47675 .64671 L .49829 .6539 L .558 .372 .856 r
F
.49941 .64679 m .47947 .64167 L .47675 .64671 L F
.25161 .42347 m .24845 .42507 L .23699 .40567 L .748 0 0 r
F
.53864 .64667 m .51955 .6542 L .54069 .6503 L .756 .618 .847 r
F
.55779 .64616 m .54069 .6503 L .56137 .64781 L .478 .243 .899 r
F
.55779 .64616 m .53864 .64667 L .54069 .6503 L F
.51907 .64799 m .4983 .6539 L .51955 .6542 L .779 .562 .821 r
F
.53864 .64667 m .51907 .64799 L .51955 .6542 L .756 .618 .847 r
F
.42981 .79761 m .39603 .74055 L .42548 .80488 L .19 0 .63 r
F
.42981 .79761 m .40171 .74085 L .39603 .74055 L F
.26106 .62134 m .23944 .67143 L .22854 .66265 L .834 0 .32 r
F
.27093 .63286 m .23944 .67143 L .26106 .62134 L .837 0 .318 r
F
.51907 .64799 m .49941 .64679 L .4983 .6539 L .779 .562 .821 r
F
.32181 .62981 m .30097 .66797 L .29089 .65604 L .862 0 .328 r
F
.33092 .64115 m .30097 .66797 L .32181 .62981 L .866 0 .337 r
F
.46016 .63495 m .43606 .63062 L .4559 .6372 L .224 .003 .857 r
F
.47947 .64167 m .46016 .63495 L .4559 .6372 L .346 .09 .88 r
F
.30147 .52822 m .29177 .49737 L .28074 .47814 L 0 0 .531 r
F
.72032 .64432 m .71257 .61292 L .7308 .63341 L .467 0 .258 r
F
.72032 .64432 m .70315 .62727 L .71257 .61292 L F
.54888 .76783 m .5219 .75598 L .55085 .76114 L .646 0 .254 r
F
.54888 .76783 m .52145 .76828 L .5219 .75598 L F
.31197 .54899 m .29177 .49737 L .30147 .52822 L 0 0 .582 r
F
.32456 .58999 m .31197 .54899 L .30147 .52822 L 0 0 .497 r
F
.72571 .5098 m .72863 .5113 L .73703 .49174 L .787 0 .481 r
F
.72571 .5098 m .71775 .52752 L .72863 .5113 L F
.67045 .69882 m .64548 .76683 L .65176 .76159 L 1 .457 .568 r
F
.663 .70825 m .64548 .76683 L .67045 .69882 L 1 .399 .559 r
F
.22566 .38549 m .21519 .38706 L .21443 .36467 L .868 0 .009 r
F
.76844 .64552 m .76174 .59888 L .77966 .63712 L .573 0 .291 r
F
.76844 .64552 m .75151 .61066 L .76174 .59888 L F
.46016 .63495 m .44179 .62978 L .43606 .63062 L .224 .003 .857 r
F
.69637 .5706 m .69243 .6007 L .70661 .55795 L 1 .654 .622 r
F
.69637 .5706 m .68294 .61124 L .69243 .6007 L F
.70691 .54227 m .70661 .55795 L .71775 .52752 L 1 .364 .619 r
F
.70691 .54227 m .69637 .5706 L .70661 .55795 L F
.51859 .64226 m .49941 .64679 L .51907 .64799 L .681 .518 .847 r
F
.51859 .64226 m .50053 .64066 L .49941 .64679 L F
.50052 .64066 m .47947 .64167 L .49941 .64679 L .565 .4 .866 r
F
.53658 .64238 m .51907 .64799 L .53864 .64667 L .65 .514 .861 r
F
.53658 .64238 m .51859 .64226 L .51907 .64799 L F
.4822 .63679 m .46016 .63495 L .47947 .64167 L .445 .22 .888 r
F
.50052 .64066 m .4822 .63679 L .47947 .64167 L .565 .4 .866 r
F
.74197 .48576 m .74823 .47265 L .75345 .46494 L 0 0 0 r
F
.74197 .48576 m .73703 .49174 L .74823 .47265 L F
.57594 .78581 m .55085 .76114 L .57946 .78389 L .786 0 .13 r
F
.57594 .78581 m .54888 .76783 L .55085 .76114 L F
.79763 .39359 m .81135 .35403 L .80879 .37017 L 0 0 0 r
F
.79763 .39359 m .80025 .37773 L .81135 .35403 L F
.55418 .64281 m .53864 .64667 L .55779 .64616 L .483 .28 .892 r
F
.55418 .64281 m .53658 .64238 L .53864 .64667 L F
.76635 .44765 m .77607 .4214 L .77775 .42453 L 0 0 0 r
F
.76635 .44765 m .76482 .44344 L .77607 .4214 L F
.46445 .63184 m .44179 .62978 L .46016 .63495 L .403 .135 .894 r
F
.4822 .63679 m .46445 .63184 L .46016 .63495 L .445 .22 .888 r
F
.43418 .78908 m .40171 .74085 L .42981 .79761 L .228 0 .652 r
F
.43418 .78908 m .40743 .74042 L .40171 .74085 L F
.41311 .73932 m .38276 .69592 L .40743 .74042 L 0 0 .627 r
F
.41311 .73932 m .38966 .70151 L .38276 .69592 L F
.4123 .84364 m .37555 .90772 L .36983 .90826 L .156 0 .142 r
F
.4164 .8492 m .37555 .90772 L .4123 .84364 L .154 0 .128 r
F
.26287 .44313 m .26002 .44354 L .24845 .42507 L .713 0 0 r
F
.27093 .63286 m .25038 .68034 L .23944 .67143 L .837 0 .318 r
F
.28088 .64439 m .25038 .68034 L .27093 .63286 L .843 0 .317 r
F
.57112 .64516 m .55779 .64616 L .57624 .64954 L .257 .017 .869 r
F
.57112 .64516 m .55418 .64281 L .55779 .64616 L F
.33092 .64115 m .31111 .68045 L .30097 .66797 L .866 0 .337 r
F
.31197 .54899 m .30293 .51568 L .29177 .49737 L 0 0 .582 r
F
.44757 .62758 m .42464 .62787 L .44179 .62978 L .496 .238 .899 r
F
.46445 .63184 m .44757 .62758 L .44179 .62978 L .403 .135 .894 r
F
.22566 .38549 m .22658 .40697 L .21519 .38706 L .868 0 .009 r
F
.23699 .40567 m .22658 .40697 L .22566 .38549 L .863 0 .004 r
F
.51811 .63673 m .50053 .64066 L .51859 .64226 L .627 .476 .859 r
F
.51811 .63673 m .50165 .63501 L .50053 .64066 L F
.50164 .63501 m .4822 .63679 L .50052 .64066 L .574 .42 .87 r
F
.33411 .61633 m .31197 .54899 L .32456 .58999 L 0 0 .546 r
F
.70976 .65486 m .70315 .62727 L .72032 .64432 L .433 0 .238 r
F
.70976 .65486 m .69365 .64161 L .70315 .62727 L F
.5345 .63749 m .51859 .64226 L .53658 .64238 L .6 .452 .866 r
F
.5345 .63749 m .51811 .63673 L .51859 .64226 L F
.71442 .52632 m .71775 .52752 L .72571 .5098 L .789 0 .515 r
F
.71442 .52632 m .70691 .54227 L .71775 .52752 L F
.48494 .63192 m .46445 .63184 L .4822 .63679 L .512 .336 .885 r
F
.50164 .63501 m .48494 .63192 L .4822 .63679 L .574 .42 .87 r
F
.75714 .65354 m .75151 .61066 L .76844 .64552 L .559 0 .281 r
F
.75714 .65354 m .7412 .62217 L .75151 .61066 L F
.663 .70825 m .63917 .77271 L .64548 .76683 L 1 .399 .559 r
F
.6555 .71834 m .63917 .77271 L .663 .70825 L 1 .298 .541 r
F
.55054 .63816 m .53658 .64238 L .55418 .64281 L .505 .322 .882 r
F
.55054 .63816 m .5345 .63749 L .53658 .64238 L F
.32243 .56918 m .30293 .51568 L .31197 .54899 L .143 0 .615 r
F
.33411 .61633 m .32243 .56918 L .31197 .54899 L 0 0 .546 r
F
.46876 .62805 m .44757 .62758 L .46445 .63184 L .508 .323 .893 r
F
.48494 .63192 m .46876 .62805 L .46445 .63184 L .512 .336 .885 r
F
.68601 .58167 m .68294 .61124 L .69637 .5706 L 1 .777 .643 r
F
.69595 .55554 m .69637 .5706 L .70691 .54227 L 1 .533 .654 r
F
.69595 .55554 m .68601 .58167 L .69637 .5706 L F
.68601 .58167 m .67334 .61987 L .68294 .61124 L 1 .777 .643 r
F
.43851 .77985 m .40743 .74042 L .43418 .78908 L .267 0 .678 r
F
.43851 .77985 m .41311 .73932 L .40743 .74042 L F
.38657 .63711 m .36825 .66152 L .38579 .63707 L 0 0 0 r
F
.73036 .50563 m .73703 .49174 L .74197 .48576 L F
.73036 .50563 m .72571 .5098 L .73703 .49174 L F
.78639 .41691 m .80025 .37773 L .79763 .39359 L F
.78639 .41691 m .78905 .40123 L .80025 .37773 L F
.58713 .64915 m .57112 .64516 L .57624 .64954 L .162 .001 .84 r
F
.56596 .63935 m .55418 .64281 L .57112 .64516 L .415 .175 .884 r
F
.56596 .63935 m .55054 .63816 L .55418 .64281 L F
.75486 .47056 m .76482 .44344 L .76635 .44765 L 0 0 0 r
F
.75486 .47056 m .75345 .46494 L .76482 .44344 L F
.61819 .69118 m .60034 .66625 L .6068 .66782 L .844 0 .037 r
F
.41883 .73765 m .38966 .70151 L .41311 .73932 L 0 0 .656 r
F
.41883 .73765 m .39663 .70638 L .38966 .70151 L F
.48525 1.02375 m .44306 .92614 L .48411 1.03441 L .152 0 .562 r
F
.48525 1.02375 m .44578 .91925 L .44306 .92614 L F
.51763 .63118 m .50165 .63501 L .51811 .63673 L .607 .456 .864 r
F
.51763 .63118 m .50277 .62952 L .50165 .63501 L F
.50277 .62952 m .48494 .63192 L .50164 .63501 L .589 .441 .869 r
F
.27424 .46196 m .2717 .4609 L .26002 .44354 L .659 0 0 r
F
.44757 .62758 m .43184 .62504 L .42464 .62787 L .496 .238 .899 r
F
.45338 .62434 m .43184 .62504 L .44757 .62758 L .6 .474 .891 r
F
.46876 .62805 m .45338 .62434 L .44757 .62758 L .508 .323 .893 r
F
.28088 .64439 m .26138 .68946 L .25038 .68034 L .843 0 .317 r
F
.29089 .65605 m .26138 .68946 L .28088 .64439 L .852 0 .318 r
F
.53242 .6321 m .51811 .63673 L .5345 .63749 L .587 .432 .866 r
F
.53242 .6321 m .51763 .63118 L .51811 .63673 L F
.4877 .62694 m .46876 .62805 L .48494 .63192 L .566 .418 .878 r
F
.50277 .62952 m .4877 .62694 L .48494 .63192 L .589 .441 .869 r
F
.43184 .62504 m .40902 .62912 L .42464 .62787 L .768 .677 .874 r
F
.4164 .8492 m .38129 .90721 L .37555 .90772 L .154 0 .128 r
F
.42052 .85518 m .38129 .90721 L .4164 .8492 L .149 0 .107 r
F
.23699 .40567 m .23807 .42615 L .22658 .40697 L .863 0 .004 r
F
.24845 .42507 m .23807 .42615 L .23699 .40567 L .855 0 0 r
F
.54688 .63263 m .5345 .63749 L .55054 .63816 L .538 .367 .872 r
F
.54688 .63263 m .53242 .6321 L .5345 .63749 L F
.4731 .62374 m .45338 .62434 L .46876 .62805 L .582 .448 .882 r
F
.4877 .62694 m .4731 .62374 L .46876 .62805 L .566 .418 .878 r
F
.31406 .53243 m .29737 .49647 L .30293 .51568 L .01 0 .647 r
F
.32243 .56918 m .31406 .53243 L .30293 .51568 L .143 0 .615 r
F
.70299 .54126 m .70691 .54227 L .71442 .52632 L .792 .003 .558 r
F
.70299 .54126 m .69595 .55554 L .70691 .54227 L F
.74578 .66113 m .7412 .62217 L .75714 .65354 L .542 0 .267 r
F
.74578 .66113 m .7308 .63341 L .7412 .62217 L F
.44285 .77044 m .41311 .73932 L .43851 .77985 L .305 .004 .708 r
F
.44285 .77044 m .41883 .73765 L .41311 .73932 L F
.5805 .6403 m .57112 .64516 L .58713 .64915 L .422 .181 .866 r
F
.5805 .6403 m .56596 .63935 L .57112 .64516 L F
.69926 .66478 m .69365 .64161 L .70975 .65486 L .385 0 .208 r
F
.69926 .66478 m .6842 .65572 L .69365 .64161 L F
.56078 .63286 m .55054 .63816 L .56596 .63935 L .504 .313 .871 r
F
.56078 .63286 m .54688 .63263 L .55054 .63816 L F
.67553 .59085 m .67334 .61987 L .68601 .58167 L 1 .851 .663 r
F
.67553 .59085 m .6636 .6259 L .67334 .61987 L F
.48639 1.01301 m .44578 .91925 L .48525 1.02375 L .175 0 .563 r
F
.48639 1.01301 m .44851 .91158 L .44578 .91925 L F
.68486 .56709 m .68601 .58167 L .69595 .55554 L 1 .725 .691 r
F
.68486 .56709 m .67553 .59085 L .68601 .58167 L F
.60994 .66535 m .60034 .66625 L .61819 .69118 L .132 0 .787 r
F
.60994 .66535 m .59375 .6584 L .60034 .66625 L F
.51714 .62547 m .50277 .62952 L .51763 .63118 L .607 .457 .863 r
F
.51714 .62547 m .5039 .62399 L .50277 .62952 L F
.5039 .62399 m .4877 .62694 L .50277 .62952 L .607 .462 .866 r
F
.45338 .62434 m .43908 .62127 L .43184 .62504 L .6 .474 .891 r
F
.45924 .62034 m .43908 .62127 L .45338 .62434 L .669 .568 .874 r
F
.4731 .62374 m .45924 .62034 L .45338 .62434 L .582 .448 .882 r
F
.43184 .62504 m .41755 .6238 L .40902 .62912 L .768 .677 .874 r
F
.43908 .62127 m .41755 .6238 L .43184 .62504 L .83 .758 .861 r
F
.53032 .62631 m .51763 .63118 L .53242 .6321 L .594 .437 .863 r
F
.53032 .62631 m .51714 .62547 L .51763 .63118 L F
.60252 .92631 m .56698 1.03046 L .60613 .93281 L 1 .665 .592 r
F
.49047 .62178 m .4731 .62374 L .4877 .62694 L .607 .47 .87 r
F
.5039 .62399 m .49047 .62178 L .4877 .62694 L .607 .462 .866 r
F
.71878 .5239 m .72571 .5098 L .73035 .50563 L 0 0 0 r
F
.71878 .5239 m .71442 .52632 L .72571 .5098 L F
.77507 .44019 m .78905 .40123 L .78639 .41691 L F
.77507 .44019 m .77775 .42453 L .78905 .40123 L F
.33304 .58776 m .31406 .53243 L .32243 .56918 L .301 0 .627 r
F
.4655 .81742 m .43418 .78908 L .46263 .8403 L .497 .039 .66 r
F
.4655 .81742 m .43851 .77985 L .43418 .78908 L F
.52051 .7728 m .4949 .79563 L .52099 .77324 L 1 .652 .705 r
F
.42459 .73551 m .39663 .70638 L .41883 .73765 L 0 0 .694 r
F
.42459 .73551 m .40366 .71036 L .39663 .70638 L F
.5432 .62657 m .53242 .6321 L .54688 .63263 L .574 .409 .863 r
F
.5432 .62657 m .53032 .62631 L .53242 .6321 L F
.28575 .47981 m .28351 .47697 L .27346 .46326 L .577 0 0 r
F
.29737 .49647 m .29543 .4916 L .28351 .47697 L 0 0 .479 r
F
.29543 .4916 m .2941 .49143 L .28351 .47697 L .718 0 0 r
F
.2941 .49143 m .28515 .49028 L .28351 .47697 L F
.27346 .46326 m .28351 .47697 L .2717 .4609 L .577 0 0 r
F
.74327 .49328 m .75345 .46494 L .75486 .47056 L 0 0 0 r
F
.74327 .49328 m .74197 .48576 L .75345 .46494 L F
.70852 .94984 m .68005 .87805 L .71648 .95482 L 1 .003 .191 r
F
.70852 .94984 m .67367 .87732 L .68005 .87805 L F
.47747 .619 m .45924 .62034 L .4731 .62374 L .634 .509 .87 r
F
.49047 .62178 m .47747 .619 L .4731 .62374 L .607 .47 .87 r
F
.60187 .6496 m .59375 .6584 L .60994 .66535 L .46 .149 .794 r
F
.60187 .6496 m .58713 .64915 L .59375 .6584 L F
.24845 .42507 m .24966 .44439 L .23807 .42615 L .855 0 0 r
F
.26002 .44354 m .24966 .44439 L .24845 .42507 L .842 0 0 r
F
.57386 .63217 m .56596 .63935 L .5805 .6403 L .536 .329 .85 r
F
.57386 .63217 m .56078 .63286 L .56596 .63935 L F
.40366 .71036 m .38465 .69127 L .37649 .68106 L .658 0 0 r
F
.48754 1.00213 m .44851 .91158 L .48639 1.01301 L .205 0 .563 r
F
.48754 1.00213 m .45127 .90277 L .44851 .91158 L F
.4472 .76146 m .41883 .73765 L .44285 .77044 L .343 .021 .739 r
F
.4472 .76146 m .42459 .73551 L .41883 .73765 L F
.41755 .6238 m .39523 .63058 L .40902 .62912 L 1 .982 .791 r
F
.55557 .62617 m .54688 .63263 L .56078 .63286 L .57 .394 .858 r
F
.55557 .62617 m .5432 .62657 L .54688 .63263 L F
.42052 .85518 m .38707 .90668 L .38129 .90721 L .149 0 .107 r
F
.42468 .86153 m .38707 .90668 L .42052 .85518 L .137 0 .075 r
F
.69144 .55431 m .69595 .55554 L .70299 .54126 L .799 .025 .615 r
F
.69144 .55431 m .68486 .56709 L .69595 .55554 L F
.43908 .62127 m .42611 .61836 L .41755 .6238 L .83 .758 .861 r
F
.44635 .61692 m .42611 .61836 L .43908 .62127 L .827 .724 .851 r
F
.45924 .62034 m .44635 .61692 L .43908 .62127 L .669 .568 .874 r
F
.31406 .53243 m .30895 .51152 L .29737 .49647 L .01 0 .647 r
F
.32533 .5473 m .30895 .51152 L .31406 .53243 L .169 0 .683 r
F
.33304 .58776 m .32533 .5473 L .31406 .53243 L .301 0 .627 r
F
.46835 .79711 m .43851 .77985 L .4655 .81742 L .585 .103 .687 r
F
.46835 .79711 m .44285 .77044 L .43851 .77985 L F
.73434 .66822 m .7308 .63341 L .74578 .66113 L .519 0 .25 r
F
.73434 .66822 m .72032 .64432 L .7308 .63341 L F
.60252 .92631 m .56485 1.01765 L .56698 1.03046 L 1 .665 .592 r
F
.5989 .91962 m .56485 1.01765 L .60252 .92631 L 1 .669 .597 r
F
.46512 .61582 m .44635 .61692 L .45924 .62034 L .703 .588 .862 r
F
.47747 .619 m .46512 .61582 L .45924 .62034 L .634 .509 .87 r
F
.66269 .6263 m .64933 .67656 L .6636 .6259 L 1 .615 .617 r
F
.67454 .5916 m .6636 .6259 L .67552 .59085 L 1 .843 .67 r
F
.67454 .5916 m .66269 .6263 L .6636 .6259 L F
.51665 .61958 m .5039 .62399 L .51714 .62547 L .62 .468 .86 r
F
.51665 .61958 m .50504 .61831 L .5039 .62399 L F
.50504 .61831 m .49047 .62178 L .5039 .62399 L .626 .48 .862 r
F
.59386 .63821 m .58713 .64915 L .60187 .6496 L .579 .271 .794 r
F
.59386 .63821 m .5805 .6403 L .58713 .64915 L F
.68381 .56808 m .67552 .59085 L .68485 .5671 L 1 .838 .708 r
F
.68381 .56808 m .67454 .5916 L .67552 .59085 L F
.52821 .62022 m .51714 .62547 L .53032 .62631 L .612 .455 .859 r
F
.52821 .62022 m .51665 .61958 L .51714 .62547 L F
.66269 .6263 m .64849 .67653 L .64933 .67656 L 1 .615 .617 r
F
.65618 .62834 m .64849 .67653 L .66268 .6263 L 1 .534 .622 r
F
.66755 .59635 m .66268 .6263 L .67454 .59161 L 1 .836 .678 r
F
.66755 .59635 m .65618 .62834 L .66268 .6263 L F
.49326 .6164 m .47747 .619 L .49047 .62178 L .638 .498 .862 r
F
.50504 .61831 m .49326 .6164 L .49047 .62178 L .626 .48 .862 r
F
.67642 .57452 m .67454 .59161 L .68381 .56808 L 1 .888 .722 r
F
.67642 .57452 m .66755 .59635 L .67454 .59161 L F
.36983 .90826 m .32546 .98584 L .36415 .90884 L 0 0 .064 r
F
.5395 .62022 m .53032 .62631 L .5432 .62657 L .608 .443 .857 r
F
.5395 .62022 m .52821 .62022 L .53032 .62631 L F
.80568 .67889 m .80189 .61935 L .81768 .67358 L .644 0 .309 r
F
.80568 .67889 m .79081 .62839 L .80189 .61935 L F
.41755 .6238 m .405 .62133 L .39523 .63058 L 1 .982 .791 r
F
.42611 .61836 m .405 .62133 L .41755 .6238 L 1 .891 .808 r
F
.48869 .99103 m .45127 .90277 L .48754 1.00213 L .241 0 .561 r
F
.48869 .99103 m .45406 .89224 L .45127 .90277 L F
.48186 .61393 m .46512 .61582 L .47747 .619 L .665 .532 .86 r
F
.49326 .6164 m .48186 .61393 L .47747 .619 L .638 .498 .862 r
F
.5672 .6247 m .56078 .63286 L .57386 .63217 L .606 .406 .841 r
F
.5672 .6247 m .55557 .62617 L .56078 .63286 L F
.68868 .67407 m .6842 .65572 L .69926 .66478 L .311 0 .159 r
F
.68868 .67407 m .67466 .66961 L .6842 .65572 L F
.70053 .94481 m .67367 .87732 L .70852 .94984 L 1 .002 .183 r
F
.70053 .94481 m .66724 .87635 L .67367 .87732 L F
.70707 .54028 m .71442 .52632 L .71878 .5239 L 0 0 0 r
F
.70707 .54028 m .70299 .54126 L .71442 .52632 L F
.47116 .7809 m .44285 .77044 L .46835 .79711 L .645 .175 .712 r
F
.47116 .7809 m .4472 .76146 L .44285 .77044 L F
.58587 .62918 m .5805 .6403 L .59386 .63821 L .644 .359 .803 r
F
.58587 .62918 m .57386 .63217 L .5805 .6403 L F
.30895 .51152 m .29544 .4916 L .29737 .49647 L 0 0 .597 r
F
.52051 .7728 m .49603 .78249 L .4949 .79563 L 1 .652 .705 r
F
.52047 .77257 m .49603 .78249 L .52051 .7728 L 1 .732 .731 r
F
.40432 .71068 m .38465 .69127 L .40366 .71036 L .585 0 0 r
F
.42513 .73529 m .40366 .71036 L .42459 .73551 L .013 0 .715 r
F
.42513 .73529 m .40432 .71068 L .40366 .71036 L F
.55034 .61947 m .5432 .62657 L .55557 .62617 L .617 .442 .85 r
F
.55034 .61947 m .5395 .62022 L .5432 .62657 L F
.44635 .61692 m .4347 .61307 L .42611 .61836 L .827 .724 .851 r
F
.45366 .61225 m .4347 .61307 L .44635 .61692 L .802 .672 .845 r
F
.46512 .61582 m .45366 .61225 L .44635 .61692 L .703 .588 .862 r
F
.76367 .4635 m .77775 .42453 L .77507 .44019 L 0 0 0 r
F
.76367 .4635 m .76635 .44765 L .77775 .42453 L F
.52047 .77257 m .49614 .78142 L .49603 .78249 L 1 .732 .731 r
F
.52015 .77028 m .49614 .78142 L .52047 .77257 L 1 .653 .748 r
F
.5433 .77113 m .52047 .77257 L .54466 .77236 L .45 .195 .898 r
F
.5433 .77113 m .52015 .77028 L .52047 .77257 L F
.65618 .62834 m .64254 .67404 L .64849 .67653 L 1 .534 .622 r
F
.64622 .62872 m .64254 .67404 L .65618 .62834 L 1 .357 .631 r
F
.65686 .60166 m .65618 .62834 L .66755 .59635 L 1 .785 .695 r
F
.65686 .60166 m .64622 .62872 L .65618 .62834 L F
.44761 .76066 m .42459 .73551 L .4472 .76146 L .356 .027 .741 r
F
.44761 .76066 m .42513 .73529 L .42459 .73551 L F
.49489 .79564 m .4655 .81742 L .49374 .81498 L 1 .367 .64 r
F
.26002 .44354 m .26137 .4614 L .24966 .44439 L .842 0 0 r
F
.2717 .4609 m .26137 .4614 L .26002 .44354 L .82 0 0 r
F
.40432 .71068 m .38542 .69212 L .38465 .69127 L .585 0 0 r
F
.409 .71261 m .38542 .69212 L .40432 .71068 L .568 0 0 r
F
.42895 .73364 m .40432 .71068 L .42514 .73529 L .024 0 .737 r
F
.42895 .73364 m .409 .71261 L .40432 .71068 L F
.5989 .91962 m .56271 1.00442 L .56485 1.01765 L 1 .669 .597 r
F
.59526 .91277 m .56271 1.00442 L .5989 .91962 L 1 .67 .602 r
F
.49489 .79564 m .46835 .79711 L .4655 .81742 L 1 .367 .64 r
F
.49603 .78249 m .46835 .79711 L .49489 .79564 L 1 .4 .671 r
F
.45049 .75521 m .42514 .73529 L .44761 .76066 L .374 .047 .762 r
F
.45049 .75521 m .42895 .73364 L .42514 .73529 L F
.73158 .51572 m .74197 .48576 L .74327 .49328 L 0 0 0 r
F
.73158 .51572 m .73036 .50563 L .74197 .48576 L F
.47103 .61095 m .45366 .61225 L .46512 .61582 L .714 .581 .853 r
F
.48186 .61393 m .47103 .61095 L .46512 .61582 L .665 .532 .86 r
F
.66512 .58256 m .66755 .59635 L .67642 .57452 L 1 .973 .749 r
F
.66512 .58256 m .65686 .60166 L .66755 .59635 L F
.42611 .61836 m .41476 .61391 L .405 .62133 L 1 .891 .808 r
F
.4347 .61307 m .41476 .61391 L .42611 .61836 L .976 .789 .819 r
F
.56604 .77998 m .54466 .77236 L .56844 .78295 L 0 0 .714 r
F
.34389 .60111 m .32533 .5473 L .33304 .58776 L .412 .005 .631 r
F
.51616 .61347 m .50504 .61831 L .51665 .61958 L .637 .483 .856 r
F
.51616 .61347 m .50618 .61243 L .50504 .61831 L F
.50618 .61243 m .49326 .6164 L .50504 .61831 L .644 .495 .857 r
F
.48985 .97954 m .45406 .89224 L .48869 .99103 L .285 0 .556 r
F
.48985 .97954 m .45688 .87903 L .45406 .89224 L F
.69035 .55542 m .68485 .5671 L .69144 .55431 L .81 .071 .655 r
F
.69035 .55542 m .68381 .56808 L .68485 .5671 L F
.52609 .61393 m .51665 .61958 L .52821 .62022 L .633 .474 .855 r
F
.52609 .61393 m .51616 .61347 L .51665 .61958 L F
.49606 .61079 m .48186 .61393 L .49326 .6164 L .658 .512 .856 r
F
.50618 .61243 m .49606 .61079 L .49326 .6164 L .644 .495 .857 r
F
.68265 .5627 m .68381 .56808 L .69035 .55542 L .809 .104 .679 r
F
.68265 .5627 m .67642 .57452 L .68381 .56808 L F
.57788 .62155 m .57386 .63217 L .58587 .62918 L .677 .421 .813 r
F
.57788 .62155 m .5672 .6247 L .57386 .63217 L F
.56053 .61773 m .55557 .62617 L .5672 .6247 L .646 .451 .838 r
F
.56053 .61773 m .55034 .61947 L .55557 .62617 L F
.32533 .5473 m .32065 .52496 L .30895 .51152 L .169 0 .683 r
F
.33676 .55951 m .32065 .52496 L .32533 .5473 L .298 .002 .702 r
F
.34389 .60111 m .33676 .55951 L .32533 .5473 L .412 .005 .631 r
F
.38542 .69212 m .36766 .68609 L .38465 .69127 L 1 0 .178 r
F
.53579 .61375 m .52821 .62022 L .5395 .62022 L .635 .47 .852 r
F
.53579 .61375 m .52609 .61393 L .52821 .62022 L F
.47143 .77958 m .4472 .76146 L .47116 .7809 L .633 .178 .719 r
F
.47143 .77958 m .44761 .76066 L .4472 .76146 L F
.72283 .67472 m .72032 .64432 L .73434 .66822 L .491 0 .226 r
F
.72283 .67472 m .70976 .65486 L .72032 .64432 L F
.61492 .63958 m .60188 .6496 L .60994 .66535 L .727 .161 .672 r
F
.60574 .63046 m .60188 .6496 L .61492 .63958 L .753 .271 .723 r
F
.60574 .63046 m .59387 .63821 L .60188 .6496 L F
.47327 .77103 m .44761 .76066 L .47143 .77958 L .657 .222 .734 r
F
.47327 .77103 m .45049 .75521 L .44761 .76066 L F
.49603 .78249 m .47116 .7809 L .46835 .79711 L 1 .4 .671 r
F
.49614 .78142 m .47116 .7809 L .49603 .78249 L 1 .443 .693 r
F
.62413 .65077 m .60994 .66535 L .61819 .69119 L .678 .064 .609 r
F
.61492 .63958 m .60994 .66535 L .62413 .65077 L .727 .161 .672 r
F
.48627 .6086 m .47103 .61095 L .48186 .61393 L .681 .536 .853 r
F
.49606 .61079 m .48627 .6086 L .48186 .61393 L .658 .512 .856 r
F
.36983 .90826 m .33282 .97954 L .32546 .98584 L 0 0 .064 r
F
.37555 .90772 m .33282 .97954 L .36983 .90826 L 0 0 .041 r
F
.79363 .68387 m .79081 .62839 L .80568 .67889 L .639 0 .302 r
F
.79363 .68387 m .77966 .63712 L .79081 .62839 L F
.49614 .78142 m .47143 .77958 L .47116 .7809 L 1 .443 .693 r
F
.52015 .77028 m .49689 .77442 L .49614 .78142 L 1 .653 .748 r
F
.49689 .77442 m .47143 .77958 L .49614 .78142 L 1 .434 .706 r
F
.38542 .69212 m .36852 .68768 L .36766 .68609 L 1 0 .178 r
F
.39087 .69748 m .36852 .68768 L .38542 .69212 L .934 0 .158 r
F
.409 .71261 m .39087 .69748 L .38542 .69212 L .568 0 0 r
F
.42468 .86153 m .39288 .90606 L .38707 .90668 L .137 0 .075 r
F
.42886 .86806 m .39288 .90606 L .42468 .86153 L .112 0 .023 r
F
.51967 .76518 m .49689 .77442 L .52015 .77028 L .936 .56 .771 r
F
.54122 .76726 m .52015 .77028 L .5433 .77113 L .53 .358 .875 r
F
.54122 .76726 m .51967 .76518 L .52015 .77028 L F
.45366 .61225 m .4433 .60805 L .4347 .61307 L .802 .672 .845 r
F
.461 .60746 m .4433 .60805 L .45366 .61225 L .774 .626 .842 r
F
.47103 .61095 m .461 .60746 L .45366 .61225 L .714 .581 .853 r
F
.49102 .96709 m .45688 .87903 L .48985 .97954 L .329 0 .548 r
F
.49102 .96709 m .45974 .86186 L .45688 .87903 L F
.64622 .62872 m .63336 .66359 L .64254 .67404 L 1 .357 .631 r
F
.63617 .6265 m .63336 .66359 L .64622 .62872 L 1 .277 .648 r
F
.64607 .60476 m .64622 .62872 L .65686 .60166 L 1 .701 .714 r
F
.64607 .60476 m .63617 .6265 L .64622 .62872 L F
.43478 .73084 m .409 .71261 L .42896 .73364 L .101 0 .783 r
F
.45485 .74763 m .42896 .73364 L .45049 .75521 L .407 .093 .79 r
F
.45485 .74763 m .43478 .73084 L .42896 .73364 L F
.38542 .64198 m .36156 .6684 L .3756 .65434 L 1 .667 .597 r
F
.38542 .64198 m .37285 .63863 L .36156 .6684 L F
.39523 .63058 m .37285 .63863 L .38542 .64198 L 1 .821 .686 r
F
.54509 .61285 m .5395 .62022 L .55034 .61947 L .646 .472 .846 r
F
.54509 .61285 m .53579 .61375 L .5395 .62022 L F
.69251 .93973 m .66724 .87635 L .70053 .94481 L 1 .001 .172 r
F
.69251 .93973 m .66078 .87505 L .66724 .87635 L F
.4347 .61307 m .42451 .60784 L .41476 .61391 L .976 .789 .819 r
F
.4433 .60805 m .42451 .60784 L .4347 .61307 L .883 .706 .826 r
F
.59656 .6229 m .59387 .63821 L .60574 .63046 L .758 .368 .762 r
F
.59656 .6229 m .58587 .62918 L .59387 .63821 L F
.41615 .71445 m .39087 .69748 L .409 .71261 L .411 0 0 r
F
.43478 .73084 m .41615 .71445 L .409 .71261 L .101 0 .783 r
F
.39523 .63058 m .38377 .62297 L .37285 .63863 L 1 .821 .686 r
F
.405 .62133 m .38377 .62297 L .39523 .63058 L 1 .831 .74 r
F
.59526 .91277 m .56056 .99066 L .56271 1.00442 L 1 .67 .602 r
F
.5916 .90579 m .56056 .99066 L .59526 .91277 L 1 .666 .607 r
F
.49226 .93178 m .45974 .86186 L .49102 .96709 L .41 0 .557 r
F
.49689 .77442 m .47327 .77103 L .47143 .77958 L 1 .434 .706 r
F
.47697 .60588 m .461 .60746 L .47103 .61095 L .714 .565 .848 r
F
.48627 .6086 m .47697 .60588 L .47103 .61095 L .681 .536 .853 r
F
.30895 .51152 m .30729 .50448 L .29544 .4916 L 0 0 .597 r
F
.32065 .52496 m .30729 .50448 L .30895 .51152 L 0 0 .7 r
F
.47607 .76014 m .45049 .75521 L .47327 .77102 L .665 .274 .757 r
F
.47607 .76014 m .45485 .74763 L .45049 .75521 L F
.6952 .55401 m .70299 .54126 L .70707 .54028 L 0 0 0 r
F
.6952 .55401 m .69144 .55431 L .70299 .54126 L F
.56237 .77378 m .5433 .77113 L .56604 .77998 L .217 .011 .852 r
F
.56237 .77378 m .54122 .76726 L .5433 .77113 L F
.51967 .76518 m .49802 .76502 L .49689 .77442 L .936 .56 .771 r
F
.49802 .76501 m .47327 .77102 L .49689 .77442 L .924 .432 .734 r
F
.405 .62133 m .39455 .61285 L .38377 .62297 L 1 .831 .74 r
F
.41476 .61391 m .39455 .61285 L .405 .62133 L 1 .785 .774 r
F
.65372 .58847 m .65686 .60166 L .66512 .58256 L 1 .998 .775 r
F
.65372 .58847 m .64607 .60476 L .65686 .60166 L F
.56987 .61478 m .5672 .6247 L .57788 .62155 L .69 .462 .822 r
F
.56987 .61478 m .56053 .61773 L .5672 .6247 L F
.2717 .4609 m .2732 .47682 L .26137 .4614 L .82 0 0 r
F
.28351 .47697 m .2732 .47682 L .2717 .4609 L .781 0 0 r
F
.67088 .57182 m .67642 .57452 L .68265 .5627 L .825 .246 .737 r
F
.67088 .57182 m .66512 .58256 L .67642 .57452 L F
.62413 .65077 m .61819 .69119 L .63336 .66359 L .678 .064 .609 r
F
.63617 .6265 m .62413 .65077 L .63336 .66359 L 1 .277 .648 r
F
.62606 .62277 m .62413 .65077 L .63617 .6265 L .936 .307 .682 r
F
.62606 .62277 m .61492 .63958 L .62413 .65077 L F
.51567 .60719 m .50618 .61243 L .51616 .61347 L .654 .496 .852 r
F
.51567 .60719 m .50733 .60635 L .50618 .61243 L F
.50733 .60635 m .49606 .61079 L .50618 .61243 L .66 .505 .852 r
F
.55383 .61114 m .55034 .61947 L .56053 .61773 L .667 .478 .839 r
F
.55383 .61114 m .54509 .61285 L .55034 .61947 L F
.58738 .61637 m .58587 .62918 L .59656 .6229 L .749 .438 .791 r
F
.58738 .61637 m .57788 .62155 L .58587 .62918 L F
.49802 .76501 m .47607 .76014 L .47327 .77102 L .924 .432 .734 r
F
.52396 .60749 m .51616 .61347 L .52609 .61393 L .652 .491 .851 r
F
.52396 .60749 m .51567 .60719 L .51616 .61347 L F
.49888 .60497 m .48627 .6086 L .49606 .61079 L .671 .517 .851 r
F
.50733 .60635 m .49888 .60497 L .49606 .61079 L .66 .505 .852 r
F
.61592 .61844 m .61492 .63958 L .62606 .62277 L .896 .376 .722 r
F
.61592 .61844 m .60574 .63046 L .61492 .63958 L F
.6352 .60594 m .63617 .6265 L .64607 .60476 L 1 .646 .736 r
F
.6352 .60594 m .62606 .62277 L .63617 .6265 L F
.8011 .39172 m .79763 .39359 L .80879 .37017 L 0 0 0 r
F
.8011 .39172 m .7996 .43371 L .81085 .41047 L 1 .431 .582 r
F
.79466 .4052 m .79763 .39359 L .8011 .39172 L 0 0 0 r
F
.78968 .41565 m .78827 .45697 L .7996 .43371 L 1 .433 .582 r
F
.78961 .41552 m .7996 .43371 L .79466 .4052 L F
.79466 .4052 m .7996 .43371 L .8011 .39172 L 1 .431 .582 r
F
.79057 .42122 m .79464 .40529 L .79664 .40109 L 0 0 0 r
F
.80105 .39186 m .79664 .40109 L .8011 .39172 L F
.79057 .42122 m .79664 .40109 L .80105 .39186 L F
.78961 .41552 m .7896 .41582 L .78968 .41565 L 1 .433 .582 r
F
.7896 .41582 m .78827 .45697 L .78968 .41565 L F
.80109 .3917 m .79466 .4052 L .8011 .39172 L 1 .431 .582 r
F
.78963 .41545 m .78639 .41692 L .79763 .39359 L 0 0 0 r
F
.78961 .41552 m .79763 .39359 L .79466 .4052 L F
.78796 .36646 m .79464 .40507 L .80109 .3917 L 1 .431 .582 r
F
.79464 .40507 m .79466 .4052 L .80109 .3917 L F
.78961 .41552 m .7896 .41552 L .78963 .41545 L 0 0 0 r
F
.7896 .41552 m .78639 .41692 L .78963 .41545 L F
.78333 .42853 m .78827 .45697 L .78961 .41552 L 1 .433 .582 r
F
.77802 .43926 m .77507 .44019 L .78639 .41692 L 0 0 0 r
F
.778 .4393 m .78639 .41692 L .78333 .42853 L F
.78333 .42853 m .78639 .41692 L .78961 .41552 L F
.77712 .39277 m .7833 .42837 L .78536 .42416 L 1 .433 .582 r
F
.78959 .41548 m .78536 .42416 L .78961 .41552 L F
.77712 .39277 m .78536 .42416 L .78959 .41548 L F
.778 .4393 m .778 .4393 L .77802 .43926 L 0 0 0 r
F
.778 .4393 m .77507 .44019 L .77802 .43926 L F
.78957 .41561 m .78333 .42853 L .78961 .41552 L F
.77808 .43943 m .77686 .48028 L .78827 .45697 L 1 .434 .583 r
F
.778 .4393 m .78827 .45697 L .78333 .42853 L F
.77942 .44336 m .78332 .42856 L .78957 .41561 L 0 0 0 r
F
.78332 .42856 m .78333 .42853 L .78957 .41561 L F
.778 .4393 m .77799 .43959 L .77808 .43943 L 1 .434 .583 r
F
.77799 .43959 m .77686 .48028 L .77808 .43943 L F
.77191 .45182 m .77507 .44019 L .778 .4393 L 0 0 0 r
F
.76629 .46309 m .76637 .46321 L .77191 .45182 L 1 .434 .583 r
F
.76637 .46321 m .77686 .48028 L .77191 .45182 L F
.77191 .45182 m .77686 .48028 L .778 .4393 L F
.77675 .44187 m .77191 .45182 L .778 .4393 L 0 0 0 r
F
.7719 .45186 m .77191 .45182 L .77675 .44187 L F
.7522 .48699 m .76635 .44765 L .76367 .4635 L F
.7522 .48699 m .75486 .47056 L .76635 .44765 L F
.76629 .46309 m .76538 .50371 L .77686 .48028 L 1 .434 .583 r
F
.76629 .46309 m .76367 .4635 L .77507 .44019 L 0 0 0 r
F
.76041 .47511 m .76367 .4635 L .76629 .46309 L F
.75451 .48691 m .75458 .48702 L .76041 .47511 L 1 .43 .582 r
F
.75458 .48702 m .76538 .50371 L .76041 .47511 L F
.76041 .47511 m .76538 .50371 L .76629 .46309 L 1 .434 .583 r
F
.76625 .46322 m .76041 .47511 L .76629 .46309 L 0 0 0 r
F
.75694 .4875 m .76041 .47511 L .76625 .46322 L F
.74067 .51096 m .75486 .47056 L .7522 .48699 L F
.74067 .51096 m .74327 .49328 L .75486 .47056 L F
.75451 .48691 m .75384 .52737 L .76538 .50371 L 1 .43 .582 r
F
.75451 .48691 m .7522 .48699 L .76367 .4635 L 0 0 0 r
F
.74886 .49848 m .7522 .48699 L .75451 .48691 L F
.7427 .5108 m .74276 .51089 L .74886 .49848 L 1 .421 .58 r
F
.74276 .51089 m .75384 .52737 L .74886 .49848 L F
.74886 .49848 m .75384 .52737 L .75451 .48691 L 1 .43 .582 r
F
.75438 .48722 m .74886 .49848 L .75451 .48691 L 0 0 0 r
F
.74562 .50963 m .74886 .49848 L .75438 .48722 L F
.7291 .536 m .74327 .49328 L .74067 .51096 L 0 0 .022 r
F
.7291 .536 m .73158 .51572 L .74327 .49328 L F
.7427 .5108 m .74223 .55147 L .75384 .52737 L 1 .421 .58 r
F
.7427 .5108 m .74067 .51096 L .7522 .48699 L 0 0 0 r
F
.73727 .52208 m .74067 .51096 L .7427 .5108 L F
.73099 .53477 m .73106 .53487 L .73727 .52208 L 1 .4 .576 r
F
.73106 .53487 m .74223 .55147 L .73727 .52208 L F
.73727 .52208 m .74223 .55147 L .7427 .5108 L 1 .421 .58 r
F
.74244 .51144 m .73727 .52208 L .7427 .5108 L 0 0 0 r
F
.73424 .53199 m .73727 .52208 L .74244 .51144 L F
.71995 .53724 m .73035 .50563 L .73158 .51572 L 0 0 .039 r
F
.71995 .53724 m .71878 .5239 L .73035 .50563 L F
.71769 .56309 m .73158 .51572 L .7291 .53601 L .03 0 .124 r
F
.71769 .56309 m .71995 .53724 L .73158 .51572 L F
.73099 .53477 m .73057 .57641 L .74223 .55147 L 1 .4 .576 r
F
.73099 .53477 m .7291 .536 L .74067 .51096 L 0 0 0 r
F
.72571 .5462 m .7291 .536 L .73099 .53477 L F
.71769 .5631 m .71327 .56654 L .71769 .56309 L .296 0 .268 r
F
.70641 .59661 m .70982 .58165 L .71769 .5631 L F
.70982 .58165 m .71327 .56654 L .71769 .5631 L F
.70641 .59661 m .70819 .55696 L .71995 .53724 L F
.70207 .61555 m .70474 .59003 L .70641 .59662 L .63 0 .414 r
F
.70474 .59003 m .70819 .55696 L .70687 .58617 L F
.70474 .59003 m .70687 .58617 L .70641 .59662 L F
.71015 .58025 m .70641 .59661 L .71769 .5631 L .906 .004 .392 r
F
.70641 .59662 m .70819 .55696 L .70641 .59661 L .63 0 .414 r
F
.69993 .68546 m .68868 .67407 L .69926 .66478 L .408 0 .14 r
F
.68838 .68957 m .68868 .67407 L .69993 .68546 L .335 0 .056 r
F
.69585 .70183 m .69993 .68546 L .70814 .70256 L .473 0 .066 r
F
.69585 .70183 m .68838 .68957 L .69993 .68546 L F
.7002 .71762 m .69585 .70183 L .70814 .70256 L .616 0 .086 r
F
.69899 .7169 m .69585 .70183 L .69978 .71612 L .62 0 .072 r
F
.69899 .7169 m .6947 .70172 L .69585 .70183 L F
.69049 .71164 m .6947 .70172 L .69899 .71689 L .561 0 0 r
F
.69114 .72093 m .69049 .71164 L .69089 .71188 L .682 0 0 r
F
.6939 .71951 m .69089 .71188 L .69899 .71689 L F
.69114 .72093 m .69089 .71188 L .6939 .71951 L F
.69169 .7329 m .69976 .74225 L .69969 .73717 L 1 .855 .673 r
F
.69148 .73279 m .69165 .73298 L .69169 .7329 L F
.69165 .73298 m .69976 .74225 L .69169 .7329 L F
.69967 .7173 m .69978 .71612 L .7002 .71761 L .62 0 .072 r
F
.69899 .7169 m .69978 .71612 L .69967 .7173 L F
.7002 .71762 m .70814 .70256 L .71308 .72464 L .616 0 .086 r
F
.70007 .72685 m .69899 .7169 L .7002 .71761 L .805 0 .108 r
F
.70007 .72685 m .70091 .74082 L .70071 .72689 L 1 .817 .652 r
F
.71284 .72487 m .70091 .74082 L .71309 .7251 L 1 .8 .646 r
F
.71284 .72487 m .7002 .71762 L .71308 .72464 L .804 0 .127 r
F
.70072 .72689 m .7002 .71762 L .71284 .72487 L F
.70053 .71334 m .70072 .72689 L .71284 .72487 L 1 .8 .646 r
F
.70072 .72689 m .70091 .74082 L .71284 .72487 L F
.70123 .736 m .70072 .72689 L .71284 .72487 L .804 0 .127 r
F
.70007 .72685 m .69976 .74225 L .70091 .74082 L 1 .817 .652 r
F
.69956 .72691 m .69899 .7169 L .70007 .72685 L .805 0 .108 r
F
.69941 .71591 m .69956 .72691 L .70007 .72685 L 1 .817 .652 r
F
.69956 .72691 m .69976 .74225 L .70007 .72685 L F
.69957 .72706 m .69956 .72691 L .70007 .72685 L .805 0 .108 r
F
.69997 .73413 m .70007 .72685 L .70122 .73599 L F
.70007 .72685 m .7002 .71761 L .70071 .72689 L F
.70007 .72685 m .70071 .72689 L .70122 .73599 L F
.70007 .72685 m .70071 .72689 L .70071 .72658 L 1 .817 .652 r
F
.69941 .71591 m .70007 .72685 L .70053 .71334 L F
.70007 .72685 m .70071 .72658 L .70053 .71334 L F
.69997 .73413 m .69957 .72706 L .70007 .72685 L .805 0 .108 r
F
.70052 .71348 m .69941 .71591 L .70053 .71334 L .251 0 .287 r
F
.69897 .72733 m .69969 .73717 L .69956 .72691 L 1 .855 .673 r
F
.69503 .7302 m .69969 .73717 L .69897 .72733 L F
.69148 .73279 m .69552 .73494 L .69503 .7302 L F
.69552 .73494 m .69969 .73717 L .69503 .7302 L F
.69114 .72093 m .6939 .71951 L .69461 .72613 L .682 0 0 r
F
.68657 .7007 m .68729 .68991 L .6947 .70172 L .42 0 0 r
F
.69049 .71164 m .68657 .7007 L .6947 .70172 L .561 0 0 r
F
.67763 .70358 m .68657 .7007 L .69049 .71164 L .416 0 0 r
F
.6779 .70363 m .67763 .70358 L .69049 .71164 L 0 0 .547 r
F
.6888 .71787 m .69049 .71164 L .69114 .72092 L F
.6779 .70363 m .68599 .70877 L .6888 .71787 L F
.68599 .70877 m .69049 .71164 L .6888 .71787 L F
.68753 .69747 m .69114 .72093 L .69461 .72613 L .121 0 .627 r
F
.68753 .69746 m .68753 .69747 L .68753 .69747 L F
.68753 .69747 m .69114 .72093 L .68753 .69747 L F
.67801 .68249 m .67466 .66961 L .68868 .67407 L .194 0 .073 r
F
.68838 .68957 m .67801 .68249 L .68868 .67407 L .335 0 .056 r
F
.68729 .68991 m .67801 .68249 L .68837 .68957 L .332 0 .035 r
F
.68729 .68991 m .677 .68322 L .67801 .68249 L F
.67963 .69203 m .677 .68322 L .68729 .68991 L .252 0 0 r
F
.68657 .7007 m .67963 .69203 L .68729 .68991 L .42 0 0 r
F
.68006 .64007 m .68753 .69745 L .68753 .69746 L 0 0 .212 r
F
.6939 .71951 m .69899 .71689 L .69461 .72613 L .682 0 0 r
F
.68753 .69747 m .69461 .72613 L .69347 .71497 L .121 0 .627 r
F
.69148 .73279 m .69897 .72733 L .69461 .72613 L 1 .855 .673 r
F
.69897 .72733 m .69956 .72691 L .69893 .72681 L F
.69897 .72733 m .69893 .72681 L .69461 .72613 L F
.69476 .72615 m .69899 .71689 L .69956 .72691 L .682 0 0 r
F
.69461 .72613 m .6947 .72594 L .69476 .72615 L F
.6947 .72594 m .69899 .71689 L .69476 .72615 L F
.67454 .57895 m .68616 .56225 L .68696 .57727 L .183 0 0 r
F
.6947 .70172 m .68837 .68957 L .69585 .70183 L .476 0 .049 r
F
.6947 .70172 m .68729 .68991 L .68837 .68957 L F
.67207 .58929 m .67454 .57895 L .68696 .57727 L .417 0 0 r
F
.67207 .58929 m .68696 .57727 L .68511 .61288 L F
.659 .57861 m .66512 .58256 L .67088 .57182 L .864 .502 .799 r
F
.66206 .57835 m .67404 .57031 L .67454 .57895 L 0 0 0 r
F
.67404 .57031 m .67088 .57182 L .68265 .5627 L F
.66182 .57559 m .67088 .57182 L .67404 .57031 L .48 0 .641 r
F
.66182 .57559 m .659 .57861 L .66888 .57296 L F
.66182 .57559 m .66888 .57296 L .67088 .57182 L F
.64952 .57887 m .659 .57861 L .66182 .57559 L .591 .047 .801 r
F
.65542 .57797 m .66182 .57559 L .66206 .57835 L .311 0 .715 r
F
.64958 .57764 m .64952 .57887 L .66182 .57559 L F
.64958 .57764 m .66182 .57559 L .65542 .57797 L F
.66206 .57835 m .66182 .57559 L .67404 .57031 L 0 0 0 r
F
.659 .57861 m .65372 .58847 L .66512 .58256 L .864 .502 .799 r
F
.6595 .57994 m .66206 .57835 L .67454 .57895 L .177 0 0 r
F
.6595 .57994 m .67454 .57895 L .67207 .58929 L F
.66626 .57464 m .67207 .58929 L .68511 .61288 L 0 0 .422 r
F
.67454 .57895 m .67404 .57031 L .68616 .56225 L .183 0 0 r
F
.66626 .57464 m .68511 .61288 L .67831 .5768 L 0 0 .422 r
F
.67831 .5768 m .68512 .61289 L .68761 .64037 L .914 0 .137 r
F
.67831 .5768 m .68761 .64037 L .6853 .63556 L F
.68554 .64167 m .69322 .70222 L .69183 .69812 L F
.67831 .5768 m .68628 .64379 L .68554 .64167 L F
.68628 .64379 m .69322 .70222 L .68554 .64167 L F
.68512 .61289 m .69505 .57265 L .69606 .65038 L .533 0 .3 r
F
.69461 .72613 m .69476 .72615 L .69854 .71784 L 1 .855 .673 r
F
.69461 .72613 m .69854 .71784 L .69852 .71781 L F
.69476 .72615 m .69956 .72691 L .69941 .71592 L F
.69476 .72615 m .69941 .71592 L .69941 .71592 L F
.69461 .72613 m .69956 .72691 L .69997 .73413 L .682 0 0 r
F
.6967 .72587 m .69461 .72613 L .6985 .73195 L .121 0 .627 r
F
.69527 .72605 m .69461 .72613 L .69564 .72394 L .053 0 .166 r
F
.69852 .71781 m .69854 .71784 L .69941 .71592 L 1 .855 .673 r
F
.69976 .74225 m .69697 .7782 L .69811 .7775 L 1 .639 .655 r
F
.69166 .75199 m .69697 .7782 L .69976 .74225 L 1 .705 .672 r
F
.69165 .73298 m .69166 .75199 L .69976 .74225 L 1 .855 .673 r
F
.69148 .73279 m .69149 .73325 L .69165 .73298 L F
.69149 .73325 m .69166 .75199 L .69165 .73298 L F
.70021 .71893 m .69941 .71591 L .70052 .71348 L .251 0 .287 r
F
.69797 .76948 m .69997 .73413 L .69801 .76978 L .121 0 .627 r
F
.6967 .72587 m .6985 .73195 L .69715 .72581 L F
.69166 .75199 m .68891 .78293 L .69697 .7782 L 1 .705 .672 r
F
.67929 .76514 m .6889 .78293 L .69166 .752 L 1 .806 .701 r
F
.67921 .75241 m .68089 .75235 L .69148 .7328 L 1 .756 .703 r
F
.68089 .75235 m .69166 .752 L .69148 .7328 L F
.68089 .75235 m .69148 .7328 L .69148 .7328 L F
.69442 .72736 m .69148 .73279 L .69461 .72613 L .053 0 .166 r
F
.69281 .73784 m .69148 .73279 L .69442 .72736 L F
.68089 .75235 m .67929 .76514 L .69166 .752 L 1 .756 .703 r
F
.67921 .75241 m .67923 .75487 L .68089 .75235 L F
.67923 .75487 m .67929 .76514 L .68089 .75235 L F
.68987 .75688 m .69122 .73667 L .69281 .73784 L .053 0 .166 r
F
.69122 .73667 m .69143 .73356 L .69204 .73544 L F
.69122 .73667 m .69204 .73544 L .69281 .73784 L F
.68932 .76 m .69373 .74073 L .69797 .76948 L F
.69373 .74073 m .69715 .72581 L .69781 .76135 L F
.69373 .74073 m .69781 .76135 L .69797 .76948 L F
.69496 .74872 m .69744 .74149 L .69797 .76948 L .121 0 .627 r
F
.69148 .73279 m .69148 .73279 L .69442 .72736 L .053 0 .166 r
F
.69715 .72581 m .69564 .72394 L .69775 .71944 L F
.69687 .72704 m .69642 .7259 L .69715 .72581 L F
.69642 .7259 m .69564 .72394 L .69715 .72581 L F
.69347 .71497 m .6967 .72587 L .69715 .72581 L .121 0 .627 r
F
.68932 .76 m .69564 .72394 L .69687 .72704 L .053 0 .166 r
F
.69347 .71497 m .69461 .72613 L .6967 .72587 L .121 0 .627 r
F
.69486 .7284 m .69461 .72613 L .69527 .72605 L .053 0 .166 r
F
.68987 .75688 m .69461 .72613 L .69486 .7284 L F
.677 .68322 m .66502 .68276 L .67801 .68249 L .176 0 .044 r
F
.677 .68322 m .66411 .68392 L .66502 .68276 L F
.66991 .68804 m .66411 .68392 L .677 .68322 L .052 0 0 r
F
.67963 .69203 m .66991 .68804 L .677 .68322 L .252 0 0 r
F
.66796 .69437 m .66991 .68804 L .67963 .69203 L .07 0 0 r
F
.67422 .69858 m .67963 .69203 L .68657 .7007 L .278 0 0 r
F
.67422 .69858 m .66796 .69437 L .67963 .69203 L F
.67763 .70358 m .67422 .69858 L .68657 .7007 L .416 0 0 r
F
.67455 .68279 m .6779 .70363 L .69114 .72092 L .173 0 .655 r
F
.67455 .68279 m .69114 .72092 L .68753 .69746 L F
.68753 .69746 m .69715 .72581 L .69496 .74872 L .121 0 .627 r
F
.69715 .72581 m .6985 .73195 L .69829 .72918 L F
.69829 .72918 m .6985 .73195 L .69997 .73413 L F
.69715 .72581 m .69997 .73413 L .69496 .74872 L F
.69424 .73547 m .69338 .73268 L .69577 .7471 L 0 0 .212 r
F
.69614 .74825 m .69577 .7471 L .69767 .75854 L F
.69424 .73547 m .69577 .7471 L .69614 .74825 L F
.69143 .73356 m .69148 .73279 L .69281 .73784 L .053 0 .166 r
F
.69744 .74149 m .69997 .73413 L .69797 .76948 L .121 0 .627 r
F
.69797 .76948 m .69941 .71592 L .698 .76952 L .053 0 .166 r
F
.69715 .72581 m .69941 .71592 L .69797 .76948 L F
.69886 .74218 m .69932 .72039 L .70021 .71893 L .251 0 .287 r
F
.69932 .72039 m .69941 .71591 L .70021 .71893 L F
.69715 .72581 m .69775 .71944 L .69941 .71592 L .053 0 .166 r
F
.68853 .65013 m .69606 .65038 L .69728 .7454 L .533 0 .3 r
F
.68512 .61289 m .69606 .65038 L .68853 .65013 L F
.6853 .63556 m .68761 .64037 L .69322 .70222 L .914 0 .137 r
F
.69183 .69812 m .69322 .70222 L .69735 .74765 L F
.68512 .61289 m .68697 .57727 L .69505 .57265 L .533 0 .3 r
F
.67831 .5768 m .68498 .63662 L .68619 .57511 L .914 0 .137 r
F
.69732 .74664 m .69726 .74176 L .69706 .71071 L .759 .005 .447 r
F
.70814 .70256 m .71141 .68047 L .72039 .70231 L .521 0 .147 r
F
.70814 .70256 m .69993 .68546 L .71141 .68047 L F
.70136 .69308 m .70053 .71334 L .71239 .68537 L 1 .51 .559 r
F
.69703 .70245 m .69701 .7025 L .69619 .57168 L .759 .005 .447 r
F
.69699 .69613 m .6979 .70056 L .70136 .69308 L 1 .51 .559 r
F
.6979 .70056 m .70053 .71334 L .70136 .69308 L F
.69709 .71061 m .69706 .71071 L .69701 .7025 L .759 .005 .447 r
F
.69709 .71061 m .69701 .7025 L .69703 .70245 L F
.69732 .74664 m .69706 .71071 L .69709 .71061 L F
.71141 .68047 m .69926 .66478 L .70975 .65486 L .456 0 .192 r
F
.69993 .68546 m .69926 .66478 L .71141 .68047 L .408 0 .14 r
F
.69699 .69613 m .70136 .69308 L .70761 .63385 L 1 .51 .559 r
F
.71141 .68047 m .70975 .65486 L .72283 .67473 L .456 0 .192 r
F
.72039 .70231 m .71141 .68047 L .72283 .67473 L .556 0 .197 r
F
.70136 .69308 m .71239 .68537 L .70986 .65816 L 1 .51 .559 r
F
.70136 .69308 m .70986 .65816 L .70761 .63385 L F
.69702 .70074 m .69699 .69565 L .697 .70037 L .759 .005 .447 r
F
.68498 .63662 m .6895 .62694 L .68619 .57511 L .914 0 .137 r
F
.69704 .7449 m .69716 .74471 L .69087 .64742 L F
.69082 .64754 m .69087 .64742 L .68619 .57511 L F
.69704 .7449 m .69087 .64742 L .69082 .64754 L F
.68498 .63662 m .68996 .68133 L .6895 .62694 L F
.68996 .68133 m .69131 .6552 L .6895 .62694 L F
.69699 .69565 m .69696 .69471 L .697 .70037 L .759 .005 .447 r
F
.69729 .74225 m .69711 .7143 L .69726 .74256 L F
.69711 .7143 m .69702 .70074 L .6971 .71416 L F
.69711 .7143 m .6971 .71416 L .69726 .74256 L F
.69702 .70074 m .697 .70037 L .69726 .74256 L F
.69622 .62051 m .69619 .57168 L .69622 .62051 L F
.69653 .68078 m .69634 .6208 L .69624 .67145 L F
.69634 .6208 m .69619 .57168 L .69622 .62051 L F
.69634 .6208 m .69622 .62051 L .69624 .67145 L F
.69651 .62118 m .69619 .57168 L .6965 .62116 L F
.697 .70037 m .6965 .62116 L .69657 .69459 L F
.6965 .62116 m .69619 .57168 L .69634 .6208 L F
.6965 .62116 m .69634 .6208 L .69657 .69459 L F
.69624 .66352 m .69506 .57264 L .69619 .57168 L F
.70293 .60736 m .6962 .57168 L .70819 .55696 L .63 0 .414 r
F
.69699 .69565 m .69651 .62118 L .69696 .69471 L .759 .005 .447 r
F
.69651 .62118 m .6965 .62116 L .69696 .69471 L F
.69624 .6714 m .69622 .62051 L .70293 .60736 L .63 0 .414 r
F
.69622 .62051 m .6962 .57168 L .70293 .60736 L F
.6962 .57168 m .70707 .54028 L .70819 .55696 L .238 0 .141 r
F
.6962 .57168 m .6952 .55401 L .70707 .54028 L F
.69506 .57264 m .6952 .55401 L .69619 .57168 L .278 0 .141 r
F
.69506 .57264 m .69408 .55514 L .6952 .55401 L F
.68697 .57727 m .69408 .55514 L .69505 .57265 L .272 0 .11 r
F
.68697 .57727 m .68616 .56224 L .69408 .55514 L F
.6873 .57453 m .6991 .60901 L .69898 .56277 L 1 .234 .513 r
F
.69975 .6076 m .70641 .59661 L .70345 .59959 L 1 .371 .477 r
F
.6991 .60901 m .70345 .59959 L .70301 .59597 L 1 .234 .513 r
F
.69909 .60435 m .70301 .59597 L .69898 .56277 L F
.6991 .60901 m .70301 .59597 L .69909 .60435 L F
.70819 .55696 m .71878 .5239 L .71995 .53724 L .13 0 .11 r
F
.70819 .55696 m .70707 .54028 L .71878 .5239 L F
.69898 .56277 m .70903 .5828 L .71039 .54358 L 1 .3 .551 r
F
.70821 .58552 m .70641 .59661 L .70966 .58238 L .906 .004 .392 r
F
.70903 .5828 m .70979 .58181 L .71015 .58025 L F
.69898 .56277 m .70301 .59597 L .70903 .5828 L 1 .3 .551 r
F
.70301 .59597 m .70345 .59959 L .70903 .5828 L F
.70703 .58735 m .70849 .58443 L .70903 .5828 L .906 .004 .392 r
F
.70849 .58443 m .70979 .58181 L .70903 .5828 L F
.70903 .5828 m .7076 .63384 L .71905 .60278 L 1 .3 .551 r
F
.70022 .60283 m .70423 .5988 L .70821 .58552 L .906 .004 .392 r
F
.70423 .5988 m .70641 .59661 L .70821 .58552 L F
.6873 .57453 m .69124 .62399 L .6991 .60901 L 1 .234 .513 r
F
.70079 .63791 m .70207 .61555 L .70641 .59662 L .63 0 .414 r
F
.69883 .64903 m .70207 .61555 L .70079 .63791 L F
.69669 .66711 m .70207 .61555 L .69769 .66075 L F
.69769 .66075 m .69883 .64903 L .70079 .63791 L F
.69624 .6714 m .69669 .66711 L .69769 .66075 L F
.6991 .60901 m .69624 .67143 L .70641 .59661 L 1 .371 .477 r
F
.6991 .60901 m .70641 .59661 L .70042 .6065 L F
.6991 .60901 m .70359 .62211 L .70345 .59959 L 1 .234 .513 r
F
.70359 .62211 m .7076 .63384 L .70513 .61343 L F
.70359 .62211 m .70513 .61343 L .70345 .59959 L F
.70022 .60283 m .70641 .59661 L .70641 .59661 L .906 .004 .392 r
F
.70345 .59959 m .70513 .61343 L .70886 .58882 L 1 .3 .551 r
F
.70513 .61343 m .7076 .63384 L .70883 .58985 L F
.70513 .61343 m .70883 .58985 L .70886 .58882 L F
.69624 .67145 m .69622 .62051 L .69624 .67145 L .759 .005 .447 r
F
.69622 .62051 m .69622 .62051 L .69624 .67145 L F
.69124 .62399 m .69389 .65716 L .6991 .60901 L 1 .234 .513 r
F
.69455 .61674 m .69538 .6434 L .6991 .60901 L 1 .371 .477 r
F
.69538 .6434 m .69624 .67143 L .6991 .60901 L F
.69657 .69459 m .69653 .68078 L .69624 .67145 L .759 .005 .447 r
F
.68619 .57511 m .69077 .6468 L .69359 .65807 L 1 .173 .372 r
F
.69359 .65807 m .69624 .67148 L .69487 .66316 L 1 .099 .328 r
F
.68619 .57511 m .69359 .65807 L .6873 .57453 L 1 .173 .372 r
F
.69704 .7449 m .69735 .74765 L .69716 .74471 L .914 0 .137 r
F
.69359 .65807 m .69748 .752 L .69748 .75164 L 1 .173 .372 r
F
.68996 .68133 m .69704 .7449 L .69131 .6552 L .914 0 .137 r
F
.69077 .6468 m .69748 .752 L .69359 .65807 L 1 .173 .372 r
F
.68773 .62844 m .69748 .75216 L .69748 .75164 L 1 .099 .328 r
F
.69726 .74256 m .697 .70037 L .69657 .69459 L .759 .005 .447 r
F
.69732 .74664 m .69729 .74225 L .69726 .74256 L F
.69359 .65807 m .69748 .75164 L .69624 .67148 L 1 .099 .328 r
F
.68773 .62844 m .69748 .75164 L .69359 .65807 L F
.69359 .65807 m .69748 .75164 L .69698 .69611 L 1 .173 .372 r
F
.69359 .65807 m .6938 .66046 L .69362 .65799 L F
.69359 .65807 m .69362 .65799 L .6873 .57453 L F
.69388 .65714 m .69624 .67141 L .69432 .63862 L 1 .371 .477 r
F
.69624 .67141 m .69624 .67135 L .69317 .61908 L F
.69317 .61908 m .69624 .67135 L .69455 .61674 L F
.69624 .67135 m .69624 .67143 L .69455 .61674 L F
.69389 .65716 m .69389 .65721 L .6991 .60901 L 1 .234 .513 r
F
.69359 .65807 m .69487 .66316 L .69389 .65721 L 1 .099 .328 r
F
.69624 .67141 m .69624 .67143 L .69624 .67135 L 1 .371 .477 r
F
.69389 .65721 m .69699 .69607 L .69789 .65911 L 1 .234 .513 r
F
.69389 .65721 m .69789 .65911 L .6991 .60901 L F
.69388 .65721 m .69389 .65721 L .69388 .6572 L 1 .099 .328 r
F
.69359 .65807 m .69389 .65721 L .69388 .65721 L F
.6938 .66046 m .69388 .65717 L .6873 .57453 L 1 .173 .372 r
F
.69359 .65807 m .69388 .6572 L .69184 .64484 L 1 .099 .328 r
F
.69184 .64481 m .69388 .65714 L .69317 .61908 L 1 .371 .477 r
F
.69388 .65714 m .69432 .63862 L .69317 .61908 L F
.6938 .66046 m .69698 .69611 L .69388 .65717 L 1 .173 .372 r
F
.6991 .60901 m .69699 .69607 L .7076 .63384 L 1 .234 .513 r
F
.69644 .61353 m .6991 .60901 L .69779 .61084 L 1 .371 .477 r
F
.6991 .60901 m .70042 .6065 L .69779 .61084 L F
.69455 .61674 m .69644 .61353 L .69441 .61642 L F
.69644 .61353 m .69779 .61084 L .69441 .61642 L F
.70345 .59959 m .70886 .58882 L .70903 .5828 L 1 .3 .551 r
F
.70903 .5828 m .71015 .58025 L .71028 .58008 L .906 .004 .392 r
F
.71968 .5587 m .7177 .56309 L .72493 .54604 L 0 0 0 r
F
.72493 .54604 m .7177 .56309 L .7291 .53601 L F
.71327 .56654 m .71995 .53724 L .71814 .55798 L .296 0 .268 r
F
.71039 .54358 m .71968 .5587 L .72163 .52087 L 1 .362 .567 r
F
.71968 .5587 m .71977 .55885 L .7257 .54621 L F
.71977 .55885 m .73056 .57642 L .7257 .54621 L F
.71977 .55885 m .7257 .54621 L .7257 .54621 L F
.72571 .5462 m .73057 .57641 L .73099 .53477 L 1 .4 .576 r
F
.73048 .53603 m .72571 .5462 L .73099 .53477 L 0 0 0 r
F
.72282 .55487 m .72571 .5462 L .73048 .53603 L F
.72571 .5462 m .72571 .5462 L .73048 .53603 L F
.70929 .58333 m .71905 .60278 L .71443 .57118 L 1 .3 .551 r
F
.71968 .5587 m .71905 .60278 L .73056 .57642 L 1 .362 .567 r
F
.71858 .5613 m .71857 .56134 L .71968 .5587 L 0 0 0 r
F
.71857 .56134 m .7177 .56309 L .71968 .5587 L F
.71443 .57117 m .7177 .56309 L .71868 .56111 L F
.71015 .58025 m .71769 .5631 L .7124 .5762 L .906 .004 .392 r
F
.71154 .57832 m .71769 .5631 L .7177 .56309 L 0 0 0 r
F
.71327 .56654 m .71814 .55798 L .71769 .56309 L .296 0 .268 r
F
.71039 .54358 m .71443 .57118 L .71968 .5587 L 1 .362 .567 r
F
.71443 .57118 m .71905 .60278 L .71968 .5587 L F
.71868 .56111 m .71858 .5613 L .71968 .5587 L 0 0 0 r
F
.71154 .57832 m .71968 .5587 L .72282 .55488 L F
.71968 .5587 m .72493 .54604 L .7241 .54954 L F
.71968 .5587 m .7241 .54954 L .72282 .55488 L F
.72493 .54604 m .72692 .54254 L .72282 .55488 L F
.71968 .5587 m .7257 .54621 L .7255 .54492 L 1 .362 .567 r
F
.72493 .54604 m .7291 .53601 L .72692 .54254 L 0 0 0 r
F
.71968 .5587 m .7255 .54492 L .72163 .52087 L 1 .362 .567 r
F
.71154 .57832 m .71443 .57117 L .71868 .56111 L 0 0 0 r
F
.70903 .5828 m .70929 .58333 L .71443 .57118 L 1 .3 .551 r
F
.70903 .5828 m .71028 .58008 L .71033 .58001 L .906 .004 .392 r
F
.70903 .5828 m .71443 .57118 L .7138 .5669 L 1 .3 .551 r
F
.70903 .5828 m .71033 .58001 L .71071 .57948 L .906 .004 .392 r
F
.70703 .58735 m .70903 .5828 L .71071 .57948 L F
.70903 .5828 m .7138 .5669 L .71039 .54358 L 1 .3 .551 r
F
.70022 .60283 m .70703 .58735 L .71154 .57832 L .906 .004 .392 r
F
.70703 .58735 m .71071 .57948 L .71154 .57832 L F
.69441 .61642 m .69975 .6076 L .70123 .60182 L 1 .371 .477 r
F
.69975 .6076 m .70345 .59959 L .70123 .60182 L F
.69437 .61632 m .70123 .60182 L .70022 .60283 L F
.69317 .61908 m .69441 .61642 L .69437 .61632 L F
.69441 .61642 m .70123 .60182 L .69437 .61632 L F
.69317 .61908 m .69455 .61674 L .69441 .61642 L F
.69405 .61561 m .69437 .61632 L .70022 .60283 L F
.69127 .64634 m .69359 .65807 L .69184 .64484 L 1 .099 .328 r
F
.68773 .62844 m .69127 .64634 L .68881 .62648 L F
.69127 .64634 m .69184 .64484 L .68881 .62648 L F
.68881 .62647 m .69317 .61908 L .69437 .61632 L 1 .371 .477 r
F
.68881 .62647 m .69437 .61632 L .69405 .61561 L F
.68881 .62647 m .69184 .64481 L .69317 .61908 L F
.67848 .62137 m .68773 .62844 L .68881 .62648 L 1 .789 .641 r
F
.67841 .62133 m .67849 .6214 L .67848 .62137 L F
.67849 .6214 m .68773 .62844 L .67848 .62137 L F
.69069 .60846 m .70022 .60283 L .71154 .57832 L 1 .186 .538 r
F
.69677 .60167 m .69069 .60846 L .70181 .59363 L 0 0 0 r
F
.67991 .62203 m .68881 .62648 L .68063 .62116 L 1 .789 .641 r
F
.67848 .62137 m .67853 .6214 L .67845 .6213 L F
.67853 .6214 m .68881 .62648 L .67857 .62136 L F
.67853 .6214 m .67857 .62136 L .67845 .6213 L F
.68808 .6111 m .67946 .62039 L .69069 .60846 L .572 0 .486 r
F
.67845 .6213 m .67991 .62203 L .67946 .6204 L 1 .789 .641 r
F
.67841 .62133 m .67848 .62137 L .67845 .6213 L F
.67094 .62702 m .68773 .62845 L .6784 .62134 L 1 .816 .665 r
F
.67094 .62702 m .68006 .64007 L .68773 .62845 L F
.65956 .63274 m .68006 .64008 L .67094 .62702 L 1 .668 .709 r
F
.64854 .62364 m .65956 .63274 L .67094 .62702 L .971 .798 .823 r
F
.64854 .62364 m .67094 .62702 L .65938 .62833 L F
.65936 .62833 m .65938 .62833 L .65938 .62833 L F
.64854 .62364 m .65938 .62833 L .65936 .62833 L F
.65938 .62833 m .65938 .62833 L .66656 .63152 L .771 .298 .792 r
F
.66837 .62503 m .67094 .62702 L .6784 .62134 L F
.66476 .62636 m .66505 .62639 L .66837 .62503 L F
.66505 .62639 m .67094 .62702 L .66837 .62503 L F
.65938 .62833 m .66192 .62804 L .66476 .62636 L F
.66192 .62804 m .67094 .62702 L .66476 .62636 L F
.65938 .62833 m .6784 .62134 L .66666 .63143 L F
.66705 .6311 m .67841 .62133 L .67946 .6204 L .486 0 .491 r
F
.66657 .63152 m .66698 .63116 L .66705 .6311 L F
.66698 .63116 m .67841 .62133 L .66705 .6311 L F
.66657 .63152 m .67927 .62056 L .66758 .63182 L F
.67927 .62056 m .67931 .62055 L .66758 .63182 L F
.67927 .62056 m .67946 .6204 L .67931 .62055 L F
.66758 .63182 m .67946 .62039 L .68808 .6111 L .572 0 .486 r
F
.66758 .63182 m .67639 .62292 L .67838 .631 L F
.67946 .62039 m .67946 .62039 L .68808 .6111 L F
.67946 .62039 m .6859 .61495 L .69069 .60846 L 1 .715 .616 r
F
.6859 .61495 m .70022 .60283 L .69178 .60782 L F
.6859 .61495 m .69178 .60782 L .69069 .60846 L F
.7054 .5913 m .70181 .59363 L .71285 .57685 L 0 0 0 r
F
.67946 .62039 m .68881 .62647 L .70022 .60283 L 1 .715 .616 r
F
.68901 .62305 m .69995 .59791 L .7054 .5913 L 0 0 0 r
F
.69995 .59791 m .70181 .59363 L .7054 .5913 L F
.67639 .62292 m .68474 .61448 L .68408 .61618 L .572 0 .486 r
F
.67991 .62203 m .68063 .62116 L .67946 .6204 L 1 .789 .641 r
F
.67639 .62292 m .68408 .61618 L .67838 .631 L .572 0 .486 r
F
.65938 .62833 m .66666 .63143 L .66656 .63152 L .771 .298 .792 r
F
.68474 .61448 m .69069 .60846 L .68868 .61213 L .572 0 .486 r
F
.68474 .61448 m .68868 .61213 L .67838 .631 L F
.67838 .631 m .6898 .61009 L .69677 .60167 L 0 0 0 r
F
.6898 .61009 m .69069 .60846 L .69677 .60167 L F
.69775 .76119 m .6985 .7408 L .69886 .74218 L .251 0 .287 r
F
.6985 .7408 m .69941 .71591 L .69886 .74218 L F
.68684 .68565 m .69338 .73268 L .69424 .73547 L 0 0 .212 r
F
.68006 .64007 m .68699 .68826 L .68684 .68565 L F
.68699 .68826 m .69338 .73268 L .68684 .68565 L F
.68699 .68826 m .68753 .69746 L .69338 .73268 L F
.68006 .64007 m .68753 .69746 L .68699 .68826 L F
.69941 .71591 m .69941 .71591 L .70052 .71348 L .251 0 .287 r
F
.68932 .76 m .68952 .75746 L .68987 .75688 L .053 0 .166 r
F
.68952 .75746 m .69148 .73279 L .68987 .75688 L F
.71015 .58025 m .7124 .5762 L .71154 .57832 L .906 .004 .392 r
F
.72163 .52086 m .72571 .5462 L .73099 .53477 L 1 .4 .576 r
F
.72282 .55487 m .73099 .53477 L .73424 .53199 L 0 0 0 r
F
.73099 .53477 m .74067 .51096 L .73727 .52208 L F
.73099 .53477 m .73727 .52208 L .73424 .53199 L F
.72163 .52086 m .73099 .53477 L .73291 .49623 L 1 .4 .576 r
F
.73099 .53477 m .73727 .52208 L .73291 .49623 L F
.73291 .49623 m .73727 .52208 L .7427 .5108 L 1 .421 .58 r
F
.73424 .53199 m .7427 .5108 L .74562 .50963 L 0 0 0 r
F
.7427 .5108 m .7522 .48699 L .74886 .49848 L F
.7427 .5108 m .74886 .49848 L .74562 .50963 L F
.73291 .49623 m .7427 .5108 L .74409 .47082 L 1 .421 .58 r
F
.7427 .5108 m .74886 .49848 L .74409 .47082 L F
.74409 .47082 m .74886 .49848 L .75451 .48691 L 1 .43 .582 r
F
.74562 .50963 m .75451 .48691 L .75694 .4875 L 0 0 0 r
F
.75451 .48691 m .76367 .4635 L .76041 .47511 L F
.75451 .48691 m .76041 .47511 L .75694 .4875 L F
.74409 .47082 m .75451 .48691 L .75519 .44502 L 1 .43 .582 r
F
.75451 .48691 m .76041 .47511 L .75519 .44502 L F
.75519 .44502 m .76041 .47511 L .76629 .46309 L 1 .434 .583 r
F
.75694 .4875 m .76629 .46309 L .76821 .46544 L 0 0 0 r
F
.76629 .46309 m .77507 .44019 L .77191 .45182 L F
.76629 .46309 m .77191 .45182 L .76821 .46544 L F
.75519 .44502 m .76629 .46309 L .7662 .41897 L 1 .434 .583 r
F
.76629 .46309 m .77191 .45182 L .7662 .41897 L F
.7662 .41897 m .77191 .45182 L .778 .4393 L F
.76821 .46544 m .7719 .45186 L .778 .4393 L 0 0 0 r
F
.778 .4393 m .78333 .42853 L .7833 .4284 L 1 .434 .583 r
F
.778 .4393 m .7833 .4284 L .77712 .39277 L F
.7662 .41897 m .778 .4393 L .77712 .39277 L F
.76821 .46544 m .778 .4393 L .77942 .44336 L 0 0 0 r
F
.778 .4393 m .78333 .42853 L .77942 .44336 L F
.7833 .42837 m .78333 .42853 L .78961 .41552 L 1 .433 .582 r
F
.78961 .41552 m .79466 .4052 L .79465 .40525 L 0 0 0 r
F
.78961 .41552 m .79465 .40525 L .79057 .42122 L F
.77942 .44336 m .78961 .41552 L .79057 .42122 L F
.77712 .39277 m .78961 .41552 L .78796 .36646 L 1 .433 .582 r
F
.78961 .41552 m .79466 .4052 L .78796 .36646 L F
.79464 .40529 m .79466 .4052 L .8011 .39172 L 0 0 0 r
F
.8011 .39172 m .80879 .37017 L .80591 .38179 L F
.8011 .39172 m .80591 .38179 L .80589 .38166 L 1 .431 .582 r
F
.8011 .39172 m .80589 .38166 L .79872 .34005 L F
.78796 .36646 m .8011 .39172 L .79872 .34005 L F
.8011 .39172 m .81085 .41047 L .80591 .38179 L F
.79057 .42122 m .8011 .39172 L .80165 .39899 L 0 0 0 r
F
.8011 .39172 m .80591 .38179 L .80165 .39899 L F
.41476 .61391 m .40529 .60565 L .39455 .61285 L 1 .785 .774 r
F
.42451 .60784 m .40529 .60565 L .41476 .61391 L .998 .724 .797 r
F
.22608 .41696 m .22607 .4089 L .21488 .39302 L .429 .001 .579 r
F
.22658 .40697 m .22607 .4089 L .21519 .38706 L .968 0 .104 r
F
.22607 .4089 m .21552 .38939 L .21519 .38706 L F
.22607 .4089 m .22599 .33006 L .21552 .38939 L .429 .001 .579 r
F
.22607 .4089 m .21552 .38939 L .21488 .39302 L F
.22053 .48879 m .22608 .41696 L .21488 .39302 L .473 .004 .586 r
F
.22607 .4089 m .22108 .42809 L .21552 .38939 L .968 0 .104 r
F
.67801 .68249 m .66502 .68275 L .67466 .66961 L .194 0 .073 r
F
.53206 .60722 m .52609 .61393 L .53579 .61375 L .655 .489 .848 r
F
.53206 .60722 m .52396 .60749 L .52609 .61393 L F
.4433 .60805 m .43426 .60271 L .42451 .60784 L .883 .706 .826 r
F
.45194 .60329 m .43426 .60271 L .4433 .60805 L .818 .643 .831 r
F
.461 .60746 m .45194 .60329 L .4433 .60805 L .774 .626 .842 r
F
.59153 .80188 m .56878 .78329 L .59202 .80274 L 0 0 .551 r
F
.46836 .60262 m .45194 .60329 L .461 .60746 L .748 .589 .841 r
F
.47697 .60588 m .46836 .60262 L .461 .60746 L .714 .565 .848 r
F
.4907 .60308 m .47697 .60588 L .48627 .6086 L .688 .532 .848 r
F
.49888 .60497 m .4907 .60308 L .48627 .6086 L .671 .517 .851 r
F
.66411 .68392 m .64971 .69371 L .66502 .68276 L .092 0 .146 r
F
.66411 .68392 m .64892 .69569 L .64971 .69371 L F
.58807 .79519 m .56844 .78295 L .59153 .80188 L 0 0 .681 r
F
.33676 .55951 m .33247 .53655 L .32065 .52496 L .298 .002 .702 r
F
.33784 .56049 m .33247 .53655 L .33676 .55951 L .343 .011 .712 r
F
.34492 .60192 m .33676 .55951 L .34389 .60111 L .461 .016 .636 r
F
.34492 .60192 m .33784 .56049 L .33676 .55951 L F
.78153 .68844 m .77966 .63712 L .79363 .68387 L .632 0 .294 r
F
.78153 .68844 m .76844 .64552 L .77966 .63712 L F
.39087 .69748 m .37463 .69677 L .36852 .68768 L .934 0 .158 r
F
.39922 .70321 m .37463 .69677 L .39087 .69748 L .622 0 0 r
F
.41615 .71445 m .39922 .70321 L .39637 .70118 L .411 0 0 r
F
.42337 .71487 m .39922 .70321 L .41615 .71445 L 0 0 .749 r
F
.40551 .70625 m .40769 .70596 L .39922 .70321 L F
.42337 .71487 m .40769 .70596 L .40551 .70625 L F
.41624 .70621 m .41002 .70566 L .40769 .70596 L .458 .171 .898 r
F
.40769 .70596 m .40226 .70537 L .39922 .70321 L 0 0 .668 r
F
.40226 .70537 m .38413 .70338 L .39922 .70321 L F
.41002 .70566 m .39379 .70422 L .40769 .70596 L .458 .171 .898 r
F
.39637 .70118 m .39922 .70321 L .39087 .69748 L .411 0 0 r
F
.60575 .61397 m .60574 .63046 L .61592 .61844 L .854 .446 .759 r
F
.60575 .61397 m .59656 .6229 L .60574 .63046 L F
.33784 .56049 m .33358 .53753 L .33247 .53655 L .343 .011 .712 r
F
.34547 .56657 m .33358 .53754 L .33784 .56049 L .385 .025 .715 r
F
.35227 .60529 m .33784 .56049 L .34493 .60192 L .494 .027 .642 r
F
.35227 .60529 m .34547 .56657 L .33784 .56049 L F
.53983 .60634 m .53579 .61375 L .54509 .61285 L .664 .491 .845 r
F
.53983 .60634 m .53206 .60722 L .53579 .61375 L F
.5916 .90579 m .5584 .97629 L .56056 .99066 L 1 .666 .607 r
F
.58793 .89878 m .5584 .97629 L .5916 .90579 L 1 .656 .613 r
F
.51918 .75881 m .49802 .76502 L .51967 .76518 L .808 .486 .787 r
F
.53912 .76147 m .51967 .76518 L .54122 .76726 L .586 .384 .843 r
F
.53912 .76147 m .51918 .75881 L .51967 .76518 L F
.36156 .6684 m .35227 .60529 L .34493 .60192 L .609 .029 .587 r
F
.46252 .85387 m .43309 .87429 L .42886 .86806 L .44 0 .158 r
F
.37555 .90772 m .34021 .97315 L .33282 .97954 L 0 0 .041 r
F
.38129 .90721 m .34021 .97315 L .37555 .90772 L 0 0 .01 r
F
.4651 .86916 m .43309 .87429 L .46252 .85388 L .46 0 .065 r
F
.44063 .72765 m .41615 .71445 L .43478 .73084 L .232 .015 .828 r
F
.45923 .74079 m .43478 .73084 L .45485 .74763 L .445 .154 .811 r
F
.45923 .74079 m .44063 .72765 L .43478 .73084 L F
.65768 .69159 m .64892 .69569 L .66411 .68392 L 0 0 .026 r
F
.56185 .60854 m .56053 .61773 L .56987 .61478 L .692 .487 .83 r
F
.56185 .60854 m .55383 .61114 L .56053 .61773 L F
.51918 .75881 m .49916 .75648 L .49802 .76502 L .808 .486 .787 r
F
.49916 .75648 m .47607 .76014 L .49802 .76501 L .821 .426 .763 r
F
.47886 .75099 m .45485 .74763 L .47607 .76014 L .651 .31 .779 r
F
.47886 .75099 m .45923 .74079 L .45485 .74763 L F
.57819 .61051 m .57788 .62155 L .58738 .61637 L .733 .48 .811 r
F
.57819 .61051 m .56987 .61478 L .57788 .62155 L F
.42451 .60784 m .416 .60018 L .40529 .60565 L .998 .724 .797 r
F
.43426 .60271 m .416 .60018 L .42451 .60784 L .895 .668 .813 r
F
.22053 .48879 m .21488 .39302 L .20898 .47003 L .473 .004 .586 r
F
.48294 .60069 m .46836 .60262 L .47697 .60588 L .708 .549 .845 r
F
.4907 .60308 m .48294 .60069 L .47697 .60588 L .688 .532 .848 r
F
.68447 .93458 m .66078 .87505 L .69251 .93973 L 1 .001 .16 r
F
.68447 .93458 m .65427 .87332 L .66078 .87505 L F
.49916 .75648 m .47886 .75099 L .47607 .76014 L .821 .426 .763 r
F
.62426 .6056 m .62606 .62277 L .6352 .60594 L 1 .622 .761 r
F
.62426 .6056 m .61592 .61844 L .62606 .62277 L F
.64222 .59237 m .64607 .60476 L .65372 .58847 L 1 .947 .796 r
F
.64222 .59237 m .6352 .60594 L .64607 .60476 L F
.32065 .52496 m .31925 .51578 L .30729 .50448 L 0 0 .7 r
F
.33247 .53655 m .31925 .51578 L .32065 .52496 L .138 0 .763 r
F
.59556 .60954 m .59656 .6229 L .60575 .61397 L .809 .494 .789 r
F
.59556 .60954 m .58738 .61637 L .59656 .6229 L F
.44063 .72765 m .42337 .71487 L .41615 .71445 L .232 .015 .828 r
F
.54712 .60481 m .54509 .61285 L .55383 .61114 L .676 .495 .84 r
F
.54712 .60481 m .53983 .60634 L .54509 .61285 L F
.45194 .60329 m .44403 .59825 L .43426 .60271 L .818 .643 .831 r
F
.46059 .59876 m .44403 .59825 L .45194 .60329 L .772 .598 .835 r
F
.46836 .60262 m .46059 .59876 L .45194 .60329 L .748 .589 .841 r
F
.55867 .76596 m .54122 .76726 L .56237 .77378 L .42 .17 .854 r
F
.55867 .76596 m .53912 .76147 L .54122 .76726 L F
.28351 .47697 m .28515 .49028 L .2732 .47682 L .781 0 0 r
F
.69408 .55514 m .69144 .55431 L .6952 .55401 L 0 0 0 r
F
.69408 .55514 m .69035 .55542 L .69144 .55431 L F
.22005 .57421 m .20898 .47003 L .20834 .56088 L .537 .015 .59 r
F
.22005 .57421 m .22053 .48879 L .20898 .47003 L F
.51517 .60076 m .50733 .60635 L .51567 .60719 L .667 .505 .849 r
F
.51517 .60076 m .50848 .60011 L .50733 .60635 L F
.50848 .60011 m .49888 .60497 L .50733 .60635 L .671 .51 .848 r
F
.5828 .78345 m .56604 .77998 L .58807 .79518 L .183 .003 .806 r
F
.5828 .78345 m .56237 .77378 L .56604 .77998 L F
.52182 .60095 m .51567 .60719 L .52396 .60749 L .666 .502 .848 r
F
.52182 .60095 m .51517 .60076 L .51567 .60719 L F
.68616 .56224 m .69035 .55542 L .69408 .55514 L 0 0 0 r
F
.68616 .56224 m .68265 .5627 L .69035 .55542 L F
.23668 .3586 m .24229 .2798 L .22599 .33006 L .431 0 .575 r
F
.22608 .41696 m .22716 .41102 L .22607 .4089 L .429 .001 .579 r
F
.23737 .4408 m .23728 .43003 L .22608 .41696 L .41 0 .579 r
F
.23807 .42615 m .23728 .42911 L .22658 .40697 L .984 0 .115 r
F
.23728 .43003 m .23728 .42911 L .22716 .41102 L .41 0 .579 r
F
.23728 .43003 m .22716 .41102 L .22608 .41696 L F
.23217 .50721 m .23737 .4408 L .22608 .41696 L .462 .004 .589 r
F
.23728 .42911 m .23243 .44725 L .22716 .41102 L .984 0 .115 r
F
.23728 .42911 m .22716 .41102 L .22658 .40697 L F
.23728 .42911 m .23668 .3586 L .22716 .41102 L .41 0 .579 r
F
.23217 .50721 m .22608 .41696 L .22053 .48879 L .462 .004 .589 r
F
.22606 .40895 m .23243 .44725 L .22108 .42809 L .968 0 .104 r
F
.22607 .4089 m .22609 .409 L .22606 .40895 L F
.22609 .409 m .23243 .44725 L .22606 .40895 L F
.22658 .40697 m .22716 .41102 L .22607 .4089 L F
.22716 .41102 m .23243 .44725 L .22607 .4089 L F
.22607 .4089 m .23668 .3586 L .22599 .33006 L .429 .001 .579 r
F
.22716 .41102 m .23668 .3586 L .22607 .4089 L F
.47575 .5978 m .46059 .59876 L .46836 .60262 L .727 .562 .841 r
F
.48294 .60069 m .47575 .5978 L .46836 .60262 L .708 .549 .845 r
F
.36361 .60446 m .34548 .56657 L .35228 .60529 L .554 .068 .667 r
F
.37285 .63862 m .35228 .60529 L .36156 .66839 L .772 .156 .653 r
F
.37285 .63862 m .36361 .60446 L .35228 .60529 L F
.50171 .59898 m .4907 .60308 L .49888 .60497 L .679 .517 .847 r
F
.50848 .60011 m .50171 .59898 L .49888 .60497 L .671 .51 .848 r
F
.43426 .60271 m .42672 .59582 L .416 .60018 L .895 .668 .813 r
F
.44403 .59825 m .42672 .59582 L .43426 .60271 L .824 .621 .823 r
F
.39455 .61285 m .37503 .60073 L .38376 .62297 L .975 .477 .734 r
F
.39455 .61285 m .38647 .5967 L .37503 .60073 L F
.40529 .60565 m .38647 .5967 L .39455 .61285 L .944 .547 .765 r
F
.34547 .56657 m .34144 .54395 L .33358 .53754 L .385 .025 .715 r
F
.35717 .57301 m .34145 .54395 L .34548 .56657 L .451 .066 .725 r
F
.36361 .60446 m .35717 .57301 L .34548 .56657 L .554 .068 .667 r
F
.38376 .62297 m .36361 .60446 L .37285 .63862 L .938 .347 .698 r
F
.38376 .62297 m .37503 .60073 L .36361 .60446 L F
.61328 .60416 m .61592 .61844 L .62426 .6056 L .932 .61 .786 r
F
.61328 .60416 m .60575 .61397 L .61592 .61844 L F
.52831 .60066 m .52396 .60749 L .53206 .60722 L .669 .502 .846 r
F
.52831 .60066 m .52182 .60095 L .52396 .60749 L F
.42886 .86806 m .39873 .90522 L .39288 .90606 L .112 0 .023 r
F
.43309 .87429 m .39873 .90522 L .42886 .86806 L .061 0 0 r
F
.56898 .60505 m .56987 .61478 L .57819 .61051 L .716 .501 .825 r
F
.56898 .60505 m .56185 .60854 L .56987 .61478 L F
.49515 .59742 m .48294 .60069 L .4907 .60308 L .689 .526 .845 r
F
.50171 .59898 m .49515 .59742 L .4907 .60308 L .679 .517 .847 r
F
.40529 .60565 m .39792 .5931 L .38647 .5967 L .944 .547 .765 r
F
.416 .60018 m .39792 .5931 L .40529 .60565 L .891 .574 .788 r
F
.5538 .60262 m .55383 .61114 L .56185 .60854 L .69 .501 .836 r
F
.5538 .60262 m .54712 .60481 L .55383 .61114 L F
.58534 .60516 m .58738 .61637 L .59556 .60954 L .766 .518 .812 r
F
.58534 .60516 m .57819 .61051 L .58738 .61637 L F
.58793 .89878 m .55624 .96132 L .5584 .97629 L 1 .656 .613 r
F
.58424 .89187 m .55624 .96132 L .58793 .89878 L 1 .643 .621 r
F
.63065 .59446 m .6352 .60594 L .64222 .59237 L 1 .861 .812 r
F
.63065 .59446 m .62426 .6056 L .6352 .60594 L F
.5003 .74841 m .47886 .75099 L .49916 .75648 L .746 .413 .783 r
F
.51869 .75163 m .49916 .75648 L .51918 .75881 L .735 .437 .796 r
F
.51869 .75163 m .5003 .74841 L .49916 .75648 L F
.53454 .59989 m .53206 .60722 L .53983 .60634 L .674 .502 .844 r
F
.53454 .59989 m .52831 .60066 L .53206 .60722 L F
.48166 .74291 m .45923 .74079 L .47886 .75099 L .638 .337 .797 r
F
.5003 .74841 m .48166 .74291 L .47886 .75099 L .746 .413 .783 r
F
.76937 .69255 m .76844 .64552 L .78153 .68844 L .624 0 .284 r
F
.76937 .69255 m .75714 .65354 L .76844 .64552 L F
.46362 .73444 m .44063 .72765 L .45923 .74079 L .488 .223 .824 r
F
.48166 .74291 m .46362 .73444 L .45923 .74079 L .638 .337 .797 r
F
.53701 .75432 m .51918 .75881 L .53912 .76147 L .622 .382 .822 r
F
.53701 .75432 m .51869 .75163 L .51918 .75881 L F
.37503 .60073 m .35717 .57301 L .36361 .60446 L .635 .151 .701 r
F
.48893 .59542 m .47575 .5978 L .48294 .60069 L .701 .535 .843 r
F
.49515 .59742 m .48893 .59542 L .48294 .60069 L .689 .526 .845 r
F
.44652 .72405 m .42337 .71487 L .44063 .72765 L .36 .1 .852 r
F
.46362 .73444 m .44652 .72405 L .44063 .72765 L .488 .223 .824 r
F
.416 .60018 m .40937 .59004 L .39792 .5931 L .891 .574 .788 r
F
.42672 .59582 m .40937 .59004 L .416 .60018 L .837 .577 .805 r
F
.46059 .59876 m .45382 .59423 L .44403 .59825 L .772 .598 .835 r
F
.46928 .59442 m .45382 .59423 L .46059 .59876 L .74 .566 .837 r
F
.47575 .5978 m .46928 .59442 L .46059 .59876 L .727 .562 .841 r
F
.60225 .60194 m .60575 .61397 L .61328 .60416 L .848 .595 .807 r
F
.60225 .60194 m .59556 .60954 L .60575 .61397 L F
.44403 .59825 m .43744 .59218 L .42672 .59582 L .824 .621 .823 r
F
.45382 .59423 m .43744 .59218 L .44403 .59825 L .775 .585 .83 r
F
.67639 .92931 m .65427 .87332 L .68447 .93458 L 1 0 .145 r
F
.67639 .92931 m .64771 .87099 L .65427 .87332 L F
.38129 .90721 m .34763 .96663 L .34021 .97315 L 0 0 .01 r
F
.38707 .90668 m .34763 .96663 L .38129 .90721 L 0 0 0 r
F
.54038 .59863 m .53983 .60634 L .54712 .60481 L .68 .504 .842 r
F
.54038 .59863 m .53454 .59989 L .53983 .60634 L F
.64703 .58329 m .65372 .58847 L .659 .57861 L .891 .718 .839 r
F
.64703 .58329 m .64222 .59237 L .65372 .58847 L F
.33247 .53655 m .3313 .52554 L .31925 .51578 L .138 0 .763 r
F
.33358 .53753 m .3313 .52554 L .33247 .53655 L .188 .001 .782 r
F
.67404 .57031 m .68265 .5627 L .68616 .56225 L 0 0 0 r
F
.37503 .60073 m .36897 .57663 L .35717 .57301 L .635 .151 .701 r
F
.38647 .5967 m .36897 .57663 L .37503 .60073 L .704 .259 .735 r
F
.39922 .70321 m .38413 .70338 L .37463 .69677 L .622 0 0 r
F
.33358 .53753 m .33243 .52637 L .3313 .52554 L .188 .001 .782 r
F
.34144 .54395 m .33244 .52638 L .33358 .53754 L .272 .017 .79 r
F
.55974 .59981 m .56185 .60854 L .56898 .60505 L .7 .509 .835 r
F
.55974 .59981 m .5538 .60262 L .56185 .60854 L F
.29543 .4916 m .29722 .50149 L .28515 .49028 L .718 0 0 r
F
.30729 .50448 m .29722 .5015 L .29544 .4916 L .6 0 0 r
F
.35717 .57301 m .35345 .55197 L .34145 .54395 L .451 .066 .725 r
F
.36897 .57663 m .35345 .55197 L .35717 .57301 L .524 .133 .741 r
F
.5751 .60081 m .57819 .61051 L .58534 .60516 L .732 .524 .827 r
F
.5751 .60081 m .56898 .60505 L .57819 .61051 L F
.48318 .59302 m .46928 .59442 L .47575 .5978 L .712 .542 .841 r
F
.48893 .59542 m .48318 .59302 L .47575 .5978 L .701 .535 .843 r
F
.55495 .75713 m .53912 .76147 L .55867 .76596 L .534 .286 .828 r
F
.55495 .75713 m .53701 .75432 L .53912 .76147 L F
.57751 .77095 m .56237 .77378 L .5828 .78345 L .418 .127 .813 r
F
.57751 .77095 m .55867 .76596 L .56237 .77378 L F
.61903 .59506 m .62426 .6056 L .63065 .59446 L .94 .769 .825 r
F
.61903 .59506 m .61328 .60416 L .62426 .6056 L F
.42672 .59582 m .42083 .58743 L .40937 .59004 L .837 .577 .805 r
F
.43744 .59218 m .42083 .58743 L .42672 .59582 L .793 .568 .818 r
F
.43064 .71388 m .40769 .70596 L .42337 .71487 L .273 .033 .868 r
F
.44652 .72405 m .43064 .71388 L .42337 .71487 L .36 .1 .852 r
F
.38647 .5967 m .38085 .57829 L .36897 .57663 L .704 .259 .735 r
F
.39792 .5931 m .38085 .57829 L .38647 .5967 L .746 .361 .763 r
F
.66991 .68804 m .65768 .69159 L .66411 .68392 L .052 0 0 r
F
.51467 .59421 m .50848 .60011 L .51517 .60076 L .676 .51 .846 r
F
.51467 .59421 m .50964 .59373 L .50848 .60011 L F
.50964 .59373 m .50171 .59898 L .50848 .60011 L .678 .512 .846 r
F
.51967 .59433 m .51517 .60076 L .52182 .60095 L .675 .508 .846 r
F
.51967 .59433 m .51467 .59421 L .51517 .60076 L F
.63451 .72163 m .6291 .8599 L .64328 .70867 L .648 .012 .525 r
F
.54572 .59688 m .54712 .60481 L .5538 .60262 L .685 .507 .84 r
F
.54572 .59688 m .54038 .59863 L .54712 .60481 L F
.50455 .59287 m .49515 .59742 L .50171 .59898 L .683 .516 .845 r
F
.50964 .59373 m .50455 .59287 L .50171 .59898 L .678 .512 .846 r
F
.5912 .59919 m .59556 .60954 L .60225 .60194 L .784 .575 .823 r
F
.5912 .59919 m .58534 .60516 L .59556 .60954 L F
.52455 .59409 m .52182 .60095 L .52831 .60066 L .676 .508 .845 r
F
.52455 .59409 m .51967 .59433 L .52182 .60095 L F
.52532 1.10975 m .52238 1.11782 L .52584 1.12843 L 1 .624 .578 r
F
.52226 1.11829 m .48411 1.03442 L .52366 1.13308 L .127 0 .558 r
F
.52226 1.11766 m .48411 1.03442 L .52235 1.11848 L F
.52481 1.09038 m .52118 1.10047 L .52532 1.10975 L 1 .621 .578 r
F
.52118 1.10047 m .52075 1.10166 L .52157 1.10312 L F
.52118 1.10047 m .52157 1.10312 L .52532 1.10975 L F
.51955 1.08339 m .51885 1.08243 L .51907 1.08474 L 1 .614 .576 r
F
.52429 1.06996 m .52112 1.07722 L .52139 1.07817 L F
.52005 1.05881 m .51676 1.06429 L .51709 1.06748 L 1 .602 .574 r
F
.52377 1.04794 m .5196 1.05766 L .52005 1.05881 L F
.5196 1.05766 m .51676 1.06429 L .52005 1.05881 L F
.51094 1.03427 m .50975 1.03811 L .51456 1.04422 L 1 .508 .566 r
F
.4945 .99332 m .48986 .97955 L .49465 .99394 L .056 0 .502 r
F
.50859 1.03469 m .48986 .97955 L .51075 1.0415 L F
.51676 1.06429 m .51594 1.06618 L .51709 1.06748 L 1 .602 .574 r
F
.51885 1.08243 m .51849 1.08327 L .51907 1.08474 L 1 .614 .576 r
F
.52429 1.06996 m .51868 1.08585 L .52481 1.09038 L F
.52045 1.09923 m .51868 1.08585 L .52054 1.10002 L .114 0 .549 r
F
.51921 1.09019 m .4864 1.01302 L .52036 1.09956 L F
.51868 1.08585 m .51854 1.08553 L .51921 1.09019 L F
.51854 1.08553 m .4864 1.01302 L .51921 1.09019 L F
.51623 1.06997 m .48755 1.00214 L .5182 1.0825 L .1 0 .54 r
F
.51325 1.05414 m .51594 1.06618 L .52377 1.04794 L 1 .577 .57 r
F
.51547 1.06384 m .51534 1.06349 L .51594 1.06618 L .08 0 .524 r
F
.51534 1.06349 m .4887 .99105 L .51594 1.06618 L F
.52325 1.02354 m .51325 1.05414 L .52377 1.04794 L 1 .577 .57 r
F
.51351 1.05481 m .51325 1.05414 L .51594 1.06512 L .08 0 .524 r
F
.51325 1.05414 m .4887 .99105 L .5151 1.06283 L F
.51325 1.05414 m .5151 1.06283 L .51594 1.06512 L F
.52069 1.10182 m .48525 1.02377 L .52218 1.11644 L .122 0 .555 r
F
.52236 1.11788 m .48525 1.02377 L .48411 1.03442 L .127 0 .558 r
F
.52238 1.11782 m .52236 1.11787 L .52236 1.11788 L 1 .624 .578 r
F
.52532 1.10975 m .52227 1.11667 L .52238 1.11782 L F
.52238 1.11782 m .52236 1.11788 L .5224 1.11801 L F
.52535 1.12441 m .52227 1.11667 L .52236 1.11788 L .127 0 .558 r
F
.52227 1.11667 m .48525 1.02377 L .52236 1.11788 L F
.52075 1.10166 m .52069 1.10182 L .52079 1.10199 L 1 .621 .578 r
F
.52075 1.10166 m .52079 1.10199 L .52532 1.10975 L F
.52069 1.10182 m .52227 1.11667 L .52532 1.10975 L F
.52069 1.10182 m .4864 1.01302 L .48525 1.02377 L .122 0 .555 r
F
.52081 1.10149 m .52068 1.10176 L .52069 1.10182 L 1 .621 .578 r
F
.52481 1.09038 m .52065 1.09982 L .52081 1.10149 L F
.52055 1.10004 m .4864 1.01302 L .52069 1.10182 L .122 0 .555 r
F
.52065 1.09982 m .52055 1.10004 L .52081 1.10149 L 1 .621 .578 r
F
.52055 1.10004 m .50204 1.14212 L .52074 1.10163 L F
.50204 1.14212 m .50206 1.14302 L .52074 1.10163 L F
.51868 1.08585 m .52055 1.10004 L .52481 1.09038 L 1 .614 .576 r
F
.51868 1.08585 m .48755 1.00214 L .4864 1.01302 L .114 0 .549 r
F
.51849 1.08327 m .51856 1.08426 L .5188 1.08535 L 1 .614 .576 r
F
.51839 1.08348 m .51866 1.08566 L .5188 1.08535 L F
.51849 1.08327 m .5188 1.08535 L .51907 1.08474 L F
.51849 1.08327 m .48755 1.00214 L .51868 1.08585 L .114 0 .549 r
F
.51907 1.08474 m .48693 1.15557 L .4857 1.17924 L 1 .614 .576 r
F
.52434 1.09862 m .51849 1.08327 L .51868 1.08585 L .114 0 .549 r
F
.51849 1.08327 m .51839 1.08348 L .51856 1.08426 L 1 .614 .576 r
F
.51623 1.06997 m .4887 .99105 L .48755 1.00214 L .1 0 .54 r
F
.51594 1.06618 m .51606 1.06763 L .51648 1.06881 L 1 .602 .574 r
F
.51572 1.0667 m .51616 1.06951 L .51648 1.06881 L F
.51594 1.06618 m .51648 1.06881 L .51709 1.06748 L F
.52139 1.07817 m .5192 1.08162 L .51955 1.08339 L 1 .614 .576 r
F
.52112 1.07722 m .5192 1.08162 L .52139 1.07817 L F
.51594 1.06618 m .4887 .99105 L .51623 1.06997 L .1 0 .54 r
F
.51709 1.06748 m .48816 1.13089 L .48693 1.15557 L 1 .602 .574 r
F
.52377 1.04794 m .51623 1.06997 L .52429 1.06996 L F
.51623 1.06997 m .5182 1.0825 L .51849 1.08327 L .1 0 .54 r
F
.51623 1.06997 m .48693 1.15557 L .51849 1.08327 L 1 .602 .574 r
F
.51623 1.06997 m .51849 1.08327 L .52429 1.06996 L F
.51623 1.06997 m .51849 1.08327 L .51865 1.0837 L .1 0 .54 r
F
.52384 1.08795 m .51594 1.06618 L .51623 1.06997 L F
.51594 1.06618 m .51572 1.0667 L .51606 1.06763 L 1 .602 .574 r
F
.51325 1.05414 m .4894 1.10408 L .48816 1.13089 L 1 .577 .57 r
F
.51325 1.05414 m .48986 .97955 L .4887 .99105 L .08 0 .524 r
F
.51376 1.05257 m .51322 1.05373 L .51325 1.05414 L 1 .577 .57 r
F
.52325 1.02354 m .51307 1.04777 L .51376 1.05257 L F
.5128 1.04842 m .48986 .97955 L .51325 1.05414 L .08 0 .524 r
F
.51353 1.05096 m .4894 1.10408 L .51376 1.05257 L 1 .577 .57 r
F
.51307 1.04777 m .5128 1.04842 L .51353 1.05096 L F
.5128 1.04842 m .4894 1.10408 L .51353 1.05096 L F
.50975 1.03811 m .5128 1.04842 L .51456 1.04422 L 1 .508 .566 r
F
.51168 1.04379 m .51028 1.03967 L .51404 1.05216 L .056 0 .502 r
F
.51028 1.03967 m .50975 1.03811 L .51113 1.04264 L F
.51028 1.03967 m .51113 1.04264 L .51404 1.05216 L F
.52334 1.08007 m .5128 1.04842 L .51325 1.05414 L .08 0 .524 r
F
.51322 1.05373 m .51318 1.05381 L .51325 1.05414 L 1 .577 .57 r
F
.51318 1.05381 m .4894 1.10408 L .51325 1.05414 L F
.51325 1.05414 m .48816 1.13089 L .51594 1.06618 L F
.51868 1.08585 m .52036 1.09956 L .52054 1.10002 L .114 0 .549 r
F
.51868 1.08585 m .4857 1.17924 L .52055 1.10004 L 1 .614 .576 r
F
.51839 1.08348 m .48693 1.15557 L .51866 1.08566 L F
.51572 1.0667 m .48816 1.13089 L .51616 1.06951 L 1 .602 .574 r
F
.51075 1.0415 m .4945 .99332 L .5128 1.04842 L .056 0 .502 r
F
.4945 .99332 m .49465 .99394 L .5128 1.04842 L F
.50965 1.03844 m .4894 1.10408 L .51229 1.04962 L 1 .508 .566 r
F
.52226 1.11659 m .52069 1.10182 L .52227 1.11667 L .122 0 .555 r
F
.52069 1.10182 m .52218 1.11644 L .52227 1.11667 L F
.52069 1.10182 m .48448 1.20238 L .52227 1.11667 L 1 .621 .578 r
F
.52069 1.10182 m .4857 1.17924 L .48448 1.20238 L F
.52068 1.10177 m .4857 1.17924 L .52069 1.10182 L F
.50257 1.1722 m .48448 1.20238 L .48325 1.22526 L 1 .624 .578 r
F
.52236 1.11788 m .52227 1.11769 L .52371 1.13321 L .127 0 .558 r
F
.52227 1.11769 m .52367 1.1331 L .52371 1.13321 L F
.52236 1.11788 m .50241 1.16237 L .50257 1.1722 L 1 .624 .578 r
F
.50241 1.16237 m .48448 1.20238 L .50257 1.1722 L F
.52236 1.11787 m .50241 1.16237 L .52236 1.11788 L F
.50241 1.16237 m .48448 1.20238 L .50241 1.16237 L F
.50241 1.16237 m .50241 1.16237 L .52236 1.11788 L F
.50975 1.03811 m .50859 1.03469 L .51075 1.0415 L .056 0 .502 r
F
.50975 1.03811 m .49066 1.07179 L .4894 1.10408 L 1 .508 .566 r
F
.52272 .99605 m .50891 1.02868 L .50975 1.03811 L F
.50975 1.03811 m .49102 .96711 L .48986 .97955 L .056 0 .502 r
F
.50973 1.03795 m .49102 .96711 L .50975 1.03811 L F
.50891 1.02868 m .49102 .96711 L .50988 1.03849 L F
.50623 1.02134 m .50026 1.00005 L .50892 1.02874 L .113 0 .489 r
F
.50026 1.00005 m .50407 1.01205 L .50892 1.02874 L F
.50599 1.02054 m .50655 1.03426 L .50891 1.02868 L .958 .077 .522 r
F
.50599 1.02054 m .49102 .96711 L .50623 1.02134 L .113 0 .489 r
F
.50758 1.01524 m .50599 1.02054 L .50891 1.02868 L .958 .077 .522 r
F
.50599 1.02054 m .49876 1.0447 L .50655 1.03426 L F
.49876 1.0447 m .49912 1.05181 L .50655 1.03426 L F
.50599 1.02054 m .49191 .97336 L .49066 1.07179 L F
.50024 1.03931 m .49746 1.01884 L .50033 1.04468 L 1 .067 .476 r
F
.49746 1.01884 m .49211 .97934 L .49772 1.0239 L F
.49746 1.01884 m .49772 1.0239 L .50033 1.04468 L F
.49876 1.0447 m .49066 1.07179 L .49912 1.05181 L .958 .077 .522 r
F
.50026 1.00005 m .49102 .96711 L .50407 1.01205 L .113 0 .489 r
F
.50599 1.02054 m .49221 .94904 L .49102 .96711 L F
.50613 1.02106 m .50598 1.02025 L .50599 1.02054 L F
.50121 .99558 m .49221 .94904 L .50599 1.02054 L F
.5222 .96637 m .49268 .95109 L .49674 .97225 L .958 .077 .522 r
F
.5222 .96637 m .49674 .97225 L .50599 1.02054 L F
.50617 1.02117 m .50599 1.02054 L .50623 1.02134 L .113 0 .489 r
F
.5057 1.00718 m .49268 .95109 L .50613 1.02106 L F
.49268 .95109 m .49221 .94904 L .50121 .99558 L F
.49268 .95109 m .50121 .99558 L .50613 1.02106 L F
.49674 .97225 m .49191 .97336 L .50599 1.02054 L .958 .077 .522 r
F
.49674 .97225 m .4922 .95084 L .49191 .97336 L F
.49268 .95109 m .4922 .95084 L .49674 .97225 L F
.50598 1.02025 m .50121 .99558 L .50599 1.02054 L .113 0 .489 r
F
.50891 1.02868 m .50655 1.03426 L .50975 1.03811 L 1 .508 .566 r
F
.52285 1.07666 m .50891 1.02868 L .50988 1.03849 L .056 0 .502 r
F
.50758 1.01524 m .50891 1.02868 L .52272 .99605 L .958 .077 .522 r
F
.51243 1.02943 m .51094 1.03427 L .51342 1.0321 L 1 .508 .566 r
F
.51094 1.03427 m .51456 1.04422 L .52325 1.02354 L F
.50828 1.02871 m .50617 1.02117 L .51075 1.03503 L .113 0 .489 r
F
.50617 1.02117 m .50892 1.02874 L .51075 1.03503 L F
.56485 1.01765 m .52584 1.12843 L .56698 1.03046 L 1 .634 .586 r
F
.56485 1.01765 m .52532 1.10975 L .52584 1.12843 L F
.56271 1.00442 m .52532 1.10975 L .56485 1.01765 L 1 .627 .588 r
F
.56271 1.00442 m .52481 1.09038 L .52532 1.10975 L F
.56056 .99066 m .52481 1.09038 L .56271 1.00442 L 1 .611 .59 r
F
.56056 .99066 m .52429 1.06996 L .52481 1.09038 L F
.55209 1.13205 m .5229 1.07676 L .52334 1.08007 L 0 0 .423 r
F
.55103 1.12981 m .52285 1.07666 L .55209 1.13205 L F
.55091 1.1179 m .53552 1.09691 L .55309 1.12714 L .849 0 .03 r
F
.55309 1.12715 m .52285 1.07666 L .5553 1.13785 L .774 0 0 r
F
.5522 1.12567 m .52639 1.08528 L .52297 1.07698 L F
.55158 1.12478 m .52639 1.08528 L .5522 1.12567 L F
.52334 1.08007 m .51431 1.05687 L .52384 1.08795 L .08 0 .524 r
F
.51431 1.05687 m .5164 1.06743 L .52384 1.08795 L F
.52384 1.08795 m .51678 1.07127 L .52434 1.09862 L .1 0 .54 r
F
.55751 1.15027 m .52334 1.08007 L .52384 1.08795 L 0 0 .527 r
F
.53293 1.0935 m .52297 1.07698 L .52292 1.07679 L .774 0 0 r
F
.55266 1.12644 m .53288 1.09348 L .53293 1.0935 L F
.53288 1.09348 m .52297 1.07698 L .53293 1.0935 L F
.55266 1.12643 m .52297 1.07698 L .55266 1.12644 L F
.5229 1.07676 m .52285 1.07669 L .52334 1.08007 L 0 0 .423 r
F
.52285 1.07666 m .5201 1.06999 L .52334 1.08007 L .056 0 .502 r
F
.51168 1.04379 m .51404 1.05216 L .52334 1.08007 L F
.5553 1.13785 m .52334 1.08007 L .55751 1.15027 L 0 0 .423 r
F
.52639 1.08528 m .52236 1.07895 L .52285 1.07666 L .774 0 0 r
F
.53552 1.09691 m .52236 1.07896 L .54038 1.10722 L .849 0 .03 r
F
.52236 1.07896 m .52236 1.07895 L .52866 1.08884 L F
.52236 1.07896 m .52866 1.08884 L .54038 1.10722 L F
.55162 1.12485 m .52639 1.08528 L .55309 1.12714 L .774 0 0 r
F
.55309 1.12714 m .55266 1.12643 L .55266 1.12644 L F
.55309 1.12714 m .55158 1.12478 L .5522 1.12567 L F
.53552 1.09691 m .54038 1.10722 L .55309 1.12714 L .849 0 .03 r
F
.55091 1.1179 m .52187 1.0845 L .52236 1.07895 L F
.52617 1.08847 m .52187 1.0845 L .52969 1.09349 L .705 0 0 r
F
.5192 1.08162 m .51885 1.08243 L .51955 1.08339 L 1 .614 .576 r
F
.51678 1.07127 m .51865 1.0837 L .52434 1.09862 L .1 0 .54 r
F
.55974 1.16444 m .52384 1.08795 L .52434 1.09862 L 0 0 .553 r
F
.55751 1.15027 m .52384 1.08795 L .55974 1.16444 L 0 0 .527 r
F
.52725 1.09234 m .52139 1.08841 L .52617 1.08847 L .705 0 0 r
F
.54872 1.10926 m .53092 1.09284 L .55091 1.1179 L F
.53092 1.09284 m .52617 1.08847 L .5291 1.09195 L F
.53092 1.09284 m .5291 1.09195 L .55091 1.1179 L F
.52617 1.08847 m .52969 1.09349 L .55091 1.1179 L F
.54097 1.10334 m .52139 1.08841 L .53871 1.10003 L F
.52542 1.09035 m .52139 1.08841 L .52744 1.09303 L .322 0 0 r
F
.52557 1.09055 m .52317 1.08941 L .52542 1.09035 L F
.53871 1.10003 m .52725 1.09234 L .52617 1.08847 L .705 0 0 r
F
.54872 1.10926 m .54097 1.10334 L .53871 1.10003 L F
.54653 1.10051 m .52542 1.09035 L .54872 1.10926 L .322 0 0 r
F
.52542 1.09035 m .52744 1.09303 L .54872 1.10926 L F
.54636 1.10043 m .52557 1.09055 L .52542 1.09035 L F
.54653 1.10051 m .54642 1.10046 L .54636 1.10043 L F
.54642 1.10046 m .52317 1.08941 L .54636 1.10043 L F
.52227 1.11769 m .52226 1.11766 L .52235 1.11848 L .127 0 .558 r
F
.52227 1.11667 m .48448 1.20238 L .52238 1.11782 L 1 .624 .578 r
F
.52235 1.11848 m .52226 1.11829 L .52367 1.1331 L .127 0 .558 r
F
.52226 1.11829 m .52366 1.13308 L .52367 1.1331 L F
.52236 1.11788 m .52371 1.13321 L .52372 1.13323 L F
.52236 1.11788 m .48325 1.22526 L .52372 1.13323 L 1 .624 .578 r
F
.5046 1.07485 m .5039 1.07305 L .50468 1.07924 L 1 .067 .476 r
F
.51884 1.08622 m .52054 1.10002 L .52055 1.10004 L .114 0 .549 r
F
.51898 1.08677 m .52055 1.10004 L .52485 1.11098 L F
.51884 1.08622 m .52055 1.10004 L .51898 1.08677 L F
.51884 1.08622 m .51868 1.08585 L .52045 1.09923 L F
.52434 1.09862 m .51884 1.08622 L .52485 1.11098 L F
.52139 1.08841 m .51017 1.08929 L .50877 1.08567 L .566 0 .139 r
F
.52089 1.08833 m .51153 1.0891 L .52139 1.08841 L .158 0 .732 r
F
.50524 1.08012 m .50468 1.07924 L .50602 1.08986 L 1 .067 .476 r
F
.50524 1.08012 m .50602 1.08986 L .50643 1.0898 L F
.50655 1.03426 m .49066 1.07179 L .50683 1.04327 L 1 .508 .566 r
F
.52203 1.20007 m .50723 1.09088 L .52256 1.22127 L 1 .067 .476 r
F
.50723 1.09088 m .5004 1.04055 L .5066 1.09113 L F
.50723 1.09088 m .5066 1.09113 L .52256 1.22127 L F
.5004 1.04055 m .50041 1.0407 L .50712 1.09543 L F
.50713 1.09541 m .50712 1.09543 L .52256 1.22127 L F
.5004 1.04055 m .50712 1.09543 L .50713 1.09541 L F
.52139 1.08841 m .50877 1.08567 L .52187 1.0845 L .566 0 .139 r
F
.52084 1.08811 m .51236 1.08866 L .52089 1.08832 L .509 .235 .898 r
F
.50643 1.0898 m .50602 1.08986 L .52256 1.22127 L 1 .067 .476 r
F
.5046 1.07485 m .50468 1.07924 L .50524 1.08012 L F
.50041 1.0407 m .50049 1.04598 L .5039 1.07305 L F
.50041 1.0407 m .5039 1.07305 L .5046 1.07485 L F
.50024 1.03931 m .50033 1.04468 L .50049 1.04598 L F
.50024 1.03931 m .50049 1.04598 L .50041 1.0407 L F
.5004 1.04055 m .50024 1.03931 L .50041 1.0407 L F
.50204 1.14212 m .4857 1.17924 L .50206 1.14302 L 1 .621 .578 r
F
.52256 1.22128 m .4921 .98027 L .49023 1.19442 L .689 .011 .505 r
F
.52203 1.20007 m .49271 1.14534 L .49251 1.09027 L 1 .067 .476 r
F
.50445 1.07036 m .49251 1.09027 L .49211 .97934 L F
.52203 1.20007 m .49251 1.09027 L .50445 1.07036 L F
.46576 1.1342 m .45698 1.18521 L .48051 1.10595 L 0 0 .075 r
F
.46576 1.1342 m .48051 1.10595 L .49065 1.07181 L F
.49192 .98224 m .46576 1.1342 L .49065 1.07181 L F
.49203 .97418 m .49032 .97722 L .49192 .98224 L F
.49032 .97722 m .45698 1.18521 L .49192 .98224 L F
.49146 .9806 m .47714 1.06551 L .47173 1.10221 L 1 .045 .354 r
F
.46662 1.15631 m .454 1.2007 L .46536 1.16969 L .882 0 .335 r
F
.46662 1.15631 m .45698 1.18521 L .45813 1.18618 L F
.46362 1.16284 m .45698 1.18521 L .46662 1.15631 L F
.49215 .96583 m .49122 .97163 L .49203 .97418 L 0 0 .075 r
F
.49122 .97163 m .49032 .97722 L .49203 .97418 L F
.48238 1.1009 m .46362 1.16284 L .46662 1.15631 L .882 0 .335 r
F
.49065 1.07181 m .48183 1.10153 L .48238 1.1009 L F
.48183 1.10153 m .46362 1.16284 L .48238 1.1009 L F
.49065 1.07181 m .46662 1.15631 L .4894 1.10409 L F
.47046 1.11564 m .47173 1.10221 L .4624 1.16551 L 1 .045 .354 r
F
.4894 1.10409 m .46639 1.17388 L .48816 1.1309 L 1 .28 .5 r
F
.46639 1.17388 m .45098 1.22063 L .46562 1.18529 L F
.46639 1.17388 m .46562 1.18529 L .48816 1.1309 L F
.47714 1.06551 m .47422 1.08295 L .47102 1.10508 L 1 .045 .354 r
F
.46639 1.17388 m .454 1.2007 L .45098 1.22063 L 1 .28 .5 r
F
.4894 1.10409 m .46536 1.16969 L .46639 1.17388 L F
.46536 1.16969 m .454 1.2007 L .46639 1.17388 L F
.47078 1.10864 m .47102 1.10508 L .46304 1.16027 L 1 .045 .354 r
F
.46136 1.17253 m .46124 1.17279 L .45683 1.2033 L F
.46286 1.1645 m .4624 1.16551 L .46136 1.17253 L F
.46173 1.17179 m .46136 1.17253 L .45683 1.2033 L F
.46286 1.1645 m .46136 1.17253 L .46173 1.17179 L F
.46904 1.11001 m .46902 1.11358 L .46886 1.11455 L 0 0 .075 r
F
.46823 1.11504 m .46886 1.11455 L .46142 1.15879 L F
.46097 1.16058 m .46142 1.15879 L .45824 1.1777 L F
.46823 1.11504 m .46142 1.15879 L .46097 1.16058 L F
.46312 1.16059 m .46304 1.16027 L .46124 1.17279 L 1 .045 .354 r
F
.46312 1.16059 m .46124 1.17279 L .46136 1.17253 L F
.47078 1.10864 m .46304 1.16027 L .46312 1.16059 L F
.47046 1.11564 m .4624 1.16551 L .46286 1.1645 L F
.46662 1.15631 m .46536 1.16969 L .4894 1.10409 L .882 0 .335 r
F
.46045 1.17821 m .45892 1.17942 L .45683 1.2033 L 1 .045 .354 r
F
.47435 1.08203 m .45892 1.17942 L .46045 1.17821 L F
.45803 1.17864 m .45824 1.1777 L .45698 1.18521 L 0 0 .075 r
F
.47714 1.06551 m .47102 1.10508 L .47078 1.10864 L 1 .045 .354 r
F
.49146 .9806 m .47173 1.10221 L .47046 1.11564 L F
.46928 1.11203 m .45953 1.17554 L .45698 1.18521 L 0 0 .075 r
F
.47474 1.07956 m .46972 1.11124 L .46928 1.11203 L F
.46972 1.11124 m .45953 1.17554 L .46928 1.11203 L F
.46904 1.11001 m .46886 1.11455 L .46823 1.11504 L F
.49063 .97529 m .47474 1.07956 L .46902 1.11358 L F
.49063 .97529 m .46902 1.11358 L .46904 1.11001 L F
.49143 .98046 m .45999 1.16716 L .49146 .9806 L 1 .045 .354 r
F
.48816 1.1309 m .44794 1.24312 L .48693 1.15559 L 1 .523 .55 r
F
.48816 1.1309 m .45098 1.22063 L .44794 1.24312 L F
.48693 1.15559 m .44488 1.26712 L .4857 1.17925 L 1 .601 .567 r
F
.48693 1.15559 m .44794 1.24312 L .44488 1.26712 L F
.4857 1.17925 m .4418 1.29211 L .48447 1.20239 L 1 .624 .574 r
F
.4857 1.17925 m .44488 1.26712 L .4418 1.29211 L F
.49211 .97641 m .45683 1.2033 L .49023 1.19441 L 1 .045 .354 r
F
.48998 1.11656 m .4631 1.15627 L .48226 1.03493 L 0 0 0 r
F
.49214 .97591 m .48226 1.03493 L .49213 .97242 L F
.49211 .97641 m .49143 .98046 L .49146 .9806 L 1 .045 .354 r
F
.4927 1.14534 m .48226 1.03493 L .49214 .97591 L 0 0 0 r
F
.4929 1.08224 m .48725 1.09681 L .49213 .97129 L 1 .601 .58 r
F
.4927 1.14534 m .45992 1.17643 L .4631 1.15627 L 0 0 0 r
F
.4927 1.14534 m .4631 1.15627 L .48998 1.11656 L F
.48725 1.09681 m .4624 1.16092 L .4698 1.11376 L 1 .601 .58 r
F
.48725 1.09681 m .4698 1.11376 L .49213 .97129 L F
.4929 1.08224 m .46897 1.12752 L .4688 1.12839 L F
.46823 1.11504 m .45824 1.1777 L .45803 1.17864 L 0 0 .075 r
F
.48003 1.04499 m .47474 1.07956 L .49063 .97529 L F
.45953 1.17554 m .45892 1.17942 L .45856 1.18049 L F
.45953 1.17554 m .45856 1.18049 L .45698 1.18521 L F
.47435 1.08203 m .45999 1.16716 L .45892 1.17942 L 1 .045 .354 r
F
.47714 1.06551 m .47435 1.08203 L .47422 1.08295 L F
.4645 1.14418 m .46189 1.16355 L .45953 1.17554 L 0 0 .075 r
F
.47474 1.07956 m .46533 1.14107 L .4645 1.14418 L F
.46533 1.14107 m .46189 1.16355 L .4645 1.14418 L F
.47558 1.07424 m .46 1.16712 L .47998 1.04534 L 1 .601 .58 r
F
.4624 1.16092 m .46 1.16712 L .47558 1.07424 L F
.4624 1.16092 m .47998 1.04534 L .49213 .97129 L F
.47652 1.09894 m .46926 1.10148 L .46898 1.10276 L 1 .802 .713 r
F
.48481 1.10311 m .46838 1.13053 L .4624 1.16092 L 1 .601 .58 r
F
.4929 1.08224 m .46295 1.13958 L .48481 1.10311 L F
.49402 1.09055 m .47561 1.11919 L .4929 1.08224 L 1 .68 .638 r
F
.47561 1.11919 m .46896 1.12952 L .47185 1.12382 L F
.47561 1.11919 m .47185 1.12382 L .4929 1.08224 L F
.46896 1.12952 m .46897 1.12752 L .4929 1.08224 L F
.50877 1.08567 m .49403 1.09054 L .49291 1.08223 L .566 0 .139 r
F
.49529 1.08943 m .47677 1.09801 L .47652 1.09894 L 1 .802 .713 r
F
.47677 1.09801 m .46926 1.10148 L .47652 1.09894 L F
.4624 1.16092 m .45999 1.16715 L .46 1.16712 L 1 .601 .58 r
F
.4624 1.16092 m .46295 1.13958 L .45999 1.16715 L F
.46838 1.13053 m .46295 1.13958 L .4624 1.16092 L F
.45953 1.17554 m .45992 1.17644 L .45892 1.17942 L 0 0 .075 r
F
.46189 1.16355 m .45992 1.17644 L .45953 1.17554 L F
.49529 1.08943 m .47652 1.09894 L .49518 1.08976 L 1 .802 .713 r
F
.47652 1.09894 m .46898 1.10276 L .47646 1.09904 L F
.47652 1.09894 m .47646 1.09904 L .49518 1.08976 L F
.4688 1.12839 m .46304 1.13873 L .46295 1.13958 L 1 .601 .58 r
F
.46897 1.12752 m .46304 1.13873 L .4688 1.12839 L F
.45999 1.16716 m .42447 1.19503 L .44806 1.20106 L 1 .355 .612 r
F
.45892 1.17942 m .4563 1.18463 L .45698 1.18521 L 1 .537 .599 r
F
.45999 1.16716 m .44806 1.20106 L .45892 1.17942 L 1 .355 .612 r
F
.44312 1.21115 m .41955 1.22465 L .43283 1.23169 L 1 .28 .602 r
F
.44312 1.21115 m .42447 1.19503 L .41955 1.22465 L F
.43118 1.25018 m .43018 1.25333 L .43039 1.25299 L 1 .608 .582 r
F
.43118 1.25018 m .43039 1.25299 L .45098 1.22063 L F
.42762 1.24237 m .41955 1.22465 L .42239 1.2531 L 1 .224 .595 r
F
.43588 1.23331 m .41955 1.22465 L .43049 1.24868 L F
.44806 1.20106 m .42447 1.19503 L .44312 1.21115 L 1 .28 .602 r
F
.45815 1.17975 m .4286 1.22651 L .42381 1.24413 L 1 .537 .599 r
F
.45992 1.17644 m .45869 1.17839 L .45815 1.17975 L F
.45869 1.17839 m .4286 1.22651 L .45815 1.17975 L F
.43147 1.24625 m .43049 1.24868 L .43058 1.24886 L 1 .224 .595 r
F
.43588 1.23331 m .43049 1.24868 L .43147 1.24625 L F
.43517 1.23586 m .43058 1.24886 L .43118 1.25018 L F
.43588 1.23331 m .43058 1.24886 L .43517 1.23586 L F
.44312 1.21115 m .44302 1.21135 L .44374 1.21349 L 1 .28 .602 r
F
.44508 1.21003 m .44325 1.21475 L .44355 1.21436 L 1 .552 .583 r
F
.44508 1.21003 m .44355 1.21436 L .454 1.2007 L F
.44508 1.21003 m .44806 1.20106 L .44312 1.21115 L 1 .28 .602 r
F
.45698 1.18521 m .44508 1.21003 L .454 1.2007 L 1 .552 .583 r
F
.44325 1.21475 m .43604 1.23339 L .454 1.2007 L F
.44302 1.21135 m .43604 1.23339 L .44374 1.21349 L 1 .28 .602 r
F
.44208 1.21628 m .43604 1.23339 L .44325 1.21475 L 1 .552 .583 r
F
.44302 1.21135 m .43588 1.23331 L .43604 1.23339 L 1 .28 .602 r
F
.454 1.2007 m .43118 1.25018 L .45098 1.22063 L 1 .608 .582 r
F
.43075 1.25032 m .4146 1.25569 L .42575 1.26406 L 1 .224 .595 r
F
.44312 1.21115 m .44374 1.21349 L .44382 1.21328 L 1 .28 .602 r
F
.42239 1.2531 m .41955 1.22465 L .4146 1.25569 L 1 .224 .595 r
F
.43075 1.25032 m .42762 1.24237 L .42239 1.2531 L F
.43118 1.25018 m .43096 1.2497 L .43075 1.25032 L F
.43096 1.2497 m .42762 1.24237 L .43075 1.25032 L F
.44302 1.21135 m .43283 1.23169 L .43588 1.23331 L 1 .28 .602 r
F
.41827 1.28659 m .4146 1.25569 L .40961 1.28768 L 1 .188 .59 r
F
.42052 1.28631 m .42575 1.26406 L .41827 1.28659 L F
.42657 1.26468 m .42575 1.26406 L .42052 1.28631 L F
.43118 1.25018 m .43075 1.25032 L .42647 1.2646 L 1 .224 .595 r
F
.43075 1.25032 m .42575 1.26406 L .42647 1.2646 L F
.43118 1.25018 m .42647 1.2646 L .42657 1.26468 L F
.42853 1.25592 m .42442 1.26857 L .42657 1.26468 L 1 .608 .582 r
F
.42941 1.25453 m .42657 1.26468 L .45098 1.22063 L F
.42853 1.25592 m .42657 1.26468 L .42941 1.25453 L F
.48447 1.20239 m .4418 1.29211 L .43872 1.31784 L 1 .629 .577 r
F
.45098 1.22063 m .42095 1.28626 L .44794 1.24312 L 1 .644 .585 r
F
.42095 1.28626 m .41891 1.29467 L .44794 1.24312 L F
.48447 1.20239 m .43872 1.31784 L .48325 1.22527 L 1 .629 .577 r
F
.44794 1.24312 m .41237 1.32063 L .44488 1.26712 L 1 .656 .586 r
F
.40413 1.35427 m .40461 1.32033 L .39957 1.3535 L .973 .151 .585 r
F
.40463 1.35217 m .40461 1.32033 L .40413 1.35427 L F
.41083 1.32677 m .40461 1.32033 L .40463 1.35435 L F
.41169 1.32061 m .40961 1.28768 L .40461 1.32033 L 1 .166 .587 r
F
.41213 1.31891 m .40961 1.28768 L .41169 1.32061 L F
.41234 1.32033 m .40961 1.28768 L .41227 1.32063 L F
.41801 1.29535 m .40961 1.28768 L .41237 1.32063 L F
.42095 1.28626 m .40961 1.28768 L .41824 1.29556 L 1 .188 .59 r
F
.42095 1.28626 m .41824 1.29556 L .41835 1.29566 L F
.45098 1.22063 m .42798 1.26214 L .42095 1.28626 L 1 .644 .585 r
F
.42379 1.27535 m .42657 1.26468 L .42361 1.27529 L 1 .188 .59 r
F
.42798 1.26214 m .42657 1.26468 L .42095 1.28626 L 1 .644 .585 r
F
.41237 1.32063 m .41234 1.32033 L .41227 1.32063 L 1 .166 .587 r
F
.41835 1.29566 m .41801 1.29535 L .41237 1.32063 L F
.41237 1.32063 m .4111 1.32628 L .44488 1.26712 L 1 .656 .586 r
F
.44488 1.26712 m .40465 1.35436 L .4418 1.29211 L 1 .654 .586 r
F
.39741 1.38791 m .39957 1.3535 L .39451 1.38712 L .955 .142 .583 r
F
.4418 1.29211 m .39746 1.38792 L .43872 1.31784 L 1 .647 .586 r
F
.39746 1.38792 m .39704 1.38997 L .43872 1.31784 L F
.44066 1.39974 m .39746 1.38792 L .43739 1.43846 L .955 .142 .583 r
F
.39746 1.38792 m .39451 1.38712 L .39697 1.39006 L F
.40375 1.3582 m .40372 1.35817 L .39741 1.38791 L F
.40372 1.35817 m .39957 1.3535 L .39756 1.38554 L F
.40372 1.35817 m .39756 1.38554 L .39741 1.38791 L F
.40463 1.35435 m .40463 1.35217 L .40413 1.35427 L .973 .151 .585 r
F
.4418 1.29211 m .40461 1.35672 L .39746 1.38792 L 1 .647 .586 r
F
.40465 1.35436 m .40389 1.35797 L .4418 1.29211 L 1 .654 .586 r
F
.44392 1.36098 m .40465 1.35436 L .44066 1.39974 L .973 .151 .585 r
F
.40465 1.35436 m .39957 1.3535 L .40372 1.35817 L F
.40461 1.35672 m .40375 1.3582 L .39746 1.38792 L 1 .647 .586 r
F
.40375 1.3582 m .39937 1.36582 L .39782 1.38371 L F
.44066 1.39974 m .40375 1.3582 L .3986 1.38233 L .955 .142 .583 r
F
.39746 1.38792 m .3986 1.38233 L .39741 1.38791 L F
.44066 1.39974 m .3986 1.38233 L .39746 1.38792 L F
.40375 1.3582 m .39782 1.38371 L .39746 1.38792 L 1 .647 .586 r
F
.40465 1.35436 m .40453 1.35485 L .40453 1.35486 L .973 .151 .585 r
F
.40465 1.35436 m .4045 1.35468 L .40421 1.35625 L 1 .654 .586 r
F
.40465 1.35436 m .40421 1.35625 L .40389 1.35797 L F
.40465 1.35436 m .40453 1.35486 L .44066 1.39974 L .973 .151 .585 r
F
.40453 1.35485 m .40372 1.35817 L .40375 1.3582 L F
.40421 1.35625 m .40375 1.3582 L .40389 1.35797 L 1 .654 .586 r
F
.4045 1.35468 m .40375 1.3582 L .40421 1.35625 L F
.40453 1.35486 m .40375 1.3582 L .44066 1.39974 L .973 .151 .585 r
F
.40453 1.35485 m .40375 1.3582 L .40453 1.35486 L F
.44488 1.26712 m .41184 1.32499 L .40465 1.35436 L 1 .654 .586 r
F
.40501 1.35274 m .41083 1.32677 L .405 1.35274 L .973 .151 .585 r
F
.41184 1.32499 m .41083 1.32677 L .40465 1.35436 L 1 .654 .586 r
F
.44392 1.36098 m .41083 1.32677 L .40501 1.35274 L .973 .151 .585 r
F
.44392 1.36098 m .405 1.35274 L .40465 1.35436 L F
.41083 1.32677 m .41075 1.3269 L .40465 1.35436 L 1 .654 .586 r
F
.40465 1.35436 m .405 1.35274 L .40463 1.35435 L .973 .151 .585 r
F
.40465 1.35436 m .41075 1.3269 L .4045 1.35468 L 1 .654 .586 r
F
.4045 1.35468 m .40432 1.33817 L .39937 1.36582 L F
.41075 1.3269 m .40432 1.33817 L .4045 1.35468 L F
.39746 1.38792 m .39937 1.36582 L .39438 1.39457 L 1 .647 .586 r
F
.39746 1.38792 m .39697 1.39006 L .39698 1.39007 L .955 .142 .583 r
F
.39746 1.38792 m .39698 1.39007 L .39704 1.38997 L 1 .647 .586 r
F
.39746 1.38792 m .39698 1.39007 L .43739 1.43846 L .955 .142 .583 r
F
.39746 1.38792 m .39438 1.39457 L .39698 1.39007 L 1 .647 .586 r
F
.4045 1.35468 m .39937 1.36582 L .40375 1.3582 L 1 .654 .586 r
F
.44716 1.32198 m .41237 1.32063 L .44392 1.36098 L 1 .166 .587 r
F
.41237 1.32063 m .40461 1.32033 L .41083 1.32677 L F
.41237 1.32063 m .4116 1.3237 L .4111 1.32628 L 1 .656 .586 r
F
.41205 1.32132 m .41083 1.32677 L .4111 1.32628 L F
.41237 1.32063 m .41083 1.32677 L .44392 1.36098 L 1 .166 .587 r
F
.41237 1.32063 m .41205 1.32132 L .4116 1.3237 L 1 .656 .586 r
F
.41237 1.32063 m .41813 1.29606 L .41205 1.32132 L F
.44794 1.24312 m .41835 1.29566 L .41237 1.32063 L F
.41835 1.29566 m .41813 1.29606 L .41237 1.32063 L F
.44716 1.32198 m .41835 1.29566 L .41237 1.32063 L 1 .166 .587 r
F
.4504 1.28256 m .42657 1.26468 L .42379 1.27535 L 1 .188 .59 r
F
.4504 1.28256 m .42361 1.27529 L .42095 1.28626 L F
.42657 1.26468 m .42607 1.26559 L .42095 1.28626 L 1 .644 .585 r
F
.42095 1.28626 m .42361 1.27529 L .42052 1.28631 L 1 .188 .59 r
F
.42095 1.28626 m .42607 1.26559 L .42029 1.28769 L 1 .644 .585 r
F
.42029 1.28769 m .41413 1.28713 L .40924 1.31184 L F
.42575 1.26406 m .42505 1.26353 L .41827 1.28659 L 1 .188 .59 r
F
.42505 1.26353 m .4146 1.25569 L .41793 1.28376 L F
.42505 1.26353 m .41793 1.28376 L .41827 1.28659 L F
.44208 1.21628 m .44055 1.21947 L .43604 1.23339 L 1 .552 .583 r
F
.44055 1.21947 m .41899 1.26443 L .43496 1.23535 L F
.44055 1.21947 m .43496 1.23535 L .43604 1.23339 L F
.42607 1.26559 m .41413 1.28713 L .42029 1.28769 L 1 .644 .585 r
F
.41227 1.32063 m .41213 1.31891 L .41169 1.32061 L 1 .166 .587 r
F
.42095 1.28626 m .42029 1.28769 L .41835 1.29566 L 1 .644 .585 r
F
.42029 1.28769 m .40924 1.31184 L .41835 1.29566 L F
.41205 1.32132 m .40924 1.31184 L .40432 1.33817 L 1 .656 .586 r
F
.41813 1.29606 m .40924 1.31184 L .41205 1.32132 L F
.41205 1.32132 m .40432 1.33817 L .41083 1.32677 L F
.4504 1.28256 m .42095 1.28626 L .44716 1.32198 L 1 .188 .59 r
F
.42095 1.28626 m .41835 1.29566 L .41891 1.29467 L 1 .644 .585 r
F
.42095 1.28626 m .41835 1.29566 L .44716 1.32198 L 1 .188 .59 r
F
.44055 1.21947 m .42381 1.24413 L .41899 1.26443 L 1 .552 .583 r
F
.44208 1.21628 m .44113 1.21773 L .44055 1.21947 L F
.44113 1.21773 m .42381 1.24413 L .44055 1.21947 L F
.454 1.2007 m .43753 1.23067 L .43118 1.25018 L 1 .608 .582 r
F
.45683 1.2033 m .44508 1.21003 L .45362 1.24272 L 1 .28 .602 r
F
.44508 1.21003 m .44312 1.21115 L .44384 1.21335 L F
.44508 1.21003 m .44384 1.21335 L .45362 1.24272 L F
.44508 1.21003 m .44354 1.21189 L .44208 1.21628 L 1 .552 .583 r
F
.44651 1.20704 m .44569 1.20838 L .44508 1.21003 L F
.44569 1.20838 m .44354 1.21189 L .44508 1.21003 L F
.44354 1.21189 m .42381 1.24413 L .44208 1.21628 L F
.45698 1.18521 m .44985 1.19788 L .44651 1.20704 L F
.44985 1.19788 m .42381 1.24413 L .44651 1.20704 L F
.43118 1.25018 m .41899 1.26443 L .41413 1.28713 L 1 .608 .582 r
F
.43753 1.23067 m .43604 1.23339 L .43118 1.25018 L F
.45362 1.24272 m .43604 1.23339 L .43118 1.25018 L 1 .224 .595 r
F
.43604 1.23339 m .43588 1.23331 L .43118 1.25018 L F
.43604 1.23339 m .41899 1.26443 L .43118 1.25018 L 1 .608 .582 r
F
.44374 1.21349 m .43604 1.23339 L .45362 1.24272 L 1 .28 .602 r
F
.45683 1.2033 m .44823 1.2011 L .44508 1.21003 L F
.44823 1.2011 m .44806 1.20106 L .44508 1.21003 L F
.44382 1.21328 m .44374 1.21349 L .45362 1.24272 L F
.44508 1.21003 m .44208 1.21628 L .44325 1.21475 L 1 .552 .583 r
F
.45578 1.18419 m .43335 1.22624 L .44583 1.20502 L 1 .537 .599 r
F
.43335 1.22624 m .43127 1.23015 L .43289 1.22734 L F
.43335 1.22624 m .43289 1.22734 L .44583 1.20502 L F
.44475 1.20168 m .4286 1.2265 L .44337 1.20289 L 1 .644 .642 r
F
.44475 1.20168 m .44337 1.20289 L .45778 1.17984 L F
.45421 1.18716 m .44475 1.20168 L .45778 1.17984 L F
.45033 1.18991 m .4333 1.2117 L .44475 1.20168 L F
.45578 1.18419 m .44583 1.20502 L .45265 1.19102 L 1 .537 .599 r
F
.45578 1.18419 m .44806 1.20106 L .45045 1.19617 L F
.45578 1.18419 m .4491 1.1992 L .45637 1.18469 L F
.45045 1.19617 m .44806 1.20106 L .4491 1.1992 L F
.45637 1.18469 m .4491 1.1992 L .45698 1.18521 L F
.45813 1.18618 m .45698 1.18521 L .454 1.2007 L .882 0 .335 r
F
.45892 1.17942 m .44806 1.20106 L .45683 1.2033 L 1 .355 .612 r
F
.45892 1.17942 m .45578 1.18419 L .4563 1.18463 L 1 .537 .599 r
F
.45992 1.17644 m .4579 1.18022 L .45892 1.17942 L F
.4579 1.18022 m .45578 1.18419 L .45892 1.17942 L F
.46277 1.17399 m .45421 1.18716 L .45992 1.17643 L 1 .644 .642 r
F
.45421 1.18716 m .45778 1.17984 L .45992 1.17643 L F
.46277 1.17399 m .45033 1.18991 L .44475 1.20168 L F
.46563 1.17356 m .4333 1.2117 L .46277 1.17399 L 1 .838 .701 r
F
.44526 1.19759 m .43797 1.19901 L .4333 1.2117 L F
.46563 1.17356 m .44882 1.18903 L .44526 1.19759 L F
.44882 1.18903 m .43797 1.19901 L .44526 1.19759 L F
.44475 1.20168 m .4333 1.2117 L .4286 1.2265 L 1 .644 .642 r
F
.43127 1.23015 m .42381 1.24413 L .42907 1.23479 L 1 .537 .599 r
F
.43127 1.23015 m .42907 1.23479 L .44583 1.20502 L F
.45265 1.19102 m .44583 1.20502 L .44806 1.20106 L F
.45362 1.24272 m .43118 1.25018 L .4504 1.28256 L 1 .224 .595 r
F
.43118 1.25018 m .42657 1.26468 L .4504 1.28256 L F
.43118 1.25018 m .42853 1.25592 L .43018 1.25333 L 1 .608 .582 r
F
.42853 1.25592 m .41413 1.28713 L .42442 1.26857 L F
.49402 1.09055 m .47302 1.11126 L .46896 1.12952 L 1 .68 .638 r
F
.46896 1.12952 m .46304 1.13873 L .46897 1.12752 L F
.47302 1.11126 m .46603 1.11815 L .46896 1.12952 L F
.47348 1.1109 m .46603 1.11815 L .47302 1.11126 L 1 .729 .691 r
F
.47348 1.1109 m .46898 1.10276 L .46603 1.11815 L F
.47395 1.11044 m .47348 1.1109 L .4746 1.1097 L F
.47348 1.1109 m .47302 1.11126 L .4746 1.1097 L F
.51017 1.08929 m .49403 1.09054 L .51014 1.08921 L .566 0 .139 r
F
.51153 1.0891 m .49518 1.08975 L .49403 1.09054 L .158 0 .732 r
F
.51153 1.0891 m .49403 1.09054 L .51017 1.08929 L F
.49518 1.08976 m .47395 1.11044 L .49402 1.09055 L 1 .729 .691 r
F
.47395 1.11044 m .4746 1.1097 L .49402 1.09055 L F
.49518 1.08976 m .47646 1.09904 L .47348 1.1109 L F
.47646 1.09904 m .46898 1.10276 L .47348 1.1109 L F
.46896 1.12952 m .46603 1.11815 L .46304 1.13873 L 1 .68 .638 r
F
.49215 .96583 m .48003 1.04499 L .49063 .97529 L 0 0 .075 r
F
.51012 1.08915 m .49658 1.0897 L .50877 1.08567 L .566 0 .139 r
F
.51236 1.08866 m .49518 1.08975 L .51224 1.08881 L .509 .235 .898 r
F
.51236 1.08866 m .51224 1.08881 L .52089 1.08832 L F
.52089 1.08833 m .51224 1.08881 L .51153 1.0891 L .158 0 .732 r
F
.51224 1.08881 m .49518 1.08975 L .51153 1.0891 L F
.51153 1.0891 m .51017 1.08929 L .52139 1.08841 L F
.50877 1.08567 m .49291 1.08223 L .5073 1.08336 L .566 0 .139 r
F
.50877 1.08567 m .5073 1.08336 L .52187 1.0845 L F
.52542 1.09035 m .52089 1.08833 L .52139 1.08841 L .322 0 0 r
F
.52317 1.08941 m .52089 1.08833 L .52542 1.09035 L F
.5229 1.07676 m .52285 1.07666 L .52285 1.07669 L 0 0 .423 r
F
.52292 1.07679 m .52297 1.07698 L .52285 1.07666 L .774 0 0 r
F
.52617 1.08847 m .52139 1.08841 L .52187 1.0845 L .705 0 0 r
F
.55309 1.12715 m .55162 1.12485 L .55309 1.12714 L .774 0 0 r
F
.5553 1.13785 m .55103 1.12981 L .55209 1.13205 L 0 0 .423 r
F
.52285 1.07666 m .51168 1.04379 L .5201 1.06999 L .056 0 .502 r
F
.52236 1.07895 m .50828 1.02871 L .52285 1.07666 L .113 0 .489 r
F
.50828 1.02871 m .51075 1.03503 L .52285 1.07666 L F
.51332 1.04669 m .5057 1.00718 L .50613 1.02106 L F
.52236 1.07895 m .51801 1.06022 L .51332 1.04669 L F
.51801 1.06022 m .5057 1.00718 L .51332 1.04669 L F
.50655 1.03426 m .50683 1.04327 L .50975 1.03811 L 1 .508 .566 r
F
.50988 1.03849 m .50973 1.03795 L .50975 1.03811 L .056 0 .502 r
F
.5222 .96637 m .50758 1.01524 L .52272 .99605 L .958 .077 .522 r
F
.52055 1.10004 m .52074 1.10163 L .52081 1.10149 L 1 .621 .578 r
F
.52485 1.11098 m .52055 1.10004 L .52069 1.10182 L .122 0 .555 r
F
.52068 1.10176 m .52068 1.10177 L .52069 1.10182 L 1 .621 .578 r
F
.51678 1.07127 m .51664 1.07092 L .51865 1.0837 L .1 0 .54 r
F
.51664 1.07092 m .51623 1.06997 L .51797 1.07984 L F
.51664 1.07092 m .51797 1.07984 L .51865 1.0837 L F
.51594 1.06512 m .51547 1.06384 L .5164 1.06743 L .08 0 .524 r
F
.51547 1.06384 m .51594 1.06618 L .5164 1.06743 L F
.51431 1.05687 m .51351 1.05481 L .51594 1.06512 L F
.50975 1.03811 m .50965 1.03844 L .5128 1.04842 L 1 .508 .566 r
F
.50965 1.03844 m .51229 1.04962 L .5128 1.04842 L F
.50975 1.03811 m .5128 1.04842 L .51404 1.05216 L .056 0 .502 r
F
.52187 1.0845 m .50289 1.00373 L .52236 1.07895 L .954 .041 .471 r
F
.50289 1.00373 m .49218 .95817 L .50495 1.00928 L F
.50289 1.00373 m .50495 1.00928 L .52236 1.07895 L F
.52272 .99605 m .51243 1.02943 L .52325 1.02354 L 1 .508 .566 r
F
.51243 1.02943 m .51342 1.0321 L .52325 1.02354 L F
.52081 1.10209 m .52069 1.10182 L .52226 1.11659 L .122 0 .555 r
F
.52485 1.11098 m .52082 1.10211 L .52535 1.12441 L F
.52082 1.10211 m .52081 1.10209 L .52082 1.10216 L F
.52082 1.10211 m .52082 1.10216 L .52535 1.12441 L F
.52081 1.10209 m .52227 1.11667 L .52535 1.12441 L F
.52238 1.11782 m .5224 1.11801 L .52584 1.12843 L 1 .624 .578 r
F
.52236 1.11788 m .52372 1.13323 L .52584 1.12843 L F
.52535 1.12441 m .52236 1.11788 L .52585 1.13855 L .127 0 .558 r
F
.52236 1.11788 m .52372 1.13323 L .52585 1.13855 L F
.49962 .59166 m .48893 .59542 L .49515 .59742 L .689 .52 .844 r
F
.50455 .59287 m .49962 .59166 L .49515 .59742 L .683 .516 .845 r
F
.58424 .89187 m .55406 .9459 L .55624 .96132 L 1 .643 .621 r
F
.58055 .88528 m .55406 .9459 L .58424 .89187 L 1 .634 .631 r
F
.23668 .3586 m .25236 .31123 L .24229 .2798 L .431 0 .575 r
F
.25236 .31123 m .26298 .24317 L .24229 .2798 L .462 .002 .578 r
F
.45382 .59423 m .44819 .58902 L .43744 .59218 L .775 .585 .83 r
F
.46364 .59054 m .44819 .58902 L .45382 .59423 L .741 .559 .834 r
F
.46928 .59442 m .46364 .59054 L .45382 .59423 L .74 .566 .837 r
F
.23184 .5871 m .22053 .48879 L .22005 .57421 L .536 .016 .593 r
F
.23184 .5871 m .23217 .50721 L .22053 .48879 L F
.48446 .73544 m .46362 .73444 L .48166 .74291 L .634 .361 .808 r
F
.50144 .74057 m .48166 .74291 L .5003 .74841 L .702 .405 .796 r
F
.50144 .74057 m .48446 .73544 L .48166 .74291 L F
.5182 .74393 m .5003 .74841 L .51869 .75163 L .701 .414 .8 r
F
.5182 .74393 m .50144 .74057 L .5003 .74841 L F
.39792 .5931 m .39278 .57877 L .38085 .57829 L .746 .361 .763 r
F
.40937 .59004 m .39278 .57877 L .39792 .5931 L .762 .437 .786 r
F
.22472 .6717 m .20834 .56088 L .21305 .66398 L .601 .028 .589 r
F
.22472 .6717 m .22005 .57421 L .20834 .56088 L F
.46802 .72835 m .44652 .72405 L .46362 .73444 L .535 .292 .831 r
F
.48446 .73544 m .46802 .72835 L .46362 .73444 L .634 .361 .808 r
F
.52923 .59349 m .52831 .60066 L .53454 .59989 L .678 .508 .844 r
F
.52923 .59349 m .52455 .59409 L .52831 .60066 L F
.47799 .59022 m .46364 .59054 L .46928 .59442 L .718 .544 .839 r
F
.48318 .59302 m .47799 .59022 L .46928 .59442 L .712 .542 .841 r
F
.34144 .54395 m .34043 .53191 L .33244 .52638 L .272 .017 .79 r
F
.35345 .55197 m .34043 .53192 L .34145 .54395 L .381 .077 .796 r
F
.23728 .42911 m .24745 .38755 L .23668 .3586 L .41 0 .579 r
F
.23737 .4408 m .23897 .43237 L .23728 .42911 L F
.23807 .42615 m .23897 .43237 L .23728 .42911 L .984 0 .115 r
F
.24966 .44439 m .24849 .44873 L .23807 .42615 L 1 0 .13 r
F
.24876 .46447 m .24851 .44989 L .23737 .4408 L .383 0 .578 r
F
.24851 .44989 m .24849 .44873 L .24749 .44802 L F
.24851 .44989 m .24749 .44802 L .23737 .4408 L F
.24749 .44802 m .23897 .43237 L .23737 .4408 L F
.24849 .44873 m .23897 .43237 L .24749 .44802 L F
.2439 .52518 m .24876 .46447 L .23737 .4408 L .449 .003 .592 r
F
.23897 .43237 m .24385 .46589 L .23731 .42932 L .984 0 .115 r
F
.23897 .43237 m .23731 .42932 L .23728 .42911 L F
.2439 .52518 m .23737 .4408 L .23217 .50721 L .449 .003 .592 r
F
.23725 .42921 m .24385 .46589 L .23243 .44725 L .984 0 .115 r
F
.23728 .42911 m .23731 .42932 L .23725 .42921 L F
.23731 .42932 m .24385 .46589 L .23725 .42921 L F
.24849 .44873 m .24385 .46589 L .23897 .43237 L 1 0 .13 r
F
.24849 .44873 m .23897 .43237 L .23807 .42615 L F
.24849 .44873 m .24745 .38755 L .23897 .43237 L .383 0 .578 r
F
.23897 .43237 m .24745 .38755 L .23728 .42911 L .41 0 .579 r
F
.60265 .83654 m .57689 .87936 L .58055 .88528 L 1 .851 .663 r
F
.5976 .83941 m .57689 .87936 L .60265 .83654 L 1 .906 .691 r
F
.75716 .6961 m .75714 .65354 L .76937 .69255 L .614 0 .271 r
F
.75716 .6961 m .74578 .66113 L .75714 .65354 L F
.53489 .74631 m .51869 .75163 L .53701 .75432 L .651 .386 .811 r
F
.53489 .74631 m .5182 .74393 L .51869 .75163 L F
.43744 .59218 m .4323 .58519 L .42083 .58743 L .793 .568 .818 r
F
.44819 .58902 m .4323 .58519 L .43744 .59218 L .758 .555 .827 r
F
.49495 .59012 m .48318 .59302 L .48893 .59542 L .695 .525 .842 r
F
.49962 .59166 m .49495 .59012 L .48893 .59542 L .689 .52 .844 r
F
.36897 .57663 m .36555 .55802 L .35345 .55197 L .524 .133 .741 r
F
.38085 .57829 m .36555 .55802 L .36897 .57663 L .589 .214 .76 r
F
.63499 .58616 m .64222 .59237 L .64703 .58329 L .879 .797 .857 r
F
.63499 .58616 m .63065 .59446 L .64222 .59237 L F
.56484 .59646 m .56898 .60505 L .5751 .60081 L .707 .521 .836 r
F
.56484 .59646 m .55974 .59981 L .56898 .60505 L F
.60735 .59451 m .61328 .60416 L .61903 .59506 L .847 .689 .834 r
F
.60735 .59451 m .60225 .60194 L .61328 .60416 L F
.55048 .59468 m .5538 .60262 L .55974 .59981 L .689 .511 .84 r
F
.55048 .59468 m .54572 .59688 L .5538 .60262 L F
.45244 .71998 m .43064 .71388 L .44652 .72405 L .46 .228 .856 r
F
.46802 .72835 m .45244 .71998 L .44652 .72405 L .535 .292 .831 r
F
.40937 .59004 m .40474 .57863 L .39278 .57877 L .762 .437 .786 r
F
.42083 .58743 m .40474 .57863 L .40937 .59004 L .758 .484 .803 r
F
.53361 .59252 m .53454 .59989 L .54038 .59863 L .68 .508 .843 r
F
.53361 .59252 m .52923 .59349 L .53454 .59989 L F
.58011 .59607 m .58534 .60516 L .5912 .59919 L .739 .554 .834 r
F
.58011 .59607 m .5751 .60081 L .58534 .60516 L F
.77217 .31206 m .79872 .34005 L .7823 .28313 L 1 .449 .582 r
F
.77217 .31206 m .78796 .36646 L .79872 .34005 L F
.24745 .38755 m .25236 .31123 L .23668 .3586 L .42 0 .573 r
F
.60908 .81551 m .58807 .79519 L .59153 .80188 L 0 0 .663 r
F
.30729 .50448 m .30922 .51037 L .29722 .5015 L .6 0 0 r
F
.31925 .51578 m .30922 .51037 L .30729 .50448 L .383 0 0 r
F
.49063 .58826 m .47799 .59022 L .48318 .59302 L .7 .528 .841 r
F
.49495 .59012 m .49063 .58826 L .48318 .59302 L .695 .525 .842 r
F
.66828 .9239 m .64771 .87099 L .67639 .92931 L .995 0 .127 r
F
.66828 .9239 m .6411 .8678 L .64771 .87099 L F
.57221 .75882 m .55867 .76596 L .57751 .77095 L .564 .257 .795 r
F
.57221 .75882 m .55495 .75713 L .55867 .76596 L F
.55122 .74785 m .53701 .75432 L .55495 .75713 L .621 .348 .809 r
F
.55122 .74785 m .53489 .74631 L .53701 .75432 L F
.46364 .59054 m .45895 .58619 L .44819 .58902 L .741 .559 .834 r
F
.47349 .58706 m .45895 .58619 L .46364 .59054 L .718 .54 .837 r
F
.47799 .59022 m .47349 .58706 L .46364 .59054 L .718 .544 .839 r
F
.53762 .59121 m .54038 .59863 L .54572 .59688 L .682 .509 .843 r
F
.53762 .59121 m .53361 .59252 L .54038 .59863 L F
.38085 .57829 m .37771 .56239 L .36555 .55802 L .589 .214 .76 r
F
.39278 .57877 m .37771 .56239 L .38085 .57829 L .642 .298 .777 r
F
.42083 .58743 m .41672 .57819 L .40474 .57863 L .758 .484 .803 r
F
.4323 .58519 m .41672 .57819 L .42083 .58743 L .746 .509 .816 r
F
.38707 .90668 m .35507 .9599 L .34763 .96663 L 0 0 0 r
F
.39288 .90606 m .35507 .9599 L .38707 .90668 L F
.4651 .86916 m .4373 .87947 L .43309 .87429 L .46 0 .065 r
F
.46776 .87853 m .4373 .87947 L .4651 .86916 L .409 0 0 r
F
.49458 .90115 m .4651 .86916 L .49344 .90934 L .875 0 .085 r
F
.49458 .90115 m .46776 .87853 L .4651 .86916 L F
.44819 .58902 m .44379 .58323 L .4323 .58519 L .758 .555 .827 r
F
.45895 .58619 m .44379 .58323 L .44819 .58902 L .732 .542 .832 r
F
.75243 .27186 m .7823 .28313 L .7618 .24103 L 1 .47 .582 r
F
.75243 .27186 m .77217 .31206 L .7823 .28313 L F
.43309 .87429 m .40462 .90399 L .39873 .90522 L .061 0 0 r
F
.4373 .87947 m .40462 .90399 L .43309 .87429 L 0 0 0 r
F
.59565 .59312 m .60225 .60194 L .60735 .59451 L .78 .626 .84 r
F
.59565 .59312 m .5912 .59919 L .60225 .60194 L F
.41624 .70621 m .40355 .70236 L .39379 .70422 L .458 .171 .898 r
F
.40355 .70236 m .396 .70423 L .39379 .70422 L 1 .889 .829 r
F
.40769 .70596 m .39379 .70422 L .39177 .70422 L 0 0 .668 r
F
.39177 .70422 m .39379 .70422 L .38413 .70338 L F
.38413 .70338 m .37328 .71621 L .37328 .71621 L .877 .032 .531 r
F
.38413 .70338 m .37098 .71893 L .36819 .72676 L F
.39379 .70422 m .37811 .71433 L .38413 .70338 L .944 .48 .75 r
F
.37328 .71621 m .37099 .71892 L .37098 .71893 L .877 .032 .531 r
F
.37328 .71621 m .37099 .71892 L .37328 .71621 L F
.37811 .71433 m .37099 .71892 L .37328 .71621 L .944 .48 .75 r
F
.37811 .71433 m .37328 .71621 L .38413 .70338 L F
.39284 .69997 m .37765 .7012 L .38195 .70769 L 1 .966 .771 r
F
.37765 .7012 m .37271 .7016 L .37675 .70426 L F
.37765 .7012 m .37675 .70426 L .38195 .70769 L F
.36819 .72676 m .37098 .71893 L .3598 .73907 L .877 .032 .531 r
F
.38195 .70769 m .37405 .71032 L .37098 .71892 L 1 .972 .729 r
F
.37405 .71032 m .36087 .7147 L .37098 .71892 L F
.37405 .71032 m .37098 .71892 L .37098 .71892 L F
.39379 .70422 m .38195 .70769 L .37099 .71892 L .944 .48 .75 r
F
.396 .70423 m .38195 .70769 L .39379 .70422 L 1 .889 .829 r
F
.43064 .71388 m .41624 .70621 L .40769 .70596 L .273 .033 .868 r
F
.35345 .55197 m .35261 .53919 L .34043 .53192 L .381 .077 .796 r
F
.36555 .55802 m .35261 .53919 L .35345 .55197 L .465 .16 .799 r
F
.6229 .58757 m .63065 .59446 L .63499 .58616 L .838 .769 .862 r
F
.6229 .58757 m .61903 .59506 L .63065 .59446 L F
.51417 .58758 m .50964 .59373 L .51467 .59421 L .68 .511 .844 r
F
.51417 .58758 m .51081 .58725 L .50964 .59373 L F
.51081 .58725 m .50455 .59287 L .50964 .59373 L .682 .512 .844 r
F
.55455 .59209 m .55974 .59981 L .56484 .59646 L .691 .516 .841 r
F
.55455 .59209 m .55048 .59468 L .55974 .59981 L F
.51751 .58766 m .51467 .59421 L .51967 .59433 L .679 .51 .844 r
F
.51751 .58766 m .51417 .58758 L .51467 .59421 L F
.48674 .58612 m .47349 .58706 L .47799 .59022 L .703 .529 .84 r
F
.49063 .58826 m .48674 .58612 L .47799 .59022 L .7 .528 .841 r
F
.65907 .69406 m .65768 .6916 L .66991 .68804 L 0 0 0 r
F
.66168 .69503 m .65907 .69406 L .66796 .69437 L F
.65907 .69406 m .64781 .70098 L .65621 .693 L F
.64814 .69826 m .64781 .70098 L .65907 .69406 L .568 0 .657 r
F
.65623 .69561 m .65907 .69406 L .66168 .69503 L 0 0 0 r
F
.65907 .69406 m .65621 .693 L .65768 .6916 L F
.7996 .43373 m .81872 .49649 L .81085 .41048 L 1 .415 .583 r
F
.43797 .71164 m .41624 .70621 L .43064 .71388 L .46 .246 .879 r
F
.45244 .71998 m .43797 .71164 L .43064 .71388 L .46 .228 .856 r
F
.60213 .79161 m .58807 .79518 L .60908 .81551 L .366 .03 .741 r
F
.60213 .79161 m .5828 .78345 L .58807 .79518 L F
.5074 .58667 m .49962 .59166 L .50455 .59287 L .684 .513 .843 r
F
.51081 .58725 m .5074 .58667 L .50455 .59287 L .682 .512 .844 r
F
.56901 .59271 m .5751 .60081 L .58011 .59607 L .709 .536 .84 r
F
.56901 .59271 m .56484 .59646 L .5751 .60081 L F
.48727 .72826 m .46802 .72835 L .48446 .73544 L .641 .385 .814 r
F
.50259 .73282 m .48446 .73544 L .50144 .74057 L .684 .406 .804 r
F
.50259 .73282 m .48727 .72826 L .48446 .73544 L F
.52077 .58749 m .51967 .59433 L .52455 .59409 L .679 .51 .844 r
F
.52077 .58749 m .51751 .58766 L .51967 .59433 L F
.58055 .88528 m .55188 .93048 L .55406 .9459 L 1 .634 .631 r
F
.57689 .87936 m .55188 .93047 L .58055 .88528 L 1 .644 .646 r
F
.51771 .73591 m .50144 .74057 L .5182 .74393 L .691 .41 .803 r
F
.51771 .73591 m .50259 .73282 L .50144 .74057 L F
.50411 .58585 m .49495 .59012 L .49962 .59166 L .687 .515 .843 r
F
.5074 .58667 m .50411 .58585 L .49962 .59166 L .684 .513 .843 r
F
.39278 .57877 m .38993 .56542 L .37771 .56239 L .642 .298 .777 r
F
.40474 .57863 m .38993 .56542 L .39278 .57877 L .678 .371 .793 r
F
.54119 .58958 m .54572 .59688 L .55048 .59468 L .682 .51 .843 r
F
.54119 .58958 m .53762 .59121 L .54572 .59688 L F
.47245 .72232 m .45244 .71998 L .46802 .72835 L .582 .353 .831 r
F
.48727 .72826 m .47245 .72232 L .46802 .72835 L .641 .385 .814 r
F
.4323 .58519 m .42872 .57763 L .41672 .57819 L .746 .509 .816 r
F
.44379 .58323 m .42872 .57763 L .4323 .58519 L .731 .519 .825 r
F
.52389 .58708 m .52455 .59409 L .52923 .59349 L .679 .51 .844 r
F
.52389 .58708 m .52077 .58749 L .52455 .59409 L F
.53275 .73784 m .5182 .74393 L .53489 .74631 L .677 .398 .804 r
F
.53275 .73784 m .51771 .73591 L .5182 .74393 L F
.50099 .5848 m .49063 .58826 L .49495 .59012 L .689 .517 .842 r
F
.50411 .58585 m .50099 .5848 L .49495 .59012 L .687 .515 .843 r
F
.64952 .57887 m .64703 .58329 L .659 .57861 L .591 .047 .801 r
F
.23645 .67899 m .22005 .57421 L .22472 .6717 L .607 .031 .591 r
F
.23645 .67899 m .23184 .5871 L .22005 .57421 L F
.24966 .44439 m .25097 .45344 L .24849 .44873 L 1 0 .13 r
F
.26137 .4614 m .25968 .46769 L .24966 .44439 L 1 .001 .148 r
F
.26024 .48783 m .25972 .46902 L .24876 .46447 L .343 0 .576 r
F
.25972 .46902 m .25968 .46769 L .25883 .46744 L F
.25972 .46902 m .25883 .46744 L .24876 .46447 L F
.25883 .46744 m .25097 .45344 L .24876 .46447 L F
.25968 .46769 m .25097 .45344 L .25883 .46744 L F
.24876 .46447 m .25097 .45344 L .24849 .44873 L .383 0 .578 r
F
.25573 .54257 m .26024 .48783 L .24876 .46447 L .435 .002 .596 r
F
.25097 .45344 m .25536 .48376 L .24858 .44918 L 1 0 .13 r
F
.25097 .45344 m .24858 .44918 L .24849 .44873 L F
.25573 .54257 m .24876 .46447 L .2439 .52518 L .435 .002 .596 r
F
.24844 .44893 m .25536 .48376 L .24385 .46589 L 1 0 .13 r
F
.24849 .44873 m .24858 .44918 L .24844 .44893 L F
.24858 .44918 m .25536 .48376 L .24844 .44893 L F
.25968 .46769 m .25536 .48376 L .25097 .45344 L 1 .001 .148 r
F
.25968 .46769 m .25097 .45344 L .24966 .44439 L F
.25968 .46769 m .25827 .41707 L .25097 .45344 L .343 0 .576 r
F
.24849 .44873 m .25827 .41707 L .24745 .38755 L .383 0 .578 r
F
.25097 .45344 m .25827 .41707 L .24849 .44873 L F
.7449 .699 m .74578 .66113 L .75716 .6961 L .6 0 .254 r
F
.7449 .699 m .73434 .66822 L .74578 .66113 L F
.47349 .58706 m .46974 .58358 L .45895 .58619 L .718 .54 .837 r
F
.45895 .58619 m .4553 .58146 L .44379 .58323 L .732 .542 .832 r
F
.46974 .58358 m .4553 .58146 L .45895 .58619 L .713 .531 .836 r
F
.58391 .59112 m .5912 .59919 L .59565 .59312 L .734 .58 .844 r
F
.58391 .59112 m .58011 .59607 L .5912 .59919 L F
.31925 .51578 m .3213 .51744 L .30922 .51037 L .383 0 0 r
F
.3313 .52554 m .3213 .51744 L .31925 .51578 L 0 0 .744 r
F
.52682 .58643 m .52923 .59349 L .53361 .59252 L .68 .509 .844 r
F
.52682 .58643 m .52389 .58708 L .52923 .59349 L F
.24372 .59944 m .23217 .50721 L .23184 .5871 L .537 .017 .596 r
F
.24372 .59944 m .2439 .52518 L .23217 .50721 L F
.48336 .58372 m .46974 .58358 L .47349 .58706 L .703 .527 .84 r
F
.48674 .58612 m .48336 .58372 L .47349 .58706 L .703 .529 .84 r
F
.61077 .58786 m .61903 .59506 L .6229 .58757 L .79 .702 .86 r
F
.61077 .58786 m .60735 .59451 L .61903 .59506 L F
.45839 .71544 m .43797 .71164 L .45244 .71998 L .546 .34 .848 r
F
.47245 .72232 m .45839 .71544 L .45244 .71998 L .582 .353 .831 r
F
.40474 .57863 m .40219 .5675 L .38993 .56542 L .678 .371 .793 r
F
.41672 .57819 m .40219 .5675 L .40474 .57863 L .697 .427 .807 r
F
.56691 .74758 m .55495 .75713 L .57221 .75882 L .667 .335 .783 r
F
.56691 .74758 m .55122 .74785 L .55495 .75713 L F
.49811 .58354 m .48674 .58612 L .49063 .58826 L .692 .518 .842 r
F
.50099 .5848 m .49811 .58354 L .49063 .58826 L .689 .517 .842 r
F
.59525 .77128 m .5828 .78345 L .60213 .79161 L .592 .168 .731 r
F
.59525 .77128 m .57751 .77095 L .5828 .78345 L F
.36555 .55802 m .36484 .54523 L .35261 .53919 L .465 .16 .799 r
F
.37771 .56239 m .36484 .54523 L .36555 .55802 L .537 .238 .8 r
F
.55788 .58917 m .56484 .59646 L .56901 .59271 L .691 .523 .844 r
F
.55788 .58917 m .55455 .59209 L .56484 .59646 L F
.44379 .58323 m .44073 .57705 L .42872 .57763 L .731 .519 .825 r
F
.4553 .58146 m .44073 .57705 L .44379 .58323 L .717 .521 .831 r
F
.54424 .58767 m .55048 .59468 L .55455 .59209 L .682 .512 .844 r
F
.54424 .58767 m .54119 .58958 L .55048 .59468 L F
.5295 .58556 m .53361 .59252 L .53762 .59121 L .679 .509 .844 r
F
.5295 .58556 m .52682 .58643 L .53361 .59252 L F
.54747 .7385 m .53489 .74631 L .55122 .74785 L .68 .387 .798 r
F
.54747 .7385 m .53275 .73784 L .53489 .74631 L F
.66014 .91829 m .6411 .8678 L .66828 .9239 L .967 0 .104 r
F
.66014 .91829 m .63444 .86331 L .6411 .8678 L F
.5584 .97629 m .52429 1.06996 L .56056 .99066 L 1 .578 .592 r
F
.49551 .58209 m .48336 .58372 L .48674 .58612 L .693 .519 .841 r
F
.49811 .58354 m .49551 .58209 L .48674 .58612 L .692 .518 .842 r
F
.41672 .57819 m .41447 .56894 L .40219 .5675 L .697 .427 .807 r
F
.42872 .57763 m .41447 .56894 L .41672 .57819 L .705 .465 .817 r
F
.57216 .5887 m .58011 .59607 L .58391 .59112 L .705 .548 .846 r
F
.57216 .5887 m .56901 .59271 L .58011 .59607 L F
.24745 .38755 m .26248 .34336 L .25236 .31123 L .42 0 .573 r
F
.25236 .31123 m .27236 .275 L .26298 .24317 L .462 .002 .578 r
F
.26248 .34335 m .27236 .275 L .25236 .31123 L .475 .003 .578 r
F
.5976 .83941 m .57323 .87426 L .57689 .87936 L 1 .906 .691 r
F
.63451 .72163 m .61958 .77186 L .6291 .8599 L .648 .012 .525 r
F
.63781 .70697 m .63451 .72163 L .64781 .70098 L 1 .774 .744 r
F
.63781 .70697 m .6255 .72571 L .63451 .72163 L F
.48336 .58372 m .48055 .58111 L .46974 .58358 L .703 .527 .84 r
F
.46974 .58358 m .46683 .57985 L .4553 .58146 L .713 .531 .836 r
F
.48055 .58111 m .46683 .57985 L .46974 .58358 L .7 .522 .839 r
F
.59861 .58731 m .60735 .59451 L .61077 .58786 L .748 .637 .857 r
F
.59861 .58731 m .59565 .59312 L .60735 .59451 L F
.53187 .58448 m .53762 .59121 L .54119 .58958 L .679 .509 .844 r
F
.53187 .58448 m .5295 .58556 L .53762 .59121 L F
.63718 .58079 m .64703 .58329 L .64952 .57887 L .647 .36 .872 r
F
.63718 .58079 m .63499 .58616 L .64703 .58329 L F
.27236 .275 m .28807 .2221 L .26298 .24317 L .466 .004 .585 r
F
.37771 .56239 m .37712 .55019 L .36484 .54523 L .537 .238 .8 r
F
.38993 .56542 m .37712 .55019 L .37771 .56239 L .593 .307 .804 r
F
.58844 .75575 m .57751 .77095 L .59525 .77128 L .724 .262 .729 r
F
.58844 .75575 m .57221 .75882 L .57751 .77095 L F
.76196 .34085 m .78796 .36646 L .77217 .31206 L 1 .451 .583 r
F
.76196 .34085 m .77712 .39277 L .78796 .36646 L F
.4553 .58146 m .45276 .57648 L .44073 .57705 L .717 .521 .831 r
F
.46683 .57985 m .45276 .57648 L .4553 .58146 L .705 .519 .836 r
F
.3313 .52554 m .33343 .52328 L .3213 .51744 L 0 0 .744 r
F
.33243 .52637 m .33343 .52328 L .3313 .52554 L 0 0 .766 r
F
.42487 .70463 m .40355 .70236 L .41624 .70621 L .621 .508 .883 r
F
.43797 .71164 m .42487 .70463 L .41624 .70621 L .46 .246 .879 r
F
.4901 .72117 m .47245 .72232 L .48727 .72826 L .657 .409 .817 r
F
.50375 .72507 m .48727 .72826 L .50259 .73282 L .683 .416 .808 r
F
.50375 .72507 m .4901 .72117 L .48727 .72826 L F
.72893 .24625 m .7618 .24103 L .73742 .21432 L 1 .488 .581 r
F
.72893 .24625 m .75243 .27186 L .7618 .24103 L F
.51721 .72771 m .50259 .73282 L .51771 .73591 L .695 .418 .804 r
F
.51721 .72771 m .50375 .72507 L .50259 .73282 L F
.51366 .58089 m .51081 .58725 L .51417 .58758 L .681 .509 .843 r
F
.51366 .58089 m .51198 .58072 L .51081 .58725 L F
.51198 .58072 m .5074 .58667 L .51081 .58725 L .682 .51 .843 r
F
.33243 .52637 m .33457 .52378 L .33343 .52328 L 0 0 .766 r
F
.34043 .53191 m .33457 .52378 L .33244 .52638 L .155 .001 .838 r
F
.51534 .58093 m .51417 .58758 L .51751 .58766 L .68 .509 .844 r
F
.51534 .58093 m .51366 .58089 L .51417 .58758 L F
.44534 .70839 m .42487 .70463 L .43797 .71164 L .573 .402 .861 r
F
.45839 .71544 m .44534 .70839 L .43797 .71164 L .546 .34 .848 r
F
.57689 .87936 m .54974 .91598 L .55188 .93047 L 1 .644 .646 r
F
.57323 .87426 m .54974 .91598 L .57689 .87936 L 1 .684 .668 r
F
.51027 .58042 m .50411 .58585 L .5074 .58667 L .683 .51 .843 r
F
.51198 .58072 m .51027 .58042 L .5074 .58667 L .682 .51 .843 r
F
.39288 .90606 m .36255 .95288 L .35507 .9599 L 0 0 0 r
F
.39873 .90522 m .36255 .95288 L .39288 .90606 L F
.42872 .57763 m .42676 .56998 L .41447 .56894 L .705 .465 .817 r
F
.44073 .57705 m .42676 .56998 L .42872 .57763 L .705 .488 .825 r
F
.54673 .58552 m .55455 .59209 L .55788 .58917 L .681 .514 .845 r
F
.54673 .58552 m .54424 .58767 L .55455 .59209 L F
.49326 .58048 m .48055 .58111 L .48336 .58372 L .693 .518 .841 r
F
.49551 .58209 m .49326 .58048 L .48336 .58372 L .693 .519 .841 r
F
.51697 .58085 m .51751 .58766 L .52077 .58749 L .68 .509 .844 r
F
.51697 .58085 m .51534 .58093 L .51751 .58766 L F
.50862 .58 m .50099 .5848 L .50411 .58585 L .684 .511 .843 r
F
.51027 .58042 m .50862 .58 L .50411 .58585 L .683 .51 .843 r
F
.47689 .7162 m .45839 .71544 L .47245 .72232 L .627 .401 .828 r
F
.4901 .72117 m .47689 .7162 L .47245 .72232 L .657 .409 .817 r
F
.51854 .58064 m .52077 .58749 L .52389 .58708 L .679 .508 .844 r
F
.51854 .58064 m .51697 .58085 L .52077 .58749 L F
.53061 .72917 m .51771 .73591 L .53275 .73784 L .7 .415 .801 r
F
.53061 .72917 m .51721 .72771 L .51771 .73591 L F
.56039 .58602 m .56901 .59271 L .57216 .5887 L .689 .528 .846 r
F
.56039 .58602 m .55788 .58917 L .56901 .59271 L F
.5584 .97629 m .52377 1.04794 L .52429 1.06996 L 1 .578 .592 r
F
.55624 .96132 m .52377 1.04794 L .5584 .97629 L 1 .517 .593 r
F
.25827 .41707 m .26248 .34336 L .24745 .38755 L .401 0 .57 r
F
.50706 .57947 m .49811 .58354 L .50099 .5848 L .685 .512 .842 r
F
.50862 .58 m .50706 .57947 L .50099 .5848 L .684 .511 .843 r
F
.5339 .58321 m .54119 .58958 L .54424 .58767 L .678 .509 .845 r
F
.5339 .58321 m .53187 .58448 L .54119 .58958 L F
.80709 .51557 m .82144 .5927 L .81872 .49649 L 1 .395 .586 r
F
.7996 .43373 m .80709 .51557 L .81872 .49649 L 1 .415 .583 r
F
.5616 .73729 m .55122 .74785 L .56691 .74758 L .726 .384 .78 r
F
.5616 .73729 m .54747 .7385 L .55122 .74785 L F
.58643 .58615 m .59565 .59312 L .59861 .58731 L .717 .587 .854 r
F
.58643 .58615 m .58391 .59112 L .59565 .59312 L F
.26766 .55919 m .26024 .48783 L .25573 .54257 L .42 .002 .603 r
F
.26137 .4614 m .26322 .47431 L .25968 .46769 L 1 .001 .148 r
F
.2732 .47682 m .27078 .48593 L .26137 .4614 L 1 .001 .168 r
F
.27182 .51063 m .27084 .48723 L .26024 .48783 L .28 0 .571 r
F
.27084 .48723 m .27078 .48593 L .27014 .48605 L F
.27084 .48723 m .27014 .48605 L .26024 .48783 L F
.27014 .48605 m .26322 .47431 L .26024 .48783 L F
.27078 .48593 m .26322 .47431 L .27014 .48605 L F
.26024 .48783 m .26322 .47431 L .25968 .46769 L .343 0 .576 r
F
.26322 .47431 m .26696 .50038 L .2599 .46866 L 1 .001 .148 r
F
.26322 .47431 m .2599 .46866 L .25968 .46769 L F
.26766 .55919 m .27182 .51063 L .26024 .48783 L .42 .002 .603 r
F
.25957 .46811 m .26696 .50038 L .25536 .48376 L 1 .001 .148 r
F
.25968 .46769 m .2599 .46866 L .25957 .46811 L F
.2599 .46866 m .26696 .50038 L .25957 .46811 L F
.27078 .48593 m .26696 .50038 L .26322 .47431 L 1 .001 .168 r
F
.27078 .48593 m .26322 .47431 L .26137 .4614 L F
.27078 .48593 m .26917 .44734 L .26322 .47431 L .28 0 .571 r
F
.25968 .46769 m .26917 .44734 L .25827 .41707 L .343 0 .576 r
F
.26322 .47431 m .26917 .44734 L .25968 .46769 L F
.52 .58032 m .52389 .58708 L .52682 .58643 L .679 .508 .844 r
F
.52 .58032 m .51854 .58064 L .52389 .58708 L F
.74298 .30261 m .77217 .31206 L .75243 .27186 L 1 .473 .583 r
F
.74298 .30261 m .76196 .34085 L .77217 .31206 L F
.38993 .56542 m .38943 .55424 L .37712 .55019 L .593 .307 .804 r
F
.40219 .5675 m .38943 .55424 L .38993 .56542 L .634 .364 .809 r
F
.73258 .70111 m .73434 .66822 L .7449 .699 L .582 0 .231 r
F
.73258 .70111 m .72283 .67472 L .73434 .66822 L F
.44073 .57705 m .43908 .57077 L .42676 .56998 L .705 .488 .825 r
F
.45276 .57648 m .43908 .57077 L .44073 .57705 L .701 .501 .831 r
F
.50562 .57883 m .49551 .58209 L .49811 .58354 L .686 .512 .842 r
F
.50706 .57947 m .50562 .57883 L .49811 .58354 L .685 .512 .842 r
F
.34043 .53191 m .34259 .52718 L .33457 .52378 L .155 .001 .838 r
F
.35261 .53919 m .34259 .52718 L .34043 .53192 L .348 .094 .867 r
F
.62481 .58179 m .63499 .58616 L .63718 .58079 L .687 .571 .885 r
F
.62481 .58179 m .6229 .58757 L .63499 .58616 L F
.78827 .45698 m .80709 .51557 L .7996 .43373 L 1 .42 .584 r
F
.24826 .68573 m .23184 .5871 L .23645 .67899 L .616 .035 .594 r
F
.24826 .68573 m .24372 .59944 L .23184 .5871 L F
.46683 .57985 m .46481 .57595 L .45276 .57648 L .705 .519 .836 r
F
.47838 .57833 m .46481 .57595 L .46683 .57985 L .696 .516 .839 r
F
.48055 .58111 m .47838 .57833 L .46683 .57985 L .7 .522 .839 r
F
.49326 .58048 m .49139 .57873 L .48055 .58111 L .693 .518 .841 r
F
.49139 .57873 m .47838 .57833 L .48055 .58111 L .691 .516 .841 r
F
.58165 .74351 m .57221 .75882 L .58844 .75575 L .785 .332 .739 r
F
.58165 .74351 m .56691 .74758 L .57221 .75882 L F
.52134 .57988 m .52682 .58643 L .5295 .58556 L .679 .508 .844 r
F
.52134 .57988 m .52 .58032 L .52682 .58643 L F
.46437 .71045 m .44534 .70839 L .45839 .71544 L .616 .412 .838 r
F
.47689 .7162 m .46437 .71045 L .45839 .71544 L .627 .401 .828 r
F
.64814 .69826 m .63781 .70697 L .64781 .70098 L .568 0 .657 r
F
.54371 .7293 m .53275 .73784 L .54747 .7385 L .716 .414 .795 r
F
.54371 .7293 m .53061 .72917 L .53275 .73784 L F
.50432 .5781 m .49326 .58048 L .49551 .58209 L .686 .512 .842 r
F
.50562 .57883 m .50432 .5781 L .49551 .58209 L F
.40219 .5675 m .40176 .55756 L .38943 .55424 L .634 .364 .809 r
F
.41447 .56894 m .40176 .55756 L .40219 .5675 L .661 .41 .815 r
F
.57424 .58457 m .58391 .59112 L .58643 .58615 L .697 .552 .851 r
F
.57424 .58457 m .57216 .5887 L .58391 .59112 L F
.4373 .87947 m .41046 .90218 L .40462 .90399 L 0 0 0 r
F
.44157 .88301 m .41046 .90218 L .4373 .87947 L F
.46776 .87853 m .44157 .88301 L .4373 .87947 L .409 0 0 r
F
.65209 .91249 m .63444 .86331 L .66014 .91829 L .928 0 .072 r
F
.5486 .58316 m .55788 .58917 L .56039 .58602 L .68 .516 .846 r
F
.5486 .58316 m .54673 .58552 L .55788 .58917 L F
.53556 .58178 m .54424 .58767 L .54673 .58552 L .678 .51 .845 r
F
.53556 .58178 m .5339 .58321 L .54424 .58767 L F
.55624 .96132 m .52325 1.02354 L .52377 1.04794 L 1 .517 .593 r
F
.55406 .9459 m .52325 1.02354 L .55624 .96132 L 1 .427 .592 r
F
.45276 .57648 m .4514 .57142 L .43908 .57077 L .701 .501 .831 r
F
.46481 .57595 m .4514 .57142 L .45276 .57648 L .696 .507 .836 r
F
.25568 .61111 m .2439 .52518 L .24372 .59944 L .538 .02 .601 r
F
.25568 .61111 m .25573 .54257 L .2439 .52518 L F
.52253 .57934 m .5295 .58556 L .53187 .58448 L .678 .508 .844 r
F
.52253 .57934 m .52134 .57988 L .5295 .58556 L F
.61242 .5821 m .6229 .58757 L .62481 .58179 L .701 .618 .879 r
F
.61242 .5821 m .61077 .58786 L .6229 .58757 L F
.50319 .57729 m .49139 .57873 L .49326 .58048 L .686 .512 .842 r
F
.50432 .5781 m .50319 .57729 L .49326 .58048 L F
.41447 .56894 m .41412 .56031 L .40176 .55756 L .661 .41 .815 r
F
.42676 .56998 m .41412 .56031 L .41447 .56894 L .677 .445 .822 r
F
.35261 .53919 m .35476 .53202 L .34259 .52718 L .348 .094 .867 r
F
.36484 .54523 m .35476 .53202 L .35261 .53919 L .455 .222 .857 r
F
.47838 .57833 m .47687 .57545 L .46481 .57595 L .696 .516 .839 r
F
.48995 .57689 m .47687 .57545 L .47838 .57833 L .689 .513 .841 r
F
.49139 .57873 m .48995 .57689 L .47838 .57833 L .691 .516 .841 r
F
.52354 .5787 m .53187 .58448 L .5339 .58321 L .678 .508 .844 r
F
.52354 .5787 m .52253 .57934 L .53187 .58448 L F
.56204 .5827 m .57216 .5887 L .57424 .58457 L .684 .529 .849 r
F
.56204 .5827 m .56039 .58602 L .57216 .5887 L F
.47048 .88236 m .44157 .88301 L .46776 .87853 L .224 0 0 r
F
.49572 .89428 m .46776 .87853 L .49458 .90115 L .567 0 0 r
F
.49572 .89428 m .47069 .88246 L .47369 .88186 L F
.49583 .89367 m .47048 .88237 L .49572 .89428 L .326 0 0 r
F
.4707 .88246 m .47073 .88251 L .47048 .88237 L F
.49583 .89367 m .47073 .88251 L .4707 .88246 L F
.47073 .88251 m .47073 .88251 L .4707 .88246 L F
.49658 .88953 m .47073 .88251 L .49583 .89367 L 0 0 .682 r
F
.47419 .88345 m .47255 .88268 L .47073 .88251 L F
.49658 .88953 m .47255 .88268 L .47419 .88345 L F
.47255 .88268 m .47255 .88268 L .47419 .88345 L F
.47369 .88186 m .47048 .88236 L .46776 .87853 L .567 0 0 r
F
.47069 .88246 m .47048 .88236 L .47369 .88186 L F
.47534 .88086 m .47009 .88153 L .47255 .88268 L .35 .001 .832 r
F
.47255 .88268 m .47097 .88279 L .47073 .88251 L .082 0 .663 r
F
.47097 .88279 m .46805 .88299 L .47073 .88251 L F
.47097 .88279 m .47073 .88251 L .47073 .88251 L F
.46805 .88299 m .4463 .8845 L .47031 .88254 L F
.46805 .88299 m .47031 .88254 L .47073 .88251 L F
.47048 .88236 m .44589 .88448 L .44157 .88301 L .224 0 0 r
F
.47073 .88251 m .44589 .88448 L .47048 .88237 L .052 0 0 r
F
.47073 .88251 m .44629 .8845 L .44589 .88448 L F
.47009 .88153 m .44918 .88418 L .47255 .88268 L .35 .001 .832 r
F
.47009 .88153 m .47255 .88268 L .47255 .88268 L F
.42487 .70463 m .41336 .69933 L .40355 .70236 L .621 .508 .883 r
F
.43354 .70182 m .41336 .69933 L .42487 .70463 L .707 .579 .856 r
F
.44534 .70839 m .43354 .70182 L .42487 .70463 L .573 .402 .861 r
F
.46481 .57595 m .46373 .572 L .4514 .57142 L .696 .507 .836 r
F
.47687 .57545 m .46373 .572 L .46481 .57595 L .691 .51 .839 r
F
.49294 .71404 m .47689 .7162 L .4901 .72117 L .678 .431 .816 r
F
.5049 .71728 m .4901 .72117 L .50375 .72507 L .694 .431 .81 r
F
.5049 .71728 m .49294 .71404 L .4901 .72117 L F
.51671 .71943 m .50375 .72507 L .51721 .72771 L .706 .431 .805 r
F
.51671 .71943 m .50491 .71728 L .50375 .72507 L F
.5368 .58021 m .54673 .58552 L .5486 .58316 L .677 .51 .845 r
F
.5368 .58021 m .53556 .58178 L .54673 .58552 L F
.55406 .9459 m .52272 .99605 L .52325 1.02354 L 1 .427 .592 r
F
.55188 .93048 m .52272 .99605 L .55406 .9459 L 1 .34 .592 r
F
.57487 .73326 m .56691 .74758 L .58165 .74351 L .807 .387 .753 r
F
.57487 .73326 m .5616 .73729 L .56691 .74758 L F
.42676 .56998 m .42648 .56263 L .41412 .56031 L .677 .445 .822 r
F
.43908 .57077 m .42648 .56263 L .42676 .56998 L .685 .47 .827 r
F
.50319 .57729 m .50226 .57642 L .49139 .57873 L .686 .512 .842 r
F
.50226 .57642 m .48995 .57689 L .49139 .57873 L .685 .511 .842 r
F
.45275 .70435 m .43354 .70182 L .44534 .70839 L .652 .469 .842 r
F
.46437 .71045 m .45275 .70435 L .44534 .70839 L .616 .412 .838 r
F
.55628 .72776 m .54747 .7385 L .5616 .73729 L .754 .418 .782 r
F
.55628 .72776 m .54371 .7293 L .54747 .7385 L F
.60002 .58188 m .61077 .58786 L .61242 .5821 L .698 .601 .87 r
F
.60002 .58188 m .59861 .58731 L .61077 .58786 L F
.52168 .93913 m .49345 .90935 L .49223 .94117 L .75 .066 .582 r
F
.52117 .91776 m .49345 .90935 L .52168 .93913 L .473 .111 .754 r
F
.52117 .91776 m .49458 .90116 L .49345 .90935 L F
.51316 .57415 m .51198 .58072 L .51366 .58089 L .679 .506 .843 r
F
.51316 .57415 m .51316 .57415 L .51198 .58072 L F
.51316 .57415 m .51027 .58042 L .51198 .58072 L .68 .506 .843 r
F
.51316 .57415 m .51366 .58089 L .51534 .58093 L .679 .506 .843 r
F
.51316 .57415 m .51316 .57415 L .51366 .58089 L F
.57323 .87426 m .5476 .90297 L .54974 .91598 L 1 .684 .668 r
F
.56956 .87011 m .5476 .90297 L .57323 .87426 L 1 .761 .7 r
F
.51316 .57415 m .50862 .58 L .51027 .58042 L .68 .506 .843 r
F
.51316 .57415 m .51316 .57415 L .51027 .58042 L F
.52846 .72049 m .51721 .72771 L .53061 .72917 L .718 .432 .8 r
F
.52846 .72049 m .51671 .71943 L .51721 .72771 L F
.48136 .7099 m .46437 .71045 L .47689 .7162 L .665 .434 .823 r
F
.49294 .71404 m .48136 .7099 L .47689 .7162 L .678 .431 .816 r
F
.52437 .57798 m .5339 .58321 L .53556 .58178 L .678 .508 .844 r
F
.52437 .57798 m .52354 .5787 L .5339 .58321 L F
.51316 .57415 m .51534 .58093 L .51697 .58085 L .679 .506 .843 r
F
.51316 .57415 m .51316 .57415 L .51534 .58093 L F
.2732 .47682 m .27583 .49506 L .27078 .48593 L 1 .001 .168 r
F
.28515 .49028 m .2817 .50339 L .2732 .47682 L 1 0 .182 r
F
.28352 .53241 m .28175 .50428 L .27182 .51063 L .19 0 .563 r
F
.28175 .50428 m .2817 .50339 L .28134 .50365 L F
.28175 .50428 m .28134 .50365 L .27182 .51063 L F
.28134 .50365 m .27583 .49506 L .27182 .51063 L F
.2817 .50339 m .27583 .49506 L .28134 .50365 L F
.27182 .51063 m .27583 .49506 L .27078 .48593 L .28 0 .571 r
F
.27583 .49506 m .27868 .51483 L .27139 .48815 L 1 .001 .168 r
F
.27583 .49506 m .27139 .48815 L .27078 .48593 L F
.27054 .48684 m .27868 .51483 L .26696 .50038 L F
.27078 .48593 m .27139 .48815 L .27054 .48684 L F
.27139 .48815 m .27868 .51483 L .27054 .48684 L F
.2817 .50339 m .27868 .51483 L .27583 .49506 L 1 0 .182 r
F
.2817 .50339 m .27583 .49506 L .2732 .47682 L F
.2817 .50339 m .28012 .4784 L .27583 .49506 L .19 0 .563 r
F
.27078 .48593 m .28012 .4784 L .26917 .44734 L .28 0 .571 r
F
.27583 .49506 m .28012 .4784 L .27078 .48593 L F
.51316 .57415 m .50706 .57947 L .50862 .58 L .681 .507 .843 r
F
.51316 .57415 m .51316 .57415 L .50862 .58 L .68 .506 .843 r
F
.54983 .58066 m .56039 .58602 L .56204 .5827 L .678 .516 .847 r
F
.54983 .58066 m .5486 .58316 L .56039 .58602 L F
.6255 .72571 m .61137 .75473 L .61958 .77186 L 1 .255 .62 r
F
.61635 .7247 m .61137 .75473 L .6255 .72571 L 1 .382 .673 r
F
.62769 .70961 m .6255 .72571 L .63781 .70697 L 1 .958 .782 r
F
.62769 .70961 m .61635 .7247 L .6255 .72571 L F
.51316 .57415 m .51697 .58085 L .51854 .58064 L .679 .506 .843 r
F
.51316 .57415 m .51316 .57415 L .51697 .58085 L F
.36484 .54523 m .36693 .5366 L .35476 .53202 L .455 .222 .857 r
F
.37712 .55019 m .36693 .5366 L .36484 .54523 L .526 .302 .843 r
F
.43908 .57077 m .43885 .56464 L .42648 .56263 L .685 .47 .827 r
F
.4514 .57142 m .43885 .56464 L .43908 .57077 L .688 .487 .832 r
F
.51316 .57415 m .50562 .57883 L .50706 .57947 L .681 .507 .843 r
F
.51316 .57415 m .51316 .57415 L .50706 .57947 L F
.61137 .75473 m .59525 .77128 L .60213 .79161 L .887 .179 .63 r
F
.60325 .74326 m .59525 .77128 L .61137 .75473 L .908 .255 .666 r
F
.60325 .74326 m .58844 .75575 L .59525 .77128 L F
.51316 .57415 m .51854 .58064 L .52 .58032 L .679 .506 .843 r
F
.51316 .57415 m .51316 .57415 L .51854 .58064 L F
.47687 .57545 m .47607 .57254 L .46373 .572 L .691 .51 .839 r
F
.48895 .57499 m .47607 .57254 L .47687 .57545 L .687 .51 .841 r
F
.48995 .57689 m .48895 .57499 L .47687 .57545 L .689 .513 .841 r
F
.51316 .57415 m .50432 .5781 L .50562 .57883 L .681 .508 .843 r
F
.51316 .57415 m .51316 .57415 L .50562 .57883 L .681 .507 .843 r
F
.72039 .70231 m .72283 .67473 L .73258 .70111 L .556 0 .197 r
F
.66796 .69437 m .65907 .69406 L .66991 .68804 L .07 0 0 r
F
.50154 .5755 m .48895 .57499 L .48995 .57689 L .684 .51 .842 r
F
.50226 .57642 m .50154 .5755 L .48995 .57689 L .685 .511 .842 r
F
.58761 .58128 m .59861 .58731 L .60002 .58188 L .69 .57 .862 r
F
.58761 .58128 m .58643 .58615 L .59861 .58731 L F
.39873 .90522 m .37005 .94547 L .36255 .95288 L 0 0 0 r
F
.40462 .90399 m .37005 .94547 L .39873 .90522 L F
.51316 .57415 m .52 .58032 L .52134 .57988 L .679 .507 .843 r
F
.51316 .57415 m .51316 .57415 L .52 .58032 L F
.74111 1.02301 m .71649 .95483 L .75063 1.03235 L 1 .001 .164 r
F
.74111 1.02301 m .70853 .94985 L .71649 .95483 L F
.59514 .73409 m .58844 .75575 L .60325 .74326 L .909 .341 .704 r
F
.59514 .73409 m .58165 .74351 L .58844 .75575 L F
.4514 .57142 m .45123 .56643 L .43885 .56464 L .688 .487 .832 r
F
.46373 .572 m .45123 .56643 L .4514 .57142 L .688 .498 .836 r
F
.51316 .57415 m .50319 .57729 L .50432 .5781 L .681 .508 .843 r
F
.51316 .57415 m .51316 .57415 L .50432 .5781 L F
.52499 .57719 m .53556 .58178 L .5368 .58021 L .678 .507 .844 r
F
.52499 .57719 m .52437 .57798 L .53556 .58178 L F
.55188 .93048 m .5222 .96637 L .52272 .99605 L 1 .34 .592 r
F
.54974 .91598 m .5222 .96637 L .55188 .93047 L 1 .308 .603 r
F
.53994 .72033 m .53061 .72917 L .54371 .7293 L .736 .435 .795 r
F
.53994 .72033 m .52846 .72049 L .53061 .72917 L F
.51316 .57415 m .52134 .57988 L .52253 .57934 L .679 .507 .843 r
F
.51316 .57415 m .51316 .57415 L .52134 .57988 L F
.53761 .57853 m .5486 .58316 L .54983 .58066 L .676 .509 .846 r
F
.53761 .57853 m .5368 .58021 L .5486 .58316 L F
.61957 .77187 m .60213 .79161 L .60908 .81551 L .866 .143 .612 r
F
.61137 .75473 m .60213 .79161 L .61957 .77187 L .887 .179 .63 r
F
.75166 .36947 m .77712 .39277 L .76196 .34085 L 1 .453 .584 r
F
.75166 .36947 m .7662 .41897 L .77712 .39277 L F
.47037 .70506 m .45275 .70435 L .46437 .71045 L .669 .452 .828 r
F
.48136 .7099 m .47037 .70506 L .46437 .71045 L .665 .434 .823 r
F
.26014 .69178 m .24372 .59944 L .24826 .68573 L .628 .04 .597 r
F
.26014 .69178 m .25568 .61111 L .24372 .59944 L F
.5752 .58038 m .58643 .58615 L .58761 .58128 L .682 .544 .855 r
F
.5752 .58038 m .57424 .58457 L .58643 .58615 L F
.72038 .27814 m .75243 .27186 L .72893 .24625 L 1 .489 .582 r
F
.72038 .27814 m .74298 .30261 L .75243 .27186 L F
.37712 .55019 m .37912 .54096 L .36693 .5366 L .526 .302 .843 r
F
.38943 .55424 m .37912 .54096 L .37712 .55019 L .579 .352 .832 r
F
.51316 .57415 m .50226 .57642 L .50319 .57729 L .681 .508 .843 r
F
.51316 .57415 m .51316 .57415 L .50319 .57729 L F
.27236 .275 m .29663 .25321 L .28807 .2221 L .466 .004 .585 r
F
.28181 .30696 m .29663 .25321 L .27236 .275 L .486 .006 .588 r
F
.26248 .34335 m .28181 .30696 L .27236 .275 L .475 .003 .578 r
F
.40355 .70236 m .39284 .69997 L .38195 .70769 L 1 .889 .829 r
F
.41336 .69933 m .39284 .69997 L .40355 .70236 L .972 .86 .837 r
F
.61635 .7247 m .60325 .74326 L .61137 .75473 L 1 .382 .673 r
F
.46373 .572 m .46362 .56808 L .45123 .56643 L .688 .498 .836 r
F
.47607 .57254 m .46362 .56808 L .46373 .572 L .687 .504 .839 r
F
.51316 .57415 m .52253 .57934 L .52354 .5787 L .679 .507 .843 r
F
.51316 .57415 m .51316 .57415 L .52253 .57934 L F
.25827 .41707 m .27265 .37663 L .26248 .34336 L .401 0 .57 r
F
.27265 .37663 m .28181 .30696 L .26248 .34335 L .495 .005 .578 r
F
.80709 .51557 m .80958 .60667 L .82144 .5927 L 1 .395 .586 r
F
.79539 .53472 m .80958 .60667 L .80709 .51557 L 1 .403 .587 r
F
.78827 .45698 m .79539 .53472 L .80709 .51557 L 1 .42 .584 r
F
.48895 .57499 m .48843 .57306 L .47607 .57254 L .687 .51 .841 r
F
.50104 .57455 m .48843 .57306 L .48895 .57499 L .683 .509 .842 r
F
.50154 .5755 m .50104 .57455 L .48895 .57499 L .684 .51 .842 r
F
.51316 .57415 m .51316 .57415 L .50226 .57642 L .681 .508 .843 r
F
.51316 .57415 m .50154 .5755 L .50226 .57642 L F
.56279 .57928 m .57424 .58457 L .5752 .58038 L .677 .525 .851 r
F
.56279 .57928 m .56204 .5827 L .57424 .58457 L F
.56809 .72417 m .5616 .73729 L .57487 .73326 L .807 .427 .767 r
F
.56809 .72417 m .55628 .72776 L .5616 .73729 L F
.51316 .57415 m .52354 .5787 L .52437 .57798 L .68 .507 .843 r
F
.51316 .57415 m .51316 .57415 L .52354 .5787 L F
.52539 .57634 m .5368 .58021 L .53761 .57853 L .677 .507 .844 r
F
.52539 .57634 m .52499 .57719 L .5368 .58021 L F
.38943 .55424 m .3913 .5451 L .37912 .54096 L .579 .352 .832 r
F
.40176 .55756 m .3913 .5451 L .38943 .55424 L .616 .387 .828 r
F
.47607 .57254 m .476 .56964 L .46362 .56808 L .687 .504 .839 r
F
.48843 .57306 m .476 .56964 L .47607 .57254 L .685 .507 .841 r
F
.51316 .57414 m .50104 .57455 L .50154 .5755 L .68 .507 .843 r
F
.51316 .57415 m .51316 .57414 L .50154 .5755 L .681 .508 .843 r
F
.55038 .57806 m .56204 .5827 L .56279 .57928 L .675 .514 .848 r
F
.55038 .57806 m .54983 .58066 L .56204 .5827 L F
.58704 .72603 m .58165 .74351 L .59514 .73409 L .887 .41 .737 r
F
.58704 .72603 m .57487 .73326 L .58165 .74351 L F
.73347 .33327 m .76196 .34085 L .74298 .30261 L 1 .477 .584 r
F
.73347 .33327 m .75166 .36947 L .76196 .34085 L F
.51316 .57415 m .52437 .57798 L .52499 .57719 L .68 .507 .843 r
F
.51316 .57415 m .51316 .57415 L .52437 .57798 L F
.63712 .7005 m .63781 .70697 L .64814 .69826 L .747 .418 .837 r
F
.63712 .7005 m .62769 .70961 L .63781 .70697 L F
.77686 .48029 m .79539 .53472 L .78827 .45698 L 1 .425 .585 r
F
.55096 .71879 m .54371 .7293 L .55628 .72776 L .764 .441 .787 r
F
.55096 .71879 m .53994 .72033 L .54371 .7293 L F
.40176 .55756 m .4035 .54896 L .3913 .5451 L .616 .387 .828 r
F
.41412 .56031 m .4035 .54896 L .40176 .55756 L .642 .417 .827 r
F
.43354 .70182 m .42321 .69578 L .41336 .69933 L .707 .579 .856 r
F
.44226 .69822 m .42321 .69578 L .43354 .70182 L .745 .572 .837 r
F
.45275 .70435 m .44226 .69822 L .43354 .70182 L .652 .469 .842 r
F
.54974 .91598 m .52168 .93913 L .5222 .96637 L 1 .308 .603 r
F
.5476 .90297 m .52168 .93913 L .54974 .91598 L 1 .353 .631 r
F
.60713 .72132 m .60325 .74326 L .61635 .7247 L 1 .466 .718 r
F
.60713 .72132 m .59515 .73408 L .60325 .74326 L F
.28515 .49028 m .28909 .51576 L .2817 .50339 L 1 0 .182 r
F
.29722 .50149 m .29216 .51969 L .28515 .49028 L .874 0 .17 r
F
.29535 .55255 m .29218 .51986 L .28352 .53241 L .098 0 .565 r
F
.29218 .51986 m .29216 .51969 L .29211 .51977 L F
.29218 .51986 m .29211 .51977 L .28352 .53241 L F
.29211 .51977 m .28909 .51576 L .28352 .53241 L F
.29216 .51969 m .28909 .51576 L .29211 .51977 L F
.28352 .53241 m .28909 .51576 L .2817 .50339 L .19 0 .563 r
F
.28909 .51576 m .29058 .52539 L .28392 .50889 L 1 0 .182 r
F
.28909 .51576 m .28392 .50889 L .2817 .50339 L F
.2812 .50528 m .29058 .52539 L .27868 .51483 L F
.2817 .50339 m .28392 .50889 L .2812 .50528 L F
.28392 .50889 m .29058 .52539 L .2812 .50528 L F
.29216 .51969 m .29058 .52539 L .28909 .51576 L .874 0 .17 r
F
.29216 .51969 m .28909 .51576 L .28515 .49028 L F
.29216 .51969 m .29118 .50953 L .28909 .51576 L .098 0 .565 r
F
.2817 .50339 m .29118 .50953 L .28012 .4784 L .19 0 .563 r
F
.28909 .51576 m .29118 .50953 L .2817 .50339 L F
.48843 .57306 m .48838 .57116 L .476 .56964 L .685 .507 .841 r
F
.50079 .5736 m .48838 .57116 L .48843 .57306 L .682 .507 .842 r
F
.50104 .57455 m .50079 .5736 L .48843 .57306 L .683 .509 .842 r
F
.53797 .57677 m .54983 .58066 L .55038 .57806 L .675 .508 .846 r
F
.53797 .57677 m .53761 .57853 L .54983 .58066 L F
.51316 .57414 m .50079 .5736 L .50104 .57455 L .68 .507 .843 r
F
.51316 .57414 m .51316 .57414 L .50104 .57455 L F
.52168 .93913 m .49223 .94117 L .5222 .96637 L .75 .066 .582 r
F
.26773 .62194 m .25573 .54257 L .25568 .61111 L .542 .023 .607 r
F
.26773 .62194 m .26766 .55919 L .25573 .54257 L F
.63713 .57723 m .64952 .57887 L .64958 .57764 L .493 .095 .871 r
F
.63713 .57723 m .63718 .58079 L .64952 .57887 L F
.51316 .57415 m .52499 .57719 L .52539 .57634 L .68 .507 .843 r
F
.51316 .57415 m .51316 .57415 L .52499 .57719 L F
.41412 .56031 m .41569 .55253 L .4035 .54896 L .642 .417 .827 r
F
.42648 .56263 m .41569 .55253 L .41412 .56031 L .66 .442 .828 r
F
.50607 .70943 m .49294 .71404 L .5049 .71728 L .708 .447 .809 r
F
.51621 .71113 m .50491 .71728 L .51671 .71943 L .719 .447 .805 r
F
.51621 .71113 m .50607 .70943 L .50491 .71728 L F
.26917 .44734 m .27265 .37663 L .25827 .41707 L .368 0 .563 r
F
.49579 .7068 m .48136 .7099 L .49294 .71404 L .699 .449 .814 r
F
.50607 .70943 m .49579 .7068 L .49294 .71404 L .708 .447 .809 r
F
.4602 .69975 m .44226 .69822 L .45275 .70435 L .7 .493 .829 r
F
.47037 .70506 m .4602 .69975 L .45275 .70435 L .669 .452 .828 r
F
.52557 .57546 m .53761 .57853 L .53797 .57677 L .677 .506 .844 r
F
.52557 .57546 m .52539 .57634 L .53761 .57853 L F
.52067 .90223 m .49458 .90116 L .52117 .91776 L .564 .293 .813 r
F
.52067 .90223 m .49572 .89428 L .49458 .90116 L F
.42648 .56263 m .42789 .55582 L .41569 .55253 L .66 .442 .828 r
F
.43885 .56464 m .42789 .55582 L .42648 .56263 L .671 .463 .831 r
F
.33282 .97954 m .28884 1.06308 L .32546 .98584 L 0 0 0 r
F
.50079 .5736 m .50077 .57265 L .48838 .57116 L .682 .507 .842 r
F
.51316 .57414 m .50077 .57265 L .50079 .5736 L .679 .506 .843 r
F
.51316 .57414 m .51316 .57414 L .50079 .5736 L .68 .507 .843 r
F
.70053 .23509 m .73742 .21432 L .70797 .20311 L 1 .503 .582 r
F
.70053 .23509 m .72892 .24624 L .73742 .21432 L F
.5263 .71188 m .51671 .71943 L .52846 .72049 L .731 .448 .801 r
F
.5263 .71188 m .51621 .71113 L .51671 .71943 L F
.43885 .56464 m .44008 .55885 L .42789 .55582 L .671 .463 .831 r
F
.45123 .56643 m .44008 .55885 L .43885 .56464 L .678 .48 .834 r
F
.51316 .57414 m .52539 .57634 L .52557 .57546 L .679 .506 .843 r
F
.51316 .57414 m .51316 .57415 L .52539 .57634 L F
.45123 .56643 m .45228 .56166 L .44008 .55885 L .678 .48 .834 r
F
.46362 .56808 m .45228 .56166 L .45123 .56643 L .682 .492 .837 r
F
.48584 .70338 m .47037 .70506 L .48136 .7099 L .696 .456 .818 r
F
.49579 .7068 m .48584 .70338 L .48136 .7099 L .699 .449 .814 r
F
.61747 .70955 m .61635 .7247 L .62769 .70961 L 1 .803 .79 r
F
.61747 .70955 m .60713 .72132 L .61635 .7247 L F
.62469 .57703 m .63718 .58079 L .63713 .57723 L .569 .369 .897 r
F
.62469 .57703 m .62481 .58179 L .63718 .58079 L F
.46362 .56808 m .46447 .56431 L .45228 .56166 L .682 .492 .837 r
F
.476 .56964 m .46447 .56431 L .46362 .56808 L .684 .5 .839 r
F
.73159 1.01386 m .70853 .94985 L .74111 1.02301 L 1 .001 .159 r
F
.73159 1.01386 m .70054 .94483 L .70853 .94985 L F
.476 .56964 m .47665 .56685 L .46447 .56431 L .684 .5 .839 r
F
.48838 .57116 m .47665 .56685 L .476 .56964 L .683 .505 .841 r
F
.48838 .57116 m .48882 .56931 L .47665 .56685 L F
.50077 .57265 m .48882 .56931 L .48838 .57116 L .682 .506 .842 r
F
.50077 .57265 m .50099 .57173 L .48882 .56931 L F
.51316 .57414 m .50099 .57173 L .50077 .57265 L .679 .506 .843 r
F
.51316 .57414 m .51316 .57414 L .50077 .57265 L F
.51316 .57414 m .51316 .57414 L .50099 .57173 L F
.51316 .57414 m .51316 .57414 L .52557 .57546 L F
.51316 .57414 m .50146 .57086 L .50099 .57173 L .679 .505 .843 r
F
.51316 .57414 m .51316 .57414 L .50146 .57086 L F
.51316 .57414 m .52557 .57546 L .52551 .57455 L .679 .506 .843 r
F
.51316 .57414 m .51316 .57414 L .52551 .57455 L .679 .505 .843 r
F
.51316 .57414 m .50215 .57005 L .50146 .57086 L F
.51316 .57414 m .51316 .57414 L .50215 .57005 L F
.51316 .57414 m .52551 .57455 L .52523 .57363 L F
.51316 .57414 m .51316 .57414 L .52523 .57363 L .678 .505 .843 r
F
.51316 .57414 m .50303 .56935 L .50215 .57005 L .679 .505 .843 r
F
.51316 .57414 m .51316 .57414 L .50303 .56935 L F
.51316 .57414 m .52523 .57363 L .52476 .57275 L .678 .505 .843 r
F
.51316 .57414 m .51316 .57414 L .52476 .57275 L .678 .504 .843 r
F
.51316 .57414 m .5041 .56873 L .50303 .56935 L .679 .505 .843 r
F
.51316 .57414 m .51316 .57414 L .5041 .56873 L F
.51316 .57414 m .52476 .57275 L .52408 .5719 L .678 .504 .843 r
F
.51316 .57414 m .51316 .57414 L .52408 .5719 L .677 .504 .843 r
F
.51316 .57414 m .50533 .56821 L .5041 .56873 L .679 .505 .843 r
F
.51316 .57414 m .51316 .57414 L .50533 .56821 L F
.51316 .57414 m .52408 .5719 L .52323 .57109 L .677 .504 .843 r
F
.51316 .57414 m .51316 .57414 L .52323 .57109 L F
.51316 .57414 m .50671 .5678 L .50533 .56821 L .68 .505 .842 r
F
.51316 .57414 m .51316 .57414 L .50671 .5678 L F
.51316 .57414 m .52323 .57109 L .5222 .57033 L .677 .504 .843 r
F
.51316 .57414 m .51316 .57414 L .5222 .57033 L F
.51316 .57414 m .50822 .56751 L .50671 .5678 L .68 .506 .843 r
F
.51316 .57414 m .51316 .57414 L .50822 .56751 L F
.51316 .57414 m .5222 .57033 L .52096 .56959 L .677 .504 .843 r
F
.51316 .57414 m .51316 .57414 L .52096 .56959 L .677 .505 .843 r
F
.51316 .57414 m .50981 .56735 L .50822 .56751 L .68 .506 .843 r
F
.51316 .57414 m .51316 .57414 L .50981 .56735 L F
.51316 .57414 m .52096 .56959 L .51958 .56895 L .677 .505 .843 r
F
.51316 .57414 m .51316 .57414 L .51958 .56895 L .678 .505 .843 r
F
.51316 .57414 m .51146 .56731 L .50981 .56735 L .68 .506 .843 r
F
.51316 .57414 m .51316 .57414 L .51146 .56731 L F
.51316 .57414 m .51958 .56895 L .51808 .56839 L .678 .505 .843 r
F
.51316 .57414 m .51316 .57414 L .51808 .56839 L F
.51316 .57414 m .51315 .5674 L .51146 .56731 L .68 .506 .843 r
F
.51316 .57414 m .51316 .57414 L .51315 .5674 L F
.51316 .57414 m .51808 .56839 L .51649 .56794 L .678 .505 .843 r
F
.51316 .57414 m .51316 .57414 L .51649 .56794 L .679 .506 .843 r
F
.51316 .57414 m .51483 .56761 L .51315 .5674 L F
.51316 .57414 m .51316 .57414 L .51483 .56761 L F
.51316 .57414 m .51649 .56794 L .51483 .56761 L F
.81744 .68309 m .81885 .69681 L .81921 .68217 L 1 .367 .588 r
F
.81754 .68411 m .80693 .70491 L .81885 .69681 L F
.81679 .68443 m .80693 .70491 L .81754 .68411 L F
.80738 .68847 m .80693 .70491 L .81744 .68309 L F
.80525 .68939 m .80568 .67889 L .80738 .68847 L .698 0 .307 r
F
.80524 .68953 m .80693 .70491 L .80738 .68847 L 1 .375 .59 r
F
.80693 .70491 m .81085 .80646 L .81885 .69681 L 1 .332 .588 r
F
.80525 .68939 m .80738 .68847 L .81603 .73739 L .698 0 .307 r
F
.81744 .68309 m .80568 .67889 L .81768 .67358 L .699 0 .313 r
F
.80738 .68847 m .80568 .67889 L .81744 .68309 L F
.80527 .68881 m .79363 .68387 L .80568 .67889 L .698 0 .307 r
F
.80459 .68921 m .79363 .68387 L .80527 .68881 L F
.79551 .69454 m .79363 .68387 L .80524 .68953 L F
.79296 .69604 m .79497 .71299 L .79551 .69454 L 1 .385 .592 r
F
.79293 .69577 m .79363 .68387 L .79551 .69454 L .698 0 .3 r
F
.79296 .69604 m .79551 .69454 L .79767 .62069 L 1 .385 .592 r
F
.80524 .68953 m .79497 .71299 L .80693 .70491 L 1 .375 .59 r
F
.79551 .69454 m .79497 .71299 L .80524 .68953 L F
.79306 .69685 m .78297 .72108 L .79497 .71299 L 1 .385 .592 r
F
.79241 .69709 m .78297 .72108 L .79306 .69685 L F
.78362 .70034 m .78297 .72108 L .79293 .69577 L F
.78054 .70095 m .76937 .69255 L .78153 .68844 L .698 0 .292 r
F
.77991 .70129 m .76937 .69255 L .78054 .70095 L F
.77172 .70584 m .77091 .72919 L .78001 .70309 L 1 .397 .595 r
F
.77172 .70584 m .78001 .70309 L .78047 .70176 L F
.78047 .70176 m .77091 .72919 L .78297 .72108 L F
.76791 .7066 m .75716 .6961 L .76937 .69255 L .699 0 .282 r
F
.76732 .70692 m .75716 .6961 L .76791 .7066 L F
.7598 .71096 m .75881 .73733 L .76742 .70882 L 1 .412 .599 r
F
.7598 .71096 m .76742 .70882 L .76782 .70746 L F
.76782 .70746 m .75881 .73733 L .77091 .72919 L F
.75498 .71231 m .75716 .6961 L .7598 .71096 L .698 0 .269 r
F
.75503 .71352 m .75881 .73733 L .7598 .71096 L 1 .432 .604 r
F
.75503 .71352 m .7598 .71096 L .75513 .71273 L F
.75881 .73733 m .76356 .81293 L .77091 .72919 L 1 .36 .601 r
F
.75514 .71273 m .7598 .71096 L .76463 .73814 L .698 0 .269 r
F
.75498 .71231 m .7598 .71096 L .75514 .71273 L F
.7598 .71096 m .75716 .6961 L .76782 .70746 L .699 0 .282 r
F
.75513 .71273 m .7598 .71096 L .76158 .66357 L 1 .432 .604 r
F
.75503 .71193 m .7449 .699 L .75716 .6961 L .698 0 .269 r
F
.75448 .71222 m .7449 .699 L .75503 .71193 L F
.74791 .71561 m .7449 .699 L .75492 .71281 L F
.74162 .71769 m .74181 .71876 L .74204 .71755 L 1 .461 .611 r
F
.74181 .71876 m .74667 .74552 L .74791 .71561 L F
.74162 .71769 m .7449 .699 L .74791 .71561 L .696 0 .25 r
F
.74181 .71876 m .74791 .71561 L .74945 .67841 L 1 .461 .611 r
F
.75492 .71281 m .74667 .74552 L .75881 .73733 L 1 .432 .604 r
F
.74791 .71561 m .74667 .74552 L .75492 .71281 L F
.74184 .71891 m .73447 .75374 L .74667 .74552 L 1 .461 .611 r
F
.74136 .71897 m .73447 .75374 L .74184 .71891 L F
.73606 .71967 m .73447 .75374 L .74162 .71769 L F
.72783 .72184 m .72809 .72072 L .72878 .72159 L .688 0 .222 r
F
.72809 .72072 m .73258 .70111 L .73605 .71967 L F
.72783 .72184 m .73447 .75374 L .73605 .71967 L 1 .501 .62 r
F
.72809 .72072 m .73605 .71967 L .73874 .73405 L .688 0 .222 r
F
.74162 .71769 m .73258 .70111 L .7449 .699 L .696 0 .25 r
F
.73606 .71967 m .73258 .70111 L .74162 .71769 L F
.72783 .72184 m .72039 .70231 L .73258 .70111 L .688 0 .222 r
F
.72448 .72286 m .7224 .76183 L .7277 .72277 L 1 .501 .62 r
F
.72448 .72286 m .7277 .72277 L .72783 .72184 L F
.71309 .7251 m .71029 .76982 L .7224 .76183 L 1 .557 .633 r
F
.70091 .74082 m .71029 .76982 L .71309 .7251 L 1 .636 .652 r
F
.71308 .72464 m .70814 .70256 L .72039 .70231 L .665 0 .174 r
F
.70053 .71334 m .71284 .72487 L .71239 .68537 L 1 .8 .646 r
F
.71284 .72487 m .71309 .7251 L .71309 .72483 L F
.71284 .72487 m .71293 .72478 L .71294 .72485 L .804 0 .127 r
F
.71293 .72478 m .71308 .72464 L .71309 .72482 L F
.71308 .72464 m .71357 .72314 L .71556 .72427 L .665 0 .174 r
F
.71466 .72447 m .71556 .72427 L .71571 .72435 L F
.71308 .72464 m .71556 .72427 L .71466 .72447 L F
.71308 .72464 m .71571 .72435 L .71336 .72476 L F
.71357 .72314 m .72039 .70231 L .72448 .72286 L F
.71309 .7251 m .7224 .76183 L .72422 .72778 L 1 .557 .633 r
F
.7137 .72498 m .72422 .72778 L .72448 .72286 L F
.71309 .7251 m .72422 .72778 L .7137 .72498 L F
.71309 .7251 m .72448 .72286 L .71336 .72476 L F
.71357 .72314 m .72448 .72286 L .72593 .73013 L .665 0 .174 r
F
.72448 .72286 m .72039 .70231 L .72783 .72184 L .688 0 .222 r
F
.71309 .72483 m .71309 .7251 L .71336 .72476 L 1 .649 .62 r
F
.71462 .75369 m .71309 .72483 L .72593 .73013 L .853 0 .235 r
F
.71309 .72483 m .71308 .72464 L .71336 .72476 L F
.71309 .72483 m .71336 .72476 L .72593 .73013 L F
.71309 .72482 m .71309 .72483 L .71336 .72476 L 1 .649 .62 r
F
.71239 .68537 m .71309 .72482 L .72521 .70923 L F
.71309 .72482 m .71336 .72476 L .72521 .70923 L F
.71284 .72487 m .71309 .72483 L .71239 .68537 L 1 .8 .646 r
F
.70123 .736 m .71284 .72487 L .71462 .75369 L .804 0 .127 r
F
.71284 .72487 m .71294 .72485 L .71462 .75369 L F
.71293 .72478 m .71309 .72482 L .71462 .75369 L F
.71336 .72476 m .72448 .72286 L .72521 .70923 L 1 .557 .633 r
F
.71336 .72476 m .71571 .72435 L .72593 .73013 L .665 0 .174 r
F
.72593 .73013 m .72448 .72286 L .72783 .72184 L .688 0 .222 r
F
.72783 .72184 m .7224 .76183 L .73447 .75374 L 1 .501 .62 r
F
.72521 .70923 m .72448 .72286 L .72783 .72184 L F
.72521 .70923 m .72783 .72184 L .73726 .69369 L F
.72783 .72184 m .73605 .71967 L .73726 .69369 L F
.72593 .73013 m .72783 .72184 L .73874 .73405 L .688 0 .222 r
F
.72783 .72184 m .72878 .72159 L .73874 .73405 L F
.74162 .71769 m .74136 .71897 L .74184 .71891 L 1 .461 .611 r
F
.73727 .69369 m .73606 .71967 L .74162 .71769 L F
.73875 .73405 m .73606 .71967 L .74162 .71769 L .696 0 .25 r
F
.73875 .73405 m .74162 .71769 L .75171 .73664 L F
.74162 .71769 m .74791 .71561 L .75171 .73664 L F
.73727 .69369 m .74162 .71769 L .74945 .67841 L 1 .461 .611 r
F
.74162 .71769 m .74204 .71755 L .74945 .67841 L F
.75492 .71281 m .75448 .71222 L .75503 .71193 L .698 0 .269 r
F
.75171 .73664 m .74791 .71561 L .75492 .71281 L F
.74945 .67841 m .74791 .71561 L .75492 .71281 L 1 .432 .604 r
F
.74945 .67841 m .75492 .71281 L .76158 .66357 L F
.75492 .71281 m .75503 .71352 L .75513 .71273 L F
.75492 .71281 m .75498 .71231 L .75514 .71273 L .698 0 .269 r
F
.75492 .71281 m .75513 .71273 L .76158 .66357 L 1 .432 .604 r
F
.75881 .73733 m .75165 .81433 L .76356 .81293 L 1 .36 .601 r
F
.74667 .74552 m .75165 .81433 L .75881 .73733 L 1 .372 .606 r
F
.75171 .73664 m .75492 .71281 L .76463 .73814 L .698 0 .269 r
F
.75492 .71281 m .75514 .71273 L .76463 .73814 L F
.75991 .71156 m .7598 .71096 L .76782 .70746 L .699 0 .282 r
F
.76782 .70746 m .76732 .70692 L .76791 .7066 L F
.76158 .66357 m .7598 .71096 L .76782 .70746 L 1 .412 .599 r
F
.76463 .73814 m .75991 .71156 L .76782 .70746 L .699 0 .282 r
F
.76782 .70746 m .76786 .70711 L .76795 .70741 L F
.76782 .70746 m .76795 .70741 L .76795 .7074 L 1 .412 .599 r
F
.76786 .70711 m .76937 .69255 L .77172 .70584 L .699 0 .282 r
F
.76789 .70795 m .77091 .72919 L .77172 .70584 L 1 .412 .599 r
F
.76789 .70795 m .77172 .70584 L .76795 .70741 L F
.77091 .72919 m .77543 .81142 L .78297 .72108 L 1 .351 .597 r
F
.76795 .70741 m .77172 .70584 L .77752 .7388 L .699 0 .282 r
F
.76786 .70711 m .77172 .70584 L .76795 .70741 L F
.77172 .70584 m .76937 .69255 L .78047 .70176 L .698 0 .292 r
F
.76795 .70741 m .77172 .70584 L .77366 .64907 L 1 .412 .599 r
F
.76782 .70746 m .76795 .7074 L .77366 .64907 L F
.76158 .66357 m .76782 .70746 L .77366 .64907 L F
.76782 .70746 m .76789 .70795 L .76795 .70741 L F
.77091 .72919 m .76356 .81293 L .77543 .81142 L 1 .351 .597 r
F
.76463 .73814 m .76782 .70746 L .77752 .7388 L .699 0 .282 r
F
.76782 .70746 m .76795 .70741 L .77752 .7388 L F
.77182 .70644 m .77172 .70584 L .78047 .70176 L .698 0 .292 r
F
.78047 .70176 m .77991 .70129 L .78054 .70095 L F
.77366 .64907 m .77172 .70584 L .78047 .70176 L 1 .397 .595 r
F
.77752 .7388 m .77182 .70644 L .78047 .70176 L .698 0 .292 r
F
.78049 .7015 m .78153 .68844 L .78362 .70034 L F
.78047 .70176 m .78297 .72108 L .78362 .70034 L 1 .397 .595 r
F
.78297 .72108 m .78727 .80984 L .79497 .71299 L 1 .344 .594 r
F
.78049 .7015 m .78362 .70034 L .79038 .7388 L .698 0 .292 r
F
.78362 .70034 m .78153 .68844 L .79293 .69577 L .698 0 .3 r
F
.78047 .70176 m .78362 .70034 L .78363 .70005 L 1 .397 .595 r
F
.78047 .70176 m .78049 .7015 L .78055 .70172 L .698 0 .292 r
F
.79293 .69577 m .78153 .68844 L .79363 .68387 L .698 0 .3 r
F
.78047 .70176 m .78363 .70005 L .78569 .6348 L 1 .397 .595 r
F
.77366 .64907 m .78047 .70176 L .78569 .6348 L F
.78297 .72108 m .77543 .81142 L .78727 .80984 L 1 .344 .594 r
F
.77752 .7388 m .78047 .70176 L .79038 .7388 L .698 0 .292 r
F
.78047 .70176 m .78055 .70172 L .79038 .7388 L F
.79293 .69577 m .79241 .69709 L .79306 .69685 L 1 .385 .592 r
F
.78569 .6348 m .78362 .70034 L .79293 .69577 L F
.79038 .7388 m .78362 .70034 L .79293 .69577 L .698 0 .3 r
F
.79497 .71299 m .79908 .80818 L .80693 .70491 L 1 .338 .591 r
F
.79497 .71299 m .78727 .80984 L .79908 .80818 L F
.79038 .7388 m .79293 .69577 L .80322 .7383 L .698 0 .3 r
F
.79293 .69577 m .79296 .69604 L .79298 .69574 L 1 .385 .592 r
F
.79293 .69577 m .79551 .69454 L .80322 .7383 L .698 0 .3 r
F
.78569 .6348 m .79293 .69577 L .79767 .62069 L 1 .385 .592 r
F
.79293 .69577 m .79298 .69574 L .79767 .62069 L F
.80524 .68953 m .80459 .68921 L .80527 .68881 L .698 0 .307 r
F
.80322 .7383 m .79551 .69454 L .80524 .68953 L F
.79767 .62069 m .79551 .69454 L .80524 .68953 L 1 .375 .59 r
F
.79767 .62069 m .80524 .68953 L .80958 .60667 L F
.80524 .68953 m .80525 .68939 L .80528 .68951 L .698 0 .307 r
F
.80524 .68953 m .80738 .68847 L .80958 .60667 L 1 .375 .59 r
F
.80693 .70491 m .79908 .80818 L .81085 .80646 L 1 .332 .588 r
F
.80322 .7383 m .80524 .68953 L .81603 .73739 L .698 0 .307 r
F
.80524 .68953 m .80528 .68951 L .81603 .73739 L F
.81744 .68309 m .81679 .68443 L .81754 .68411 L 1 .367 .588 r
F
.80958 .60667 m .80738 .68847 L .81744 .68309 L F
.81603 .73739 m .80738 .68847 L .81744 .68309 L .699 0 .313 r
F
.81603 .73739 m .81744 .68309 L .82881 .73615 L F
.81744 .68309 m .81768 .67358 L .81921 .68217 L F
.81744 .68309 m .81921 .68217 L .82881 .73615 L F
.80958 .60667 m .81744 .68309 L .82144 .5927 L 1 .367 .588 r
F
.81744 .68309 m .81921 .68217 L .82144 .5927 L F
.41336 .69933 m .4037 .69409 L .39284 .69997 L .972 .86 .837 r
F
.42321 .69578 m .4037 .69409 L .41336 .69933 L .906 .748 .83 r
F
.52551 .57455 m .52557 .57546 L .53797 .57677 L .676 .505 .844 r
F
.56956 .87011 m .54546 .89195 L .5476 .90297 L 1 .761 .7 r
F
.56922 .86977 m .54546 .89195 L .56956 .87011 L 1 .831 .714 r
F
.44589 .88448 m .41635 .89958 L .44157 .88301 L .413 0 .636 r
F
.44508 .88489 m .42228 .89603 L .41635 .89958 L F
.44083 .88695 m .42228 .89603 L .44508 .88489 L F
.44525 .88479 m .42228 .89603 L .44589 .88448 L F
.44589 .88448 m .44083 .88695 L .44508 .88489 L F
.44629 .8845 m .42229 .89603 L .44589 .88448 L .497 0 .693 r
F
.42229 .89603 m .4254 .8945 L .44589 .88448 L F
.47255 .88268 m .44917 .88418 L .4463 .8845 L .082 0 .663 r
F
.42229 .89603 m .42228 .89603 L .4254 .8945 L .497 0 .693 r
F
.44628 .88451 m .42284 .89565 L .42228 .89603 L F
.44629 .8845 m .44184 .88662 L .44628 .88451 L F
.44184 .88662 m .42284 .89565 L .44628 .88451 L F
.42354 .89534 m .42284 .89565 L .42628 .89401 L .578 .018 .779 r
F
.42284 .89565 m .42284 .89565 L .42313 .89551 L F
.42284 .89565 m .42313 .89551 L .42628 .89401 L F
.44917 .88418 m .42354 .89534 L .4463 .8845 L F
.42354 .89534 m .42628 .89401 L .4463 .8845 L F
.44589 .88448 m .44525 .88479 L .44589 .88448 L .413 0 .636 r
F
.45358 .88212 m .43723 .88858 L .44918 .88418 L .68 .328 .851 r
F
.44157 .88301 m .4244 .89429 L .42033 .8961 L 0 0 0 r
F
.43723 .88858 m .42677 .89271 L .43489 .88962 L .68 .328 .851 r
F
.43723 .88858 m .43489 .88962 L .44918 .88418 L F
.42033 .8961 m .41635 .89958 L .41046 .90218 L 0 0 0 r
F
.4244 .89429 m .41635 .89958 L .42033 .8961 L F
.61226 .57689 m .62481 .58179 L .62469 .57703 L .615 .499 .889 r
F
.61226 .57689 m .61242 .5821 L .62481 .58179 L F
.53788 .57496 m .53797 .57677 L .55038 .57806 L .673 .505 .846 r
F
.52551 .57455 m .53797 .57677 L .53788 .57496 L .676 .505 .844 r
F
.57892 .71854 m .57487 .73326 L .58704 .72603 L .854 .454 .762 r
F
.57892 .71854 m .56809 .72417 L .57487 .73326 L F
.53616 .71159 m .52846 .72049 L .53994 .72033 L .746 .451 .797 r
F
.53616 .71159 m .5263 .71188 L .52846 .72049 L F
.55025 .57538 m .55038 .57806 L .56279 .57928 L .67 .508 .848 r
F
.53788 .57496 m .55038 .57806 L .55025 .57538 L .673 .505 .846 r
F
.50099 .57173 m .48974 .56755 L .48882 .56931 L .681 .505 .842 r
F
.50099 .57173 m .50146 .57086 L .48974 .56755 L F
.59786 .71677 m .59515 .73408 L .60713 .72132 L .952 .509 .751 r
F
.59786 .71677 m .58704 .72603 L .59515 .73408 L F
.59984 .57673 m .61242 .5821 L .61226 .57689 L .643 .534 .877 r
F
.59984 .57673 m .60002 .58188 L .61242 .5821 L F
.5613 .71575 m .55628 .72776 L .56809 .72417 L .796 .452 .78 r
F
.5613 .71575 m .55096 .71879 L .55628 .72776 L F
.56263 .57579 m .56279 .57928 L .5752 .58038 L .668 .515 .852 r
F
.55025 .57538 m .56279 .57928 L .56263 .57579 L .67 .508 .848 r
F
.56922 .86977 m .54526 .89102 L .54546 .89195 L 1 .831 .714 r
F
.56679 .86759 m .54526 .89102 L .56921 .86977 L 1 .857 .735 r
F
.58869 .84673 m .56679 .86759 L .56921 .86977 L 1 .917 .77 r
F
.52523 .57363 m .52551 .57455 L .53788 .57496 L .675 .503 .844 r
F
.57502 .57617 m .5752 .58038 L .58761 .58128 L .664 .524 .858 r
F
.56263 .57579 m .5752 .58038 L .57502 .57617 L .668 .515 .852 r
F
.58743 .57649 m .60002 .58188 L .59984 .57673 L .657 .534 .866 r
F
.58743 .57649 m .58761 .58128 L .60002 .58188 L F
.29535 .55255 m .30242 .53819 L .29859 .52843 L .098 0 .565 r
F
.29722 .50149 m .29859 .52843 L .29216 .51969 L .874 0 .17 r
F
.29216 .51969 m .29859 .52843 L .29118 .50953 L .098 0 .565 r
F
.29535 .55255 m .29859 .52843 L .29216 .51969 L F
.29722 .50149 m .30271 .52999 L .29859 .52843 L .874 0 .17 r
F
.29216 .51969 m .29859 .52843 L .29058 .52539 L F
.30922 .51037 m .30271 .52999 L .29722 .5015 L .614 0 .095 r
F
.57502 .57617 m .58761 .58128 L .58743 .57649 L .664 .524 .858 r
F
.5476 .90297 m .52117 .91776 L .52168 .93913 L 1 .353 .631 r
F
.54546 .89195 m .52117 .91776 L .5476 .90297 L 1 .472 .678 r
F
.66186 .696 m .65623 .69561 L .66796 .69437 L .023 0 0 r
F
.6584 .69522 m .65623 .69561 L .66186 .696 L .289 0 .819 r
F
.65623 .69561 m .65393 .69604 L .65907 .69406 L 0 0 0 r
F
.64949 .69319 m .65623 .69561 L .6584 .69522 L .289 0 .819 r
F
.65623 .69561 m .64814 .69826 L .65393 .69604 L 0 0 0 r
F
.47641 .69932 m .4602 .69975 L .47037 .70506 L .704 .472 .82 r
F
.48584 .70338 m .47641 .69932 L .47037 .70506 L .696 .456 .818 r
F
.27209 .69695 m .25568 .61111 L .26014 .69178 L .645 .048 .601 r
F
.27209 .69695 m .26773 .62194 L .25568 .61111 L F
.48882 .56931 m .47801 .5642 L .47665 .56685 L .682 .504 .841 r
F
.48882 .56931 m .48974 .56755 L .47801 .5642 L F
.50146 .57086 m .49112 .56593 L .48974 .56755 L .681 .505 .842 r
F
.50146 .57086 m .50215 .57005 L .49112 .56593 L F
.52523 .57363 m .53788 .57496 L .53732 .57314 L .675 .503 .844 r
F
.52476 .57275 m .52523 .57363 L .53732 .57314 L .674 .501 .844 r
F
.53732 .57314 m .53788 .57496 L .55025 .57538 L .67 .501 .845 r
F
.40462 .90399 m .37759 .93756 L .37005 .94547 L 0 0 0 r
F
.41046 .90218 m .37759 .93755 L .40462 .90399 L .562 0 .463 r
F
.47665 .56685 m .46627 .56077 L .46447 .56431 L .681 .499 .839 r
F
.47665 .56685 m .47801 .5642 L .46627 .56077 L F
.50215 .57005 m .49287 .56451 L .49112 .56593 L .681 .505 .842 r
F
.50215 .57005 m .50303 .56935 L .49287 .56451 L F
.54561 .71021 m .53994 .72033 L .55096 .71879 L .764 .457 .792 r
F
.54561 .71021 m .53616 .71159 L .53994 .72033 L F
.52476 .57275 m .53732 .57314 L .53638 .5714 L .674 .501 .844 r
F
.52408 .5719 m .52476 .57275 L .53638 .5714 L .673 .5 .844 r
F
.29663 .25321 m .31722 .21987 L .28807 .2221 L .43 .001 .591 r
F
.44226 .69822 m .43309 .69201 L .42321 .69578 L .745 .572 .837 r
F
.45101 .69412 m .43309 .69201 L .44226 .69822 L .759 .55 .824 r
F
.4602 .69975 m .45101 .69412 L .44226 .69822 L .7 .493 .829 r
F
.46447 .56431 m .45451 .55722 L .45228 .56166 L .678 .49 .838 r
F
.46447 .56431 m .46627 .56077 L .45451 .55722 L F
.58356 .85085 m .56679 .86759 L .5868 .84853 L .958 .771 .825 r
F
.58356 .85085 m .56309 .86484 L .56679 .86759 L F
.59631 .85097 m .58021 .85323 L .58356 .85085 L .101 0 0 r
F
.57837 .85349 m .56309 .86484 L .58008 .85322 L .729 .515 .865 r
F
.57837 .85349 m .58008 .85322 L .58356 .85085 L F
.57837 .85349 m .55938 .8624 L .56309 .86484 L F
.57312 .8541 m .55938 .8624 L .57837 .85349 L .616 .367 .885 r
F
.58962 .85251 m .57657 .85377 L .57837 .85349 L 0 0 0 r
F
.57657 .85377 m .57312 .8541 L .57837 .85349 L F
.58021 .85323 m .57837 .85349 L .58356 .85085 L .101 0 0 r
F
.58356 .85085 m .5868 .84853 L .58869 .84673 L .958 .771 .825 r
F
.60288 .84364 m .58869 .84673 L .60928 .82873 L 0 0 0 r
F
.60288 .84364 m .58356 .85085 L .58869 .84673 L F
.30922 .51037 m .31483 .52905 L .30271 .52999 L .614 0 .095 r
F
.3213 .51744 m .31483 .52905 L .30922 .51037 L .394 0 0 r
F
.50303 .56935 m .49501 .56326 L .49287 .56451 L .681 .504 .842 r
F
.50303 .56935 m .5041 .56873 L .49501 .56326 L F
.48974 .56755 m .48007 .56176 L .47801 .5642 L .682 .503 .841 r
F
.48974 .56755 m .49112 .56593 L .48007 .56176 L F
.54943 .57268 m .55025 .57538 L .56263 .57579 L .665 .501 .848 r
F
.53732 .57314 m .55025 .57538 L .54943 .57268 L .67 .501 .845 r
F
.33282 .97954 m .29789 1.05113 L .28884 1.06308 L 0 0 0 r
F
.34021 .97315 m .29789 1.05113 L .33282 .97954 L F
.52408 .5719 m .53638 .5714 L .53504 .56971 L .673 .5 .844 r
F
.52323 .57109 m .52408 .5719 L .53504 .56971 L .672 .499 .844 r
F
.45228 .56166 m .44275 .55353 L .44008 .55885 L .671 .478 .836 r
F
.45228 .56166 m .45451 .55722 L .44275 .55353 L F
.79539 .53472 m .79767 .62069 L .80958 .60667 L 1 .403 .587 r
F
.78363 .55401 m .79767 .62069 L .79539 .53472 L 1 .413 .589 r
F
.77686 .48029 m .78363 .55401 L .79539 .53472 L 1 .425 .585 r
F
.46767 .69473 m .45101 .69412 L .4602 .69975 L .728 .498 .819 r
F
.47641 .69932 m .46767 .69473 L .4602 .69975 L .704 .472 .82 r
F
.53638 .5714 m .53732 .57314 L .54943 .57268 L .668 .497 .845 r
F
.62602 .70087 m .62769 .70961 L .63712 .7005 L .858 .785 .861 r
F
.62602 .70087 m .61747 .70955 L .62769 .70961 L F
.5041 .56873 m .49748 .56222 L .49501 .56326 L .68 .504 .842 r
F
.5041 .56873 m .50533 .56821 L .49748 .56222 L F
.74129 .39785 m .7662 .41897 L .75166 .36947 L 1 .453 .585 r
F
.74129 .39785 m .75519 .44502 L .7662 .41897 L F
.42321 .69578 m .41456 .68932 L .4037 .69409 L .906 .748 .83 r
F
.43309 .69201 m .41456 .68932 L .42321 .69578 L .857 .659 .822 r
F
.52323 .57109 m .53504 .56971 L .53333 .56808 L .672 .499 .844 r
F
.5222 .57033 m .52323 .57109 L .53333 .56808 L F
.60719 .70753 m .60713 .72132 L .61747 .70955 L .968 .692 .798 r
F
.60719 .70753 m .59786 .71677 L .60713 .72132 L F
.58856 .71153 m .58704 .72603 L .59786 .71677 L .885 .521 .774 r
F
.58856 .71153 m .57892 .71854 L .58704 .72603 L F
.57078 .71132 m .56809 .72417 L .57892 .71854 L .821 .474 .779 r
F
.57078 .71132 m .5613 .71575 L .56809 .72417 L F
.50724 .70152 m .49579 .7068 L .50607 .70943 L .723 .461 .808 r
F
.51571 .70283 m .50607 .70943 L .51621 .71113 L .731 .46 .805 r
F
.51571 .70283 m .50724 .70152 L .50607 .70943 L F
.72205 1.00497 m .70054 .94483 L .73159 1.01386 L 1 0 .154 r
F
.72205 1.00497 m .69252 .93974 L .70054 .94483 L F
.71176 .31004 m .74298 .30261 L .72038 .27814 L 1 .492 .584 r
F
.71176 .31004 m .73347 .33327 L .74298 .30261 L F
.49865 .69943 m .48584 .70338 L .49579 .7068 L .719 .463 .811 r
F
.50724 .70152 m .49865 .69943 L .49579 .7068 L .723 .461 .808 r
F
.56156 .57228 m .56263 .57579 L .57502 .57617 L .656 .5 .852 r
F
.54943 .57268 m .56263 .57579 L .56156 .57228 L .665 .501 .848 r
F
.44008 .55885 m .43097 .54966 L .42789 .55582 L .661 .462 .835 r
F
.44008 .55885 m .44275 .55353 L .43097 .54966 L F
.3213 .51744 m .32698 .52634 L .31483 .52905 L .394 0 0 r
F
.33343 .52328 m .32698 .52634 L .3213 .51744 L .086 0 0 r
F
.50533 .56821 m .50025 .5614 L .49748 .56222 L .68 .504 .842 r
F
.50533 .56821 m .50671 .5678 L .50025 .5614 L F
.5222 .57033 m .53333 .56808 L .53128 .56655 L .672 .499 .844 r
F
.52096 .56959 m .5222 .57033 L .53128 .56655 L F
.52413 .70335 m .51621 .71113 L .5263 .71188 L .74 .461 .802 r
F
.52413 .70335 m .51571 .70283 L .51621 .71113 L F
.52062 .90102 m .49573 .89428 L .52067 .90223 L .553 .303 .825 r
F
.52062 .90102 m .49583 .89367 L .49573 .89428 L F
.47801 .5642 m .469 .55752 L .46627 .56077 L .68 .499 .84 r
F
.47801 .5642 m .48007 .56176 L .469 .55752 L F
.49112 .56593 m .4827 .55962 L .48007 .56176 L .681 .503 .841 r
F
.49112 .56593 m .49287 .56451 L .4827 .55962 L F
.27969 .5748 m .27182 .51063 L .26766 .55919 L .408 .002 .612 r
F
.27988 .63174 m .26766 .55919 L .26773 .62194 L .551 .029 .614 r
F
.27988 .63174 m .27969 .5748 L .26766 .55919 L F
.42789 .55582 m .41918 .54561 L .41569 .55253 L .648 .445 .835 r
F
.42789 .55582 m .43097 .54966 L .41918 .54561 L F
.28181 .30696 m .30525 .28394 L .29663 .25321 L .486 .006 .588 r
F
.29133 .33905 m .30525 .28394 L .28181 .30696 L .514 .011 .59 r
F
.27265 .37663 m .29133 .33905 L .28181 .30696 L .495 .005 .578 r
F
.50671 .5678 m .50325 .56082 L .50025 .5614 L .68 .504 .842 r
F
.50671 .5678 m .50822 .56751 L .50325 .56082 L F
.49035 .69666 m .47641 .69932 L .48584 .70338 L .719 .47 .813 r
F
.49865 .69943 m .49035 .69666 L .48584 .70338 L .719 .463 .811 r
F
.33457 .52378 m .33905 .52482 L .33343 .52328 L .069 0 0 r
F
.34259 .52718 m .34018 .52478 L .33457 .52378 L .188 0 .777 r
F
.33343 .52328 m .33905 .52482 L .32698 .52634 L .086 0 0 r
F
.52096 .56959 m .53128 .56655 L .5288 .56507 L .672 .499 .844 r
F
.51958 .56895 m .52096 .56959 L .5288 .56507 L .673 .5 .844 r
F
.55449 .70771 m .55096 .71879 L .5613 .71575 L .781 .466 .789 r
F
.55449 .70771 m .54561 .71021 L .55096 .71879 L F
.33457 .52378 m .34017 .52478 L .33905 .52482 L .069 0 0 r
F
.54546 .89195 m .52067 .90223 L .52117 .91776 L 1 .472 .678 r
F
.52187 1.0845 m .49291 1.08223 L .49218 .95817 L .954 .041 .471 r
F
.54526 .89102 m .52067 .90223 L .54546 .89195 L 1 .579 .707 r
F
.7789 .46065 m .80165 .39899 L .78974 .44043 L 0 0 0 r
F
.7789 .46065 m .79057 .42122 L .80165 .39899 L F
.52029 .89336 m .49583 .89367 L .52062 .90101 L .628 .436 .842 r
F
.52029 .89336 m .49659 .88953 L .49583 .89367 L F
.53638 .5714 m .54943 .57268 L .54802 .57012 L .668 .497 .845 r
F
.53504 .56971 m .53638 .5714 L .54802 .57012 L .665 .494 .845 r
F
.41569 .55253 m .40738 .54143 L .4035 .54896 L .632 .428 .836 r
F
.41569 .55253 m .41918 .54561 L .40738 .54143 L F
.34259 .52718 m .34808 .52495 L .34018 .52478 L .188 0 .777 r
F
.35476 .53202 m .34808 .52495 L .34259 .52718 L .42 .126 .895 r
F
.5737 .57194 m .57502 .57617 L .58743 .57649 L .644 .497 .858 r
F
.56156 .57228 m .57502 .57617 L .5737 .57194 L .656 .5 .852 r
F
.50822 .56751 m .50645 .56049 L .50325 .56082 L .679 .504 .842 r
F
.50822 .56751 m .50981 .56735 L .50645 .56049 L F
.51958 .56895 m .5288 .56507 L .52603 .56375 L .673 .5 .844 r
F
.51808 .56839 m .51958 .56895 L .52603 .56375 L .674 .501 .843 r
F
.56679 .86759 m .54385 .88502 L .54526 .89102 L 1 .857 .735 r
F
.56309 .86484 m .54385 .88502 L .56679 .86759 L 1 .909 .777 r
F
.54526 .89102 m .52062 .90102 L .52067 .90223 L 1 .579 .707 r
F
.54385 .88502 m .52062 .90101 L .54526 .89102 L 1 .627 .728 r
F
.4035 .54896 m .39557 .53722 L .3913 .5451 L .612 .413 .841 r
F
.4035 .54896 m .40738 .54143 L .39557 .53722 L F
.35476 .53202 m .36002 .5266 L .34808 .52495 L .42 .126 .895 r
F
.36693 .5366 m .36002 .5266 L .35476 .53202 L .505 .322 .888 r
F
.38195 .70769 m .37271 .7016 L .36087 .7147 L 1 .972 .729 r
F
.53236 .70303 m .5263 .71188 L .53616 .71159 L .75 .463 .799 r
F
.53236 .70303 m .52413 .70335 L .5263 .71188 L F
.54802 .57012 m .54943 .57268 L .56156 .57228 L .659 .492 .848 r
F
.36693 .5366 m .3719 .52949 L .36002 .5266 L .505 .322 .888 r
F
.37912 .54096 m .3719 .52949 L .36693 .5366 L .553 .383 .866 r
F
.3913 .5451 m .38374 .53315 L .37912 .54096 L .587 .401 .85 r
F
.3913 .5451 m .39557 .53722 L .38374 .53315 L F
.50981 .56735 m .50976 .56041 L .50645 .56049 L .679 .503 .842 r
F
.50981 .56735 m .51146 .56731 L .50976 .56041 L F
.37912 .54096 m .38374 .53315 L .3719 .52949 L .553 .383 .866 r
F
.51808 .56839 m .52603 .56375 L .52302 .56263 L .674 .501 .843 r
F
.51649 .56794 m .51808 .56839 L .52302 .56263 L .676 .502 .843 r
F
.76538 .50372 m .78363 .55401 L .77686 .48029 L 1 .431 .585 r
F
.72388 .36386 m .75166 .36947 L .73347 .33327 L 1 .483 .586 r
F
.72388 .36386 m .74129 .39785 L .75166 .36947 L F
.51146 .56731 m .51314 .5606 L .50976 .56041 L .679 .503 .842 r
F
.51146 .56731 m .51315 .5674 L .51314 .5606 L F
.51649 .56794 m .52302 .56263 L .51983 .56171 L .676 .502 .843 r
F
.51483 .56761 m .51649 .56794 L .51983 .56171 L .677 .502 .843 r
F
.51315 .5674 m .51652 .56103 L .51314 .5606 L .678 .503 .842 r
F
.51315 .5674 m .51483 .56761 L .51652 .56103 L F
.51483 .56761 m .51983 .56171 L .51652 .56103 L .677 .502 .843 r
F
.37098 .71892 m .34887 .73248 L .35979 .73908 L 1 .873 .679 r
F
.49287 .56451 m .48589 .55776 L .4827 .55962 L .681 .503 .841 r
F
.49287 .56451 m .49501 .56326 L .48589 .55776 L F
.46627 .56077 m .45791 .55319 L .45451 .55722 L .674 .491 .84 r
F
.46627 .56077 m .469 .55752 L .45791 .55319 L F
.58587 .5717 m .58743 .57649 L .59984 .57673 L .624 .488 .867 r
F
.5737 .57194 m .58743 .57649 L .58587 .5717 L .644 .497 .858 r
F
.48247 .6933 m .46767 .69473 L .47641 .69932 L .727 .48 .814 r
F
.49035 .69666 m .48247 .6933 L .47641 .69932 L .719 .47 .813 r
F
.39284 .69997 m .38445 .69241 L .37271 .7016 L 1 .966 .771 r
F
.4037 .69409 m .38445 .69241 L .39284 .69997 L 1 .87 .793 r
F
.53504 .56971 m .54802 .57012 L .54602 .56759 L .665 .494 .845 r
F
.53333 .56808 m .53504 .56971 L .54602 .56759 L .664 .492 .845 r
F
.26917 .44734 m .28283 .41192 L .27265 .37663 L .368 0 .563 r
F
.28283 .41191 m .29133 .33905 L .27265 .37663 L .532 .01 .577 r
F
.64445 .69578 m .64814 .69826 L .65623 .69561 L .479 .011 .816 r
F
.64445 .69578 m .63712 .7005 L .64814 .69826 L F
.28413 .70095 m .26773 .62194 L .27209 .69695 L .666 .058 .605 r
F
.28413 .70095 m .27988 .63174 L .26773 .62194 L F
.69304 .26699 m .72892 .24624 L .70053 .23509 L 1 .501 .583 r
F
.69304 .26699 m .72037 .27813 L .72892 .24624 L F
.45101 .69412 m .443 .68815 L .43309 .69201 L .759 .55 .824 r
F
.4598 .68971 m .443 .68815 L .45101 .69412 L .764 .529 .816 r
F
.46767 .69473 m .4598 .68971 L .45101 .69412 L .728 .498 .819 r
F
.48007 .56176 m .47249 .55469 L .469 .55752 L .679 .5 .841 r
F
.48007 .56176 m .4827 .55962 L .47249 .55469 L F
.54025 .70187 m .53616 .71159 L .54561 .71021 L .76 .467 .797 r
F
.54025 .70187 m .53236 .70303 L .53616 .71159 L F
.59805 .57159 m .59984 .57673 L .61226 .57689 L .593 .46 .878 r
F
.58587 .5717 m .59984 .57673 L .59805 .57159 L .624 .488 .867 r
F
.34021 .97315 m .30695 1.03906 L .29789 1.05113 L 0 0 0 r
F
.34763 .96663 m .30695 1.03906 L .34021 .97315 L F
.57922 .70586 m .57892 .71854 L .58856 .71153 L .832 .515 .788 r
F
.57922 .70586 m .57078 .71132 L .57892 .71854 L F
.43309 .69201 m .42543 .68525 L .41456 .68932 L .857 .659 .822 r
F
.443 .68815 m .42543 .68525 L .43309 .69201 L .823 .596 .816 r
F
.55969 .56892 m .56156 .57228 L .5737 .57194 L .645 .483 .852 r
F
.54802 .57012 m .56156 .57228 L .55969 .56892 L .659 .492 .848 r
F
.49501 .56326 m .4896 .5562 L .48589 .55776 L .68 .503 .842 r
F
.49501 .56326 m .49748 .56222 L .4896 .5562 L F
.54385 .88502 m .52029 .89336 L .52062 .90101 L 1 .627 .728 r
F
.59685 .70416 m .59786 .71677 L .60719 .70753 L .88 .617 .803 r
F
.59685 .70416 m .58856 .71153 L .59786 .71677 L F
.45451 .55722 m .4468 .54875 L .44275 .55353 L .665 .479 .839 r
F
.45451 .55722 m .45791 .55319 L .4468 .54875 L F
.56262 .7042 m .5613 .71575 L .57078 .71132 L .793 .481 .79 r
F
.56262 .7042 m .55449 .70771 L .5613 .71575 L F
.54602 .56759 m .54802 .57012 L .55969 .56892 L .654 .484 .847 r
F
.53333 .56808 m .54602 .56759 L .54346 .56515 L .664 .492 .845 r
F
.53128 .56655 m .53333 .56808 L .54346 .56515 L .664 .491 .845 r
F
.4037 .69409 m .39614 .68587 L .38445 .69241 L 1 .87 .793 r
F
.41456 .68932 m .39614 .68587 L .4037 .69409 L 1 .761 .803 r
F
.61026 .57169 m .61226 .57689 L .62469 .57703 L .548 .394 .89 r
F
.59805 .57159 m .61226 .57689 L .61026 .57169 L .593 .46 .878 r
F
.24978 .89126 m .2232 .77659 L .23886 .89475 L .683 .047 .584 r
F
.24978 .89126 m .23461 .77868 L .2232 .77659 L F
.71252 .9964 m .69252 .93974 L .72205 1.00497 L 1 0 .151 r
F
.71252 .9964 m .68447 .93458 L .69252 .93974 L F
.61487 .69965 m .61747 .70955 L .62602 .70087 L .856 .755 .849 r
F
.61487 .69965 m .60719 .70753 L .61747 .70955 L F
.54172 .87744 m .52029 .89336 L .54385 .88502 L 1 .737 .771 r
F
.56309 .86484 m .54172 .87744 L .54385 .88502 L 1 .909 .777 r
F
.47518 .68943 m .4598 .68971 L .46767 .69473 L .743 .496 .813 r
F
.48247 .6933 m .47518 .68943 L .46767 .69473 L .727 .48 .814 r
F
.27969 .5748 m .28352 .53241 L .27182 .51063 L .408 .002 .612 r
F
.28012 .4784 m .28283 .41192 L .26917 .44734 L .297 0 .546 r
F
.40564 .90737 m .38506 .92919 L .38221 .93258 L .562 0 .463 r
F
.40561 .90739 m .38506 .92919 L .40564 .90737 L F
.40579 .90715 m .38506 .92919 L .40691 .906 L F
.40691 .906 m .40561 .90739 L .40564 .90737 L F
.41046 .90218 m .40579 .90715 L .40691 .906 L F
.41635 .89958 m .38506 .92919 L .41046 .90218 L .724 .001 .62 r
F
.4131 .90265 m .39255 .92025 L .38506 .92919 L F
.41635 .89958 m .41224 .90315 L .4131 .90265 L F
.41224 .90315 m .39255 .92025 L .4131 .90265 L F
.42228 .89603 m .39462 .91857 L .41635 .89958 L .852 .271 .728 r
F
.39462 .91857 m .39535 .91782 L .41635 .89958 L F
.42677 .89271 m .40271 .90864 L .42284 .89565 L 1 .635 .77 r
F
.40271 .90864 m .40078 .90993 L .40312 .90841 L F
.40271 .90864 m .40312 .90841 L .42284 .89565 L F
.39255 .92025 m .38805 .92563 L .38506 .92919 L 1 .425 .647 r
F
.37005 .94547 m .33423 1.00103 L .36255 .95288 L 0 0 0 r
F
.36551 .95251 m .34337 .98726 L .33862 .99422 L F
.36569 .9523 m .34337 .98726 L .36551 .95251 L F
.37759 .93756 m .34337 .98726 L .37005 .94547 L .713 0 .444 r
F
.36159 .95721 m .35749 .96405 L .35253 .97262 L .965 .12 .534 r
F
.34774 .98091 m .35253 .97262 L .34337 .98726 L .713 0 .444 r
F
.35253 .97262 m .35253 .97262 L .34774 .98091 L F
.35253 .97262 m .34835 .97996 L .34337 .98726 L .782 0 .42 r
F
.37759 .93756 m .35253 .97262 L .34774 .98091 L .713 0 .444 r
F
.34835 .97996 m .33715 .99959 L .34337 .98726 L .782 0 .42 r
F
.33268 1.05656 m .32207 1.03062 L .32351 1.06893 L .696 .057 .592 r
F
.32207 1.03062 m .32094 1.02787 L .32123 1.03235 L F
.32207 1.03062 m .32123 1.03235 L .32351 1.06893 L F
.33671 .99932 m .33245 1.00703 L .32951 1.01237 L 0 0 0 r
F
.33671 .99932 m .32951 1.01237 L .32901 1.01327 L F
.33726 .99832 m .33245 1.00703 L .33671 .99932 L F
.33715 .99959 m .33595 1.00148 L .34337 .98726 L .782 0 .42 r
F
.33595 1.00148 m .33245 1.00703 L .33301 1.00602 L F
.33595 1.00148 m .33301 1.00602 L .34337 .98726 L F
.34337 .98726 m .33726 .99832 L .33671 .99932 L 0 0 0 r
F
.35749 .96405 m .34419 .98623 L .35253 .97262 L .965 .12 .534 r
F
.34419 .98623 m .34293 .98832 L .34375 .98698 L F
.34419 .98623 m .34375 .98698 L .35253 .97262 L F
.34763 .96663 m .31603 1.02676 L .30695 1.03906 L 0 0 0 r
F
.35507 .9599 m .31603 1.02676 L .34763 .96663 L F
.35507 .9599 m .32512 1.01414 L .31603 1.02676 L F
.36255 .95288 m .32512 1.01414 L .35507 .9599 L F
.36255 .95288 m .33423 1.00103 L .32512 1.01414 L F
.37066 .94088 m .34799 .97537 L .36159 .95721 L 1 .593 .594 r
F
.34799 .97537 m .34665 .97816 L .36159 .95721 L F
.33862 .99422 m .34337 .98726 L .33423 1.00103 L 0 0 0 r
F
.32094 1.02787 m .32045 1.02666 L .32059 1.02851 L .696 .057 .592 r
F
.32094 1.02787 m .32059 1.02851 L .32351 1.06893 L F
.32045 1.02666 m .32034 1.02682 L .32035 1.02684 L F
.32045 1.02666 m .32035 1.02684 L .32351 1.06893 L F
.32045 1.02666 m .31488 1.03462 L .31498 1.03443 L 0 0 0 r
F
.34182 1.04544 m .32898 1.0146 L .33268 1.05656 L .671 .051 .594 r
F
.32047 1.02662 m .31507 1.03425 L .32512 1.01414 L 0 0 0 r
F
.32208 1.02386 m .32377 1.02111 L .32182 1.02435 L F
.33423 1.00103 m .32394 1.02077 L .32208 1.02386 L F
.32394 1.02077 m .32377 1.02111 L .32208 1.02386 L F
.33423 1.00103 m .32169 1.0246 L .3205 1.02658 L F
.35989 1.02858 m .34412 .99132 L .35094 1.03594 L .558 .025 .602 r
F
.34337 .98726 m .32939 1.01258 L .33423 1.00103 L 0 0 0 r
F
.34072 .99211 m .33128 .961 L .33984 .99362 L .558 .025 .602 r
F
.34235 .98715 m .33128 .961 L .34072 .99211 L F
.32939 1.01258 m .32903 1.0131 L .33423 1.00103 L 0 0 0 r
F
.32877 1.0137 m .32394 1.02077 L .33423 1.00103 L F
.33423 1.00103 m .32045 1.02666 L .32512 1.01414 L F
.33607 1.0007 m .32115 .96531 L .33201 1.00742 L .63 .041 .597 r
F
.34235 .98715 m .34121 .95968 L .33128 .961 L .558 .025 .602 r
F
.34288 .98841 m .34274 .98595 L .34235 .98715 L F
.34274 .98595 m .34121 .95968 L .34235 .98715 L F
.34799 .97537 m .34695 .97296 L .34634 .97859 L .429 .004 .612 r
F
.34695 .97296 m .34121 .95968 L .34579 .97656 L F
.34695 .97296 m .34579 .97656 L .34634 .97859 L F
.35746 .94123 m .35615 .94456 L .35328 .95392 L 1 .326 .503 r
F
.37066 .94088 m .35114 .95988 L .35104 .96013 L 1 .593 .594 r
F
.35069 .9618 m .35104 .96013 L .35017 .96235 L F
.37066 .94088 m .35104 .96013 L .35069 .9618 L F
.37066 .94088 m .35017 .96235 L .35007 .96276 L F
.37066 .94088 m .34995 .96288 L .34799 .97537 L F
.36183 .93014 m .35746 .94123 L .35328 .95392 L 1 .326 .503 r
F
.36159 .95721 m .34665 .97816 L .34419 .98623 L .965 .12 .534 r
F
.37613 .93961 m .35253 .97262 L .37759 .93756 L .713 0 .444 r
F
.38221 .93258 m .38506 .92919 L .37759 .93755 L .562 0 .463 r
F
.38506 .92919 m .35253 .97262 L .37759 .93755 L .857 .038 .566 r
F
.35253 .97262 m .35507 .96906 L .37496 .94124 L F
.37496 .94124 m .37496 .94124 L .37759 .93755 L F
.35253 .97262 m .37496 .94124 L .37496 .94124 L F
.35253 .97262 m .35253 .97262 L .35507 .96906 L F
.38506 .92919 m .36159 .95721 L .35253 .97262 L F
.38805 .92563 m .36884 .94855 L .38506 .92919 L 1 .425 .647 r
F
.3552 .94696 m .34839 .8669 L .33761 .86316 L .565 .007 .549 r
F
.35615 .94456 m .3552 .94696 L .3525 .95583 L 1 .326 .503 r
F
.35615 .94456 m .3525 .95583 L .35328 .95392 L F
.37688 .92939 m .35114 .95988 L .37066 .94088 L 1 .692 .603 r
F
.37974 .9241 m .37327 .93219 L .37688 .92939 L F
.37327 .93219 m .35114 .95988 L .37688 .92939 L F
.37327 .93219 m .36183 .93014 L .35114 .95988 L F
.37974 .9241 m .36335 .92963 L .37327 .93219 L F
.36335 .92963 m .36183 .93014 L .37327 .93219 L F
.35497 .94769 m .35443 .94328 L .35227 .95607 L .565 .007 .549 r
F
.3552 .94696 m .35322 .95311 L .3525 .95583 L 1 .326 .503 r
F
.35749 .96405 m .35253 .97262 L .35253 .97262 L .965 .12 .534 r
F
.3552 .94696 m .35443 .94328 L .35773 .97035 L .565 .007 .549 r
F
.3552 .94696 m .35365 .9515 L .35322 .95311 L 1 .326 .503 r
F
.35773 .97035 m .35497 .94769 L .35106 .96329 L .565 .007 .549 r
F
.35328 .95392 m .35256 .95567 L .35172 .95828 L 1 .326 .503 r
F
.35256 .95567 m .35182 .95749 L .35172 .95828 L F
.35443 .94328 m .35064 .96021 L .35073 .96086 L .565 .007 .549 r
F
.35443 .94328 m .35073 .96086 L .35227 .95607 L F
.34695 .97296 m .34984 .9636 L .3497 .96354 L .429 .004 .612 r
F
.34651 .97194 m .3497 .96354 L .34121 .95968 L F
.34695 .97296 m .3497 .96354 L .34651 .97194 L F
.34973 .96355 m .34995 .96288 L .34121 .95968 L F
.34984 .9636 m .34994 .96299 L .34973 .96355 L F
.34994 .96299 m .34995 .96288 L .34973 .96355 L F
.34419 .98623 m .34365 .98631 L .34288 .98841 L .965 .12 .534 r
F
.34333 .98764 m .34329 .98723 L .34288 .98841 L .558 .025 .602 r
F
.34329 .98723 m .34121 .95968 L .34288 .98841 L F
.34365 .98631 m .34362 .98632 L .34288 .98841 L .965 .12 .534 r
F
.34288 .98841 m .34235 .98715 L .34072 .99211 L .558 .025 .602 r
F
.34665 .97816 m .34634 .97859 L .34419 .98623 L .965 .12 .534 r
F
.34293 .98832 m .34291 .98836 L .35253 .97262 L F
.34288 .98841 m .34225 .98949 L .35253 .97262 L F
.34225 .98949 m .34012 .99315 L .35253 .97262 L F
.34112 .99135 m .34019 .99302 L .34225 .98949 L F
.34019 .99302 m .34012 .99315 L .34225 .98949 L F
.35253 .97262 m .3409 .99186 L .33715 .99959 L .782 0 .42 r
F
.34765 .98343 m .34706 .98124 L .34349 .98985 L .558 .025 .602 r
F
.34706 .98124 m .34634 .97859 L .3446 .98545 L F
.34706 .98124 m .3446 .98545 L .34349 .98985 L F
.34634 .97859 m .34121 .95968 L .34329 .98723 L F
.34634 .97859 m .34362 .98632 L .34419 .98623 L .965 .12 .534 r
F
.34634 .97859 m .34329 .98723 L .34349 .98985 L .558 .025 .602 r
F
.34634 .97859 m .34048 .9868 L .34362 .98632 L .965 .12 .534 r
F
.34362 .98632 m .34048 .9868 L .34288 .98841 L F
.34995 .96288 m .34636 .97169 L .34048 .9868 L .723 0 .282 r
F
.33201 1.00742 m .32115 .96531 L .32845 1.01334 L .671 .051 .594 r
F
.33602 1.00058 m .33128 .961 L .32115 .96531 L .63 .041 .597 r
F
.3409 .99186 m .33984 .99362 L .33715 .99959 L .782 0 .42 r
F
.33968 .99394 m .33984 .99362 L .33602 1.00058 L .63 .041 .597 r
F
.33984 .99362 m .33984 .99362 L .33968 .99394 L F
.33984 .99362 m .33128 .961 L .33598 1.00022 L F
.33984 .99362 m .33598 1.00022 L .33602 1.00058 L F
.34636 .97169 m .3392 .98926 L .34048 .9868 L .723 0 .282 r
F
.33435 1.00269 m .32988 1.0101 L .33365 1.00464 L .782 0 .42 r
F
.33426 1.00279 m .34048 .9868 L .32988 1.01009 L .965 .12 .534 r
F
.34048 .9868 m .336 .99705 L .32988 1.01009 L 0 0 0 r
F
.34112 .99135 m .33545 1.0008 L .33984 .99362 L .965 .12 .534 r
F
.35114 .95988 m .35056 .96131 L .34995 .96288 L .723 0 .282 r
F
.35056 .96131 m .32667 .86666 L .34997 .96289 L .68 .031 .56 r
F
.35056 .96131 m .35042 .96164 L .34995 .96288 L .723 0 .282 r
F
.34995 .96288 m .32667 .86666 L .34121 .95968 L .68 .031 .56 r
F
.34997 .96289 m .34996 .96286 L .34995 .96288 L F
.34996 .96286 m .32667 .86666 L .34995 .96288 L F
.35007 .96276 m .35017 .96235 L .34995 .96288 L 1 .593 .594 r
F
.35106 .96329 m .35056 .96131 L .34997 .96289 L .68 .031 .56 r
F
.35056 .96131 m .33761 .86316 L .32667 .86666 L F
.35106 .96329 m .35073 .96086 L .35056 .96131 L F
.35073 .96086 m .33761 .86316 L .35056 .96131 L F
.35114 .95988 m .35073 .96086 L .35062 .96116 L .723 0 .282 r
F
.35208 .95721 m .35073 .96086 L .35106 .96329 L .565 .007 .549 r
F
.35182 .95749 m .35103 .95992 L .35172 .95828 L 1 .326 .503 r
F
.35172 .95828 m .34003 .98634 L .35114 .95988 L F
.34003 .98634 m .33374 1.00144 L .33984 .98687 L F
.34003 .98634 m .33984 .98687 L .35114 .95988 L F
.33426 1.00279 m .32988 1.01009 L .33435 1.00269 L .965 .12 .534 r
F
.32939 1.01258 m .32877 1.0137 L .32903 1.0131 L 0 0 0 r
F
.32877 1.0137 m .32867 1.01387 L .32394 1.02077 L F
.32898 1.0146 m .32867 1.01387 L .32577 1.01913 L .671 .051 .594 r
F
.32094 1.02787 m .32384 1.02186 L .32045 1.02666 L .696 .057 .592 r
F
.33268 1.05656 m .32397 1.02238 L .32094 1.02787 L F
.32397 1.02238 m .32384 1.02186 L .32094 1.02787 L F
.33245 1.00703 m .33224 1.00742 L .32894 1.01339 L 0 0 0 r
F
.34182 1.04544 m .3323 1.00853 L .32867 1.01387 L .671 .051 .594 r
F
.33715 .99959 m .33626 1.00114 L .33245 1.00703 L .782 0 .42 r
F
.33615 1.00131 m .33478 1.00346 L .34182 1.04544 L .63 .041 .597 r
F
.33626 1.00114 m .33208 1.0077 L .33245 1.00703 L .782 0 .42 r
F
.3347 1.00296 m .33208 1.0077 L .34182 1.04544 L .63 .041 .597 r
F
.33224 1.00742 m .33208 1.0077 L .32918 1.01297 L 0 0 0 r
F
.33224 1.00742 m .32883 1.01359 L .32894 1.01339 L F
.32894 1.01339 m .32879 1.01367 L .32867 1.01387 L F
.32901 1.01327 m .32951 1.01237 L .32894 1.01339 L F
.3323 1.00853 m .33201 1.00742 L .32867 1.01387 L .671 .051 .594 r
F
.32898 1.0146 m .32577 1.01913 L .33268 1.05656 L F
.32577 1.01913 m .32384 1.02186 L .32397 1.02238 L F
.32577 1.01913 m .32397 1.02238 L .33268 1.05656 L F
.32918 1.01297 m .32913 1.01305 L .32883 1.01359 L 0 0 0 r
F
.32045 1.02666 m .31498 1.03443 L .31507 1.03425 L F
.32045 1.02666 m .31507 1.03425 L .32047 1.02662 L F
.32031 1.0263 m .31494 1.03482 L .31561 1.03752 L .696 .057 .592 r
F
.32049 1.0287 m .31561 1.03752 L .32351 1.06893 L F
.32031 1.0263 m .31561 1.03752 L .32049 1.0287 L F
.32913 1.01305 m .31917 1.0311 L .32879 1.01367 L 0 0 0 r
F
.32913 1.01305 m .32879 1.01367 L .32883 1.01359 L F
.33362 1.00529 m .31917 1.0311 L .33208 1.0077 L .782 0 .42 r
F
.3326 1.00755 m .31917 1.0311 L .33362 1.00529 L F
.33208 1.0077 m .31917 1.0311 L .32918 1.01297 L 0 0 0 r
F
.31727 1.03453 m .31917 1.0311 L .31634 1.03622 L F
.32334 1.02354 m .31917 1.0311 L .31727 1.03453 L F
.32867 1.01387 m .32371 1.02286 L .32334 1.02354 L F
.32371 1.02286 m .31917 1.0311 L .32334 1.02354 L F
.32879 1.01367 m .31917 1.0311 L .32867 1.01387 L F
.32577 1.01913 m .32867 1.01387 L .32384 1.02186 L .671 .051 .594 r
F
.32867 1.01387 m .32845 1.01334 L .32607 1.01774 L F
.32867 1.01387 m .32607 1.01774 L .32384 1.02186 L F
.32867 1.01387 m .32369 1.02126 L .32377 1.02111 L 0 0 0 r
F
.32867 1.01387 m .32377 1.02111 L .32394 1.02077 L F
.32845 1.01334 m .32369 1.02126 L .32384 1.02186 L .671 .051 .594 r
F
.32182 1.02435 m .32375 1.02115 L .32169 1.0246 L 0 0 0 r
F
.32377 1.02111 m .32375 1.02115 L .32182 1.02435 L F
.3205 1.02658 m .32169 1.0246 L .32045 1.02666 L F
.32384 1.02186 m .32369 1.02126 L .32045 1.02666 L .696 .057 .592 r
F
.32375 1.02115 m .32369 1.02126 L .32045 1.02666 L 0 0 0 r
F
.32351 1.06893 m .31178 1.03956 L .31432 1.08229 L .712 .06 .591 r
F
.31178 1.03956 m .31177 1.03958 L .31177 1.03958 L 0 0 0 r
F
.31178 1.03956 m .31177 1.03958 L .31603 1.02676 L F
.31178 1.03956 m .30581 1.04791 L .30602 1.04878 L .712 .06 .591 r
F
.31178 1.03956 m .30602 1.04878 L .31432 1.08229 L F
.29789 1.05113 m .28438 1.07866 L .28884 1.06308 L 0 0 0 r
F
.28526 1.08213 m .28674 1.07562 L .28415 1.07912 L .733 .064 .586 r
F
.28674 1.07562 m .2869 1.07496 L .28415 1.07912 L F
.29789 1.05113 m .28729 1.07426 L .28438 1.07866 L 0 0 0 r
F
.28729 1.07426 m .28713 1.0746 L .28438 1.07866 L F
.28713 1.0746 m .2869 1.07496 L .28526 1.08213 L .733 .064 .586 r
F
.29589 1.11118 m .28476 1.08077 L .28665 1.12645 L F
.28476 1.08077 m .28442 1.07985 L .28448 1.0812 L F
.28476 1.08077 m .28448 1.0812 L .28665 1.12645 L F
.28442 1.07985 m .28421 1.08017 L .28665 1.12645 L F
.28415 1.07912 m .27763 1.08808 L .28665 1.12645 L F
.30512 1.09643 m .29702 1.06321 L .29701 1.06323 L .729 .063 .588 r
F
.29425 1.06765 m .29672 1.06206 L .29384 1.06655 L F
.30512 1.09643 m .29701 1.06323 L .29425 1.06765 L F
.29701 1.06323 m .29672 1.06206 L .29425 1.06765 L F
.31177 1.03959 m .31175 1.03963 L .31176 1.0396 L 0 0 0 r
F
.31432 1.08229 m .30278 1.0526 L .30512 1.09643 L .722 .063 .589 r
F
.30695 1.03906 m .29679 1.06069 L .29421 1.06468 L 0 0 0 r
F
.29376 1.06537 m .29421 1.06468 L .29373 1.06542 L F
.30695 1.03906 m .29421 1.06468 L .29376 1.06537 L F
.29674 1.06204 m .29663 1.06161 L .29369 1.06615 L .729 .063 .588 r
F
.30695 1.03906 m .29355 1.06579 L .29789 1.05113 L 0 0 0 r
F
.29355 1.06579 m .29351 1.06583 L .29789 1.05113 L F
.30633 1.04683 m .30607 1.04737 L .30328 1.05162 L F
.30512 1.09643 m .29384 1.06655 L .29589 1.11118 L .729 .063 .588 r
F
.29384 1.06655 m .29361 1.06692 L .29589 1.11118 L F
.29355 1.06579 m .28713 1.0746 L .28732 1.0754 L F
.29355 1.06579 m .28732 1.0754 L .29589 1.11118 L F
.28791 1.07787 m .28732 1.0754 L .28526 1.08213 L .733 .064 .586 r
F
.28732 1.0754 m .28713 1.0746 L .28669 1.07636 L F
.28732 1.0754 m .28669 1.07636 L .28526 1.08213 L F
.29589 1.11118 m .28791 1.07787 L .28526 1.08213 L F
.29341 1.06607 m .27648 1.10389 L .26581 1.1211 L 0 0 0 r
F
.29355 1.06579 m .29345 1.066 L .29341 1.06607 L F
.29345 1.066 m .27648 1.10389 L .29341 1.06607 L F
.29373 1.06542 m .29361 1.06569 L .29355 1.06579 L F
.29663 1.06161 m .29654 1.06122 L .2936 1.06571 L .729 .063 .588 r
F
.29351 1.06583 m .28729 1.07426 L .29789 1.05113 L 0 0 0 r
F
.29654 1.06122 m .2936 1.0657 L .2936 1.06571 L .729 .063 .588 r
F
.29384 1.06655 m .29355 1.06579 L .29361 1.06692 L F
.29369 1.06615 m .2936 1.06571 L .29355 1.06579 L F
.29663 1.06161 m .2936 1.06571 L .29369 1.06615 L F
.29679 1.06069 m .29654 1.06122 L .29373 1.06542 L 0 0 0 r
F
.29384 1.06655 m .29672 1.06206 L .29369 1.06615 L .729 .063 .588 r
F
.29654 1.06122 m .27648 1.10389 L .29358 1.06577 L 0 0 0 r
F
.29654 1.06122 m .29358 1.06577 L .29373 1.06542 L F
.31603 1.02676 m .30278 1.0526 L .30695 1.03906 L F
.30278 1.0526 m .29875 1.05816 L .29663 1.06161 L .722 .063 .589 r
F
.30278 1.0526 m .29654 1.06122 L .29667 1.06093 L 0 0 0 r
F
.30278 1.0526 m .29667 1.06093 L .30695 1.03906 L F
.31603 1.02676 m .30633 1.04683 L .30328 1.05162 L F
.30278 1.0526 m .30565 1.04726 L .30254 1.05199 L .722 .063 .589 r
F
.31175 1.03963 m .31174 1.03964 L .31174 1.03964 L 0 0 0 r
F
.31432 1.08229 m .30602 1.04878 L .3031 1.05344 L .722 .063 .589 r
F
.30278 1.0526 m .29674 1.06204 L .30512 1.09643 L F
.31174 1.03964 m .29781 1.06878 L .31174 1.03965 L 0 0 0 r
F
.31174 1.03964 m .31174 1.03965 L .31174 1.03964 L F
.3031 1.05344 m .30591 1.04833 L .30278 1.0526 L .722 .063 .589 r
F
.30602 1.04878 m .30591 1.04833 L .3031 1.05344 L F
.30607 1.04737 m .30581 1.04791 L .30309 1.05205 L 0 0 0 r
F
.30591 1.04833 m .30581 1.04791 L .30278 1.0526 L .722 .063 .589 r
F
.30581 1.04791 m .28715 1.08651 L .30295 1.05233 L 0 0 0 r
F
.30581 1.04791 m .30295 1.05233 L .30309 1.05205 L F
.30607 1.04737 m .30309 1.05205 L .30328 1.05162 L F
.30328 1.05162 m .30296 1.05232 L .30278 1.0526 L F
.30581 1.04791 m .30565 1.04726 L .30278 1.0526 L .722 .063 .589 r
F
.30254 1.05199 m .29654 1.06122 L .29663 1.06161 L F
.29963 1.05751 m .29663 1.06161 L .29674 1.06204 L F
.30278 1.0526 m .29663 1.06161 L .29963 1.05751 L F
.29701 1.06323 m .29674 1.06204 L .29672 1.06206 L .729 .063 .588 r
F
.29702 1.06321 m .29674 1.06204 L .29701 1.06323 L F
.30278 1.0526 m .27648 1.10389 L .29654 1.06122 L 0 0 0 r
F
.30278 1.0526 m .30254 1.05199 L .29875 1.05816 L .722 .063 .589 r
F
.30254 1.05199 m .28044 .99514 L .29654 1.06122 L F
.29654 1.06122 m .28044 .99514 L .2936 1.0657 L .729 .063 .588 r
F
.29361 1.06569 m .29361 1.06569 L .29355 1.06579 L 0 0 0 r
F
.29361 1.06569 m .27648 1.10389 L .29355 1.06579 L F
.29223 1.0676 m .28717 1.07453 L .28729 1.07426 L F
.29008 1.07056 m .28717 1.07453 L .29223 1.0676 L F
.2935 1.06589 m .28729 1.07426 L .29351 1.06583 L F
.28438 1.07866 m .28423 1.07886 L .28884 1.06308 L F
.28415 1.07912 m .2778 1.08771 L .28884 1.06308 L F
.29355 1.06579 m .27025 1.00406 L .28713 1.0746 L .729 .063 .588 r
F
.2935 1.06589 m .29008 1.07056 L .29223 1.0676 L 0 0 0 r
F
.29355 1.06579 m .29346 1.06493 L .29331 1.06515 L .729 .063 .588 r
F
.2936 1.06571 m .29346 1.06493 L .29355 1.06579 L F
.29355 1.06579 m .2935 1.06589 L .29351 1.06583 L 0 0 0 r
F
.2935 1.06589 m .26581 1.1211 L .28717 1.07453 L F
.30254 1.05199 m .29063 .98662 L .28044 .99514 L .722 .063 .589 r
F
.30565 1.04726 m .29063 .98662 L .30254 1.05199 L F
.30278 1.0526 m .30289 1.05248 L .30267 1.05281 L 0 0 0 r
F
.30296 1.05232 m .30289 1.05248 L .30278 1.0526 L F
.31175 1.03963 m .31174 1.03964 L .31176 1.0396 L F
.31173 1.03966 m .29781 1.06878 L .28715 1.08651 L F
.31176 1.0396 m .31174 1.03964 L .31173 1.03966 L F
.31174 1.03964 m .29781 1.06878 L .31173 1.03966 L F
.30267 1.05281 m .28715 1.08651 L .27648 1.10389 L F
.30289 1.05248 m .28715 1.08651 L .30267 1.05281 L F
.28442 1.07985 m .28415 1.07912 L .28421 1.08017 L .733 .064 .586 r
F
.28415 1.07912 m .27763 1.08808 L .2778 1.08771 L 0 0 0 r
F
.28415 1.07912 m .26005 1.01328 L .27763 1.08808 L .733 .064 .586 r
F
.28415 1.07912 m .25513 1.13826 L .27763 1.08808 L 0 0 0 r
F
.28713 1.0746 m .26581 1.1211 L .28423 1.07901 L F
.28713 1.0746 m .28423 1.07901 L .28438 1.07866 L F
.28713 1.0746 m .28705 1.07427 L .2869 1.07496 L .733 .064 .586 r
F
.2869 1.07496 m .28705 1.07427 L .28415 1.07912 L F
.28415 1.07912 m .26581 1.1211 L .25513 1.13826 L 0 0 0 r
F
.28438 1.07866 m .28423 1.07901 L .28415 1.07912 L F
.28423 1.07901 m .26581 1.1211 L .28415 1.07912 L F
.29331 1.06515 m .28044 .99514 L .27025 1.00406 L .729 .063 .588 r
F
.29346 1.06493 m .28044 .99514 L .29331 1.06515 L F
.28438 1.07866 m .28415 1.07912 L .28423 1.07886 L 0 0 0 r
F
.28415 1.07912 m .28705 1.07427 L .28396 1.0786 L .733 .064 .586 r
F
.31178 1.03956 m .31177 1.03959 L .31176 1.0396 L 0 0 0 r
F
.32369 1.02126 m .32357 1.02081 L .32045 1.02666 L .696 .057 .592 r
F
.31213 1.0389 m .31498 1.03443 L .31197 1.0392 L 0 0 0 r
F
.32512 1.01414 m .31507 1.03425 L .31213 1.0389 L F
.31507 1.03425 m .31498 1.03443 L .31213 1.0389 L F
.32845 1.01334 m .32839 1.01319 L .32369 1.02126 L .671 .051 .594 r
F
.32512 1.01414 m .31178 1.03956 L .31603 1.02676 L 0 0 0 r
F
.32839 1.01319 m .31099 .97142 L .32357 1.02081 L .671 .051 .594 r
F
.32839 1.01319 m .32357 1.02081 L .32369 1.02126 L F
.32357 1.02081 m .31099 .97142 L .32033 1.02595 L .696 .057 .592 r
F
.32357 1.02081 m .32033 1.02595 L .32045 1.02666 L F
.32031 1.0263 m .32023 1.02611 L .31494 1.03482 L F
.31197 1.0392 m .31495 1.03449 L .31188 1.0394 L 0 0 0 r
F
.31498 1.03443 m .31495 1.03449 L .31197 1.0392 L F
.32351 1.06893 m .31501 1.0351 L .31178 1.03956 L .712 .06 .591 r
F
.31495 1.03449 m .31488 1.03462 L .31178 1.03956 L 0 0 0 r
F
.31501 1.0351 m .31488 1.03462 L .31178 1.03956 L .712 .06 .591 r
F
.31488 1.03462 m .29781 1.06878 L .31178 1.03956 L 0 0 0 r
F
.31178 1.03956 m .31188 1.0394 L .31178 1.03956 L F
.31197 1.0392 m .31188 1.0394 L .31178 1.03956 L F
.31176 1.0396 m .30574 1.04805 L .30592 1.04767 L F
.31177 1.03958 m .30592 1.04767 L .31603 1.02676 L F
.31176 1.0396 m .30592 1.04767 L .31177 1.03958 L F
.31488 1.03462 m .30081 .97864 L .31178 1.03956 L .712 .06 .591 r
F
.32023 1.02611 m .30081 .97864 L .31488 1.03462 L .696 .057 .592 r
F
.32023 1.02611 m .31488 1.03462 L .31494 1.03482 L F
.31178 1.03956 m .30081 .97864 L .29063 .98662 L .712 .06 .591 r
F
.31178 1.03956 m .29063 .98662 L .30581 1.04791 L F
.31178 1.03956 m .31176 1.0396 L .31177 1.03958 L 0 0 0 r
F
.31176 1.0396 m .28715 1.08651 L .30574 1.04805 L F
.28396 1.0786 m .27025 1.00406 L .26005 1.01328 L .733 .064 .586 r
F
.28705 1.07427 m .27025 1.00406 L .28396 1.0786 L F
.32369 1.02126 m .30848 1.05045 L .32045 1.02666 L 0 0 0 r
F
.32867 1.01387 m .30848 1.05045 L .32369 1.02126 L F
.32867 1.01387 m .33201 1.00742 L .32845 1.01334 L .671 .051 .594 r
F
.32845 1.01334 m .32115 .96531 L .31099 .97142 L F
.3326 1.00755 m .32988 1.0101 L .31917 1.0311 L .782 0 .42 r
F
.32988 1.0101 m .32539 1.01984 L .31917 1.0311 L 0 0 0 r
F
.32539 1.01984 m .29786 1.07959 L .31917 1.0311 L F
.33626 1.00114 m .3326 1.00755 L .33362 1.00529 L .782 0 .42 r
F
.33626 1.00114 m .33353 1.00497 L .3326 1.00755 L F
.3347 1.00296 m .33201 1.00742 L .33208 1.0077 L .63 .041 .597 r
F
.33353 1.00497 m .32988 1.0101 L .3326 1.00755 L .782 0 .42 r
F
.32867 1.01387 m .31634 1.03622 L .3126 1.043 L 0 0 0 r
F
.33607 1.0007 m .33478 1.00346 L .33615 1.00131 L .63 .041 .597 r
F
.33626 1.00114 m .33607 1.0007 L .33615 1.00136 L F
.33668 1.00026 m .33667 1.00027 L .33626 1.00114 L .782 0 .42 r
F
.33667 1.00027 m .32988 1.0101 L .33626 1.00114 L F
.33984 .99362 m .33667 1.00027 L .33715 .99959 L F
.35093 1.03594 m .33984 .99365 L .33968 .99394 L .63 .041 .597 r
F
.33626 1.00114 m .33968 .99394 L .33602 1.00058 L F
.33715 .99959 m .33668 1.00026 L .33626 1.00114 L .782 0 .42 r
F
.35093 1.03594 m .33968 .99394 L .33626 1.00114 L .63 .041 .597 r
F
.34048 .9868 m .33102 1.00965 L .32846 1.01428 L 0 0 0 r
F
.33102 1.00965 m .32175 1.03203 L .32846 1.01428 L F
.336 .99705 m .32846 1.01428 L .32988 1.0101 L F
.32846 1.01428 m .32679 1.0173 L .32988 1.0101 L F
.336 .99705 m .32988 1.0101 L .32988 1.01009 L F
.35443 .94328 m .33761 .86316 L .35064 .96021 L .565 .007 .549 r
F
.34121 .95968 m .31575 .87015 L .33128 .961 L .691 .04 .57 r
F
.34121 .95968 m .32667 .86666 L .31575 .87015 L F
.3552 .94696 m .34787 .87904 L .33374 1.00144 L 1 .326 .503 r
F
.32988 1.0101 m .30988 1.05677 L .29786 1.07959 L 0 0 0 r
F
.34688 .89617 m .32813 1.01481 L .33374 1.00145 L .636 0 .44 r
F
.33896 .98992 m .3232 1.0285 L .3374 .99424 L .723 0 .282 r
F
.33847 .99105 m .3232 1.0285 L .33896 .98992 L F
.3232 1.0285 m .32348 1.02787 L .3374 .99424 L F
.32846 1.01428 m .30988 1.05676 L .32679 1.0173 L 0 0 0 r
F
.32846 1.01428 m .32175 1.03203 L .30988 1.05676 L F
.33383 1.00239 m .33323 1.00385 L .33379 1.00249 L .723 0 .282 r
F
.33323 1.00385 m .32175 1.03203 L .33326 1.00382 L F
.33323 1.00385 m .33326 1.00382 L .34995 .96288 L F
.33323 1.00385 m .33228 1.00515 L .32175 1.03203 L F
.347 .97006 m .33228 1.00515 L .33323 1.00385 L F
.3232 1.0285 m .32175 1.03203 L .32348 1.02787 L F
.347 .97006 m .33374 1.00144 L .33228 1.00515 L F
.33374 1.00145 m .30995 1.07701 L .32175 1.03204 L .424 0 .338 r
F
.30995 1.07701 m .3058 1.0902 L .30794 1.0824 L F
.30995 1.07701 m .30794 1.0824 L .32175 1.03204 L F
.33374 1.00145 m .3187 1.07553 L .3058 1.0902 L F
.35042 1.14711 m .32351 1.06893 L .31432 1.08229 L .762 .083 .597 r
F
.32593 1.02875 m .31852 1.07532 L .3187 1.07553 L .415 0 .399 r
F
.32593 1.02875 m .31839 1.07517 L .31852 1.07532 L F
.31982 1.06639 m .31871 1.07444 L .31839 1.07517 L F
.32593 1.02875 m .32194 1.05396 L .3218 1.05417 L F
.32062 1.06312 m .31872 1.07488 L .31873 1.07536 L .636 0 .44 r
F
.32593 1.02875 m .32058 1.06296 L .32062 1.06312 L F
.32058 1.06296 m .31872 1.07488 L .32062 1.06312 L F
.32809 1.0149 m .32593 1.02875 L .33356 1.00234 L F
.32593 1.02875 m .3187 1.07553 L .33356 1.00234 L F
.32809 1.0149 m .33356 1.00234 L .33374 1.00145 L F
.34765 .89488 m .32593 1.02875 L .32718 1.0431 L .415 0 .399 r
F
.35093 1.03594 m .33626 1.00114 L .34182 1.04544 L .63 .041 .597 r
F
.33626 1.00114 m .33615 1.00136 L .34182 1.04544 L F
.35838 1.12875 m .32351 1.06893 L .35042 1.14711 L .748 .082 .601 r
F
.35838 1.12875 m .33268 1.05656 L .32351 1.06893 L F
.36631 1.1116 m .33268 1.05656 L .35838 1.12875 L .728 .08 .607 r
F
.36631 1.1116 m .34182 1.04544 L .33268 1.05656 L F
.339 .99783 m .32718 1.0431 L .33126 1.09 L .415 0 .399 r
F
.3392 .98926 m .33847 .99105 L .33896 .98992 L .723 0 .282 r
F
.33607 1.0007 m .3347 1.00296 L .33478 1.00346 L .63 .041 .597 r
F
.35042 .96164 m .33383 1.00239 L .34995 .96288 L .723 0 .282 r
F
.33383 1.00239 m .33379 1.00249 L .34995 .96288 L F
.33545 1.0008 m .33426 1.00279 L .33572 1.00043 L .965 .12 .534 r
F
.33426 1.00279 m .33435 1.00269 L .33572 1.00043 L F
.33545 1.0008 m .33572 1.00043 L .33984 .99362 L F
.3392 .98926 m .3374 .99424 L .34048 .9868 L .723 0 .282 r
F
.33984 .99362 m .33435 1.00269 L .33667 1.00027 L .782 0 .42 r
F
.33435 1.00269 m .33365 1.00464 L .33667 1.00027 L F
.33545 1.0008 m .34048 .9868 L .33426 1.00279 L .965 .12 .534 r
F
.34288 .98841 m .34066 .98692 L .33545 1.0008 L F
.34066 .98692 m .34048 .9868 L .33545 1.0008 L F
.34786 .96775 m .33374 1.00144 L .347 .97006 L .723 0 .282 r
F
.35056 .96128 m .33984 .98687 L .35042 .96164 L F
.33984 .98687 m .33374 1.00144 L .33975 .9871 L F
.33984 .98687 m .33975 .9871 L .35042 .96164 L F
.35316 .95285 m .35166 .95661 L .35146 .95837 L 1 .326 .503 r
F
.35166 .95661 m .33374 1.00144 L .35137 .95857 L F
.35166 .95661 m .35137 .95857 L .35146 .95837 L F
.35416 .94962 m .34868 .96352 L .35316 .95285 L F
.34868 .96352 m .33374 1.00144 L .35316 .95285 L F
.35497 .94769 m .35227 .95607 L .35106 .96329 L .565 .007 .549 r
F
.36079 .97359 m .3552 .94696 L .35773 .97035 L F
.36079 .97359 m .35738 .94423 L .3552 .94696 L F
.3552 .94696 m .34812 .87687 L .34787 .87904 L 1 .326 .503 r
F
.36183 .93014 m .35072 .88694 L .3552 .94696 L F
.35072 .88694 m .34839 .8669 L .3552 .94696 L .565 .007 .549 r
F
.35072 .88694 m .34812 .87687 L .3552 .94696 L 1 .326 .503 r
F
.35706 .94151 m .35072 .88694 L .3552 .94696 L .565 .007 .549 r
F
.35738 .94423 m .35662 .94279 L .3552 .94696 L F
.3552 .94696 m .35416 .94962 L .35365 .9515 L 1 .326 .503 r
F
.35738 .94423 m .35706 .94151 L .35662 .94279 L .565 .007 .549 r
F
.3617 .97485 m .35626 .93556 L .36079 .97359 L 1 .26 .434 r
F
.35626 .93556 m .35598 .93685 L .36079 .97359 L F
.35416 .94962 m .35146 .95837 L .3525 .95583 L 1 .326 .503 r
F
.3617 .97485 m .35094 .94953 L .35749 .94444 L 1 .26 .434 r
F
.36811 .9841 m .35239 .95158 L .3617 .97485 L 1 .11 .346 r
F
.35011 .95798 m .34963 .94715 L .34987 .95865 L 1 .258 .427 r
F
.34963 .94715 m .34753 .89942 L .3494 .94678 L F
.34963 .94715 m .3494 .94678 L .34987 .95865 L F
.35239 .95158 m .35238 .95157 L .35224 .95261 L 1 .11 .346 r
F
.33984 .99365 m .33984 .99362 L .33968 .99394 L .63 .041 .597 r
F
.34029 .99285 m .33984 .99362 L .34012 .99315 L .965 .12 .534 r
F
.34112 .99135 m .33984 .99362 L .34029 .99285 L F
.35042 .96164 m .34786 .96775 L .347 .97006 L .723 0 .282 r
F
.35182 .95749 m .33374 1.00144 L .35103 .95992 L 1 .326 .503 r
F
.34799 .97537 m .35005 .96292 L .34695 .97296 L .429 .004 .612 r
F
.34799 .97537 m .34995 .96288 L .34048 .9868 L 1 .593 .594 r
F
.34984 .9636 m .35005 .96292 L .34995 .96288 L .429 .004 .612 r
F
.34799 .97537 m .35106 .96329 L .35005 .96292 L F
.34288 .98841 m .34222 .98955 L .34225 .98949 L .965 .12 .534 r
F
.34288 .98841 m .33984 .99362 L .34031 .99542 L .558 .025 .602 r
F
.34288 .98841 m .34112 .99135 L .34222 .98955 L .965 .12 .534 r
F
.34412 .99132 m .34288 .98841 L .34058 .99643 L .558 .025 .602 r
F
.34288 .98841 m .34031 .99542 L .34058 .99643 L F
.34412 .99132 m .34058 .99643 L .35094 1.03594 L F
.35322 .97062 m .35112 .96349 L .34905 .97782 L .429 .004 .612 r
F
.35112 .96349 m .35096 .96401 L .34905 .97782 L F
.34905 .97782 m .34799 .97537 L .34706 .98124 L F
.34799 .97537 m .34634 .97859 L .34665 .97816 L 1 .593 .594 r
F
.34799 .97537 m .34634 .97859 L .34706 .98124 L .429 .004 .612 r
F
.34799 .97537 m .34048 .9868 L .34634 .97859 L 1 .593 .594 r
F
.34905 .97782 m .34995 .97133 L .34799 .97537 L .429 .004 .612 r
F
.34995 .97133 m .35106 .96329 L .34799 .97537 L F
.3688 1.02356 m .35322 .97062 L .34905 .97782 L F
.3688 1.02356 m .34905 .97782 L .35989 1.02858 L F
.34905 .97782 m .34706 .98124 L .35989 1.02858 L F
.34293 .98832 m .34288 .98841 L .34291 .98836 L .965 .12 .534 r
F
.34349 .98985 m .34333 .98764 L .34288 .98841 L .558 .025 .602 r
F
.35989 1.02858 m .34765 .98343 L .34349 .98985 L F
.37421 1.09588 m .34182 1.04544 L .36631 1.1116 L .698 .077 .614 r
F
.37421 1.09588 m .35093 1.03594 L .34182 1.04544 L F
.38197 1.082 m .35094 1.03594 L .37421 1.09588 L .655 .071 .625 r
F
.38197 1.082 m .35989 1.02858 L .35094 1.03594 L F
.38755 1.18574 m .35838 1.12875 L .35042 1.14711 L .849 .127 .606 r
F
.3569 1.13669 m .34753 .89942 L .33126 1.09001 L 1 .19 .503 r
F
.35011 .95798 m .34987 .95865 L .34995 .96076 L 1 .258 .427 r
F
.35019 .96014 m .34995 .96076 L .3569 1.13669 L F
.35011 .95798 m .34995 .96076 L .35019 .96014 L F
.3579 1.13506 m .35024 .96086 L .3569 1.13669 L F
.35024 .96086 m .35011 .95798 L .35022 .96089 L F
.35024 .96086 m .35022 .96089 L .3569 1.13669 L F
.3579 1.13506 m .34611 .99323 L .34753 .89942 L F
.35094 .94953 m .34746 .94136 L .35749 .94444 L 1 .26 .434 r
F
.35238 .95157 m .34746 .9414 L .35051 .94857 L 1 .11 .346 r
F
.35238 .95157 m .35051 .94857 L .35224 .95261 L F
.35239 .95158 m .35224 .95261 L .3617 .97485 L F
.34018 .98375 m .32718 1.0431 L .339 .99783 L .415 0 .399 r
F
.34765 .89488 m .33302 1.00082 L .34018 .98375 L F
.33302 1.00082 m .32718 1.0431 L .34018 .98375 L F
.31873 1.07536 m .31871 1.07494 L .3187 1.07553 L .636 0 .44 r
F
.31872 1.07488 m .31871 1.07494 L .31873 1.07536 L F
.33442 1.18667 m .30512 1.09643 L .29589 1.11118 L .776 .082 .591 r
F
.34244 1.16647 m .30512 1.09643 L .33442 1.18667 L .77 .083 .594 r
F
.34244 1.16647 m .31432 1.08229 L .30512 1.09643 L F
.35042 1.14711 m .31432 1.08229 L .34244 1.16647 L .762 .083 .597 r
F
.31848 1.09878 m .3187 1.0762 L .30524 1.10788 L 1 .649 .592 r
F
.3187 1.0762 m .3187 1.07553 L .31799 1.07725 L F
.3187 1.0762 m .31799 1.07725 L .30524 1.10788 L F
.3187 1.07553 m .31693 1.07882 L .30524 1.10788 L F
.32638 1.20759 m .29589 1.11118 L .28665 1.12645 L .779 .081 .589 r
F
.33442 1.18667 m .29589 1.11118 L .32638 1.20759 L .776 .082 .591 r
F
.31693 1.07882 m .30263 1.09974 L .3058 1.0902 L .22 0 .143 r
F
.3187 1.07553 m .31693 1.07882 L .3058 1.0902 L .424 0 .338 r
F
.31917 1.0311 m .28583 1.10139 L .30848 1.05045 L 0 0 0 r
F
.31917 1.0311 m .29786 1.07959 L .28583 1.10139 L F
.30848 1.05045 m .28583 1.10139 L .27379 1.12274 L F
.32175 1.03204 m .2931 1.10756 L .30988 1.05677 L .231 0 .227 r
F
.32175 1.03204 m .3058 1.0902 L .2931 1.10756 L F
.30988 1.05678 m .2801 1.12756 L .29786 1.0796 L .041 0 .116 r
F
.30988 1.05678 m .2931 1.10757 L .2801 1.12756 L F
.29786 1.0796 m .26699 1.14896 L .28583 1.1014 L 0 0 .027 r
F
.29786 1.0796 m .2801 1.12756 L .26699 1.14896 L F
.32638 1.20759 m .28665 1.12645 L .31832 1.2291 L .779 .081 .589 r
F
.30524 1.10788 m .29834 1.10562 L .29202 1.13971 L 1 .675 .627 r
F
.3058 1.0902 m .29834 1.10562 L .2931 1.10756 L .097 0 .091 r
F
.29834 1.10562 m .29664 1.10834 L .2931 1.10756 L F
.29834 1.10562 m .28773 1.12254 L .29202 1.13971 L 1 .675 .627 r
F
.29699 1.10842 m .29487 1.11188 L .2931 1.10756 L .097 0 .091 r
F
.29201 1.13971 m .28772 1.12254 L .28122 1.13224 L 1 .585 .615 r
F
.29781 1.06878 m .26171 1.14393 L .28715 1.08651 L 0 0 0 r
F
.29781 1.06878 m .27379 1.12274 L .26171 1.14393 L F
.28715 1.08651 m .24959 1.16515 L .27648 1.10389 L F
.28715 1.08651 m .26171 1.14393 L .24959 1.16515 L F
.28583 1.1014 m .2538 1.17133 L .27378 1.12274 L F
.28583 1.1014 m .26699 1.14896 L .2538 1.17133 L F
.27378 1.12274 m .24052 1.19448 L .2617 1.14394 L F
.27378 1.12274 m .2538 1.17133 L .24052 1.19448 L F
.2931 1.10757 m .28118 1.13221 L .2801 1.12756 L 0 0 .02 r
F
.28118 1.13221 m .28021 1.13384 L .27855 1.17084 L 1 .585 .615 r
F
.28118 1.13221 m .27312 1.14564 L .2736 1.14439 L 0 0 .02 r
F
.28118 1.13221 m .2736 1.14439 L .2801 1.12756 L F
.30848 1.05045 m .27379 1.12274 L .29781 1.06878 L 0 0 0 r
F
.2801 1.12756 m .26647 1.1556 L .26699 1.14896 L F
.27855 1.17084 m .26544 1.15772 L .26503 1.20119 L 1 .53 .608 r
F
.26647 1.1556 m .26544 1.15772 L .25958 1.16713 L 0 0 0 r
F
.26544 1.15772 m .25876 1.16916 L .25958 1.16713 L F
.26647 1.1556 m .25958 1.16713 L .26699 1.14896 L F
.27648 1.10389 m .23743 1.1865 L .26581 1.1211 L F
.27648 1.10389 m .24959 1.16515 L .23743 1.1865 L F
.26581 1.1211 m .23743 1.1865 L .22523 1.20807 L F
.2617 1.14394 m .22716 1.21832 L .24959 1.16515 L F
.2617 1.14394 m .24052 1.19448 L .22716 1.21832 L F
.26699 1.14896 m .25108 1.18164 L .2538 1.17133 L F
.26503 1.20119 m .25044 1.18295 L .25144 1.23118 L 1 .495 .603 r
F
.24983 1.18402 m .24451 1.19332 L .24472 1.19283 L 0 0 0 r
F
.24984 1.18399 m .24472 1.19283 L .2538 1.17133 L F
.24983 1.18402 m .24472 1.19283 L .24984 1.18399 L F
.25108 1.18164 m .24967 1.18454 L .24998 1.18353 L F
.25108 1.18164 m .24998 1.18353 L .2538 1.17133 L F
.26581 1.1211 m .22523 1.20807 L .25513 1.13826 L F
.24959 1.16515 m .21371 1.2428 L .23743 1.18651 L F
.24959 1.16515 m .22716 1.21832 L .21371 1.2428 L F
.2538 1.17133 m .23626 1.20744 L .24052 1.19448 L F
.25144 1.23118 m .23581 1.20837 L .23777 1.26113 L 1 .472 .599 r
F
.23626 1.20744 m .23581 1.20837 L .23072 1.21723 L 0 0 0 r
F
.23581 1.20837 m .23031 1.21819 L .23072 1.21723 L F
.23626 1.20744 m .23072 1.21723 L .24052 1.19448 L F
.23743 1.18651 m .20016 1.26789 L .22522 1.20808 L F
.23743 1.18651 m .21371 1.2428 L .20016 1.26789 L F
.24052 1.19448 m .22172 1.23348 L .22716 1.21832 L F
.23777 1.26113 m .23031 1.21819 L .22137 1.23421 L 1 .456 .596 r
F
.23777 1.26113 m .22137 1.23421 L .22401 1.29125 L F
.22137 1.23421 m .22105 1.23478 L .22116 1.23448 L 0 0 0 r
F
.22172 1.23348 m .22116 1.23448 L .22716 1.21832 L F
.22137 1.23421 m .2161 1.24378 L .22401 1.29125 L 1 .456 .596 r
F
.24052 1.19448 m .23031 1.21819 L .22137 1.23421 L 0 0 0 r
F
.23029 1.2181 m .23024 1.21781 L .22137 1.23421 L 1 .456 .596 r
F
.22716 1.21832 m .2073 1.25995 L .21371 1.2428 L 0 0 0 r
F
.22106 1.23477 m .21622 1.24349 L .22716 1.21832 L F
.22401 1.29125 m .21611 1.24383 L .207 1.26057 L 1 .444 .594 r
F
.21611 1.24383 m .2161 1.24378 L .207 1.26057 L F
.22401 1.29125 m .207 1.26057 L .21015 1.32168 L F
.207 1.26057 m .20185 1.27009 L .20185 1.27012 L F
.207 1.26057 m .20185 1.27012 L .21015 1.32168 L F
.21371 1.2428 m .19291 1.28696 L .20016 1.26789 L 0 0 0 r
F
.22716 1.21832 m .21622 1.24349 L .2073 1.25995 L F
.2073 1.25995 m .2071 1.26032 L .21371 1.2428 L F
.207 1.26057 m .20196 1.26984 L .21371 1.2428 L F
.21015 1.32168 m .20188 1.27026 L .19265 1.28751 L 1 .435 .592 r
F
.20188 1.27026 m .20185 1.27009 L .19265 1.28751 L F
.21015 1.32168 m .19265 1.28751 L .19619 1.35254 L F
.19265 1.28751 m .18754 1.29711 L .18756 1.2972 L F
.19265 1.28751 m .18756 1.2972 L .19619 1.35254 L F
.19265 1.28751 m .18101 1.31224 L .18754 1.29711 L 0 0 0 r
F
.19265 1.28751 m .18754 1.29711 L .18764 1.29689 L F
.19265 1.28751 m .18764 1.29689 L .20016 1.26789 L F
.19265 1.28751 m .18315 1.26895 L .18754 1.29711 L 1 .435 .592 r
F
.19265 1.28751 m .19565 1.28437 L .18101 1.31224 L 0 0 0 r
F
.19291 1.28696 m .19297 1.2869 L .19265 1.28751 L F
.19297 1.2869 m .19565 1.28437 L .19265 1.28751 L F
.21371 1.2428 m .20196 1.26984 L .19291 1.28696 L F
.207 1.26057 m .20185 1.27009 L .20196 1.26984 L F
.207 1.26057 m .20693 1.26043 L .20185 1.27009 L 1 .444 .594 r
F
.20196 1.26984 m .20185 1.27009 L .19291 1.28696 L 0 0 0 r
F
.20693 1.26043 m .19758 1.24357 L .20185 1.27009 L 1 .444 .594 r
F
.20185 1.27009 m .19565 1.28437 L .19304 1.28683 L 0 0 0 r
F
.20185 1.27009 m .19304 1.28683 L .19291 1.28696 L F
.20803 1.25835 m .21191 1.21869 L .2069 1.26039 L 1 .444 .594 r
F
.21385 1.24784 m .21382 1.2474 L .20803 1.25835 L F
.21382 1.2474 m .21191 1.21869 L .20803 1.25835 L F
.2161 1.24378 m .21608 1.24367 L .21385 1.24784 L F
.21608 1.24367 m .21191 1.21869 L .21385 1.24784 L F
.19291 1.28696 m .19265 1.28751 L .19274 1.28728 L 0 0 0 r
F
.19291 1.28696 m .19274 1.28728 L .20016 1.26789 L F
.19265 1.28751 m .20185 1.27009 L .19252 1.28726 L 1 .435 .592 r
F
.19252 1.28726 m .19758 1.24357 L .18315 1.26895 L F
.20185 1.27009 m .19758 1.24357 L .19252 1.28726 L F
.207 1.26057 m .20684 1.2609 L .20185 1.27009 L 0 0 0 r
F
.20684 1.2609 m .19565 1.28437 L .20185 1.27009 L F
.207 1.26057 m .21015 1.25746 L .19565 1.28437 L F
.2073 1.25995 m .20737 1.25989 L .207 1.26057 L F
.20737 1.25989 m .21015 1.25746 L .207 1.26057 L F
.21852 1.2394 m .2161 1.24378 L .21622 1.24349 L F
.22137 1.23421 m .22131 1.23411 L .2161 1.24378 L 1 .456 .596 r
F
.21622 1.24349 m .2161 1.24378 L .2073 1.25995 L 0 0 0 r
F
.22131 1.23411 m .21191 1.21869 L .2161 1.24378 L 1 .456 .596 r
F
.2161 1.24378 m .21015 1.25746 L .20746 1.25981 L 0 0 0 r
F
.2161 1.24378 m .20746 1.25981 L .2073 1.25995 L F
.23024 1.21781 m .23022 1.21768 L .22138 1.23408 L 1 .456 .596 r
F
.23022 1.21768 m .22615 1.19426 L .2214 1.23395 L F
.23022 1.21768 m .2214 1.23395 L .22138 1.23408 L F
.22172 1.23348 m .22137 1.23421 L .22116 1.23448 L 0 0 0 r
F
.23024 1.21781 m .22138 1.23408 L .22137 1.23421 L 1 .456 .596 r
F
.2073 1.25995 m .207 1.26057 L .2071 1.26032 L 0 0 0 r
F
.207 1.26057 m .2161 1.24378 L .2069 1.26039 L 1 .444 .594 r
F
.2069 1.26039 m .21191 1.21869 L .19758 1.24357 L F
.22092 1.23513 m .21585 1.24434 L .2161 1.24378 L 0 0 0 r
F
.22092 1.23513 m .2161 1.24378 L .21852 1.2394 L F
.22092 1.23513 m .21622 1.24349 L .22106 1.23477 L F
.23031 1.21819 m .23029 1.2181 L .22137 1.23421 L 1 .456 .596 r
F
.22137 1.23421 m .22092 1.23513 L .22105 1.23478 L 0 0 0 r
F
.22137 1.23421 m .22452 1.2316 L .21015 1.25746 L F
.23031 1.21819 m .22452 1.2316 L .22137 1.23421 L F
.22137 1.23421 m .22615 1.19426 L .21191 1.21869 L 1 .456 .596 r
F
.23572 1.20824 m .24029 1.17025 L .22615 1.19426 L 1 .472 .599 r
F
.23626 1.20744 m .24451 1.19332 L .23581 1.20837 L 0 0 0 r
F
.2538 1.17133 m .24472 1.19283 L .23626 1.20744 L F
.24472 1.19283 m .24451 1.19332 L .23626 1.20744 L F
.26699 1.14896 m .25904 1.16845 L .25044 1.18295 L F
.25867 1.16873 m .25867 1.16872 L .25044 1.18295 L 1 .495 .603 r
F
.25867 1.16872 m .25434 1.14661 L .25044 1.18294 L F
.25867 1.16872 m .25044 1.18294 L .25044 1.18295 L F
.23581 1.20837 m .24446 1.19303 L .23572 1.20824 L 1 .472 .599 r
F
.25144 1.23118 m .24451 1.19332 L .23581 1.20837 L F
.24451 1.19332 m .24446 1.19303 L .23581 1.20837 L F
.23581 1.20837 m .23031 1.21819 L .23777 1.26113 L F
.23581 1.20837 m .23877 1.20692 L .22452 1.2316 L 0 0 0 r
F
.24451 1.19332 m .23877 1.20692 L .23581 1.20837 L F
.26544 1.15772 m .25876 1.16916 L .26503 1.20119 L 1 .53 .608 r
F
.26544 1.15772 m .26486 1.15891 L .25876 1.16916 L 0 0 0 r
F
.26503 1.20119 m .25876 1.16916 L .2505 1.18302 L 1 .495 .603 r
F
.26486 1.15891 m .25287 1.18358 L .25876 1.16916 L 0 0 0 r
F
.2505 1.18302 m .25876 1.16916 L .25044 1.18295 L 1 .495 .603 r
F
.25904 1.16845 m .25876 1.16916 L .25044 1.18295 L 0 0 0 r
F
.25876 1.16916 m .25867 1.16873 L .25044 1.18295 L 1 .495 .603 r
F
.25876 1.16916 m .25287 1.18358 L .25044 1.18295 L 0 0 0 r
F
.25044 1.18295 m .24451 1.19332 L .25144 1.23118 L 1 .495 .603 r
F
.25006 1.18372 m .25287 1.18358 L .23877 1.20692 L 0 0 0 r
F
.25044 1.18295 m .25052 1.18297 L .25006 1.18372 L F
.25052 1.18297 m .25287 1.18358 L .25006 1.18372 L F
.24446 1.19303 m .24438 1.19262 L .24066 1.19932 L 1 .472 .599 r
F
.24446 1.19303 m .24066 1.19932 L .23572 1.20824 L F
.24438 1.19262 m .24029 1.17025 L .23572 1.20824 L F
.22092 1.23513 m .21015 1.25746 L .21585 1.24434 L 0 0 0 r
F
.23581 1.20837 m .23572 1.20824 L .23031 1.21819 L 1 .472 .599 r
F
.23572 1.20824 m .22615 1.19426 L .23029 1.2181 L F
.23572 1.20824 m .23029 1.2181 L .23031 1.21819 L F
.23581 1.20837 m .22452 1.2316 L .23031 1.21819 L 0 0 0 r
F
.25026 1.18272 m .25434 1.14661 L .24029 1.17025 L 1 .495 .603 r
F
.25044 1.18295 m .25051 1.18226 L .25026 1.18272 L F
.25051 1.18226 m .25434 1.14661 L .25026 1.18272 L F
.25044 1.18295 m .24446 1.19303 L .24451 1.19332 L F
.24967 1.18454 m .24408 1.19434 L .24451 1.19332 L 0 0 0 r
F
.24967 1.18454 m .24451 1.19332 L .24983 1.18402 L F
.25044 1.18295 m .24029 1.17025 L .24446 1.19303 L 1 .495 .603 r
F
.26513 1.1574 m .2683 1.12329 L .25434 1.14661 L 1 .53 .608 r
F
.26544 1.15772 m .26685 1.16186 L .25287 1.18358 L 0 0 0 r
F
.2801 1.12756 m .27312 1.14564 L .26544 1.15772 L F
.26554 1.15781 m .26634 1.1563 L .26544 1.15772 L 1 .53 .608 r
F
.27855 1.17084 m .27312 1.14564 L .26554 1.15781 L F
.27312 1.14564 m .2728 1.14416 L .26554 1.15781 L F
.27312 1.14564 m .26685 1.16186 L .26544 1.15772 L 0 0 0 r
F
.26544 1.15772 m .2728 1.14416 L .26513 1.1574 L 1 .53 .608 r
F
.26634 1.1563 m .2728 1.14416 L .26544 1.15772 L F
.28031 1.13161 m .27252 1.14289 L .27312 1.14564 L 1 .585 .615 r
F
.28021 1.13384 m .27312 1.14564 L .27855 1.17084 L F
.28031 1.13161 m .27312 1.14564 L .28021 1.13384 L F
.28118 1.13221 m .28019 1.13426 L .27312 1.14564 L 0 0 .02 r
F
.28019 1.13426 m .26685 1.16186 L .27312 1.14564 L F
.2728 1.14416 m .2683 1.12329 L .26513 1.1574 L 1 .53 .608 r
F
.24967 1.18454 m .23877 1.20692 L .24408 1.19434 L 0 0 0 r
F
.26544 1.15772 m .26513 1.1574 L .25876 1.16916 L 1 .53 .608 r
F
.26513 1.1574 m .25434 1.14661 L .25867 1.16873 L F
.26513 1.1574 m .25867 1.16873 L .25876 1.16916 L F
.28066 1.13185 m .28217 1.10035 L .2683 1.12329 L 1 .585 .615 r
F
.28118 1.13221 m .28122 1.13091 L .28066 1.13185 L F
.28122 1.13091 m .28217 1.10035 L .28066 1.13185 L F
.28122 1.13224 m .28122 1.13215 L .28118 1.13221 L F
.2931 1.10757 m .28772 1.12254 L .28118 1.13221 L 0 0 .02 r
F
.28122 1.13215 m .28217 1.10035 L .28118 1.13221 L 1 .585 .615 r
F
.29201 1.13971 m .28118 1.13221 L .27855 1.17084 L F
.28118 1.13221 m .28031 1.13161 L .28021 1.13384 L F
.28031 1.13161 m .2683 1.12329 L .27252 1.14289 L F
.29834 1.10562 m .29576 1.07825 L .28217 1.10034 L 1 .675 .627 r
F
.30524 1.10788 m .30263 1.09974 L .29834 1.10562 L F
.2986 1.10509 m .29854 1.10535 L .29834 1.10562 L .097 0 .091 r
F
.3058 1.0902 m .30295 1.09879 L .2986 1.10509 L F
.30295 1.09879 m .29419 1.12516 L .2986 1.10509 L F
.30263 1.09974 m .29576 1.07825 L .29834 1.10562 L 1 .675 .627 r
F
.29834 1.10562 m .29419 1.12516 L .28069 1.14213 L .097 0 .091 r
F
.29854 1.10535 m .29419 1.12516 L .29834 1.10562 L F
.28118 1.13221 m .28069 1.14213 L .26685 1.16186 L 0 0 .02 r
F
.28772 1.12254 m .28217 1.10035 L .28122 1.13224 L 1 .585 .615 r
F
.28772 1.12254 m .28069 1.14213 L .28118 1.13221 L 0 0 .02 r
F
.29487 1.11188 m .28686 1.12495 L .28773 1.12254 L .097 0 .091 r
F
.29487 1.11188 m .28773 1.12254 L .2931 1.10756 L F
.29834 1.10562 m .28217 1.10034 L .28773 1.12254 L 1 .675 .627 r
F
.29834 1.10562 m .29699 1.10842 L .29664 1.10834 L .097 0 .091 r
F
.29699 1.10842 m .28069 1.14213 L .28686 1.12495 L F
.31839 1.07517 m .31727 1.07533 L .30263 1.09974 L 1 .802 .647 r
F
.31727 1.07533 m .29576 1.07825 L .30252 1.09939 L F
.31727 1.07533 m .30252 1.09939 L .30263 1.09974 L F
.31693 1.07882 m .30263 1.09974 L .30524 1.10788 L F
.31839 1.07517 m .30263 1.09974 L .31693 1.07882 L F
.31693 1.07882 m .30247 1.10021 L .30263 1.09974 L .22 0 .143 r
F
.31833 1.07739 m .29419 1.12516 L .30247 1.10021 L F
.31833 1.07739 m .30247 1.10021 L .31693 1.07882 L F
.3187 1.07553 m .31818 1.07754 L .31693 1.07882 L .424 0 .338 r
F
.31871 1.07494 m .31833 1.07739 L .3187 1.07553 L .636 0 .44 r
F
.33126 1.09 m .3187 1.07553 L .31848 1.09878 L 1 .649 .592 r
F
.32593 1.02875 m .3187 1.07553 L .33126 1.09 L .415 0 .399 r
F
.31871 1.07494 m .3306 1.07276 L .31833 1.07739 L .636 0 .44 r
F
.32593 1.02875 m .32864 1.0543 L .31871 1.07494 L F
.32864 1.0543 m .3306 1.07276 L .31871 1.07494 L F
.3187 1.07553 m .31852 1.07532 L .31693 1.07882 L 1 .649 .592 r
F
.31852 1.07532 m .31839 1.07517 L .31736 1.07775 L F
.31852 1.07532 m .31736 1.07775 L .31693 1.07882 L F
.34765 .89488 m .34464 .92258 L .32761 1.01918 L .415 0 .399 r
F
.34464 .92258 m .33639 1.01082 L .32593 1.02875 L .636 0 .44 r
F
.33424 1.03387 m .3306 1.07276 L .32786 1.04696 L F
.34611 .9932 m .33061 1.07276 L .34765 .89488 L .648 0 .391 r
F
.34611 .9932 m .33174 1.07283 L .33061 1.07276 L F
.39406 1.1625 m .35838 1.12875 L .38755 1.18574 L .846 .135 .613 r
F
.39406 1.1625 m .36631 1.1116 L .35838 1.12875 L F
.36488 1.1263 m .34611 .9933 L .3579 1.13506 L 1 .021 .239 r
F
.36488 1.1263 m .35184 1.05766 L .35184 1.05765 L F
.36488 1.1263 m .35184 1.05765 L .35285 1.0463 L F
.35127 1.02988 m .34791 1.01351 L .34872 1.01182 L F
.36488 1.1263 m .35031 1.02942 L .35127 1.02988 L F
.35031 1.02942 m .34791 1.01351 L .35127 1.02988 L F
.35184 1.05765 m .33174 1.07283 L .3405 1.02434 L .617 0 .165 r
F
.34791 1.01351 m .3405 1.02434 L .34611 .99327 L F
.35184 1.05765 m .3405 1.02434 L .34791 1.01351 L F
.34245 1.02486 m .34213 1.02552 L .341 1.02688 L 0 0 0 r
F
.33486 1.03547 m .34099 1.02688 L .3326 1.04213 L .057 0 .161 r
F
.33804 1.02607 m .34099 1.02688 L .33486 1.03547 L F
.34099 1.02688 m .34099 1.02688 L .33486 1.03547 L F
.34213 1.02552 m .34197 1.02551 L .341 1.02688 L .957 .391 .709 r
F
.34872 1.01182 m .34791 1.01351 L .34611 .9933 L 1 .021 .239 r
F
.35379 .97951 m .34517 1.01143 L .33804 1.02607 L .057 0 .161 r
F
.34517 1.01143 m .34127 1.02584 L .33804 1.02607 L F
.35285 1.0463 m .35184 1.05765 L .34791 1.01351 L 1 .021 .239 r
F
.33639 1.01082 m .33424 1.03387 L .32716 1.04033 L .636 0 .44 r
F
.33245 1.0379 m .3326 1.04213 L .3314 1.04465 L .34 0 .351 r
F
.33424 1.03387 m .32786 1.04696 L .32716 1.04033 L .636 0 .44 r
F
.33693 1.00912 m .3333 1.03676 L .33245 1.0379 L .34 0 .351 r
F
.3333 1.03676 m .3326 1.04213 L .33245 1.0379 L F
.3777 1.02091 m .35106 .96329 L .3688 1.02356 L .169 0 .613 r
F
.3646 .99405 m .341 1.02688 L .3538 .97952 L 0 0 0 r
F
.34197 1.02551 m .34177 1.0255 L .341 1.02688 L .957 .391 .709 r
F
.34127 1.02584 m .34099 1.02688 L .34058 1.02677 L .057 0 .161 r
F
.34127 1.02584 m .34058 1.02677 L .33804 1.02607 L F
.33796 1.00583 m .33341 1.03662 L .33693 1.00912 L .34 0 .351 r
F
.33341 1.03662 m .3326 1.04213 L .3333 1.03676 L F
.33341 1.03662 m .3333 1.03676 L .33693 1.00912 L F
.33639 1.01082 m .32716 1.04033 L .32593 1.02875 L .636 0 .44 r
F
.33523 1.00933 m .33211 1.03805 L .32462 1.03772 L .415 0 .399 r
F
.3326 1.04213 m .33258 1.04212 L .3314 1.04465 L 1 .773 .681 r
F
.33211 1.03805 m .33148 1.04385 L .32897 1.04217 L .415 0 .399 r
F
.33148 1.04385 m .33139 1.04465 L .33114 1.04439 L F
.33148 1.04385 m .33114 1.04439 L .32897 1.04217 L F
.33211 1.03805 m .32897 1.04217 L .32462 1.03772 L F
.34765 .89488 m .32097 1.0604 L .32593 1.02875 L F
.32097 1.0604 m .31871 1.07444 L .32091 1.06049 L F
.32097 1.0604 m .32091 1.06049 L .32593 1.02875 L F
.32761 1.01918 m .33523 1.00933 L .32462 1.03772 L F
.32462 1.03772 m .33139 1.04465 L .31871 1.07444 L F
.34727 .89442 m .34464 .92258 L .32593 1.02875 L .636 0 .44 r
F
.34464 .92258 m .33523 1.00933 L .32761 1.01918 L .415 0 .399 r
F
.34781 .88868 m .32809 1.0149 L .32813 1.01481 L .636 0 .44 r
F
.34781 .88868 m .32813 1.01481 L .34688 .89617 L F
.34781 .88868 m .34727 .89442 L .32593 1.02875 L F
.34746 .94143 m .3314 1.04465 L .34781 .88868 L .34 0 .351 r
F
.33258 1.04212 m .32386 1.03613 L .32262 1.03781 L 1 .773 .681 r
F
.3326 1.04213 m .33258 1.04212 L .33258 1.04212 L F
.33258 1.04212 m .32386 1.03613 L .33258 1.04212 L F
.33258 1.04212 m .32262 1.03781 L .3314 1.04465 L F
.33258 1.04212 m .3314 1.04465 L .3314 1.04465 L F
.35062 .96116 m .35073 .96086 L .35056 .96131 L .723 0 .282 r
F
.35073 .96086 m .35069 .96096 L .35056 .96131 L F
.35056 .96131 m .35056 .96128 L .35042 .96164 L F
.35069 .96096 m .35056 .96128 L .35056 .96131 L F
.35112 .96349 m .35106 .96329 L .35096 .96401 L .429 .004 .612 r
F
.3777 1.02091 m .36079 .97359 L .35106 .96329 L .169 0 .613 r
F
.35379 .97951 m .3326 1.04213 L .34746 .94147 L .057 0 .161 r
F
.33628 1.02273 m .33261 1.02504 L .34169 1.0255 L .957 .391 .709 r
F
.34171 1.02547 m .34169 1.0255 L .34177 1.0255 L F
.33628 1.02273 m .34169 1.0255 L .34171 1.02547 L F
.34186 1.02539 m .34177 1.0255 L .34213 1.02552 L F
.33628 1.02273 m .34177 1.0255 L .34186 1.02539 L F
.34177 1.0255 m .33261 1.02504 L .34077 1.02683 L F
.34177 1.0255 m .34077 1.02683 L .341 1.02688 L F
.35021 1.01399 m .34574 1.01106 L .33261 1.02504 L F
.34799 1.01731 m .35347 1.01194 L .34213 1.02552 L 0 0 0 r
F
.37853 1.02077 m .36079 .97359 L .3777 1.02091 L 0 0 .576 r
F
.37853 1.02077 m .3617 .97485 L .36079 .97359 L F
.3844 1.02016 m .3617 .97485 L .37854 1.02077 L 0 0 .539 r
F
.36277 .97697 m .36811 .9841 L .3617 .97485 L F
.3844 1.02016 m .36811 .9841 L .36277 .97697 L F
.36811 .9841 m .36811 .9841 L .36277 .97697 L F
.37315 .99127 m .37795 .99611 L .36811 .98411 L 0 0 .517 r
F
.39332 1.01997 m .37795 .99611 L .37315 .99127 L F
.40228 1.01961 m .37795 .99611 L .39332 1.01997 L 0 0 .689 r
F
.38448 1.00242 m .38795 1.00318 L .37795 .99611 L F
.40228 1.01961 m .38795 1.00318 L .38448 1.00242 L F
.3981 1.00601 m .39169 1.00399 L .38795 1.00318 L .25 .013 .867 r
F
.38795 1.00318 m .38303 1.00125 L .37795 .99611 L .346 0 0 r
F
.39332 1.01997 m .36811 .98411 L .3844 1.02016 L 0 0 .517 r
F
.38795 1.00318 m .3757 .99895 L .3646 .99405 L .346 0 0 r
F
.39169 1.00399 m .3757 .99895 L .38795 1.00318 L .25 .013 .867 r
F
.38303 1.00125 m .3646 .99405 L .37795 .99611 L .346 0 0 r
F
.37795 .99611 m .37623 .99494 L .36811 .98411 L .876 0 .074 r
F
.37623 .99494 m .3538 .97951 L .36811 .98411 L F
.37623 .99494 m .36811 .98411 L .36811 .98411 L F
.3757 .99895 m .35347 1.01194 L .3646 .99405 L .553 0 .655 r
F
.3981 1.00601 m .38692 1.00001 L .3757 .99895 L .25 .013 .867 r
F
.3607 1.00772 m .36577 1.00348 L .35347 1.01194 L .553 0 .655 r
F
.3757 .99895 m .36577 1.00348 L .3607 1.00772 L F
.38692 1.00001 m .36577 1.00348 L .3757 .99895 L .668 .348 .861 r
F
.37801 .99802 m .37128 .99888 L .36577 1.00348 L 1 .847 .825 r
F
.37128 .99888 m .36605 .99955 L .36577 1.00348 L F
.3646 .99405 m .35517 1.00921 L .35135 1.01261 L 0 0 0 r
F
.34293 1.02418 m .34213 1.02552 L .34245 1.02486 L F
.3646 .99405 m .34507 1.0214 L .34452 1.02197 L F
.37795 .99611 m .3646 .99405 L .3538 .97951 L .876 0 .074 r
F
.36605 .99955 m .37169 .99274 L .35876 1.00048 L 1 .847 .825 r
F
.37801 .99802 m .37219 .99315 L .36605 .99955 L F
.37219 .99315 m .37169 .99274 L .36605 .99955 L F
.34452 1.02197 m .34362 1.02343 L .34293 1.02418 L 0 0 0 r
F
.34507 1.0214 m .34362 1.02343 L .34452 1.02197 L F
.34362 1.02343 m .34213 1.02552 L .34293 1.02418 L F
.35981 1.00574 m .35876 1.00048 L .34574 1.01106 L .97 .608 .777 r
F
.36577 1.00348 m .36297 1.00228 L .35981 1.00574 L F
.36297 1.00228 m .35876 1.00048 L .35981 1.00574 L F
.36605 .99955 m .35876 1.00048 L .36297 1.00228 L 1 .847 .825 r
F
.36605 .99955 m .36297 1.00228 L .36577 1.00348 L F
.35135 1.01261 m .35347 1.01194 L .34799 1.01731 L 0 0 0 r
F
.35517 1.00921 m .35347 1.01194 L .35135 1.01261 L F
.36577 1.00348 m .35981 1.00574 L .35347 1.01194 L .97 .608 .777 r
F
.35981 1.00574 m .34574 1.01106 L .35347 1.01194 L F
.35347 1.01194 m .35189 1.01176 L .35021 1.01399 L .957 .391 .709 r
F
.35189 1.01176 m .34574 1.01106 L .35021 1.01399 L F
.35347 1.01194 m .35021 1.01399 L .34213 1.02552 L F
.35021 1.01399 m .33628 1.02273 L .34201 1.02546 L F
.35021 1.01399 m .34201 1.02546 L .34213 1.02552 L F
.34197 1.02551 m .341 1.02688 L .341 1.02688 L F
.40054 1.14082 m .36631 1.1116 L .39406 1.1625 L .841 .144 .622 r
F
.40054 1.14082 m .37421 1.09588 L .36631 1.1116 L F
.37533 1.11994 m .35185 1.05767 L .36489 1.1263 L 0 0 .304 r
F
.37533 1.11994 m .36251 1.08414 L .36251 1.08413 L F
.35987 1.07894 m .36251 1.08413 L .35185 1.05767 L F
.37533 1.11994 m .36251 1.08413 L .35987 1.07894 L F
.36251 1.08413 m .35173 1.0819 L .36251 1.08413 L 0 0 .721 r
F
.38573 1.11695 m .36251 1.08414 L .37533 1.11994 L .002 0 .671 r
F
.4069 1.12123 m .37421 1.09588 L .40054 1.14081 L .829 .156 .634 r
F
.4069 1.12123 m .38197 1.082 L .37421 1.09588 L F
.38573 1.11695 m .37364 1.09465 L .36251 1.08414 L .002 0 .671 r
F
.37364 1.09464 m .36542 1.08986 L .36251 1.08413 L 0 0 .721 r
F
.36542 1.08986 m .35173 1.0819 L .36251 1.08413 L F
.36251 1.08413 m .34994 1.07925 L .35185 1.05766 L .502 0 0 r
F
.34994 1.07925 m .3397 1.07527 L .35184 1.05766 L F
.34994 1.07925 m .35184 1.05766 L .35185 1.05766 L F
.34746 .94143 m .33796 1.00583 L .33693 1.00912 L .34 0 .351 r
F
.33139 1.04465 m .32262 1.03781 L .31678 1.04624 L 1 .777 .668 r
F
.31812 1.05213 m .31678 1.04624 L .30925 1.05714 L F
.33139 1.04465 m .31678 1.04624 L .31812 1.05213 L F
.34043 1.02718 m .3326 1.02504 L .32387 1.03612 L 1 .52 .681 r
F
.34099 1.02688 m .34069 1.02682 L .34043 1.02718 L F
.34069 1.02682 m .3326 1.02504 L .34043 1.02718 L F
.3218 1.05417 m .32005 1.06595 L .31982 1.06639 L .415 0 .399 r
F
.32194 1.05396 m .32005 1.06595 L .3218 1.05417 L F
.32005 1.06595 m .31871 1.07444 L .31982 1.06639 L F
.34099 1.02688 m .34043 1.02718 L .3326 1.04213 L 1 .52 .681 r
F
.34043 1.02718 m .32387 1.03612 L .33258 1.04211 L F
.34043 1.02718 m .33258 1.04211 L .3326 1.04213 L F
.31871 1.07444 m .30925 1.05714 L .31839 1.07517 L 1 .777 .668 r
F
.33139 1.04465 m .31812 1.05213 L .31871 1.07444 L F
.31812 1.05213 m .30925 1.05714 L .31871 1.07444 L F
.3187 1.07553 m .31833 1.07739 L .31818 1.07754 L .424 0 .338 r
F
.3126 1.043 m .31634 1.03622 L .30848 1.05045 L 0 0 0 r
F
.35227 .95607 m .35073 .96086 L .35208 .95721 L .565 .007 .549 r
F
.35749 .94444 m .34746 .94136 L .34763 .92557 L 1 .26 .434 r
F
.35626 .93556 m .34813 .87686 L .35598 .93685 L F
.35514 .92751 m .34763 .92557 L .34813 .87686 L F
.35749 .94444 m .34763 .92557 L .35514 .92751 L F
.32045 1.02666 m .31099 .97142 L .30081 .97864 L .696 .057 .592 r
F
.32045 1.02666 m .30848 1.05045 L .29781 1.06878 L 0 0 0 r
F
.32045 1.02666 m .32031 1.0263 L .32034 1.02682 L .696 .057 .592 r
F
.32045 1.02666 m .29781 1.06878 L .31488 1.03462 L 0 0 0 r
F
.37759 .93756 m .37613 .93961 L .37759 .93756 L .713 0 .444 r
F
.37005 .94547 m .36569 .9523 L .36551 .95251 L 0 0 0 r
F
.36884 .94855 m .36159 .95721 L .36851 .94894 L 1 .425 .647 r
F
.36884 .94855 m .36851 .94894 L .38506 .92919 L F
.42284 .89565 m .40396 .90824 L .42228 .89603 L .884 .344 .736 r
F
.40396 .90824 m .40007 .91083 L .40397 .90823 L F
.40396 .90824 m .40397 .90823 L .42228 .89603 L F
.39462 .91857 m .39255 .92025 L .39535 .91782 L .852 .271 .728 r
F
.49748 .56222 m .49375 .55498 L .4896 .5562 L .68 .503 .842 r
F
.49748 .56222 m .50025 .5614 L .49375 .55498 L F
.53128 .56655 m .54346 .56515 L .54038 .56283 L .664 .491 .845 r
F
.5288 .56507 m .53128 .56655 L .54038 .56283 L .665 .491 .844 r
F
.49773 .88356 m .47255 .88268 L .49658 .88953 L .273 .005 .859 r
F
.49773 .88356 m .47534 .88086 L .47255 .88268 L F
.51979 .88408 m .49659 .88953 L .52029 .89336 L .702 .578 .858 r
F
.51979 .88408 m .49773 .88356 L .49659 .88953 L F
.44275 .55353 m .43567 .54418 L .43097 .54966 L .653 .464 .84 r
F
.44275 .55353 m .4468 .54875 L .43567 .54418 L F
.6225 .57216 m .62469 .57703 L .63713 .57723 L .485 .261 .899 r
F
.61026 .57169 m .62469 .57703 L .6225 .57216 L .548 .394 .89 r
F
.54765 .69986 m .54561 .71021 L .55449 .70771 L .768 .472 .796 r
F
.54765 .69986 m .54025 .70187 L .54561 .71021 L F
.4827 .55962 m .47675 .55224 L .47249 .55469 L .678 .501 .842 r
F
.4827 .55962 m .48589 .55776 L .47675 .55224 L F
.50841 .69355 m .49865 .69943 L .50724 .70152 L .736 .471 .807 r
F
.5152 .69452 m .50724 .70152 L .51571 .70283 L .74 .47 .805 r
F
.5152 .69452 m .50841 .69355 L .50724 .70152 L F
.57138 .56788 m .5737 .57194 L .58587 .5717 L .625 .469 .857 r
F
.55969 .56892 m .5737 .57194 L .57138 .56788 L .645 .483 .852 r
F
.469 .55752 m .46226 .54972 L .45791 .55319 L .672 .493 .841 r
F
.469 .55752 m .47249 .55469 L .46226 .54972 L F
.50153 .69194 m .49035 .69666 L .49865 .69943 L .734 .473 .809 r
F
.50841 .69355 m .50153 .69194 L .49865 .69943 L .736 .471 .807 r
F
.52195 .69488 m .51571 .70283 L .52413 .70335 L .746 .47 .803 r
F
.52195 .69488 m .5152 .69452 L .51571 .70283 L F
.50025 .5614 m .49827 .5541 L .49375 .55498 L .68 .503 .842 r
F
.50025 .5614 m .50325 .56082 L .49827 .5541 L F
.54602 .56759 m .55969 .56892 L .55703 .5656 L .654 .484 .847 r
F
.54346 .56515 m .54602 .56759 L .55703 .5656 L .651 .479 .847 r
F
.29663 .25321 m .32477 .24996 L .31722 .21987 L .43 .001 .591 r
F
.30525 .28394 m .32477 .24996 L .29663 .25321 L .443 .003 .595 r
F
.5288 .56507 m .54038 .56283 L .53667 .56058 L .665 .491 .844 r
F
.52603 .56375 m .5288 .56507 L .53667 .56058 L .668 .493 .844 r
F
.54172 .87744 m .51979 .88408 L .52029 .89336 L 1 .737 .771 r
F
.63477 .57324 m .63713 .57723 L .64958 .57764 L .377 .069 .888 r
F
.6225 .57216 m .63713 .57723 L .63477 .57324 L .485 .261 .899 r
F
.49487 .68976 m .48247 .6933 L .49035 .69666 L .735 .477 .809 r
F
.50153 .69194 m .49487 .68976 L .49035 .69666 L .734 .473 .809 r
F
.41456 .68932 m .4078 .68104 L .39614 .68587 L 1 .761 .803 r
F
.42543 .68525 m .4078 .68104 L .41456 .68932 L .922 .672 .806 r
F
.55703 .5656 m .55969 .56892 L .57138 .56788 L .636 .469 .851 r
F
.43097 .54966 m .42453 .53947 L .41918 .54561 L .639 .447 .84 r
F
.43097 .54966 m .43567 .54418 L .42453 .53947 L F
.52855 .6946 m .52413 .70335 L .53236 .70303 L .751 .471 .801 r
F
.52855 .6946 m .52195 .69488 L .52413 .70335 L F
.50325 .56082 m .50307 .55359 L .49827 .5541 L .68 .503 .842 r
F
.50325 .56082 m .50645 .56049 L .50307 .55359 L F
.29183 .58914 m .28352 .53241 L .27969 .5748 L .404 .003 .625 r
F
.29211 .64028 m .27969 .5748 L .27988 .63174 L .565 .038 .623 r
F
.29211 .64028 m .29183 .58914 L .27969 .5748 L F
.52603 .56375 m .53667 .56058 L .53251 .55856 L .668 .493 .844 r
F
.52302 .56263 m .52603 .56375 L .53251 .55856 L .671 .496 .843 r
F
.78363 .55401 m .78569 .6348 L .79767 .62069 L 1 .413 .589 r
F
.7718 .57356 m .78569 .6348 L .78363 .55401 L 1 .425 .591 r
F
.76538 .50372 m .7718 .57356 L .78363 .55401 L 1 .431 .585 r
F
.56986 .69987 m .57078 .71132 L .57922 .70586 L .795 .504 .797 r
F
.56986 .69987 m .56262 .70419 L .57078 .71132 L F
.443 .68815 m .43631 .68163 L .42543 .68525 L .823 .596 .816 r
F
.45293 .68425 m .43631 .68163 L .443 .68815 L .8 .555 .811 r
F
.4598 .68971 m .45293 .68425 L .443 .68815 L .764 .529 .816 r
F
.58648 .69989 m .58856 .71153 L .59685 .70416 L .823 .564 .806 r
F
.58648 .69989 m .57922 .70586 L .58856 .71153 L F
.64709 .57547 m .64958 .57764 L .66206 .57835 L .163 0 .796 r
F
.63477 .57324 m .64958 .57764 L .64709 .57547 L .377 .069 .888 r
F
.63262 .69494 m .63712 .7005 L .64445 .69578 L .61 .394 .89 r
F
.63262 .69494 m .62602 .70087 L .63712 .7005 L F
.46862 .6851 m .45293 .68425 L .4598 .68971 L .764 .513 .811 r
F
.47518 .68943 m .46862 .6851 L .4598 .68971 L .743 .496 .813 r
F
.48589 .55776 m .48169 .55019 L .47675 .55224 L .678 .502 .842 r
F
.48589 .55776 m .4896 .5562 L .48169 .55019 L F
.50645 .56049 m .50805 .55346 L .50307 .55359 L .68 .502 .841 r
F
.50645 .56049 m .50976 .56041 L .50805 .55346 L F
.58311 .56704 m .58587 .5717 L .59805 .57159 L .596 .444 .865 r
F
.57138 .56788 m .58587 .5717 L .58311 .56704 L .625 .469 .857 r
F
.76801 .48071 m .79057 .42122 L .7789 .46065 L 0 0 0 r
F
.76801 .48071 m .77942 .44336 L .79057 .42122 L F
.52302 .56263 m .53251 .55856 L .52799 .55683 L .671 .496 .843 r
F
.51983 .56171 m .52302 .56263 L .52799 .55683 L .675 .498 .842 r
F
.29626 .70345 m .27988 .63174 L .28413 .70095 L .694 .072 .611 r
F
.29626 .70345 m .29211 .64028 L .27988 .63174 L F
.48856 .68707 m .47518 .68943 L .48247 .6933 L .741 .483 .809 r
F
.49487 .68976 m .48856 .68707 L .48247 .6933 L .735 .477 .809 r
F
.55444 .69709 m .55449 .70771 L .56262 .7042 L .772 .481 .797 r
F
.55444 .69709 m .54765 .69986 L .55449 .70771 L F
.45791 .55319 m .45201 .54467 L .4468 .54875 L .662 .482 .842 r
F
.45791 .55319 m .46226 .54972 L .45201 .54467 L F
.73082 .42585 m .75519 .44502 L .74129 .39785 L 1 .453 .586 r
F
.73082 .42585 m .74409 .47082 L .75519 .44502 L F
.54346 .56515 m .55703 .5656 L .55362 .56234 L .651 .479 .847 r
F
.54038 .56283 m .54346 .56515 L .55362 .56234 L .651 .477 .846 r
F
.50976 .56041 m .51313 .55372 L .50805 .55346 L .68 .502 .841 r
F
.50976 .56041 m .51314 .5606 L .51313 .55372 L F
.51983 .56171 m .52799 .55683 L .52319 .55542 L .675 .498 .842 r
F
.51652 .56103 m .51983 .56171 L .52319 .55542 L .677 .5 .842 r
F
.41918 .54561 m .41336 .53468 L .40738 .54143 L .624 .432 .842 r
F
.41918 .54561 m .42453 .53947 L .41336 .53468 L F
.53487 .69366 m .53236 .70303 L .54025 .70187 L .756 .472 .8 r
F
.53487 .69366 m .52855 .6946 L .53236 .70303 L F
.51314 .5606 m .51821 .55438 L .51313 .55372 L .679 .501 .841 r
F
.51314 .5606 m .51652 .56103 L .51821 .55438 L F
.51652 .56103 m .52319 .55542 L .51821 .55438 L .677 .5 .842 r
F
.7031 .34206 m .73347 .33327 L .71176 .31004 L 1 .496 .585 r
F
.7031 .34206 m .72388 .36386 L .73347 .33327 L F
.26071 .88776 m .23461 .77868 L .24978 .89126 L .69 .05 .585 r
F
.26071 .88776 m .24606 .78048 L .23461 .77868 L F
.59631 .85097 m .58356 .85085 L .60288 .84364 L .101 0 0 r
F
.60366 .69719 m .60719 .70753 L .61487 .69965 L .822 .663 .835 r
F
.60366 .69719 m .59685 .70416 L .60719 .70753 L F
.55938 .8624 m .54172 .87744 L .56309 .86484 L 1 .903 .822 r
F
.47249 .55469 m .46758 .54672 L .46226 .54972 L .671 .496 .843 r
F
.47249 .55469 m .47675 .55224 L .46758 .54672 L F
.64709 .57547 m .66206 .57835 L .6595 .57994 L .163 0 .796 r
F
.70297 .98826 m .68447 .93458 L .71252 .9964 L 1 0 .15 r
F
.70297 .98826 m .67639 .92932 L .68447 .93458 L F
.23243 .44725 m .23249 .48542 L .22108 .42809 L 1 .001 .138 r
F
.42543 .68525 m .41945 .67732 L .4078 .68104 L .922 .672 .806 r
F
.43631 .68163 m .41945 .67732 L .42543 .68525 L .863 .608 .806 r
F
.40738 .54143 m .40218 .5299 L .39557 .53722 L .612 .423 .845 r
F
.40738 .54143 m .41336 .53468 L .40218 .5299 L F
.4896 .5562 m .48723 .54856 L .48169 .55019 L .678 .504 .843 r
F
.4896 .5562 m .49375 .55498 L .48723 .54856 L F
.56807 .5638 m .57138 .56788 L .58311 .56704 L .612 .446 .855 r
F
.55703 .5656 m .57138 .56788 L .56807 .5638 L .636 .469 .851 r
F
.48272 .68393 m .46862 .6851 L .47518 .68943 L .751 .492 .809 r
F
.48856 .68707 m .48272 .68393 L .47518 .68943 L .741 .483 .809 r
F
.55362 .56234 m .55703 .5656 L .56807 .5638 L .632 .46 .849 r
F
.59486 .56649 m .59805 .57159 L .61026 .57169 L .556 .398 .874 r
F
.58311 .56704 m .59805 .57159 L .59486 .56649 L .596 .444 .865 r
F
.54038 .56283 m .55362 .56234 L .54952 .55921 L .651 .477 .846 r
F
.53667 .56058 m .54038 .56283 L .54952 .5592 L .654 .479 .845 r
F
.29133 .33905 m .31395 .31415 L .30525 .28394 L .514 .011 .59 r
F
.30093 .3712 m .31395 .31415 L .29133 .33905 L .556 .02 .593 r
F
.28283 .41191 m .30093 .3712 L .29133 .33905 L .532 .01 .577 r
F
.75384 .52738 m .7718 .57356 L .76538 .50372 L 1 .437 .585 r
F
.5408 .6921 m .54025 .70187 L .54765 .69986 L .759 .475 .8 r
F
.5408 .6921 m .53487 .69366 L .54025 .70187 L F
.71422 .39438 m .74129 .39785 L .72388 .36386 L 1 .492 .589 r
F
.71422 .39438 m .73082 .42585 L .74129 .39785 L F
.53959 .87129 m .51979 .88408 L .54172 .87744 L 1 .806 .815 r
F
.55938 .8624 m .53959 .87129 L .54172 .87744 L 1 .903 .822 r
F
.4468 .54875 m .44174 .53954 L .43567 .54417 L .647 .467 .844 r
F
.4468 .54875 m .45201 .54467 L .44174 .53954 L F
.39557 .53722 m .39098 .52529 L .38374 .53315 L .605 .426 .85 r
F
.39557 .53722 m .40218 .5299 L .39098 .52529 L F
.6855 .29885 m .72037 .27813 L .69304 .26699 L 1 .497 .583 r
F
.6855 .29885 m .71176 .31004 L .72037 .27813 L F
.56047 .69366 m .56262 .70419 L .56986 .69987 L .772 .493 .801 r
F
.56047 .69366 m .55444 .69709 L .56262 .70419 L F
.57607 .695 m .57922 .70586 L .58648 .69989 L .788 .528 .807 r
F
.57607 .695 m .56986 .69987 L .57922 .70586 L F
.44917 .88418 m .42677 .89271 L .42284 .89565 L .578 .018 .779 r
F
.45293 .68425 m .44722 .67832 L .43631 .68163 L .8 .555 .811 r
F
.4629 .68036 m .44722 .67832 L .45293 .68425 L .785 .527 .808 r
F
.46862 .6851 m .4629 .68036 L .45293 .68425 L .764 .513 .811 r
F
.47534 .88086 m .45358 .88212 L .44918 .88418 L .35 .001 .832 r
F
.49375 .55498 m .49327 .54737 L .48723 .54856 L .679 .504 .842 r
F
.49375 .55498 m .49827 .5541 L .49327 .54737 L F
.22209 .72701 m .19684 .78598 L .21018 .72208 L .711 0 .302 r
F
.50959 .68551 m .50153 .69194 L .50841 .69355 L .745 .477 .806 r
F
.51469 .68621 m .50841 .69355 L .5152 .69452 L .747 .476 .805 r
F
.51469 .68621 m .50959 .68551 L .50841 .69355 L F
.5193 .87666 m .49773 .88356 L .51979 .88408 L .738 .649 .866 r
F
.53959 .87129 m .5193 .87666 L .51979 .88408 L 1 .806 .815 r
F
.50442 .68433 m .49487 .68976 L .50153 .69194 L .745 .478 .806 r
F
.50959 .68551 m .50442 .68433 L .50153 .69194 L .745 .477 .806 r
F
.53667 .56058 m .54952 .5592 L .54457 .55613 L .654 .479 .845 r
F
.53251 .55856 m .53667 .56058 L .54457 .55613 L .661 .483 .843 r
F
.51977 .68645 m .5152 .69452 L .52195 .69488 L .749 .476 .804 r
F
.51977 .68645 m .51469 .68621 L .5152 .69452 L F
.5193 .87666 m .49888 .87783 L .49773 .88356 L .738 .649 .866 r
F
.49888 .87783 m .47534 .88086 L .49773 .88356 L .504 .254 .9 r
F
.47675 .55224 m .47376 .54421 L .46758 .54672 L .671 .5 .845 r
F
.47675 .55224 m .48169 .55019 L .47376 .54421 L F
.62076 .69321 m .62602 .70087 L .63262 .69494 L .695 .611 .88 r
F
.62076 .69321 m .61487 .69965 L .62602 .70087 L F
.46226 .54972 m .45838 .54119 L .45201 .54467 L .66 .487 .845 r
F
.46226 .54972 m .46758 .54672 L .45838 .54119 L F
.49941 .68271 m .48856 .68707 L .49487 .68976 L .746 .48 .807 r
F
.50442 .68433 m .49941 .68271 L .49487 .68976 L .745 .478 .806 r
F
.47747 .68038 m .4629 .68036 L .46862 .6851 L .763 .501 .807 r
F
.48272 .68393 m .47747 .68038 L .46862 .6851 L .751 .492 .809 r
F
.43631 .68163 m .4311 .67434 L .41945 .67732 L .863 .608 .806 r
F
.44722 .67832 m .4311 .67434 L .43631 .68163 L .825 .563 .805 r
F
.60665 .56631 m .61026 .57169 L .6225 .57216 L .504 .322 .883 r
F
.59486 .56649 m .61026 .57169 L .60665 .56631 L .556 .398 .874 r
F
.66186 .696 m .66796 .69437 L .67422 .69858 L .023 0 0 r
F
.38445 .69241 m .36642 .68265 L .37271 .7016 L 1 .667 .745 r
F
.38445 .69241 m .37866 .67755 L .36642 .68265 L F
.39614 .68587 m .37866 .67755 L .38445 .69241 L 1 .678 .768 r
F
.38374 .53315 m .37974 .52116 L .3719 .52949 L .606 .447 .859 r
F
.38374 .53315 m .39098 .52529 L .37974 .52116 L F
.30427 .64726 m .29183 .58915 L .29212 .64029 L .587 .053 .634 r
F
.30831 .70405 m .29212 .64029 L .29626 .70345 L .728 .092 .618 r
F
.30831 .70405 m .30427 .64726 L .29212 .64029 L F
.52472 .68622 m .52195 .69488 L .52855 .6946 L .752 .475 .803 r
F
.52472 .68622 m .51977 .68645 L .52195 .69488 L F
.59243 .6938 m .59685 .70416 L .60366 .69719 L .791 .59 .825 r
F
.59243 .6938 m .58648 .69989 L .59685 .70416 L F
.54623 .68995 m .54765 .69986 L .55444 .69709 L .76 .479 .801 r
F
.54623 .68995 m .5408 .6921 L .54765 .69986 L F
.55362 .56234 m .56807 .5638 L .56382 .55973 L .632 .46 .849 r
F
.54952 .55921 m .55362 .56234 L .56382 .55973 L .632 .456 .847 r
F
.66855 .24033 m .70797 .20311 L .67481 .20941 L 1 .524 .584 r
F
.66855 .24033 m .70053 .23509 L .70797 .20311 L F
.39614 .68587 m .39088 .67347 L .37866 .67755 L 1 .678 .768 r
F
.4078 .68104 m .39088 .67347 L .39614 .68587 L .987 .654 .783 r
F
.27167 .88425 m .24606 .78048 L .26071 .88776 L .7 .052 .585 r
F
.27167 .88425 m .25756 .7819 L .24606 .78048 L F
.49827 .5541 m .49968 .54666 L .49327 .54737 L .681 .505 .842 r
F
.49827 .5541 m .50307 .55359 L .49968 .54666 L F
.29183 .58914 m .29535 .55255 L .28352 .53241 L .404 .003 .625 r
F
.57915 .56227 m .58311 .56704 L .59486 .56649 L .578 .411 .861 r
F
.56807 .5638 m .58311 .56704 L .57915 .56227 L .612 .446 .855 r
F
.53251 .55856 m .54457 .55613 L .53902 .55335 L .661 .483 .843 r
F
.52799 .55683 m .53251 .55856 L .53902 .55335 L .669 .489 .842 r
F
.43567 .54417 m .43144 .5343 L .42453 .53947 L .631 .448 .845 r
F
.43567 .54417 m .44174 .53954 L .43144 .5343 L F
.30391 .60176 m .29536 .55255 L .29183 .58915 L .417 .009 .644 r
F
.30427 .64726 m .30391 .60176 L .29183 .58915 L .587 .053 .634 r
F
.37271 .7016 m .35415 .68857 L .36087 .7147 L 1 .594 .716 r
F
.37271 .7016 m .36642 .68265 L .35415 .68857 L F
.56644 1.21505 m .52585 1.13855 L .56868 1.23383 L .131 0 .568 r
F
.56644 1.21505 m .52535 1.12441 L .52585 1.13855 L F
.49467 .68068 m .48272 .68393 L .48856 .68707 L .75 .484 .806 r
F
.49941 .68271 m .49467 .68068 L .48856 .68707 L .746 .48 .807 r
F
.47816 .87738 m .45358 .88212 L .47534 .88086 L .545 .248 .891 r
F
.49888 .87783 m .47816 .87738 L .47534 .88086 L .504 .254 .9 r
F
.52947 .68552 m .52855 .6946 L .53487 .69366 L .753 .476 .802 r
F
.52947 .68552 m .52472 .68622 L .52855 .6946 L F
.56382 .55973 m .56807 .5638 L .57915 .56227 L .605 .431 .853 r
F
.61309 .86267 m .59631 .85097 L .60288 .84364 L .669 0 .178 r
F
.4078 .68104 m .40308 .67035 L .39088 .67347 L .987 .654 .783 r
F
.41945 .67732 m .40308 .67035 L .4078 .68104 L .919 .618 .792 r
F
.50307 .55359 m .50633 .54644 L .49968 .54666 L .684 .505 .841 r
F
.50307 .55359 m .50805 .55346 L .50633 .54644 L F
.30525 .28394 m .33238 .27955 L .32477 .24996 L .443 .003 .595 r
F
.31395 .31415 m .33238 .27955 L .30525 .28394 L .458 .005 .599 r
F
.69343 .98077 m .67639 .92932 L .70297 .98826 L 1 .001 .153 r
F
.69343 .98077 m .66829 .92391 L .67639 .92932 L F
.3719 .52949 m .36846 .51796 L .36002 .5266 L .617 .49 .873 r
F
.3719 .52949 m .37974 .52116 L .36846 .51796 L F
.52799 .55683 m .53902 .55335 L .53298 .55096 L .669 .489 .842 r
F
.52319 .55542 m .52799 .55683 L .53298 .55096 L .676 .495 .84 r
F
.48169 .55019 m .48069 .54221 L .47376 .54421 L .673 .504 .845 r
F
.48169 .55019 m .48723 .54856 L .48069 .54221 L F
.28012 .4784 m .29297 .45117 L .28283 .41192 L .297 0 .546 r
F
.29297 .45116 m .30093 .3712 L .28283 .41191 L .609 .024 .576 r
F
.75708 .50061 m .77942 .44336 L .76801 .48071 L 0 0 0 r
F
.75708 .50061 m .76821 .46544 L .77942 .44336 L F
.50805 .55346 m .51312 .54675 L .50633 .54644 L .685 .504 .84 r
F
.50805 .55346 m .51313 .55372 L .51312 .54675 L F
.52319 .55542 m .53298 .55096 L .52657 .54902 L .676 .495 .84 r
F
.51821 .55438 m .52319 .55542 L .52657 .54902 L .682 .5 .839 r
F
.56564 .6897 m .56986 .69987 L .57607 .695 L .767 .504 .807 r
F
.56564 .6897 m .56047 .69366 L .56986 .69987 L F
.61847 .56661 m .6225 .57216 L .63477 .57324 L .438 .208 .888 r
F
.60665 .56631 m .6225 .57216 L .61847 .56661 L .504 .322 .883 r
F
.49029 .67829 m .47747 .68038 L .48272 .68393 L .755 .488 .806 r
F
.49467 .68068 m .49029 .67829 L .48272 .68393 L .75 .484 .806 r
F
.23243 .44725 m .24357 .50389 L .23249 .48542 L 1 .001 .138 r
F
.24385 .46589 m .24357 .50389 L .23243 .44725 L 1 .002 .151 r
F
.51313 .55372 m .51991 .54762 L .51312 .54675 L .685 .503 .839 r
F
.51313 .55372 m .51821 .55438 L .51991 .54762 L F
.54952 .55921 m .56382 .55973 L .5587 .55574 L .632 .456 .847 r
F
.54457 .55613 m .54952 .5592 L .5587 .55574 L .639 .459 .845 r
F
.51821 .55438 m .52657 .54902 L .51991 .54762 L .682 .5 .839 r
F
.53392 .68436 m .53487 .69366 L .5408 .6921 L .754 .476 .802 r
F
.53392 .68436 m .52947 .68552 L .53487 .69366 L F
.4629 .68036 m .45814 .67521 L .44722 .67832 L .785 .527 .808 r
F
.47289 .67647 m .45814 .67521 L .4629 .68036 L .775 .509 .805 r
F
.47747 .68038 m .47289 .67647 L .4629 .68036 L .763 .501 .807 r
F
.55105 .68728 m .55444 .69709 L .56047 .69366 L .759 .485 .803 r
F
.55105 .68728 m .54623 .68995 L .55444 .69709 L F
.7718 .57356 m .77366 .64907 L .78569 .6348 L 1 .425 .591 r
F
.75992 .59352 m .77366 .64907 L .7718 .57356 L 1 .441 .593 r
F
.75384 .52738 m .75992 .59352 L .7718 .57356 L 1 .437 .585 r
F
.44722 .67832 m .44277 .67185 L .4311 .67434 L .825 .563 .805 r
F
.45814 .67521 m .44277 .67185 L .44722 .67832 L .799 .533 .805 r
F
.60886 .69076 m .61487 .69965 L .62076 .69321 L .733 .615 .856 r
F
.60886 .69076 m .60366 .69719 L .61487 .69965 L F
.42453 .53947 m .42111 .52891 L .41336 .53468 L .616 .429 .845 r
F
.42453 .53947 m .43144 .5343 L .42111 .52891 L F
.41945 .67732 m .41527 .66798 L .40308 .67035 L .919 .618 .792 r
F
.4311 .67434 m .41527 .66798 L .41945 .67732 L .867 .582 .797 r
F
.45201 .54467 m .44916 .53565 L .44174 .53954 L .643 .472 .848 r
F
.45201 .54467 m .45838 .54119 L .44916 .53565 L F
.22209 .72701 m .20967 .78609 L .19684 .78598 L .711 0 .302 r
F
.23404 .73207 m .20967 .78609 L .22209 .72701 L .705 0 .294 r
F
.36087 .7147 m .34188 .69464 L .34887 .73248 L 1 .453 .679 r
F
.36087 .7147 m .35415 .68857 L .34188 .69464 L F
.58116 .68979 m .58648 .69989 L .59243 .6938 L .77 .541 .817 r
F
.58116 .68979 m .57607 .695 L .58648 .69989 L F
.64949 .69319 m .64445 .69578 L .65623 .69561 L .289 0 .819 r
F
.36002 .5266 m .35711 .51645 L .34808 .52495 L .631 .52 .889 r
F
.36002 .5266 m .36846 .51796 L .35711 .51645 L F
.29118 .50953 m .29297 .45117 L .28012 .4784 L .103 0 .487 r
F
.46758 .54672 m .4658 .53831 L .45838 .54119 L .66 .494 .848 r
F
.46758 .54672 m .47376 .54421 L .4658 .53831 L F
.59026 .56112 m .59486 .56649 L .60665 .56631 L .537 .361 .868 r
F
.57915 .56227 m .59486 .56649 L .59026 .56112 L .578 .411 .861 r
F
.5642 1.19709 m .52535 1.12441 L .56644 1.21505 L .107 0 .567 r
F
.5642 1.19709 m .52485 1.11098 L .52535 1.12441 L F
.31651 .65264 m .30391 .60176 L .30427 .64726 L .618 .077 .647 r
F
.32044 .70246 m .30427 .64726 L .30831 .70405 L .769 .12 .628 r
F
.32044 .70246 m .31651 .65264 L .30427 .64726 L F
.55565 .85983 m .53959 .87129 L .55938 .8624 L .881 .806 .855 r
F
.57312 .8541 m .55565 .85983 L .55938 .8624 L .616 .367 .885 r
F
.72027 .45323 m .74409 .47082 L .73082 .42585 L 1 .45 .588 r
F
.72027 .45323 m .73291 .49623 L .74409 .47082 L F
.28265 .88074 m .25756 .7819 L .27167 .88425 L .712 .056 .585 r
F
.28265 .88074 m .26912 .78279 L .25756 .7819 L F
.48723 .54856 m .48824 .54071 L .48069 .54221 L .677 .508 .844 r
F
.48723 .54856 m .49327 .54737 L .48824 .54071 L F
.48634 .67558 m .47289 .67647 L .47747 .68038 L .762 .492 .805 r
F
.49029 .67829 m .48634 .67558 L .47747 .68038 L .755 .488 .806 r
F
.53744 .86606 m .5193 .87666 L .53959 .87129 L .895 .79 .845 r
F
.55565 .85983 m .53744 .86606 L .53959 .87129 L .881 .806 .855 r
F
.538 .68277 m .5408 .6921 L .54623 .68995 L .754 .478 .803 r
F
.538 .68277 m .53392 .68436 L .5408 .6921 L F
.56382 .55973 m .57915 .56227 L .57406 .5574 L .605 .431 .853 r
F
.5587 .55574 m .56382 .55973 L .57406 .5574 L .607 .425 .849 r
F
.69438 .37434 m .72388 .36386 L .7031 .34206 L 1 .503 .586 r
F
.69438 .37434 m .71422 .39438 L .72388 .36386 L F
.54457 .55613 m .5587 .55574 L .5525 .55175 L .639 .459 .845 r
F
.53902 .55335 m .54457 .55613 L .5525 .55175 L .651 .468 .842 r
F
.51077 .6774 m .50442 .68433 L .50959 .68551 L .751 .479 .804 r
F
.51418 .67786 m .50959 .68551 L .51469 .68621 L F
.51418 .67786 m .51077 .6774 L .50959 .68551 L F
.50732 .67662 m .49941 .68271 L .50442 .68433 L .751 .48 .805 r
F
.51077 .6774 m .50732 .67662 L .50442 .68433 L .751 .479 .804 r
F
.4311 .67434 m .42747 .66621 L .41527 .66798 L .867 .582 .797 r
F
.44277 .67185 m .42747 .66621 L .4311 .67434 L .83 .552 .8 r
F
.5188 .87038 m .49888 .87783 L .5193 .87666 L .753 .676 .87 r
F
.53744 .86606 m .5188 .87038 L .5193 .87666 L .895 .79 .845 r
F
.51757 .67801 m .51469 .68621 L .51977 .68645 L .752 .478 .804 r
F
.51757 .67801 m .51418 .67786 L .51469 .68621 L F
.57406 .5574 m .57915 .56227 L .59026 .56112 L .571 .391 .857 r
F
.63034 .56748 m .63477 .57324 L .64709 .57547 L .333 .077 .879 r
F
.61847 .56661 m .63477 .57324 L .63034 .56748 L .438 .208 .888 r
F
.41336 .53468 m .41077 .52335 L .40218 .5299 L .608 .415 .844 r
F
.41336 .53468 m .42111 .52891 L .41077 .52335 L F
.50398 .67554 m .49467 .68068 L .49941 .68271 L .752 .481 .805 r
F
.50732 .67662 m .50398 .67554 L .49941 .68271 L .751 .48 .805 r
F
.52088 .67785 m .51977 .68645 L .52472 .68622 L .752 .478 .803 r
F
.52088 .67785 m .51757 .67801 L .51977 .68645 L F
.42228 .89603 m .40007 .91083 L .39255 .92025 L .852 .271 .728 r
F
.30391 .60176 m .30716 .57014 L .29536 .55255 L .417 .009 .644 r
F
.31608 .61263 m .30716 .57014 L .30391 .60176 L .45 .026 .667 r
F
.31651 .65264 m .31608 .61263 L .30391 .60176 L .618 .077 .647 r
F
.55519 .68415 m .56047 .69366 L .56564 .6897 L .756 .489 .806 r
F
.55519 .68415 m .55105 .68728 L .56047 .69366 L F
.58962 .85251 m .57837 .85349 L .59631 .85097 L 0 0 0 r
F
.59695 .68776 m .60366 .69719 L .60886 .69076 L .744 .572 .837 r
F
.59695 .68776 m .59243 .6938 L .60366 .69719 L F
.34808 .52495 m .34956 .51697 L .34018 .52478 L .612 .347 .883 r
F
.34808 .52495 m .35711 .51645 L .34956 .51697 L F
.5188 .87038 m .50004 .87223 L .49888 .87783 L .753 .676 .87 r
F
.50004 .87223 m .47816 .87738 L .49888 .87783 L .623 .497 .892 r
F
.47289 .67647 m .4691 .67224 L .45814 .67521 L .775 .509 .805 r
F
.45814 .67521 m .45445 .66969 L .44277 .67185 L .799 .533 .805 r
F
.46909 .67224 m .45445 .66969 L .45814 .67521 L .783 .512 .804 r
F
.6839 .97428 m .66829 .92391 L .69343 .98077 L 1 .001 .163 r
F
.6839 .97428 m .66015 .9183 L .66829 .92391 L F
.49327 .54737 m .49627 .53974 L .48824 .54071 L .684 .511 .842 r
F
.49327 .54737 m .49968 .54666 L .49627 .53974 L F
.7045 .42481 m .73082 .42585 L .71422 .39438 L 1 .509 .593 r
F
.7045 .42481 m .72027 .45323 L .73082 .42585 L F
.63711 .69032 m .64445 .69578 L .64949 .69319 L .484 .211 .899 r
F
.63711 .69032 m .63262 .69494 L .64445 .69578 L F
.50081 .67418 m .49029 .67829 L .49467 .68068 L .754 .483 .804 r
F
.50398 .67554 m .50081 .67418 L .49467 .68068 L .752 .481 .805 r
F
.42284 .89565 m .40078 .90993 L .40007 .91083 L .884 .344 .736 r
F
.56987 .68535 m .57607 .695 L .58116 .68979 L .758 .51 .812 r
F
.56987 .68535 m .56564 .6897 L .57607 .695 L F
.74223 .55148 m .75992 .59352 L .75384 .52738 L 1 .444 .584 r
F
.44174 .53954 m .4399 .53005 L .43144 .5343 L .624 .452 .85 r
F
.44174 .53954 m .44916 .53565 L .4399 .53005 L F
.52405 .67738 m .52472 .68622 L .52947 .68552 L .753 .478 .803 r
F
.52405 .67738 m .52088 .67785 L .52472 .68622 L F
.45358 .88212 m .43278 .88751 L .42677 .89271 L .68 .328 .851 r
F
.45802 .8785 m .43278 .88751 L .45358 .88212 L .796 .668 .865 r
F
.47816 .87738 m .45802 .8785 L .45358 .88212 L .545 .248 .891 r
F
.53902 .55335 m .5525 .55175 L .54555 .54811 L .651 .468 .842 r
F
.53298 .55096 m .53902 .55335 L .54555 .54811 L .667 .48 .839 r
F
.48292 .67259 m .4691 .67224 L .47289 .67647 L .768 .496 .804 r
F
.48634 .67558 m .48292 .67259 L .47289 .67647 L .762 .492 .805 r
F
.54161 .68078 m .54623 .68995 L .55105 .68728 L .753 .48 .804 r
F
.54161 .68078 m .538 .68277 L .54623 .68995 L F
.47376 .54421 m .47412 .536 L .4658 .53831 L .664 .502 .849 r
F
.47376 .54421 m .48069 .54221 L .47412 .536 L F
.30093 .3712 m .32273 .34358 L .31395 .31415 L .556 .02 .593 r
F
.3106 .40301 m .32273 .34358 L .30093 .3712 L .615 .036 .596 r
F
.29297 .45116 m .3106 .40301 L .30093 .3712 L .609 .024 .576 r
F
.60142 .56041 m .60665 .56631 L .61847 .56661 L .491 .295 .875 r
F
.59026 .56112 m .60665 .56631 L .60142 .56041 L .537 .361 .868 r
F
.67791 .33073 m .71176 .31004 L .6855 .29885 L 1 .492 .583 r
F
.67791 .33073 m .70309 .34205 L .71176 .31004 L F
.32883 .65635 m .31608 .61263 L .31651 .65264 L .659 .112 .662 r
F
.33265 .69866 m .31651 .65264 L .32044 .70246 L .815 .161 .642 r
F
.33265 .69866 m .32883 .65635 L .31651 .65264 L F
.37866 .67755 m .36304 .65944 L .36642 .68265 L .944 .44 .731 r
F
.37866 .67755 m .37552 .65906 L .36304 .65944 L F
.39088 .67347 m .37552 .65906 L .37866 .67755 L .935 .499 .752 r
F
.44277 .67185 m .43967 .66488 L .42747 .66621 L .83 .552 .8 r
F
.45445 .66969 m .43967 .66488 L .44277 .67185 L .804 .528 .802 r
F
.56196 1.18014 m .52485 1.11098 L .5642 1.19709 L .068 0 .563 r
F
.56196 1.18014 m .52434 1.09862 L .52485 1.11098 L F
.32775 .76379 m .32044 .70246 L .30831 .70405 L .893 .141 .603 r
F
.49788 .67257 m .48634 .67558 L .49029 .67829 L .757 .484 .804 r
F
.50081 .67418 m .49788 .67257 L .49029 .67829 L .754 .483 .804 r
F
.39088 .67347 m .38801 .65848 L .37552 .65906 L .935 .499 .752 r
F
.40308 .67035 m .38801 .65848 L .39088 .67347 L .91 .531 .77 r
F
.36642 .68265 m .35058 .65926 L .35415 .68857 L .931 .36 .705 r
F
.36642 .68265 m .36304 .65944 L .35058 .65926 L F
.52702 .6766 m .52947 .68552 L .53392 .68436 L .752 .477 .803 r
F
.52702 .6766 m .52405 .67738 L .52947 .68552 L F
.23404 .73207 m .22249 .78627 L .20967 .78609 L .705 0 .294 r
F
.24601 .73734 m .22249 .78627 L .23404 .73207 L .699 0 .285 r
F
.66226 .27104 m .70053 .23509 L .66855 .24033 L 1 .519 .585 r
F
.66226 .27104 m .69304 .26699 L .70053 .23509 L F
.40218 .5299 m .40041 .5176 L .39098 .52529 L .613 .41 .839 r
F
.40218 .5299 m .41077 .52335 L .40041 .5176 L F
.49968 .54666 m .50461 .53936 L .49627 .53974 L .691 .513 .84 r
F
.49968 .54666 m .50633 .54644 L .50461 .53936 L F
.45838 .54119 m .4578 .53251 L .44916 .53565 L .642 .482 .853 r
F
.45838 .54119 m .4658 .53831 L .4578 .53251 L F
.5587 .55574 m .57406 .5574 L .56791 .5525 L .607 .425 .849 r
F
.5525 .55175 m .5587 .55574 L .56791 .5525 L .617 .43 .845 r
F
.30175 .56207 m .30242 .53821 L .29536 .55255 L .081 0 .61 r
F
.29859 .52843 m .30286 .50035 L .29118 .50953 L 0 0 .069 r
F
.30242 .53819 m .30245 .53558 L .29859 .52843 L F
.30221 .52981 m .30201 .53477 L .29859 .52843 L 1 .024 .25 r
F
.30271 .52999 m .30245 .53558 L .30221 .52981 L F
.30245 .53558 m .29887 .6124 L .30221 .52981 L F
.30245 .53558 m .30286 .50035 L .29859 .52843 L 0 0 .069 r
F
.29859 .52843 m .29887 .6124 L .29058 .52539 L 1 .024 .25 r
F
.30201 .53477 m .29887 .6124 L .29859 .52843 L F
.30242 .53819 m .30242 .5382 L .30245 .53558 L 0 0 .069 r
F
.30242 .53819 m .30245 .53558 L .30245 .53558 L F
.30716 .57014 m .30242 .5382 L .30242 .53821 L .081 0 .61 r
F
.30716 .57014 m .30242 .53821 L .30175 .56207 L F
.30271 .52999 m .30291 .53806 L .30245 .53558 L 1 .024 .25 r
F
.30716 .57014 m .31033 .56545 L .30242 .5382 L .081 0 .61 r
F
.31033 .56545 m .30355 .5404 L .30242 .5382 L F
.31033 .56545 m .31379 .56033 L .31183 .55653 L F
.30801 .55688 m .31183 .55653 L .30355 .5404 L F
.31033 .56545 m .31183 .55653 L .30801 .55688 L F
.31483 .52905 m .32483 .53949 L .32318 .55547 L .049 0 .308 r
F
.31608 .61263 m .31911 .58503 L .30716 .57014 L .45 .026 .667 r
F
.31911 .58503 m .31379 .56033 L .30716 .57014 L .192 0 .702 r
F
.31379 .56033 m .30761 .70749 L .30757 .70627 L .195 0 .34 r
F
.30355 .5404 m .30555 .64047 L .30242 .5382 L F
.31183 .55653 m .30757 .70627 L .30555 .64047 L F
.31183 .55653 m .30555 .64047 L .30355 .5404 L F
.31379 .56033 m .30757 .70627 L .31183 .55653 L F
.30291 .53806 m .30479 .6109 L .30247 .53643 L 1 .024 .25 r
F
.30291 .53806 m .30247 .53643 L .30245 .53558 L F
.31483 .52905 m .30778 .70319 L .30271 .52999 L .049 0 .308 r
F
.30778 .70319 m .30765 .70637 L .30608 .65024 L F
.30778 .70319 m .30608 .65024 L .30271 .52999 L F
.31483 .52905 m .32318 .55547 L .31373 .55635 L F
.32698 .52634 m .32483 .53949 L .31483 .52905 L 0 0 0 r
F
.32883 .65635 m .32835 .62163 L .31608 .61263 L .659 .112 .662 r
F
.32835 .62163 m .31911 .58503 L .31608 .61263 L .506 .066 .691 r
F
.32835 .62163 m .33119 .59716 L .31911 .58503 L F
.31911 .58503 m .32409 .57754 L .31379 .56033 L .192 0 .702 r
F
.32409 .57754 m .32543 .57552 L .32397 .57361 L F
.32409 .57754 m .32397 .57361 L .31379 .56033 L F
.32483 .53948 m .33044 .45841 L .32288 .53912 L 1 .192 .588 r
F
.33119 .59716 m .32543 .57552 L .31911 .58503 L .36 .045 .77 r
F
.31379 .56033 m .323 .59715 L .30761 .70749 L .195 0 .34 r
F
.32543 .57552 m .323 .59715 L .32054 .5873 L .366 0 .094 r
F
.32397 .57361 m .32054 .5873 L .31379 .56033 L F
.32543 .57552 m .32054 .5873 L .32397 .57361 L F
.31373 .55635 m .32315 .55548 L .30789 .70025 L .049 0 .308 r
F
.32334 .55359 m .32288 .53912 L .31708 .60113 L 1 .192 .588 r
F
.30619 .63081 m .32041 .4331 L .30287 .50034 L 1 .181 .517 r
F
.30791 .6985 m .3104 .64563 L .30619 .63081 L F
.3104 .64563 m .32041 .4331 L .30619 .63081 L F
.30411 .58901 m .30504 .61767 L .30247 .53629 L 0 0 .069 r
F
.30504 .61767 m .3074 .69055 L .30509 .61835 L F
.30504 .61767 m .30509 .61835 L .30247 .53629 L F
.3074 .69055 m .30739 .69035 L .30703 .67888 L F
.30703 .67905 m .30703 .67888 L .30247 .53629 L F
.3074 .69055 m .30703 .67888 L .30703 .67905 L F
.30791 .6985 m .33043 .4584 L .32041 .4331 L 1 .181 .517 r
F
.33905 .52482 m .33687 .52267 L .32698 .52634 L .525 0 .704 r
F
.32698 .52634 m .33687 .52267 L .32483 .53949 L 0 0 0 r
F
.32483 .53948 m .34058 .47572 L .33044 .45841 L 1 .192 .588 r
F
.31521 .59063 m .32742 .50481 L .30649 .58057 L 1 .374 .596 r
F
.30479 .6109 m .30605 .64955 L .30411 .58901 L 0 0 .069 r
F
.30605 .64955 m .30732 .68819 L .30411 .58901 L F
.30732 .68819 m .30778 .70236 L .30731 .68802 L F
.30732 .68819 m .30731 .68802 L .30411 .58901 L F
.30247 .53629 m .30754 .6948 L .30315 .51198 L F
.30754 .6948 m .30753 .69377 L .30315 .51198 L F
.3076 .69682 m .30758 .69405 L .30315 .51198 L F
.30245 .53558 m .30245 .53558 L .30286 .50035 L F
.30242 .5382 m .30315 .51198 L .30286 .50035 L F
.27868 .51483 m .28795 .58468 L .27688 .56228 L 1 .026 .237 r
F
.29058 .52539 m .28795 .58468 L .27868 .51483 L 1 .057 .282 r
F
.29058 .52539 m .29887 .6124 L .28795 .58468 L F
.28795 .58469 m .29076 .61258 L .27688 .56229 L .938 0 .089 r
F
.29076 .61258 m .29065 .61241 L .27688 .56229 L F
.29079 .6129 m .28837 .6086 L .27153 .69756 L 1 .339 .564 r
F
.29079 .6129 m .28853 .60922 L .28837 .6086 L .938 0 .089 r
F
.29075 .61276 m .28837 .6086 L .27688 .56229 L F
.25964 .68961 m .2787 .59288 L .27 .57952 L 1 .298 .573 r
F
.27153 .69756 m .28837 .6086 L .28216 .59846 L 1 .315 .57 r
F
.27688 .56229 m .28837 .6086 L .28042 .59563 L .962 0 .104 r
F
.27153 .69756 m .28218 .59827 L .28042 .59563 L 1 .315 .57 r
F
.2834 .70587 m .29079 .6129 L .27153 .69756 L 1 .339 .564 r
F
.2834 .70587 m .29771 .62527 L .29079 .6129 L F
.28795 .58469 m .29771 .62527 L .29684 .62372 L .938 0 .089 r
F
.29076 .61258 m .29684 .62372 L .29079 .6129 L F
.28795 .58469 m .29684 .62372 L .29076 .61258 L F
.30597 .66131 m .30688 .70664 L .29888 .61241 L 1 .024 .25 r
F
.30597 .66131 m .29888 .61241 L .29888 .61241 L F
.30754 .6948 m .3076 .69682 L .30753 .69377 L 0 0 .069 r
F
.3076 .69682 m .30778 .70236 L .30758 .69405 L F
.31327 .64862 m .31245 .65063 L .30788 .69942 L 1 .192 .588 r
F
.30789 .70025 m .32318 .55547 L .30765 .70637 L .049 0 .308 r
F
.32315 .55548 m .32318 .55547 L .30789 .70025 L F
.3074 .69055 m .30778 .70236 L .30739 .69035 L 0 0 .069 r
F
.30242 .5382 m .30479 .6109 L .30247 .53629 L F
.30245 .53558 m .30597 .66131 L .29887 .6124 L 1 .024 .25 r
F
.30597 .66131 m .30742 .713 L .30688 .70664 L F
.30479 .6109 m .30737 .71088 L .30245 .53558 L F
.30737 .71088 m .30742 .713 L .30736 .71085 L F
.30737 .71088 m .30736 .71085 L .30245 .53558 L F
.33119 .59716 m .33725 .58606 L .32543 .57552 L .36 .045 .77 r
F
.32543 .57552 m .33496 .58682 L .323 .59715 L .366 0 .094 r
F
.33725 .58606 m .33496 .58682 L .32543 .57552 L 0 0 0 r
F
.33496 .58682 m .33753 .57975 L .32301 .59716 L .647 .02 .738 r
F
.32301 .59716 m .33753 .57975 L .32644 .58668 L .758 .091 .716 r
F
.32301 .59716 m .32644 .58668 L .31621 .65782 L F
.31599 .65189 m .31621 .65782 L .3139 .67392 L F
.31599 .65189 m .3139 .67392 L .31325 .67326 L F
.31325 .67326 m .3139 .67392 L .30717 .72074 L F
.30691 .72819 m .30704 .72686 L .3066 .64424 L .559 .025 .602 r
F
.32301 .59716 m .31621 .65782 L .31599 .65189 L .758 .091 .716 r
F
.31919 .59268 m .31708 .60113 L .31245 .65063 L 1 .192 .588 r
F
.31919 .59268 m .31245 .65063 L .31327 .64862 L F
.32334 .55359 m .31708 .60113 L .31919 .59268 L F
.30704 .72686 m .32644 .58668 L .31521 .59063 L 1 .373 .538 r
F
.30568 .71036 m .3066 .64424 L .29888 .61242 L .559 .025 .602 r
F
.30691 .72819 m .3066 .64424 L .30568 .71036 L F
.30691 .72819 m .30717 .72768 L .30704 .72686 L F
.30703 .72869 m .30717 .72768 L .30704 .72686 L 1 .373 .538 r
F
.30717 .72768 m .32644 .58668 L .30704 .72686 L F
.30717 .72768 m .30725 .72752 L .30704 .72686 L .559 .025 .602 r
F
.30704 .72686 m .32302 .69649 L .31262 .66906 L F
.30725 .72752 m .32302 .69649 L .30704 .72686 L F
.30685 .73002 m .30704 .72686 L .29522 .7151 L 1 .373 .538 r
F
.30704 .72686 m .31133 .6554 L .29897 .7012 L F
.30704 .72686 m .29897 .7012 L .29522 .7151 L F
.31133 .6554 m .31521 .59063 L .3066 .64424 L F
.31133 .6554 m .3066 .64424 L .29522 .7151 L F
.30704 .72686 m .30738 .64745 L .3066 .64424 L .559 .025 .602 r
F
.30078 .63051 m .30435 .63964 L .30103 .63285 L .893 0 .045 r
F
.29888 .61242 m .30647 .64368 L .30078 .63051 L F
.30647 .64368 m .3066 .64424 L .30556 .6418 L F
.30647 .64368 m .30556 .6418 L .30078 .63051 L F
.29888 .61242 m .30096 .63214 L .29466 .60917 L F
.29887 .61241 m .29466 .60917 L .28795 .58469 L F
.29888 .61242 m .29466 .60917 L .29887 .61241 L F
.29888 .61241 m .29888 .61241 L .29887 .6124 L 1 .024 .25 r
F
.30096 .63214 m .30088 .63198 L .28795 .58469 L .893 0 .045 r
F
.29522 .7151 m .30103 .63285 L .2834 .70587 L 1 .367 .555 r
F
.30098 .63233 m .29796 .62584 L .29771 .62527 L .893 0 .045 r
F
.30088 .63198 m .29771 .62527 L .28795 .58469 L F
.30098 .63233 m .29771 .62527 L .30088 .63198 L F
.29869 .66593 m .30442 .63984 L .30103 .63285 L 1 .367 .555 r
F
.30442 .63984 m .30443 .6398 L .30103 .63285 L F
.30098 .63233 m .30103 .63285 L .29772 .62534 L .893 0 .045 r
F
.30103 .63285 m .29771 .62527 L .2834 .70587 L 1 .367 .555 r
F
.30103 .63285 m .3022 .64398 L .29805 .62669 L .893 0 .045 r
F
.30103 .63285 m .29805 .62669 L .29772 .62534 L F
.30111 .67844 m .3066 .64424 L .29869 .66593 L 1 .367 .555 r
F
.3066 .64424 m .30443 .6398 L .29869 .66593 L F
.3066 .64424 m .30734 .64729 L .30435 .63964 L .893 0 .045 r
F
.3066 .64424 m .30435 .63964 L .30078 .63051 L F
.3066 .64424 m .31521 .59063 L .30443 .6398 L 1 .367 .555 r
F
.30096 .63214 m .30098 .63233 L .30088 .63198 L .893 0 .045 r
F
.30103 .63285 m .30411 .58919 L .29771 .62527 L 1 .367 .555 r
F
.29796 .62584 m .29772 .62534 L .29771 .62527 L .893 0 .045 r
F
.29786 .62438 m .30411 .58919 L .29137 .61187 L 1 .339 .564 r
F
.29216 .61355 m .29137 .61187 L .29132 .61196 L F
.29786 .62438 m .29137 .61187 L .29216 .61355 L F
.29515 .61997 m .29132 .61196 L .29079 .6129 L F
.29786 .62438 m .29132 .61196 L .29515 .61997 L F
.30103 .63285 m .30682 .6289 L .30411 .58919 L 1 .367 .555 r
F
.30443 .6398 m .30682 .6289 L .30103 .63285 L F
.30103 .63285 m .30734 .64729 L .3022 .64398 L .893 0 .045 r
F
.30435 .63964 m .30734 .64729 L .30103 .63285 L F
.30704 .72686 m .31262 .66906 L .30738 .64745 L .559 .025 .602 r
F
.30685 .73002 m .30703 .72869 L .30704 .72686 L 1 .373 .538 r
F
.30976 .65724 m .31262 .66906 L .30874 .65972 L .893 0 .045 r
F
.30976 .65724 m .30874 .65972 L .3022 .64398 L F
.33977 .74735 m .33265 .69866 L .32044 .70246 L .978 .206 .619 r
F
.32302 .69649 m .33153 .70202 L .31262 .66906 L 0 0 .517 r
F
.31262 .66906 m .33153 .70202 L .32167 .6877 L .695 0 0 r
F
.31262 .66906 m .31608 .67617 L .3022 .64398 L F
.31608 .67617 m .32167 .6877 L .31693 .67705 L F
.31608 .67617 m .31693 .67705 L .3022 .64398 L F
.3022 .64398 m .31693 .67705 L .3118 .6738 L .816 0 0 r
F
.31693 .67705 m .32167 .6877 L .31709 .68125 L F
.31693 .67705 m .31709 .68125 L .3118 .6738 L F
.30682 .6289 m .31521 .59063 L .30737 .58961 L 1 .367 .555 r
F
.30682 .6289 m .30737 .58961 L .30411 .58919 L F
.29522 .7151 m .30111 .67844 L .29869 .66593 L F
.29094 .61098 m .30411 .58919 L .29313 .58345 L 1 .339 .564 r
F
.29079 .6129 m .29137 .61187 L .29094 .61098 L F
.29137 .61187 m .30411 .58919 L .29094 .61098 L F
.28097 .58934 m .29313 .58345 L .28222 .57501 L 1 .315 .57 r
F
.28057 .59392 m .2824 .5924 L .28097 .58934 L F
.2824 .5924 m .29313 .58345 L .28097 .58934 L F
.28045 .59538 m .28106 .59481 L .28057 .59392 L F
.28106 .59481 m .29313 .58345 L .28057 .59392 L F
.29771 .62527 m .29786 .62438 L .29079 .6129 L 1 .339 .564 r
F
.29079 .6129 m .3022 .64398 L .29171 .62207 L .938 0 .089 r
F
.29771 .62527 m .3022 .64398 L .29079 .6129 L F
.28042 .59563 m .29171 .62207 L .28116 .60256 L .962 0 .104 r
F
.28837 .6086 m .29171 .62207 L .28042 .59563 L F
.28216 .59846 m .28837 .6086 L .28218 .59827 L 1 .315 .57 r
F
.28042 .59563 m .28218 .59827 L .28045 .59538 L F
.27153 .69756 m .28042 .59563 L .25964 .68961 L F
.27688 .56229 m .28042 .59563 L .26578 .54196 L .962 0 .104 r
F
.28042 .59563 m .2787 .59288 L .26578 .54196 L F
.28042 .59563 m .28222 .57501 L .2787 .59288 L 1 .315 .57 r
F
.28042 .59563 m .2787 .59288 L .25964 .68961 L F
.28042 .59563 m .28116 .60256 L .2787 .59288 L .962 0 .104 r
F
.27005 .58004 m .28116 .60256 L .27057 .58464 L .977 0 .112 r
F
.27 .57952 m .27077 .58111 L .27005 .58004 L F
.27077 .58111 m .28116 .60256 L .27005 .58004 L F
.26578 .54196 m .2787 .59288 L .2722 .5829 L F
.26578 .54196 m .2722 .5829 L .26999 .57946 L F
.24773 .68183 m .26879 .57769 L .25952 .56403 L 1 .286 .574 r
F
.26999 .57946 m .2722 .5829 L .27 .57952 L .977 0 .112 r
F
.25964 .68961 m .27 .57952 L .24773 .68183 L 1 .298 .573 r
F
.26578 .54196 m .27 .57952 L .25467 .52266 L .977 0 .112 r
F
.26997 .57944 m .26879 .57769 L .25467 .52266 L F
.27 .57952 m .26879 .57769 L .26997 .57944 L F
.25467 .52266 m .26879 .57769 L .2606 .56562 L .987 0 .119 r
F
.25952 .56401 m .2606 .56562 L .25952 .56403 L F
.25467 .52266 m .2606 .56562 L .25952 .56401 L F
.23581 .67415 m .25869 .56281 L .24901 .54891 L 1 .277 .575 r
F
.24773 .68183 m .25952 .56403 L .23581 .67415 L 1 .286 .574 r
F
.25467 .52266 m .25952 .56403 L .24357 .5039 L .987 0 .119 r
F
.25951 .564 m .25869 .56281 L .24357 .5039 L F
.25952 .56403 m .25869 .56281 L .25951 .564 L F
.24357 .5039 m .25869 .56281 L .24901 .54891 L .996 0 .124 r
F
.24903 .54876 m .25869 .56278 L .24906 .54845 L 1 .277 .575 r
F
.24901 .54891 m .25724 .5607 L .24903 .54876 L F
.25724 .5607 m .25869 .56278 L .24903 .54876 L F
.25952 .56403 m .26055 .55377 L .25869 .56281 L 1 .286 .574 r
F
.25952 .56403 m .25869 .56281 L .23581 .67415 L F
.25952 .56403 m .25995 .56774 L .25869 .56281 L .987 0 .119 r
F
.24901 .54891 m .25995 .56774 L .24932 .5515 L .996 0 .124 r
F
.25869 .56281 m .25995 .56774 L .24901 .54891 L F
.25869 .56281 m .25869 .56278 L .24901 .54891 L 1 .277 .575 r
F
.24906 .54845 m .26055 .55377 L .24975 .5419 L F
.25869 .56278 m .26055 .55377 L .24906 .54845 L F
.25952 .564 m .2688 .57761 L .25959 .5633 L 1 .286 .574 r
F
.25952 .56403 m .26203 .5677 L .25952 .564 L F
.26203 .5677 m .2688 .57761 L .25952 .564 L F
.27 .57952 m .27137 .56492 L .26879 .57769 L 1 .298 .573 r
F
.27 .57952 m .26879 .57769 L .24773 .68183 L F
.27 .57952 m .27057 .58464 L .26879 .57769 L .977 0 .112 r
F
.25952 .56403 m .27057 .58464 L .25995 .56774 L .987 0 .119 r
F
.26879 .57769 m .27057 .58464 L .25952 .56403 L F
.26879 .57769 m .2688 .57761 L .25952 .56403 L 1 .286 .574 r
F
.25959 .5633 m .27137 .56492 L .26055 .55377 L F
.2688 .57761 m .27137 .56492 L .25959 .5633 L F
.2787 .59288 m .28116 .60256 L .27 .57952 L .977 0 .112 r
F
.27 .57952 m .27879 .59246 L .27016 .57781 L 1 .298 .573 r
F
.2787 .59288 m .27879 .59246 L .27 .57952 L F
.27016 .57781 m .28222 .57501 L .27137 .56492 L F
.27879 .59246 m .28222 .57501 L .27016 .57781 L F
.29079 .6129 m .28989 .61131 L .29075 .61276 L .938 0 .089 r
F
.28989 .61131 m .28837 .6086 L .29075 .61276 L F
.29076 .61258 m .29079 .6129 L .29065 .61241 L F
.29079 .6129 m .29313 .58345 L .28837 .6086 L 1 .339 .564 r
F
.28837 .6086 m .29313 .58345 L .28045 .59538 L 1 .315 .57 r
F
.29079 .6129 m .29171 .62207 L .28853 .60922 L .938 0 .089 r
F
.29313 .58345 m .30578 .49536 L .28222 .57501 L 1 .315 .584 r
F
.30287 .50034 m .32041 .4331 L .3106 .40301 L .786 .066 .569 r
F
.30578 .49536 m .30824 .47826 L .30572 .48765 L 1 .315 .584 r
F
.29118 .50953 m .30286 .50035 L .29297 .45117 L .103 0 .487 r
F
.30287 .50034 m .3106 .40301 L .29297 .45116 L .786 .066 .569 r
F
.30578 .49536 m .30572 .48765 L .28222 .57501 L 1 .315 .584 r
F
.30578 .49536 m .31781 .49225 L .30824 .47826 L F
.29313 .58345 m .30614 .53536 L .30578 .49536 L F
.30614 .53536 m .31781 .49225 L .30578 .49536 L F
.30411 .58919 m .30643 .57279 L .29313 .58345 L 1 .34 .588 r
F
.30643 .57279 m .31781 .49225 L .30614 .53536 L F
.30643 .57279 m .30614 .53536 L .29313 .58345 L F
.30654 .5895 m .30649 .58057 L .30411 .58919 L 1 .374 .596 r
F
.31521 .59063 m .30649 .58057 L .30654 .5895 L F
.30734 .64729 m .30976 .65724 L .30786 .6539 L .893 0 .045 r
F
.30734 .64729 m .30786 .6539 L .3022 .64398 L F
.32483 .53948 m .32288 .53912 L .32334 .55359 L 1 .192 .588 r
F
.30643 .57279 m .32742 .50481 L .31781 .49225 L 1 .34 .588 r
F
.30411 .58919 m .30649 .58057 L .30643 .57279 L F
.30649 .58057 m .32742 .50481 L .30643 .57279 L F
.24385 .46589 m .25467 .52265 L .24357 .50389 L 1 .002 .151 r
F
.25536 .48376 m .25467 .52265 L .24385 .46589 L 1 .004 .17 r
F
.53298 .55096 m .54555 .54811 L .53799 .54495 L .667 .48 .839 r
F
.52657 .54902 m .53298 .55096 L .53799 .54495 L .682 .493 .837 r
F
.34887 .73248 m .3338 .69821 L .3409 .74554 L 1 .299 .641 r
F
.34887 .73248 m .34188 .69464 L .3338 .69821 L F
.29366 .87721 m .26912 .78279 L .28265 .88074 L .729 .06 .584 r
F
.29366 .87721 m .28074 .78295 L .26912 .78279 L F
.34017 .52478 m .34849 .51719 L .33905 .52482 L .565 .098 .844 r
F
.34017 .52478 m .34956 .51697 L .34849 .51719 L F
.40308 .67035 m .40051 .65794 L .38801 .65848 L .91 .531 .77 r
F
.41527 .66798 m .40051 .65794 L .40308 .67035 L .879 .541 .782 r
F
.35415 .68857 m .33815 .6581 L .34188 .69464 L .897 .275 .679 r
F
.35415 .68857 m .35058 .65926 L .33815 .6581 L F
.32477 .24996 m .35016 .23756 L .31722 .21987 L .381 0 .593 r
F
.48099 .87285 m .45802 .8785 L .47816 .87738 L .663 .539 .888 r
F
.50004 .87223 m .48099 .87285 L .47816 .87738 L .623 .497 .892 r
F
.33905 .52482 m .34848 .51719 L .33687 .52267 L .525 0 .704 r
F
.64226 .56905 m .64709 .57547 L .6595 .57994 L .163 .002 .836 r
F
.63034 .56748 m .64709 .57547 L .64226 .56905 L .333 .077 .879 r
F
.58501 .68435 m .59243 .6938 L .59695 .68776 L .746 .533 .824 r
F
.58501 .68435 m .58116 .68979 L .59243 .6938 L F
.50633 .54644 m .51311 .53964 L .50461 .53936 L .697 .513 .837 r
F
.50633 .54644 m .51312 .54675 L .51311 .53964 L F
.52657 .54902 m .53799 .54495 L .52996 .54244 L .682 .493 .837 r
F
.51991 .54762 m .52657 .54902 L .52996 .54244 L .694 .503 .835 r
F
.33977 .74735 m .32044 .70246 L .32775 .76379 L .978 .206 .619 r
F
.62473 .68743 m .63262 .69494 L .63711 .69032 L .584 .453 .887 r
F
.62473 .68743 m .62076 .69321 L .63262 .69494 L F
.34188 .69464 m .32999 .65662 L .3338 .69821 L .863 .21 .656 r
F
.34188 .69464 m .33815 .6581 L .32999 .65662 L F
.49525 .67074 m .48292 .67259 L .48634 .67558 L .76 .486 .803 r
F
.49788 .67257 m .49525 .67074 L .48634 .67558 L .757 .484 .804 r
F
.7461 .52029 m .76821 .46544 L .75708 .50061 L 0 0 0 r
F
.7461 .52029 m .75694 .4875 L .76821 .46544 L F
.31395 .31415 m .34005 .30847 L .33238 .27955 L .458 .005 .599 r
F
.32273 .34358 m .34005 .30847 L .31395 .31415 L .476 .009 .604 r
F
.52974 .67554 m .53392 .68436 L .538 .68277 L .752 .477 .803 r
F
.52974 .67554 m .52702 .6766 L .53392 .68436 L F
.33379 .69821 m .32883 .65635 L .33265 .69866 L .849 .181 .644 r
F
.33379 .69821 m .32998 .65661 L .32883 .65635 L F
.3409 .74555 m .33379 .69821 L .33265 .69866 L 1 .228 .62 r
F
.3409 .74555 m .33265 .69866 L .33977 .74735 L F
.41527 .66798 m .413 .65758 L .40051 .65794 L .879 .541 .782 r
F
.42747 .66621 m .413 .65758 L .41527 .66798 L .848 .538 .79 r
F
.51312 .54675 m .52162 .54066 L .51311 .53964 L .699 .509 .835 r
F
.51312 .54675 m .51991 .54762 L .52162 .54066 L F
.54471 .67844 m .55105 .68728 L .55519 .68415 L .752 .481 .805 r
F
.54471 .67844 m .54161 .68078 L .55105 .68728 L F
.51991 .54762 m .52996 .54244 L .52162 .54066 L .694 .503 .835 r
F
.55856 .68064 m .56564 .6897 L .56987 .68535 L .752 .491 .808 r
F
.55856 .68064 m .55519 .68415 L .56564 .6897 L F
.58433 .55547 m .59026 .56112 L .60142 .56041 L .532 .341 .861 r
F
.57406 .5574 m .59026 .56112 L .58433 .55547 L .571 .391 .857 r
F
.48292 .67259 m .48007 .66936 L .4691 .67224 L .768 .496 .804 r
F
.46909 .67224 m .46615 .66775 L .45445 .66969 L .783 .512 .804 r
F
.48007 .66936 m .46615 .66775 L .46909 .67224 L .772 .499 .803 r
F
.56791 .5525 m .57406 .5574 L .58433 .55547 L .574 .383 .851 r
F
.32998 .65661 m .32836 .62163 L .32883 .65635 L .698 .136 .666 r
F
.45445 .66969 m .45188 .66385 L .43967 .66488 L .804 .528 .802 r
F
.46615 .66775 m .45188 .66385 L .45445 .66969 L .786 .511 .802 r
F
.43144 .5343 m .43062 .52426 L .42111 .52891 L .605 .426 .85 r
F
.43144 .5343 m .4399 .53005 L .43062 .52426 L F
.32998 .65661 m .32951 .62238 L .32836 .62163 L .698 .136 .666 r
F
.33815 .6581 m .32951 .62238 L .32999 .65662 L .707 .156 .676 r
F
.48069 .54221 m .48319 .5342 L .47412 .536 L .672 .512 .849 r
F
.48069 .54221 m .48824 .54071 L .48319 .5342 L F
.75992 .59352 m .76158 .66357 L .77366 .64907 L 1 .441 .593 r
F
.39098 .52529 m .39002 .51168 L .37974 .52116 L .638 .422 .831 r
F
.39098 .52529 m .40041 .5176 L .39002 .51168 L F
.42677 .89271 m .40575 .90353 L .40078 .90993 L 1 .635 .77 r
F
.43278 .88751 m .40575 .90353 L .42677 .89271 L 1 .917 .793 r
F
.5525 .55175 m .56791 .5525 L .56046 .54749 L .617 .43 .845 r
F
.54555 .54811 m .5525 .55175 L .56046 .54749 L .637 .445 .84 r
F
.42747 .66621 m .4255 .65744 L .413 .65758 L .848 .538 .79 r
F
.43967 .66488 m .4255 .65744 L .42747 .66621 L .822 .528 .795 r
F
.49297 .66871 m .48007 .66936 L .48292 .67259 L .763 .488 .803 r
F
.49525 .67074 m .49297 .66871 L .48292 .67259 L .76 .486 .803 r
F
.53215 .67422 m .538 .68277 L .54161 .68078 L .752 .478 .803 r
F
.53215 .67422 m .52974 .67554 L .538 .68277 L F
.61262 .56017 m .61847 .56661 L .63034 .56748 L .442 .216 .878 r
F
.60142 .56041 m .61847 .56661 L .61262 .56017 L .491 .295 .875 r
F
.67452 .96956 m .66014 .9183 L .68389 .97428 L 1 .004 .183 r
F
.67452 .96956 m .65209 .9125 L .66014 .9183 L F
.51196 .66923 m .50732 .67662 L .51077 .6774 L .754 .48 .803 r
F
.51367 .66946 m .51077 .6774 L .51418 .67786 L .754 .479 .803 r
F
.51367 .66946 m .51196 .66923 L .51077 .6774 L F
.57307 .68067 m .58116 .68979 L .58501 .68435 L .746 .505 .815 r
F
.57307 .68067 m .56987 .68535 L .58116 .68979 L F
.51023 .66884 m .50398 .67554 L .50732 .67662 L .755 .48 .803 r
F
.51196 .66923 m .51023 .66884 L .50732 .67662 L .754 .48 .803 r
F
.33815 .6581 m .33766 .62718 L .32951 .62238 L .707 .156 .676 r
F
.35058 .65926 m .33766 .62718 L .33815 .6581 L .741 .205 .694 r
F
.51537 .66953 m .51418 .67786 L .51757 .67801 L .754 .479 .803 r
F
.51537 .66953 m .51367 .66946 L .51418 .67786 L F
.61234 .68453 m .62076 .69321 L .62473 .68743 L .655 .52 .861 r
F
.61234 .68453 m .60886 .69076 L .62076 .69321 L F
.74798 .61419 m .76158 .66357 L .75992 .59352 L 1 .463 .596 r
F
.74223 .55148 m .74798 .61419 L .75992 .59352 L 1 .444 .584 r
F
.55974 1.16444 m .52434 1.09862 L .56196 1.18014 L 0 0 .553 r
F
.50856 .66829 m .50081 .67418 L .50398 .67554 L .755 .48 .803 r
F
.51023 .66884 m .50856 .66829 L .50398 .67554 L F
.53529 .86127 m .5188 .87038 L .53744 .86606 L .81 .735 .862 r
F
.55189 .85683 m .53744 .86606 L .55565 .85983 L .763 .693 .873 r
F
.55189 .85683 m .53529 .86127 L .53744 .86606 L F
.51703 .66944 m .51757 .67801 L .52088 .67785 L .754 .479 .803 r
F
.51703 .66944 m .51537 .66953 L .51757 .67801 L F
.30469 .87368 m .28074 .78295 L .29366 .87721 L .753 .066 .581 r
F
.30469 .87368 m .29242 .78202 L .28074 .78295 L F
.5183 .86471 m .50004 .87223 L .5188 .87038 L .757 .683 .871 r
F
.53529 .86127 m .5183 .86471 L .5188 .87038 L .81 .735 .862 r
F
.50697 .66761 m .49788 .67257 L .50081 .67418 L .756 .481 .803 r
F
.50856 .66829 m .50697 .66761 L .50081 .67418 L .755 .48 .803 r
F
.4658 .53831 m .46752 .53 L .4578 .53251 L .646 .495 .856 r
F
.4658 .53831 m .47412 .536 L .46752 .53 L F
.51862 .6692 m .52088 .67785 L .52405 .67738 L .754 .479 .803 r
F
.51862 .6692 m .51703 .66944 L .52088 .67785 L F
.44916 .53565 m .44978 .52677 L .4399 .53005 L .617 .459 .858 r
F
.44916 .53565 m .4578 .53251 L .44978 .52677 L F
.43967 .66488 m .438 .65752 L .4255 .65744 L .822 .528 .795 r
F
.45188 .66385 m .438 .65752 L .43967 .66488 L .801 .516 .799 r
F
.56783 .85283 m .55565 .85983 L .57312 .8541 L .581 .359 .894 r
F
.56783 .85283 m .55189 .85683 L .55565 .85983 L F
.54723 .67579 m .55519 .68415 L .55856 .68064 L .75 .481 .805 r
F
.54723 .67579 m .54471 .67844 L .55519 .68415 L F
.24601 .73734 m .23532 .78657 L .22249 .78627 L .699 0 .285 r
F
.25801 .74293 m .23532 .78657 L .24601 .73734 L .693 0 .273 r
F
.46615 .66775 m .46411 .66306 L .45188 .66385 L .786 .511 .802 r
F
.47787 .66595 m .46411 .66306 L .46615 .66775 L .774 .498 .802 r
F
.48007 .66936 m .47787 .66595 L .46615 .66775 L .772 .499 .803 r
F
.35058 .65926 m .35007 .63305 L .33766 .62718 L .741 .205 .694 r
F
.36304 .65944 m .35007 .63305 L .35058 .65926 L .785 .273 .713 r
F
.48824 .54071 m .49284 .53291 L .48319 .5342 L .687 .521 .845 r
F
.48824 .54071 m .49627 .53974 L .49284 .53291 L F
.60491 .85658 m .59631 .85097 L .61309 .86267 L .391 0 0 r
F
.60491 .85658 m .58962 .85251 L .59631 .85097 L F
.50551 .66679 m .49525 .67074 L .49788 .67257 L .758 .482 .803 r
F
.50697 .66761 m .50551 .66679 L .49788 .67257 L .756 .481 .803 r
F
.70961 .47957 m .73291 .49623 L .72027 .45323 L 1 .442 .59 r
F
.70961 .47957 m .72163 .52086 L .73291 .49623 L F
.54555 .54811 m .56046 .54749 L .55211 .54281 L .637 .445 .84 r
F
.53799 .54495 m .54555 .54811 L .55211 .54281 L .665 .467 .835 r
F
.53421 .67265 m .54161 .68078 L .54471 .67844 L .752 .478 .804 r
F
.53421 .67265 m .53215 .67422 L .54161 .68078 L F
.49297 .66871 m .49107 .66654 L .48007 .66936 L .763 .488 .803 r
F
.49107 .66654 m .47787 .66595 L .48007 .66936 L .765 .49 .803 r
F
.5201 .66881 m .52405 .67738 L .52702 .6766 L .754 .478 .803 r
F
.5201 .66881 m .51862 .6692 L .52405 .67738 L F
.59995 .68161 m .60886 .69076 L .61234 .68453 L .696 .519 .84 r
F
.59995 .68161 m .59695 .68776 L .60886 .69076 L F
.37974 .52116 m .37962 .5056 L .36846 .51796 L .693 .451 .817 r
F
.37974 .52116 m .39002 .51168 L .37962 .5056 L F
.25536 .48376 m .26578 .54195 L .25467 .52265 L 1 .004 .17 r
F
.26696 .50038 m .26578 .54195 L .25536 .48376 L 1 .011 .198 r
F
.65423 .57148 m .6595 .57994 L .67207 .58929 L 0 0 .71 r
F
.64226 .56905 m .6595 .57994 L .65423 .57148 L .163 .002 .836 r
F
.5183 .86471 m .5012 .86667 L .50004 .87223 L .757 .683 .871 r
F
.5012 .86667 m .48099 .87285 L .50004 .87223 L .705 .623 .881 r
F
.42111 .52891 m .42132 .51813 L .41077 .52335 L .591 .398 .846 r
F
.42111 .52891 m .43062 .52426 L .42132 .51813 L F
.56111 .67681 m .56987 .68535 L .57307 .68067 L .747 .488 .809 r
F
.56111 .67681 m .55856 .68064 L .56987 .68535 L F
.56791 .5525 m .58433 .55547 L .57716 .5496 L .574 .383 .851 r
F
.56046 .54749 m .56791 .5525 L .57716 .5496 L .588 .389 .844 r
F
.36304 .65944 m .36254 .63744 L .35007 .63305 L .785 .273 .713 r
F
.37552 .65906 m .36254 .63744 L .36304 .65944 L .818 .343 .732 r
F
.68562 .40719 m .71422 .39438 L .69438 .37434 L 1 .517 .587 r
F
.68562 .40719 m .7045 .42481 L .71422 .39438 L F
.50419 .66587 m .49297 .66871 L .49525 .67074 L .759 .482 .803 r
F
.50551 .66679 m .50419 .66587 L .49525 .67074 L .758 .482 .803 r
F
.45188 .66385 m .45051 .65781 L .438 .65752 L .801 .516 .799 r
F
.46411 .66306 m .45051 .65781 L .45188 .66385 L .785 .505 .801 r
F
.52146 .66828 m .52702 .6766 L .52974 .67554 L .754 .478 .803 r
F
.52146 .66828 m .5201 .66881 L .52702 .6766 L F
.37552 .65906 m .37505 .64069 L .36254 .63744 L .818 .343 .732 r
F
.38801 .65848 m .37505 .64069 L .37552 .65906 L .837 .404 .75 r
F
.59465 .55401 m .60142 .56041 L .61262 .56017 L .492 .286 .865 r
F
.58433 .55547 m .60142 .56041 L .59465 .55401 L .532 .341 .861 r
F
.45802 .8785 m .43881 .88157 L .43278 .88751 L .796 .668 .865 r
F
.46249 .87375 m .43881 .88157 L .45802 .8785 L .875 .803 .858 r
F
.48099 .87285 m .46249 .87375 L .45802 .8785 L .663 .539 .888 r
F
.32951 .62238 m .33119 .59717 L .32836 .62163 L .552 .1 .7 r
F
.32951 .62238 m .33233 .59817 L .33119 .59717 L F
.33766 .62718 m .33233 .59817 L .32951 .62238 L .574 .124 .709 r
F
.49627 .53974 m .50287 .53224 L .49285 .53291 L .705 .528 .839 r
F
.49627 .53974 m .50461 .53936 L .50287 .53224 L F
.38801 .65848 m .38758 .64314 L .37505 .64069 L .837 .404 .75 r
F
.40051 .65794 m .38758 .64314 L .38801 .65848 L .842 .451 .765 r
F
.53799 .54495 m .55211 .54281 L .54302 .53874 L .665 .467 .835 r
F
.52996 .54244 m .53799 .54495 L .54302 .53874 L .693 .49 .831 r
F
.57716 .5496 m .58433 .55547 L .59465 .55401 L .535 .332 .852 r
F
.58756 .67867 m .59695 .68776 L .59995 .68161 L .719 .504 .825 r
F
.58756 .67867 m .58501 .68435 L .59695 .68776 L F
.31575 .87014 m .29242 .78202 L .30469 .87368 L .787 .073 .577 r
F
.31575 .87014 m .30419 .77937 L .29242 .78202 L F
.6947 .45511 m .72027 .45323 L .7045 .42481 L 1 .54 .6 r
F
.6947 .45511 m .70961 .47957 L .72027 .45323 L F
.40051 .65794 m .40013 .6451 L .38758 .64314 L .842 .451 .765 r
F
.413 .65758 m .40013 .6451 L .40051 .65794 L .836 .481 .776 r
F
.27025 1.00406 m .23887 .89477 L .26005 1.01328 L .705 .053 .584 r
F
.27025 1.00406 m .24978 .89128 L .23887 .89477 L F
.58285 .85091 m .57312 .8541 L .58962 .85251 L .308 0 .831 r
F
.58285 .85091 m .56783 .85283 L .57312 .8541 L F
.50305 .66484 m .49107 .66654 L .49297 .66871 L .76 .483 .802 r
F
.50419 .66587 m .50305 .66484 L .49297 .66871 L .759 .482 .803 r
F
.53589 .67087 m .54471 .67844 L .54723 .67579 L .751 .477 .804 r
F
.53589 .67087 m .53421 .67265 L .54471 .67844 L F
.62386 .56032 m .63034 .56748 L .64226 .56905 L .391 .144 .875 r
F
.61262 .56017 m .63034 .56748 L .62386 .56032 L .442 .216 .878 r
F
.52267 .66761 m .52974 .67554 L .53215 .67422 L .754 .478 .803 r
F
.52267 .66761 m .52146 .66828 L .52974 .67554 L F
.47787 .66595 m .47635 .66242 L .46411 .66306 L .774 .498 .802 r
F
.48961 .66424 m .47635 .66242 L .47787 .66595 L .767 .49 .802 r
F
.49107 .66654 m .48961 .66424 L .47787 .66595 L .765 .49 .803 r
F
.32477 .24996 m .35653 .26633 L .35016 .23756 L .381 0 .593 r
F
.33238 .27955 m .35653 .26633 L .32477 .24996 L .386 0 .597 r
F
.54913 .67287 m .55856 .68064 L .56111 .67681 L .748 .479 .805 r
F
.54913 .67287 m .54723 .67579 L .55856 .68064 L F
.65593 .30155 m .69304 .26699 L .66226 .27104 L 1 .513 .586 r
F
.65593 .30155 m .6855 .29885 L .69304 .26699 L F
.413 .65758 m .41268 .6468 L .40013 .6451 L .836 .481 .776 r
F
.4255 .65744 m .41268 .6468 L .413 .65758 L .823 .496 .785 r
F
.50461 .53936 m .5131 .53234 L .50287 .53224 L .719 .528 .833 r
F
.50461 .53936 m .51311 .53964 L .5131 .53234 L F
.46411 .66306 m .46302 .65825 L .45051 .65781 L .785 .505 .801 r
F
.47635 .66242 m .46302 .65825 L .46411 .66306 L .774 .496 .802 r
F
.52996 .54244 m .54302 .53874 L .53337 .53555 L .693 .49 .831 r
F
.52162 .54066 m .52996 .54244 L .53337 .53555 L .714 .509 .829 r
F
.66518 .96786 m .65209 .9125 L .67452 .96956 L 1 .012 .216 r
F
.66518 .96786 m .644 .90629 L .65209 .9125 L F
.73057 .57642 m .74798 .61419 L .74223 .55148 L 1 .45 .581 r
F
.47412 .536 m .47812 .52796 L .46752 .53 L .66 .514 .856 r
F
.47412 .536 m .48319 .5342 L .47812 .52796 L F
.67029 .36274 m .70309 .34205 L .67791 .33073 L 1 .484 .583 r
F
.67029 .36274 m .69438 .37433 L .70309 .34205 L F
.48384 .86765 m .46249 .87375 L .48099 .87285 L .751 .679 .876 r
F
.5012 .86667 m .48384 .86765 L .48099 .87285 L .705 .623 .881 r
F
.57517 .67569 m .58501 .68435 L .58756 .67867 L .732 .489 .815 r
F
.57517 .67569 m .57307 .68067 L .58501 .68435 L F
.73507 .53968 m .75694 .4875 L .7461 .52029 L 0 0 0 r
F
.73507 .53968 m .74562 .50963 L .75694 .4875 L F
.51311 .53964 m .52333 .53341 L .5131 .53234 L .723 .522 .829 r
F
.51311 .53964 m .52162 .54066 L .52333 .53341 L F
.52162 .54066 m .53337 .53555 L .52333 .53341 L .714 .509 .829 r
F
.33766 .62718 m .34036 .60466 L .33233 .59817 L .574 .124 .709 r
F
.35007 .63305 m .34036 .60466 L .33766 .62718 L .632 .185 .723 r
F
.4255 .65744 m .42524 .64841 L .41268 .6468 L .823 .496 .785 r
F
.438 .65752 m .42524 .64841 L .4255 .65744 L .808 .501 .792 r
F
.36846 .51796 m .3692 .49932 L .35711 .51645 L .787 .485 .794 r
F
.36846 .51796 m .37962 .5056 L .3692 .49932 L F
.50305 .66484 m .5021 .66375 L .49107 .66654 L .76 .483 .802 r
F
.5021 .66375 m .48961 .66424 L .49107 .66654 L .761 .484 .802 r
F
.5237 .66682 m .53215 .67422 L .53421 .67265 L .754 .477 .803 r
F
.5237 .66682 m .52267 .66761 L .53215 .67422 L F
.4399 .53005 m .44173 .52102 L .43062 .52426 L .587 .424 .862 r
F
.4399 .53005 m .44978 .52677 L .44173 .52102 L F
.32273 .34358 m .34778 .33655 L .34005 .30847 L .476 .009 .604 r
F
.3316 .37183 m .34778 .33655 L .32273 .34358 L .497 .014 .61 r
F
.3106 .40301 m .3316 .37183 L .32273 .34358 L .615 .036 .596 r
F
.41077 .52335 m .412 .51142 L .40041 .5176 L .589 .371 .836 r
F
.41077 .52335 m .42132 .51813 L .412 .51142 L F
.79908 .80818 m .79743 .91904 L .81085 .80646 L 1 .296 .588 r
F
.56046 .54749 m .57716 .5496 L .56846 .54339 L .588 .389 .844 r
F
.55211 .54281 m .56046 .54749 L .56846 .54339 L .618 .412 .837 r
F
.43278 .88751 m .41331 .89383 L .40575 .90353 L 1 .917 .793 r
F
.43881 .88157 m .41331 .89383 L .43278 .88751 L 1 .983 .801 r
F
.32041 .4331 m .3316 .37183 L .3106 .40301 L .691 .061 .599 r
F
.51293 .15174 m .55528 .13236 L .51292 .11871 L .969 .149 .584 r
F
.47228 .15818 m .51292 .11871 L .47063 .12499 L 1 .163 .582 r
F
.47228 .15818 m .51293 .15174 L .51292 .11871 L F
.32667 .86664 m .30419 .77937 L .31575 .87014 L .835 .081 .569 r
F
.32667 .86664 m .31589 .77393 L .30419 .77937 L F
.438 .65752 m .43779 .65003 L .42524 .64841 L .808 .501 .792 r
F
.45051 .65781 m .43779 .65003 L .438 .65752 L .794 .5 .796 r
F
.25801 .74293 m .24815 .78705 L .23532 .78657 L .693 0 .273 r
F
.27004 .74899 m .24815 .78705 L .25801 .74293 L .686 0 .257 r
F
.51316 .66098 m .51023 .66884 L .51196 .66923 L .756 .479 .802 r
F
.51316 .66098 m .51196 .66923 L .51367 .66946 L F
.51316 .66098 m .51316 .66098 L .51196 .66923 L F
.51316 .66098 m .50856 .66829 L .51023 .66884 L F
.51316 .66098 m .51316 .66098 L .51023 .66884 L F
.51316 .66098 m .51367 .66946 L .51537 .66953 L F
.51316 .66098 m .51316 .66098 L .51367 .66946 L F
.4578 .53251 m .46089 .5243 L .44978 .52677 L .616 .474 .865 r
F
.4578 .53251 m .46752 .53 L .46089 .5243 L F
.53715 .6689 m .54723 .67579 L .54913 .67287 L .75 .476 .803 r
F
.53715 .6689 m .53589 .67087 L .54723 .67579 L F
.51316 .66098 m .50697 .66761 L .50856 .66829 L .756 .478 .802 r
F
.51316 .66098 m .51316 .66098 L .50856 .66829 L .756 .479 .802 r
F
.56277 .67271 m .57307 .68067 L .57517 .67569 L .74 .48 .809 r
F
.56277 .67271 m .56111 .67681 L .57307 .68067 L F
.51316 .66098 m .51537 .66953 L .51703 .66944 L .756 .479 .802 r
F
.51316 .66098 m .51316 .66098 L .51537 .66953 L F
.74798 .61419 m .74945 .67841 L .76158 .66357 L 1 .463 .596 r
F
.47635 .66242 m .47554 .65882 L .46302 .65825 L .774 .496 .802 r
F
.4886 .66188 m .47554 .65882 L .47635 .66242 L .767 .489 .802 r
F
.48961 .66424 m .4886 .66188 L .47635 .66242 L .767 .49 .802 r
F
.43222 .18263 m .47063 .12499 L .42895 .15043 L 1 .173 .58 r
F
.43222 .18263 m .47228 .15818 L .47063 .12499 L F
.51316 .66098 m .50551 .66679 L .50697 .66761 L .757 .479 .802 r
F
.51316 .66098 m .51316 .66098 L .50697 .66761 L .756 .478 .802 r
F
.26696 .50038 m .27688 .56228 L .26578 .54195 L 1 .011 .198 r
F
.27868 .51483 m .27688 .56228 L .26696 .50038 L 1 .026 .237 r
F
.51316 .66098 m .51703 .66944 L .51862 .6692 L .757 .479 .802 r
F
.51316 .66098 m .51316 .66098 L .51703 .66944 L F
.52453 .66592 m .53421 .67265 L .53589 .67087 L .754 .477 .803 r
F
.52453 .66592 m .5237 .66682 L .53421 .67265 L F
.50137 .66259 m .4886 .66188 L .48961 .66424 L .762 .484 .802 r
F
.5021 .66375 m .50137 .66259 L .48961 .66424 L .761 .484 .802 r
F
.33761 .86314 m .31589 .77393 L .32667 .86664 L .895 .091 .558 r
F
.45051 .65781 m .45035 .6517 L .43779 .65003 L .794 .5 .796 r
F
.46302 .65825 m .45035 .6517 L .45051 .65781 L .782 .496 .799 r
F
.28044 .99514 m .24978 .89128 L .27025 1.00406 L .706 .054 .585 r
F
.28044 .99514 m .26071 .88778 L .24978 .89128 L F
.51316 .66098 m .50419 .66587 L .50551 .66679 L .757 .479 .802 r
F
.51316 .66098 m .51316 .66098 L .50551 .66679 L F
.51316 .66098 m .51862 .6692 L .5201 .66881 L F
.51316 .66098 m .51316 .66098 L .51862 .6692 L F
.32765 .76703 m .31796 .78107 L .30604 .7717 L .844 0 .155 r
F
.3386 .78884 m .31796 .78107 L .32765 .76703 L .704 0 0 r
F
.35007 .63305 m .3526 .61279 L .34036 .60466 L .632 .185 .723 r
F
.36254 .63744 m .3526 .61279 L .35007 .63305 L .698 .259 .737 r
F
.51316 .66098 m .50305 .66484 L .50419 .66587 L .758 .479 .802 r
F
.51316 .66098 m .51316 .66098 L .50419 .66587 L .757 .479 .802 r
F
.51316 .66098 m .5201 .66881 L .52146 .66828 L F
.51316 .66098 m .51316 .66098 L .5201 .66881 L F
.55037 .66974 m .56111 .67681 L .56277 .67271 L .745 .475 .805 r
F
.55037 .66974 m .54913 .67287 L .56111 .67681 L F
.60501 .55312 m .61262 .56017 L .62386 .56032 L .459 .239 .869 r
F
.59465 .55401 m .61262 .56017 L .60501 .55312 L .492 .286 .865 r
F
.48319 .5342 m .4894 .52629 L .47812 .52796 L .688 .537 .85 r
F
.48319 .5342 m .49284 .53291 L .4894 .52629 L F
.66481 .69623 m .66186 .696 L .67422 .69858 L 0 0 .654 r
F
.66481 .69623 m .67422 .69858 L .67763 .70358 L F
.53313 .8566 m .5183 .86471 L .53529 .86127 L .759 .686 .871 r
F
.54811 .85329 m .53529 .86127 L .55189 .85683 L .706 .624 .881 r
F
.54811 .85329 m .53313 .8566 L .53529 .86127 L F
.46302 .65825 m .46291 .65344 L .45035 .6517 L .782 .496 .799 r
F
.47554 .65882 m .46291 .65344 L .46302 .65825 L .772 .492 .801 r
F
.57716 .5496 m .59465 .55401 L .58645 .54714 L .535 .332 .852 r
F
.56846 .54339 m .57716 .5496 L .58645 .54714 L .55 .336 .843 r
F
.5178 .85932 m .5012 .86667 L .5183 .86471 L .757 .683 .871 r
F
.53313 .8566 m .5178 .85932 L .5183 .86471 L .759 .686 .871 r
F
.55211 .54281 m .56846 .54339 L .5587 .53744 L .618 .412 .837 r
F
.54302 .53874 m .55211 .54281 L .5587 .53744 L .661 .446 .829 r
F
.51316 .66098 m .5021 .66375 L .50305 .66484 L .758 .479 .802 r
F
.51316 .66098 m .51316 .66098 L .50305 .66484 L F
.51316 .66098 m .52146 .66828 L .52267 .66761 L .757 .479 .802 r
F
.51316 .66098 m .51316 .66098 L .52146 .66828 L F
.65205 .69007 m .66186 .696 L .66481 .69623 L .226 .004 .858 r
F
.65205 .69007 m .64949 .69319 L .66186 .696 L F
.52516 .66493 m .53589 .67087 L .53715 .6689 L .753 .476 .802 r
F
.52516 .66493 m .52453 .66592 L .53589 .67087 L F
.4886 .66188 m .48807 .65948 L .47554 .65882 L .767 .489 .802 r
F
.50087 .6614 m .48807 .65948 L .4886 .66188 L .762 .484 .802 r
F
.50137 .66259 m .50087 .6614 L .4886 .66188 L F
.63514 .56051 m .64226 .56905 L .65423 .57148 L .355 .1 .862 r
F
.62386 .56032 m .64226 .56905 L .63514 .56051 L .391 .144 .875 r
F
.63934 .68512 m .64949 .69319 L .65205 .69007 L .419 .178 .889 r
F
.63934 .68512 m .63711 .69032 L .64949 .69319 L F
.40041 .5176 m .40268 .50383 L .39002 .51168 L .605 .346 .816 r
F
.40041 .5176 m .412 .51142 L .40268 .50383 L F
.53797 .66678 m .54913 .67287 L .55037 .66974 L .749 .474 .803 r
F
.53797 .66678 m .53715 .6689 L .54913 .67287 L F
.36254 .63744 m .3649 .61929 L .3526 .61279 L .698 .259 .737 r
F
.37505 .64069 m .3649 .61929 L .36254 .63744 L .749 .325 .748 r
F
.51316 .66098 m .51316 .66098 L .5021 .66375 L .758 .479 .802 r
F
.51316 .66098 m .50137 .66259 L .5021 .66375 L .759 .48 .802 r
F
.51316 .66098 m .52267 .66761 L .5237 .66682 L .757 .479 .802 r
F
.51316 .66098 m .51316 .66098 L .52267 .66761 L F
.58645 .54714 m .59465 .55401 L .60501 .55312 L .493 .274 .854 r
F
.47554 .65882 m .47547 .65525 L .46291 .65344 L .772 .492 .801 r
F
.48807 .65948 m .47547 .65525 L .47554 .65882 L .766 .488 .802 r
F
.62666 .68113 m .63711 .69032 L .63934 .68512 L .522 .343 .872 r
F
.62666 .68113 m .62473 .68743 L .63711 .69032 L F
.65423 .57148 m .67207 .58929 L .66626 .57464 L 0 0 .71 r
F
.56249 .85012 m .55189 .85683 L .56783 .85283 L .589 .423 .896 r
F
.56249 .85012 m .54811 .85329 L .55189 .85683 L F
.66483 .968 m .64666 1.03443 L .66521 .96906 L 1 .144 .568 r
F
.65363 .959 m .65306 .95589 L .66125 .96513 L 1 .033 .261 r
F
.65306 .95589 m .644 .90629 L .66355 .96668 L F
.65027 .95407 m .63511 .89845 L .63587 .89921 L 1 .033 .256 r
F
.65027 .95406 m .63511 .89845 L .65027 .95407 L F
.65363 .959 m .63587 .89921 L .644 .90629 L 1 .033 .261 r
F
.64999 .95354 m .63511 .89845 L .65027 .95406 L 1 .033 .256 r
F
.65029 .95415 m .64903 .95906 L .65115 .95574 L .894 .09 .558 r
F
.64291 .98274 m .63787 1.00221 L .64322 .98349 L F
.64348 .95026 m .63704 .99829 L .64943 .95547 L .396 0 .494 r
F
.64372 .94848 m .62984 .89983 L .63704 .99829 L F
.64372 .94848 m .62973 .8937 L .6351 .89845 L 1 .062 .303 r
F
.64269 .94452 m .62973 .8937 L .64372 .94848 L F
.6315 .90156 m .62984 .89983 L .64372 .94848 L .396 0 .494 r
F
.64084 .943 m .64075 .94259 L .64376 .94874 L 1 .062 .303 r
F
.64075 .94259 m .62973 .8937 L .64368 .94839 L F
.64075 .94259 m .64368 .94839 L .64376 .94874 L F
.64372 .94848 m .64348 .95026 L .64422 .94946 L .396 0 .494 r
F
.64903 .95906 m .64291 .98274 L .64978 .96054 L .894 .09 .558 r
F
.64291 .98274 m .64322 .98349 L .64978 .96054 L F
.64348 .95026 m .64943 .95547 L .64999 .95354 L .396 0 .494 r
F
.64372 .94848 m .6351 .89845 L .64999 .95354 L 1 .062 .303 r
F
.64348 .95026 m .64999 .95354 L .64649 .94701 L .396 0 .494 r
F
.65582 .96415 m .64666 1.03443 L .66256 .97629 L 1 .144 .568 r
F
.65353 .96004 m .65325 .96305 L .65582 .96415 L F
.65325 .96305 m .64666 1.03443 L .65582 .96415 L F
.65363 .959 m .65353 .96004 L .66292 .97499 L F
.65353 .96004 m .66256 .97629 L .66292 .97499 L F
.65363 .959 m .66292 .97499 L .66483 .968 L F
.66521 .96906 m .65533 1.05991 L .6751 .99273 L 1 .201 .576 r
F
.66521 .96906 m .64666 1.03443 L .65533 1.05991 L F
.6751 .99273 m .65533 1.05991 L .66398 1.08323 L 1 .221 .581 r
F
.67303 1.00385 m .65594 .97163 L .66483 .968 L .914 0 .257 r
F
.66525 .96818 m .66483 .968 L .66518 .96786 L F
.66526 .96844 m .66483 .968 L .66521 .96906 L .795 .089 .591 r
F
.66527 .96828 m .66483 .968 L .66526 .96844 L F
.66527 .96828 m .66483 .968 L .66525 .96818 L .914 0 .257 r
F
.66408 .96831 m .644 .90629 L .66518 .96786 L 1 .033 .261 r
F
.67607 .97602 m .66518 .96786 L .67452 .96956 L 1 0 .216 r
F
.66657 .9692 m .66518 .96786 L .67607 .97602 L F
.67638 .9773 m .66521 .96906 L .6751 .99273 L .939 .145 .591 r
F
.66543 .96838 m .66518 .96786 L .66729 .9699 L 1 0 .216 r
F
.66543 .96838 m .66521 .96906 L .67638 .9773 L .939 .145 .591 r
F
.67638 .9773 m .6751 .99273 L .67891 .97931 L F
.69809 .99714 m .6839 .97428 L .69343 .98077 L 1 0 .152 r
F
.70895 1.00812 m .69343 .98077 L .70297 .98826 L .995 0 .134 r
F
.70895 1.00811 m .69343 .98077 L .70895 1.00812 L F
.70291 1.00203 m .69343 .98077 L .70896 1.00813 L F
.69114 .99048 m .6839 .97428 L .69809 .99714 L 1 0 .152 r
F
.69817 .99743 m .69491 1.03319 L .70291 1.00203 L 1 .21 .59 r
F
.73047 1.03113 m .71252 .9964 L .72205 1.00497 L .982 0 .12 r
F
.72539 1.02566 m .71252 .9964 L .73047 1.03113 L F
.74114 1.04309 m .72205 1.00497 L .73159 1.01386 L .983 0 .12 r
F
.76252 1.06851 m .75463 1.14068 L .76885 1.07606 L 1 .243 .584 r
F
.76255 1.06824 m .76248 1.06802 L .76887 1.07595 L .993 0 .125 r
F
.75191 1.0557 m .74111 1.02301 L .75813 1.06313 L .987 0 .121 r
F
.75191 1.0557 m .75189 1.05593 L .75813 1.06313 L 1 .243 .585 r
F
.75189 1.05593 m .74466 1.12296 L .75812 1.06317 L F
.75189 1.05593 m .75812 1.06317 L .75813 1.06313 L F
.74125 1.04341 m .74118 1.0432 L .74733 1.05049 L .983 0 .12 r
F
.74118 1.0432 m .73159 1.01386 L .74723 1.05027 L F
.74118 1.0432 m .74723 1.05027 L .74733 1.05049 L F
.73636 1.03786 m .72205 1.00497 L .74114 1.04309 L F
.75191 1.05572 m .7347 1.1053 L .74466 1.12296 L 1 .243 .585 r
F
.75191 1.0557 m .7519 1.05572 L .75191 1.05572 L F
.7519 1.05572 m .7347 1.1053 L .75191 1.05572 L F
.73055 1.03139 m .73039 1.03089 L .73079 1.03166 L .982 0 .12 r
F
.73039 1.03089 m .72205 1.00497 L .7363 1.03771 L F
.73235 1.03343 m .72475 1.08763 L .73645 1.03805 L 1 .239 .587 r
F
.73055 1.03139 m .73054 1.03147 L .73235 1.03343 L F
.73054 1.03147 m .72475 1.08763 L .73235 1.03343 L F
.7198 1.01978 m .7148 1.06984 L .72546 1.02582 L 1 .234 .588 r
F
.73039 1.03089 m .7363 1.03771 L .73645 1.03805 L .982 0 .12 r
F
.74123 1.04357 m .72475 1.08763 L .7347 1.1053 L 1 .241 .586 r
F
.73645 1.03805 m .72475 1.08763 L .74123 1.04357 L F
.74601 1.04896 m .7347 1.1053 L .74733 1.05049 L F
.74125 1.04341 m .74123 1.04357 L .74601 1.04896 L F
.74123 1.04357 m .7347 1.1053 L .74601 1.04896 L F
.73059 1.03127 m .73645 1.03805 L .73657 1.03834 L .982 0 .12 r
F
.75191 1.0557 m .73159 1.01386 L .74111 1.02301 L .987 0 .121 r
F
.75182 1.0556 m .7347 1.1053 L .75191 1.0557 L 1 .243 .585 r
F
.74733 1.05049 m .73159 1.01386 L .75191 1.0557 L .987 0 .121 r
F
.74741 1.0501 m .7347 1.1053 L .75197 1.05518 L 1 .243 .585 r
F
.76248 1.06802 m .76241 1.06783 L .76876 1.07569 L .993 0 .125 r
F
.76241 1.06783 m .75063 1.03235 L .76867 1.07548 L F
.76241 1.06783 m .76867 1.07548 L .76876 1.07569 L F
.76248 1.06802 m .76876 1.07569 L .76887 1.07595 L F
.76255 1.06824 m .74466 1.12296 L .75463 1.14068 L 1 .243 .584 r
F
.76255 1.06824 m .74111 1.02301 L .75063 1.03235 L .993 0 .125 r
F
.75813 1.06313 m .74111 1.02301 L .76255 1.06824 L F
.76782 1.02007 m .75813 1.06313 L .76255 1.06824 L 1 .243 .584 r
F
.75813 1.06313 m .74466 1.12296 L .76255 1.06824 L F
.76252 1.06851 m .76885 1.07606 L .76898 1.07546 L F
.76261 1.0683 m .76898 1.07546 L .77864 1.03158 L F
.76252 1.06851 m .76898 1.07546 L .76261 1.0683 L F
.76255 1.06824 m .76252 1.06851 L .76261 1.06831 L F
.7707 1.09277 m .75824 1.0634 L .76255 1.06824 L .993 0 .125 r
F
.75824 1.0634 m .75813 1.06313 L .76255 1.06824 L F
.75969 1.07925 m .74733 1.05049 L .75191 1.0557 L .987 0 .121 r
F
.75182 1.05559 m .75182 1.0556 L .75191 1.0557 L 1 .243 .585 r
F
.731 1.03206 m .73657 1.03834 L .7487 1.0662 L .982 0 .12 r
F
.73059 1.03127 m .73657 1.03834 L .731 1.03206 L F
.73039 1.03089 m .73645 1.03805 L .73059 1.03127 L F
.7402 1.04224 m .73636 1.03786 L .74009 1.04194 L .983 0 .12 r
F
.74125 1.04341 m .73645 1.03805 L .74123 1.04357 L 1 .241 .586 r
F
.7487 1.0662 m .73645 1.03805 L .7402 1.04224 L .983 0 .12 r
F
.73645 1.03805 m .73636 1.03786 L .7402 1.04224 L F
.74115 1.04312 m .74009 1.04194 L .74114 1.04309 L F
.7487 1.0662 m .74009 1.04194 L .74115 1.04312 L F
.74617 .99684 m .73645 1.03805 L .74125 1.04341 L 1 .241 .586 r
F
.73054 1.03147 m .7148 1.06984 L .72475 1.08763 L 1 .239 .587 r
F
.73048 1.03119 m .72539 1.02566 L .73047 1.03113 L .982 0 .12 r
F
.73055 1.03139 m .72546 1.02582 L .73048 1.03119 L F
.73055 1.03139 m .72546 1.02582 L .73054 1.03147 L 1 .239 .587 r
F
.72546 1.02582 m .7148 1.06984 L .73054 1.03147 L F
.73773 1.05372 m .72546 1.02582 L .73055 1.03139 L .982 0 .12 r
F
.72546 1.02582 m .72539 1.02566 L .73048 1.03119 L F
.73534 .98498 m .72546 1.02582 L .73055 1.03139 L 1 .239 .587 r
F
.71981 1.01969 m .71974 1.01947 L .72255 1.02266 L .986 0 .125 r
F
.71974 1.01947 m .71252 .9964 L .72539 1.02566 L F
.72058 1.02039 m .72539 1.02566 L .72546 1.02582 L F
.71974 1.01947 m .72539 1.02566 L .72058 1.02039 L F
.71981 1.01969 m .71981 1.01973 L .71982 1.0197 L 1 .234 .588 r
F
.71981 1.01973 m .7198 1.01978 L .71982 1.01974 L F
.69817 .99743 m .69343 .98077 L .70291 1.00203 L 1 0 .152 r
F
.69817 .99743 m .70294 1.00192 L .70298 1.00176 L 1 .21 .59 r
F
.71975 1.01948 m .70297 .98826 L .71252 .9964 L .986 0 .125 r
F
.71964 1.01936 m .70297 .98826 L .71975 1.01948 L F
.7143 1.01381 m .70297 .98826 L .71965 1.01938 L F
.7143 1.01381 m .71965 1.01938 L .71981 1.01969 L F
.71981 1.01969 m .71964 1.01936 L .71975 1.01948 L F
.72255 1.02266 m .72546 1.02582 L .72559 1.02613 L F
.71974 1.01947 m .72546 1.02582 L .72255 1.02266 L F
.71983 1.01971 m .72546 1.02582 L .73534 .98498 L 1 .234 .588 r
F
.7198 1.01978 m .72546 1.02582 L .71983 1.01971 L F
.71982 1.01964 m .70486 1.05178 L .7148 1.06984 L F
.71973 1.01955 m .70486 1.05178 L .71982 1.01964 L F
.71434 1.01365 m .70486 1.05178 L .71985 1.01928 L F
.70902 1.00835 m .70897 1.00816 L .70912 1.00845 L .995 0 .134 r
F
.70902 1.00835 m .70486 1.05178 L .7143 1.01381 L 1 .225 .589 r
F
.70897 1.00816 m .7143 1.01381 L .71447 1.01419 L .995 0 .134 r
F
.70912 1.00846 m .71447 1.01419 L .72678 1.04194 L F
.70897 1.00816 m .71447 1.01419 L .70912 1.00846 L F
.70902 1.00835 m .69491 1.03319 L .70486 1.05178 L 1 .225 .589 r
F
.70897 1.00816 m .70297 .98826 L .7143 1.01381 L .995 0 .134 r
F
.70745 1.00672 m .70291 1.00203 L .70739 1.00655 L F
.70291 1.00203 m .69491 1.03319 L .70902 1.00835 L 1 .225 .589 r
F
.71587 1.03108 m .70291 1.00203 L .70745 1.00672 L .995 0 .134 r
F
.71587 1.03108 m .70739 1.00655 L .70897 1.00816 L F
.70296 1.00185 m .70291 1.00203 L .70902 1.00835 L 1 .225 .589 r
F
.70897 1.00816 m .70739 1.00655 L .70896 1.00813 L .995 0 .134 r
F
.70896 1.00813 m .70895 1.00811 L .70895 1.00812 L F
.71364 .96023 m .70296 1.00185 L .70902 1.00835 L 1 .225 .589 r
F
.70903 1.0083 m .70902 1.00835 L .7143 1.01381 L F
.71587 1.03108 m .70902 1.00835 L .72678 1.04194 L .995 0 .134 r
F
.70902 1.00835 m .70912 1.00845 L .72678 1.04194 L F
.71985 1.01928 m .71973 1.01955 L .71982 1.01964 L 1 .234 .588 r
F
.7245 .97283 m .71434 1.01365 L .71985 1.01928 L F
.71446 1.01415 m .7143 1.01381 L .71981 1.01969 L .986 0 .125 r
F
.70905 1.00812 m .70903 1.0083 L .71444 1.01327 L 1 .225 .589 r
F
.70903 1.0083 m .7143 1.01381 L .71444 1.01327 L F
.69838 .99691 m .70298 1.00176 L .71364 .96023 L 1 .21 .59 r
F
.69817 .99743 m .70298 1.00176 L .69838 .99691 L F
.71981 1.01973 m .71982 1.01974 L .71983 1.01971 L 1 .234 .588 r
F
.72678 1.04194 m .71446 1.01415 L .71981 1.01969 L .986 0 .125 r
F
.71982 1.0197 m .71983 1.01971 L .73534 .98498 L 1 .234 .588 r
F
.71981 1.01973 m .71983 1.01971 L .71982 1.0197 L F
.71364 .96023 m .70908 1.0078 L .7245 .97283 L 1 .225 .589 r
F
.70908 1.0078 m .70905 1.00806 L .70914 1.00787 L F
.70908 1.0078 m .70914 1.00787 L .7245 .97283 L F
.7245 .97283 m .71981 1.01969 L .73534 .98498 L 1 .234 .588 r
F
.71981 1.01969 m .71982 1.0197 L .73534 .98498 L F
.71991 1.01998 m .71981 1.01969 L .72559 1.02613 L .986 0 .125 r
F
.71981 1.01969 m .72255 1.02266 L .72559 1.02613 L F
.72678 1.04194 m .71991 1.01998 L .73773 1.05372 L F
.71991 1.01998 m .72559 1.02613 L .73773 1.05372 L F
.73061 1.03086 m .73055 1.03139 L .73652 1.03776 L 1 .239 .587 r
F
.73055 1.03139 m .73645 1.03805 L .73652 1.03776 L F
.73773 1.05372 m .73055 1.03139 L .7487 1.0662 L .982 0 .12 r
F
.73055 1.03139 m .73079 1.03166 L .7487 1.0662 L F
.73534 .98498 m .73061 1.03086 L .74617 .99684 L 1 .239 .587 r
F
.73061 1.03086 m .73652 1.03776 L .74617 .99684 L F
.74138 1.04211 m .74125 1.04341 L .74753 1.04962 L 1 .241 .586 r
F
.74125 1.04341 m .74733 1.05049 L .74753 1.04962 L F
.74132 1.04365 m .74125 1.04341 L .74745 1.05077 L .983 0 .12 r
F
.74125 1.04341 m .74733 1.05049 L .74745 1.05077 L F
.7487 1.0662 m .74132 1.04365 L .75969 1.07925 L F
.74132 1.04365 m .74745 1.05077 L .75969 1.07925 L F
.75191 1.0557 m .75813 1.06313 L .7583 1.06352 L .987 0 .121 r
F
.75197 1.05518 m .75191 1.0557 L .7582 1.06279 L 1 .243 .585 r
F
.75191 1.0557 m .75813 1.06313 L .7582 1.06279 L F
.74617 .99684 m .74138 1.04211 L .757 1.00851 L 1 .241 .586 r
F
.74138 1.04211 m .74753 1.04962 L .757 1.00851 L F
.757 1.00851 m .75197 1.05518 L .76782 1.02007 L 1 .243 .585 r
F
.75197 1.05518 m .7582 1.06279 L .76782 1.02007 L F
.7707 1.09277 m .76255 1.06824 L .78173 1.1067 L .993 0 .125 r
F
.76255 1.06824 m .76887 1.07595 L .78173 1.1067 L F
.76782 1.02007 m .76255 1.06824 L .77864 1.03158 L 1 .243 .584 r
F
.76255 1.06824 m .76261 1.06831 L .77864 1.03158 L F
.75969 1.07925 m .75199 1.05593 L .7707 1.09277 L .987 0 .121 r
F
.75199 1.05593 m .75191 1.0557 L .75209 1.05605 L F
.75199 1.05593 m .75209 1.05605 L .7707 1.09277 L F
.75191 1.0557 m .7583 1.06352 L .7707 1.09277 L F
.75197 1.05518 m .75182 1.05559 L .75191 1.0557 L 1 .243 .585 r
F
.757 1.00851 m .74741 1.0501 L .75197 1.05518 L F
.70905 1.00806 m .70905 1.00812 L .70907 1.00808 L 1 .225 .589 r
F
.70905 1.00806 m .70907 1.00808 L .7245 .97283 L F
.70905 1.00812 m .71444 1.01327 L .7245 .97283 L F
.70498 1.0214 m .69829 .99786 L .71587 1.03108 L 1 0 .152 r
F
.69829 .99786 m .69817 .99743 L .6985 .99806 L F
.69829 .99786 m .6985 .99806 L .71587 1.03108 L F
.69817 .99743 m .70291 1.00203 L .71587 1.03108 L F
.69817 .99743 m .70291 1.00203 L .70294 1.00192 L 1 .21 .59 r
F
.68728 .98705 m .68495 1.01364 L .69114 .99047 L 1 .186 .591 r
F
.69817 .99743 m .69114 .99048 L .69809 .99714 L 1 0 .152 r
F
.69817 .99743 m .68495 1.01365 L .69491 1.03319 L 1 .21 .59 r
F
.69114 .99048 m .69114 .99048 L .69817 .99743 L 1 0 .152 r
F
.70276 .947 m .69114 .99048 L .69817 .99743 L 1 .21 .59 r
F
.69114 .99048 m .68495 1.01365 L .69817 .99743 L F
.69141 .99108 m .69114 .99048 L .69817 .99743 L 1 0 .152 r
F
.69429 1.01341 m .68728 .98705 L .70498 1.0214 L 1 0 .179 r
F
.68728 .98705 m .68389 .97428 L .69114 .99047 L F
.68728 .98705 m .69114 .99047 L .70498 1.0214 L F
.68731 .98679 m .68728 .98705 L .69114 .99047 L 1 .186 .591 r
F
.68728 .98705 m .69114 .99047 L .69114 .99047 L F
.68749 .98605 m .69139 .98953 L .70276 .947 L F
.68734 .98643 m .68936 .98798 L .68749 .98605 L F
.68936 .98798 m .69139 .98953 L .68749 .98605 L F
.70276 .947 m .69819 .99725 L .71364 .96023 L 1 .21 .59 r
F
.69819 .99725 m .69817 .99743 L .69823 .99729 L F
.69819 .99725 m .69823 .99729 L .71364 .96023 L F
.70498 1.0214 m .69141 .99108 L .69817 .99743 L 1 0 .152 r
F
.68734 .98643 m .68731 .98679 L .69139 .98953 L 1 .186 .591 r
F
.68731 .98679 m .69114 .99047 L .69139 .98953 L F
.69203 .93312 m .68734 .98643 L .70276 .947 L F
.68728 .98705 m .67891 .97931 L .68714 .98652 L 1 0 .179 r
F
.68728 .98705 m .6751 .99273 L .68495 1.01364 L 1 .186 .591 r
F
.68688 .98667 m .6751 .99273 L .68728 .98705 L F
.68714 .98652 m .67452 .96956 L .68389 .97428 L 1 0 .179 r
F
.67891 .97931 m .67452 .96956 L .68714 .98652 L F
.67891 .97931 m .6751 .99273 L .68734 .98643 L 1 .186 .591 r
F
.69429 1.01341 m .67891 .97931 L .68728 .98705 L 1 0 .179 r
F
.68734 .98643 m .68688 .98667 L .68728 .98705 L 1 .186 .591 r
F
.69203 .93312 m .67891 .97931 L .68734 .98643 L F
.67638 .9773 m .67634 .97714 L .67916 .97986 L 1 0 .216 r
F
.67634 .97714 m .67452 .96956 L .67891 .97931 L F
.67634 .97714 m .67891 .97931 L .67916 .97986 L F
.68364 1.00743 m .6766 .9782 L .69429 1.01341 L F
.6766 .9782 m .67638 .9773 L .67697 .97848 L F
.6766 .9782 m .67697 .97848 L .69429 1.01341 L F
.67638 .9773 m .67916 .97986 L .69429 1.01341 L F
.67638 .9773 m .66657 .9692 L .67607 .97602 L F
.67682 .97913 m .66729 .9699 L .67638 .9773 L F
.66729 .9699 m .66657 .9692 L .67638 .9773 L F
.68127 .91828 m .66571 .96747 L .67638 .9773 L .939 .145 .591 r
F
.66571 .96747 m .66543 .96838 L .67638 .9773 L F
.67745 .97803 m .67891 .97931 L .67898 .97908 L F
.67638 .9773 m .67891 .97931 L .67745 .97803 L F
.66546 .96844 m .66543 .96838 L .67146 .97394 L 1 0 .216 r
F
.66543 .96838 m .66729 .9699 L .67146 .97394 L F
.67087 .97353 m .67146 .97394 L .67682 .97913 L F
.66546 .96844 m .67146 .97394 L .67087 .97353 L F
.68127 .91828 m .67638 .9773 L .69203 .93312 L .939 .145 .591 r
F
.67638 .9773 m .67898 .97908 L .69203 .93312 L F
.6751 .99273 m .66398 1.08323 L .68495 1.01364 L 1 .221 .581 r
F
.67303 1.00385 m .66518 .96786 L .68364 1.00743 L .914 0 .257 r
F
.6705 .90256 m .66527 .96827 L .68127 .91828 L .795 .089 .591 r
F
.66529 .96828 m .66521 .96906 L .66543 .96838 L F
.66527 .96828 m .66521 .96906 L .66529 .96828 L F
.67303 1.00385 m .66486 .96812 L .66527 .96828 L .914 0 .257 r
F
.66486 .96812 m .66483 .968 L .66527 .96828 L F
.66527 .96827 m .66527 .96828 L .66529 .96828 L .795 .089 .591 r
F
.66527 .96827 m .66543 .96838 L .68127 .91828 L F
.68364 1.00743 m .66546 .96844 L .67682 .97913 L 1 0 .216 r
F
.66527 .96827 m .66483 .968 L .66527 .96828 L .795 .089 .591 r
F
.6705 .90256 m .66484 .96786 L .66527 .96827 L F
.66484 .96786 m .66483 .968 L .66527 .96827 L F
.64903 .95906 m .64978 .96054 L .65115 .95574 L .894 .09 .558 r
F
.65029 .95415 m .63704 .9983 L .63787 1.00221 L F
.64993 .95376 m .63704 .9983 L .65029 .95415 L F
.63004 .91091 m .61794 1.09641 L .63703 .99831 L 1 .375 .489 r
F
.64997 .99859 m .63788 1.00222 L .64666 1.03443 L 1 .144 .568 r
F
.64393 .98506 m .63788 1.00222 L .64997 .99859 L F
.64386 .94929 m .64084 .943 L .64376 .94874 L 1 .062 .303 r
F
.64978 .96054 m .64323 .98349 L .65127 .96338 L 1 .144 .568 r
F
.64323 .98349 m .64393 .98506 L .65331 .95845 L F
.65184 .95592 m .63587 .89921 L .65363 .959 L 1 .033 .261 r
F
.65327 .95838 m .65331 .95845 L .65381 .95704 L 1 .144 .568 r
F
.64323 .98349 m .65331 .95845 L .65327 .95838 L F
.65143 .95518 m .63587 .89921 L .65184 .95592 L 1 .033 .261 r
F
.65135 .95506 m .65133 .95501 L .65144 .95524 L F
.65133 .95501 m .63587 .89921 L .65143 .95518 L F
.65133 .95501 m .65143 .95518 L .65144 .95524 L F
.65135 .95506 m .64978 .96054 L .65293 .9578 L 1 .144 .568 r
F
.65029 .95415 m .63587 .89921 L .65134 .95506 L 1 .033 .256 r
F
.65029 .95415 m .65115 .95574 L .65134 .95506 L .894 .09 .558 r
F
.65029 .95415 m .65134 .95506 L .65143 .95536 L 1 .033 .256 r
F
.65029 .95415 m .65134 .95506 L .65526 .94136 L .894 .09 .558 r
F
.64774 .9185 m .64449 .94276 L .65432 .93856 L .396 0 .494 r
F
.64449 .94276 m .64443 .94316 L .64465 .94306 L F
.64449 .94276 m .64465 .94306 L .65432 .93856 L F
.65135 .95506 m .65135 .95506 L .65381 .95704 L 1 .144 .568 r
F
.65144 .95523 m .65143 .95518 L .65178 .95582 L 1 .033 .261 r
F
.65135 .95506 m .65293 .9578 L .65381 .95704 L 1 .144 .568 r
F
.65144 .95524 m .65144 .95523 L .65184 .95592 L 1 .033 .261 r
F
.65144 .95523 m .65178 .95582 L .65184 .95592 L F
.64978 .96054 m .65127 .96338 L .65381 .95704 L 1 .144 .568 r
F
.65381 .95704 m .64393 .98506 L .64997 .99859 L F
.65184 .95592 m .65184 .95592 L .65363 .959 L 1 .033 .261 r
F
.64904 .97936 m .64106 .94397 L .64386 .94929 L 1 .062 .303 r
F
.64106 .94397 m .64084 .943 L .64386 .94929 L F
.64323 .98349 m .63788 1.00222 L .64393 .98506 L 1 .144 .568 r
F
.63703 .99832 m .63256 1.02228 L .63787 1.00223 L 1 .469 .547 r
F
.62111 1.08368 m .61859 1.09719 L .62115 1.08456 L F
.6296 .91774 m .62195 .99955 L .62039 1.0371 L 1 .375 .489 r
F
.62193 1.03527 m .62039 1.0371 L .61794 1.09641 L F
.6296 .91774 m .62039 1.0371 L .62193 1.03527 L F
.62624 .95258 m .62195 .99955 L .6296 .91774 L F
.61686 1.07687 m .61388 1.08324 L .61567 1.09498 L 1 .295 .517 r
F
.61388 1.08324 m .61323 1.08464 L .61359 1.08618 L F
.61388 1.08324 m .61359 1.08618 L .61567 1.09498 L F
.62195 .99955 m .61595 1.09071 L .61794 1.09641 L 1 .375 .489 r
F
.61595 1.09071 m .61567 1.09498 L .61664 1.09559 L F
.61595 1.09071 m .61664 1.09559 L .61794 1.09641 L F
.61862 1.03202 m .61323 1.08464 L .62042 1.06926 L 1 .295 .517 r
F
.61932 1.02326 m .61926 1.02338 L .62044 1.01146 L 1 .283 .581 r
F
.62057 1.01136 m .62044 1.01146 L .62621 .9529 L F
.61414 1.07801 m .62044 1.01146 L .62057 1.01136 L F
.62447 1.00696 m .61862 1.03202 L .62042 1.06926 L 1 .295 .517 r
F
.63019 .91907 m .62076 1.01112 L .62447 1.00696 L F
.62076 1.01112 m .61862 1.03202 L .62447 1.00696 L F
.62156 1.00548 m .61427 1.08376 L .61567 1.09498 L 1 .375 .489 r
F
.61354 1.08637 m .60678 1.11046 L .61239 1.10783 L .931 .202 .631 r
F
.61859 1.09719 m .61314 1.11815 L .62565 1.11025 L 1 .479 .611 r
F
.61265 1.1083 m .61239 1.10784 L .61243 1.10843 L .807 .144 .633 r
F
.61006 1.12516 m .59602 1.11787 L .60169 1.14137 L .784 .128 .629 r
F
.61167 1.12204 m .61053 1.12174 L .61006 1.12516 L F
.61053 1.12174 m .59602 1.11787 L .61006 1.12516 L F
.61177 1.12013 m .59602 1.11787 L .61167 1.12204 L F
.61211 1.1111 m .59602 1.11787 L .6122 1.12019 L F
.61226 1.11398 m .6122 1.12019 L .6126 1.12025 L F
.61211 1.1111 m .6122 1.12019 L .61226 1.11398 L F
.60169 1.14137 m .5796 1.14649 L .60737 1.16594 L .505 .053 .675 r
F
.60169 1.14137 m .57567 1.12939 L .5796 1.14649 L F
.59602 1.11787 m .57567 1.12939 L .60169 1.14137 L .618 .12 .686 r
F
.61274 1.10825 m .61273 1.10842 L .61859 1.09719 L 1 .539 .617 r
F
.61274 1.10825 m .59602 1.11787 L .61222 1.11105 L .807 .144 .633 r
F
.61231 1.10922 m .61222 1.11105 L .61222 1.11105 L 1 .539 .617 r
F
.61269 1.10849 m .61222 1.11105 L .61859 1.09719 L F
.61231 1.10922 m .61222 1.11105 L .61269 1.10849 L F
.6126 1.12025 m .61177 1.12013 L .61167 1.12204 L .784 .128 .629 r
F
.61203 1.16013 m .60169 1.14137 L .60737 1.16594 L .619 .06 .628 r
F
.61231 1.15977 m .61087 1.14176 L .61203 1.16013 L F
.61099 1.14176 m .61087 1.14176 L .61231 1.15977 L F
.61087 1.14176 m .60169 1.14137 L .61203 1.16013 L F
.61206 1.1274 m .61099 1.14176 L .62565 1.11025 L 1 .479 .611 r
F
.61314 1.11815 m .6126 1.12025 L .61367 1.12537 L F
.61314 1.11815 m .61367 1.12537 L .62565 1.11025 L F
.62565 1.11025 m .61318 1.15868 L .63279 1.12887 L 1 .392 .603 r
F
.60737 1.16594 m .58354 1.16438 L .61308 1.19107 L .427 .017 .662 r
F
.61609 1.18885 m .60737 1.16594 L .61308 1.19107 L .514 .024 .625 r
F
.61554 1.18483 m .60737 1.16594 L .61609 1.18885 L F
.61353 1.16827 m .60737 1.16594 L .61699 1.18818 L F
.60737 1.16594 m .5796 1.14649 L .58354 1.16438 L .427 .017 .662 r
F
.61318 1.15868 m .61451 1.16627 L .63279 1.12887 L 1 .392 .603 r
F
.63279 1.12887 m .61708 1.18812 L .63999 1.1503 L 1 .33 .599 r
F
.61308 1.19108 m .58753 1.18342 L .61888 1.21699 L .376 .003 .648 r
F
.61708 1.18812 m .61814 1.19301 L .63999 1.1503 L 1 .33 .599 r
F
.61888 1.21699 m .59154 1.20337 L .6247 1.24331 L .341 0 .634 r
F
.64 1.1503 m .62222 1.21566 L .64734 1.1737 L 1 .286 .596 r
F
.62741 1.24294 m .61888 1.21699 L .6247 1.24331 L .414 .003 .616 r
F
.62666 1.2392 m .61888 1.21699 L .62741 1.24294 L F
.62287 1.22007 m .61888 1.21699 L .62794 1.24286 L F
.62147 1.21596 m .61308 1.19108 L .61888 1.21699 L .452 .009 .621 r
F
.62222 1.21566 m .62068 1.21154 L .62147 1.21596 L F
.62068 1.21154 m .61308 1.19108 L .62147 1.21596 L F
.61712 1.19353 m .61308 1.19108 L .62222 1.21566 L F
.61708 1.18812 m .61308 1.19107 L .61753 1.19378 L .514 .024 .625 r
F
.61708 1.18812 m .61753 1.19378 L .61769 1.19388 L F
.63279 1.12887 m .61523 1.16479 L .61708 1.18812 L 1 .33 .599 r
F
.61663 1.18561 m .61353 1.16827 L .61655 1.18565 L .514 .024 .625 r
F
.61523 1.16479 m .61353 1.16827 L .61708 1.18812 L 1 .33 .599 r
F
.61769 1.19388 m .61712 1.19353 L .62222 1.21566 L .452 .009 .621 r
F
.62222 1.21566 m .62312 1.21959 L .64734 1.1737 L 1 .286 .596 r
F
.64734 1.1737 m .62797 1.24286 L .65472 1.19823 L 1 .257 .593 r
F
.6247 1.24331 m .59556 1.22424 L .63054 1.27009 L .318 0 .623 r
F
.63368 1.27026 m .6247 1.24331 L .63054 1.27009 L .389 .001 .612 r
F
.6332 1.26802 m .6247 1.24331 L .63368 1.27026 L F
.62866 1.24685 m .6247 1.24331 L .63397 1.27028 L F
.62794 1.24286 m .62666 1.2392 L .62741 1.24294 L .414 .003 .616 r
F
.6247 1.24331 m .59154 1.20337 L .59556 1.22424 L .318 0 .623 r
F
.62797 1.24286 m .62883 1.24652 L .65472 1.19823 L 1 .257 .593 r
F
.65472 1.19823 m .6341 1.27028 L .66214 1.22366 L 1 .236 .59 r
F
.63054 1.27009 m .59959 1.246 L .6364 1.29737 L .304 0 .614 r
F
.64015 1.29814 m .63054 1.27009 L .6364 1.29737 L .373 0 .607 r
F
.63997 1.29732 m .63054 1.27009 L .64015 1.29814 L F
.63486 1.27434 m .63054 1.27009 L .64026 1.29816 L F
.63054 1.27009 m .59556 1.22424 L .59959 1.246 L .304 0 .614 r
F
.6341 1.27028 m .63499 1.27409 L .66214 1.22366 L 1 .236 .59 r
F
.64046 1.2982 m .63486 1.27434 L .64026 1.29816 L .373 0 .607 r
F
.66214 1.22366 m .64046 1.2982 L .66958 1.24985 L 1 .222 .588 r
F
.64046 1.2982 m .64063 1.2989 L .66958 1.24985 L F
.64132 1.30259 m .6364 1.29737 L .64673 1.32663 L .361 0 .604 r
F
.64061 1.29893 m .64132 1.30259 L .66958 1.24985 L 1 .222 .588 r
F
.64699 1.32672 m .64132 1.30259 L .64673 1.32663 L .361 0 .604 r
F
.66958 1.24985 m .64721 1.32598 L .67706 1.27671 L 1 .213 .586 r
F
.64721 1.32598 m .64699 1.32672 L .64727 1.32625 L F
.64721 1.32598 m .64727 1.32625 L .67706 1.27671 L F
.64699 1.32672 m .64711 1.32723 L .67706 1.27671 L F
.64796 1.33157 m .64228 1.3252 L .65334 1.35575 L .352 0 .6 r
F
.6471 1.32725 m .64796 1.33157 L .67706 1.27671 L 1 .213 .586 r
F
.65364 1.35587 m .64796 1.33157 L .65334 1.35575 L .352 0 .6 r
F
.67706 1.27671 m .65384 1.35518 L .68457 1.30419 L 1 .206 .584 r
F
.65384 1.35518 m .65364 1.35587 L .6539 1.35543 L F
.65384 1.35518 m .6539 1.35543 L .68457 1.30419 L F
.65364 1.35587 m .65372 1.35626 L .68457 1.30419 L F
.65472 1.36124 m .64818 1.35358 L .66004 1.38551 L .346 0 .597 r
F
.65372 1.35627 m .65472 1.36124 L .68457 1.30419 L 1 .206 .584 r
F
.66036 1.38567 m .65472 1.36124 L .66004 1.38551 L .346 0 .597 r
F
.68457 1.30419 m .66055 1.38502 L .69212 1.33224 L 1 .201 .583 r
F
.66055 1.38502 m .66036 1.38567 L .66061 1.38526 L F
.66055 1.38502 m .66061 1.38526 L .69212 1.33224 L F
.65364 1.35587 m .64818 1.35358 L .65472 1.36124 L .352 0 .6 r
F
.66004 1.38551 m .64818 1.35358 L .6541 1.38253 L .346 0 .597 r
F
.65334 1.35575 m .64228 1.3252 L .64818 1.35358 L .352 0 .6 r
F
.64818 1.35358 m .60768 1.2919 L .61175 1.3159 L .287 0 .597 r
F
.64228 1.3252 m .60768 1.2919 L .64818 1.35358 L .29 0 .601 r
F
.64818 1.35358 m .61175 1.3159 L .6541 1.38253 L .287 0 .597 r
F
.67706 1.27671 m .64259 1.34169 L .64857 1.373 L 1 .206 .584 r
F
.65381 1.35594 m .64816 1.33178 L .65364 1.35587 L .352 0 .6 r
F
.66036 1.38567 m .66043 1.38598 L .69212 1.33224 L 1 .201 .583 r
F
.66036 1.38567 m .6541 1.38253 L .66155 1.39159 L .346 0 .597 r
F
.6601 1.38653 m .66126 1.39215 L .66155 1.39159 L 1 .201 .583 r
F
.66042 1.38599 m .66155 1.39159 L .69212 1.33224 L F
.6601 1.38653 m .66155 1.39159 L .66042 1.38599 L F
.687 1.39907 m .66036 1.38567 L .69477 1.43202 L .346 0 .597 r
F
.66036 1.38567 m .66155 1.39159 L .69477 1.43202 L F
.68457 1.30419 m .64857 1.373 L .65457 1.40514 L 1 .201 .583 r
F
.67927 1.36663 m .64822 1.33185 L .65381 1.35594 L .352 0 .6 r
F
.64822 1.33185 m .64816 1.33178 L .65381 1.35594 L F
.687 1.39907 m .65495 1.36152 L .66036 1.38567 L .346 0 .597 r
F
.65495 1.36152 m .65472 1.36124 L .66036 1.38567 L F
.66036 1.38567 m .6601 1.38653 L .66043 1.38598 L 1 .201 .583 r
F
.6601 1.38653 m .65457 1.40514 L .66126 1.39215 L F
.67927 1.36663 m .65381 1.35594 L .687 1.39907 L .352 0 .6 r
F
.65381 1.35594 m .65364 1.35587 L .65385 1.35614 L F
.65381 1.35594 m .65385 1.35614 L .687 1.39907 L F
.65364 1.35587 m .65472 1.36124 L .687 1.39907 L F
.65365 1.35638 m .65472 1.36124 L .65372 1.35627 L 1 .206 .584 r
F
.65331 1.35695 m .65434 1.36196 L .65472 1.36124 L F
.65331 1.35695 m .65472 1.36124 L .65365 1.35638 L F
.64699 1.32672 m .64228 1.3252 L .64796 1.33157 L .361 0 .604 r
F
.64673 1.32663 m .6364 1.29737 L .64228 1.3252 L F
.64228 1.3252 m .60363 1.26857 L .60768 1.2919 L .29 0 .601 r
F
.6364 1.29737 m .60363 1.26857 L .64228 1.3252 L .295 0 .607 r
F
.66958 1.24985 m .63665 1.3113 L .64259 1.34169 L 1 .213 .586 r
F
.67158 1.33463 m .64145 1.30273 L .64149 1.30289 L .361 0 .604 r
F
.64713 1.32676 m .64149 1.30289 L .64699 1.32672 L F
.67158 1.33463 m .64149 1.30289 L .64713 1.32676 L F
.64816 1.33178 m .64796 1.33157 L .65364 1.35587 L .352 0 .6 r
F
.65364 1.35587 m .65331 1.35695 L .65372 1.35626 L 1 .206 .584 r
F
.65331 1.35695 m .64857 1.373 L .65434 1.36196 L F
.67158 1.33463 m .64713 1.32676 L .67927 1.36663 L .361 0 .604 r
F
.64713 1.32676 m .64699 1.32672 L .64716 1.32692 L F
.64713 1.32676 m .64716 1.32692 L .67927 1.36663 L F
.64699 1.32672 m .64796 1.33157 L .67927 1.36663 L F
.64703 1.32737 m .64796 1.33157 L .6471 1.32725 L 1 .213 .586 r
F
.64658 1.32813 m .64746 1.33251 L .64796 1.33157 L F
.64658 1.32813 m .64796 1.33157 L .64703 1.32737 L F
.64046 1.2982 m .6364 1.29737 L .64132 1.30259 L .373 0 .607 r
F
.6364 1.29737 m .59959 1.246 L .60363 1.26857 L .295 0 .607 r
F
.6399 1.30012 m .63075 1.28198 L .63665 1.3113 L 1 .222 .588 r
F
.64026 1.29816 m .63997 1.29732 L .64015 1.29814 L .373 0 .607 r
F
.66214 1.22366 m .63486 1.27434 L .6399 1.30012 L 1 .222 .588 r
F
.63486 1.27434 m .63075 1.28198 L .6399 1.30012 L F
.63445 1.27215 m .63486 1.27434 L .63499 1.27409 L 1 .236 .59 r
F
.63421 1.27088 m .63461 1.27308 L .6347 1.27348 L .389 .001 .612 r
F
.63461 1.27308 m .63484 1.27433 L .63486 1.27434 L F
.6341 1.27028 m .63054 1.27009 L .63484 1.27433 L F
.63401 1.27059 m .63486 1.27434 L .63445 1.27215 L 1 .236 .59 r
F
.63426 1.27118 m .6347 1.27348 L .63489 1.27437 L .389 .001 .612 r
F
.63421 1.27088 m .6347 1.27348 L .63426 1.27118 L F
.63461 1.27308 m .63486 1.27434 L .63489 1.27437 L F
.66392 1.30297 m .63489 1.27437 L .63764 1.28615 L .373 0 .607 r
F
.64054 1.29822 m .63764 1.28615 L .64046 1.2982 L F
.66392 1.30297 m .63764 1.28615 L .64054 1.29822 L F
.64145 1.30273 m .64132 1.30259 L .64699 1.32672 L .361 0 .604 r
F
.64699 1.32672 m .64658 1.32813 L .64711 1.32723 L 1 .213 .586 r
F
.64658 1.32813 m .64259 1.34169 L .64746 1.33251 L F
.66392 1.30297 m .64054 1.29822 L .67158 1.33463 L .373 0 .607 r
F
.64054 1.29822 m .64046 1.2982 L .64056 1.29832 L F
.64054 1.29822 m .64056 1.29832 L .67158 1.33463 L F
.64046 1.2982 m .64132 1.30259 L .67158 1.33463 L F
.64053 1.29906 m .64132 1.30259 L .64061 1.29893 L 1 .222 .588 r
F
.6399 1.30012 m .64063 1.30387 L .64132 1.30259 L F
.6399 1.30012 m .64132 1.30259 L .64053 1.29906 L F
.63489 1.27437 m .63486 1.27434 L .64046 1.2982 L .373 0 .607 r
F
.64046 1.2982 m .6399 1.30012 L .64063 1.2989 L 1 .222 .588 r
F
.6399 1.30012 m .63665 1.3113 L .64063 1.30387 L F
.6341 1.27028 m .63421 1.27088 L .63421 1.27088 L .389 .001 .612 r
F
.6341 1.27028 m .63401 1.27059 L .63445 1.27215 L 1 .236 .59 r
F
.6341 1.27028 m .63445 1.27215 L .63499 1.27409 L F
.6341 1.27028 m .63421 1.27088 L .66392 1.30297 L .389 .001 .612 r
F
.63421 1.27088 m .63489 1.27437 L .66392 1.30297 L F
.65629 1.2715 m .6341 1.27028 L .66392 1.30297 L F
.63104 1.25712 m .62866 1.24685 L .63098 1.25709 L F
.6341 1.27028 m .6287 1.24678 L .62993 1.25233 L 1 .236 .59 r
F
.65472 1.19823 m .6295 1.24529 L .6341 1.27028 L F
.6295 1.24529 m .6287 1.24678 L .6341 1.27028 L F
.63397 1.27028 m .6332 1.26802 L .63368 1.27026 L .389 .001 .612 r
F
.62993 1.25233 m .62488 1.2539 L .63401 1.27059 L 1 .236 .59 r
F
.6287 1.24678 m .62866 1.24685 L .62993 1.25233 L F
.62866 1.24685 m .62488 1.2539 L .62993 1.25233 L F
.65629 1.2715 m .63104 1.25712 L .6341 1.27028 L .389 .001 .612 r
F
.63104 1.25712 m .63098 1.25709 L .6341 1.27028 L F
.65629 1.2715 m .62866 1.24685 L .63104 1.25712 L F
.6341 1.27028 m .63098 1.25709 L .63397 1.27028 L F
.6341 1.27028 m .62993 1.25233 L .63401 1.27059 L 1 .236 .59 r
F
.63401 1.27059 m .62488 1.2539 L .63075 1.28198 L F
.63401 1.27059 m .63075 1.28198 L .63486 1.27434 L F
.64869 1.23999 m .62797 1.24286 L .65629 1.2715 L .414 .003 .616 r
F
.62797 1.24286 m .6247 1.24331 L .62861 1.2468 L F
.62797 1.24286 m .62785 1.24328 L .6283 1.24476 L 1 .257 .593 r
F
.62797 1.24286 m .6283 1.24476 L .62883 1.24652 L F
.62797 1.24286 m .62861 1.2468 L .62866 1.24685 L .414 .003 .616 r
F
.62785 1.24328 m .62866 1.24685 L .62883 1.24652 L 1 .257 .593 r
F
.62797 1.24286 m .62866 1.24685 L .65629 1.2715 L .414 .003 .616 r
F
.64734 1.1737 m .62393 1.21806 L .62797 1.24286 L 1 .257 .593 r
F
.62745 1.24054 m .62287 1.22007 L .62742 1.24054 L .414 .003 .616 r
F
.62393 1.21806 m .62287 1.22007 L .62797 1.24286 L 1 .257 .593 r
F
.64869 1.23999 m .62287 1.22007 L .62745 1.24054 L .414 .003 .616 r
F
.64869 1.23999 m .62742 1.24054 L .62797 1.24286 L F
.62287 1.22007 m .62285 1.22011 L .62797 1.24286 L 1 .257 .593 r
F
.62797 1.24286 m .62742 1.24054 L .62794 1.24286 L .414 .003 .616 r
F
.62797 1.24286 m .62285 1.22011 L .62785 1.24328 L 1 .257 .593 r
F
.62785 1.24328 m .61905 1.22731 L .62488 1.2539 L F
.62285 1.22011 m .61905 1.22731 L .62785 1.24328 L F
.62785 1.24328 m .62488 1.2539 L .62866 1.24685 L F
.64111 1.20811 m .62222 1.21566 L .64869 1.23999 L .452 .009 .621 r
F
.62222 1.21566 m .61888 1.21699 L .62287 1.22007 L F
.62222 1.21566 m .62254 1.21783 L .62312 1.21959 L 1 .286 .596 r
F
.62204 1.21632 m .62287 1.22007 L .62312 1.21959 L F
.62222 1.21566 m .62287 1.22007 L .64869 1.23999 L .452 .009 .621 r
F
.62222 1.21566 m .62204 1.21632 L .62254 1.21783 L 1 .286 .596 r
F
.62222 1.21566 m .61756 1.19415 L .62204 1.21632 L F
.61709 1.18811 m .61655 1.18565 L .61708 1.18812 L .514 .024 .625 r
F
.64 1.1503 m .61814 1.19301 L .62264 1.21409 L 1 .286 .596 r
F
.63365 1.17587 m .61656 1.18565 L .61709 1.18811 L .514 .024 .625 r
F
.61656 1.18565 m .61655 1.18565 L .61709 1.18811 L F
.62264 1.21409 m .61769 1.19388 L .62222 1.21566 L 1 .286 .596 r
F
.61814 1.19301 m .61769 1.19388 L .62264 1.21409 L F
.61769 1.19388 m .61756 1.19415 L .62222 1.21566 L F
.64111 1.20811 m .61769 1.19388 L .62222 1.21566 L .452 .009 .621 r
F
.63365 1.17587 m .61353 1.16827 L .61663 1.18561 L .514 .024 .625 r
F
.61353 1.16827 m .61314 1.16906 L .61708 1.18812 L 1 .33 .599 r
F
.61708 1.18812 m .61655 1.18565 L .61699 1.18818 L .514 .024 .625 r
F
.61699 1.18818 m .61554 1.18483 L .61609 1.18885 L F
.61708 1.18812 m .61314 1.16906 L .61675 1.18937 L 1 .33 .599 r
F
.61308 1.19108 m .58354 1.16439 L .58753 1.18342 L .376 .003 .648 r
F
.61675 1.18937 m .60758 1.18043 L .61325 1.20256 L 1 .33 .599 r
F
.61314 1.16906 m .60758 1.18043 L .61675 1.18937 L F
.61888 1.21699 m .58753 1.18342 L .59154 1.20337 L .341 0 .634 r
F
.62204 1.21632 m .61325 1.20256 L .61905 1.22731 L 1 .286 .596 r
F
.61756 1.19415 m .61325 1.20256 L .62204 1.21632 L F
.62204 1.21632 m .61905 1.22731 L .62287 1.22007 L F
.63365 1.17587 m .61708 1.18812 L .64111 1.2081 L .514 .024 .625 r
F
.61708 1.18812 m .61769 1.19388 L .61814 1.19301 L 1 .33 .599 r
F
.61708 1.18812 m .61769 1.19388 L .64111 1.2081 L .514 .024 .625 r
F
.61708 1.18812 m .61325 1.20256 L .61769 1.19388 L 1 .33 .599 r
F
.6262 1.14241 m .61318 1.15868 L .63365 1.17587 L .619 .06 .628 r
F
.61318 1.15868 m .60737 1.16594 L .61327 1.16817 L F
.61318 1.15868 m .61327 1.16817 L .61353 1.16827 L F
.61318 1.15868 m .6124 1.16173 L .61337 1.16382 L 1 .392 .603 r
F
.61318 1.15868 m .61337 1.16382 L .61451 1.16627 L F
.6124 1.16173 m .61353 1.16827 L .61451 1.16627 L F
.61318 1.15868 m .61353 1.16827 L .63365 1.17587 L .619 .06 .628 r
F
.61318 1.15868 m .61154 1.14933 L .61231 1.15977 L F
.61318 1.15868 m .60997 1.14394 L .6124 1.16173 L 1 .392 .603 r
F
.62565 1.11025 m .61298 1.13749 L .61318 1.15868 L F
.61194 1.14914 m .61099 1.14176 L .61154 1.14933 L .619 .06 .628 r
F
.61298 1.13749 m .61099 1.14176 L .61318 1.15868 L 1 .392 .603 r
F
.6262 1.14241 m .61099 1.14176 L .61194 1.14914 L .619 .06 .628 r
F
.6262 1.14241 m .61154 1.14933 L .61318 1.15868 L F
.61099 1.14176 m .60997 1.14394 L .61318 1.15868 L 1 .392 .603 r
F
.6124 1.16173 m .60195 1.16119 L .60758 1.18043 L F
.60997 1.14394 m .60195 1.16119 L .6124 1.16173 L F
.6124 1.16173 m .60758 1.18043 L .61353 1.16827 L F
.61877 1.1083 m .6126 1.12025 L .6262 1.14241 L .784 .128 .629 r
F
.6126 1.12025 m .60169 1.14137 L .61099 1.14176 L F
.6126 1.12025 m .61009 1.12988 L .61292 1.12631 L 1 .479 .611 r
F
.6126 1.12025 m .61292 1.12631 L .61367 1.12537 L F
.6126 1.12025 m .61099 1.14176 L .6262 1.14241 L .784 .128 .629 r
F
.61011 1.12986 m .61099 1.14176 L .61206 1.1274 L 1 .479 .611 r
F
.61009 1.12988 m .60824 1.14768 L .61099 1.14176 L F
.61009 1.12988 m .61099 1.14176 L .61011 1.12986 L F
.61011 1.12981 m .59637 1.14553 L .60195 1.16119 L F
.6126 1.12025 m .60978 1.12463 L .61011 1.12981 L F
.60978 1.12463 m .59637 1.14553 L .61011 1.12981 L F
.61859 1.09719 m .61222 1.11105 L .6126 1.12025 L F
.61222 1.11105 m .61211 1.1111 L .6126 1.12025 L .784 .128 .629 r
F
.61222 1.11105 m .59637 1.14553 L .6126 1.12025 L 1 .479 .611 r
F
.61877 1.1083 m .61222 1.11105 L .6126 1.12025 L .784 .128 .629 r
F
.61274 1.10825 m .61222 1.11105 L .61229 1.11102 L .807 .144 .633 r
F
.61808 1.10518 m .61274 1.10825 L .61877 1.10829 L F
.61274 1.10825 m .61229 1.11102 L .61877 1.10829 L F
.61274 1.10825 m .61232 1.10859 L .61231 1.10922 L 1 .539 .617 r
F
.61794 1.09641 m .61288 1.10737 L .61274 1.10825 L F
.61274 1.10825 m .61267 1.10817 L .61265 1.1083 L .807 .144 .633 r
F
.61267 1.10817 m .61239 1.10784 L .61265 1.1083 L F
.61288 1.10737 m .61273 1.10768 L .61274 1.10825 L 1 .539 .617 r
F
.61276 1.10767 m .61273 1.10768 L .61274 1.10825 L .807 .144 .633 r
F
.61273 1.10768 m .61239 1.10784 L .61274 1.10825 L F
.61273 1.10768 m .61232 1.10859 L .61274 1.10825 L 1 .539 .617 r
F
.61231 1.10922 m .59585 1.14426 L .59637 1.14552 L F
.61232 1.10859 m .59585 1.14426 L .61231 1.10922 L F
.61243 1.10843 m .59549 1.11576 L .59602 1.11787 L .807 .144 .633 r
F
.61239 1.10784 m .59549 1.11576 L .61243 1.10843 L F
.61354 1.08637 m .61239 1.10783 L .61423 1.09023 L .931 .202 .631 r
F
.61336 1.09353 m .59585 1.14426 L .61232 1.10858 L 1 .589 .628 r
F
.61423 1.09023 m .61239 1.10783 L .61273 1.10767 L .931 .202 .631 r
F
.61567 1.09498 m .61273 1.10767 L .61794 1.09641 L 1 .589 .628 r
F
.61794 1.09641 m .61274 1.10825 L .61859 1.09719 L 1 .539 .617 r
F
.61534 1.09641 m .61273 1.10767 L .617 1.10568 L .931 .202 .631 r
F
.61423 1.09023 m .61273 1.10767 L .61534 1.09641 L F
.61447 1.09422 m .61273 1.10768 L .61273 1.10767 L 1 .589 .628 r
F
.61323 1.08464 m .617 1.10568 L .61567 1.09498 L .931 .202 .631 r
F
.61447 1.09422 m .61273 1.10767 L .61567 1.09498 L 1 .589 .628 r
F
.61288 1.10446 m .61232 1.10858 L .61273 1.10768 L F
.61336 1.09353 m .61232 1.10858 L .61288 1.10446 L F
.61336 1.09353 m .61273 1.10768 L .61447 1.09422 L F
.61808 1.10518 m .61276 1.10767 L .61274 1.10825 L .807 .144 .633 r
F
.61274 1.10825 m .61231 1.10922 L .61273 1.10842 L 1 .539 .617 r
F
.61231 1.10922 m .59637 1.14552 L .61222 1.11105 L F
.61009 1.12988 m .60195 1.16119 L .60824 1.14768 L 1 .479 .611 r
F
.61427 1.08376 m .61336 1.09353 L .61567 1.09498 L 1 .375 .489 r
F
.61345 1.09259 m .61336 1.09353 L .62156 1.00548 L F
.62042 1.06926 m .61686 1.07687 L .61741 1.08967 L 1 .295 .517 r
F
.62111 1.08368 m .61794 1.09641 L .61859 1.09719 L 1 .469 .547 r
F
.6201 1.08532 m .61794 1.09641 L .62111 1.08368 L F
.62959 1.07545 m .61859 1.09719 L .62565 1.11025 L 1 .427 .553 r
F
.63787 1.00224 m .63244 1.02897 L .62959 1.07545 L F
.63244 1.02897 m .61859 1.09719 L .62959 1.07545 L F
.63256 1.02228 m .6201 1.08532 L .62111 1.08368 L 1 .469 .547 r
F
.63703 .99832 m .63266 1.02077 L .63256 1.02228 L F
.63266 1.02077 m .6201 1.08532 L .63256 1.02228 L F
.63787 1.00224 m .62565 1.11025 L .64665 1.03444 L 1 .427 .553 r
F
.64665 1.03444 m .62847 1.10004 L .63279 1.12887 L 1 .361 .575 r
F
.62847 1.10004 m .62565 1.11025 L .62733 1.11463 L F
.62847 1.10004 m .62733 1.11463 L .63279 1.12887 L F
.63256 1.02228 m .63245 1.02895 L .63787 1.00223 L 1 .469 .547 r
F
.63019 .91907 m .63005 .92125 L .63862 1.0827 L 1 .295 .517 r
F
.63497 .98574 m .63418 .99767 L .63512 1.01566 L .119 0 .421 r
F
.63578 1.00726 m .63512 1.01566 L .6387 1.08418 L F
.63497 .98574 m .63512 1.01566 L .63578 1.00726 L F
.63862 1.0827 m .61808 1.10517 L .63869 1.08417 L 1 .295 .517 r
F
.63256 1.02228 m .62111 1.08368 L .63245 1.02895 L 1 .469 .547 r
F
.62111 1.08368 m .62115 1.08456 L .63245 1.02895 L F
.63005 .92125 m .61808 1.10517 L .63862 1.0827 L 1 .295 .517 r
F
.63377 .95428 m .6333 .9808 L .63418 .99767 L .119 0 .421 r
F
.63377 .95428 m .63418 .99767 L .63497 .98574 L F
.64665 1.03444 m .63279 1.12887 L .65533 1.05992 L 1 .361 .575 r
F
.65533 1.05992 m .63999 1.1503 L .66397 1.08324 L 1 .308 .583 r
F
.65533 1.05992 m .63279 1.12887 L .63999 1.1503 L F
.66398 1.08324 m .64 1.1503 L .64734 1.1737 L 1 .276 .586 r
F
.66398 1.08324 m .64734 1.1737 L .67274 1.10602 L F
.65867 1.13411 m .6387 1.0842 L .6396 1.09079 L .186 0 .49 r
F
.65867 1.13411 m .65439 1.12438 L .65963 1.13658 L F
.65439 1.12438 m .6396 1.09079 L .65442 1.12469 L F
.65439 1.12438 m .65442 1.12469 L .65963 1.13658 L F
.67274 1.10602 m .65472 1.19823 L .68152 1.12847 L 1 .256 .586 r
F
.67274 1.10602 m .64734 1.1737 L .65472 1.19823 L F
.65706 1.12031 m .65382 1.11951 L .66824 1.13704 L 0 0 .564 r
F
.65201 1.11907 m .65201 1.11907 L .65867 1.13411 L .119 0 .421 r
F
.65201 1.11907 m .6387 1.08418 L .65507 1.12509 L F
.65201 1.11907 m .65507 1.12509 L .65867 1.13411 L F
.65382 1.11951 m .65201 1.11907 L .65403 1.12131 L 0 0 .564 r
F
.65382 1.11951 m .65403 1.12131 L .66824 1.13704 L F
.65201 1.11907 m .63587 .97325 L .6387 1.08418 L .119 0 .421 r
F
.63587 .97325 m .63377 .95428 L .63502 .98713 L F
.63587 .97325 m .63502 .98713 L .6387 1.08418 L F
.61928 1.08664 m .61741 1.08967 L .61808 1.10517 L 1 .295 .517 r
F
.62042 1.06926 m .61741 1.08967 L .61928 1.08664 L F
.61686 1.07687 m .61567 1.09498 L .61808 1.10517 L F
.62477 1.0737 m .61336 1.09353 L .61431 1.08364 L .937 .363 .71 r
F
.62537 1.04421 m .62126 1.01071 L .62613 1.00613 L F
.62477 1.0737 m .62732 .94714 L .63011 .91888 L F
.63377 .95428 m .63026 .92255 L .6333 .9808 L .119 0 .421 r
F
.6387 1.08419 m .61808 1.10518 L .61877 1.10829 L .758 .074 .589 r
F
.6387 1.08419 m .61877 1.10829 L .63959 1.09079 L F
.6396 1.09081 m .61877 1.1083 L .6262 1.14241 L .715 .06 .588 r
F
.6396 1.09081 m .6262 1.14241 L .64892 1.14373 L F
.65963 1.13659 m .6396 1.09081 L .64892 1.14373 L .11 0 .496 r
F
.64212 1.10585 m .62478 1.07371 L .63025 .92203 L .495 0 .453 r
F
.6332 1.00377 m .62939 1.00504 L .63058 1.00291 L 0 0 0 r
F
.63058 1.00291 m .62366 1.00901 L .63161 1.00106 L F
.62613 1.00613 m .62126 1.01071 L .62732 .94714 L .937 .363 .71 r
F
.63058 1.00291 m .62749 1.0061 L .62366 1.00901 L 0 0 0 r
F
.63011 .91888 m .62732 .94714 L .63016 .9173 L .937 .363 .71 r
F
.62537 1.04421 m .61431 1.08364 L .62126 1.01071 L F
.62195 .99955 m .61345 1.09259 L .62156 1.00548 L 1 .375 .489 r
F
.62366 1.00902 m .61414 1.07801 L .63009 .91349 L 1 .283 .581 r
F
.6328 .96016 m .635 .96509 L .65201 1.11907 L .495 0 .453 r
F
.64212 1.10585 m .6327 .95992 L .65099 1.11067 L F
.64212 1.10585 m .65099 1.11067 L .65201 1.11907 L F
.63237 1.10056 m .62478 1.07371 L .64074 1.1033 L .546 0 .285 r
F
.63237 1.10056 m .64074 1.1033 L .64212 1.10585 L F
.63237 1.10056 m .61672 1.09048 L .62478 1.07371 L F
.62263 1.09763 m .61672 1.09048 L .63217 1.10043 L .333 0 0 r
F
.62263 1.09763 m .63217 1.10043 L .63237 1.10056 L F
.61567 1.09498 m .617 1.10568 L .61808 1.10517 L .931 .202 .631 r
F
.61323 1.08464 m .59549 1.11575 L .60678 1.11046 L F
.61323 1.08464 m .60678 1.11046 L .61354 1.08637 L F
.61336 1.09353 m .59219 1.13641 L .59585 1.14426 L 1 .589 .628 r
F
.61323 1.08464 m .59177 1.10143 L .59549 1.11575 L .931 .202 .631 r
F
.60651 1.09642 m .59219 1.13641 L .61336 1.09353 L 1 .733 .668 r
F
.62477 1.0737 m .60651 1.09642 L .61336 1.09353 L .937 .363 .71 r
F
.62263 1.09763 m .60842 1.09636 L .61672 1.09048 L .333 0 0 r
F
.624 1.09229 m .61302 1.0948 L .62263 1.09763 L .381 .082 .89 r
F
.61302 1.0948 m .61286 1.09484 L .62263 1.09763 L F
.63498 1.09894 m .6238 1.09775 L .63237 1.10056 L .022 0 .76 r
F
.6238 1.09775 m .62263 1.09763 L .63237 1.10056 L F
.64599 1.1079 m .63302 1.10091 L .64212 1.10585 L 0 0 .562 r
F
.63302 1.10091 m .63237 1.10056 L .64212 1.10585 L F
.6327 .95992 m .6328 .96016 L .65201 1.11907 L .495 0 .453 r
F
.63988 .99278 m .62366 1.00901 L .62367 1.00887 L .376 0 .42 r
F
.61414 1.07801 m .62621 .9529 L .63009 .91349 L 1 .283 .581 r
F
.63004 .91091 m .62624 .95258 L .6296 .91774 L 1 .375 .489 r
F
.6307 .91033 m .62367 1.00887 L .6299 .90318 L .376 0 .42 r
F
.63499 .96504 m .63486 .96383 L .635 .96509 L .495 0 .453 r
F
.6326 .95851 m .63485 .96379 L .63499 .96504 L F
.63485 .96379 m .63486 .96383 L .63499 .96504 L F
.6326 .95851 m .635 .96509 L .6328 .96016 L F
.6327 .95992 m .6326 .95851 L .6328 .96016 L F
.6326 .95851 m .63025 .92203 L .63486 .96383 L F
.63988 .99278 m .62367 1.00887 L .6307 .91033 L .376 0 .42 r
F
.62849 1.00399 m .62749 1.0061 L .63058 1.00291 L .819 .431 .803 r
F
.62112 1.0078 m .62749 1.0061 L .62849 1.00399 L F
.62939 1.00504 m .62112 1.0078 L .63058 1.00291 L 0 0 0 r
F
.63058 1.00291 m .63161 1.00106 L .63306 .9996 L F
.63714 .99577 m .63306 .9996 L .63988 .99278 L F
.63058 1.00291 m .63306 .9996 L .63714 .99577 L F
.62477 1.0737 m .61431 1.08364 L .62537 1.04421 L .937 .363 .71 r
F
.61414 1.07801 m .61323 1.08464 L .61926 1.02338 L 1 .283 .581 r
F
.61414 1.07801 m .61926 1.02338 L .61932 1.02326 L F
.62366 1.00902 m .61007 1.04942 L .61414 1.07801 L F
.61557 1.01839 m .60819 1.05167 L .62366 1.00902 L 1 .431 .639 r
F
.60819 1.05167 m .61007 1.04942 L .62366 1.00902 L F
.62749 1.0061 m .61557 1.01838 L .62366 1.00901 L 0 0 0 r
F
.62749 1.0061 m .62366 1.00901 L .62366 1.00901 L F
.62112 1.0078 m .61557 1.01838 L .62749 1.0061 L .819 .431 .803 r
F
.61414 1.07801 m .60601 1.0615 L .61323 1.08464 L 1 .283 .581 r
F
.61007 1.04942 m .60601 1.0615 L .61414 1.07801 L F
.60819 1.05167 m .60601 1.0615 L .61007 1.04942 L 1 .431 .639 r
F
.65306 .95589 m .66355 .96668 L .66369 .96711 L 1 .033 .261 r
F
.66132 .9652 m .66369 .96711 L .66408 .96831 L F
.65306 .95589 m .66369 .96711 L .66132 .9652 L F
.65526 .94136 m .65135 .95506 L .65381 .95704 L 1 .144 .568 r
F
.65508 .97236 m .65032 .95424 L .65593 .97163 L 1 .033 .256 r
F
.65032 .95424 m .65029 .95415 L .65032 .95424 L F
.65032 .95424 m .65032 .95424 L .65593 .97163 L F
.65029 .95415 m .65143 .95536 L .65593 .97163 L F
.64999 .95354 m .64993 .95376 L .65029 .95415 L .894 .09 .558 r
F
.65002 .95364 m .64999 .95354 L .65015 .95389 L 1 .033 .256 r
F
.65032 .95425 m .65027 .95406 L .65027 .95407 L F
.65432 .93857 m .64999 .95354 L .65029 .95415 L .894 .09 .558 r
F
.64904 .97936 m .64372 .94848 L .65507 .97237 L 1 .062 .303 r
F
.64372 .94848 m .64422 .94946 L .64453 .94913 L .396 0 .494 r
F
.64372 .94848 m .64999 .95354 L .65507 .97237 L 1 .062 .303 r
F
.64372 .94848 m .64453 .94913 L .64649 .94701 L .396 0 .494 r
F
.64443 .94316 m .64372 .94848 L .64649 .94701 L F
.64774 .9185 m .6315 .90156 L .64372 .94848 L F
.64376 .94874 m .64269 .94452 L .64372 .94848 L 1 .062 .303 r
F
.64649 .94701 m .64999 .95354 L .65016 .95292 L .396 0 .494 r
F
.64672 .94676 m .65016 .95292 L .65432 .93856 L F
.64649 .94701 m .65016 .95292 L .64672 .94676 L F
.65135 .95507 m .65135 .95506 L .65144 .95524 L 1 .033 .261 r
F
.65432 .93857 m .65046 .9535 L .65526 .94136 L .894 .09 .558 r
F
.65046 .9535 m .65029 .95415 L .65051 .95359 L F
.65046 .9535 m .65051 .95359 L .65526 .94136 L F
.65005 .95377 m .65002 .95364 L .65032 .95425 L 1 .033 .256 r
F
.65002 .95364 m .65015 .95389 L .65032 .95425 L F
.64999 .95354 m .65027 .95406 L .65032 .95425 L F
.64443 .94316 m .64649 .94701 L .65432 .93856 L .396 0 .494 r
F
.65508 .97236 m .65005 .95377 L .65032 .95425 L 1 .033 .256 r
F
.65594 .97163 m .65135 .95507 L .65363 .959 L 1 .033 .261 r
F
.65526 .94136 m .65363 .959 L .66483 .968 L 1 .144 .568 r
F
.65366 .95918 m .65363 .959 L .66408 .96831 L 1 .033 .261 r
F
.65363 .959 m .66125 .96513 L .66408 .96831 L F
.6705 .90256 m .65526 .94136 L .66483 .968 L .795 .089 .591 r
F
.65594 .97163 m .65366 .95918 L .66408 .96831 L 1 .033 .261 r
F
.73602 .63601 m .74945 .67841 L .74798 .61419 L 1 .496 .6 r
F
.73057 .57642 m .73602 .63601 L .74798 .61419 L 1 .45 .581 r
F
.39255 .92025 m .37066 .94088 L .36159 .95721 L 1 .425 .647 r
F
.40007 .91083 m .37066 .94088 L .39255 .92025 L 1 .806 .684 r
F
.5178 .85932 m .50237 .86109 L .5012 .86667 L .757 .683 .871 r
F
.50237 .86109 m .48384 .86765 L .5012 .86667 L .752 .679 .873 r
F
.79908 .80818 m .78601 .91413 L .79743 .91904 L 1 .296 .588 r
F
.78727 .80984 m .78601 .91413 L .79908 .80818 L 1 .299 .59 r
F
.61401 .67787 m .62473 .68743 L .62666 .68113 L .601 .421 .851 r
F
.61401 .67787 m .61234 .68453 L .62473 .68743 L F
.35711 .51645 m .36232 .49496 L .34956 .51697 L .918 .497 .757 r
F
.35711 .51645 m .3692 .49932 L .36232 .49496 L F
.51316 .66098 m .50087 .6614 L .50137 .66259 L .759 .48 .802 r
F
.51316 .66098 m .51316 .66098 L .50137 .66259 L F
.51316 .66098 m .5237 .66682 L .52453 .66592 L .757 .478 .802 r
F
.51316 .66098 m .51316 .66098 L .5237 .66682 L F
.37505 .64069 m .37723 .62457 L .3649 .61929 L .749 .325 .748 r
F
.38758 .64314 m .37723 .62457 L .37505 .64069 L .782 .379 .758 r
F
.60137 .67509 m .61234 .68453 L .61401 .67787 L .656 .452 .834 r
F
.60137 .67509 m .59995 .68161 L .61234 .68453 L F
.43062 .52426 m .43365 .51503 L .42132 .51813 L .555 .378 .862 r
F
.43062 .52426 m .44173 .52102 L .43365 .51503 L F
.46249 .87375 m .44487 .87513 L .43881 .88157 L .875 .803 .858 r
F
.46699 .86824 m .44487 .87513 L .46249 .87375 L .905 .824 .851 r
F
.48384 .86765 m .46699 .86824 L .46249 .87375 L .751 .679 .876 r
F
.52557 .66386 m .53715 .6689 L .53797 .66678 L .753 .475 .802 r
F
.52557 .66386 m .52516 .66493 L .53715 .6689 L F
.49285 .53291 m .50113 .5251 L .4894 .52629 L .725 .553 .839 r
F
.49285 .53291 m .50287 .53224 L .50113 .5251 L F
.54302 .53874 m .5587 .53744 L .54808 .53223 L .661 .446 .829 r
F
.53337 .53555 m .54302 .53874 L .54808 .53223 L .708 .484 .822 r
F
.58875 .67265 m .59995 .68161 L .60137 .67509 L .693 .463 .821 r
F
.58875 .67265 m .58756 .67867 L .59995 .68161 L F
.48807 .65948 m .48803 .65711 L .47547 .65525 L .766 .488 .802 r
F
.50061 .66021 m .48803 .65711 L .48807 .65948 L .762 .484 .802 r
F
.50087 .6614 m .50061 .66021 L .48807 .65948 L F
.69898 .50373 m .72163 .52087 L .70961 .47957 L 1 .428 .594 r
F
.69898 .50373 m .71039 .54358 L .72163 .52087 L F
.29063 .98662 m .26071 .88778 L .28044 .99514 L .706 .054 .585 r
F
.29063 .98662 m .27167 .88427 L .26071 .88778 L F
.38758 .64314 m .38959 .629 L .37723 .62457 L .782 .379 .758 r
F
.40013 .6451 m .38959 .629 L .38758 .64314 L .799 .42 .768 r
F
.51316 .66098 m .52453 .66592 L .52516 .66493 L .757 .478 .802 r
F
.51316 .66098 m .51316 .66098 L .52453 .66592 L F
.51316 .66098 m .50061 .66021 L .50087 .6614 L .759 .48 .802 r
F
.51316 .66098 m .51316 .66098 L .50087 .6614 L F
.57614 .67044 m .58756 .67867 L .58875 .67265 L .717 .466 .813 r
F
.57614 .67044 m .57517 .67569 L .58756 .67867 L F
.55363 .16427 m .59715 .16626 L .55528 .13236 L .918 .13 .586 r
F
.51293 .15174 m .55363 .16427 L .55528 .13236 L .969 .149 .584 r
F
.59671 .85095 m .58962 .85251 L .60491 .85658 L .147 0 .791 r
F
.59671 .85095 m .58285 .85091 L .58962 .85251 L F
.40013 .6451 m .40195 .63285 L .38959 .629 L .799 .42 .768 r
F
.41268 .6468 m .40195 .63285 L .40013 .6451 L .804 .45 .776 r
F
.56353 .66838 m .57517 .67569 L .57614 .67044 L .732 .468 .807 r
F
.56353 .66838 m .56277 .67271 L .57517 .67569 L F
.41268 .6468 m .41432 .63632 L .40195 .63285 L .804 .45 .776 r
F
.42524 .64841 m .41432 .63632 L .41268 .6468 L .801 .469 .784 r
F
.46752 .53 m .47302 .52219 L .46089 .5243 L .634 .503 .867 r
F
.46752 .53 m .47812 .52796 L .47302 .52219 L F
.33238 .27955 m .36294 .29462 L .35653 .26633 L .386 0 .597 r
F
.34005 .30847 m .36294 .29462 L .33238 .27955 L .389 0 .601 r
F
.42524 .64841 m .42669 .63955 L .41432 .63632 L .801 .469 .784 r
F
.43779 .65003 m .42669 .63955 L .42524 .64841 L .794 .48 .79 r
F
.43779 .65003 m .43906 .64266 L .42669 .63955 L F
.45035 .6517 m .43906 .64266 L .43779 .65003 L .785 .486 .795 r
F
.55093 .66643 m .56277 .67271 L .56353 .66838 L .742 .469 .804 r
F
.55093 .66643 m .55037 .66974 L .56277 .67271 L F
.45035 .6517 m .45142 .64571 L .43906 .64266 L .785 .486 .795 r
F
.46291 .65344 m .45142 .64571 L .45035 .6517 L .777 .487 .798 r
F
.51316 .66098 m .52516 .66493 L .52557 .66386 L .756 .477 .802 r
F
.51316 .66098 m .51316 .66098 L .52516 .66493 L F
.27004 .74899 m .26098 .78779 L .24815 .78705 L .686 0 .257 r
F
.28208 .7557 m .26098 .78779 L .27004 .74899 L .677 0 .235 r
F
.50061 .66021 m .50059 .65902 L .48803 .65711 L .762 .484 .802 r
F
.51316 .66098 m .50059 .65902 L .50061 .66021 L .759 .48 .802 r
F
.51316 .66098 m .51316 .66098 L .50061 .66021 L F
.53337 .53555 m .54808 .53223 L .53679 .52822 L .708 .484 .822 r
F
.52333 .53341 m .53337 .53555 L .53679 .52822 L .746 .516 .819 r
F
.46291 .65344 m .46378 .64873 L .45142 .64571 L .777 .487 .798 r
F
.47547 .65525 m .46378 .64873 L .46291 .65344 L .77 .487 .8 r
F
.53834 .66455 m .55037 .66974 L .55093 .66643 L .748 .471 .803 r
F
.53834 .66455 m .53797 .66678 L .55037 .66974 L F
.50287 .53224 m .51309 .52477 L .50113 .5251 L .754 .555 .828 r
F
.50287 .53224 m .5131 .53234 L .51309 .52477 L F
.67684 .44123 m .7045 .42481 L .68562 .40719 L 1 .546 .589 r
F
.67684 .44123 m .6947 .45511 L .7045 .42481 L F
.43881 .88157 m .42088 .88442 L .41331 .89383 L 1 .983 .801 r
F
.44487 .87513 m .42088 .88442 L .43881 .88157 L 1 .953 .807 r
F
.47547 .65525 m .47613 .65176 L .46378 .64873 L .77 .487 .8 r
F
.48803 .65711 m .47613 .65176 L .47547 .65525 L .765 .485 .801 r
F
.44978 .52677 m .45423 .51896 L .44173 .52102 L .571 .424 .876 r
F
.44978 .52677 m .46089 .5243 L .45423 .51896 L F
.56846 .54339 m .58645 .54714 L .5765 .53955 L .55 .336 .843 r
F
.5587 .53744 m .56846 .54339 L .5765 .53955 L .59 .365 .832 r
F
.52575 .66274 m .53797 .66678 L .53834 .66455 L .752 .474 .802 r
F
.52575 .66274 m .52557 .66386 L .53797 .66678 L F
.68497 .48459 m .70961 .47957 L .6947 .45512 L 1 .603 .612 r
F
.68497 .48459 m .69898 .50373 L .70961 .47957 L F
.51294 .18445 m .55363 .16427 L .51293 .15174 L .974 .154 .586 r
F
.47394 .19116 m .51293 .15174 L .47228 .15818 L 1 .168 .584 r
F
.47394 .19116 m .51294 .18445 L .51293 .15174 L F
.48803 .65711 m .48848 .6548 L .47613 .65176 L .765 .485 .801 r
F
.50059 .65902 m .48848 .6548 L .48803 .65711 L .761 .483 .802 r
F
.39002 .51168 m .39335 .495 L .37962 .5056 L .64 .316 .786 r
F
.39002 .51168 m .40268 .50383 L .39335 .495 L F
.52333 .53341 m .53679 .52822 L .52505 .52572 L .746 .516 .819 r
F
.5131 .53234 m .52333 .53341 L .52505 .52572 L .762 .541 .82 r
F
.5131 .53234 m .52505 .52572 L .51309 .52477 L F
.51316 .66098 m .52557 .66386 L .52575 .66274 L .756 .477 .802 r
F
.51316 .66098 m .51316 .66098 L .52557 .66386 L F
.50059 .65902 m .50082 .65787 L .48848 .6548 L .761 .483 .802 r
F
.51316 .66098 m .50082 .65787 L .50059 .65902 L .758 .48 .802 r
F
.51316 .66098 m .51316 .66098 L .50059 .65902 L .759 .48 .802 r
F
.48671 .86203 m .46699 .86824 L .48384 .86765 L .799 .728 .866 r
F
.50237 .86109 m .48671 .86203 L .48384 .86765 L .752 .679 .873 r
F
.64957 .33185 m .6855 .29885 L .65593 .30155 L 1 .503 .587 r
F
.64957 .33185 m .67791 .33073 L .6855 .29885 L F
.72399 .55862 m .74562 .50963 L .73507 .53968 L 0 0 0 r
F
.72399 .55862 m .73424 .53199 L .74562 .50963 L F
.33233 .59817 m .33725 .58606 L .33119 .59717 L .408 .096 .793 r
F
.57603 .84772 m .56783 .85283 L .58285 .85091 L .476 .178 .896 r
F
.57603 .84772 m .56249 .85012 L .56783 .85283 L F
.3316 .37183 m .35557 .36353 L .34778 .33655 L .497 .014 .61 r
F
.34056 .39833 m .35557 .36353 L .3316 .37183 L .519 .022 .618 r
F
.32041 .4331 m .34056 .39833 L .3316 .37183 L .691 .061 .599 r
F
.39327 .22418 m .42895 .15044 L .3884 .19426 L 1 .182 .58 r
F
.39327 .22418 m .43222 .18263 L .42895 .15044 L F
.51316 .66098 m .51316 .66098 L .50082 .65787 L .758 .48 .802 r
F
.51316 .66098 m .51316 .66098 L .52575 .66274 L .756 .477 .802 r
F
.51316 .66098 m .50129 .65679 L .50082 .65787 L .758 .48 .802 r
F
.51316 .66098 m .51316 .66098 L .50129 .65679 L F
.51316 .66098 m .52575 .66274 L .52569 .66159 L .756 .477 .802 r
F
.51316 .66098 m .51316 .66098 L .52569 .66159 L .755 .477 .802 r
F
.51316 .66098 m .50199 .65578 L .50129 .65679 L .758 .48 .802 r
F
.51316 .66098 m .51316 .66098 L .50199 .65578 L F
.51316 .66098 m .52569 .66159 L .52541 .66042 L .755 .477 .802 r
F
.51316 .66098 m .51316 .66098 L .52541 .66042 L F
.51316 .66098 m .50288 .65489 L .50199 .65578 L .757 .479 .802 r
F
.51316 .66098 m .51316 .66098 L .50288 .65489 L F
.51316 .66098 m .52541 .66042 L .52492 .65931 L .755 .477 .802 r
F
.51316 .66098 m .51316 .66098 L .52492 .65931 L .756 .477 .802 r
F
.51316 .66098 m .50397 .65412 L .50288 .65489 L .757 .479 .802 r
F
.51316 .66098 m .51316 .66098 L .50397 .65412 L F
.51316 .66098 m .52492 .65931 L .52424 .65823 L .756 .477 .802 r
F
.51316 .66098 m .51316 .66098 L .52424 .65823 L .756 .478 .802 r
F
.51316 .66098 m .50522 .65347 L .50397 .65412 L .757 .478 .802 r
F
.51316 .66098 m .51316 .66098 L .50522 .65347 L F
.51316 .66098 m .52424 .65823 L .52337 .65719 L .756 .478 .802 r
F
.51316 .66098 m .51316 .66098 L .52337 .65719 L F
.51316 .66098 m .50662 .65296 L .50522 .65347 L .757 .478 .802 r
F
.51316 .66098 m .51316 .66098 L .50662 .65296 L F
.51316 .66098 m .52337 .65719 L .52233 .65622 L .756 .478 .802 r
F
.51316 .66098 m .51316 .66098 L .52233 .65622 L .757 .479 .802 r
F
.51316 .66098 m .50815 .6526 L .50662 .65296 L .757 .478 .802 r
F
.51316 .66098 m .51316 .66098 L .50815 .6526 L F
.51316 .66098 m .52233 .65622 L .52108 .65529 L .757 .479 .802 r
F
.51316 .66098 m .51316 .66098 L .52108 .65529 L F
.51316 .66098 m .50976 .6524 L .50815 .6526 L .758 .478 .802 r
F
.51316 .66098 m .51316 .66098 L .50976 .6524 L F
.51316 .66098 m .52108 .65529 L .51967 .65446 L .757 .479 .802 r
F
.51316 .66098 m .51316 .66098 L .51967 .65446 L .758 .479 .802 r
F
.51316 .66098 m .51144 .65236 L .50976 .6524 L .758 .478 .802 r
F
.51316 .66098 m .51316 .66098 L .51144 .65236 L F
.51316 .66098 m .51967 .65446 L .51815 .65375 L .758 .479 .802 r
F
.51316 .66098 m .51316 .66098 L .51815 .65375 L F
.51316 .66098 m .51315 .65247 L .51144 .65236 L .758 .478 .801 r
F
.51316 .66098 m .51316 .66098 L .51315 .65247 L F
.51316 .66098 m .51815 .65375 L .51654 .65318 L .758 .479 .802 r
F
.51316 .66098 m .51316 .66098 L .51654 .65318 L F
.51316 .66098 m .51486 .65275 L .51315 .65247 L .758 .479 .801 r
F
.51316 .66098 m .51316 .66098 L .51486 .65275 L F
.51316 .66098 m .51654 .65318 L .51486 .65275 L .758 .479 .802 r
F
.33233 .59817 m .33836 .58689 L .33725 .58606 L .408 .096 .793 r
F
.34036 .60466 m .33836 .58689 L .33233 .59817 L .477 .162 .792 r
F
.63786 .89105 m .62126 .8695 L .62966 .89004 L 0 0 .57 r
F
.62817 .87156 m .62126 .8695 L .63786 .89105 L 0 0 .661 r
F
.40007 .91083 m .37974 .9241 L .37066 .94088 L 1 .806 .684 r
F
.40078 .90993 m .37974 .92409 L .40007 .91083 L 1 .826 .686 r
F
.43551 .21468 m .47228 .15818 L .43222 .18263 L 1 .175 .582 r
F
.43551 .21468 m .47394 .19116 L .47228 .15818 L F
.61543 .55278 m .62386 .56032 L .63514 .56051 L .447 .224 .874 r
F
.60501 .55312 m .62386 .56032 L .61543 .55278 L .459 .239 .869 r
F
.52569 .66159 m .52575 .66274 L .53834 .66455 L .752 .473 .802 r
F
.34956 .51697 m .36134 .49431 L .34849 .51718 L 1 .486 .725 r
F
.34956 .51697 m .36232 .49496 L .36134 .49431 L F
.40078 .90993 m .38059 .92253 L .37974 .92409 L 1 .826 .686 r
F
.40575 .90353 m .38059 .92253 L .40078 .90993 L 1 .916 .698 r
F
.50082 .65787 m .48941 .65261 L .48848 .6548 L .761 .482 .802 r
F
.50082 .65787 m .50129 .65679 L .48941 .65261 L F
.78727 .80984 m .77458 .90913 L .78601 .91413 L 1 .299 .59 r
F
.77543 .81142 m .77458 .90913 L .78727 .80984 L 1 .301 .592 r
F
.30081 .97864 m .27167 .88427 L .29063 .98662 L .706 .054 .585 r
F
.30081 .97864 m .28266 .88075 L .27167 .88427 L F
.63304 .2473 m .6398 .25427 L .63798 .2201 L .814 .089 .584 r
F
.6398 .25427 m .67481 .20941 L .64344 .23022 L 1 .556 .587 r
F
.6398 .25427 m .66855 .24033 L .67481 .20941 L F
.63304 .2473 m .63927 .2588 L .6398 .25427 L .814 .089 .584 r
F
.62807 .27398 m .63581 .28174 L .63304 .2473 L .81 .089 .586 r
F
.63581 .28174 m .63585 .28168 L .63927 .2588 L 1 .554 .589 r
F
.63585 .28168 m .66855 .24033 L .63927 .2588 L F
.63927 .2588 m .66855 .24033 L .6398 .25427 L 1 .556 .587 r
F
.63581 .28174 m .66226 .27104 L .66855 .24033 L 1 .554 .589 r
F
.62807 .27398 m .63521 .28707 L .63581 .28174 L .81 .089 .586 r
F
.64317 .36192 m .67791 .33073 L .64957 .33185 L 1 .487 .587 r
F
.62308 .30006 m .63196 .30872 L .62807 .27398 L .804 .089 .588 r
F
.63196 .30872 m .63197 .30871 L .63521 .28707 L 1 .549 .591 r
F
.63197 .30871 m .66226 .27104 L .63521 .28707 L F
.63521 .28707 m .66226 .27104 L .63581 .28174 L 1 .554 .589 r
F
.63196 .30872 m .65593 .30155 L .66226 .27104 L 1 .549 .591 r
F
.62308 .30006 m .63128 .31502 L .63196 .30872 L .804 .089 .588 r
F
.61807 .32545 m .62826 .3351 L .62308 .30006 L .797 .089 .591 r
F
.62826 .3351 m .62858 .33287 L .62308 .30006 L F
.62861 .33308 m .63128 .31502 L .62308 .30006 L F
.6283 .33514 m .65593 .30155 L .63128 .31502 L 1 .542 .593 r
F
.6283 .33514 m .64957 .33185 L .65593 .30155 L F
.62756 .34264 m .64957 .33185 L .6283 .33514 L F
.64317 .36192 m .67029 .36274 L .67791 .33073 L 1 .487 .587 r
F
.63674 .39172 m .67029 .36274 L .64317 .36192 L 1 .464 .586 r
F
.63674 .39172 m .66263 .39504 L .67029 .36274 L F
.61303 .35 m .62479 .36083 L .61807 .32545 L .786 .088 .593 r
F
.62479 .36083 m .62483 .36055 L .61807 .32545 L F
.6249 .36093 m .62756 .34264 L .61807 .32545 L F
.61807 .32545 m .62756 .34264 L .6283 .33514 L .797 .089 .591 r
F
.61846 .3471 m .62827 .33518 L .62345 .3193 L 1 .542 .593 r
F
.62827 .33518 m .6283 .33514 L .62829 .33507 L F
.62827 .33518 m .62829 .33507 L .62345 .3193 L F
.62479 .36083 m .6249 .36093 L .62483 .36055 L .786 .088 .593 r
F
.6249 .36093 m .64957 .33185 L .62756 .34264 L 1 .532 .595 r
F
.6249 .36093 m .64317 .36192 L .64957 .33185 L F
.61303 .35 m .62376 .36932 L .6249 .36093 L .786 .088 .593 r
F
.62376 .36932 m .62411 .36995 L .6249 .36093 L F
.62572 .35494 m .6249 .36093 L .62756 .34264 L 1 .532 .595 r
F
.62481 .36105 m .6249 .36093 L .62572 .35494 L F
.60796 .37355 m .62185 .38602 L .61303 .35 L .772 .087 .597 r
F
.63027 .42116 m .66263 .39504 L .63674 .39172 L 1 .43 .585 r
F
.63027 .42116 m .65493 .42786 L .66263 .39504 L F
.62387 .44959 m .65493 .42787 L .63027 .42116 L 1 .383 .581 r
F
.62106 .39697 m .63674 .39172 L .62185 .38602 L 1 .517 .597 r
F
.59276 .43553 m .61492 .4543 L .59783 .41654 L .689 .079 .62 r
F
.61755 .4764 m .64732 .46094 L .62387 .44959 L 1 .326 .578 r
F
.61758 .4769 m .64732 .46094 L .61755 .4764 L F
.61755 .47693 m .63967 .49448 L .61755 .47692 L F
.61757 .47711 m .63967 .49448 L .61754 .47692 L F
.63194 .52605 m .65962 .52038 L .63967 .49448 L 1 .165 .513 r
F
.64644 .55996 m .65423 .57148 L .66626 .57464 L .375 .103 .835 r
F
.63514 .56051 m .65423 .57148 L .64644 .55996 L .355 .1 .862 r
F
.62589 .55289 m .63514 .56051 L .64644 .55996 L .486 .289 .881 r
F
.64644 .55996 m .66626 .57464 L .65773 .5572 L .375 .103 .835 r
F
.6364 .55298 m .64644 .55996 L .65773 .5572 L .639 .533 .881 r
F
.62589 .55289 m .64644 .55996 L .6364 .55298 L .486 .289 .881 r
F
.65319 .55139 m .65773 .5572 L .66893 .55034 L .997 .897 .838 r
F
.64693 .55181 m .65099 .55384 L .65319 .55139 L F
.65099 .55384 m .65773 .5572 L .65319 .55139 L F
.66512 .53543 m .68822 .5249 L .67514 .51256 L 1 .9 .688 r
F
.67038 .53224 m .66512 .53543 L .67514 .51256 L .07 0 .237 r
F
.65773 .5572 m .66626 .57464 L .67831 .5768 L .526 .187 .777 r
F
.65773 .5572 m .67831 .5768 L .66893 .55034 L F
.66512 .53543 m .67729 .54152 L .68822 .5249 L 1 .9 .688 r
F
.66417 .5371 m .66425 .53713 L .66512 .53544 L 1 .968 .727 r
F
.66425 .53713 m .67728 .54153 L .66512 .53544 L F
.66425 .53713 m .66512 .53544 L .66512 .53544 L F
.66425 .53713 m .67625 .5428 L .67728 .54153 L F
.66417 .5371 m .66425 .53714 L .66425 .53713 L F
.66425 .53714 m .67625 .5428 L .66425 .53713 L F
.65739 .54604 m .65902 .54576 L .66417 .53711 L 1 .993 .765 r
F
.65902 .54576 m .67625 .5428 L .66425 .53715 L F
.66509 .53584 m .66417 .5371 L .66512 .53544 L .372 0 .398 r
F
.65902 .54576 m .66425 .53715 L .66417 .53711 L 1 .993 .765 r
F
.65199 .68309 m .65205 .69007 L .66481 .69623 L .278 .035 .838 r
F
.65199 .68309 m .66481 .69623 L .66487 .6914 L F
.65773 .54598 m .66894 .55034 L .67625 .5428 L 1 .993 .765 r
F
.65739 .54604 m .65762 .54612 L .65773 .54598 L F
.65762 .54612 m .66894 .55034 L .65773 .54598 L F
.66499 .53715 m .66417 .5371 L .66509 .53584 L .372 0 .398 r
F
.64693 .55181 m .65149 .5515 L .65739 .54604 L .997 .897 .838 r
F
.65149 .5515 m .66893 .55034 L .65739 .54604 L F
.65149 .5515 m .65739 .54604 L .65739 .54604 L F
.66138 .54234 m .65739 .54604 L .66417 .53711 L 0 0 0 r
F
.6364 .55298 m .6448 .55464 L .64693 .55181 L .639 .533 .881 r
F
.6448 .55464 m .65773 .5572 L .64693 .55181 L F
.64891 .54918 m .64693 .55181 L .65739 .54604 L .564 .014 .78 r
F
.6242 .54746 m .6364 .55298 L .64693 .55181 L .421 .152 .896 r
F
.61465 .54477 m .62589 .55289 L .6364 .55298 L .391 .144 .875 r
F
.61465 .54477 m .6364 .55298 L .6242 .54746 L F
.6242 .54746 m .64693 .55181 L .6339 .55474 L .421 .152 .896 r
F
.6339 .55474 m .64693 .55181 L .64891 .54918 L .564 .014 .78 r
F
.64396 .57505 m .65739 .54604 L .66138 .54234 L 0 0 0 r
F
.65739 .54604 m .65739 .54604 L .66138 .54234 L F
.6492 .66965 m .65199 .68309 L .66487 .6914 L .354 .038 .764 r
F
.6492 .66965 m .66487 .6914 L .66182 .67494 L F
.64407 .65313 m .6492 .66965 L .66182 .67494 L .479 .108 .748 r
F
.64407 .65313 m .66182 .67494 L .65615 .65286 L F
.63671 .63757 m .64407 .65313 L .65615 .65286 L .694 .307 .76 r
F
.64814 .63585 m .65615 .65286 L .66819 .64974 L .892 .437 .745 r
F
.63671 .63757 m .65615 .65286 L .64814 .63585 L .694 .307 .76 r
F
.64814 .63585 m .66819 .64974 L .65956 .63274 L .892 .437 .745 r
F
.63783 .62197 m .64814 .63585 L .65956 .63274 L .786 .454 .784 r
F
.63783 .62197 m .65956 .63274 L .64854 .62364 L F
.62522 .60248 m .63783 .62197 L .64854 .62364 L .422 .07 .752 r
F
.62522 .60248 m .64854 .62364 L .63486 .6025 L F
.64855 .61692 m .64854 .62364 L .65938 .62833 L .265 .005 .747 r
F
.63486 .6025 m .64361 .61601 L .64855 .61692 L F
.64361 .61601 m .64854 .62364 L .64855 .61692 L F
.65874 .61881 m .66409 .53825 L .66499 .53715 L .372 0 .398 r
F
.64396 .57505 m .66417 .53711 L .66416 .53712 L 0 0 0 r
F
.63486 .6025 m .65613 .62491 L .64478 .61288 L .265 .005 .747 r
F
.65613 .62491 m .65938 .62833 L .6448 .61291 L F
.65613 .62491 m .6448 .61291 L .64478 .61288 L F
.61543 .55278 m .63514 .56051 L .62589 .55289 L .447 .224 .874 r
F
.60911 .5319 m .6242 .54746 L .63389 .55474 L 0 0 .627 r
F
.60911 .5319 m .63389 .55474 L .61745 .53427 L F
.61745 .53427 m .63389 .55474 L .64042 .56793 L .835 0 0 r
F
.63726 .56476 m .64042 .56793 L .64395 .57505 L F
.61745 .53427 m .64042 .56793 L .63726 .56476 L F
.60519 .54437 m .61543 .55278 L .62589 .55289 L .415 .169 .862 r
F
.60519 .54437 m .62589 .55289 L .61465 .54477 L F
.6339 .55474 m .65487 .54697 L .64395 .57505 L .564 .014 .78 r
F
.65487 .54697 m .65739 .54604 L .64397 .575 L F
.65487 .54697 m .64397 .575 L .64395 .57505 L F
.61745 .53427 m .64395 .57505 L .62586 .53823 L .835 0 0 r
F
.62546 .54659 m .627 .54897 L .626 .54537 L .047 0 .605 r
F
.61796 .56359 m .627 .54897 L .62546 .54659 L F
.6251 .57671 m .64478 .61287 L .62761 .55117 L F
.63934 .58693 m .64395 .57506 L .64656 .61031 L 1 .172 .407 r
F
.62674 .57972 m .63486 .6025 L .64478 .61287 L .047 0 .605 r
F
.62913 .55661 m .64478 .61288 L .64478 .61288 L 1 .134 .353 r
F
.62913 .55661 m .64478 .61288 L .62913 .55661 L F
.6392 .67732 m .63934 .68512 L .65205 .69007 L .409 .147 .844 r
F
.6392 .67732 m .65205 .69007 L .65199 .68309 L F
.63665 .66585 m .6392 .67732 L .65199 .68309 L .434 .121 .793 r
F
.63665 .66585 m .65199 .68309 L .6492 .66965 L F
.65615 .65286 m .66182 .67494 L .67455 .68278 L .442 .045 .704 r
F
.65615 .65286 m .67455 .68278 L .66819 .64974 L F
.65956 .63274 m .66819 .64974 L .68006 .64008 L 1 .668 .709 r
F
.62722 .6228 m .63671 .63757 L .64814 .63585 L .692 .321 .767 r
F
.62722 .6228 m .64814 .63585 L .63783 .62197 L F
.64478 .61289 m .65938 .62833 L .66316 .63001 L .094 0 .783 r
F
.65352 .62036 m .66316 .63001 L .66641 .63145 L F
.65352 .62036 m .66641 .63145 L .66615 .63116 L F
.64478 .61289 m .66316 .63001 L .65352 .62036 L F
.66615 .63116 m .66641 .63145 L .66656 .63152 L F
.64478 .61289 m .66656 .63152 L .65726 .68632 L F
.64478 .61289 m .65726 .68632 L .65057 .67738 L F
.65793 .62413 m .65802 .62421 L .65427 .67737 L 0 0 0 r
F
.65057 .67738 m .65726 .68632 L .65341 .70899 L .094 0 .783 r
F
.65425 .67735 m .65427 .67737 L .65308 .69435 L 0 0 0 r
F
.65793 .62413 m .65427 .67737 L .65425 .67735 L F
.65298 .69314 m .65793 .62413 L .65308 .69435 L F
.65793 .62413 m .66416 .53712 L .65802 .62421 L F
.64396 .57505 m .66416 .53712 L .65298 .69314 L F
.65429 .67692 m .65835 .61874 L .65874 .61881 L .372 0 .398 r
F
.65305 .69309 m .65419 .67711 L .65429 .67692 L F
.65419 .67711 m .65835 .61874 L .65429 .67692 L F
.66182 .67494 m .66487 .6914 L .6779 .70363 L .257 .001 .714 r
F
.66182 .67494 m .6779 .70363 L .67455 .68279 L F
.66001 .67816 m .66657 .63152 L .66758 .63182 L .526 0 .387 r
F
.65981 .67828 m .66657 .63152 L .66001 .67816 L F
.65797 .68844 m .65934 .67936 L .65839 .68806 L F
.65934 .67936 m .66657 .63152 L .65968 .67915 L F
.65934 .67936 m .65968 .67915 L .65839 .68806 L F
.68006 .64007 m .69767 .75854 L .68773 .62845 L 0 0 .212 r
F
.66819 .64974 m .68753 .69745 L .68006 .64008 L .359 .001 .636 r
F
.66819 .64974 m .67455 .68278 L .68753 .69745 L F
.68204 .6652 m .68022 .69847 L .69072 .6818 L .852 .089 .571 r
F
.65839 .68806 m .65981 .67828 L .66001 .67816 L .526 0 .387 r
F
.65361 .71738 m .65797 .68844 L .65839 .68806 L F
.65631 .67309 m .65665 .67965 L .659 .68152 L 1 .18 .585 r
F
.65839 .68806 m .65987 .67904 L .65848 .68713 L .526 0 .387 r
F
.65987 .67904 m .66008 .67684 L .65863 .68556 L F
.65848 .68713 m .65863 .68556 L .65862 .68557 L F
.65848 .68713 m .65862 .68557 L .6572 .69461 L F
.65987 .67904 m .65863 .68556 L .65848 .68713 L F
.65305 .69309 m .65408 .67958 L .65276 .66939 L .372 0 .398 r
F
.65408 .67958 m .65844 .62264 L .65276 .66939 L F
.65361 .71734 m .65862 .68557 L .65862 .68557 L 1 .794 .651 r
F
.65359 .71059 m .65862 .68557 L .65344 .67007 L F
.65361 .71734 m .65508 .70806 L .6536 .71379 L F
.62632 .78112 m .64136 .7814 L .6389 .77651 L .873 .763 .854 r
F
.62219 .77722 m .62632 .78112 L .6389 .77651 L .733 .584 .874 r
F
.63438 .77334 m .6389 .77651 L .65148 .77156 L .669 .373 .865 r
F
.62219 .77722 m .6389 .77651 L .63438 .77334 L .733 .584 .874 r
F
.63438 .77334 m .65148 .77156 L .6466 .76992 L .669 .373 .865 r
F
.62775 .77026 m .63438 .77334 L .6466 .76992 L .573 .286 .888 r
F
.6466 .76992 m .65148 .77156 L .66406 .76656 L .564 .056 .822 r
F
.6466 .76992 m .65281 .76872 L .65887 .76797 L F
.65281 .76872 m .66406 .76656 L .65887 .76797 L F
.66671 .76553 m .66679 .77577 L .67929 .76514 L 1 .78 .746 r
F
.65408 .77466 m .66679 .77577 L .66671 .76553 L 1 .885 .789 r
F
.65148 .77156 m .66671 .76553 L .66406 .76656 L .762 .181 .757 r
F
.65148 .77156 m .65408 .77466 L .66671 .76553 L F
.66671 .76553 m .67012 .76543 L .67921 .75241 L 1 .78 .746 r
F
.67012 .76543 m .67929 .76514 L .67921 .75241 L F
.68775 .74018 m .67921 .75241 L .69148 .7328 L 0 0 0 r
F
.67665 .76213 m .67921 .75241 L .68775 .74018 L F
.66406 .76656 m .66671 .76553 L .67921 .75241 L .628 0 .525 r
F
.66406 .76656 m .67921 .75241 L .67665 .76213 L F
.65887 .76797 m .66406 .76656 L .67665 .76213 L .27 0 .633 r
F
.65887 .76797 m .66381 .76635 L .67125 .76945 L F
.66381 .76635 m .67665 .76213 L .67125 .76945 L F
.67929 .76514 m .67662 .7894 L .6889 .78293 L 1 .806 .701 r
F
.66679 .77577 m .67662 .7894 L .67929 .76514 L 1 .882 .734 r
F
.67125 .76945 m .68932 .76001 L .68384 .77709 L .268 0 0 r
F
.6783 .77239 m .67125 .76945 L .68384 .77709 L 0 0 .74 r
F
.67125 .76945 m .67665 .76213 L .68932 .76001 L .268 0 0 r
F
.66262 .7591 m .67125 .76945 L .6783 .77239 L 0 0 .74 r
F
.66456 .76726 m .65887 .76797 L .67125 .76945 L .225 .004 .857 r
F
.65097 .76282 m .65887 .76797 L .66456 .76726 L F
.63935 .76655 m .6466 .76992 L .65887 .76797 L .458 .11 .886 r
F
.62775 .77026 m .6466 .76992 L .63935 .76655 L .573 .286 .888 r
F
.63935 .76655 m .65887 .76797 L .65097 .76282 L .458 .11 .886 r
F
.62989 .76384 m .63935 .76655 L .65097 .76282 L .57 .277 .887 r
F
.64065 .75839 m .65097 .76282 L .66262 .7591 L .622 .463 .892 r
F
.62989 .76384 m .65097 .76282 L .64065 .75839 L .57 .277 .887 r
F
.64065 .75839 m .65114 .75873 L .65137 .74948 L .622 .463 .892 r
F
.65114 .75873 m .66262 .7591 L .65388 .75163 L F
.65114 .75873 m .65388 .75163 L .65137 .74948 L F
.66081 .73372 m .66195 .73441 L .66884 .72104 L .838 .001 .476 r
F
.6427 .75418 m .64116 .75797 L .65137 .74948 L .758 .229 .778 r
F
.64073 .75525 m .64065 .75839 L .64116 .75797 L F
.64073 .75525 m .64116 .75797 L .6427 .75418 L F
.62056 .76364 m .62989 .76384 L .64065 .75839 L .614 .186 .85 r
F
.61839 .76421 m .61924 .76418 L .62056 .76364 L F
.61924 .76418 m .62989 .76384 L .62056 .76364 L F
.61839 .76421 m .64065 .75839 L .6282 .76204 L F
.63317 .75935 m .63924 .75881 L .63946 .75594 L .758 .229 .778 r
F
.63946 .75594 m .63924 .75881 L .64073 .75525 L F
.6282 .76204 m .63039 .7614 L .63317 .75935 L F
.63039 .7614 m .63924 .75881 L .63317 .75935 L F
.6282 .76204 m .63946 .75594 L .63804 .75928 L F
.63924 .75881 m .64065 .75839 L .64073 .75525 L F
.63946 .75594 m .65137 .74948 L .64648 .75308 L F
.64073 .75542 m .64648 .75308 L .64071 .75731 L F
.64073 .75542 m .64071 .75731 L .63804 .75928 L F
.64119 .756 m .65137 .74948 L .66195 .73441 L .896 .174 .644 r
F
.63804 .75928 m .64071 .75731 L .64119 .756 L F
.64071 .75731 m .65137 .74948 L .64119 .756 L F
.64092 .75778 m .64972 .74714 L .64787 .75415 L F
.63804 .75928 m .64119 .756 L .64092 .75778 L F
.64119 .756 m .64972 .74714 L .64092 .75778 L F
.65508 .70806 m .65862 .68557 L .6536 .71379 L 1 .794 .651 r
F
.65361 .71738 m .65591 .7033 L .65438 .71108 L .526 0 .387 r
F
.65438 .71108 m .65839 .68806 L .65439 .71099 L F
.65591 .7033 m .65839 .68806 L .65438 .71108 L F
.65839 .68806 m .65848 .68713 L .65439 .71099 L F
.65361 .71764 m .66981 .71903 L .65862 .68557 L 1 .794 .651 r
F
.65361 .71764 m .65862 .68557 L .65361 .71734 L F
.65436 .71117 m .65424 .71615 L .65439 .71106 L 1 .281 .456 r
F
.65489 .71779 m .66884 .72104 L .66957 .71954 L 1 .794 .651 r
F
.65361 .71764 m .65485 .71792 L .65489 .71779 L F
.65485 .71792 m .66884 .72104 L .65489 .71779 L F
.65361 .71764 m .66957 .71954 L .66569 .71868 L F
.64972 .74714 m .66195 .73441 L .65639 .74221 L .896 .174 .644 r
F
.63828 .77247 m .64787 .75416 L .64787 .75415 L .803 0 .386 r
F
.63828 .77247 m .64787 .75416 L .63828 .77247 L F
.63736 .77423 m .64787 .75416 L .63736 .77423 L F
.62632 .78112 m .6286 .7866 L .64136 .7814 L .873 .763 .854 r
F
.63275 .78304 m .63736 .77423 L .63275 .78303 L .803 0 .386 r
F
.63736 .77423 m .64787 .75416 L .63736 .77423 L F
.63736 .77423 m .63736 .77423 L .63275 .78303 L F
.6286 .7866 m .64151 .78993 L .64136 .7814 L 1 .907 .835 r
F
.6286 .7866 m .62877 .79434 L .64151 .78993 L F
.61618 .77396 m .62219 .77722 L .63438 .77334 L .639 .45 .887 r
F
.61618 .77396 m .63438 .77334 L .62775 .77026 L F
.60838 .77125 m .61618 .77396 L .62775 .77026 L .594 .372 .892 r
F
.61912 .76778 m .62775 .77026 L .63935 .76655 L .571 .282 .888 r
F
.60838 .77125 m .62775 .77026 L .61912 .76778 L .594 .372 .892 r
F
.61912 .76778 m .63935 .76655 L .62989 .76384 L .571 .282 .888 r
F
.62165 .77364 m .64787 .75416 L .63058 .78716 L 0 0 0 r
F
.63819 .7718 m .64787 .75415 L .6421 .7639 L .803 0 .386 r
F
.63058 .78716 m .63736 .77423 L .63819 .7718 L F
.63736 .77423 m .64787 .75415 L .63819 .7718 L F
.62165 .77364 m .63804 .75928 L .64092 .75778 L 0 0 0 r
F
.64095 .7593 m .64092 .75778 L .64787 .75416 L F
.62165 .77364 m .64092 .75778 L .64095 .7593 L F
.63736 .77423 m .63828 .77247 L .63828 .77247 L .803 0 .386 r
F
.63275 .78303 m .63736 .77423 L .63736 .77423 L F
.63058 .78716 m .63275 .78304 L .63275 .78303 L F
.64972 .74714 m .65381 .74411 L .64787 .75415 L .896 .174 .644 r
F
.64787 .75415 m .64789 .75412 L .65382 .72684 L .838 .001 .476 r
F
.65381 .74411 m .65594 .74254 L .6479 .75411 L .896 .174 .644 r
F
.65381 .74411 m .6479 .75411 L .64787 .75415 L F
.64789 .75412 m .66884 .72104 L .663 .7233 L .838 .001 .476 r
F
.64789 .75412 m .663 .7233 L .65382 .72684 L F
.6421 .7639 m .64787 .75415 L .65362 .74078 L .803 0 .386 r
F
.6421 .7639 m .65362 .74078 L .6525 .74291 L F
.65594 .74254 m .65511 .744 L .64787 .75415 L .896 .174 .644 r
F
.64787 .75415 m .65511 .744 L .65398 .7445 L .838 .001 .476 r
F
.64643 .75926 m .65175 .74549 L .64559 .76075 L 1 .269 .494 r
F
.65175 .74549 m .65362 .74064 L .65167 .74553 L F
.65175 .74549 m .65167 .74553 L .64559 .76075 L F
.65398 .7445 m .65887 .73873 L .66081 .73372 L .838 .001 .476 r
F
.65594 .74254 m .65639 .74221 L .65511 .744 L .896 .174 .644 r
F
.65511 .744 m .65887 .73873 L .65398 .7445 L .838 .001 .476 r
F
.6525 .74291 m .65362 .74078 L .65382 .74033 L .803 0 .386 r
F
.6525 .74291 m .65382 .74033 L .65362 .74064 L F
.6389 .77651 m .65408 .77466 L .65148 .77156 L .845 .602 .833 r
F
.6389 .77651 m .64136 .7814 L .65408 .77466 L F
.63058 .78716 m .65362 .74064 L .63295 .79238 L .803 0 .386 r
F
.62877 .79434 m .63938 .80218 L .64151 .78993 L 1 .876 .813 r
F
.62877 .79434 m .62687 .80434 L .63938 .80218 L F
.63295 .79238 m .64643 .75926 L .63622 .78113 L 1 .269 .494 r
F
.6158 .79071 m .62877 .79434 L .6286 .7866 L .941 .854 .846 r
F
.61373 .78527 m .6286 .7866 L .62632 .78112 L .86 .787 .861 r
F
.61373 .78527 m .6158 .79071 L .6286 .7866 L F
.61001 .78112 m .61373 .78527 L .62632 .78112 L .764 .674 .875 r
F
.61001 .78112 m .62632 .78112 L .62219 .77722 L F
.60463 .77766 m .61001 .78112 L .62219 .77722 L .684 .564 .886 r
F
.60463 .77766 m .62219 .77722 L .61618 .77396 L F
.59767 .77468 m .60463 .77766 L .61618 .77396 L .627 .476 .892 r
F
.59767 .77468 m .61618 .77396 L .60838 .77125 L F
.61599 .79757 m .62687 .80434 L .62877 .79434 L .972 .83 .83 r
F
.61599 .79757 m .61432 .80576 L .62687 .80434 L F
.6158 .79071 m .61599 .79757 L .62877 .79434 L .941 .854 .846 r
F
.63082 .7997 m .63254 .79526 L .63215 .79515 L 1 .269 .494 r
F
.64706 .81742 m .63987 .83587 L .65131 .84183 L .98 .419 .714 r
F
.635 .81657 m .63987 .83587 L .64706 .81742 L .95 .488 .745 r
F
.63938 .80218 m .635 .81657 L .64706 .81742 L 1 .689 .763 r
F
.62687 .80434 m .635 .81657 L .63938 .80218 L 1 .72 .791 r
F
.64706 .81742 m .65131 .84183 L .6591 .81812 L .98 .419 .714 r
F
.65185 .79906 m .64706 .81742 L .6591 .81812 L 1 .642 .734 r
F
.63938 .80218 m .64706 .81742 L .65185 .79906 L 1 .689 .763 r
F
.64151 .78993 m .65185 .79906 L .65419 .7839 L 1 .91 .792 r
F
.64151 .78993 m .63938 .80218 L .65185 .79906 L F
.64136 .7814 m .65419 .7839 L .65408 .77466 L 1 .93 .818 r
F
.64136 .7814 m .64151 .78993 L .65419 .7839 L F
.65097 .76282 m .67125 .76945 L .66262 .7591 L .225 .004 .857 r
F
.65137 .74948 m .66262 .7591 L .6743 .75536 L .772 .644 .849 r
F
.65137 .74948 m .6743 .75536 L .66195 .73441 L F
.63082 .7997 m .64929 .81935 L .65409 .73971 L 1 .269 .494 r
F
.65362 .74064 m .65409 .73971 L .65411 .73939 L F
.65362 .74064 m .65382 .74033 L .65409 .73971 L .803 0 .386 r
F
.63082 .7997 m .65409 .73971 L .65362 .74064 L 1 .269 .494 r
F
.65362 .74064 m .65409 .73971 L .65411 .73965 L .803 0 .386 r
F
.61551 .78053 m .62489 .78992 L .62343 .79195 L 1 0 .135 r
F
.62489 .78992 m .62666 .79168 L .62343 .79195 L F
.62384 .7876 m .62562 .78938 L .62379 .78803 L .991 0 .151 r
F
.62562 .78938 m .62746 .79123 L .62543 .78946 L F
.62562 .78938 m .62543 .78946 L .62379 .78803 L F
.62746 .79123 m .6271 .79114 L .62379 .78803 L F
.61081 .81468 m .61698 .82673 L .62292 .81563 L .882 .623 .804 r
F
.61081 .81468 m .60554 .8234 L .61698 .82673 L F
.61432 .80576 m .62292 .81563 L .62687 .80434 L .945 .732 .814 r
F
.61432 .80576 m .61081 .81468 L .62292 .81563 L F
.62666 .79168 m .62666 .79168 L .62343 .79195 L 1 .558 .582 r
F
.61482 .77963 m .62681 .79174 L .61551 .78053 L .995 0 .132 r
F
.62796 .79194 m .62753 .79176 L .62725 .79148 L .991 0 .151 r
F
.62762 .79163 m .62725 .79148 L .61482 .77962 L F
.62796 .79194 m .62725 .79148 L .62762 .79163 L F
.62487 .79427 m .62727 .79208 L .62681 .79174 L 1 .614 .581 r
F
.61526 .80675 m .62513 .79469 L .62487 .79427 L F
.62513 .79469 m .62727 .79208 L .62487 .79427 L F
.61526 .80675 m .62487 .79427 L .61592 .80536 L F
.62487 .79427 m .62681 .79174 L .62484 .79422 L F
.62487 .79427 m .62484 .79422 L .61592 .80536 L F
.62681 .79174 m .62666 .79168 L .62477 .79409 L F
.62484 .79422 m .62477 .79409 L .61592 .80536 L F
.62681 .79174 m .62477 .79409 L .62484 .79422 L F
.61062 .81673 m .62572 .79574 L .61526 .80675 L 1 .694 .601 r
F
.62572 .79574 m .6281 .79244 L .62549 .79534 L F
.62572 .79574 m .62549 .79534 L .61526 .80675 L F
.6281 .79244 m .62805 .79242 L .62064 .80073 L F
.62064 .80076 m .62064 .80073 L .61526 .80675 L F
.6281 .79244 m .62064 .80073 L .62064 .80076 L F
.61482 .77963 m .61722 .78191 L .61751 .78235 L .995 0 .132 r
F
.62727 .79208 m .62753 .79176 L .62681 .79174 L 1 .614 .581 r
F
.61722 .78191 m .62753 .79176 L .61751 .78235 L .995 0 .132 r
F
.62753 .79176 m .62745 .79175 L .61751 .78235 L F
.6281 .79244 m .62833 .79211 L .62805 .79242 L 1 .694 .601 r
F
.62833 .79211 m .62753 .79176 L .62517 .79465 L F
.62552 .79526 m .62517 .79465 L .61526 .80675 L F
.62833 .79211 m .62517 .79465 L .62552 .79526 L F
.61592 .80536 m .62666 .79168 L .62343 .79195 L 1 .558 .582 r
F
.61062 .81673 m .63082 .7997 L .63215 .79515 L 1 .694 .601 r
F
.60995 .77365 m .63058 .78716 L .63295 .79238 L .991 0 .151 r
F
.63099 .79423 m .63295 .79238 L .63268 .79236 L 1 .694 .601 r
F
.61062 .81673 m .63215 .79515 L .63099 .79423 L F
.60995 .77365 m .63295 .79238 L .62833 .79211 L .991 0 .151 r
F
.61062 .81673 m .63309 .79191 L .6292 .7909 L 1 .694 .601 r
F
.62833 .79211 m .63295 .79238 L .63108 .79486 L .991 0 .151 r
F
.63099 .79423 m .63215 .79515 L .63295 .79238 L 1 .694 .601 r
F
.63268 .79236 m .63295 .79238 L .63309 .79191 L F
.62486 .78977 m .63661 .80042 L .63747 .8025 L .995 0 .132 r
F
.62554 .78994 m .63661 .80042 L .62486 .78977 L F
.62753 .79176 m .62753 .79175 L .62681 .79174 L 1 .614 .581 r
F
.62713 .79114 m .62865 .79257 L .6271 .79114 L .991 0 .151 r
F
.62865 .79257 m .6286 .79254 L .6271 .79114 L F
.62746 .79123 m .62833 .79211 L .62713 .79114 L F
.62833 .79211 m .62921 .79299 L .62713 .79114 L F
.62921 .79299 m .63108 .79486 L .62865 .79257 L F
.62921 .79299 m .62865 .79257 L .62713 .79114 L F
.63671 .77926 m .65171 .72866 L .65436 .71117 L 1 .281 .456 r
F
.5989 .76896 m .60838 .77125 L .61912 .76778 L .552 .293 .895 r
F
.5989 .76896 m .61912 .76778 L .60862 .76642 L F
.58734 .76628 m .5989 .76896 L .60862 .76642 L .464 .167 .896 r
F
.60265 .76644 m .62165 .77364 L .63058 .78716 L .822 0 .067 r
F
.62559 .78346 m .62838 .78553 L .62554 .7837 L F
.62838 .78553 m .62824 .78562 L .62552 .78384 L F
.62554 .7837 m .62552 .78384 L .60995 .77365 L F
.62838 .78553 m .62552 .78384 L .62554 .7837 L F
.61751 .78235 m .62554 .78994 L .62486 .78977 L .995 0 .132 r
F
.6268 .79173 m .6268 .79173 L .61551 .78053 L F
.62681 .79174 m .62681 .79174 L .61551 .78053 L F
.62707 .79199 m .6269 .79192 L .61551 .78053 L F
.63664 .77953 m .65171 .72866 L .63671 .77926 L 1 .281 .456 r
F
.63671 .77945 m .65171 .72866 L .63664 .77953 L F
.63633 .78079 m .65171 .72866 L .63631 .7808 L F
.64123 .76417 m .64962 .74248 L .65171 .72866 L F
.64653 .74145 m .64658 .74132 L .64104 .76282 L F
.64653 .74145 m .64104 .76282 L .64104 .76281 L F
.64653 .74145 m .64033 .76557 L .6403 .76566 L F
.64018 .76602 m .64653 .74145 L .6403 .76566 L F
.64229 .76106 m .64928 .73801 L .64553 .75184 L 0 0 .109 r
F
.64229 .76106 m .64553 .75184 L .64522 .75299 L F
.64229 .76106 m .65436 .71118 L .6487 .73994 L F
.64033 .76557 m .65436 .71118 L .64229 .76106 L F
.64962 .74248 m .6539 .73015 L .65436 .71117 L 1 .281 .456 r
F
.64254 .75676 m .64657 .74124 L .64065 .76418 L F
.64657 .74124 m .64663 .74106 L .64065 .76418 L F
.64254 .75676 m .64065 .76418 L .64065 .7641 L F
.64928 .73801 m .65062 .73473 L .64894 .74038 L 0 0 .109 r
F
.64767 .74394 m .64812 .74317 L .64522 .75299 L F
.64522 .75299 m .65019 .73918 L .65354 .73287 L 0 0 .139 r
F
.65424 .71615 m .65408 .7226 L .65426 .71615 L 1 .281 .456 r
F
.65408 .7226 m .6539 .73015 L .65409 .72257 L F
.65408 .7226 m .65409 .72257 L .65426 .71615 L F
.66493 .68223 m .66255 .68436 L .68022 .69847 L 1 .18 .585 r
F
.66487 .6914 m .66481 .69623 L .67763 .70358 L .045 0 .788 r
F
.66487 .6914 m .67763 .70358 L .6779 .70363 L F
.66179 .68455 m .66019 .69023 L .67341 .69567 L 1 .18 .585 r
F
.66347 .68069 m .65864 .6855 L .66242 .67505 L .472 0 .369 r
F
.66617 .67171 m .66273 .67421 L .66369 .67153 L F
.66681 .66956 m .66369 .67153 L .67838 .631 L F
.66617 .67171 m .66369 .67153 L .66681 .66956 L F
.69359 .65263 m .69072 .6818 L .70131 .66849 L .796 .075 .576 r
F
.66598 .67234 m .66242 .67505 L .66273 .67421 L .472 0 .369 r
F
.66598 .67234 m .66273 .67421 L .66617 .67171 L F
.66347 .68069 m .66242 .67505 L .66598 .67234 L F
.65987 .67904 m .66001 .67816 L .66008 .67684 L .526 0 .387 r
F
.66001 .67816 m .66758 .63182 L .66021 .67603 L F
.66001 .67816 m .66021 .67603 L .66008 .67684 L F
.6606 .67575 m .66758 .63182 L .66946 .63168 L .472 0 .369 r
F
.65864 .6855 m .66021 .67603 L .6606 .67575 L F
.66021 .67603 m .66758 .63182 L .6606 .67575 L F
.66681 .66956 m .67838 .631 L .67119 .66017 L F
.68204 .6652 m .68587 .66295 L .68467 .65827 L .852 .089 .571 r
F
.66273 .67421 m .66946 .63168 L .67838 .631 L .472 0 .369 r
F
.68919 .64359 m .68467 .65827 L .69359 .65263 L .796 .075 .576 r
F
.67736 .65404 m .67838 .631 L .68901 .62305 L .324 0 .283 r
F
.67711 .65472 m .67714 .65424 L .67736 .65404 L F
.67714 .65424 m .67838 .631 L .67736 .65404 L F
.67838 .631 m .70181 .59363 L .68901 .62305 L 0 0 0 r
F
.71905 .60279 m .7242 .65937 L .73601 .63602 L 1 .46 .577 r
F
.70761 .63385 m .7242 .65937 L .71905 .60279 L 1 .487 .572 r
F
.71745 .59969 m .72296 .64644 L .73383 .63641 L .736 .061 .582 r
F
.69761 .6254 m .69952 .61073 L .71011 .59593 L .001 0 .103 r
F
.69069 .60846 m .71154 .57832 L .70181 .59363 L 1 .186 .538 r
F
.70181 .59363 m .71154 .57832 L .72282 .55488 L .773 0 .382 r
F
.70181 .59363 m .72282 .55488 L .71285 .57685 L F
.71011 .59593 m .73507 .53968 L .72065 .57993 L 0 0 0 r
F
.71011 .59593 m .72399 .55862 L .73507 .53968 L F
.69952 .61073 m .72399 .55862 L .71011 .59593 L F
.69952 .61073 m .71286 .57685 L .72399 .55862 L F
.68901 .62305 m .71285 .57685 L .69952 .61073 L F
.71651 .59759 m .71229 .60637 L .71745 .59969 L .736 .061 .582 r
F
.71229 .60637 m .72296 .64644 L .71745 .59969 L F
.69751 .62565 m .69753 .62551 L .69761 .6254 L .001 0 .103 r
F
.69753 .62551 m .69952 .61073 L .69761 .6254 L F
.69743 .62584 m .69451 .62968 L .69751 .62565 L F
.69202 .63303 m .69952 .61073 L .69751 .62565 L F
.70761 .63385 m .71239 .68537 L .7242 .65937 L 1 .487 .572 r
F
.6983 .62768 m .70131 .66849 L .71211 .65696 L .764 .068 .579 r
F
.68758 .63996 m .68901 .62305 L .69952 .61073 L .145 0 .184 r
F
.69448 .62975 m .69202 .63303 L .69451 .62968 L .001 0 .103 r
F
.69743 .62584 m .69239 .63445 L .6983 .62768 L .764 .068 .579 r
F
.69202 .63303 m .69239 .63445 L .69743 .62584 L F
.69239 .63445 m .70131 .66849 L .6983 .62768 L F
.68751 .64013 m .68919 .64359 L .68848 .639 L .796 .075 .576 r
F
.68919 .64359 m .70131 .66849 L .69373 .63958 L F
.68752 .64003 m .68901 .62305 L .68758 .63996 L .145 0 .184 r
F
.68185 .64671 m .68901 .62305 L .68751 .64013 L F
.68919 .64359 m .69373 .63958 L .69223 .63384 L .796 .075 .576 r
F
.67087 .66146 m .67162 .66442 L .67096 .66137 L .852 .089 .571 r
F
.67162 .66442 m .67239 .66746 L .67169 .6643 L F
.67087 .66146 m .67093 .66124 L .67688 .65533 L .324 0 .283 r
F
.67093 .66124 m .67838 .631 L .67688 .65533 L F
.66254 .67434 m .66946 .63168 L .66273 .67421 L .472 0 .369 r
F
.66043 .67656 m .66946 .63168 L .66242 .67505 L F
.67162 .66442 m .67169 .6643 L .671 .66118 L .852 .089 .571 r
F
.66681 .66956 m .67119 .66017 L .67087 .66146 L .472 0 .369 r
F
.67094 .66131 m .671 .66118 L .6644 .63147 L .852 .089 .571 r
F
.67162 .66442 m .671 .66118 L .67094 .66131 L F
.66347 .68069 m .66385 .68109 L .67087 .66146 L 1 .18 .585 r
F
.66385 .68109 m .68022 .69847 L .67191 .66555 L F
.66385 .68109 m .67191 .66555 L .67087 .66146 L F
.68856 .63953 m .69223 .63384 L .69202 .63303 L .796 .075 .576 r
F
.68751 .64013 m .68758 .63996 L .69134 .6341 L .145 0 .184 r
F
.6877 .63966 m .69658 .61791 L .69139 .63394 L F
.68856 .63953 m .69202 .63303 L .68934 .63725 L .796 .075 .576 r
F
.68919 .64359 m .69223 .63384 L .68856 .63953 L F
.69658 .61791 m .69806 .61506 L .69206 .63291 L .145 0 .184 r
F
.67736 .65404 m .68901 .62305 L .68185 .64671 L .324 0 .283 r
F
.68751 .64013 m .68438 .64802 L .68919 .64359 L .796 .075 .576 r
F
.68177 .64698 m .68185 .64671 L .68751 .64013 L .145 0 .184 r
F
.68395 .63281 m .68427 .644 L .68751 .64013 L .796 .075 .576 r
F
.68427 .644 m .68438 .64802 L .68751 .64013 L F
.68124 .66076 m .68467 .65827 L .68249 .64977 L .852 .089 .571 r
F
.67974 .65249 m .68249 .64977 L .68177 .64698 L F
.67736 .65404 m .68185 .64671 L .68177 .64698 L .324 0 .283 r
F
.67736 .65404 m .68177 .64698 L .67723 .65473 L F
.67691 .65491 m .67838 .631 L .67711 .65472 L F
.67946 .65092 m .68177 .64698 L .67161 .60744 L .852 .089 .571 r
F
.67974 .65249 m .68177 .64698 L .67946 .65092 L F
.68124 .66076 m .68249 .64977 L .67974 .65249 L F
.66541 .62068 m .68014 .66156 L .67161 .60744 L F
.67688 .65533 m .67736 .65404 L .67723 .65472 L .324 0 .283 r
F
.6644 .63147 m .67688 .65533 L .66541 .62068 L .852 .089 .571 r
F
.67688 .65533 m .68014 .66156 L .67751 .65426 L F
.67688 .65533 m .67723 .65472 L .67723 .65473 L .324 0 .283 r
F
.67688 .65533 m .67691 .65491 L .67711 .65472 L F
.67688 .65533 m .67751 .65426 L .66541 .62068 L .852 .089 .571 r
F
.68014 .66156 m .67321 .67071 L .68204 .6652 L F
.6644 .63147 m .67247 .6674 L .68014 .66156 L F
.67247 .6674 m .67321 .67071 L .68014 .66156 L F
.67321 .67071 m .68022 .69847 L .68204 .6652 L F
.67688 .65533 m .67723 .65473 L .67338 .67471 L .324 0 .283 r
F
.68014 .66156 m .68124 .66076 L .67161 .60744 L .852 .089 .571 r
F
.67723 .65473 m .68177 .64698 L .67338 .67471 L .324 0 .283 r
F
.6802 .64086 m .68467 .65827 L .68395 .63281 L .796 .075 .576 r
F
.67338 .67471 m .68177 .64698 L .68751 .64013 L .145 0 .184 r
F
.68438 .64802 m .68467 .65827 L .68919 .64359 L .796 .075 .576 r
F
.68204 .6652 m .68467 .65827 L .68124 .66076 L .852 .089 .571 r
F
.69139 .63394 m .69206 .63291 L .68296 .65997 L .145 0 .184 r
F
.69658 .61791 m .69206 .63291 L .69139 .63394 L F
.68296 .65996 m .69743 .62584 L .69268 .64523 L .001 0 .103 r
F
.69743 .62584 m .69751 .62565 L .69748 .62576 L F
.69945 .62317 m .71211 .65696 L .7022 .61955 L .764 .068 .579 r
F
.69766 .6259 m .71211 .65696 L .69945 .62317 L F
.69743 .62585 m .71211 .65696 L .69755 .62567 L F
.69976 .62216 m .71011 .59593 L .70215 .61845 L .001 0 .103 r
F
.69751 .62565 m .69761 .6254 L .69976 .62216 L F
.69761 .6254 m .71011 .59593 L .69976 .62216 L F
.71186 .60435 m .72065 .57993 L .7167 .59715 L 0 0 .028 r
F
.71632 .59715 m .71182 .60459 L .71651 .59759 L .736 .061 .582 r
F
.71072 .60608 m .72065 .57993 L .71186 .60435 L 0 0 .053 r
F
.70709 .61159 m .70718 .61138 L .71072 .60608 L F
.70718 .61138 m .72065 .57993 L .71072 .60608 L F
.71905 .60279 m .73601 .63602 L .73057 .57642 L 1 .46 .577 r
F
.73114 .57567 m .73122 .57598 L .73536 .56923 L .728 .058 .582 r
F
.73122 .57598 m .74473 .62661 L .7354 .56952 L F
.73122 .57598 m .7354 .56952 L .73536 .56923 L F
.74079 .56114 m .74088 .56149 L .74481 .55493 L .726 .057 .581 r
F
.74088 .56149 m .75563 .61688 L .74487 .55529 L F
.74088 .56149 m .74487 .55529 L .74481 .55493 L F
.75045 .54653 m .76656 .60715 L .75429 .54054 L .726 .057 .58 r
F
.75425 .54061 m .75425 .54061 L .75429 .54054 L 0 0 .02 r
F
.75425 .54061 m .76253 .51154 L .75429 .54054 L F
.75429 .54054 m .76656 .60715 L .77749 .59736 L .726 .057 .58 r
F
.74492 .55521 m .76656 .60715 L .75045 .54653 L .726 .057 .581 r
F
.75039 .5467 m .75045 .54653 L .75421 .54075 L 0 0 .02 r
F
.75045 .54653 m .76253 .51154 L .75427 .54052 L F
.75045 .54653 m .75427 .54052 L .75421 .54075 L F
.73536 .56923 m .74473 .62661 L .75563 .61688 L .728 .058 .582 r
F
.726 .58359 m .73383 .63641 L .74473 .62661 L .731 .059 .582 r
F
.72595 .58367 m .73383 .63641 L .726 .58359 L F
.71656 .59748 m .73116 .56327 L .72149 .59014 L 0 0 .028 r
F
.72149 .59014 m .73383 .63641 L .72593 .58354 L .731 .059 .582 r
F
.74079 .56114 m .74479 .55491 L .74474 .5551 L 0 0 .016 r
F
.7448 .55492 m .74079 .56114 L .74481 .55493 L .726 .057 .581 r
F
.72605 .58316 m .73116 .56327 L .74164 .54624 L 0 0 .017 r
F
.73536 .56923 m .7521 .52897 L .74079 .56114 L 0 0 .014 r
F
.74079 .56114 m .74084 .561 L .74479 .55491 L 0 0 .016 r
F
.74084 .561 m .7521 .52897 L .7448 .55487 L F
.74084 .561 m .7448 .55487 L .74479 .55491 L F
.75421 .54032 m .75045 .54653 L .75429 .54054 L .726 .057 .58 r
F
.74481 .55493 m .76253 .51154 L .75045 .54653 L 0 0 .016 r
F
.74477 .55499 m .7521 .52897 L .74481 .55493 L F
.74481 .55493 m .7521 .52897 L .76253 .51154 L F
.73548 .56892 m .74164 .54624 L .7521 .52897 L 0 0 .014 r
F
.73536 .56923 m .73541 .56904 L .73548 .56892 L F
.73541 .56904 m .74164 .54624 L .73548 .56892 L F
.75419 .54028 m .75037 .54625 L .75421 .54032 L .726 .057 .58 r
F
.74164 .54624 m .76801 .48071 L .7521 .52897 L 0 0 0 r
F
.74164 .54624 m .75708 .50061 L .76801 .48071 L F
.73116 .56327 m .75708 .50061 L .74164 .54624 L F
.73116 .56327 m .7461 .52029 L .75708 .50061 L F
.72065 .57993 m .7461 .52029 L .73116 .56327 L F
.72065 .57993 m .73507 .53968 L .7461 .52029 L F
.7387 .50234 m .75035 .54616 L .75419 .54028 L .726 .057 .58 r
F
.75035 .54616 m .75037 .54625 L .75419 .54028 L F
.75037 .54625 m .75045 .54653 L .75421 .54032 L F
.73533 .56927 m .73536 .56917 L .73536 .56923 L 0 0 .014 r
F
.73536 .56917 m .74164 .54624 L .73538 .56913 L F
.73536 .56917 m .73538 .56913 L .73536 .56923 L F
.74475 .5548 m .74076 .56101 L .7448 .55492 L .726 .057 .581 r
F
.726 .58359 m .74473 .62661 L .73114 .57567 L .731 .059 .582 r
F
.73111 .57577 m .73114 .57567 L .73531 .56934 L 0 0 .014 r
F
.73114 .57567 m .74164 .54624 L .73535 .5692 L F
.73114 .57567 m .73535 .5692 L .73531 .56934 L F
.72149 .59014 m .72153 .59002 L .72593 .58344 L 0 0 .017 r
F
.72153 .59002 m .73116 .56327 L .72595 .58336 L F
.72153 .59002 m .72595 .58336 L .72593 .58344 L F
.73535 .56921 m .73114 .57567 L .73536 .56923 L .728 .058 .582 r
F
.72598 .58328 m .73116 .56327 L .72605 .58316 L 0 0 .017 r
F
.7167 .59715 m .72065 .57993 L .73116 .56327 L 0 0 .028 r
F
.71286 .57685 m .73424 .53199 L .72399 .55862 L 0 0 0 r
F
.71286 .57685 m .72282 .55487 L .73424 .53199 L F
.72149 .59014 m .72593 .58354 L .72592 .58347 L .731 .059 .582 r
F
.70705 .61169 m .72296 .64644 L .7118 .60453 L .745 .063 .581 r
F
.71182 .60459 m .71229 .60637 L .71651 .59759 L .736 .061 .582 r
F
.71657 .59745 m .71186 .60435 L .7167 .59715 L 0 0 .028 r
F
.70705 .61169 m .71211 .65696 L .72296 .64644 L .745 .063 .581 r
F
.70705 .61169 m .71011 .59593 L .72065 .57993 L 0 0 .053 r
F
.70703 .61172 m .70703 .61173 L .70705 .61169 L .745 .063 .581 r
F
.70703 .61173 m .71211 .65696 L .70705 .61169 L F
.70201 .61883 m .71011 .59593 L .70705 .61169 L 0 0 .053 r
F
.70205 .61897 m .71211 .65696 L .70701 .61162 L .745 .063 .581 r
F
.69743 .62584 m .7022 .61955 L .70201 .61883 L .764 .068 .579 r
F
.69268 .64523 m .70201 .61883 L .70705 .61169 L 0 0 .053 r
F
.70701 .61162 m .70703 .61172 L .70705 .61169 L .745 .063 .581 r
F
.70709 .61159 m .71186 .60435 L .71181 .60451 L 0 0 .053 r
F
.70708 .61165 m .71181 .60451 L .70241 .63062 L F
.70709 .61159 m .71181 .60451 L .70708 .61165 L F
.70241 .63062 m .71181 .60451 L .71657 .59745 L 0 0 .028 r
F
.71181 .60451 m .71186 .60435 L .71657 .59745 L F
.69751 .62565 m .70215 .61845 L .70201 .61883 L .001 0 .103 r
F
.69755 .62567 m .69766 .6259 L .69945 .62317 L .764 .068 .579 r
F
.6975 .6257 m .70201 .61883 L .69268 .64523 L .001 0 .103 r
F
.69751 .62565 m .70201 .61883 L .6975 .6257 L F
.70691 .61139 m .70205 .61897 L .70701 .61162 L .745 .063 .581 r
F
.69062 .57583 m .70201 .61883 L .70691 .61139 L F
.70201 .61883 m .70205 .61897 L .70691 .61139 L F
.70023 .56109 m .71651 .59759 L .70985 .54651 L .736 .061 .582 r
F
.71651 .59759 m .73383 .63641 L .72149 .59014 L F
.71651 .59759 m .71656 .59748 L .71977 .59271 L 0 0 .028 r
F
.71656 .59748 m .72149 .59014 L .72147 .59019 L F
.71651 .59759 m .72149 .59014 L .70985 .54651 L .736 .061 .582 r
F
.71651 .59759 m .71977 .59271 L .72147 .59019 L 0 0 .028 r
F
.71215 .61608 m .72593 .58344 L .72189 .60161 L 0 0 .017 r
F
.72593 .58344 m .74164 .54624 L .73114 .57567 L F
.72593 .58344 m .726 .58359 L .72597 .58339 L .731 .059 .582 r
F
.72593 .58344 m .72598 .58328 L .72605 .58316 L 0 0 .017 r
F
.726 .58359 m .73114 .57567 L .71947 .53191 L .731 .059 .582 r
F
.72593 .58344 m .72595 .58367 L .726 .58359 L F
.7259 .58337 m .72592 .58347 L .72593 .58344 L F
.72592 .58347 m .72595 .58367 L .72593 .58344 L F
.72593 .58344 m .73114 .57567 L .73111 .57577 L 0 0 .017 r
F
.72593 .58344 m .73111 .57577 L .72189 .60161 L F
.70985 .54651 m .72593 .58344 L .71947 .53191 L .731 .059 .582 r
F
.72593 .58344 m .72597 .58339 L .71947 .53191 L F
.71947 .53191 m .73112 .57558 L .73535 .56921 L .728 .058 .582 r
F
.73112 .57558 m .73114 .57567 L .73535 .56921 L F
.72909 .5172 m .74074 .56094 L .74475 .5548 L .726 .057 .581 r
F
.74074 .56094 m .74076 .56101 L .74475 .5548 L F
.74076 .56101 m .74079 .56114 L .7448 .55492 L F
.71215 .61608 m .72149 .59014 L .72593 .58344 L 0 0 .017 r
F
.72149 .59014 m .72592 .58347 L .7259 .58337 L .731 .059 .582 r
F
.72146 .59002 m .72149 .59014 L .7259 .58337 L F
.72189 .60161 m .73536 .56923 L .73164 .58717 L 0 0 .014 r
F
.73536 .56923 m .73545 .56945 L .73843 .56466 L .728 .058 .582 r
F
.73545 .56945 m .75563 .61688 L .74079 .56114 L F
.73545 .56945 m .74079 .56114 L .74074 .56094 L F
.73536 .56923 m .74079 .56114 L .73164 .58717 L 0 0 .014 r
F
.73536 .56923 m .73843 .56466 L .74074 .56094 L .728 .058 .582 r
F
.74074 .56127 m .74079 .56114 L .74474 .5551 L 0 0 .016 r
F
.73164 .58717 m .74481 .55493 L .74139 .57277 L F
.74481 .55493 m .74492 .55521 L .74784 .55041 L .726 .057 .581 r
F
.74492 .55521 m .75045 .54653 L .75037 .54625 L F
.74481 .55493 m .75563 .61688 L .76656 .60715 L F
.74481 .55493 m .75045 .54653 L .74139 .57277 L 0 0 .016 r
F
.74481 .55493 m .74784 .55041 L .75037 .54625 L .726 .057 .581 r
F
.7521 .52897 m .7789 .46065 L .76253 .51154 L 0 0 0 r
F
.7521 .52897 m .76801 .48071 L .7789 .46065 L F
.7387 .50234 m .75429 .54054 L .74831 .48731 L .726 .057 .58 r
F
.74139 .57277 m .75429 .54054 L .75115 .55838 L 0 0 .02 r
F
.75429 .54054 m .77294 .49397 L .76012 .53185 L F
.75429 .54054 m .77749 .59736 L .76012 .53185 L .726 .057 .58 r
F
.75429 .54054 m .76012 .53185 L .75115 .55838 L 0 0 .02 r
F
.75429 .54054 m .76012 .53185 L .76003 .53151 L .726 .057 .58 r
F
.75429 .54054 m .76253 .51154 L .77294 .49397 L 0 0 .02 r
F
.75429 .54054 m .76003 .53151 L .74831 .48731 L .726 .057 .58 r
F
.75421 .54075 m .75425 .54061 L .75429 .54054 L 0 0 .02 r
F
.74139 .57277 m .75039 .5467 L .75421 .54075 L F
.74477 .55499 m .74477 .55499 L .74481 .55493 L 0 0 .016 r
F
.72909 .5172 m .74481 .55493 L .7387 .50234 L .726 .057 .581 r
F
.74481 .55493 m .75037 .54625 L .7387 .50234 L F
.74474 .5551 m .74477 .55499 L .74481 .55493 L 0 0 .016 r
F
.73164 .58717 m .74074 .56127 L .74474 .5551 L F
.73533 .56927 m .73533 .56927 L .73536 .56923 L 0 0 .014 r
F
.71947 .53191 m .73536 .56923 L .72909 .5172 L .728 .058 .582 r
F
.73536 .56923 m .74074 .56094 L .72909 .5172 L F
.73531 .56934 m .73533 .56927 L .73536 .56923 L 0 0 .014 r
F
.72189 .60161 m .73111 .57577 L .73531 .56934 L F
.70985 .54651 m .72146 .59002 L .7259 .58337 L .731 .059 .582 r
F
.70023 .56109 m .71169 .60413 L .71632 .59715 L .736 .061 .582 r
F
.71169 .60413 m .71182 .60459 L .71632 .59715 L F
.69062 .57583 m .70705 .61169 L .70023 .56109 L .745 .063 .581 r
F
.70705 .61169 m .70709 .61159 L .70708 .61165 L 0 0 .053 r
F
.70705 .61169 m .7118 .60453 L .70023 .56109 L .745 .063 .581 r
F
.69268 .64523 m .70705 .61169 L .70241 .63062 L 0 0 .053 r
F
.70705 .61169 m .70708 .61165 L .70241 .63062 L F
.69743 .62584 m .69743 .62585 L .69755 .62567 L .764 .068 .579 r
F
.69743 .62584 m .69748 .62576 L .69268 .64523 L .001 0 .103 r
F
.69743 .62584 m .70201 .61883 L .70176 .61788 L .764 .068 .579 r
F
.69658 .61791 m .69952 .61073 L .69806 .61506 L .145 0 .184 r
F
.69729 .62481 m .70176 .61788 L .69062 .57583 L .764 .068 .579 r
F
.69743 .62584 m .70176 .61788 L .69729 .62481 L F
.68103 .59109 m .69709 .62512 L .69062 .57583 L F
.69709 .62512 m .69743 .62584 L .69729 .62481 L F
.69709 .62512 m .69729 .62481 L .69062 .57583 L F
.68758 .63996 m .6877 .63966 L .69134 .63408 L .145 0 .184 r
F
.6877 .63966 m .69139 .63394 L .69134 .63408 L F
.68758 .63996 m .69134 .63408 L .69134 .6341 L F
.69202 .63303 m .69202 .63303 L .69448 .62975 L .001 0 .103 r
F
.68296 .65996 m .69451 .62968 L .69743 .62584 L F
.69709 .62512 m .69202 .63303 L .69743 .62584 L .764 .068 .579 r
F
.68103 .59109 m .69202 .63303 L .69709 .62512 L F
.69202 .63303 m .69202 .63303 L .69709 .62512 L F
.68934 .63725 m .69202 .63303 L .69148 .63097 L .796 .075 .576 r
F
.68014 .66156 m .68204 .6652 L .68124 .66076 L .852 .089 .571 r
F
.67338 .67471 m .68751 .64013 L .68296 .65997 L .145 0 .184 r
F
.68856 .63953 m .69148 .63097 L .68809 .63651 L .796 .075 .576 r
F
.68751 .64013 m .69134 .6341 L .68296 .65997 L .145 0 .184 r
F
.66759 .66876 m .67087 .66146 L .66958 .66671 L .472 0 .369 r
F
.66681 .66956 m .67087 .66146 L .66759 .66876 L F
.67239 .66746 m .67247 .6674 L .6644 .63147 L .852 .089 .571 r
F
.66194 .68387 m .67341 .69567 L .68022 .69847 L 1 .18 .585 r
F
.66169 .68432 m .67341 .69567 L .66194 .68387 L F
.65864 .6855 m .66043 .67656 L .66242 .67505 L .472 0 .369 r
F
.65863 .68555 m .65864 .6855 L .66347 .68069 L F
.65776 .68071 m .67341 .69567 L .65785 .6806 L 1 .18 .585 r
F
.67239 .66746 m .67321 .67071 L .67247 .6674 L .852 .089 .571 r
F
.66382 .69009 m .67503 .66026 L .67338 .67471 L .324 0 .283 r
F
.67503 .66026 m .67688 .65533 L .67645 .65769 L F
.67503 .66026 m .67645 .65769 L .67338 .67471 L F
.65785 .6806 m .66169 .68432 L .66194 .68387 L 1 .18 .585 r
F
.65665 .67965 m .65776 .68071 L .65785 .6806 L F
.67503 .66026 m .67087 .66146 L .67688 .65533 L .324 0 .283 r
F
.66382 .69009 m .66958 .66671 L .67503 .66026 L F
.66958 .66671 m .67087 .66146 L .67503 .66026 L F
.6641 .63463 m .67087 .66146 L .6644 .63147 L .852 .089 .571 r
F
.67087 .66146 m .67096 .66137 L .6644 .63147 L F
.68809 .63651 m .69148 .63097 L .68103 .59109 L .796 .075 .576 r
F
.68296 .65996 m .69202 .63303 L .69448 .62975 L .001 0 .103 r
F
.68751 .64013 m .68752 .64003 L .68758 .63996 L .145 0 .184 r
F
.6872 .6395 m .68751 .64013 L .68832 .638 L .796 .075 .576 r
F
.68751 .64013 m .68848 .639 L .68832 .638 L F
.70241 .63062 m .71651 .59759 L .71215 .61608 L 0 0 .028 r
F
.71651 .59759 m .72147 .59019 L .71215 .61608 L F
.67161 .60744 m .6872 .6395 L .68103 .59109 L .796 .075 .576 r
F
.6872 .6395 m .68832 .638 L .68103 .59109 L F
.66242 .67505 m .66254 .67434 L .66273 .67421 L .472 0 .369 r
F
.66227 .6274 m .6644 .63147 L .66541 .62068 L .852 .089 .571 r
F
.65344 .67004 m .66347 .68069 L .66227 .6274 L 1 .18 .585 r
F
.66347 .68069 m .66681 .66956 L .66838 .66795 L .472 0 .369 r
F
.66347 .68069 m .67087 .66146 L .66227 .6274 L 1 .18 .585 r
F
.66347 .68069 m .66838 .66795 L .66958 .66671 L .472 0 .369 r
F
.67161 .60744 m .6802 .64086 L .68395 .63281 L .796 .075 .576 r
F
.68467 .65827 m .69072 .6818 L .69359 .65263 L F
.65946 .67643 m .66255 .68436 L .66493 .68223 L 1 .18 .585 r
F
.65928 .67845 m .66255 .68436 L .65946 .67643 L F
.65928 .67845 m .659 .68152 L .66255 .68436 L F
.66019 .69023 m .66981 .71903 L .67463 .70953 L F
.66019 .69023 m .67463 .70953 L .68022 .69847 L F
.65439 .71098 m .66347 .68069 L .66382 .69009 L .472 0 .369 r
F
.66347 .68069 m .66958 .66671 L .66382 .69009 L F
.66068 .6835 m .66037 .6878 L .66179 .68455 L 1 .18 .585 r
F
.66037 .6878 m .66019 .69023 L .66179 .68455 L F
.65665 .67965 m .65863 .68555 L .66068 .6835 L F
.65863 .68555 m .66019 .69023 L .66068 .6835 L F
.6572 .69461 m .65862 .68557 L .65439 .71099 L .526 0 .387 r
F
.65439 .71098 m .65863 .68555 L .66347 .68069 L .472 0 .369 r
F
.65019 .73918 m .67338 .67472 L .65354 .73287 L 0 0 .139 r
F
.65674 .72686 m .65354 .73287 L .66195 .7167 L 0 0 0 r
F
.64522 .75299 m .66382 .6901 L .67338 .67472 L 0 0 .139 r
F
.64732 .74497 m .64522 .75299 L .65354 .73287 L .882 .009 .468 r
F
.63911 .76999 m .64254 .75676 L .63923 .76965 L 1 .281 .456 r
F
.6281 .78236 m .64401 .75506 L .64732 .74497 L .882 .009 .468 r
F
.64401 .75506 m .64522 .75299 L .64732 .74497 L F
.63631 .7808 m .63671 .77945 L .63664 .77953 L 1 .281 .456 r
F
.63623 .78113 m .63633 .78079 L .63631 .7808 L F
.63623 .78113 m .64375 .75941 L .64123 .76417 L F
.64375 .75941 m .64962 .74248 L .64123 .76417 L F
.63699 .77851 m .64229 .76106 L .64522 .75299 L 0 0 .109 r
F
.63699 .77851 m .64033 .76557 L .64229 .76106 L F
.64389 .75536 m .63699 .77851 L .64522 .75299 L 1 .558 .582 r
F
.63631 .7808 m .63911 .76999 L .63663 .77971 L 1 .281 .456 r
F
.63911 .76999 m .63923 .76965 L .63664 .7797 L F
.63663 .77971 m .63664 .7797 L .6366 .77986 L F
.63911 .76999 m .63664 .7797 L .63663 .77971 L F
.62838 .78553 m .63058 .78716 L .62824 .78562 L .822 0 .067 r
F
.63664 .7797 m .64018 .76602 L .63699 .77852 L 1 .281 .456 r
F
.64011 .76622 m .64018 .76602 L .6366 .77986 L F
.62521 .79018 m .63699 .77851 L .62464 .78978 L 1 .558 .582 r
F
.64104 .76281 m .64104 .76282 L .64033 .76557 L 1 .281 .456 r
F
.6403 .76566 m .64033 .76557 L .63699 .77852 L F
.64018 .76602 m .6403 .76566 L .63699 .77852 L F
.64065 .7641 m .64065 .76418 L .64018 .76602 L F
.64065 .7641 m .64018 .76602 L .64011 .76622 L F
.62464 .78978 m .63699 .77851 L .64389 .75536 L 1 .558 .582 r
F
.63699 .77851 m .63699 .77851 L .64389 .75536 L F
.63623 .78113 m .63631 .7808 L .6366 .77986 L 1 .281 .456 r
F
.63631 .7808 m .63663 .77971 L .6366 .77986 L F
.65021 .73957 m .65354 .73287 L .65674 .72686 L 0 0 0 r
F
.62353 .7902 m .6281 .78236 L .65354 .73287 L .882 .009 .468 r
F
.63009 .77876 m .64942 .74093 L .65021 .73957 L 0 0 0 r
F
.64942 .74093 m .65354 .73287 L .65021 .73957 L F
.64871 .74012 m .64894 .74038 L .64812 .74317 L 0 0 .109 r
F
.64871 .74012 m .64812 .74317 L .64767 .74394 L F
.64928 .73801 m .64894 .74038 L .64871 .74012 L F
.62477 .78782 m .64936 .74086 L .62475 .78795 L .882 .009 .468 r
F
.64936 .74086 m .65354 .73287 L .64936 .74086 L F
.64936 .74086 m .64936 .74086 L .62475 .78795 L F
.62353 .7902 m .62477 .78782 L .62352 .7903 L F
.62477 .78782 m .62475 .78795 L .62352 .7903 L F
.62359 .79021 m .64522 .75299 L .62353 .7902 L F
.6262 .78699 m .64522 .75299 L .62498 .78781 L 1 .558 .582 r
F
.63235 .77547 m .63009 .77876 L .63724 .76794 L 0 0 0 r
F
.6247 .78823 m .62823 .78146 L .63009 .77876 L .882 .009 .468 r
F
.62475 .78795 m .65354 .73287 L .6247 .78823 L F
.62666 .79168 m .63747 .80251 L .62354 .79203 L 1 0 .135 r
F
.62348 .79194 m .62354 .79203 L .62343 .79195 L F
.62666 .79168 m .62354 .79203 L .62348 .79194 L F
.62666 .79168 m .62493 .79046 L .62343 .79195 L 1 .558 .582 r
F
.62343 .79195 m .62521 .79018 L .62464 .78978 L F
.635 .81657 m .62842 .83084 L .63987 .83587 L .95 .488 .745 r
F
.62292 .81563 m .62842 .83084 L .635 .81657 L .918 .562 .777 r
F
.62292 .81563 m .61698 .82673 L .62842 .83084 L F
.62687 .80434 m .62292 .81563 L .635 .81657 L 1 .72 .791 r
F
.62255 .82516 m .64218 .8209 L .63082 .79971 L 1 .423 .621 r
F
.64218 .8209 m .64929 .81935 L .64501 .8148 L F
.64218 .8209 m .64501 .8148 L .63082 .79971 L F
.63786 .89105 m .62966 .89004 L .64774 .91849 L 0 0 .57 r
F
.63988 .99278 m .6299 .90318 L .64904 .97936 L .376 0 .42 r
F
.65166 .8752 m .63786 .89105 L .64774 .91849 L .567 .03 .609 r
F
.64097 .86179 m .63786 .89105 L .65166 .8752 L .55 .057 .657 r
F
.65131 .84183 m .64097 .86179 L .65166 .8752 L .794 .193 .669 r
F
.63987 .83587 m .64097 .86179 L .65131 .84183 L .787 .254 .703 r
F
.63174 .95512 m .63202 .96866 L .6453 .97287 L .706 .303 .754 r
F
.63174 .95512 m .6453 .97287 L .64499 .95656 L F
.62923 .94038 m .63174 .95512 L .64499 .95656 L .798 .357 .744 r
F
.66276 .84857 m .65166 .8752 L .66239 .89052 L .83 .17 .643 r
F
.65131 .84183 m .65166 .8752 L .66276 .84857 L .794 .193 .669 r
F
.67422 .85575 m .66949 .90106 L .68177 .86055 L .893 .175 .626 r
F
.66276 .84857 m .66239 .89052 L .67422 .85575 L .83 .17 .643 r
F
.67422 .85575 m .6624 .89052 L .66949 .90106 L .893 .175 .626 r
F
.67111 .81859 m .66276 .84857 L .67422 .85575 L 1 .336 .662 r
F
.6591 .81812 m .66276 .84857 L .67111 .81859 L 1 .368 .685 r
F
.6591 .81812 m .65131 .84183 L .66276 .84857 L F
.66427 .79482 m .6591 .81812 L .67111 .81859 L 1 .588 .706 r
F
.65185 .79906 m .6591 .81812 L .66427 .79482 L 1 .642 .734 r
F
.65419 .7839 m .66427 .79482 L .66679 .77577 L 1 .916 .765 r
F
.65419 .7839 m .65185 .79906 L .66427 .79482 L F
.65408 .77466 m .65419 .7839 L .66679 .77577 L 1 .885 .789 r
F
.68285 .86123 m .6705 .90256 L .68127 .91828 L .949 .189 .617 r
F
.68177 .86056 m .6705 .90256 L .68284 .86123 L .936 .183 .618 r
F
.68177 .86056 m .66949 .90106 L .6705 .90256 L F
.65418 .87456 m .6571 .87638 L .66542 .87745 L .664 .35 .791 r
F
.68285 .86123 m .68127 .91828 L .69429 .86835 L .949 .189 .617 r
F
.66581 .89085 m .67459 .9001 L .68686 .88724 L 1 .966 .733 r
F
.68688 .88722 m .68686 .88724 L .68688 .88722 L F
.66581 .89085 m .68686 .88724 L .68688 .88722 L F
.69429 .86835 m .69203 .93312 L .70571 .87513 L 1 .21 .609 r
F
.69429 .86835 m .68127 .91828 L .69203 .93312 L F
.704 .8183 m .69429 .86835 L .70571 .87513 L 1 .31 .623 r
F
.69209 .81868 m .69429 .86835 L .704 .8183 L 1 .313 .634 r
F
.69812 .7775 m .69209 .81868 L .704 .8183 L 1 .459 .645 r
F
.69209 .81868 m .68285 .86123 L .69429 .86835 L 1 .313 .634 r
F
.68688 .88721 m .69346 .90493 L .6944 .88677 L 1 .121 .356 r
F
.68688 .88721 m .6944 .88677 L .69543 .86703 L F
.68688 .88721 m .69543 .86703 L .68831 .87685 L F
.66581 .89085 m .68688 .88722 L .6778 .88928 L 1 .966 .733 r
F
.6778 .88928 m .68688 .88721 L .68688 .88721 L .838 .174 .694 r
F
.68831 .87685 m .69543 .86703 L .69891 .80005 L 1 .121 .356 r
F
.69591 .82181 m .69627 .81919 L .69779 .8224 L F
.69627 .81919 m .69891 .80005 L .69785 .82135 L F
.69627 .81919 m .69785 .82135 L .69779 .8224 L F
.71588 .81763 m .70571 .87513 L .7171 .8815 L 1 .308 .614 r
F
.704 .8183 m .70571 .87513 L .71588 .81763 L 1 .31 .623 r
F
.71029 .76982 m .704 .8183 L .71588 .81763 L 1 .428 .631 r
F
.69812 .7775 m .704 .8183 L .71029 .76982 L 1 .459 .645 r
F
.7062 .8386 m .70004 .79737 L .71331 .81108 L .909 .01 .405 r
F
.7067 .84064 m .70129 .83902 L .7154 .87596 L .07 0 .519 r
F
.7062 .8386 m .70534 .83867 L .7067 .84064 L F
.70534 .83867 m .70129 .83902 L .7067 .84064 L F
.72773 .81673 m .71711 .8815 L .72865 .88757 L 1 .307 .608 r
F
.71588 .81763 m .7171 .8815 L .72772 .81673 L 1 .308 .614 r
F
.69697 .7782 m .69208 .81868 L .69811 .7775 L 1 .458 .647 r
F
.69697 .7782 m .69097 .8187 L .69208 .81868 L F
.68891 .78293 m .69097 .8187 L .69697 .7782 L 1 .487 .659 r
F
.69746 .82015 m .69867 .79164 L .69867 .79167 L 1 .101 .404 r
F
.69591 .82181 m .69779 .8224 L .69497 .87865 L 1 .121 .356 r
F
.69717 .82694 m .69746 .82014 L .69746 .82015 L 1 .101 .404 r
F
.69746 .82014 m .69867 .79164 L .69746 .82015 L F
.69717 .82692 m .69746 .82013 L .69717 .82694 L F
.69746 .82013 m .69867 .79164 L .69746 .82014 L F
.69746 .82013 m .69746 .82014 L .69717 .82694 L F
.69865 .79578 m .69867 .79167 L .69892 .79622 L 1 .02 .248 r
F
.71711 .8815 m .70276 .947 L .71364 .96023 L 1 .243 .6 r
F
.70571 .87513 m .70276 .947 L .7171 .8815 L 1 .229 .604 r
F
.70571 .87513 m .69203 .93312 L .70276 .947 L F
.69917 .80977 m .70752 .98257 L .69919 .80922 L 1 .392 .621 r
F
.7046 .97431 m .70752 .98257 L .69917 .80977 L F
.72282 1.05781 m .70498 1.0214 L .71587 1.03108 L .877 0 .046 r
F
.71092 1.04532 m .70498 1.0214 L .72282 1.05781 L .865 0 .049 r
F
.71092 1.04532 m .69429 1.01341 L .70498 1.0214 L F
.69907 1.0343 m .69429 1.01341 L .71092 1.04532 L .834 0 .049 r
F
.71113 1.05094 m .69907 1.0343 L .71092 1.04532 L .67 0 0 r
F
.72398 1.06644 m .71092 1.04532 L .72282 1.05781 L .722 0 0 r
F
.71113 1.05094 m .71092 1.04532 L .72398 1.06644 L .67 0 0 r
F
.70593 1.0388 m .71113 1.05094 L .71944 1.05653 L 0 0 .644 r
F
.70837 1.02581 m .70593 1.0388 L .70966 1.02765 L .167 0 .694 r
F
.70967 1.02765 m .70593 1.0388 L .71944 1.05653 L .137 0 .68 r
F
.7087 1.00975 m .70837 1.02581 L .70966 1.02765 L .36 .001 .64 r
F
.70867 1.00963 m .70837 1.02581 L .7087 1.00975 L F
.70809 1.00776 m .70837 1.02581 L .70867 1.00923 L F
.69871 .98142 m .70836 1.02581 L .70823 1.01707 L .413 .007 .64 r
F
.70441 .99742 m .70823 1.01707 L .70809 1.00775 L F
.69871 .98142 m .70823 1.01707 L .70441 .99742 L F
.69917 .80977 m .70714 .97872 L .69919 .80938 L .572 .013 .567 r
F
.69346 .90495 m .69715 .9588 L .6966 .93391 L F
.69346 .90495 m .70232 .98669 L .7046 .97431 L F
.69346 .90495 m .7046 .97431 L .69917 .80977 L F
.6966 .93391 m .69871 .98142 L .70232 .98669 L F
.69715 .9588 m .69871 .98142 L .6966 .93391 L F
.68094 .92394 m .6987 .98141 L .69346 .90495 L .585 .04 .616 r
F
.69464 .94611 m .7046 .97431 L .69917 .80977 L 1 .392 .621 r
F
.68094 .92394 m .68505 .969 L .6976 .98041 L .585 .04 .616 r
F
.69744 .97731 m .6976 .98041 L .6987 .98141 L F
.68094 .92394 m .6976 .98041 L .69744 .97731 L F
.68505 .969 m .69925 1.01372 L .69895 .99623 L .47 .026 .653 r
F
.6976 .98041 m .69895 .99623 L .6987 .98141 L F
.68505 .969 m .69895 .99623 L .6976 .98041 L F
.68505 .969 m .68557 .99855 L .69925 1.01372 L F
.67161 .96257 m .68557 .99855 L .68505 .969 L .528 .067 .68 r
F
.68234 .97669 m .69683 .98777 L .69463 .94613 L 1 .71 .669 r
F
.69871 .98142 m .69925 1.01372 L .70836 1.02581 L .413 .007 .64 r
F
.69683 .98777 m .69893 .98938 L .69464 .94619 L 1 .71 .669 r
F
.69683 .98777 m .69464 .94619 L .69463 .94613 L F
.68939 .97822 m .69463 .94612 L .69464 .94611 L .938 0 .23 r
F
.69463 .94594 m .69464 .94611 L .69465 .94582 L F
.67161 .96257 m .67204 .98712 L .68557 .99855 L .528 .067 .68 r
F
.6681 .93175 m .67161 .96257 L .68505 .969 L .678 .121 .662 r
F
.6681 .93175 m .68505 .969 L .68094 .92394 L F
.67204 1.00364 m .65593 .97163 L .67303 1.00385 L .843 0 .291 r
F
.67204 1.00364 m .65508 .97236 L .65593 .97163 L F
.66506 1.00277 m .65507 .97237 L .67203 1.00364 L .712 0 .284 r
F
.65863 .97882 m .6693 1.00147 L .67204 .98712 L .495 .126 .753 r
F
.65827 .95889 m .65863 .97882 L .67204 .98712 L .588 .133 .709 r
F
.65827 .95889 m .67204 .98712 L .67161 .96257 L F
.68495 1.01365 m .67275 1.10601 L .69491 1.03319 L 1 .229 .583 r
F
.68495 1.01365 m .66398 1.08323 L .67275 1.10601 L F
.68728 1.0249 m .67303 1.00385 L .68364 1.00743 L .766 0 .036 r
F
.68617 1.02411 m .67303 1.00385 L .68727 1.0249 L .755 0 .063 r
F
.68617 1.02411 m .67204 1.00364 L .67303 1.00385 L F
.67842 1.01892 m .67203 1.00364 L .68617 1.0241 L .678 0 .016 r
F
.67842 1.01892 m .66506 1.00277 L .67203 1.00364 L F
.67204 .98712 m .6693 1.00147 L .68252 1.01293 L .42 .056 .736 r
F
.69907 1.0343 m .68364 1.00743 L .69429 1.01341 L .834 0 .049 r
F
.68728 1.0249 m .68364 1.00743 L .69907 1.0343 L .766 0 .036 r
F
.67204 .98712 m .68252 1.01293 L .68557 .99855 L .42 .056 .736 r
F
.66403 .98652 m .66959 .99293 L .68234 .97669 L 1 .807 .696 r
F
.66403 .98652 m .67125 .98264 L .67663 .97977 L F
.67125 .98264 m .68234 .97669 L .67663 .97977 L F
.67663 .97977 m .68234 .97669 L .69463 .94613 L .936 .04 .459 r
F
.68557 .99855 m .68252 1.01293 L .69583 1.02681 L .342 .013 .718 r
F
.68557 .99855 m .69583 1.02681 L .69925 1.01372 L F
.68234 .97669 m .68594 1.00172 L .69893 .98938 L 1 .71 .669 r
F
.66959 .99293 m .68594 1.00172 L .68234 .97669 L 1 .805 .7 r
F
.67663 .97977 m .69463 .94613 L .68939 .97822 L .936 .04 .459 r
F
.68162 .97711 m .67663 .97977 L .68939 .97822 L .441 .109 .89 r
F
.66786 .97514 m .67663 .97977 L .68162 .97711 L F
.68939 .97822 m .69464 .94611 L .69463 .94594 L .938 0 .23 r
F
.69419 .94046 m .69465 .94582 L .6951 .93332 L F
.68939 .97822 m .69465 .94582 L .69419 .94046 L F
.69456 .92322 m .6951 .93332 L .69602 .90769 L F
.68939 .97822 m .6951 .93332 L .69456 .92322 L F
.7046 .97431 m .70456 .97454 L .70648 .97976 L 1 .392 .621 r
F
.70651 .97971 m .70648 .97976 L .70752 .98257 L F
.7046 .97431 m .70648 .97976 L .70651 .97971 L F
.70423 .97367 m .70232 .98669 L .70752 .98257 L F
.69953 .98262 m .70809 1.00775 L .70232 .98669 L .413 .007 .64 r
F
.70178 .98712 m .70809 1.00775 L .70809 1.00775 L .964 .189 .613 r
F
.70232 .98669 m .70809 1.00775 L .70752 .98257 L F
.70178 .98712 m .70809 1.00775 L .70232 .98669 L F
.69953 .98262 m .70809 1.00775 L .70809 1.00775 L .413 .007 .64 r
F
.70753 .98257 m .70809 1.00776 L .7081 1.00776 L .941 .159 .6 r
F
.70753 .98257 m .70808 1.00725 L .70867 1.00923 L F
.70808 1.00725 m .7081 1.00776 L .70867 1.00923 L F
.73495 1.07177 m .71587 1.03108 L .72678 1.04194 L .884 0 .045 r
F
.72282 1.05781 m .71587 1.03108 L .73495 1.07177 L .877 0 .046 r
F
.72398 1.06644 m .72282 1.05781 L .73691 1.0833 L .722 0 0 r
F
.73692 1.0833 m .72282 1.05781 L .73495 1.07177 L .756 0 0 r
F
.72365 1.04895 m .71944 1.05653 L .73306 1.07602 L 0 0 .639 r
F
.70967 1.02765 m .71944 1.05653 L .723 1.05013 L .137 0 .68 r
F
.7185 1.0411 m .723 1.05013 L .72365 1.04895 L F
.70967 1.02765 m .723 1.05013 L .7185 1.0411 L F
.7046 .97431 m .70714 .97872 L .69917 .80977 L .572 .013 .567 r
F
.70714 .97872 m .70714 .97872 L .69919 .80938 L F
.699 .80273 m .70753 .98257 L .70875 .98184 L .965 .081 .524 r
F
.69969 .82052 m .70713 .97859 L .70812 .9768 L .715 .021 .524 r
F
.69933 .81383 m .69965 .82054 L .69969 .82052 L F
.69965 .82054 m .70713 .97859 L .69969 .82052 L F
.6954 .87979 m .69602 .90769 L .69873 .83231 L .938 0 .23 r
F
.69849 .82901 m .69873 .83231 L .69936 .81485 L F
.6954 .87979 m .69873 .83231 L .69849 .82901 L F
.69497 .87865 m .69751 .81907 L .69848 .82234 L 1 .101 .404 r
F
.69751 .81907 m .69867 .79167 L .69848 .82197 L F
.69751 .81907 m .69848 .82197 L .69848 .82234 L F
.69485 .94825 m .69752 .96198 L .70423 .97367 L 1 .392 .621 r
F
.69752 .96198 m .70232 .98669 L .70423 .97367 L F
.68939 .97822 m .69602 .90769 L .69567 .8919 L .938 0 .23 r
F
.69466 .8918 m .69567 .8919 L .6954 .87979 L F
.68939 .97822 m .69567 .8919 L .69466 .8918 L F
.68688 .88721 m .69591 .82181 L .69497 .87865 L 1 .121 .356 r
F
.68742 .88333 m .68688 .88721 L .69486 .87872 L .838 .174 .694 r
F
.68053 .88759 m .68688 .88721 L .68742 .88333 L F
.68053 .88759 m .68688 .88721 L .68688 .88721 L F
.6778 .88928 m .68688 .88721 L .68053 .88759 L F
.69486 .87872 m .68688 .88721 L .69497 .87865 L F
.68688 .88721 m .68688 .88721 L .69486 .87872 L F
.68688 .88722 m .68688 .88722 L .68639 .88733 L 1 .966 .733 r
F
.68688 .88722 m .68639 .88733 L .6778 .88928 L F
.679 .889 m .68688 .88721 L .6778 .88928 L .838 .174 .694 r
F
.67459 .9001 m .69346 .90494 L .68688 .88722 L 1 .645 .632 r
F
.67918 .88945 m .69497 .87865 L .68578 .89031 L .838 .174 .694 r
F
.6778 .88928 m .679 .889 L .6778 .88928 L F
.6778 .88928 m .68053 .88759 L .67918 .88945 L F
.68053 .88759 m .69497 .87865 L .67918 .88945 L F
.6571 .87638 m .66764 .88295 L .6657 .87772 L .664 .35 .791 r
F
.66764 .88295 m .6778 .88928 L .67381 .88547 L F
.66764 .88295 m .67381 .88547 L .6657 .87772 L F
.68577 .89035 m .68692 .8906 L .68808 .89109 L .339 0 0 r
F
.66542 .87745 m .6778 .88928 L .67849 .88937 L .364 .11 .865 r
F
.67583 .88403 m .67849 .88937 L .68578 .89031 L F
.66542 .87745 m .67849 .88937 L .67583 .88403 L F
.66542 .87745 m .66583 .87771 L .67301 .88514 L F
.66583 .87771 m .66786 .87899 L .67301 .88514 L F
.66786 .87899 m .68578 .89031 L .67311 .88518 L F
.66786 .87899 m .67311 .88518 L .67301 .88514 L F
.67459 .9001 m .68094 .92393 L .69346 .90494 L 1 .645 .632 r
F
.65418 .87456 m .66581 .89085 L .6778 .88928 L .664 .35 .791 r
F
.69464 .94611 m .69485 .94825 L .70423 .97367 L 1 .392 .621 r
F
.69464 .94611 m .70423 .97367 L .7046 .97431 L F
.69871 .98142 m .70809 1.00775 L .69953 .98262 L .413 .007 .64 r
F
.69485 .94825 m .69894 .98938 L .70232 .98669 L 1 .392 .621 r
F
.68939 .97822 m .69731 .84843 L .69799 .98304 L .938 0 .23 r
F
.69849 .82901 m .69936 .81485 L .69923 .83059 L F
.72865 .88757 m .71364 .96023 L .7245 .97283 L 1 .253 .596 r
F
.71711 .8815 m .71364 .96023 L .72865 .88757 L 1 .243 .6 r
F
.70129 .8391 m .70875 .98184 L .72198 .97863 L .942 .084 .535 r
F
.74714 1.08684 m .72678 1.04194 L .73773 1.05372 L .889 0 .045 r
F
.73495 1.07177 m .72678 1.04194 L .74714 1.08684 L .884 0 .045 r
F
.72198 .97863 m .72365 1.04878 L .7373 1.05812 L .836 .104 .591 r
F
.70875 .98184 m .70884 .98577 L .72331 1.04774 L .898 .138 .599 r
F
.72336 1.0479 m .70967 1.02765 L .72365 1.04895 L .325 0 .633 r
F
.72336 1.0479 m .72331 1.04774 L .72332 1.04779 L .898 .138 .599 r
F
.70875 .98184 m .72331 1.04774 L .72336 1.0479 L F
.70944 1.01216 m .70944 1.01216 L .72336 1.0479 L .325 0 .633 r
F
.70944 1.01216 m .70967 1.02765 L .71827 1.04038 L F
.70944 1.01216 m .71827 1.04038 L .72336 1.0479 L F
.70867 1.00923 m .70966 1.02765 L .70944 1.01215 L .36 .001 .64 r
F
.70911 1.0111 m .70944 1.01215 L .70875 .98184 L .941 .159 .6 r
F
.70867 1.00923 m .70944 1.01215 L .70943 1.01178 L .36 .001 .64 r
F
.70753 .98257 m .70867 1.00923 L .70879 .98507 L .941 .159 .6 r
F
.70867 1.00923 m .70925 1.02251 L .7091 1.01088 L F
.70867 1.00923 m .7091 1.01088 L .70879 .98507 L F
.70925 1.02251 m .70969 1.02341 L .70944 1.01215 L F
.70925 1.02251 m .70944 1.01215 L .70911 1.0111 L F
.70884 .98577 m .71015 1.04346 L .71324 1.04479 L .898 .138 .599 r
F
.70884 .98577 m .71324 1.04479 L .72366 1.04926 L F
.70922 .99708 m .70944 1.01216 L .72336 1.0479 L .325 0 .633 r
F
.72336 1.0479 m .72332 1.04779 L .72366 1.04926 L .898 .138 .599 r
F
.71556 .98019 m .72294 1.02668 L .72198 .97863 L F
.72336 1.0479 m .72365 1.04878 L .72198 .97863 L F
.70639 .92246 m .72349 1.02483 L .70657 .92274 L .521 .004 .553 r
F
.70629 .9223 m .70768 .93055 L .70639 .92246 L F
.70768 .93055 m .72349 1.02483 L .70639 .92246 L F
.70875 .98184 m .72336 1.0479 L .72294 1.02668 L .898 .138 .599 r
F
.70875 .98184 m .72294 1.02668 L .71556 .98019 L F
.72336 1.0479 m .72346 1.04824 L .72346 1.04819 L .325 0 .633 r
F
.72346 1.04824 m .72365 1.04895 L .72365 1.04878 L F
.72336 1.0479 m .72366 1.04926 L .72365 1.04878 L .898 .138 .599 r
F
.72336 1.0479 m .72346 1.04819 L .72346 1.04818 L .325 0 .633 r
F
.70922 .99708 m .72336 1.0479 L .72349 1.02483 L F
.72336 1.0479 m .72346 1.04818 L .72349 1.02483 L F
.72346 1.04824 m .72365 1.04878 L .72349 1.02483 L F
.72365 1.04878 m .72372 1.04894 L .7373 1.05812 L .836 .104 .591 r
F
.72365 1.04878 m .72365 1.04895 L .72396 1.04945 L .157 0 .621 r
F
.72365 1.04889 m .72396 1.04945 L .7373 1.05812 L .836 .104 .591 r
F
.75012 1.10162 m .73495 1.07177 L .74714 1.08684 L .78 0 0 r
F
.73692 1.0833 m .73495 1.07177 L .75012 1.10162 L .756 0 0 r
F
.72365 1.04895 m .73306 1.07602 L .73657 1.07344 L 0 0 .639 r
F
.72396 1.04945 m .73657 1.07344 L .7373 1.05812 L .737 .089 .612 r
F
.7347 1.1053 m .7168 1.21913 L .74466 1.12296 L 1 .23 .583 r
F
.74466 1.12296 m .72568 1.24239 L .75463 1.14068 L 1 .228 .582 r
F
.74466 1.12296 m .7168 1.21913 L .72568 1.24239 L F
.73306 1.07602 m .72398 1.06644 L .73691 1.0833 L 0 0 .455 r
F
.73306 1.07602 m .73691 1.0833 L .7468 1.09694 L F
.7468 1.09694 m .73692 1.0833 L .75012 1.10162 L 0 0 .374 r
F
.74057 1.08003 m .73306 1.07602 L .7468 1.09694 L 0 0 .578 r
F
.74036 1.07947 m .74017 1.07938 L .74057 1.08003 L F
.74017 1.07938 m .73306 1.07602 L .74057 1.08003 L F
.72365 1.04895 m .73657 1.07344 L .72497 1.05139 L 0 0 .639 r
F
.7373 1.05812 m .73662 1.07243 L .74036 1.07947 L .705 .071 .606 r
F
.73662 1.07243 m .73657 1.07344 L .74036 1.07947 L F
.75012 1.10162 m .74714 1.08684 L .76341 1.12099 L .78 0 0 r
F
.75938 1.10284 m .73773 1.05372 L .7487 1.0662 L .895 0 .048 r
F
.74714 1.08684 m .73773 1.05372 L .75938 1.10284 L .889 0 .045 r
F
.77167 1.11964 m .7487 1.0662 L .75969 1.07925 L .901 0 .052 r
F
.75938 1.10284 m .7487 1.0662 L .77167 1.11964 L .895 0 .048 r
F
.7373 1.05812 m .74036 1.07947 L .75107 1.06956 L .705 .071 .606 r
F
.74036 1.07947 m .7468 1.09694 L .74979 1.09731 L 0 0 .578 r
F
.7468 1.09694 m .75012 1.10162 L .76086 1.11937 L 0 0 .374 r
F
.76086 1.11937 m .75012 1.10162 L .76341 1.12099 L .639 0 0 r
F
.75637 1.10823 m .7468 1.09694 L .76086 1.11937 L 0 0 .507 r
F
.78402 1.13711 m .75969 1.07925 L .7707 1.09277 L .908 0 .057 r
F
.77167 1.11964 m .75969 1.07925 L .78402 1.13711 L .901 0 .052 r
F
.76341 1.12099 m .74714 1.08684 L .75938 1.10284 L .798 0 0 r
F
.75107 1.06956 m .75617 1.10772 L .76517 1.08326 L .677 .058 .602 r
F
.75617 1.10772 m .7498 1.09732 L .75637 1.10823 L 0 0 .507 r
F
.7498 1.09732 m .7468 1.09694 L .75637 1.10823 L F
.76341 1.12099 m .75938 1.10284 L .77678 1.14129 L .798 0 0 r
F
.77502 1.14282 m .76341 1.12099 L .77678 1.14129 L .688 0 0 r
F
.76086 1.11937 m .76341 1.12099 L .77502 1.14282 L .639 0 0 r
F
.77176 1.13542 m .76086 1.11937 L .77502 1.14282 L 0 0 .437 r
F
.79642 1.1552 m .7707 1.09277 L .78173 1.1067 L .916 0 .063 r
F
.78402 1.13711 m .7707 1.09277 L .79642 1.1552 L .908 0 .057 r
F
.77678 1.14129 m .75938 1.10284 L .77167 1.11964 L .811 0 0 r
F
.79024 1.16242 m .77167 1.11964 L .78402 1.13711 L .823 0 0 r
F
.77678 1.14129 m .77167 1.11964 L .79024 1.16242 L .811 0 0 r
F
.76517 1.08326 m .7716 1.13504 L .77938 1.09858 L .654 .049 .599 r
F
.7716 1.13504 m .76347 1.12145 L .77176 1.13542 L 0 0 .437 r
F
.76347 1.12145 m .76086 1.11937 L .77176 1.13542 L F
.77502 1.14282 m .77678 1.14129 L .78931 1.16716 L .688 0 0 r
F
.78688 1.1622 m .77502 1.14282 L .78931 1.16716 L 0 0 .375 r
F
.79642 1.1552 m .78173 1.1067 L .80888 1.17382 L .916 0 .063 r
F
.80378 1.18429 m .78402 1.13711 L .79642 1.1552 L .833 0 0 r
F
.79024 1.16242 m .78402 1.13711 L .80378 1.18429 L .823 0 0 r
F
.78931 1.16716 m .77678 1.14129 L .79024 1.16242 L .723 0 0 r
F
.77938 1.09858 m .78675 1.16194 L .79372 1.11521 L .635 .041 .596 r
F
.78675 1.16194 m .77733 1.14582 L .78688 1.1622 L 0 0 .375 r
F
.77733 1.14582 m .77502 1.14282 L .78688 1.1622 L F
.78931 1.16716 m .79024 1.16242 L .80372 1.19231 L .723 0 0 r
F
.80189 1.18902 m .78931 1.16716 L .80372 1.19231 L 0 0 .325 r
F
.81742 1.20685 m .79642 1.1552 L .80888 1.17382 L .842 0 0 r
F
.80378 1.18429 m .79642 1.1552 L .81742 1.20685 L .833 0 0 r
F
.80372 1.19231 m .79024 1.16242 L .80378 1.18429 L .749 0 0 r
F
.79372 1.11521 m .80178 1.18882 L .80816 1.13292 L .62 .036 .594 r
F
.80178 1.18882 m .79138 1.17064 L .80189 1.18902 L 0 0 .325 r
F
.79138 1.17064 m .78931 1.16716 L .80189 1.18902 L F
.80372 1.19231 m .80378 1.18429 L .81824 1.21822 L .749 0 0 r
F
.81687 1.21608 m .80372 1.19231 L .81824 1.21822 L .648 0 0 r
F
.81678 1.21595 m .80557 1.19599 L .81687 1.21608 L F
.80557 1.19599 m .80372 1.19231 L .81687 1.21608 L F
.81742 1.20685 m .80888 1.17382 L .83114 1.23004 L .842 0 0 r
F
.81824 1.21822 m .80378 1.18429 L .81742 1.20685 L .77 0 0 r
F
.83289 1.24484 m .81742 1.20685 L .83114 1.23004 L .785 0 0 r
F
.81824 1.21822 m .81742 1.20685 L .83289 1.24484 L .77 0 0 r
F
.80816 1.13292 m .81678 1.21595 L .82272 1.15156 L .608 .032 .592 r
F
.83186 1.24353 m .81824 1.21822 L .83289 1.24484 L .682 0 0 r
F
.83178 1.24344 m .81992 1.22193 L .83186 1.24353 L F
.81992 1.22193 m .81824 1.21822 L .83186 1.24353 L F
.83289 1.24484 m .83114 1.23004 L .84766 1.27216 L .785 0 0 r
F
.82272 1.15156 m .83178 1.24344 L .8374 1.17102 L .599 .028 .59 r
F
.84689 1.27144 m .83289 1.24484 L .84766 1.27216 L .708 0 0 r
F
.84683 1.27138 m .83441 1.24849 L .84689 1.27144 L F
.83441 1.24849 m .83289 1.24484 L .84689 1.27144 L F
.8374 1.17102 m .84683 1.27138 L .85219 1.19123 L .591 .026 .588 r
F
.84683 1.27138 m .84853 1.28946 L .84904 1.27568 L F
.84695 1.27265 m .83381 1.26402 L .84853 1.28946 L F
.8374 1.17102 m .83441 1.24849 L .84695 1.27265 L F
.83441 1.24849 m .83381 1.26402 L .84695 1.27265 L F
.83178 1.24344 m .83181 1.24371 L .83292 1.24563 L .599 .028 .59 r
F
.8318 1.24346 m .83289 1.24484 L .83441 1.24849 L .682 0 0 r
F
.83178 1.24344 m .83292 1.24563 L .83442 1.24822 L .599 .028 .59 r
F
.83181 1.24371 m .83381 1.26402 L .83441 1.24849 L F
.83292 1.24563 m .83441 1.24849 L .83442 1.24822 L F
.83181 1.24371 m .83441 1.24849 L .83292 1.24563 L F
.83183 1.24353 m .83441 1.24849 L .84213 1.26701 L .682 0 0 r
F
.8318 1.24346 m .83441 1.24849 L .83183 1.24353 L F
.83192 1.24483 m .81922 1.23949 L .83381 1.26402 L .599 .028 .59 r
F
.82272 1.15156 m .81992 1.22193 L .83192 1.24483 L F
.81992 1.22193 m .81922 1.23949 L .83192 1.24483 L F
.81678 1.21595 m .81682 1.21632 L .81816 1.21857 L .608 .032 .592 r
F
.81678 1.21595 m .8168 1.21598 L .81684 1.21606 L .648 0 0 r
F
.8168 1.21598 m .81824 1.21822 L .81992 1.22193 L F
.81678 1.21595 m .81816 1.21857 L .81993 1.22157 L .608 .032 .592 r
F
.81682 1.21632 m .81922 1.23949 L .81992 1.22193 L F
.81816 1.21857 m .81992 1.22193 L .81993 1.22157 L F
.81682 1.21632 m .81992 1.22193 L .81816 1.21857 L F
.81684 1.21606 m .81992 1.22193 L .82676 1.23707 L .648 0 0 r
F
.8168 1.21598 m .81992 1.22193 L .81684 1.21606 L F
.81694 1.2175 m .80475 1.21592 L .81922 1.23949 L .608 .032 .592 r
F
.80816 1.13292 m .80557 1.19599 L .81694 1.2175 L F
.80557 1.19599 m .80475 1.21592 L .81694 1.2175 L F
.80178 1.18882 m .80184 1.18936 L .80347 1.19201 L .62 .036 .594 r
F
.80178 1.18882 m .80182 1.18889 L .80187 1.18899 L 0 0 .325 r
F
.80178 1.18882 m .80347 1.19201 L .80559 1.19548 L .62 .036 .594 r
F
.80184 1.18936 m .80475 1.21592 L .80557 1.19599 L F
.80182 1.18889 m .80372 1.19231 L .80557 1.19599 L 0 0 .325 r
F
.80347 1.19201 m .80557 1.19599 L .80559 1.19548 L .62 .036 .594 r
F
.80184 1.18936 m .80557 1.19599 L .80347 1.19201 L F
.80187 1.18899 m .80557 1.19599 L .81154 1.20781 L 0 0 .325 r
F
.80182 1.18889 m .80557 1.19599 L .80187 1.18899 L F
.80198 1.19057 m .79041 1.19342 L .80475 1.21592 L .62 .036 .594 r
F
.79372 1.11521 m .79138 1.17064 L .80198 1.19057 L F
.79138 1.17064 m .79041 1.19342 L .80198 1.19057 L F
.78675 1.16194 m .78681 1.16205 L .78689 1.16219 L 0 0 .375 r
F
.78675 1.16194 m .78684 1.16272 L .78883 1.16585 L .635 .041 .596 r
F
.78675 1.16194 m .78883 1.16585 L .79141 1.16991 L F
.78681 1.16205 m .78931 1.16716 L .79138 1.17064 L 0 0 .375 r
F
.78883 1.16585 m .79138 1.17064 L .79141 1.16991 L .635 .041 .596 r
F
.78684 1.16272 m .79138 1.17064 L .78883 1.16585 L F
.78689 1.16219 m .79138 1.17064 L .79647 1.17922 L 0 0 .375 r
F
.78681 1.16205 m .79138 1.17064 L .78689 1.16219 L F
.78675 1.16194 m .79141 1.16991 L .79372 1.11521 L .635 .041 .596 r
F
.78698 1.16387 m .7762 1.1721 L .79041 1.19342 L F
.77938 1.09858 m .77733 1.14582 L .78698 1.16387 L F
.77733 1.14582 m .7762 1.1721 L .78698 1.16387 L F
.7716 1.13504 m .77738 1.14474 L .77938 1.09858 L .654 .049 .599 r
F
.7716 1.13504 m .7621 1.15213 L .7762 1.1721 L F
.76517 1.08326 m .76353 1.11992 L .7716 1.13504 L F
.75617 1.10772 m .75634 1.10814 L .75663 1.10859 L 0 0 .507 r
F
.75634 1.10814 m .76086 1.11937 L .76347 1.12145 L F
.75617 1.10772 m .75642 1.10957 L .75953 1.11404 L .677 .058 .602 r
F
.75617 1.10772 m .75953 1.11404 L .76354 1.1198 L F
.75617 1.10772 m .76354 1.1198 L .76517 1.08326 L F
.75617 1.10772 m .74812 1.13371 L .7621 1.15213 L F
.75107 1.06956 m .7498 1.09732 L .75617 1.10772 L F
.7498 1.09732 m .7498 1.09732 L .75617 1.10772 L 0 0 .507 r
F
.7498 1.09732 m .74812 1.13371 L .75617 1.10772 L .677 .058 .602 r
F
.74983 1.09732 m .7498 1.09732 L .75617 1.10772 L 0 0 .507 r
F
.7521 1.09761 m .75617 1.10772 L .76675 1.12406 L F
.75617 1.10772 m .75663 1.10859 L .76675 1.12406 L F
.76353 1.11992 m .76347 1.12145 L .7716 1.13504 L .654 .049 .599 r
F
.75953 1.11404 m .76347 1.12145 L .76354 1.1198 L .677 .058 .602 r
F
.75642 1.10957 m .76347 1.12145 L .75953 1.11404 L F
.75663 1.10859 m .76347 1.12145 L .76675 1.12406 L 0 0 .507 r
F
.75634 1.10814 m .76347 1.12145 L .75663 1.10859 L F
.76347 1.12145 m .7621 1.15213 L .77116 1.13582 L .654 .049 .599 r
F
.76347 1.12145 m .77116 1.13582 L .7716 1.13504 L F
.76675 1.12406 m .7716 1.13504 L .78154 1.15129 L 0 0 .437 r
F
.7716 1.13504 m .77169 1.13525 L .77183 1.13548 L F
.77169 1.13525 m .77502 1.14282 L .77733 1.14582 L F
.7716 1.13504 m .77174 1.13623 L .77421 1.13995 L .654 .049 .599 r
F
.7716 1.13504 m .77421 1.13995 L .77738 1.14474 L F
.7716 1.13504 m .77183 1.13548 L .77183 1.13549 L 0 0 .437 r
F
.7716 1.13504 m .77183 1.13549 L .78154 1.15129 L F
.77421 1.13995 m .77733 1.14582 L .77738 1.14474 L .654 .049 .599 r
F
.77174 1.13623 m .77733 1.14582 L .77421 1.13995 L F
.77183 1.13548 m .77733 1.14582 L .78154 1.15129 L 0 0 .437 r
F
.77169 1.13525 m .77733 1.14582 L .77183 1.13548 L F
.78154 1.15129 m .78675 1.16194 L .79647 1.17922 L 0 0 .375 r
F
.78675 1.16194 m .78689 1.16219 L .79647 1.17922 L F
.79647 1.17922 m .79141 1.1707 L .80178 1.18882 L 0 0 .325 r
F
.79141 1.1707 m .79138 1.17064 L .80178 1.18882 L F
.79647 1.17922 m .80178 1.18882 L .81154 1.20781 L F
.80178 1.18882 m .80187 1.18899 L .81154 1.20781 L F
.81154 1.20781 m .81678 1.21595 L .82676 1.23707 L .648 0 0 r
F
.81678 1.21595 m .81684 1.21606 L .82676 1.23707 L F
.82676 1.23707 m .83178 1.24344 L .84213 1.26701 L .682 0 0 r
F
.83178 1.24344 m .8318 1.24346 L .83183 1.24353 L F
.83178 1.24344 m .83183 1.24353 L .84213 1.26701 L F
.84213 1.26701 m .84683 1.27138 L .85766 1.29765 L .708 0 0 r
F
.84683 1.27138 m .84766 1.27216 L .84904 1.27568 L F
.84683 1.27138 m .84904 1.27568 L .85766 1.29765 L F
.84683 1.27138 m .84904 1.27568 L .84905 1.27547 L .591 .026 .588 r
F
.84683 1.27138 m .84905 1.27547 L .85219 1.19123 L F
.84213 1.26701 m .83447 1.24863 L .84683 1.27138 L .708 0 0 r
F
.83447 1.24863 m .83441 1.24849 L .84683 1.27138 L F
.83178 1.24344 m .83442 1.24822 L .8374 1.17102 L .599 .028 .59 r
F
.82676 1.23707 m .81997 1.22204 L .83178 1.24344 L .682 0 0 r
F
.81997 1.22204 m .81992 1.22193 L .83178 1.24344 L F
.81678 1.21595 m .81993 1.22157 L .82272 1.15156 L .608 .032 .592 r
F
.81154 1.20781 m .80562 1.19608 L .81678 1.21595 L .648 0 0 r
F
.80562 1.19608 m .80557 1.19599 L .81678 1.21595 L F
.80178 1.18882 m .80559 1.19548 L .80816 1.13292 L .62 .036 .594 r
F
.78684 1.16272 m .79041 1.19342 L .79138 1.17064 L .635 .041 .596 r
F
.78154 1.15129 m .77737 1.14587 L .78675 1.16194 L 0 0 .375 r
F
.77737 1.14587 m .77733 1.14582 L .78675 1.16194 L F
.77174 1.13623 m .7762 1.1721 L .77733 1.14582 L .654 .049 .599 r
F
.76675 1.12406 m .7635 1.12147 L .7716 1.13504 L 0 0 .437 r
F
.7635 1.12147 m .76347 1.12145 L .7716 1.13504 L F
.75642 1.10957 m .7621 1.15213 L .76347 1.12145 L .677 .058 .602 r
F
.7521 1.09761 m .74983 1.09732 L .75617 1.10772 L 0 0 .507 r
F
.74036 1.07947 m .74077 1.08235 L .74979 1.09731 L .705 .071 .606 r
F
.74077 1.08235 m .74812 1.1337 L .74979 1.09731 L F
.74077 1.08235 m .74979 1.09731 L .74979 1.09731 L F
.74036 1.07947 m .74979 1.09731 L .75107 1.06956 L F
.74036 1.07947 m .74979 1.09731 L .74985 1.09732 L 0 0 .578 r
F
.7378 1.07254 m .74036 1.07947 L .7521 1.09761 L F
.74036 1.07947 m .74985 1.09732 L .7521 1.09761 L F
.72365 1.04895 m .73681 1.07326 L .72396 1.04945 L 0 0 .639 r
F
.72396 1.04945 m .72829 1.05981 L .73657 1.07344 L .737 .089 .612 r
F
.73657 1.07344 m .73306 1.07602 L .74017 1.07938 L 0 0 .578 r
F
.73657 1.07344 m .74017 1.07938 L .74036 1.07947 L F
.72475 1.08763 m .70795 1.19615 L .7347 1.1053 L 1 .231 .584 r
F
.7347 1.1053 m .70795 1.19615 L .7168 1.21913 L 1 .23 .583 r
F
.71944 1.05653 m .72398 1.06644 L .73306 1.07602 L 0 0 .548 r
F
.72783 1.05905 m .73446 1.1173 L .7363 1.07895 L .737 .089 .612 r
F
.72366 1.04926 m .72429 1.05322 L .72783 1.05905 L F
.72429 1.05322 m .73446 1.1173 L .72783 1.05905 L F
.72829 1.05981 m .7363 1.07895 L .73657 1.07344 L F
.74036 1.07947 m .73446 1.1173 L .74812 1.1337 L .705 .071 .606 r
F
.73657 1.07344 m .73446 1.1173 L .74036 1.07947 L F
.7378 1.07254 m .73657 1.07344 L .74036 1.07947 L 0 0 .578 r
F
.72497 1.05139 m .73657 1.07344 L .73681 1.07326 L 0 0 .639 r
F
.72366 1.04926 m .7363 1.07895 L .72396 1.04945 L .737 .089 .612 r
F
.72349 1.02483 m .72365 1.04872 L .7378 1.07254 L .157 0 .621 r
F
.72365 1.04872 m .72365 1.04878 L .72374 1.04892 L F
.72365 1.04872 m .72374 1.04892 L .7378 1.07254 L F
.72365 1.04878 m .72396 1.04945 L .7378 1.07254 L F
.72365 1.04878 m .7237 1.04892 L .72372 1.04894 L .836 .104 .591 r
F
.72365 1.04878 m .72365 1.04889 L .7237 1.04892 L F
.72365 1.04889 m .72366 1.04926 L .72396 1.04945 L F
.72396 1.04945 m .73681 1.07326 L .7378 1.07254 L 0 0 .639 r
F
.70657 .92274 m .72349 1.02483 L .71917 .99323 L .521 .004 .553 r
F
.70129 .83902 m .70558 .92119 L .70129 .83907 L .965 .081 .524 r
F
.70558 .92119 m .70558 .92119 L .70129 .83907 L F
.70146 .84799 m .70228 .8631 L .70129 .83902 L F
.70233 .86375 m .70875 .98184 L .70324 .87641 L F
.70232 .86371 m .70875 .98184 L .70233 .86375 L F
.70228 .8631 m .70324 .87641 L .70129 .83902 L F
.69731 .84843 m .69906 .85086 L .69799 .98304 L .938 0 .23 r
F
.70272 .88525 m .70799 .97434 L .70325 .90414 L .715 .021 .524 r
F
.70191 .86519 m .70241 .87409 L .70163 .8668 L F
.70241 .87409 m .70799 .97434 L .70272 .88525 L F
.70241 .87409 m .70272 .88525 L .70163 .8668 L F
.70558 .92119 m .70875 .98184 L .70558 .92119 L .965 .081 .524 r
F
.70073 .84118 m .70201 .86465 L .70031 .83646 L .715 .021 .524 r
F
.70201 .86465 m .70799 .97434 L .70191 .86519 L F
.70201 .86465 m .70191 .86519 L .70031 .83646 L F
.70163 .8668 m .70272 .88525 L .70325 .90412 L F
.69969 .82052 m .70093 .84358 L .69971 .82251 L F
.70093 .84358 m .70799 .97434 L .70073 .84118 L F
.70093 .84358 m .70073 .84118 L .69971 .82251 L F
.699 .80273 m .70146 .84799 L .70129 .83908 L .965 .081 .524 r
F
.70129 .839 m .70129 .83908 L .70129 .83902 L F
.699 .80273 m .70129 .83908 L .70129 .839 L F
.70119 .83839 m .69906 .7987 L .70129 .83898 L 1 .02 .248 r
F
.70129 .83898 m .69906 .7987 L .70129 .83899 L F
.69971 .82251 m .70073 .84118 L .70031 .83646 L .715 .021 .524 r
F
.69799 .98304 m .69911 .85075 L .70325 .90414 L 1 .098 .322 r
F
.69911 .85075 m .6994 .81612 L .70078 .84778 L F
.69911 .85075 m .70078 .84778 L .70325 .90414 L F
.67661 .89054 m .69917 .89581 L .68588 .9051 L .339 0 0 r
F
.6741 .88659 m .67803 .88804 L .67661 .89054 L F
.67803 .88804 m .69917 .89581 L .67661 .89054 L F
.69842 .82198 m .69842 .82163 L .70119 .83839 L 1 .02 .248 r
F
.69933 .81383 m .69969 .82052 L .69971 .82251 L .715 .021 .524 r
F
.69842 .82163 m .69892 .79622 L .70119 .83839 L 1 .02 .248 r
F
.69853 .82263 m .70129 .83898 L .69885 .82273 L F
.70129 .83898 m .70129 .83899 L .70129 .83898 L F
.70129 .83898 m .70129 .83898 L .69885 .82273 L F
.69906 .7987 m .69906 .79865 L .70129 .83899 L F
.69926 .82447 m .7004 .8331 L .70116 .83244 L .07 0 .519 r
F
.69885 .82274 m .69948 .82692 L .69926 .82447 L F
.69948 .82692 m .7004 .8331 L .69926 .82447 L F
.69949 .87903 m .70496 .87268 L .70527 .87371 L .053 0 0 r
F
.68692 .8906 m .69968 .87793 L .69949 .87903 L F
.69968 .87793 m .70496 .87268 L .69949 .87903 L F
.70799 .97434 m .70802 .97495 L .70632 .95195 L .715 .021 .524 r
F
.70753 .98257 m .70879 .98507 L .70855 .98196 L .941 .159 .6 r
F
.70812 .9768 m .7079 .99482 L .70922 .99707 L .715 .021 .524 r
F
.70714 .97872 m .7079 .99482 L .70714 .97872 L .572 .013 .567 r
F
.70713 .97859 m .7079 .99482 L .70812 .9768 L .715 .021 .524 r
F
.70802 .97495 m .70922 .99707 L .70654 .95534 L F
.70802 .97495 m .70654 .95534 L .70632 .95195 L F
.70855 .98196 m .70879 .98507 L .70875 .98184 L .941 .159 .6 r
F
.70799 .97434 m .70632 .95195 L .70325 .90412 L .715 .021 .524 r
F
.7046 .97431 m .7079 .99482 L .70714 .97872 L .572 .013 .567 r
F
.7046 .97431 m .70232 .98669 L .7079 .99482 L F
.70326 .90419 m .70922 .99708 L .72349 1.02483 L .521 .004 .553 r
F
.70558 .98707 m .70657 .92276 L .71139 .9897 L 1 .132 .385 r
F
.7046 .97431 m .70423 .97367 L .70456 .97454 L 1 .392 .621 r
F
.69923 .98419 m .70431 .94171 L .70558 .98707 L 1 .132 .385 r
F
.70431 .94171 m .70657 .92276 L .70558 .98707 L F
.70326 .90419 m .70629 .9223 L .70657 .92274 L .521 .004 .553 r
F
.70431 .94171 m .70326 .9042 L .70657 .92276 L 1 .132 .385 r
F
.69923 .98419 m .70325 .90422 L .70431 .94171 L F
.70325 .90422 m .70326 .9042 L .70431 .94171 L F
.70272 .88525 m .70325 .90414 L .70325 .90412 L .715 .021 .524 r
F
.70031 .83646 m .70191 .86519 L .70163 .8668 L F
.68692 .8906 m .69612 .8776 L .70013 .87537 L .053 0 0 r
F
.69968 .87793 m .70013 .87537 L .70496 .87268 L F
.68692 .8906 m .70013 .87537 L .69968 .87793 L F
.70129 .8391 m .72198 .97863 L .7154 .87598 L .942 .084 .535 r
F
.70527 .87371 m .70496 .87268 L .70856 .87068 L .053 0 0 r
F
.70228 .8631 m .70232 .86371 L .70233 .86375 L .965 .081 .524 r
F
.71139 .9897 m .70657 .92276 L .71917 .99323 L 1 .132 .385 r
F
.69881 .82248 m .70004 .79737 L .7062 .8386 L .909 .01 .405 r
F
.70103 .82574 m .70106 .82739 L .70406 .82991 L .07 0 .519 r
F
.70106 .82739 m .70116 .83244 L .70275 .83106 L F
.70106 .82739 m .70275 .83106 L .70406 .82991 L F
.69885 .82274 m .70116 .83244 L .70103 .82574 L F
.7004 .8331 m .70129 .83902 L .70203 .83658 L F
.7004 .8331 m .70203 .83658 L .70406 .82991 L F
.69731 .84843 m .69849 .82901 L .69906 .85086 L .938 0 .23 r
F
.69849 .82901 m .69923 .83059 L .69906 .85086 L F
.68123 .89475 m .6741 .88659 L .68588 .9051 L 0 0 .543 r
F
.68578 .89031 m .68558 .89023 L .67301 .88514 L .364 .11 .865 r
F
.68578 .89031 m .69612 .8776 L .68692 .8906 L 0 0 0 r
F
.68578 .89031 m .69497 .87865 L .69612 .8776 L F
.67312 .88519 m .68578 .89031 L .68692 .8906 L 0 0 .712 r
F
.67302 .88515 m .67311 .88519 L .67312 .88519 L F
.67311 .88519 m .68578 .89031 L .67312 .88519 L F
.67301 .88514 m .67643 .88653 L .67302 .88515 L F
.67643 .88653 m .68578 .89031 L .67302 .88515 L F
.6741 .88659 m .68463 .88989 L .68577 .89035 L .339 0 0 r
F
.6741 .88659 m .68808 .89109 L .68564 .89083 L F
.67301 .88514 m .67312 .88519 L .6741 .88659 L 0 0 .712 r
F
.67312 .88519 m .68692 .8906 L .6741 .88659 L F
.67312 .88519 m .6741 .88659 L .6741 .88659 L F
.67404 .88621 m .67301 .88514 L .6741 .88659 L .383 0 .523 r
F
.6741 .88659 m .67301 .88514 L .6741 .88659 L F
.67292 .87884 m .67301 .88514 L .67404 .88621 L F
.67301 .88514 m .67301 .88514 L .67404 .88621 L F
.6493 .81936 m .67301 .88514 L .67104 .871 L .293 0 .587 r
F
.6516 .7883 m .67104 .871 L .65437 .75082 L F
.6493 .81936 m .67104 .871 L .6516 .7883 L F
.65452 .75736 m .67208 .87871 L .67292 .87884 L .383 0 .523 r
F
.67208 .87871 m .67301 .88514 L .67292 .87884 L F
.66583 .87771 m .67301 .88514 L .67301 .88514 L .364 .11 .865 r
F
.66949 .90106 m .65526 .94136 L .6705 .90256 L .755 .071 .587 r
F
.6624 .89052 m .65432 .93856 L .66949 .90106 L .668 .048 .591 r
F
.66949 .90106 m .65432 .93857 L .65526 .94136 L .755 .071 .587 r
F
.66221 .90973 m .68094 .92393 L .67459 .9001 L 1 .528 .687 r
F
.66221 .90973 m .6681 .93175 L .68094 .92393 L F
.65166 .8752 m .64774 .91849 L .66239 .89052 L .567 .03 .609 r
F
.6624 .89052 m .64774 .9185 L .65432 .93856 L .668 .048 .591 r
F
.65393 .89525 m .67459 .9001 L .66581 .89085 L 1 .738 .726 r
F
.65393 .89525 m .66221 .90973 L .67459 .9001 L F
.6606 .85072 m .66542 .87745 L .67301 .88514 L .293 0 .587 r
F
.6493 .81936 m .65647 .8452 L .66032 .85034 L F
.6493 .81936 m .66032 .85034 L .66 .84905 L F
.62923 .94038 m .64499 .95656 L .6422 .93839 L .798 .357 .744 r
F
.62482 .92661 m .62923 .94038 L .6422 .93839 L .911 .447 .743 r
F
.66 .84905 m .66032 .85034 L .6606 .85072 L .293 0 .587 r
F
.65647 .8452 m .66542 .87745 L .6606 .85072 L F
.6571 .87638 m .6657 .87772 L .66542 .87745 L .664 .35 .791 r
F
.65516 .93583 m .67161 .96257 L .6681 .93175 L .741 .212 .698 r
F
.64977 .91665 m .65516 .93583 L .6681 .93175 L 1 .458 .711 r
F
.64977 .91665 m .6681 .93175 L .66221 .90973 L F
.6421 .90115 m .64977 .91665 L .66221 .90973 L 1 .584 .728 r
F
.6421 .90115 m .66221 .90973 L .65393 .89525 L F
.64314 .87878 m .65393 .89525 L .66581 .89085 L .87 .437 .751 r
F
.64314 .87878 m .66581 .89085 L .65418 .87456 L F
.63987 .83587 m .63034 .85093 L .64097 .86179 L .787 .254 .703 r
F
.63972 .8424 m .66542 .87745 L .64929 .81937 L .426 .023 .678 r
F
.63972 .8424 m .65418 .87456 L .66542 .87745 L F
.65132 .91197 m .67453 .9449 L .66593 .86585 L .705 .126 .655 r
F
.65301 .8354 m .66593 .86585 L .65463 .76199 L F
.64097 .86179 m .62817 .87156 L .63786 .89105 L .55 .057 .657 r
F
.6322 .88608 m .6421 .90115 L .65393 .89525 L .968 .485 .739 r
F
.6322 .88608 m .65393 .89525 L .64314 .87878 L F
.63034 .85093 m .62817 .87156 L .64097 .86179 L .586 .147 .72 r
F
.62999 .85821 m .64314 .87878 L .65418 .87456 L .736 .25 .719 r
F
.62999 .85821 m .65418 .87456 L .63972 .8424 L F
.65132 .91197 m .66593 .86585 L .65301 .8354 L .705 .126 .655 r
F
.66578 .85764 m .66616 .86647 L .66693 .86782 L .525 0 .514 r
F
.66512 .85675 m .66616 .86647 L .66578 .85764 L F
.66266 .85555 m .66294 .85659 L .66269 .85591 L F
.66117 .83764 m .66294 .85659 L .66266 .85555 L F
.65907 .81223 m .66126 .83743 L .66117 .83764 L F
.66126 .83743 m .66294 .85659 L .66117 .83764 L F
.65916 .81211 m .66294 .85659 L .65907 .81223 L F
.65453 .75752 m .66512 .85675 L .66578 .85764 L F
.65453 .75752 m .66693 .86782 L .66294 .85659 L F
.64997 .80852 m .65336 .82222 L .65368 .80839 L 1 .276 .457 r
F
.65014 .80692 m .65368 .80839 L .65468 .76431 L F
.64997 .80852 m .65368 .80839 L .65014 .80692 L F
.6373 .92203 m .6422 .93839 L .65516 .93583 L .952 .438 .728 r
F
.62482 .92661 m .6422 .93839 L .6373 .92203 L .911 .447 .743 r
F
.6373 .92203 m .65516 .93583 L .64977 .91665 L .952 .438 .728 r
F
.6303 .90756 m .6373 .92203 L .64977 .91665 L 1 .523 .734 r
F
.6303 .90756 m .64977 .91665 L .6421 .90115 L F
.62129 .89433 m .6303 .90756 L .6421 .90115 L 1 .518 .739 r
F
.62129 .89433 m .6421 .90115 L .6322 .88608 L F
.62021 .87126 m .6322 .88608 L .64314 .87878 L .953 .444 .73 r
F
.64218 .8209 m .63972 .8424 L .64929 .81935 L 1 .423 .621 r
F
.62842 .83084 m .63034 .85093 L .63987 .83587 L .796 .348 .742 r
F
.62842 .83084 m .61974 .8425 L .63034 .85093 L F
.61698 .82673 m .61974 .8425 L .62842 .83084 L .806 .456 .778 r
F
.62255 .82516 m .63444 .83709 L .64218 .8209 L 1 .423 .621 r
F
.63444 .83709 m .63972 .8424 L .64218 .8209 L F
.64541 .87837 m .65336 .82222 L .65012 .80914 L 1 .276 .457 r
F
.61851 .95434 m .61878 .9657 L .63202 .96866 L .755 .382 .768 r
F
.61851 .95434 m .63202 .96866 L .63174 .95512 L F
.61628 .94223 m .61851 .95434 L .63174 .95512 L .819 .415 .759 r
F
.61628 .94223 m .63174 .95512 L .62923 .94038 L F
.6422 .93839 m .64499 .95656 L .65827 .95889 L .775 .29 .724 r
F
.6422 .93839 m .65827 .95889 L .65516 .93583 L F
.61878 .9657 m .61708 .97561 L .63008 .97978 L .718 .393 .786 r
F
.60556 .96367 m .61708 .97561 L .61878 .9657 L .774 .46 .79 r
F
.61878 .9657 m .63008 .97978 L .63202 .96866 L .718 .393 .786 r
F
.61623 .97249 m .63197 .96439 L .6332 .96212 L 1 .813 .682 r
F
.61623 .97249 m .6332 .96212 L .64182 .94622 L F
.62074 .96786 m .64182 .94622 L .625 .96485 L F
.60097 .98012 m .60802 .99088 L .61347 .98389 L .784 .57 .821 r
F
.60097 .98012 m .59624 .98703 L .60802 .99088 L F
.6041 .97238 m .61347 .98389 L .61708 .97561 L .771 .504 .805 r
F
.6041 .97238 m .60097 .98012 L .61347 .98389 L F
.60556 .96367 m .6041 .97238 L .61708 .97561 L .774 .46 .79 r
F
.58443 .98314 m .59 .99343 L .59624 .98703 L .846 .621 .815 r
F
.58846 .97676 m .59624 .98703 L .60097 .98012 L .828 .581 .809 r
F
.58846 .97676 m .58443 .98314 L .59624 .98703 L F
.59109 .98598 m .60749 .98021 L .61623 .97249 L .737 .269 .805 r
F
.58443 .98314 m .57911 .98907 L .59 .99343 L .846 .621 .815 r
F
.59202 .98657 m .60711 .98037 L .59109 .98598 L .801 .596 .85 r
F
.60711 .98037 m .60706 .98036 L .59109 .98598 L F
.59348 .9847 m .61623 .97249 L .5984 .9836 L .737 .269 .805 r
F
.59021 .98542 m .59109 .98598 L .5984 .9836 L .279 0 .725 r
F
.56818 .98443 m .57259 .99467 L .57911 .98907 L .876 .622 .806 r
F
.5726 .97924 m .57911 .98907 L .58443 .98314 L .865 .608 .805 r
F
.5726 .97924 m .56818 .98443 L .57911 .98907 L F
.57305 .98924 m .59109 .98598 L .59021 .98542 L .279 0 .725 r
F
.58383 .98994 m .59202 .98657 L .59109 .98598 L .801 .596 .85 r
F
.60711 .98037 m .60749 .98021 L .60706 .98036 L F
.5984 .9836 m .60432 .97991 L .60078 .98193 L .611 0 .66 r
F
.60432 .97991 m .61623 .97249 L .60413 .97988 L F
.60432 .97991 m .60413 .97988 L .60078 .98193 L F
.60078 .98193 m .61623 .97249 L .625 .96485 L F
.625 .96485 m .64182 .94622 L .65132 .91199 L 1 .57 .559 r
F
.625 .96485 m .65132 .91199 L .63386 .95988 L F
.63386 .95988 m .65132 .91197 L .65336 .82222 L 1 .276 .457 r
F
.61861 .85851 m .61309 .86267 L .62817 .87156 L .217 .012 .846 r
F
.63034 .85093 m .61861 .85851 L .62817 .87156 L .586 .147 .72 r
F
.62021 .87126 m .64314 .87878 L .62999 .85821 L .953 .444 .73 r
F
.64776 .82932 m .64806 .82643 L .64787 .82958 L 1 .276 .457 r
F
.66506 1.00277 m .64904 .97936 L .65507 .97237 L .712 0 .284 r
F
.64499 .95656 m .6453 .97287 L .65863 .97882 L .649 .216 .734 r
F
.64499 .95656 m .65863 .97882 L .65827 .95889 L F
.63197 .96439 m .65606 .95832 L .64183 .94622 L 1 .947 .766 r
F
.64806 .82643 m .64872 .82809 L .6398 .96071 L 1 .276 .457 r
F
.65014 .80692 m .65025 .80723 L .64884 .82798 L F
.64874 .82773 m .64884 .82798 L .6398 .96071 L F
.65014 .80692 m .64884 .82798 L .64874 .82773 L F
.65647 .81449 m .66269 .85591 L .66268 .85589 L .383 0 .523 r
F
.65651 .81539 m .66268 .85589 L .6574 .84169 L F
.65647 .81449 m .66268 .85589 L .65651 .81539 L F
.66267 .85589 m .6627 .85595 L .65847 .84411 L 0 0 .543 r
F
.65453 .75752 m .65916 .81211 L .65907 .81223 L .525 0 .514 r
F
.65452 .75736 m .6741 .88659 L .66269 .85591 L .383 0 .523 r
F
.6741 .88659 m .67391 .88609 L .6574 .84169 L F
.6627 .85595 m .66965 .87464 L .66301 .85651 L 0 0 .543 r
F
.65906 .81224 m .66269 .85591 L .65644 .81336 L .383 0 .523 r
F
.66173 .84433 m .66269 .85591 L .66034 .83968 L .525 0 .514 r
F
.66173 .84433 m .66034 .83968 L .65679 .81524 L F
.65454 .75788 m .65906 .81224 L .65644 .81336 L .383 0 .523 r
F
.65454 .75788 m .66173 .84433 L .65679 .81524 L .525 0 .514 r
F
.66965 .87464 m .67001 .87548 L .66307 .85661 L 0 0 .543 r
F
.65453 .75752 m .66269 .85591 L .65454 .75788 L .525 0 .514 r
F
.65452 .75736 m .66269 .85591 L .65454 .75788 L .383 0 .523 r
F
.66033 .83967 m .6627 .85595 L .66803 .86539 L .471 0 .531 r
F
.65661 .81454 m .66269 .85591 L .65647 .81449 L .383 0 .523 r
F
.66301 .85651 m .66307 .85661 L .65847 .84411 L 0 0 .543 r
F
.66965 .87464 m .66307 .85661 L .66301 .85651 L F
.65847 .84411 m .66766 .8691 L .67078 .87454 L F
.66803 .86539 m .67078 .87454 L .67706 .88548 L F
.65847 .84411 m .67078 .87454 L .66803 .86539 L F
.66922 .88824 m .67453 .9449 L .67559 .94483 L .525 0 .514 r
F
.66693 .86782 m .6689 .88779 L .66922 .88824 L F
.6689 .88779 m .67453 .9449 L .66922 .88824 L F
.69518 .92423 m .68588 .9051 L .69781 .92493 L .992 .001 .255 r
F
.66616 .86647 m .67453 .9449 L .66693 .86782 L .525 0 .514 r
F
.66693 .86782 m .66922 .88824 L .6627 .85596 L F
.66922 .88824 m .67559 .94483 L .66766 .89017 L F
.66922 .88824 m .66766 .89017 L .6627 .85596 L F
.66766 .8691 m .67359 .88522 L .67704 .88548 L 0 0 .543 r
F
.66766 .8691 m .67704 .88548 L .67706 .88548 L F
.66693 .86782 m .6627 .85596 L .66269 .85591 L .525 0 .514 r
F
.66803 .86539 m .66273 .85621 L .67369 .89855 L .471 0 .531 r
F
.69799 .98304 m .70325 .90414 L .69922 .98418 L 1 .098 .322 r
F
.70658 .94441 m .69781 .92493 L .70983 .9439 L .936 0 .294 r
F
.67729 .90667 m .67503 .90375 L .68712 .95049 L .471 0 .531 r
F
.67019 .88505 m .67631 .94518 L .68712 .95049 L F
.66273 .85621 m .66598 .87748 L .67019 .88505 L F
.66598 .87748 m .67631 .94518 L .67019 .88505 L F
.66273 .85621 m .67559 .94483 L .67631 .94518 L F
.67628 .90216 m .67369 .89855 L .67503 .90375 L F
.67628 .90216 m .67503 .90375 L .67729 .90667 L F
.66965 .87464 m .67359 .88522 L .67001 .87548 L 0 0 .543 r
F
.66803 .86539 m .67369 .89855 L .67628 .90216 L .471 0 .531 r
F
.66411 .85845 m .66446 .85919 L .66803 .86539 L F
.6627 .85595 m .66446 .85919 L .66411 .85845 L F
.6627 .85595 m .66273 .85621 L .66446 .85919 L F
.6627 .85595 m .66301 .85651 L .65847 .84411 L 0 0 .543 r
F
.65741 .84174 m .66267 .85589 L .65847 .84411 L F
.65797 .8453 m .66856 .86799 L .66893 .88878 L F
.66188 .86983 m .66893 .88878 L .66944 .91737 L F
.65797 .8453 m .66893 .88878 L .66188 .86983 L F
.66856 .86799 m .66927 .87149 L .66944 .91737 L F
.67825 .91394 m .68712 .95049 L .67853 .9161 L .471 0 .531 r
F
.67712 .90927 m .67825 .91394 L .67737 .91145 L F
.6995 .94552 m .69473 .92914 L .70658 .94441 L .936 0 .294 r
F
.68577 .92625 m .6802 .91843 L .68157 .92181 L .276 0 .569 r
F
.6866 .92867 m .68157 .92181 L .69897 .96483 L F
.68577 .92625 m .68157 .92181 L .6866 .92867 L F
.74017 .89331 m .7245 .97283 L .73534 .98498 L 1 .259 .594 r
F
.72865 .88757 m .7245 .97283 L .74017 .89331 L 1 .253 .596 r
F
.7154 .87598 m .72198 .97863 L .73544 .98246 L .862 .081 .559 r
F
.71352 .96537 m .70984 .9439 L .72213 .96243 L .905 0 .302 r
F
.6802 .91843 m .69583 .96103 L .69897 .96483 L .276 0 .569 r
F
.66927 .87149 m .67737 .91145 L .66944 .91737 L 0 0 .543 r
F
.66925 .87083 m .67396 .89183 L .66639 .86508 L .471 0 .531 r
F
.67396 .89183 m .68712 .95049 L .67594 .90445 L F
.66128 .85999 m .6684 .87552 L .6684 .87552 L .717 0 0 r
F
.67396 .89183 m .67594 .90445 L .67095 .88387 L .471 0 .531 r
F
.67347 .89028 m .67095 .88387 L .66938 .87741 L F
.67396 .89183 m .67095 .88387 L .67347 .89028 L F
.67396 .89183 m .66938 .87741 L .67048 .87952 L F
.67957 .91468 m .68019 .91212 L .68406 .92127 L .992 .001 .255 r
F
.68019 .91212 m .68101 .90873 L .68406 .92127 L F
.67737 .91145 m .67973 .91777 L .6802 .91843 L .276 0 .569 r
F
.68406 .92127 m .67737 .91145 L .6802 .91843 L F
.67825 .91394 m .67853 .9161 L .67737 .91145 L .471 0 .531 r
F
.67737 .91145 m .68712 .95049 L .69583 .96103 L .276 0 .569 r
F
.67737 .91145 m .68101 .90873 L .67835 .91974 L .992 .001 .255 r
F
.67599 .90464 m .67712 .90927 L .67737 .91145 L .471 0 .531 r
F
.6741 .88659 m .6741 .88659 L .67391 .88609 L .383 0 .523 r
F
.67394 .88616 m .6741 .88659 L .68123 .89475 L 0 0 .543 r
F
.67706 .88548 m .67394 .88616 L .68123 .89475 L F
.67359 .88522 m .67394 .88616 L .67706 .88548 L F
.66926 .86949 m .68101 .90873 L .67737 .91145 L F
.66926 .86949 m .67737 .91145 L .66927 .87149 L F
.66639 .86508 m .67164 .8867 L .6684 .87553 L .471 0 .531 r
F
.67164 .8867 m .67594 .90445 L .6684 .87553 L F
.66926 .86949 m .68588 .9051 L .68101 .90873 L 0 0 .543 r
F
.6684 .87553 m .67617 .89823 L .67939 .90289 L .276 0 .569 r
F
.67617 .89823 m .67737 .91145 L .68406 .92127 L F
.67594 .90445 m .67649 .90791 L .6684 .87553 L .471 0 .531 r
F
.6684 .87553 m .67145 .88772 L .67617 .89823 L .276 0 .569 r
F
.67594 .90445 m .67599 .90464 L .67649 .90791 L .471 0 .531 r
F
.67599 .90464 m .67737 .91145 L .67649 .90791 L F
.67145 .88772 m .67737 .91145 L .67617 .89823 L .276 0 .569 r
F
.66537 .86967 m .6663 .87148 L .67939 .90289 L .717 0 0 r
F
.6663 .87148 m .6684 .87552 L .67938 .90288 L F
.66128 .85999 m .6684 .87552 L .66537 .86967 L F
.65516 .93583 m .65827 .95889 L .67161 .96257 L .741 .212 .698 r
F
.65132 .91197 m .66713 .94809 L .67453 .9449 L .705 .126 .655 r
F
.64183 .94622 m .66713 .94809 L .65132 .91198 L 1 .694 .741 r
F
.64183 .94622 m .65606 .95832 L .66713 .94809 L F
.64065 .96119 m .65741 .84178 L .66943 .91738 L .979 .032 .442 r
F
.65789 .85128 m .6684 .87552 L .66128 .85999 L .717 0 0 r
F
.65058 .80277 m .65468 .76431 L .65199 .79972 L 1 .276 .457 r
F
.65058 .80277 m .65199 .79972 L .65122 .81001 L F
.65027 .8073 m .65122 .81001 L .6398 .96071 L F
.65058 .80277 m .65122 .81001 L .65027 .8073 L F
.6398 .96071 m .65112 .80995 L .6574 .84172 L 1 .174 .454 r
F
.65112 .80995 m .65465 .76303 L .65645 .81444 L F
.65112 .80995 m .65645 .81444 L .6574 .84172 L F
.64806 .82643 m .65014 .80692 L .64872 .82809 L 1 .276 .457 r
F
.65051 .80348 m .65054 .80342 L .65027 .8073 L F
.65025 .80723 m .65027 .8073 L .6398 .96071 L F
.65051 .80348 m .65027 .8073 L .65025 .80723 L F
.6553 .81409 m .65494 .81397 L .6519 .81197 L 1 .189 .445 r
F
.65186 .81185 m .6519 .81197 L .63747 .8025 L F
.6553 .81409 m .6519 .81197 L .65186 .81185 L F
.63929 .80238 m .65173 .81148 L .63703 .80144 L F
.65173 .81148 m .6553 .81409 L .65179 .81166 L F
.65173 .81148 m .65179 .81166 L .63703 .80144 L F
.6398 .96071 m .65567 .8534 L .64065 .96119 L 1 .174 .454 r
F
.65567 .8534 m .6574 .84172 L .65575 .85353 L F
.65567 .8534 m .65575 .85353 L .64065 .96119 L F
.67108 .88295 m .67939 .90289 L .67939 .90289 L 0 0 .363 r
F
.65615 .8471 m .67108 .88295 L .67108 .88295 L F
.67108 .88295 m .67939 .90289 L .67108 .88295 L F
.68406 .92127 m .68101 .90873 L .69144 .92323 L .992 .001 .255 r
F
.67973 .91777 m .69583 .96103 L .6802 .91843 L .276 0 .569 r
F
.68406 .92127 m .6802 .91843 L .68577 .92625 L F
.67835 .91974 m .68406 .92127 L .68225 .94462 L .992 .001 .255 r
F
.68464 .92142 m .69144 .92323 L .68855 .92996 L F
.68406 .92127 m .68577 .92625 L .68981 .93586 L .276 0 .569 r
F
.68577 .92625 m .69897 .96483 L .68981 .93586 L F
.68246 .94593 m .68981 .93586 L .68275 .94814 L .936 0 .294 r
F
.70941 .96676 m .70427 .95277 L .71352 .96537 L .905 0 .302 r
F
.69748 .94895 m .69897 .96483 L .71106 .98352 L .041 0 .559 r
F
.69702 .94779 m .69709 .94836 L .69748 .94895 L F
.69709 .94836 m .69897 .96483 L .69748 .94895 L F
.75166 .89877 m .73534 .98498 L .74617 .99684 L 1 .263 .591 r
F
.74017 .89331 m .73534 .98498 L .75166 .89877 L 1 .259 .594 r
F
.72198 .97863 m .7373 1.05812 L .73544 .98246 L .836 .104 .591 r
F
.72212 .98636 m .72213 .96243 L .73454 .98068 L .889 0 .305 r
F
.69877 .95224 m .71106 .98352 L .70388 .96337 L .041 0 .559 r
F
.70232 .98669 m .70809 1.00775 L .7079 .99482 L .413 .007 .64 r
F
.69894 .98938 m .70809 1.00775 L .70178 .98712 L .964 .189 .613 r
F
.7079 .99482 m .70867 1.00923 L .70922 .99707 L .36 .001 .64 r
F
.70867 1.00923 m .70943 1.01178 L .70922 .99707 L F
.7079 .99482 m .70809 1.00776 L .70867 1.00923 L F
.69923 .98419 m .71917 .99323 L .71266 1.00229 L 1 .132 .385 r
F
.66786 .97514 m .68939 .97822 L .68004 .97499 L .441 .109 .89 r
F
.68004 .97499 m .68939 .97822 L .6899 .97851 L .439 0 0 r
F
.69454 .98149 m .6899 .97851 L .69799 .98304 L F
.68004 .97499 m .6899 .97851 L .69454 .98149 L F
.68004 .97499 m .69799 .98304 L .68819 .97835 L F
.68819 .97835 m .6964 .98269 L .68936 .97907 L .628 0 0 r
F
.6964 .98269 m .69922 .98418 L .69662 .98283 L F
.6964 .98269 m .69662 .98283 L .68936 .97907 L F
.68936 .97907 m .69923 .98419 L .71266 1.00229 L .765 0 0 r
F
.73544 .98246 m .7373 1.05812 L .75107 1.06956 L .781 .082 .589 r
F
.71917 .99323 m .72349 1.02483 L .73798 1.05533 L 0 0 .548 r
F
.68936 .97907 m .69372 .98341 L .70195 .99024 L .765 0 0 r
F
.69372 .98341 m .71266 1.00229 L .70195 .99024 L F
.70195 .99024 m .71266 1.00229 L .7264 1.02663 L .77 0 0 r
F
.71244 1.00205 m .70195 .99024 L .7148 1.00686 L .036 0 .609 r
F
.70986 .99679 m .70195 .99024 L .71244 1.00205 L F
.68712 .95049 m .70195 .99024 L .70986 .99679 L F
.70195 .99024 m .7264 1.02663 L .7148 1.00686 L .77 0 0 r
F
.71917 .99323 m .73798 1.05533 L .73384 1.03448 L 0 0 .548 r
F
.71266 1.00229 m .71917 .99323 L .73384 1.03448 L 1 .005 .168 r
F
.71266 1.00229 m .73384 1.03448 L .7264 1.02663 L F
.68712 .95049 m .7148 1.00686 L .69897 .96483 L .036 0 .609 r
F
.69897 .96483 m .7148 1.00686 L .72789 1.02729 L 0 0 .553 r
F
.69897 .96483 m .72789 1.02729 L .71106 .98352 L F
.70786 .96729 m .70232 .95589 L .70941 .96676 L .905 0 .302 r
F
.69645 .94691 m .69897 .96483 L .69702 .94779 L .041 0 .559 r
F
.68981 .93586 m .69897 .96483 L .69633 .94601 L F
.69877 .95224 m .70388 .96337 L .70161 .95701 L F
.69144 .92323 m .69473 .92914 L .6907 .93465 L .992 .001 .255 r
F
.68868 .93022 m .6907 .93465 L .68246 .94593 L F
.69144 .92323 m .6907 .93465 L .68868 .93022 L F
.68745 .93253 m .68246 .94593 L .68225 .94462 L F
.69144 .92323 m .68763 .93287 L .68745 .93253 L F
.68763 .93287 m .68246 .94593 L .68745 .93253 L F
.71476 .9838 m .71106 .98353 L .72352 1.00474 L 0 0 .523 r
F
.70786 .96729 m .70388 .96338 L .71476 .9838 L F
.70161 .95701 m .70388 .96338 L .70786 .96729 L F
.70689 .96762 m .70407 .96106 L .70786 .96729 L .905 0 .302 r
F
.70407 .96106 m .70204 .95633 L .70786 .96729 L F
.70161 .95701 m .70204 .95633 L .70689 .96762 L F
.70204 .95633 m .70232 .95589 L .70786 .96729 L F
.70232 .95589 m .70427 .95277 L .70941 .96676 L F
.69124 .93392 m .69473 .92914 L .69149 .93428 L .936 0 .294 r
F
.69633 .94601 m .69149 .93428 L .6995 .94552 L F
.69149 .93428 m .69473 .92914 L .6995 .94552 L F
.68101 .90873 m .68296 .90728 L .69144 .92323 L .992 .001 .255 r
F
.67939 .9029 m .69633 .94601 L .69039 .92553 L .041 0 .559 r
F
.68819 .97835 m .69799 .98304 L .69922 .98418 L .628 0 0 r
F
.67559 .94483 m .68936 .97907 L .70195 .99024 L .213 0 .667 r
F
.67559 .94483 m .70195 .99024 L .68712 .95049 L F
.68059 .94848 m .69633 .94601 L .69171 .97279 L .936 0 .294 r
F
.69633 .94601 m .70983 .9439 L .70161 .95701 L F
.69633 .94601 m .69877 .95224 L .69774 .94896 L .041 0 .559 r
F
.69798 .9497 m .70161 .95701 L .69039 .92553 L F
.69877 .95224 m .70161 .95701 L .69798 .9497 L F
.69633 .94601 m .69645 .94691 L .69702 .94779 L F
.69633 .94601 m .70161 .95701 L .69171 .97279 L .936 0 .294 r
F
.69633 .94601 m .69774 .94896 L .69767 .94873 L .041 0 .559 r
F
.69633 .94601 m .69767 .94873 L .69039 .92553 L F
.69537 .94616 m .69337 .94005 L .69633 .94601 L .936 0 .294 r
F
.69337 .94005 m .69149 .93428 L .69633 .94601 L F
.68275 .94814 m .68982 .93692 L .69537 .94616 L F
.68982 .93692 m .69149 .93428 L .69537 .94616 L F
.70739 .96618 m .70161 .95701 L .70786 .96729 L 0 0 .523 r
F
.69039 .92554 m .70121 .95588 L .70739 .96618 L F
.70121 .95588 m .70161 .95701 L .70739 .96618 L F
.70388 .96338 m .71106 .98353 L .71476 .9838 L F
.69171 .9728 m .70161 .95701 L .70689 .96762 L .905 0 .302 r
F
.69039 .92554 m .70786 .96729 L .70163 .94689 L 0 0 .523 r
F
.69171 .9728 m .70786 .96729 L .70306 .99508 L .905 0 .302 r
F
.70803 .96723 m .72213 .96243 L .71345 .97729 L F
.71916 .98771 m .71472 .97513 L .72212 .98636 L .889 0 .305 r
F
.7154 .87598 m .73544 .98246 L .72888 .88945 L .862 .081 .559 r
F
.76313 .90402 m .74617 .99684 L .757 1.00851 L 1 .265 .589 r
F
.75166 .89877 m .74617 .99684 L .76313 .90402 L 1 .263 .591 r
F
.72888 .88945 m .73544 .98246 L .74908 .99022 L .784 .067 .572 r
F
.73544 .98246 m .75107 1.06956 L .74908 .99022 L .781 .082 .589 r
F
.73081 1.00773 m .73454 .98068 L .74707 .99897 L .883 0 .307 r
F
.71944 .98836 m .72352 1.00474 L .73616 1.0273 L 0 0 .49 r
F
.71935 .98816 m .71937 .98825 L .71944 .98836 L F
.71937 .98825 m .72352 1.00474 L .71944 .98836 L F
.77458 .90913 m .757 1.00851 L .76782 1.02007 L 1 .265 .587 r
F
.76313 .90402 m .757 1.00851 L .77458 .90913 L 1 .265 .589 r
F
.74908 .99022 m .76517 1.08326 L .76304 1.00019 L .736 .067 .589 r
F
.74908 .99022 m .75107 1.06956 L .76517 1.08326 L F
.74255 1.02786 m .74707 .99897 L .75973 1.01748 L .882 0 .309 r
F
.71956 .98863 m .73616 1.0273 L .7252 .99911 L 0 0 .49 r
F
.72349 1.02483 m .7378 1.07254 L .73798 1.05533 L .157 0 .621 r
F
.73384 1.03448 m .73798 1.05533 L .7526 1.08582 L 0 0 .469 r
F
.73384 1.03448 m .7526 1.08582 L .74845 1.06863 L F
.7264 1.02663 m .73384 1.03448 L .74845 1.06862 L .819 0 0 r
F
.7264 1.02663 m .74845 1.06862 L .74035 1.05319 L F
.7148 1.00686 m .7264 1.02663 L .74035 1.05319 L .68 0 0 r
F
.7148 1.00686 m .74035 1.05319 L .72789 1.02729 L F
.74845 1.06863 m .7526 1.08582 L .76757 1.1164 L 0 0 .424 r
F
.74845 1.06863 m .76757 1.1164 L .76335 1.10084 L F
.74035 1.05319 m .74845 1.06863 L .76335 1.10084 L .687 0 0 r
F
.72789 1.0273 m .74035 1.05319 L .75468 1.08113 L 0 0 .319 r
F
.72789 1.0273 m .75468 1.08113 L .74138 1.05059 L F
.71106 .98353 m .72789 1.0273 L .74138 1.05059 L 0 0 .503 r
F
.71106 .98353 m .74138 1.05059 L .72352 1.00474 L F
.72352 1.00474 m .74138 1.05059 L .75507 1.0756 L 0 0 .468 r
F
.72352 1.00474 m .75507 1.0756 L .73616 1.0273 L F
.73041 1.00795 m .72498 .99778 L .73081 1.00773 L .883 0 .307 r
F
.71921 .98792 m .72352 1.00474 L .71935 .98816 L 0 0 .49 r
F
.71326 .97762 m .72352 1.00474 L .71916 .98771 L F
.71956 .98863 m .7252 .99911 L .72481 .9981 L F
.71472 .97513 m .72213 .96243 L .72212 .98636 L .889 0 .305 r
F
.70821 .96813 m .72352 1.00474 L .71326 .97762 L 0 0 .523 r
F
.70306 .99508 m .71916 .98771 L .71451 1.01652 L .889 0 .305 r
F
.71916 .98771 m .73454 .98068 L .72481 .9981 L F
.71948 .98839 m .72481 .9981 L .71941 .98818 L 0 0 .49 r
F
.71956 .98863 m .72481 .9981 L .71948 .98839 L F
.71916 .98771 m .71921 .98792 L .71935 .98816 L F
.71916 .98771 m .71956 .98863 L .71941 .98817 L F
.71916 .98771 m .72481 .9981 L .71451 1.01652 L .889 0 .305 r
F
.71941 .98818 m .72481 .9981 L .71298 .96768 L 0 0 .49 r
F
.78601 .91413 m .76782 1.02007 L .77864 1.03158 L 1 .265 .586 r
F
.77458 .90913 m .76782 1.02007 L .78601 .91413 L 1 .265 .587 r
F
.76304 1.00019 m .77938 1.09858 L .7771 1.01144 L .702 .056 .589 r
F
.76304 1.00019 m .76517 1.08326 L .77938 1.09858 L F
.7536 1.04885 m .75973 1.01748 L .77252 1.03633 L .883 0 .311 r
F
.73054 1.00824 m .73616 1.0273 L .74896 1.05079 L 0 0 .468 r
F
.73052 1.00821 m .74896 1.05079 L .73638 1.01875 L F
.73798 1.05533 m .7378 1.07254 L .7521 1.09761 L 0 0 .583 r
F
.73798 1.05533 m .7521 1.09761 L .7526 1.08582 L F
.74035 1.05319 m .76335 1.10084 L .75468 1.08113 L .687 0 0 r
F
.74138 1.05059 m .75468 1.08113 L .7692 1.10977 L 0 0 .355 r
F
.74138 1.05059 m .7692 1.10977 L .75507 1.0756 L F
.73616 1.0273 m .75507 1.0756 L .76895 1.10187 L 0 0 .446 r
F
.73616 1.0273 m .76895 1.10187 L .74896 1.05079 L F
.74173 1.02835 m .73678 1.01801 L .74255 1.02786 L .882 0 .309 r
F
.78601 .91413 m .77864 1.03158 L .79743 .91904 L 1 .265 .586 r
F
.7771 1.01144 m .79372 1.11521 L .79126 1.02357 L .677 .048 .589 r
F
.7771 1.01144 m .77938 1.09858 L .79372 1.11521 L F
.765 1.07022 m .77252 1.03633 L .78545 1.0556 L .885 0 .313 r
F
.74179 1.02847 m .74896 1.05079 L .76194 1.07507 L 0 0 .454 r
F
.74181 1.02852 m .76194 1.07507 L .74805 1.03974 L F
.75507 1.0756 m .7692 1.10977 L .78389 1.13907 L 0 0 .372 r
F
.75507 1.0756 m .78389 1.13907 L .76895 1.10187 L F
.74896 1.05079 m .76895 1.10187 L .78303 1.12915 L 0 0 .431 r
F
.74896 1.05079 m .78303 1.12915 L .76194 1.07507 L F
.75325 1.04908 m .74823 1.0394 L .7536 1.04885 L .883 0 .311 r
F
.7532 1.04912 m .74805 1.03974 L .75325 1.04908 L F
.74175 1.02841 m .74896 1.05079 L .74179 1.02847 L 0 0 .454 r
F
.73638 1.01875 m .74896 1.05079 L .74173 1.02835 L F
.75326 1.04925 m .76194 1.07507 L .77508 1.10004 L 0 0 .445 r
F
.74805 1.03974 m .74823 1.0394 L .75325 1.04908 L .883 0 .311 r
F
.74823 1.0394 m .75973 1.01748 L .7536 1.04885 L F
.73678 1.01801 m .74707 .99897 L .74255 1.02786 L .882 0 .309 r
F
.73041 1.00795 m .73045 1.00809 L .73054 1.00824 L 0 0 .468 r
F
.73045 1.00809 m .73616 1.0273 L .73054 1.00824 L F
.72481 .9981 m .73616 1.0273 L .73041 1.00795 L F
.71451 1.01652 m .73041 1.00795 L .72608 1.03781 L .883 0 .307 r
F
.73041 1.00795 m .74707 .99897 L .73638 1.01875 L F
.73041 1.00795 m .73052 1.00821 L .73049 1.00808 L 0 0 .468 r
F
.72498 .99778 m .73454 .98068 L .73081 1.00773 L .883 0 .307 r
F
.73052 1.00821 m .73638 1.01875 L .72445 .98838 L 0 0 .468 r
F
.73041 1.00795 m .73638 1.01875 L .72608 1.03781 L .883 0 .307 r
F
.73041 1.00795 m .73049 1.00808 L .73048 1.00808 L 0 0 .468 r
F
.74173 1.02835 m .74175 1.02841 L .74179 1.02847 L 0 0 .454 r
F
.74173 1.02835 m .74181 1.02852 L .74178 1.02844 L F
.74173 1.02835 m .74179 1.02832 L .74178 1.02843 L .882 0 .309 r
F
.74173 1.02835 m .74178 1.02844 L .74178 1.02844 L 0 0 .454 r
F
.72608 1.03781 m .74173 1.02835 L .73779 1.05931 L .882 0 .309 r
F
.74173 1.02835 m .74178 1.02843 L .73779 1.05931 L F
.74179 1.02832 m .75973 1.01748 L .74805 1.03974 L F
.74179 1.02832 m .74805 1.03974 L .74178 1.02843 L F
.74178 1.02844 m .74805 1.03974 L .73605 1.00922 L 0 0 .454 r
F
.74181 1.02852 m .74805 1.03974 L .74178 1.02844 L F
.74178 1.02843 m .74805 1.03974 L .73779 1.05931 L .882 0 .309 r
F
.7532 1.04912 m .74805 1.03974 L .75326 1.04925 L 0 0 .445 r
F
.74805 1.03974 m .7526 1.04806 L .75326 1.04925 L F
.74807 1.03978 m .76194 1.07507 L .75326 1.04925 L F
.73779 1.05931 m .7532 1.04912 L .74965 1.08121 L .883 0 .311 r
F
.7532 1.04912 m .75331 1.04904 L .75986 1.06117 L F
.75331 1.04904 m .77252 1.03633 L .75986 1.06117 L F
.79126 1.02357 m .79372 1.11521 L .80816 1.13292 L .658 .043 .588 r
F
.77183 1.08308 m .7884 1.12568 L .77666 1.09211 L 0 0 .434 r
F
.77663 1.09205 m .77663 1.09205 L .77666 1.09211 L .888 0 .315 r
F
.77663 1.09205 m .78545 1.0556 L .77666 1.09211 L F
.77666 1.09211 m .7884 1.12568 L .80191 1.152 L 0 0 .434 r
F
.76489 1.07047 m .7884 1.12568 L .77183 1.08308 L 0 0 .439 r
F
.77177 1.08321 m .77183 1.08308 L .7766 1.09216 L .888 0 .315 r
F
.77183 1.08308 m .78545 1.0556 L .77667 1.09187 L F
.77183 1.08308 m .77667 1.09187 L .7766 1.09216 L F
.76483 1.07035 m .75986 1.06117 L .76492 1.07029 L .885 0 .313 r
F
.76492 1.07029 m .75991 1.06107 L .765 1.07022 L F
.75986 1.06117 m .75991 1.06107 L .76492 1.07029 L F
.75991 1.06107 m .77252 1.03633 L .765 1.07022 L F
.76483 1.07035 m .75986 1.06117 L .76488 1.07045 L 0 0 .439 r
F
.74779 1.03034 m .75981 1.06102 L .76483 1.07035 L F
.75981 1.06102 m .75986 1.06117 L .76483 1.07035 L F
.75986 1.06117 m .77508 1.10004 L .76488 1.07045 L F
.75326 1.04925 m .77508 1.10004 L .75986 1.06117 L 0 0 .445 r
F
.7526 1.08582 m .7521 1.09761 L .76675 1.12406 L 0 0 .525 r
F
.7526 1.08582 m .76675 1.12406 L .76757 1.1164 L F
.75468 1.08113 m .76335 1.10084 L .77837 1.13223 L 0 0 .302 r
F
.75468 1.08113 m .77837 1.13223 L .7692 1.10977 L F
.76194 1.07507 m .78303 1.12915 L .7973 1.15731 L 0 0 .421 r
F
.76194 1.07507 m .7973 1.15731 L .77508 1.10004 L F
.74965 1.08121 m .76483 1.07035 L .76165 1.10363 L .885 0 .313 r
F
.76483 1.07035 m .78545 1.0556 L .77183 1.08308 L F
.76487 1.07041 m .77183 1.08308 L .75968 1.05183 L 0 0 .439 r
F
.76489 1.07047 m .77183 1.08308 L .76487 1.07041 L F
.76483 1.07035 m .77183 1.08308 L .77177 1.08321 L .885 0 .313 r
F
.76483 1.07035 m .76489 1.07047 L .76487 1.07041 L 0 0 .439 r
F
.76489 1.07047 m .77508 1.10004 L .7884 1.12568 L F
.76488 1.07045 m .76488 1.07046 L .76489 1.07047 L F
.76488 1.07046 m .77508 1.10004 L .76489 1.07047 L F
.76483 1.07035 m .77177 1.08321 L .76165 1.10363 L .885 0 .313 r
F
.76482 1.07035 m .76416 1.06914 L .76483 1.07035 L F
.76416 1.06914 m .75986 1.06117 L .76483 1.07035 L F
.74779 1.03034 m .76483 1.07035 L .75968 1.05183 L 0 0 .439 r
F
.76483 1.07035 m .76487 1.07041 L .75968 1.05183 L F
.75968 1.05183 m .77183 1.08308 L .77666 1.09211 L 0 0 .434 r
F
.75968 1.05183 m .77666 1.09211 L .77171 1.07375 L F
.76335 1.10084 m .76757 1.1164 L .78267 1.14688 L 0 0 .398 r
F
.76335 1.10084 m .78267 1.14688 L .77837 1.13223 L F
.7692 1.10977 m .77837 1.13223 L .79354 1.1635 L 0 0 .334 r
F
.7692 1.10977 m .79354 1.1635 L .78389 1.13907 L F
.76895 1.10187 m .78389 1.13907 L .79877 1.16906 L 0 0 .378 r
F
.76895 1.10187 m .79877 1.16906 L .78303 1.12915 L F
.77508 1.10004 m .7973 1.15731 L .81176 1.18628 L 0 0 .414 r
F
.77508 1.10004 m .81176 1.18628 L .7884 1.12568 L F
.76165 1.10363 m .77666 1.09211 L .77382 1.12664 L .888 0 .315 r
F
.77666 1.09211 m .79853 1.07532 L .78398 1.10554 L F
.77666 1.09211 m .80191 1.152 L .78398 1.10554 L 0 0 .434 r
F
.77666 1.09211 m .78398 1.10554 L .77382 1.12664 L .888 0 .315 r
F
.77666 1.09211 m .78398 1.10554 L .7839 1.10533 L 0 0 .434 r
F
.77666 1.09211 m .78545 1.0556 L .79853 1.07532 L .888 0 .315 r
F
.77666 1.09211 m .7839 1.10533 L .77171 1.07375 L 0 0 .434 r
F
.7766 1.09216 m .77663 1.09205 L .77666 1.09211 L .888 0 .315 r
F
.76165 1.10363 m .77177 1.08321 L .7766 1.09216 L F
.75324 1.04919 m .75986 1.06117 L .74779 1.03034 L 0 0 .445 r
F
.75326 1.04925 m .75986 1.06117 L .75324 1.04919 L F
.7532 1.04912 m .75986 1.06117 L .75983 1.06124 L .883 0 .311 r
F
.7532 1.04912 m .75326 1.04925 L .75324 1.04919 L 0 0 .445 r
F
.7532 1.04912 m .75983 1.06124 L .74965 1.08121 L .883 0 .311 r
F
.73605 1.00922 m .74799 1.0396 L .7532 1.04912 L 0 0 .445 r
F
.74799 1.0396 m .74805 1.03974 L .7532 1.04912 L F
.74805 1.03974 m .74807 1.03978 L .7526 1.04806 L F
.74965 1.08121 m .75983 1.06124 L .76482 1.07035 L .885 0 .313 r
F
.75983 1.06124 m .75986 1.06117 L .76482 1.07035 L F
.73779 1.05931 m .74802 1.0398 L .7532 1.04912 L .883 0 .311 r
F
.74802 1.0398 m .74805 1.03974 L .7532 1.04912 L F
.73605 1.00922 m .7532 1.04912 L .74779 1.03034 L 0 0 .445 r
F
.7532 1.04912 m .75324 1.04919 L .74779 1.03034 L F
.74155 1.02801 m .74154 1.02801 L .74173 1.02835 L .882 0 .309 r
F
.74154 1.02801 m .73678 1.01801 L .74173 1.02835 L F
.73638 1.01875 m .73678 1.01801 L .74171 1.02836 L F
.72445 .98838 m .73638 1.01875 L .74173 1.02835 L 0 0 .454 r
F
.74171 1.02836 m .74155 1.02801 L .74173 1.02835 L .882 0 .309 r
F
.72445 .98838 m .74173 1.02835 L .73605 1.00922 L 0 0 .454 r
F
.74173 1.02835 m .74178 1.02844 L .73605 1.00922 L F
.72703 1.00201 m .72487 .99798 L .73041 1.00795 L .883 0 .307 r
F
.72487 .99798 m .72498 .99778 L .73041 1.00795 L F
.71298 .96768 m .72481 .9981 L .73041 1.00795 L 0 0 .468 r
F
.73025 1.00803 m .72703 1.00201 L .73041 1.00795 L .883 0 .307 r
F
.71451 1.01652 m .72481 .9981 L .73025 1.00803 L F
.72481 .9981 m .72487 .99798 L .73025 1.00803 L F
.71298 .96768 m .73041 1.00795 L .72445 .98838 L 0 0 .468 r
F
.73041 1.00795 m .73048 1.00808 L .72445 .98838 L F
.72608 1.03781 m .73638 1.01875 L .74171 1.02836 L .882 0 .309 r
F
.71811 .98592 m .71802 .98564 L .71916 .98771 L .889 0 .305 r
F
.71802 .98564 m .71472 .97513 L .71916 .98771 L F
.70803 .96723 m .71345 .97729 L .71326 .97762 L .905 0 .302 r
F
.71326 .97762 m .71472 .97513 L .71874 .98791 L .889 0 .305 r
F
.70163 .94689 m .71326 .97762 L .71916 .98771 L 0 0 .49 r
F
.71874 .98791 m .71811 .98592 L .71916 .98771 L .889 0 .305 r
F
.70427 .95277 m .70984 .9439 L .71352 .96537 L .905 0 .302 r
F
.70163 .94689 m .71916 .98771 L .71298 .96768 L 0 0 .49 r
F
.71916 .98771 m .71941 .98817 L .71298 .96768 L F
.70786 .96729 m .70803 .96723 L .71326 .97762 L .905 0 .302 r
F
.70786 .96729 m .70821 .96813 L .70808 .96772 L 0 0 .523 r
F
.70821 .96813 m .71326 .97762 L .70163 .94689 L F
.70786 .96729 m .71326 .97762 L .70306 .99508 L .905 0 .302 r
F
.70786 .96729 m .70808 .96772 L .70808 .96771 L 0 0 .523 r
F
.70786 .96729 m .70808 .96771 L .70163 .94689 L F
.70306 .99508 m .71326 .97762 L .71874 .98791 L .889 0 .305 r
F
.68981 .93586 m .69124 .93392 L .68995 .93608 L .936 0 .294 r
F
.68464 .92142 m .68855 .92996 L .688 .93125 L .992 .001 .255 r
F
.69124 .93392 m .69149 .93428 L .68275 .94814 L .936 0 .294 r
F
.67939 .9029 m .68981 .93586 L .69633 .94601 L .041 0 .559 r
F
.68981 .93586 m .68995 .93608 L .68992 .93612 L .936 0 .294 r
F
.68981 .93586 m .68992 .93612 L .68275 .94814 L F
.68406 .92127 m .68464 .92142 L .688 .93125 L .992 .001 .255 r
F
.68406 .92127 m .688 .93125 L .68225 .94462 L F
.68406 .92127 m .68981 .93586 L .68858 .93195 L .276 0 .569 r
F
.68244 .90732 m .67939 .90289 L .69038 .92552 L 0 0 .363 r
F
.65452 .84275 m .65789 .85128 L .64677 .82561 L 1 .081 .345 r
F
.65452 .84275 m .6684 .87552 L .65789 .85128 L F
.65847 .84411 m .66803 .86539 L .65797 .8453 L 0 0 .543 r
F
.66803 .86539 m .66925 .87083 L .66883 .86931 L .471 0 .531 r
F
.66803 .86539 m .68588 .9051 L .66856 .86799 L 0 0 .543 r
F
.66803 .86539 m .66856 .86799 L .65797 .8453 L F
.66803 .86539 m .66883 .86931 L .66362 .8507 L .471 0 .531 r
F
.66362 .8507 m .66883 .86931 L .66639 .86508 L F
.6568 .81528 m .66033 .83967 L .66803 .86539 L F
.6568 .81528 m .66803 .86539 L .66362 .8507 L F
.65741 .84174 m .65847 .84411 L .65797 .8453 L 0 0 .543 r
F
.64783 .82695 m .65679 .81522 L .6684 .87552 L 1 .081 .345 r
F
.65615 .8471 m .66065 .85789 L .66146 .85927 L 0 0 .363 r
F
.64677 .82561 m .65789 .85128 L .65981 .85621 L .717 0 0 r
F
.6586 .85363 m .65981 .85621 L .66128 .85999 L F
.64677 .82561 m .65981 .85621 L .6586 .85363 L F
.63386 .95988 m .64776 .82932 L .6398 .96071 L 1 .276 .457 r
F
.64776 .82932 m .64787 .82958 L .6398 .96071 L F
.60554 .8234 m .60916 .83602 L .61698 .82673 L .807 .549 .807 r
F
.60554 .8234 m .59859 .83096 L .60916 .83602 L F
.6036 .83196 m .62938 .80142 L .61062 .81673 L 1 .702 .627 r
F
.62938 .80142 m .63082 .79971 L .62918 .80109 L F
.62938 .80142 m .62918 .80109 L .61062 .81673 L F
.61698 .82673 m .60916 .83602 L .61974 .8425 L .806 .456 .778 r
F
.6036 .83196 m .62255 .82516 L .63082 .79971 L 1 .702 .627 r
F
.62343 .79195 m .63747 .80251 L .64677 .82561 L 1 0 .135 r
F
.62373 .79217 m .62425 .79293 L .6236 .79193 L F
.62425 .79293 m .64677 .82561 L .62402 .79255 L F
.62425 .79293 m .62402 .79255 L .6236 .79193 L F
.62343 .79195 m .62464 .78978 L .62336 .79172 L 1 .558 .582 r
F
.62298 .7913 m .62343 .79195 L .62034 .78714 L 1 0 .135 r
F
.62343 .79195 m .62339 .79181 L .62034 .78714 L F
.62343 .79195 m .62336 .79172 L .62085 .7955 L 1 .558 .582 r
F
.62343 .79195 m .62424 .79312 L .62339 .79181 L 1 0 .135 r
F
.6236 .79193 m .64677 .82561 L .62347 .7917 L F
.62432 .79323 m .64677 .82561 L .62372 .79216 L F
.62291 .79065 m .62314 .79099 L .62297 .79075 L F
.62336 .79172 m .62464 .78978 L .62317 .79108 L 1 .558 .582 r
F
.62034 .78714 m .62347 .7917 L .62291 .79065 L 1 0 .135 r
F
.62317 .79108 m .62312 .79101 L .62311 .79113 L 1 .558 .582 r
F
.62464 .78978 m .62314 .79099 L .62317 .79108 L F
.6232 .7912 m .62314 .79099 L .62291 .79065 L 1 0 .135 r
F
.62314 .79099 m .62312 .79101 L .62317 .79108 L 1 .558 .582 r
F
.62347 .7917 m .64677 .82561 L .62314 .79099 L 1 0 .135 r
F
.62347 .7917 m .62314 .79099 L .6232 .7912 L F
.64677 .82561 m .65159 .83702 L .65615 .8471 L .717 0 0 r
F
.65159 .83702 m .66128 .85999 L .65615 .8471 L F
.65615 .8471 m .66146 .85927 L .66558 .86611 L 0 0 .363 r
F
.67048 .87952 m .66938 .87741 L .66639 .86508 L .471 0 .531 r
F
.66146 .85927 m .69038 .92552 L .66558 .86611 L 0 0 .363 r
F
.66146 .85927 m .66558 .86611 L .66558 .86611 L F
.66593 .86669 m .66558 .86611 L .6663 .86742 L 0 0 .346 r
F
.66055 .85682 m .65615 .8471 L .66558 .86611 L .713 0 0 r
F
.62314 .79102 m .64677 .82561 L .65615 .8471 L .846 0 0 r
F
.62314 .79099 m .64677 .82561 L .62314 .79098 L 1 0 .135 r
F
.62316 .79101 m .64677 .82561 L .62314 .79102 L .846 0 0 r
F
.63254 .80507 m .63287 .80557 L .63254 .80506 L F
.63254 .80507 m .63254 .80506 L .62313 .79096 L F
.62312 .79097 m .63254 .80507 L .62313 .79096 L F
.62313 .79096 m .63287 .80557 L .62429 .79259 L F
.62429 .79259 m .63287 .80557 L .63051 .80133 L F
.62314 .79099 m .62313 .79098 L .62312 .79101 L 1 .558 .582 r
F
.62314 .79099 m .62314 .79098 L .62297 .79075 L 1 0 .135 r
F
.62297 .79075 m .62316 .79101 L .62314 .79102 L .846 0 0 r
F
.62311 .79095 m .65299 .84173 L .63287 .80557 L F
.62297 .79075 m .62312 .79099 L .62311 .79095 L F
.62312 .79099 m .65299 .84173 L .62311 .79095 L F
.62312 .79099 m .62359 .79021 L .62353 .7902 L .882 .009 .468 r
F
.62298 .79124 m .62312 .79101 L .62312 .79099 L F
.62312 .79101 m .62359 .79021 L .62312 .79099 L F
.65299 .84173 m .65615 .8471 L .65218 .84001 L .846 0 0 r
F
.65299 .84173 m .65218 .84001 L .63051 .80133 L F
.66128 .85999 m .66558 .86973 L .65615 .8471 L .717 0 0 r
F
.63051 .80133 m .65615 .8471 L .66055 .85682 L .713 0 0 r
F
.63812 .81173 m .66558 .86611 L .66593 .86669 L 0 0 .346 r
F
.66558 .86611 m .66558 .86611 L .66593 .86669 L F
.62424 .79312 m .62347 .7917 L .62034 .78714 L 1 0 .135 r
F
.61551 .78053 m .62298 .7913 L .62034 .78714 L F
.59407 .82066 m .59859 .83096 L .60554 .8234 L .799 .611 .828 r
F
.59868 .81374 m .60554 .8234 L .61081 .81468 L .845 .66 .826 r
F
.59868 .81374 m .59407 .82066 L .60554 .8234 L F
.60174 .80665 m .61081 .81468 L .61432 .80576 L .882 .726 .832 r
F
.60174 .80665 m .59868 .81374 L .61081 .81468 L F
.60318 .79995 m .61432 .80576 L .61599 .79757 L .896 .782 .842 r
F
.60318 .79995 m .60174 .80665 L .61432 .80576 L F
.588 .82686 m .5901 .83673 L .59859 .83096 L .749 .589 .841 r
F
.59407 .82066 m .588 .82686 L .59859 .83096 L .799 .611 .828 r
F
.5925 .83198 m .61592 .80536 L .62298 .79124 L .944 .194 .615 r
F
.5901 .83673 m .58023 .84075 L .58848 .8457 L .64 .506 .864 r
F
.58058 .83201 m .58023 .84075 L .5901 .83673 L .694 .575 .861 r
F
.588 .82686 m .58058 .83201 L .5901 .83673 L .749 .589 .841 r
F
.58833 .83765 m .5935 .83171 L .59198 .83266 L 1 .591 .669 r
F
.5935 .83171 m .61526 .80675 L .59736 .82667 L F
.5935 .83171 m .59736 .82667 L .59198 .83266 L F
.62352 .7903 m .62475 .78795 L .6247 .78823 L .882 .009 .468 r
F
.62314 .79097 m .62353 .7902 L .62352 .7903 L F
.62313 .79097 m .62353 .7902 L .62314 .79097 L F
.62384 .7876 m .62379 .78803 L .61482 .77962 L .991 0 .151 r
F
.62293 .78916 m .62314 .79097 L .63009 .77876 L .769 0 .488 r
F
.62617 .78797 m .6265 .78721 L .62677 .78701 L 0 0 0 r
F
.62377 .78869 m .62387 .78909 L .62404 .78912 L 0 0 .44 r
F
.62255 .78971 m .62303 .79074 L .62293 .78916 L .769 0 .488 r
F
.62303 .79074 m .62314 .79097 L .62293 .78916 L F
.59795 .8247 m .6144 .80272 L .59807 .82528 L .944 .194 .615 r
F
.6144 .80272 m .62298 .79124 L .61338 .80437 L F
.6144 .80272 m .61338 .80437 L .59807 .82528 L F
.59807 .82528 m .62298 .79124 L .6231 .79105 L .769 0 .488 r
F
.62298 .79124 m .62313 .79097 L .62314 .79097 L .882 .009 .468 r
F
.59807 .82528 m .6231 .79105 L .62308 .79106 L .769 0 .488 r
F
.62311 .79093 m .62313 .79096 L .62314 .79097 L 0 0 .388 r
F
.62311 .79091 m .62297 .79075 L .62313 .79096 L F
.62288 .79043 m .62297 .79075 L .62311 .79091 L F
.62297 .79075 m .62312 .79097 L .62313 .79096 L .846 0 0 r
F
.62255 .78971 m .62261 .79012 L .62277 .79002 L 0 0 .388 r
F
.62261 .79012 m .62297 .79075 L .62277 .79002 L F
.58922 .77196 m .59767 .77468 L .60838 .77125 L .578 .397 .897 r
F
.58922 .77196 m .60838 .77125 L .5989 .76896 L F
.60265 .76644 m .6075 .77004 L .60995 .77365 L .822 0 .067 r
F
.6075 .77004 m .62559 .78346 L .60995 .77365 L F
.6075 .77004 m .60995 .77365 L .60995 .77365 L F
.6116 .77609 m .60995 .77365 L .61482 .77962 L .601 0 0 r
F
.59579 .76465 m .60862 .76642 L .61839 .76421 L .388 .033 .87 r
F
.58734 .76628 m .60862 .76642 L .59579 .76465 L .464 .167 .896 r
F
.59579 .76465 m .60384 .7645 L .60431 .76461 L .388 .033 .87 r
F
.60384 .7645 m .61839 .76421 L .60431 .76461 L F
.60862 .76642 m .61912 .76778 L .62989 .76384 L .553 .209 .881 r
F
.60862 .76642 m .62989 .76384 L .61839 .76421 L F
.60431 .76461 m .61839 .76421 L .6282 .76204 L .286 0 .782 r
F
.60431 .76461 m .61208 .76378 L .61291 .76703 L F
.61208 .76378 m .6282 .76204 L .61291 .76703 L F
.6137 .77009 m .61291 .76703 L .62165 .77364 L .564 0 0 r
F
.60475 .76472 m .60431 .76461 L .61291 .76703 L 0 0 .615 r
F
.58833 .76007 m .60431 .76461 L .60475 .76472 L F
.58129 .7604 m .59579 .76465 L .60431 .76461 L .161 0 .829 r
F
.58129 .7604 m .60431 .76461 L .58833 .76007 L F
.58833 .76007 m .59519 .76201 L .59545 .76193 L 0 0 .615 r
F
.59519 .76201 m .61291 .76703 L .59545 .76193 L F
.59545 .76193 m .61291 .76703 L .6137 .77009 L .564 0 0 r
F
.59545 .76193 m .6015 .76464 L .60265 .76644 L F
.6015 .76464 m .62165 .77364 L .60265 .76644 L F
.60375 .76815 m .60265 .76644 L .60995 .77365 L .544 0 0 r
F
.59569 .76185 m .59545 .76193 L .60265 .76644 L 0 0 .559 r
F
.57625 .74905 m .60265 .76644 L .58173 .74864 L F
.58173 .74864 m .60265 .76644 L .60375 .76815 L .544 0 0 r
F
.57625 .74905 m .59545 .76193 L .59569 .76185 L 0 0 .559 r
F
.58173 .74864 m .60995 .77365 L .58726 .74935 L .544 0 0 r
F
.59411 .75688 m .60995 .77365 L .6116 .77609 L .601 0 0 r
F
.58825 .7504 m .60995 .77365 L .59411 .75688 L F
.60995 .77365 m .60995 .77365 L .6116 .77609 L F
.62559 .78346 m .62554 .7837 L .60995 .77365 L .822 0 .067 r
F
.60995 .77365 m .6128 .77652 L .61482 .77962 L .991 0 .151 r
F
.6128 .77652 m .62384 .7876 L .61496 .77975 L F
.6128 .77652 m .61496 .77975 L .61482 .77962 L F
.61835 .78483 m .61551 .78053 L .62297 .79075 L .612 0 0 r
F
.58726 .74935 m .58825 .7504 L .59411 .75688 L .601 0 0 r
F
.58726 .74935 m .61482 .77962 L .59094 .75032 L F
.59106 .75047 m .61482 .77963 L .61551 .78053 L .588 0 0 r
F
.59094 .75032 m .59105 .75045 L .59106 .75047 L F
.59105 .75045 m .61482 .77963 L .59106 .75047 L F
.59094 .75032 m .59106 .75047 L .59146 .75048 L F
.59106 .75047 m .61516 .7801 L .59146 .75048 L F
.59106 .75047 m .59146 .75048 L .59146 .75048 L F
.61516 .7801 m .61551 .78053 L .61521 .78015 L F
.61516 .7801 m .61521 .78015 L .59146 .75048 L F
.59147 .75048 m .61531 .78028 L .61835 .78483 L .612 0 0 r
F
.59147 .75048 m .608 .77162 L .59708 .75252 L F
.61531 .78028 m .61551 .78053 L .61835 .78483 L F
.608 .77162 m .62297 .79075 L .62103 .78788 L F
.608 .77162 m .62103 .78788 L .59708 .75252 L F
.59708 .75252 m .62277 .79044 L .62133 .78792 L 0 0 .388 r
F
.62277 .79044 m .62297 .79075 L .62133 .78792 L F
.61304 .80479 m .62314 .79097 L .62255 .78971 L .769 0 .488 r
F
.59198 .83266 m .61526 .80675 L .61592 .80536 L 1 .306 .628 r
F
.59198 .83266 m .61592 .80536 L .5925 .83198 L F
.59807 .82528 m .62255 .78971 L .60369 .81963 L .769 0 .488 r
F
.62133 .78792 m .62255 .78971 L .62142 .78614 L 0 0 .388 r
F
.62464 .78978 m .62359 .79021 L .62313 .79098 L 1 .558 .582 r
F
.62464 .78978 m .62313 .79098 L .62314 .79099 L F
.62464 .78978 m .6262 .78699 L .62359 .79021 L F
.6262 .78699 m .62498 .78781 L .62359 .79021 L F
.62255 .78971 m .63051 .80133 L .6233 .78927 L 0 0 .388 r
F
.62255 .78971 m .63009 .77876 L .6233 .78927 L .769 0 .488 r
F
.62255 .78971 m .6233 .78927 L .62142 .78614 L 0 0 .388 r
F
.62255 .78971 m .6233 .78927 L .62283 .78999 L .769 0 .488 r
F
.62255 .78971 m .62283 .78999 L .60369 .81963 L F
.62133 .78792 m .62211 .78926 L .62255 .78971 L 0 0 .388 r
F
.62211 .78926 m .62261 .79012 L .62255 .78971 L F
.62289 .78859 m .6233 .78927 L .6228 .78712 L 0 0 .44 r
F
.6233 .78927 m .63051 .80133 L .62387 .78909 L F
.62707 .79141 m .63335 .78325 L .62692 .79136 L 1 .614 .581 r
F
.63335 .78325 m .63272 .78396 L .62692 .79136 L F
.62515 .79062 m .63699 .77851 L .62493 .79046 L 1 .558 .582 r
F
.62666 .79168 m .63271 .78397 L .62515 .79062 L F
.63271 .78397 m .63699 .77851 L .62515 .79062 L F
.62681 .79174 m .62709 .79143 L .62707 .79141 L 1 .614 .581 r
F
.62753 .79175 m .62709 .79143 L .62681 .79174 L F
.62681 .79174 m .62707 .79141 L .62666 .79168 L F
.62707 .79141 m .62692 .79136 L .62666 .79168 L F
.62699 .79192 m .62698 .79191 L .6268 .79173 L .995 0 .132 r
F
.62699 .79192 m .6268 .79173 L .6268 .79173 L F
.62681 .79174 m .62699 .79192 L .62681 .79174 L F
.62699 .79192 m .62707 .79199 L .62698 .79191 L F
.62707 .79199 m .63747 .8025 L .6269 .79192 L F
.62404 .78912 m .63812 .81173 L .62527 .78823 L 0 0 .44 r
F
.62509 .78831 m .62527 .78823 L .62524 .78819 L F
.62404 .78912 m .62527 .78823 L .62509 .78831 L F
.63215 .79515 m .63438 .79048 L .63295 .79238 L 1 .269 .494 r
F
.63254 .79526 m .63438 .79048 L .63215 .79515 L F
.63438 .79048 m .64643 .75926 L .63295 .79238 L F
.64643 .75926 m .64302 .76526 L .63622 .78113 L F
.63295 .79238 m .65411 .73965 L .63661 .80041 L .803 0 .386 r
F
.65362 .74064 m .65411 .73965 L .63295 .79238 L F
.64559 .76075 m .65362 .74064 L .64302 .76526 L 1 .269 .494 r
F
.65362 .74064 m .65346 .74089 L .64302 .76526 L F
.6303 .78605 m .64455 .75841 L .65192 .75002 L 0 0 0 r
F
.62707 .79141 m .63623 .78113 L .63335 .78325 L 1 .614 .581 r
F
.62709 .79143 m .63623 .78113 L .62707 .79141 L F
.62753 .79175 m .63623 .78113 L .62709 .79143 L F
.62753 .79176 m .63661 .80042 L .62745 .79175 L .995 0 .132 r
F
.62833 .79211 m .63622 .78113 L .62753 .79176 L 1 .694 .601 r
F
.62852 .79246 m .62764 .79185 L .62753 .79176 L .991 0 .151 r
F
.62852 .79246 m .62753 .79176 L .62796 .79194 L F
.63108 .79486 m .63068 .79475 L .62764 .79185 L F
.63108 .79486 m .62764 .79185 L .62852 .79246 L F
.62524 .78819 m .63812 .81173 L .62622 .7883 L 0 0 .477 r
F
.6257 .78808 m .62622 .7883 L .62607 .788 L F
.62524 .78819 m .62622 .7883 L .6257 .78808 L F
.6366 .77986 m .63664 .7797 L .63699 .77852 L 1 .281 .456 r
F
.63664 .7797 m .63699 .77852 L .63699 .77852 L F
.63335 .78325 m .63623 .78113 L .63699 .77852 L 1 .614 .581 r
F
.6292 .7909 m .63309 .79191 L .63622 .78113 L 1 .694 .601 r
F
.65014 .80692 m .65051 .80348 L .65025 .80723 L 1 .276 .457 r
F
.65051 .80348 m .65058 .80277 L .65054 .80342 L F
.65644 .81336 m .65661 .81454 L .65647 .81449 L .383 0 .523 r
F
.63661 .80042 m .65431 .74812 L .65679 .81518 L 1 .189 .445 r
F
.62938 .78757 m .62883 .78668 L .6303 .78605 L 0 0 0 r
F
.63747 .80251 m .65452 .84275 L .64677 .82561 L 1 .081 .345 r
F
.64427 .81856 m .65678 .81522 L .64783 .82695 L F
.62865 .79257 m .63108 .79486 L .6286 .79254 L .991 0 .151 r
F
.62644 .78845 m .63812 .81173 L .64591 .82195 L 0 0 .477 r
F
.62617 .78797 m .6264 .78845 L .62644 .78845 L F
.6264 .78845 m .63812 .81173 L .62644 .78845 L F
.62464 .78921 m .62466 .78918 L .62512 .78928 L 0 0 0 r
F
.62833 .78759 m .62883 .78668 L .62915 .78721 L F
.62833 .78759 m .62915 .78721 L .62938 .78757 L F
.63703 .80144 m .65179 .81166 L .63747 .8025 L 1 .189 .445 r
F
.65179 .81166 m .65186 .81185 L .63747 .8025 L F
.63747 .80251 m .65493 .814 L .64427 .81856 L 1 .081 .345 r
F
.65493 .814 m .65678 .81522 L .64427 .81856 L F
.65678 .81522 m .65679 .81522 L .64783 .82695 L F
.63108 .79486 m .63661 .80041 L .63068 .79475 L .991 0 .151 r
F
.63108 .79486 m .63295 .79238 L .63661 .80041 L F
.6297 .78816 m .64591 .82195 L .65376 .83186 L 0 0 .498 r
F
.62966 .78809 m .62969 .78816 L .6297 .78816 L F
.62969 .78816 m .64591 .82195 L .6297 .78816 L F
.67665 .76213 m .69148 .7328 L .68932 .76 L 0 0 0 r
F
.66195 .73441 m .6743 .75536 L .68201 .75289 L .826 .363 .738 r
F
.66195 .73441 m .68201 .75289 L .66884 .72104 L F
.63661 .80042 m .63929 .80238 L .63703 .80144 L 1 .189 .445 r
F
.62966 .78809 m .65376 .83186 L .63234 .78784 L 0 0 .498 r
F
.63012 .78796 m .63234 .78784 L .63212 .7874 L F
.62966 .78809 m .63234 .78784 L .63012 .78796 L F
.66884 .72104 m .68201 .75289 L .68311 .75254 L .791 .204 .676 r
F
.66884 .72104 m .68311 .75254 L .66981 .71903 L F
.66981 .71903 m .68311 .75254 L .69483 .74878 L .785 .189 .669 r
F
.64243 .78731 m .66679 .73566 L .67429 .72932 L 0 0 .023 r
F
.63346 .78804 m .63356 .78824 L .63641 .78756 L 0 0 .51 r
F
.66262 .7591 m .68384 .77709 L .6743 .75536 L 0 0 .74 r
F
.66981 .71903 m .69483 .74878 L .68022 .69847 L .785 .189 .669 r
F
.64712 .78829 m .67429 .72932 L .68184 .7234 L 0 0 .047 r
F
.63356 .78824 m .66168 .84158 L .63673 .78825 L 0 0 .51 r
F
.63356 .78824 m .65376 .83186 L .66168 .84158 L F
.63212 .7874 m .63234 .78784 L .63317 .78749 L F
.63187 .78787 m .63212 .7874 L .63291 .78757 L 0 0 0 r
F
.63335 .78325 m .63699 .77852 L .63272 .78396 L 1 .614 .581 r
F
.63212 .7874 m .65192 .75002 L .63295 .78747 L 0 0 0 r
F
.63212 .7874 m .63295 .78747 L .63291 .78757 L F
.63317 .78749 m .63234 .78784 L .63356 .78824 L 0 0 .51 r
F
.62559 .78761 m .63724 .76794 L .62623 .78733 L 0 0 0 r
F
.63234 .78784 m .65376 .83186 L .63356 .78824 L 0 0 .51 r
F
.63317 .78749 m .63313 .78712 L .63343 .78704 L 0 0 0 r
F
.63146 .79042 m .63291 .78757 L .63317 .78749 L F
.63291 .78757 m .63313 .78712 L .63317 .78749 L F
.62953 .78806 m .64591 .82195 L .62966 .78809 L 0 0 .498 r
F
.62883 .78668 m .64455 .75841 L .6303 .78605 L 0 0 0 r
F
.62669 .78713 m .64455 .75841 L .62833 .78759 L F
.62784 .78664 m .62833 .78759 L .62867 .78628 L 0 0 .498 r
F
.62833 .78759 m .64591 .82195 L .62945 .7879 L F
.62833 .78759 m .62945 .7879 L .62927 .78753 L F
.62644 .78845 m .64591 .82195 L .62833 .78759 L 0 0 .477 r
F
.62607 .788 m .63812 .81173 L .62617 .78797 L F
.62404 .78912 m .63051 .80133 L .63812 .81173 L 0 0 .44 r
F
.62387 .78909 m .63051 .80133 L .62404 .78912 L F
.62355 .79117 m .62314 .79097 L .63051 .80133 L 0 0 .388 r
F
.61514 .8113 m .62938 .78757 L .62098 .80844 L 0 0 0 r
F
.62938 .78757 m .65192 .75002 L .63212 .7874 L F
.6233 .78927 m .63009 .77876 L .62371 .78877 L F
.62377 .78869 m .63724 .76794 L .62524 .78819 L F
.62582 .78806 m .63724 .76794 L .62607 .788 L F
.62427 .78793 m .63009 .77876 L .63235 .77547 L F
.6242 .78802 m .63009 .77876 L .62427 .78793 L F
.6236 .78894 m .63009 .77876 L .62377 .78869 L F
.62677 .78701 m .63724 .76794 L .64455 .75841 L F
.6265 .78721 m .63724 .76794 L .62677 .78701 L F
.62823 .78146 m .65354 .73287 L .63009 .77876 L .882 .009 .468 r
F
.61291 .76703 m .6282 .76204 L .63804 .75928 L 0 0 0 r
F
.61291 .76703 m .63804 .75928 L .62165 .77364 L F
.62947 .78757 m .63212 .7874 L .62019 .76288 L 0 0 .498 r
F
.62966 .78809 m .63212 .7874 L .62947 .78757 L F
.62938 .78757 m .63212 .7874 L .63155 .78848 L 0 0 0 r
F
.62938 .78757 m .62966 .78809 L .62946 .78754 L 0 0 .498 r
F
.62938 .78757 m .63155 .78848 L .62098 .80844 L 0 0 0 r
F
.62843 .78718 m .62927 .78753 L .62867 .78628 L 0 0 .498 r
F
.62833 .78759 m .62927 .78753 L .62843 .78718 L F
.62617 .78797 m .62669 .78713 L .6263 .78795 L 0 0 0 r
F
.62644 .78845 m .62833 .78759 L .62623 .78796 L 0 0 .477 r
F
.62617 .78797 m .62644 .78845 L .62623 .78796 L F
.62424 .79312 m .62432 .79323 L .62372 .79216 L 1 0 .135 r
F
.6263 .78795 m .62833 .78759 L .61514 .8113 L 0 0 0 r
F
.62669 .78713 m .62833 .78759 L .6263 .78795 L F
.62617 .78797 m .62623 .78796 L .62622 .78793 L 0 0 .477 r
F
.62559 .78761 m .62623 .78733 L .62561 .78842 L 0 0 0 r
F
.62607 .788 m .6265 .78721 L .62617 .78797 L F
.62623 .78796 m .62833 .78759 L .6143 .76019 L 0 0 .477 r
F
.62372 .79216 m .62373 .79217 L .6236 .79193 L 1 0 .135 r
F
.61592 .80536 m .62343 .79195 L .62085 .7955 L 1 .558 .582 r
F
.58833 .83765 m .61062 .81673 L .61526 .80675 L 1 .591 .669 r
F
.60935 .81501 m .62617 .78797 L .61514 .8113 L 0 0 0 r
F
.62617 .78797 m .6263 .78795 L .61514 .8113 L F
.62098 .80844 m .63317 .78749 L .62687 .80632 L F
.63366 .78664 m .65933 .74251 L .63641 .78756 L F
.64193 .78822 m .6412 .78773 L .64223 .78766 L 0 0 .023 r
F
.63738 .78771 m .63733 .78742 L .63757 .78738 L 0 0 0 r
F
.63641 .78756 m .66168 .84158 L .63749 .78793 L 0 0 .516 r
F
.63591 .79032 m .63717 .78775 L .63738 .78771 L 0 0 0 r
F
.63738 .78771 m .63641 .78756 L .63749 .78793 L 0 0 .516 r
F
.6372 .78768 m .63733 .78742 L .63738 .78771 L 0 0 0 r
F
.63514 .79005 m .63623 .78791 L .63591 .79032 L F
.63623 .78791 m .65933 .74251 L .63717 .78775 L F
.63623 .78791 m .63717 .78775 L .63591 .79032 L F
.63051 .80133 m .66558 .86611 L .63812 .81173 L .713 0 0 r
F
.62687 .80632 m .63738 .78771 L .6328 .80483 L 0 0 0 r
F
.65179 .81166 m .6553 .81409 L .65186 .81185 L 1 .189 .445 r
F
.68309 .81876 m .67422 .85575 L .68177 .86055 L 1 .319 .644 r
F
.67111 .81859 m .67422 .85575 L .68309 .81876 L 1 .336 .662 r
F
.70091 .74082 m .69812 .7775 L .71029 .76982 L 1 .636 .652 r
F
.69976 .74225 m .69811 .7775 L .70091 .74082 L 1 .639 .655 r
F
.69775 .76119 m .70053 .71334 L .69699 .69617 L .251 0 .287 r
F
.69829 .77892 m .69997 .73413 L .70122 .73599 L 1 .022 .333 r
F
.69829 .77892 m .70122 .73599 L .70003 .79728 L F
.70004 .79729 m .70123 .736 L .71462 .75369 L 1 .023 .372 r
F
.68022 .69847 m .69483 .74878 L .70657 .74503 L .743 .102 .622 r
F
.63786 .78687 m .66679 .73566 L .64105 .78804 L 0 0 0 r
F
.64685 .78879 m .64621 .78829 L .64712 .78829 L 0 0 .047 r
F
.64675 .789 m .6461 .7888 L .64685 .78879 L F
.6553 .81409 m .65679 .81518 L .65494 .81397 L 1 .189 .445 r
F
.64224 .78885 m .67775 .86081 L .64596 .78881 L 0 0 .519 r
F
.64675 .789 m .67775 .86081 L .68589 .87049 L F
.64609 .78884 m .6461 .7888 L .64675 .789 L 0 0 .047 r
F
.6461 .7888 m .64621 .78829 L .64685 .78879 L F
.64621 .78829 m .67429 .72932 L .64712 .78829 L F
.64138 .78736 m .66679 .73566 L .64243 .78731 L 0 0 .023 r
F
.63757 .78738 m .65933 .74251 L .66679 .73566 L 0 0 0 r
F
.63733 .78742 m .65933 .74251 L .63757 .78738 L F
.63343 .78704 m .65192 .75002 L .65933 .74251 L F
.63313 .78712 m .65192 .75002 L .63343 .78704 L F
.64105 .78804 m .66968 .8512 L .64202 .7884 L 0 0 .519 r
F
.63768 .7883 m .66968 .8512 L .64105 .78804 L 0 0 .516 r
F
.63784 .78861 m .66168 .84158 L .66968 .8512 L F
.63779 .7886 m .66168 .84158 L .63784 .78861 L F
.6328 .80483 m .64181 .78843 L .63879 .80386 L 0 0 .023 r
F
.64193 .78822 m .64105 .78804 L .64202 .7884 L 0 0 .519 r
F
.64114 .78803 m .6412 .78773 L .6416 .788 L 0 0 .023 r
F
.64223 .78766 m .64138 .78736 L .64243 .78731 L F
.6412 .78773 m .64138 .78736 L .64223 .78766 L F
.63009 .77876 m .66195 .7167 L .63724 .76794 L 0 0 0 r
F
.6321 .7683 m .64094 .78779 L .64193 .78822 L 0 0 .519 r
F
.64114 .78803 m .6416 .788 L .64193 .78822 L 0 0 .023 r
F
.64094 .78779 m .64105 .78804 L .64193 .78822 L 0 0 .519 r
F
.64283 .78835 m .67429 .72932 L .64596 .78881 L 0 0 .023 r
F
.64224 .78885 m .64596 .78881 L .6421 .78824 L 0 0 .519 r
F
.64193 .78822 m .67429 .72932 L .64272 .78856 L 0 0 .023 r
F
.6421 .78824 m .64596 .78881 L .63813 .77105 L 0 0 .519 r
F
.64272 .78856 m .64283 .78835 L .64587 .78901 L 0 0 .023 r
F
.64283 .78835 m .64596 .78881 L .64587 .78901 L F
.64193 .78822 m .64224 .78885 L .64209 .78821 L 0 0 .519 r
F
.64181 .78843 m .64193 .78822 L .64272 .78856 L 0 0 .023 r
F
.64244 .78925 m .66968 .8512 L .67775 .86081 L 0 0 .519 r
F
.64202 .7884 m .64239 .78923 L .64244 .78925 L F
.64239 .78923 m .66968 .8512 L .64244 .78925 L F
.64181 .78843 m .64587 .78901 L .63879 .80386 L 0 0 .023 r
F
.64596 .78881 m .67775 .86081 L .64675 .789 L 0 0 .519 r
F
.63879 .80386 m .64675 .789 L .64483 .80336 L 0 0 .047 r
F
.69097 .8187 m .68284 .86123 L .69208 .81868 L 1 .311 .635 r
F
.69097 .8187 m .68177 .86056 L .68284 .86123 L F
.68309 .81876 m .68177 .86055 L .69097 .8187 L 1 .319 .644 r
F
.65184 .79015 m .68589 .87049 L .69412 .88028 L 0 0 .519 r
F
.64719 .78816 m .68184 .7234 L .65109 .78983 L 0 0 .047 r
F
.65178 .79002 m .65172 .78986 L .65187 .78986 L 0 0 .067 r
F
.65109 .78983 m .68589 .87049 L .65184 .79015 L 0 0 .519 r
F
.64707 .78967 m .68589 .87049 L .65109 .78983 L F
.65074 .79202 m .65166 .78999 L .65178 .79002 L 0 0 .067 r
F
.65166 .78999 m .65172 .78986 L .65178 .79002 L F
.65178 .79002 m .65109 .78983 L .65184 .79015 L 0 0 .519 r
F
.65017 .79183 m .65102 .78999 L .65074 .79202 L 0 0 .067 r
F
.65102 .78999 m .68184 .7234 L .65165 .79002 L F
.65102 .78999 m .65165 .79002 L .65074 .79202 L F
.65172 .78986 m .68184 .7234 L .65187 .78986 L F
.6442 .77387 m .65178 .79002 L .65033 .77675 L 0 0 .519 r
F
.64483 .80336 m .65178 .79002 L .65092 .80327 L 0 0 .067 r
F
.65178 .79002 m .68944 .7178 L .6564 .7911 L F
.65178 .79002 m .69412 .88028 L .6564 .7911 L 0 0 .519 r
F
.65178 .79002 m .6564 .7911 L .65092 .80327 L 0 0 .067 r
F
.65178 .79002 m .6564 .7911 L .65602 .79019 L 0 0 .519 r
F
.65187 .78986 m .68184 .7234 L .68944 .7178 L 0 0 .067 r
F
.65178 .79002 m .65602 .79019 L .65033 .77675 L 0 0 .519 r
F
.6442 .77387 m .65109 .78983 L .65178 .79002 L F
.64675 .789 m .64719 .78816 L .65109 .78983 L 0 0 .047 r
F
.64707 .78967 m .65109 .78983 L .65065 .78975 L 0 0 .519 r
F
.64698 .78917 m .65106 .78976 L .6442 .77387 L F
.64707 .78967 m .65106 .78976 L .64698 .78917 L F
.64675 .789 m .64707 .78967 L .64695 .78899 L F
.64675 .789 m .65109 .78983 L .64483 .80336 L 0 0 .047 r
F
.65065 .78975 m .65109 .78983 L .65106 .78976 L 0 0 .519 r
F
.63813 .77105 m .64596 .78881 L .64675 .789 L F
.64606 .78901 m .64609 .78884 L .64675 .789 L 0 0 .047 r
F
.6456 .79114 m .64606 .78901 L .64675 .789 L F
.63813 .77105 m .64675 .789 L .6442 .77387 L 0 0 .519 r
F
.64675 .789 m .64695 .78899 L .6442 .77387 L F
.64483 .80336 m .65017 .79183 L .65074 .79202 L 0 0 .067 r
F
.63738 .78771 m .63786 .78687 L .64105 .78804 L 0 0 0 r
F
.63768 .7883 m .64105 .78804 L .63886 .78784 L 0 0 .516 r
F
.63738 .78771 m .63768 .7883 L .63751 .78769 L F
.63749 .78793 m .63779 .7886 L .63784 .78861 L F
.63738 .78771 m .64105 .78804 L .6328 .80483 L 0 0 0 r
F
.63886 .78784 m .64105 .78804 L .64064 .78715 L 0 0 .516 r
F
.63751 .78769 m .64064 .78715 L .6321 .7683 L F
.63768 .7883 m .64064 .78715 L .63751 .78769 L F
.62612 .76558 m .63641 .78756 L .63738 .78771 L F
.63717 .78775 m .6372 .78768 L .63738 .78771 L 0 0 0 r
F
.62612 .76558 m .63738 .78771 L .6321 .7683 L 0 0 .516 r
F
.63738 .78771 m .63751 .78769 L .6321 .7683 L F
.64109 .78829 m .64114 .78803 L .64193 .78822 L 0 0 .023 r
F
.64064 .79056 m .64109 .78829 L .64193 .78822 L F
.6321 .7683 m .64193 .78822 L .63813 .77105 L 0 0 .519 r
F
.64193 .78822 m .64209 .78821 L .63813 .77105 L F
.63879 .80386 m .64495 .79092 L .6456 .79114 L 0 0 .047 r
F
.64495 .79092 m .64621 .78829 L .6456 .79114 L F
.63317 .78749 m .63366 .78664 L .63641 .78756 L 0 0 0 r
F
.63346 .78804 m .63641 .78756 L .63441 .78752 L 0 0 .51 r
F
.63359 .78824 m .63673 .78825 L .63663 .78804 L F
.63356 .78824 m .63673 .78825 L .63359 .78824 L F
.63356 .78824 m .63663 .78804 L .63641 .78756 L F
.63317 .78749 m .63346 .78804 L .63327 .78746 L F
.63317 .78749 m .63641 .78756 L .62687 .80632 L 0 0 0 r
F
.63441 .78752 m .63641 .78756 L .63598 .78666 L 0 0 .51 r
F
.63327 .78746 m .63598 .78666 L .62612 .76558 L F
.63346 .78804 m .63598 .78666 L .63327 .78746 L F
.62019 .76288 m .63212 .7874 L .63317 .78749 L F
.6328 .80483 m .63993 .79032 L .64064 .79056 L 0 0 .023 r
F
.63993 .79032 m .6412 .78773 L .64064 .79056 L F
.63155 .78848 m .63187 .78787 L .63236 .78865 L 0 0 0 r
F
.63187 .78787 m .63291 .78757 L .63236 .78865 L F
.62019 .76288 m .63317 .78749 L .62612 .76558 L 0 0 .51 r
F
.63317 .78749 m .63327 .78746 L .62612 .76558 L F
.62687 .80632 m .63514 .79005 L .63591 .79032 L 0 0 0 r
F
.63069 .7901 m .63155 .78848 L .63146 .79042 L F
.63155 .78848 m .63236 .78865 L .63146 .79042 L F
.62867 .78628 m .62953 .78806 L .62966 .78809 L 0 0 .498 r
F
.6143 .76019 m .62784 .78664 L .62867 .78628 L F
.62466 .78918 m .62559 .78761 L .62561 .78842 L 0 0 0 r
F
.62466 .78918 m .62561 .78842 L .62512 .78928 L F
.60846 .75751 m .62617 .78797 L .6143 .76019 L 0 0 .477 r
F
.62617 .78797 m .62622 .78793 L .6143 .76019 L F
.62795 .78826 m .62833 .78759 L .62938 .78757 L 0 0 0 r
F
.6286 .78886 m .62795 .78826 L .62938 .78757 L F
.61514 .8113 m .62771 .78869 L .6286 .78886 L F
.62771 .78869 m .62795 .78826 L .6286 .78886 L F
.6143 .76019 m .62938 .78757 L .62019 .76288 L 0 0 .498 r
F
.62938 .78757 m .62946 .78754 L .62019 .76288 L F
.62098 .80844 m .63069 .7901 L .63146 .79042 L 0 0 0 r
F
.61988 .79725 m .62464 .78921 L .62267 .7936 L F
.62464 .78921 m .62512 .78928 L .62267 .7936 L F
.62349 .78904 m .62387 .78909 L .6237 .78878 L 0 0 .44 r
F
.6233 .78927 m .62387 .78909 L .62349 .78904 L F
.6233 .78927 m .6237 .78878 L .6228 .78712 L F
.62283 .78999 m .6233 .78927 L .6236 .78894 L 0 0 0 r
F
.6233 .78927 m .62371 .78877 L .6236 .78894 L F
.6229 .78995 m .6236 .78894 L .62299 .7899 L F
.62283 .78999 m .6236 .78894 L .6229 .78995 L F
.62404 .78912 m .62524 .78819 L .62475 .78728 L 0 0 .44 r
F
.62377 .78869 m .6242 .78802 L .62427 .78793 L 0 0 0 r
F
.62381 .78864 m .62475 .78728 L .60846 .75751 L 0 0 .44 r
F
.62404 .78912 m .62475 .78728 L .62381 .78864 L F
.6228 .78712 m .62359 .78858 L .62377 .78869 L F
.62359 .78858 m .62387 .78909 L .62377 .78869 L F
.62377 .78869 m .62524 .78819 L .62464 .78921 L 0 0 0 r
F
.62377 .78869 m .62404 .78912 L .62382 .78867 L 0 0 .44 r
F
.62283 .79011 m .62311 .79093 L .62314 .79097 L 0 0 .388 r
F
.62283 .79011 m .62314 .79097 L .62355 .79117 L F
.62308 .79106 m .6231 .79105 L .62314 .79097 L .769 0 .488 r
F
.62277 .79002 m .62288 .79043 L .62311 .79091 L 0 0 .388 r
F
.62277 .79002 m .62313 .79096 L .62283 .79011 L F
.62311 .79113 m .62312 .79101 L .62298 .79124 L 1 .558 .582 r
F
.62085 .7955 m .62336 .79172 L .62298 .79124 L F
.62336 .79172 m .62317 .79108 L .62298 .79124 L F
.62377 .78869 m .62464 .78921 L .60935 .81501 L 0 0 0 r
F
.60369 .81963 m .62377 .78869 L .60935 .81501 L F
.62377 .78869 m .62382 .78867 L .62381 .78864 L 0 0 .44 r
F
.62475 .78728 m .62524 .78819 L .62532 .78652 L 0 0 .477 r
F
.62524 .78819 m .62607 .788 L .62532 .78652 L F
.62512 .78928 m .62582 .78806 L .62534 .78931 L 0 0 0 r
F
.62582 .78806 m .62607 .788 L .62534 .78931 L F
.62534 .78931 m .62607 .788 L .62617 .78797 L F
.62532 .78652 m .62607 .788 L .62617 .78797 L 0 0 .477 r
F
.60846 .75751 m .62475 .78728 L .62532 .78652 L F
.62299 .7899 m .6236 .78894 L .62377 .78869 L 0 0 0 r
F
.60275 .75493 m .62377 .78869 L .60846 .75751 L 0 0 .44 r
F
.62377 .78869 m .62381 .78864 L .60846 .75751 L F
.62267 .7936 m .62512 .78928 L .62534 .78931 L 0 0 0 r
F
.60275 .75493 m .62289 .78859 L .6228 .78712 L 0 0 .44 r
F
.60935 .81501 m .61988 .79725 L .62267 .7936 L 0 0 0 r
F
.5982 .82583 m .59807 .82528 L .60369 .81963 L F
.5925 .83198 m .59795 .8247 L .59807 .82528 L .944 .194 .615 r
F
.58848 .8457 m .57603 .84772 L .58285 .85091 L .45 .18 .898 r
F
.58023 .84075 m .57603 .84772 L .58848 .8457 L .57 .429 .891 r
F
.55672 .86408 m .57733 .85449 L .58281 .84583 L .995 .74 .803 r
F
.56049 .86044 m .58281 .84583 L .58833 .83765 L .839 .305 .75 r
F
.56916 .84373 m .56249 .85012 L .57603 .84772 L .567 .406 .896 r
F
.58023 .84075 m .56916 .84373 L .57603 .84772 L .57 .429 .891 r
F
.55672 .86408 m .57619 .85046 L .56049 .86044 L .995 .74 .803 r
F
.57619 .85046 m .57924 .84833 L .57619 .8503 L F
.57619 .85046 m .57619 .8503 L .56049 .86044 L F
.57924 .84833 m .57914 .84834 L .56049 .86044 L F
.58033 .84757 m .57949 .848 L .56049 .86044 L F
.58523 .84019 m .58833 .83765 L .58364 .84162 L .839 .305 .75 r
F
.56049 .86044 m .57999 .84448 L .56429 .85801 L F
.59145 .83315 m .58833 .83765 L .59198 .83266 L .739 .011 .648 r
F
.57999 .84448 m .58523 .84019 L .58002 .84463 L .839 .305 .75 r
F
.57999 .84448 m .58002 .84463 L .56429 .85801 L F
.56959 .85316 m .584 .84124 L .59145 .83315 L .739 .011 .648 r
F
.584 .84124 m .58833 .83765 L .59145 .83315 L F
.58523 .84019 m .58364 .84162 L .56429 .85801 L .839 .305 .75 r
F
.5707 .85258 m .58833 .83765 L .56959 .85316 L .739 .011 .648 r
F
.56429 .85801 m .5707 .85258 L .56959 .85316 L F
.56429 .85801 m .59145 .83315 L .56682 .85706 L F
.59145 .83315 m .59198 .83266 L .58886 .83569 L F
.59145 .83315 m .58886 .83569 L .56682 .85706 L F
.56682 .85706 m .57542 .84872 L .57535 .84872 L .675 0 .566 r
F
.57535 .84872 m .59198 .83266 L .5925 .83198 L F
.57542 .84872 m .59198 .83266 L .57535 .84872 L F
.56682 .85706 m .59249 .83199 L .56718 .85696 L F
.59249 .83199 m .5925 .83198 L .58962 .83482 L F
.59249 .83199 m .58962 .83482 L .56718 .85696 L F
.56718 .85696 m .56961 .85456 L .56749 .85663 L .618 0 .527 r
F
.56718 .85696 m .56747 .85667 L .56718 .85696 L F
.56747 .85667 m .56961 .85456 L .56718 .85696 L F
.56749 .85663 m .5761 .84816 L .57608 .84783 L F
.56961 .85456 m .5761 .84816 L .56749 .85663 L F
.57608 .84783 m .5925 .83198 L .59807 .82528 L F
.5761 .84816 m .5925 .83198 L .57608 .84783 L F
.58027 .8461 m .59807 .82528 L .5982 .82583 L 0 0 0 r
F
.57104 .85653 m .58023 .8459 L .58027 .8461 L F
.58023 .8459 m .59807 .82528 L .58027 .8461 L F
.57924 .84833 m .58033 .84757 L .57914 .84834 L .995 .74 .803 r
F
.58033 .84757 m .58281 .84583 L .57949 .848 L F
.60914 .81123 m .62283 .78999 L .62299 .7899 L 0 0 0 r
F
.60369 .81963 m .60973 .81027 L .60914 .81123 L F
.60973 .81027 m .62283 .78999 L .60914 .81123 L F
.67036 .87426 m .6663 .86742 L .67522 .88368 L 0 0 .346 r
F
.63812 .81173 m .6663 .86742 L .67036 .87426 L F
.66146 .85927 m .67571 .89406 L .68244 .90732 L 0 0 .363 r
F
.66065 .85789 m .67571 .89406 L .66146 .85927 L F
.67571 .89406 m .67939 .90289 L .67966 .90328 L F
.67571 .89406 m .67966 .90328 L .68244 .90732 L F
.67939 .90289 m .68406 .92127 L .67939 .9029 L .276 0 .569 r
F
.67617 .89823 m .68406 .92127 L .67939 .90289 L F
.68406 .92127 m .68858 .93195 L .67939 .9029 L F
.66386 .86583 m .67939 .90289 L .66558 .86973 L .717 0 0 r
F
.66128 .85999 m .66537 .86967 L .66386 .86583 L F
.66537 .86967 m .67939 .90289 L .66386 .86583 L F
.68225 .94462 m .68246 .94593 L .68059 .94848 L .992 .001 .255 r
F
.67835 .91974 m .67957 .91468 L .68406 .92127 L F
.66944 .91737 m .67737 .91145 L .67835 .91974 L F
.68059 .94848 m .68246 .94593 L .68275 .94814 L .936 0 .294 r
F
.66883 .86931 m .66925 .87083 L .66906 .87043 L .471 0 .531 r
F
.66883 .86931 m .66906 .87043 L .66639 .86508 L F
.66856 .86799 m .66926 .86949 L .66927 .87149 L 0 0 .543 r
F
.66944 .91737 m .67835 .91974 L .68059 .94848 L .992 .001 .255 r
F
.67835 .91974 m .68225 .94462 L .68059 .94848 L F
.69144 .92323 m .69781 .92493 L .69473 .92914 L F
.69473 .92914 m .69781 .92493 L .70658 .94441 L .936 0 .294 r
F
.69144 .92323 m .68296 .90728 L .69518 .92423 L .992 .001 .255 r
F
.68296 .90728 m .68588 .9051 L .69518 .92423 L F
.68578 .89031 m .68578 .89031 L .68558 .89023 L .364 .11 .865 r
F
.68463 .88989 m .68692 .8906 L .68577 .89035 L .339 0 0 r
F
.68564 .89083 m .68808 .89109 L .69917 .89581 L F
.69497 .87865 m .69848 .82234 L .69612 .8776 L 1 .101 .404 r
F
.69911 .82291 m .69885 .82274 L .69915 .82315 L .07 0 .519 r
F
.6985 .82203 m .70003 .79736 L .69881 .82247 L 1 .101 .404 r
F
.69849 .82237 m .69885 .82273 L .69881 .82247 L 1 .02 .248 r
F
.6988 .82246 m .69881 .82247 L .69881 .82247 L 1 .101 .404 r
F
.6985 .82203 m .69881 .82247 L .6988 .82246 L F
.69848 .82234 m .69848 .82229 L .69848 .8223 L F
.69228 .78561 m .69892 .79622 L .69842 .82198 L 1 .02 .248 r
F
.69848 .82229 m .69867 .79167 L .69848 .8223 L 1 .101 .404 r
F
.69906 .7987 m .69892 .79622 L .69906 .79865 L 1 .02 .248 r
F
.69848 .8223 m .69867 .79167 L .70003 .79736 L 1 .101 .404 r
F
.69228 .78561 m .69867 .79167 L .69865 .79578 L 1 .02 .248 r
F
.69849 .82235 m .69881 .82247 L .69348 .78693 L F
.69849 .82237 m .69881 .82247 L .69849 .82235 L F
.69717 .81051 m .69882 .82248 L .69911 .82291 L .07 0 .519 r
F
.69882 .82248 m .69885 .82274 L .69911 .82291 L F
.69848 .82234 m .6985 .82203 L .69814 .83627 L 1 .101 .404 r
F
.69853 .82263 m .69862 .82266 L .69849 .82237 L 1 .02 .248 r
F
.69862 .82266 m .69885 .82273 L .69849 .82237 L F
.69848 .82234 m .69853 .82263 L .69849 .82237 L F
.6985 .82203 m .69881 .82247 L .69814 .83627 L 1 .101 .404 r
F
.69848 .82234 m .69814 .83627 L .69612 .8776 L F
.69349 .78694 m .69731 .81246 L .69717 .81051 L .07 0 .519 r
F
.69731 .81246 m .69885 .82274 L .69717 .81051 L F
.69736 .80267 m .69915 .82315 L .70406 .82991 L F
.69349 .78694 m .69915 .82315 L .69736 .80267 L F
.71029 .76982 m .71588 .81763 L .7224 .76183 L 1 .428 .631 r
F
.70004 .79729 m .71462 .75369 L .71331 .81107 L 1 .023 .372 r
F
.69349 .78694 m .7062 .8386 L .70637 .80028 L .07 0 .519 r
F
.7062 .8386 m .71221 .86303 L .71 .83929 L F
.7075 .83883 m .71233 .81488 L .71068 .83923 L .909 .01 .405 r
F
.7094 .83918 m .71068 .83923 L .71067 .83942 L F
.7075 .83883 m .71068 .83923 L .7094 .83918 L F
.70003 .8625 m .7062 .8386 L .70013 .87537 L F
.7062 .8386 m .71233 .81488 L .7075 .83883 L F
.7062 .8386 m .7075 .83883 L .70013 .87537 L F
.71221 .86303 m .71451 .86855 L .71105 .83948 L .07 0 .519 r
F
.71221 .86303 m .71105 .83948 L .71 .83929 L F
.71233 .81488 m .71303 .81456 L .71105 .83948 L .909 .01 .405 r
F
.71067 .83949 m .71105 .83948 L .70856 .87068 L F
.71233 .81488 m .71105 .83948 L .71067 .83949 L F
.71765 .84497 m .7154 .87596 L .72887 .88944 L .564 .015 .577 r
F
.71759 .84475 m .71758 .84494 L .71765 .84497 L F
.71758 .84494 m .7154 .87596 L .71765 .84497 L F
.71759 .84475 m .72647 .81929 L .72373 .84661 L .841 .001 .369 r
F
.72366 .8466 m .72373 .84661 L .72373 .84662 L F
.71759 .84475 m .72373 .84661 L .72366 .8466 L F
.73447 .75374 m .72773 .81673 L .73971 .81561 L 1 .386 .612 r
F
.7224 .76183 m .72772 .81673 L .73447 .75374 L 1 .404 .62 r
F
.72773 .81673 m .72865 .88757 L .73971 .81561 L 1 .307 .608 r
F
.7224 .76183 m .71588 .81763 L .72772 .81673 L 1 .404 .62 r
F
.73447 .75374 m .73971 .81561 L .74667 .74552 L 1 .386 .612 r
F
.72647 .81928 m .72792 .76631 L .74114 .77514 L .931 .002 .339 r
F
.71331 .81107 m .72792 .76631 L .72647 .81928 L 1 .01 .358 r
F
.74667 .74552 m .73971 .81561 L .75165 .81433 L 1 .372 .606 r
F
.73971 .81561 m .74017 .89331 L .75165 .81433 L 1 .306 .603 r
F
.73971 .81561 m .72865 .88757 L .74017 .89331 L F
.72647 .81928 m .74114 .77514 L .73967 .82687 L .931 .002 .339 r
F
.71759 .84475 m .71331 .81108 L .72647 .81929 L .841 .001 .369 r
F
.71105 .83948 m .71106 .83924 L .71759 .84475 L F
.71106 .83924 m .71331 .81108 L .71759 .84475 L F
.71625 .83944 m .71615 .8436 L .71759 .84475 L .564 .015 .577 r
F
.71615 .8436 m .71614 .84431 L .71759 .84475 L F
.71614 .84431 m .7154 .87596 L .71759 .84475 L F
.71105 .83948 m .7154 .87596 L .71625 .83944 L F
.70856 .87068 m .71105 .83948 L .71759 .84475 L .841 .001 .369 r
F
.71625 .83944 m .71759 .84475 L .72284 .83968 L .564 .015 .577 r
F
.71759 .84475 m .71765 .84497 L .71774 .84488 L F
.71759 .84475 m .72373 .84662 L .72371 .84685 L .841 .001 .369 r
F
.71759 .84475 m .71774 .84488 L .71779 .84482 L .564 .015 .577 r
F
.71765 .84497 m .72887 .88944 L .72389 .84839 L F
.71765 .84497 m .72389 .84839 L .72371 .84685 L F
.71927 .84332 m .72371 .84685 L .72284 .83968 L F
.71765 .84497 m .72371 .84685 L .71927 .84332 L F
.72979 .85073 m .72647 .81929 L .73966 .82688 L .829 0 .344 r
F
.7294 .85047 m .72647 .81929 L .72979 .85073 L F
.72371 .84685 m .72647 .81929 L .7294 .85049 L F
.72371 .84685 m .72389 .84839 L .72979 .85073 L .63 .031 .581 r
F
.72389 .84839 m .72887 .88944 L .72979 .85073 L F
.75165 .81433 m .74017 .89331 L .75166 .89877 L 1 .305 .598 r
F
.72979 .85073 m .72887 .88944 L .74229 .89916 L .63 .031 .581 r
F
.72979 .85073 m .74229 .89916 L .73691 .85558 L F
.72979 .85073 m .73966 .82688 L .73671 .85349 L .829 0 .344 r
F
.72979 .85073 m .73691 .85558 L .73668 .85376 L .63 .031 .581 r
F
.72979 .85073 m .73671 .85349 L .73668 .85376 L .829 0 .344 r
F
.72979 .85073 m .73668 .85376 L .73615 .84946 L .63 .031 .581 r
F
.72979 .85073 m .73668 .85376 L .73659 .85466 L .829 0 .344 r
F
.72964 .8511 m .72979 .85073 L .73659 .85466 L F
.72371 .84685 m .7294 .85049 L .72949 .85145 L F
.71921 .80976 m .72371 .84685 L .72979 .85073 L .63 .031 .581 r
F
.72904 .84783 m .72979 .85073 L .73615 .84946 L F
.72949 .85145 m .7294 .85047 L .72979 .85073 L .829 0 .344 r
F
.72125 .87136 m .72371 .84685 L .72949 .85145 L F
.71759 .84475 m .72371 .84685 L .7221 .86292 L .841 .001 .369 r
F
.71759 .84475 m .71779 .84482 L .72284 .83968 L .564 .015 .577 r
F
.71921 .80976 m .72904 .84783 L .732 .81583 L .63 .031 .581 r
F
.72904 .84783 m .73615 .84946 L .732 .81583 L F
.72125 .87136 m .72949 .85145 L .73414 .87671 L .829 0 .344 r
F
.72949 .85145 m .72964 .8511 L .72972 .85157 L F
.72949 .85145 m .72972 .85157 L .73414 .87671 L F
.72964 .8511 m .73659 .85466 L .73414 .87671 L F
.7149 .8525 m .71759 .84475 L .7221 .86292 L .841 .001 .369 r
F
.70637 .80028 m .71105 .83948 L .71625 .83944 L .564 .015 .577 r
F
.71 .83929 m .71105 .83948 L .70637 .80028 L .07 0 .519 r
F
.71233 .81488 m .71331 .81108 L .71303 .81456 L .909 .01 .405 r
F
.71331 .81107 m .71462 .75369 L .72792 .76631 L 1 .01 .358 r
F
.70637 .80028 m .71625 .83944 L .71921 .80976 L .564 .015 .577 r
F
.71625 .83944 m .72284 .83968 L .71921 .80976 L F
.7062 .8386 m .71 .83929 L .70637 .80028 L .07 0 .519 r
F
.70013 .87537 m .7075 .83883 L .70856 .87068 L .909 .01 .405 r
F
.7075 .83883 m .71067 .83942 L .70856 .87068 L F
.69612 .8776 m .70003 .8625 L .70013 .87537 L F
.70925 1.02251 m .71015 1.04346 L .70969 1.02341 L .941 .159 .6 r
F
.69925 1.01372 m .70467 1.03724 L .70836 1.02581 L .245 0 .704 r
F
.70837 1.02581 m .70467 1.03725 L .70593 1.0388 L .167 0 .694 r
F
.69894 .98938 m .70889 1.04307 L .70809 1.00775 L .964 .189 .613 r
F
.70867 1.00923 m .70867 1.00963 L .7087 1.00975 L .36 .001 .64 r
F
.70867 1.00923 m .7081 1.00776 L .70869 1.00949 L .941 .159 .6 r
F
.70869 1.00949 m .70889 1.04308 L .71015 1.04346 L F
.70809 1.00776 m .70889 1.04308 L .70869 1.00949 L F
.69228 .78561 m .69848 .82234 L .69348 .78693 L 1 .02 .248 r
F
.69848 .82234 m .69849 .82237 L .69348 .78693 L F
.71221 .86303 m .7154 .87596 L .71451 .86855 L .07 0 .519 r
F
.69497 .87865 m .69717 .82692 L .69717 .82694 L 1 .101 .404 r
F
.69228 .78561 m .69866 .79137 L .69867 .79167 L 1 .02 .248 r
F
.70333 .83233 m .70129 .83902 L .7062 .8386 L .07 0 .519 r
F
.69742 .87257 m .69881 .82248 L .7062 .8386 L .909 .01 .405 r
F
.69612 .8776 m .69813 .83638 L .69742 .87257 L F
.69813 .83638 m .69881 .82248 L .69742 .87257 L F
.70856 .87068 m .7149 .8525 L .72125 .87136 L .841 .001 .369 r
F
.7149 .8525 m .7221 .86292 L .72125 .87136 L F
.70406 .82991 m .70333 .83233 L .7062 .8386 L .07 0 .519 r
F
.59708 .75252 m .62133 .78792 L .60275 .75493 L 0 0 .388 r
F
.62133 .78792 m .62142 .78614 L .60275 .75493 L F
.65362 .74064 m .65411 .73939 L .65346 .74089 L 1 .269 .494 r
F
.64928 .73801 m .66225 .69529 L .65062 .73473 L 0 0 .109 r
F
.66225 .69529 m .66382 .6901 L .66266 .69401 L F
.66225 .69529 m .66266 .69401 L .65062 .73473 L F
.65424 .71615 m .65426 .71615 L .65439 .71106 L 1 .281 .456 r
F
.66569 .71868 m .66957 .71954 L .66981 .71903 L 1 .794 .651 r
F
.6487 .73994 m .65439 .71105 L .66382 .6901 L 0 0 .109 r
F
.65436 .71118 m .65439 .71105 L .6487 .73994 L F
.64657 .74124 m .65439 .71106 L .64663 .74106 L 1 .281 .456 r
F
.63946 .75594 m .64073 .75542 L .63804 .75928 L .758 .229 .778 r
F
.64653 .74145 m .65439 .71106 L .64658 .74132 L 1 .281 .456 r
F
.65887 .73873 m .66195 .73441 L .66081 .73372 L .838 .001 .476 r
F
.6536 .71379 m .65862 .68557 L .65359 .71059 L 1 .794 .651 r
F
.65631 .67309 m .65928 .67845 L .65946 .67643 L 1 .18 .585 r
F
.65631 .67309 m .659 .68152 L .65928 .67845 L F
.66227 .6274 m .6641 .63463 L .6644 .63147 L .852 .089 .571 r
F
.68204 .6652 m .69072 .6818 L .68587 .66295 L F
.65344 .67004 m .65518 .67524 L .65631 .67309 L 1 .18 .585 r
F
.65518 .67524 m .65665 .67965 L .65631 .67309 L F
.65276 .66939 m .65844 .62264 L .6521 .61563 L .372 0 .398 r
F
.65152 .69008 m .64478 .61288 L .65316 .69938 L 1 .134 .353 r
F
.63201 .65253 m .63665 .66584 L .6492 .66965 L .514 .171 .773 r
F
.63201 .65253 m .6492 .66965 L .64407 .65313 L F
.63678 .6044 m .64478 .61288 L .65152 .69008 L 1 .134 .353 r
F
.65309 .69898 m .65316 .69938 L .65319 .69975 L 1 .172 .407 r
F
.65309 .69898 m .65319 .69975 L .65316 .69961 L F
.63632 .60391 m .65152 .69008 L .65261 .69642 L 1 .134 .353 r
F
.65152 .69008 m .65316 .69938 L .65261 .69642 L F
.61796 .56359 m .6251 .57671 L .627 .54897 L .047 0 .605 r
F
.6251 .57671 m .62761 .55117 L .627 .54897 L F
.626 .54536 m .64478 .61288 L .63632 .60391 L 1 .134 .353 r
F
.63569 .59632 m .63934 .58693 L .65309 .69898 L 1 .172 .407 r
F
.63569 .59632 m .65309 .69898 L .65261 .69642 L F
.63934 .58693 m .65316 .69938 L .65309 .69898 L F
.626 .54536 m .62913 .55661 L .62913 .55661 L 1 .134 .353 r
F
.62586 .53823 m .64395 .57506 L .64358 .576 L 1 .172 .407 r
F
.62721 .5462 m .64358 .576 L .63569 .59632 L F
.62586 .53823 m .64358 .576 L .62721 .5462 L F
.59208 .50979 m .61745 .53427 L .59884 .50353 L .19 0 .733 r
F
.59208 .50979 m .60911 .5319 L .61745 .53427 L F
.59884 .50353 m .61745 .53427 L .62586 .53823 L .144 0 .677 r
F
.60598 .5201 m .626 .54536 L .62627 .54449 L 1 .254 .598 r
F
.62805 .5388 m .62878 .54342 L .62934 .54001 L 1 .134 .353 r
F
.62805 .5388 m .62934 .54001 L .6312 .52872 L F
.62927 .52806 m .62805 .5388 L .6312 .52872 L 1 .254 .598 r
F
.62417 .52632 m .62805 .5388 L .62927 .52806 L F
.62878 .54342 m .63709 .5745 L .63322 .54437 L 1 .134 .353 r
F
.62919 .5409 m .63322 .54437 L .6312 .52872 L F
.62878 .54342 m .63322 .54437 L .62919 .5409 L F
.61949 .51096 m .62153 .5165 L .62087 .51407 L .351 0 .624 r
F
.61005 .48965 m .61855 .50954 L .61836 .50841 L F
.62061 .52426 m .62456 .53549 L .62697 .53696 L .273 0 .642 r
F
.62061 .52426 m .62697 .53696 L .62638 .53516 L F
.6056 .49589 m .62236 .5309 L .62061 .52426 L F
.62236 .5309 m .62456 .53549 L .62061 .52426 L F
.62329 .52588 m .6275 .53728 L .62339 .52605 L F
.6056 .49589 m .62635 .5351 L .62329 .52588 L F
.62635 .5351 m .6275 .53728 L .62329 .52588 L F
.6056 .49589 m .62339 .52605 L .61005 .48966 L F
.62339 .52605 m .62417 .52632 L .6225 .51878 L 1 .254 .598 r
F
.62417 .52632 m .6312 .52872 L .6225 .51878 L F
.62417 .52632 m .6225 .51878 L .6225 .51878 L F
.62339 .52605 m .6225 .51878 L .61005 .48966 L .273 0 .642 r
F
.61977 .5124 m .62153 .5165 L .61949 .51096 L .351 0 .624 r
F
.62087 .51407 m .62184 .51642 L .62176 .51608 L F
.62185 .51617 m .63121 .52871 L .63194 .52605 L 1 .274 .59 r
F
.62186 .51621 m .63121 .52871 L .62185 .51617 L F
.62249 .51877 m .63121 .52871 L .62176 .51608 L F
.61005 .48965 m .62176 .51608 L .61068 .48868 L .351 0 .624 r
F
.62176 .51608 m .62185 .51617 L .62171 .51565 L 1 .274 .59 r
F
.62185 .51617 m .63194 .52605 L .62158 .5145 L F
.62176 .51608 m .62186 .51621 L .62185 .51617 L F
.62176 .51608 m .63221 .53967 L .62158 .5145 L .351 0 .624 r
F
.62176 .51608 m .62158 .5145 L .61068 .48868 L F
.62176 .51608 m .62171 .51565 L .62133 .51422 L 1 .274 .59 r
F
.62185 .51617 m .62158 .5145 L .62133 .51422 L F
.63194 .52605 m .64124 .56407 L .65962 .52038 L 1 .165 .513 r
F
.64395 .57506 m .64395 .57506 L .63569 .59632 L 1 .172 .407 r
F
.64124 .56407 m .65201 .60815 L .6534 .59213 L 1 .165 .513 r
F
.64124 .56407 m .6534 .59213 L .65962 .52038 L F
.61824 .50052 m .63194 .52605 L .63967 .49448 L 1 .275 .581 r
F
.61068 .48868 m .62137 .51398 L .62023 .50883 L .454 .009 .619 r
F
.61068 .48868 m .61896 .50615 L .61824 .50052 L F
.61896 .50615 m .62023 .50883 L .61824 .50052 L F
.61068 .48868 m .61791 .5 L .61741 .47671 L F
.61458 .47149 m .61741 .47671 L .61755 .4764 L .689 .079 .62 r
F
.59276 .43553 m .61455 .47194 L .61458 .47149 L F
.61455 .47194 m .61741 .47671 L .61458 .47149 L F
.59276 .43553 m .61553 .47306 L .61644 .45559 L F
.61553 .47306 m .61755 .4764 L .61655 .4575 L F
.61553 .47306 m .61655 .4575 L .61644 .45559 L F
.61719 .45532 m .61751 .47546 L .62387 .44959 L 1 .447 .607 r
F
.61751 .47546 m .61755 .4764 L .62387 .44959 L F
.61644 .45559 m .61755 .4764 L .61666 .45577 L .689 .079 .62 r
F
.61666 .45577 m .61753 .4765 L .61719 .45532 L 1 .447 .607 r
F
.58383 .46428 m .61005 .48966 L .5872 .45417 L .592 .076 .658 r
F
.58383 .46428 m .6056 .49589 L .61005 .48966 L F
.5872 .45417 m .61068 .48868 L .58768 .45267 L .602 .068 .645 r
F
.5872 .45417 m .61005 .48965 L .61068 .48868 L F
.58768 .45266 m .61444 .47431 L .59276 .43553 L .644 .077 .637 r
F
.61444 .47431 m .61448 .47348 L .59276 .43553 L F
.6154 .47509 m .6155 .47352 L .59276 .43553 L F
.61492 .4543 m .61547 .44712 L .59783 .41654 L .689 .079 .62 r
F
.61666 .45577 m .62387 .44959 L .61727 .45024 L 1 .447 .607 r
F
.62387 .44959 m .64732 .46094 L .65493 .42787 L 1 .383 .581 r
F
.61743 .4336 m .62387 .44959 L .63027 .42116 L 1 .473 .603 r
F
.59783 .41654 m .61598 .44801 L .61743 .4336 L .725 .081 .609 r
F
.61598 .44801 m .61727 .45024 L .61743 .4336 L F
.59783 .41654 m .61743 .4336 L .60287 .39591 L F
.61743 .4336 m .63027 .42116 L .61865 .4238 L 1 .473 .603 r
F
.61743 .4336 m .63076 .4452 L .61865 .4238 L .725 .081 .609 r
F
.61743 .4336 m .61865 .4238 L .60287 .39591 L F
.61743 .4336 m .61865 .4238 L .61841 .42386 L 1 .473 .603 r
F
.61635 .43465 m .61743 .4336 L .61685 .42421 L F
.61743 .4336 m .61841 .42386 L .61685 .42421 L F
.61492 .4543 m .61666 .45577 L .61547 .44712 L .689 .079 .62 r
F
.61666 .45577 m .61728 .45629 L .61668 .44921 L F
.61728 .45629 m .6241 .46208 L .61727 .45024 L F
.61728 .45629 m .61727 .45024 L .61668 .44921 L F
.61726 .43377 m .61727 .45024 L .61743 .4336 L 1 .473 .603 r
F
.61666 .45577 m .61668 .44921 L .61547 .44712 L .689 .079 .62 r
F
.59835 .4521 m .61727 .45024 L .61726 .43377 L 1 .473 .603 r
F
.61727 .45024 m .62387 .44959 L .61743 .4336 L F
.61743 .4336 m .61727 .45024 L .61913 .43509 L .725 .081 .609 r
F
.61913 .43509 m .6241 .46208 L .63076 .4452 L F
.61727 .45024 m .6241 .46208 L .61913 .43509 L F
.61673 .45462 m .61727 .45024 L .61702 .45027 L 1 .447 .607 r
F
.61666 .45577 m .61727 .45024 L .61673 .45462 L F
.59835 .4521 m .6163 .43471 L .60335 .42728 L 1 .473 .603 r
F
.6163 .43471 m .61635 .43465 L .6163 .43462 L F
.6163 .43471 m .6163 .43462 L .60335 .42728 L F
.61444 .47431 m .6154 .47509 L .61448 .47348 L .644 .077 .637 r
F
.6154 .47509 m .61741 .47671 L .6155 .47352 L F
.58768 .45266 m .61068 .48868 L .61548 .48014 L F
.6154 .47509 m .61548 .48014 L .61741 .47671 L F
.58768 .45266 m .61548 .48014 L .6154 .47509 L F
.59331 .47579 m .61511 .4571 L .59835 .4521 L 1 .447 .607 r
F
.61511 .4571 m .61663 .4558 L .61509 .45548 L F
.61511 .4571 m .61509 .45548 L .59835 .4521 L F
.61663 .4558 m .61666 .45577 L .61663 .45577 L F
.61663 .4558 m .61663 .45577 L .59835 .4521 L F
.59331 .47579 m .61661 .47647 L .61666 .45577 L F
.61661 .47647 m .61753 .4765 L .61666 .45577 L F
.61666 .45577 m .61755 .4764 L .6241 .46208 L .689 .079 .62 r
F
.61751 .47546 m .61753 .4765 L .61755 .4764 L 1 .447 .607 r
F
.61666 .45577 m .61702 .45027 L .59835 .4521 L F
.61635 .43465 m .61685 .42421 L .60335 .42728 L 1 .473 .603 r
F
.59331 .47579 m .61742 .47699 L .61753 .4765 L 1 .447 .607 r
F
.61791 .5 m .61824 .50052 L .61764 .48329 L .454 .009 .619 r
F
.61791 .5 m .61764 .48329 L .61741 .47671 L F
.61824 .50052 m .63967 .49448 L .61788 .48807 L 1 .275 .581 r
F
.61824 .50052 m .61759 .47801 L .61741 .47671 L .454 .009 .619 r
F
.61483 .48717 m .61745 .48794 L .61742 .47699 L 1 .275 .581 r
F
.61759 .47801 m .61757 .47711 L .61741 .47671 L .454 .009 .619 r
F
.61788 .48807 m .63967 .49448 L .61757 .47711 L 1 .275 .581 r
F
.62145 .50554 m .61757 .47711 L .61759 .47801 L .454 .009 .619 r
F
.61745 .48794 m .61788 .48807 L .61757 .47711 L 1 .275 .581 r
F
.61745 .48794 m .61757 .47711 L .61742 .47699 L F
.61757 .47696 m .64055 .53548 L .64878 .52494 L .59 .031 .598 r
F
.61755 .47692 m .61757 .47698 L .61757 .47696 L F
.61757 .47698 m .64055 .53548 L .61757 .47696 L F
.61824 .50052 m .62145 .50554 L .61759 .47801 L .454 .009 .619 r
F
.61824 .50052 m .61788 .48807 L .61661 .4877 L 1 .275 .581 r
F
.61749 .50073 m .61824 .50052 L .61483 .48717 L F
.61824 .50052 m .61661 .4877 L .61483 .48717 L F
.61836 .50841 m .61977 .5124 L .61949 .51096 L .351 0 .624 r
F
.61855 .50954 m .61977 .5124 L .61836 .50841 L F
.61091 .50258 m .62158 .51449 L .61824 .50052 L 1 .275 .581 r
F
.62158 .51449 m .63194 .52605 L .61824 .50052 L F
.61824 .50052 m .62023 .50883 L .61847 .50088 L .454 .009 .619 r
F
.63121 .52871 m .65201 .60821 L .63194 .52605 L 1 .198 .462 r
F
.64203 .60887 m .64681 .61365 L .65316 .69938 L 1 .172 .407 r
F
.63934 .58693 m .64656 .61031 L .64681 .61365 L F
.63934 .58693 m .64681 .61365 L .64203 .60887 L F
.63121 .52871 m .6531 .69535 L .65201 .60821 L 1 .198 .462 r
F
.61972 .50283 m .63221 .53967 L .64055 .53548 L .454 .009 .619 r
F
.61847 .50088 m .62018 .50569 L .61972 .50283 L F
.62018 .50569 m .63221 .53967 L .61972 .50283 L F
.62137 .51398 m .63221 .53967 L .61847 .50088 L F
.62184 .51642 m .62188 .51652 L .62176 .51608 L .351 0 .624 r
F
.62153 .5165 m .63142 .53967 L .62087 .51407 L F
.6103 .50486 m .62249 .51877 L .62176 .51608 L 1 .274 .59 r
F
.62188 .51652 m .63142 .53967 L .62176 .51608 L .351 0 .624 r
F
.62203 .5167 m .63142 .53967 L .63221 .53967 L F
.62176 .51608 m .62206 .51681 L .62203 .5167 L F
.62206 .51681 m .63142 .53967 L .62203 .5167 L F
.62339 .52605 m .62609 .53343 L .62417 .52632 L 1 .254 .598 r
F
.62609 .53343 m .62805 .5388 L .62417 .52632 L F
.62339 .52605 m .63142 .53967 L .6225 .51878 L .273 0 .642 r
F
.62339 .52605 m .6225 .51878 L .62011 .51606 L 1 .254 .598 r
F
.6103 .50486 m .61921 .51358 L .61091 .50259 L 1 .274 .59 r
F
.61921 .51358 m .62176 .51608 L .61883 .51244 L F
.61921 .51358 m .61883 .51244 L .61091 .50259 L F
.59884 .50353 m .62586 .53823 L .6056 .49589 L .144 0 .677 r
F
.60598 .5201 m .62339 .52605 L .6103 .50486 L 1 .254 .598 r
F
.62339 .52605 m .62011 .51606 L .6103 .50486 L F
.62638 .53516 m .62697 .53696 L .6275 .53728 L .273 0 .642 r
F
.57359 .48992 m .59884 .50353 L .57872 .47799 L .549 .122 .719 r
F
.57359 .48992 m .59208 .50979 L .59884 .50353 L F
.57872 .47799 m .6056 .49589 L .58383 .46428 L .566 .092 .686 r
F
.57872 .47799 m .59884 .50353 L .6056 .49589 L F
.58825 .49803 m .61091 .50258 L .61288 .49486 L 1 .425 .615 r
F
.61124 .48864 m .61288 .49486 L .61483 .48717 L F
.58825 .49803 m .61288 .49486 L .61124 .48864 L F
.61359 .47975 m .61483 .48717 L .61742 .47699 L F
.58825 .49803 m .61483 .48717 L .61359 .47975 L F
.61091 .50258 m .61749 .50073 L .61483 .48717 L 1 .275 .581 r
F
.62176 .51608 m .62133 .51422 L .61091 .50259 L 1 .274 .59 r
F
.62456 .53549 m .62805 .5388 L .63142 .53967 L .273 0 .642 r
F
.61447 .523 m .62805 .5388 L .62339 .52605 L 1 .254 .598 r
F
.62339 .52605 m .6275 .53728 L .63142 .53967 L .273 0 .642 r
F
.62456 .53549 m .62586 .53823 L .62805 .5388 L F
.65261 .69642 m .65309 .69898 L .6532 .6999 L 1 .172 .407 r
F
.65261 .69642 m .65316 .69938 L .6532 .69974 L 1 .134 .353 r
F
.65253 .6959 m .6532 .69974 L .62805 .5388 L F
.62805 .5388 m .62777 .54952 L .62881 .53899 L 1 .172 .407 r
F
.62586 .53823 m .62721 .5462 L .62805 .5388 L F
.62721 .5462 m .62777 .54952 L .62805 .5388 L F
.61447 .523 m .62627 .54449 L .62805 .5388 L 1 .254 .598 r
F
.60598 .5201 m .62627 .54449 L .61447 .523 L F
.63142 .53967 m .63768 .57668 L .63221 .53967 L 1 .177 .476 r
F
.63768 .57668 m .64074 .59484 L .63829 .57897 L F
.63768 .57668 m .63829 .57897 L .63221 .53967 L F
.62878 .54342 m .6532 .69974 L .63709 .5745 L 1 .134 .353 r
F
.62777 .54952 m .65261 .69642 L .62853 .54184 L 1 .172 .407 r
F
.63632 .60391 m .63678 .6044 L .65152 .69008 L 1 .134 .353 r
F
.62627 .54449 m .65253 .6959 L .62805 .5388 L F
.65261 .69642 m .6532 .69974 L .62627 .54449 L F
.62853 .54184 m .65261 .69642 L .62881 .53899 L 1 .172 .407 r
F
.65261 .69642 m .6532 .6999 L .65312 .69939 L F
.65261 .69642 m .65312 .69939 L .62881 .53899 L F
.63616 .5875 m .65312 .69939 L .63819 .58948 L F
.65312 .69939 m .6532 .6999 L .65316 .69961 L F
.65312 .69939 m .65316 .69961 L .63819 .58948 L F
.64074 .59484 m .65085 .65467 L .64129 .59543 L 1 .177 .476 r
F
.65085 .65467 m .65344 .67 L .65048 .65187 L F
.65085 .65467 m .65048 .65187 L .64129 .59543 L F
.65835 .61874 m .66409 .53825 L .65874 .61881 L .372 0 .398 r
F
.66409 .53825 m .66417 .5371 L .66499 .53715 L F
.66417 .5371 m .66417 .5371 L .66509 .53584 L F
.6521 .61563 m .66512 .53544 L .65201 .6082 L F
.65844 .62264 m .66512 .53544 L .6521 .61563 L F
.65316 .69961 m .65319 .69975 L .6532 .6999 L 1 .172 .407 r
F
.626 .54536 m .65261 .69642 L .62627 .54449 L 1 .134 .353 r
F
.64074 .59484 m .64129 .59543 L .63221 .53967 L 1 .177 .476 r
F
.6251 .57671 m .6259 .57881 L .62674 .57972 L .047 0 .605 r
F
.6259 .57881 m .63486 .6025 L .62674 .57972 L F
.61796 .56359 m .6226 .57428 L .6251 .57671 L F
.6226 .57428 m .63486 .6025 L .6251 .57671 L F
.62881 .53899 m .63616 .5875 L .63142 .53967 L 1 .172 .407 r
F
.63616 .5875 m .63819 .58948 L .63142 .53967 L F
.66452 .53876 m .66505 .53582 L .67038 .53224 L .07 0 .237 r
F
.66505 .53582 m .66506 .53577 L .66509 .53575 L F
.66505 .53582 m .66509 .53575 L .67038 .53224 L F
.66506 .53577 m .66512 .53543 L .66534 .5353 L F
.66506 .53577 m .66534 .5353 L .67038 .53224 L F
.65201 .60814 m .66452 .53876 L .67038 .53224 L F
.61741 .47671 m .61755 .47692 L .61755 .4764 L .59 .031 .598 r
F
.61755 .47642 m .61755 .47692 L .61755 .4764 L 1 .326 .578 r
F
.61741 .47671 m .61754 .47705 L .61755 .47692 L .59 .031 .598 r
F
.61742 .47699 m .61755 .47692 L .61755 .47642 L 1 .326 .578 r
F
.61754 .47705 m .61757 .47711 L .61755 .47692 L .59 .031 .598 r
F
.61757 .47711 m .64055 .53548 L .61755 .47692 L F
.61755 .47692 m .63967 .49448 L .64732 .46094 L 1 .326 .578 r
F
.61754 .47692 m .61755 .47693 L .61755 .47692 L F
.61742 .47699 m .61757 .47711 L .61754 .47692 L F
.62145 .50554 m .64055 .53548 L .61757 .47711 L .454 .009 .619 r
F
.61755 .4764 m .64878 .52494 L .6241 .46208 L .59 .031 .598 r
F
.61755 .47692 m .61758 .4769 L .61755 .4764 L 1 .326 .578 r
F
.61755 .47692 m .64878 .52494 L .61755 .4764 L .59 .031 .598 r
F
.61886 .40995 m .61783 .42235 L .61928 .41032 L .752 .084 .602 r
F
.60287 .39591 m .61757 .42189 L .61886 .40995 L F
.61757 .42189 m .61783 .42235 L .61886 .40995 L F
.60796 .37355 m .62106 .39697 L .62185 .38602 L .772 .087 .597 r
F
.61928 .41032 m .63027 .42116 L .63674 .39172 L 1 .497 .6 r
F
.61783 .42235 m .61865 .4238 L .61928 .41032 L .752 .084 .602 r
F
.61865 .4238 m .63027 .42116 L .61928 .41032 L 1 .497 .6 r
F
.61865 .4238 m .63076 .4452 L .61928 .41032 L .752 .084 .602 r
F
.61846 .42384 m .61865 .4238 L .61928 .41032 L 1 .497 .6 r
F
.60336 .42727 m .61846 .42384 L .61928 .41032 L F
.60287 .39591 m .61928 .41032 L .60796 .37355 L .752 .084 .602 r
F
.61928 .41032 m .62106 .39697 L .62018 .3954 L F
.61997 .40455 m .62006 .40448 L .62106 .39697 L 1 .497 .6 r
F
.62006 .40448 m .63674 .39172 L .62106 .39697 L F
.61928 .41032 m .63674 .39172 L .61997 .40455 L F
.61928 .41032 m .63748 .42631 L .62106 .39697 L .752 .084 .602 r
F
.61928 .41032 m .62018 .3954 L .60796 .37355 L F
.60841 .40121 m .62138 .38656 L .61345 .37444 L 1 .517 .597 r
F
.62138 .38656 m .62185 .38602 L .62149 .38553 L F
.62138 .38656 m .62149 .38553 L .61345 .37444 L F
.61928 .41032 m .63076 .4452 L .63748 .42631 L .752 .084 .602 r
F
.61911 .4105 m .61928 .41032 L .61997 .40455 L 1 .497 .6 r
F
.60336 .42727 m .61818 .41149 L .60841 .40121 L F
.61818 .41149 m .61911 .4105 L .61831 .4098 L F
.61818 .41149 m .61831 .4098 L .60841 .40121 L F
.61911 .4105 m .62106 .39697 L .60841 .40121 L F
.62255 .38666 m .63748 .42631 L .64417 .40608 L .772 .087 .597 r
F
.62185 .38602 m .62243 .38753 L .62255 .38666 L F
.62243 .38753 m .63748 .42631 L .62255 .38666 L F
.62106 .39697 m .63748 .42631 L .62185 .38602 L F
.62185 .38602 m .63674 .39172 L .64317 .36192 L 1 .517 .597 r
F
.60841 .40121 m .62106 .39697 L .62185 .38602 L F
.62185 .38602 m .64317 .36192 L .62411 .36995 L F
.62185 .38602 m .62208 .38435 L .61303 .35 L .772 .087 .597 r
F
.62273 .38682 m .62411 .36995 L .61303 .35 L F
.62185 .38602 m .62411 .36995 L .61345 .37444 L 1 .517 .597 r
F
.62185 .38602 m .62273 .38682 L .62208 .38435 L .772 .087 .597 r
F
.62273 .38682 m .64417 .40608 L .62411 .36995 L F
.62483 .36101 m .62411 .36995 L .6249 .36093 L 1 .532 .595 r
F
.61345 .37444 m .62411 .36995 L .62483 .36101 L F
.62411 .36995 m .64317 .36192 L .6249 .36093 L F
.6249 .36093 m .64417 .40608 L .65083 .38482 L .786 .088 .593 r
F
.62411 .36995 m .64417 .40608 L .6249 .36093 L F
.6249 .36093 m .65083 .38482 L .62756 .34264 L F
.61345 .37444 m .62481 .36105 L .61846 .3471 L 1 .532 .595 r
F
.62481 .36105 m .62756 .34264 L .61846 .3471 L F
.62863 .33545 m .65083 .38482 L .65746 .36274 L .797 .089 .591 r
F
.6283 .33514 m .62858 .33576 L .62863 .33545 L F
.62858 .33576 m .65083 .38482 L .62863 .33545 L F
.62756 .34264 m .65083 .38482 L .6283 .33514 L F
.62749 .34268 m .62756 .34264 L .6283 .33514 L 1 .542 .593 r
F
.61846 .3471 m .62749 .34268 L .6283 .33514 L F
.62846 .33366 m .62908 .33587 L .62858 .33287 L .797 .089 .591 r
F
.62826 .3351 m .6283 .33514 L .62846 .33366 L F
.6283 .33514 m .62908 .33587 L .62846 .33366 L F
.62908 .33587 m .63128 .31502 L .62861 .33308 L F
.6283 .33514 m .63128 .31502 L .62345 .3193 L 1 .542 .593 r
F
.62345 .3193 m .63195 .30873 L .62842 .29109 L 1 .549 .591 r
F
.63195 .30873 m .63196 .30872 L .63196 .30869 L F
.63195 .30873 m .63196 .30869 L .62842 .29109 L F
.62908 .33587 m .65746 .36274 L .63128 .31502 L .797 .089 .591 r
F
.63195 .30873 m .63128 .31502 L .63196 .30872 L 1 .549 .591 r
F
.62345 .3193 m .63128 .31502 L .63195 .30873 L F
.63128 .31502 m .65593 .30155 L .63196 .30872 L F
.63196 .30872 m .65746 .36274 L .66407 .33999 L .804 .089 .588 r
F
.63128 .31502 m .65746 .36274 L .63196 .30872 L F
.63598 .28191 m .66407 .33999 L .67065 .31668 L .81 .089 .586 r
F
.63581 .28174 m .63596 .28205 L .63598 .28191 L F
.63596 .28205 m .66407 .33999 L .63598 .28191 L F
.63196 .30872 m .66407 .33999 L .63521 .28707 L .804 .089 .588 r
F
.63196 .30872 m .63521 .28707 L .62807 .27398 L F
.63196 .30872 m .63521 .28707 L .62842 .29109 L 1 .549 .591 r
F
.62842 .29109 m .63521 .28707 L .63581 .28174 L 1 .554 .589 r
F
.63521 .28707 m .66407 .33999 L .63581 .28174 L .81 .089 .586 r
F
.63993 .25441 m .67065 .31668 L .67721 .29289 L .814 .089 .584 r
F
.6398 .25427 m .63991 .25451 L .63993 .25441 L F
.63991 .25451 m .67065 .31668 L .63993 .25441 L F
.63581 .28174 m .67065 .31668 L .63927 .2588 L .81 .089 .586 r
F
.63581 .28174 m .63927 .2588 L .63304 .2473 L F
.62842 .29109 m .63581 .28174 L .63336 .26252 L 1 .554 .589 r
F
.63581 .28174 m .63927 .2588 L .63336 .26252 L F
.63336 .26252 m .63927 .2588 L .6398 .25427 L 1 .556 .587 r
F
.63927 .2588 m .67065 .31668 L .6398 .25427 L .814 .089 .584 r
F
.6398 .25427 m .67721 .29289 L .64344 .23022 L F
.6398 .25427 m .64344 .23022 L .63798 .2201 L F
.63336 .26252 m .6398 .25427 L .63828 .23364 L 1 .556 .587 r
F
.6398 .25427 m .64344 .23022 L .63828 .23364 L F
.53824 .66225 m .53834 .66455 L .55093 .66643 L .747 .469 .802 r
F
.52569 .66159 m .53834 .66455 L .53824 .66225 L .752 .473 .802 r
F
.34848 .51718 m .35092 .4866 L .33687 .52267 L .998 .437 .715 r
F
.34848 .51718 m .36134 .49431 L .35092 .4866 L F
.48848 .6548 m .47752 .64844 L .47613 .65176 L .764 .483 .801 r
F
.48848 .6548 m .48941 .65261 L .47752 .64844 L F
.66263 .39504 m .69438 .37433 L .67029 .36274 L 1 .471 .582 r
F
.66263 .39504 m .68562 .40718 L .69438 .37433 L F
.52541 .66042 m .52569 .66159 L .53824 .66225 L .752 .473 .802 r
F
.50129 .65679 m .49081 .65058 L .48941 .65261 L .761 .481 .802 r
F
.50129 .65679 m .50199 .65578 L .49081 .65058 L F
.58645 .54714 m .60501 .55312 L .59579 .54531 L .493 .274 .854 r
F
.5765 .53955 m .58645 .54714 L .59579 .54531 L .503 .269 .841 r
F
.55079 .66299 m .55093 .66643 L .56353 .66838 L .738 .463 .803 r
F
.53824 .66225 m .55093 .66643 L .55079 .66299 L .747 .469 .802 r
F
.73602 .63601 m .73727 .69369 L .74945 .67841 L 1 .496 .6 r
F
.42132 .51813 m .42555 .50847 L .412 .51142 L .527 .324 .854 r
F
.42132 .51813 m .43365 .51503 L .42555 .50847 L F
.47613 .65176 m .46561 .64425 L .46378 .64873 L .768 .483 .8 r
F
.47613 .65176 m .47752 .64844 L .46561 .64425 L F
.34036 .60466 m .34621 .59228 L .33836 .58689 L .477 .162 .792 r
F
.3526 .61279 m .34621 .59229 L .34036 .60466 L .588 .264 .786 r
F
.47812 .52796 m .48594 .52005 L .47302 .52219 L .683 .553 .859 r
F
.47812 .52796 m .4894 .52629 L .48594 .52005 L F
.5587 .53744 m .5765 .53955 L .56532 .532 L .59 .365 .832 r
F
.54808 .53223 m .5587 .53744 L .56532 .532 L .654 .415 .821 r
F
.33043 .4584 m .34056 .39833 L .32041 .4331 L .764 .092 .606 r
F
.56336 .66385 m .56353 .66838 L .57614 .67044 L .725 .454 .806 r
F
.55079 .66299 m .56353 .66838 L .56336 .66385 L .738 .463 .803 r
F
.52541 .66042 m .53824 .66225 L .53767 .65991 L .752 .473 .802 r
F
.52492 .65931 m .52541 .66042 L .53767 .65991 L F
.59579 .54531 m .60501 .55312 L .61543 .55278 L .451 .216 .856 r
F
.50199 .65578 m .49259 .6488 L .49081 .65058 L .76 .481 .801 r
F
.50199 .65578 m .50288 .65489 L .49259 .6488 L F
.46378 .64873 m .4537 .64001 L .45142 .64571 L .772 .48 .797 r
F
.46378 .64873 m .46561 .64425 L .4537 .64001 L F
.37962 .5056 m .38405 .48452 L .3692 .49932 L .691 .277 .748 r
F
.37962 .5056 m .39335 .495 L .38405 .48452 L F
.53767 .65991 m .53824 .66225 L .55079 .66299 L .746 .467 .802 r
F
.57594 .6649 m .57614 .67044 L .58875 .67265 L .704 .442 .809 r
F
.56336 .66385 m .57614 .67044 L .57594 .6649 L .725 .454 .806 r
F
.40575 .90353 m .38657 .91172 L .38059 .92253 L 1 .916 .698 r
F
.41331 .89383 m .38658 .91172 L .40575 .90353 L 1 .931 .712 r
F
.52492 .65931 m .53767 .65991 L .53671 .65769 L .752 .473 .802 r
F
.52424 .65823 m .52492 .65931 L .53671 .65769 L .753 .473 .802 r
F
.48941 .65261 m .4796 .64537 L .47752 .64844 L .763 .482 .801 r
F
.48941 .65261 m .49081 .65058 L .4796 .64537 L F
.45142 .64571 m .44178 .63567 L .43906 .64266 L .776 .474 .794 r
F
.45142 .64571 m .4537 .64001 L .44178 .63567 L F
.50288 .65489 m .49475 .64724 L .49259 .6488 L .76 .48 .801 r
F
.50288 .65489 m .50397 .65412 L .49475 .64724 L F
.51729 .85397 m .50237 .86109 L .5178 .85932 L .755 .68 .87 r
F
.53096 .85182 m .5178 .85932 L .53313 .8566 L .735 .659 .874 r
F
.53096 .85182 m .51729 .85397 L .5178 .85932 L F
.54431 .84919 m .53313 .8566 L .54811 .85329 L .689 .604 .881 r
F
.54431 .84919 m .53096 .85182 L .53313 .8566 L F
.58854 .66622 m .58875 .67265 L .60137 .67509 L .674 .423 .815 r
F
.57594 .6649 m .58875 .67265 L .58854 .66622 L .704 .442 .809 r
F
.55363 .16427 m .59385 .1962 L .59715 .16626 L .918 .13 .586 r
F
.55198 .19575 m .59385 .1962 L .55363 .16427 L .921 .134 .588 r
F
.51294 .18445 m .55198 .19575 L .55363 .16427 L .974 .154 .586 r
F
.52424 .65823 m .53671 .65769 L .53535 .65551 L .753 .473 .802 r
F
.52337 .65719 m .52424 .65823 L .53535 .65551 L .754 .474 .802 r
F
.43906 .64266 m .42984 .6312 L .42669 .63955 L .781 .466 .789 r
F
.43906 .64266 m .44178 .63567 L .42984 .6312 L F
.50397 .65412 m .49726 .64593 L .49475 .64724 L .76 .48 .801 r
F
.50397 .65412 m .50522 .65347 L .49726 .64593 L F
.3526 .61279 m .35814 .59933 L .34621 .59229 L .588 .264 .786 r
F
.3649 .61929 m .35814 .59933 L .3526 .61279 L .676 .335 .78 r
F
.54808 .53223 m .56532 .532 L .55315 .52529 L .654 .415 .821 r
F
.53679 .52822 m .54808 .53223 L .55315 .52529 L .728 .471 .81 r
F
.54996 .65949 m .55079 .66299 L .56336 .66385 L .736 .457 .802 r
F
.53767 .65991 m .55079 .66299 L .54996 .65949 L .746 .467 .802 r
F
.31099 .97142 m .28266 .88075 L .30081 .97864 L .705 .053 .584 r
F
.31099 .97142 m .29366 .87723 L .28266 .88075 L F
.46699 .86824 m .45096 .86844 L .44487 .87513 L .905 .824 .851 r
F
.47152 .86227 m .45096 .86844 L .46699 .86824 L .902 .807 .847 r
F
.48671 .86203 m .47152 .86227 L .46699 .86824 L .799 .728 .866 r
F
.52337 .65719 m .53535 .65551 L .53362 .65341 L .754 .474 .802 r
F
.52233 .65622 m .52337 .65719 L .53362 .65341 L .755 .475 .801 r
F
.42669 .63955 m .4179 .62657 L .41432 .63632 L .785 .455 .784 r
F
.42669 .63955 m .42984 .6312 L .4179 .62657 L F
.28208 .7557 m .2738 .78891 L .26098 .78779 L .677 0 .235 r
F
.29414 .76326 m .2738 .78891 L .28208 .7557 L .665 0 .203 r
F
.60116 .66792 m .60137 .67509 L .61401 .67787 L .63 .391 .822 r
F
.58854 .66622 m .60137 .67509 L .60116 .66792 L .674 .423 .815 r
F
.51729 .85397 m .50355 .85543 L .50237 .86109 L .755 .68 .87 r
F
.50355 .85543 m .48671 .86203 L .50237 .86109 L .774 .699 .867 r
F
.53671 .65769 m .53767 .65991 L .54996 .65949 L .746 .466 .802 r
F
.47752 .64844 m .46839 .6401 L .46561 .64425 L .765 .479 .799 r
F
.47752 .64844 m .4796 .64537 L .46839 .6401 L F
.50522 .65347 m .50007 .64491 L .49726 .64593 L .76 .48 .801 r
F
.50522 .65347 m .50662 .65296 L .50007 .64491 L F
.61861 .85851 m .60491 .85658 L .61309 .86267 L .217 .012 .846 r
F
.4894 .52629 m .49938 .518 L .48595 .52005 L .754 .593 .84 r
F
.4894 .52629 m .50113 .5251 L .49938 .518 L F
.49081 .65058 m .48227 .64267 L .47961 .64537 L .763 .481 .801 r
F
.49081 .65058 m .49259 .6488 L .48227 .64267 L F
.55712 .84644 m .54811 .85329 L .56249 .85012 L .62 .5 .891 r
F
.55712 .84644 m .54431 .84919 L .54811 .85329 L F
.44173 .52102 m .44753 .51395 L .43365 .51503 L .508 .328 .887 r
F
.44173 .52102 m .45423 .51896 L .44753 .51395 L F
.46089 .5243 m .46789 .51715 L .45423 .51896 L .581 .447 .884 r
F
.46089 .5243 m .47302 .52219 L .46789 .51715 L F
.34005 .30847 m .36939 .32232 L .36294 .29462 L .389 0 .601 r
F
.34778 .33655 m .36939 .32232 L .34005 .30847 L .392 0 .606 r
F
.77543 .81142 m .76313 .90402 L .77458 .90913 L 1 .301 .592 r
F
.76356 .81293 m .76313 .90402 L .77543 .81142 L 1 .303 .595 r
F
.41432 .63632 m .40595 .62173 L .40195 .63285 L .785 .441 .78 r
F
.41432 .63632 m .4179 .62657 L .40595 .62173 L F
.44487 .87513 m .42846 .87554 L .42088 .88442 L 1 .953 .807 r
F
.45096 .86844 m .42846 .87554 L .44487 .87513 L 1 .898 .814 r
F
.52233 .65622 m .53362 .65341 L .53153 .65145 L .755 .475 .801 r
F
.52108 .65529 m .52233 .65622 L .53153 .65145 L .756 .476 .801 r
F
.3649 .61929 m .37009 .60556 L .35814 .59933 L .676 .335 .78 r
F
.37723 .62457 m .37009 .60556 L .3649 .61929 L .731 .377 .775 r
F
.50662 .65296 m .50312 .64418 L .50007 .64491 L .76 .479 .801 r
F
.50662 .65296 m .50815 .6526 L .50312 .64418 L F
.40195 .63285 m .394 .61666 L .38959 .629 L .779 .424 .776 r
F
.40195 .63285 m .40595 .62173 L .394 .61666 L F
.68822 .5249 m .71039 .54358 L .69898 .50373 L 1 .407 .605 r
F
.68822 .5249 m .69898 .56277 L .71039 .54358 L F
.6138 .67018 m .61401 .67787 L .62666 .68113 L .571 .338 .831 r
F
.60116 .66792 m .61401 .67787 L .6138 .67018 L .63 .391 .822 r
F
.51295 .21679 m .55198 .19575 L .51294 .18445 L .982 .16 .589 r
F
.4756 .22393 m .51294 .18445 L .47394 .19116 L 1 .174 .585 r
F
.4756 .22393 m .51295 .21679 L .51294 .18445 L F
.52108 .65529 m .53153 .65145 L .52902 .64956 L .756 .476 .801 r
F
.51967 .65446 m .52108 .65529 L .52902 .64956 L .758 .476 .801 r
F
.37723 .62457 m .38204 .61129 L .37009 .60556 L .731 .377 .775 r
F
.38959 .629 m .38204 .61129 L .37723 .62457 L .762 .404 .774 r
F
.38959 .629 m .394 .61666 L .38204 .61129 L F
.50815 .6526 m .50635 .64377 L .50312 .64418 L .76 .479 .801 r
F
.50815 .6526 m .50976 .6524 L .50635 .64377 L F
.53679 .52822 m .55315 .52529 L .54022 .52024 L .728 .471 .81 r
F
.52505 .52572 m .53679 .52822 L .54022 .52024 L .79 .522 .804 r
F
.412 .51142 m .41744 .50082 L .40268 .50383 L .51 .268 .835 r
F
.412 .51142 m .42555 .50847 L .41744 .50082 L F
.56226 .6592 m .56336 .66385 L .57594 .6649 L .721 .444 .803 r
F
.54996 .65949 m .56336 .66385 L .56226 .6592 L .736 .457 .802 r
F
.5765 .53955 m .59579 .54531 L .58457 .53614 L .503 .269 .841 r
F
.56532 .532 m .5765 .53955 L .58457 .53614 L .549 .302 .826 r
F
.51967 .65446 m .52902 .64956 L .52621 .64788 L .758 .476 .801 r
F
.51815 .65375 m .51967 .65446 L .52621 .64788 L .759 .477 .801 r
F
.58848 .8457 m .58285 .85091 L .59671 .85095 L .45 .18 .898 r
F
.3692 .49932 m .37793 .47648 L .36232 .49496 L .755 .247 .711 r
F
.3692 .49932 m .38404 .48452 L .37793 .47648 L F
.46561 .64425 m .45715 .63475 L .4537 .64001 L .767 .474 .797 r
F
.46561 .64425 m .46839 .6401 L .45715 .63475 L F
.50976 .6524 m .50971 .64367 L .50635 .64377 L .76 .478 .801 r
F
.50976 .6524 m .51144 .65236 L .50971 .64367 L F
.53671 .65769 m .54996 .65949 L .54852 .65613 L .746 .466 .802 r
F
.53535 .65551 m .53671 .65769 L .54852 .65613 L .747 .466 .801 r
F
.34056 .39833 m .36343 .38911 L .35557 .36353 L .519 .022 .618 r
F
.34963 .42239 m .36343 .38911 L .34056 .39833 L .539 .033 .629 r
F
.33043 .4584 m .34963 .42239 L .34056 .39833 L .764 .092 .606 r
F
.39818 .2539 m .43222 .18263 L .39327 .22418 L 1 .182 .581 r
F
.39818 .2539 m .43551 .21468 L .43222 .18263 L F
.50113 .5251 m .51308 .51682 L .49938 .518 L .808 .593 .82 r
F
.50113 .5251 m .51309 .52477 L .51308 .51682 L F
.51815 .65375 m .52621 .64788 L .52316 .64645 L .759 .477 .801 r
F
.51654 .65318 m .51815 .65375 L .52316 .64645 L .76 .477 .801 r
F
.51144 .65236 m .51314 .6439 L .50971 .64367 L .76 .478 .801 r
F
.51144 .65236 m .51315 .65247 L .51314 .6439 L F
.49259 .6488 m .48552 .64032 L .48227 .64267 L .762 .48 .801 r
F
.49259 .6488 m .49475 .64724 L .48552 .64032 L F
.41331 .89383 m .39562 .89652 L .38658 .91172 L 1 .931 .712 r
F
.42088 .88442 m .39562 .89652 L .41331 .89383 L 1 .908 .732 r
F
.51654 .65318 m .52316 .64645 L .51993 .6453 L .76 .477 .801 r
F
.51486 .65275 m .51654 .65318 L .51993 .6453 L .76 .478 .8 r
F
.51315 .65247 m .51656 .64444 L .51314 .6439 L .76 .478 .801 r
F
.51315 .65247 m .51486 .65275 L .51656 .64444 L F
.52505 .52572 m .54022 .52024 L .52678 .51739 L .79 .522 .804 r
F
.51309 .52477 m .52505 .52572 L .52678 .51739 L .821 .564 .807 r
F
.51486 .65275 m .51993 .6453 L .51656 .64444 L .76 .478 .8 r
F
.67514 .51256 m .69898 .50373 L .68497 .48459 L 1 .725 .638 r
F
.67514 .51256 m .68822 .5249 L .69898 .50373 L F
.7242 .65937 m .73726 .69369 L .73601 .63602 L 1 .55 .607 r
F
.43882 .24663 m .47394 .19116 L .43551 .21468 L 1 .178 .583 r
F
.43882 .24663 m .4756 .22393 L .47394 .19116 L F
.51309 .52477 m .52678 .51739 L .51308 .51682 L .821 .564 .807 r
F
.62648 .6732 m .62666 .68113 L .63934 .68512 L .497 .257 .839 r
F
.6138 .67018 m .62666 .68113 L .62648 .6732 L .571 .338 .831 r
F
.54852 .65613 m .54996 .65949 L .56226 .6592 L .736 .455 .801 r
F
.48959 .85615 m .47152 .86227 L .48671 .86203 L .816 .736 .86 r
F
.50355 .85543 m .48959 .85615 L .48671 .86203 L .774 .699 .867 r
F
.47961 .64537 m .47193 .63648 L .46839 .6401 L .764 .478 .799 r
F
.47961 .64537 m .48227 .64267 L .47193 .63648 L F
.57458 .65912 m .57594 .6649 L .58854 .66622 L .698 .423 .805 r
F
.56226 .6592 m .57594 .6649 L .57458 .65912 L .721 .444 .803 r
F
.53535 .65551 m .54852 .65613 L .54649 .65283 L .747 .466 .801 r
F
.53362 .65341 m .53535 .65551 L .54649 .65283 L .75 .468 .801 r
F
.4537 .64001 m .4459 .62925 L .44178 .63567 L .769 .467 .794 r
F
.4537 .64001 m .45715 .63475 L .4459 .62925 L F
.32115 .96531 m .29366 .87723 L .31099 .97142 L .703 .051 .581 r
F
.32115 .96531 m .30469 .87369 L .29366 .87723 L F
.49475 .64724 m .48928 .63836 L .48552 .64032 L .762 .48 .801 r
F
.49475 .64724 m .49726 .64593 L .48928 .63836 L F
.36232 .49496 m .37706 .47525 L .36134 .49431 L .807 .241 .691 r
F
.36232 .49496 m .37792 .47647 L .37706 .47525 L F
.56916 .84373 m .55712 .84644 L .56249 .85012 L .567 .406 .896 r
F
.59579 .54531 m .61543 .55278 L .60519 .54437 L .451 .216 .856 r
F
.58457 .53614 m .59579 .54531 L .60519 .54437 L .443 .185 .839 r
F
.36134 .49431 m .36783 .46069 L .35092 .4866 L .778 .198 .677 r
F
.36134 .49431 m .37706 .47525 L .36783 .46069 L F
.66818 .47738 m .6947 .45512 L .67683 .44124 L 1 .608 .593 r
F
.66818 .47738 m .68497 .48459 L .6947 .45512 L F
.62648 .6732 m .63934 .68512 L .6392 .67732 L .497 .257 .839 r
F
.59385 .1962 m .63798 .2201 L .59715 .16626 L .864 .109 .586 r
F
.56532 .532 m .58457 .53614 L .57197 .52652 L .549 .302 .826 r
F
.55315 .52529 m .56532 .532 L .57197 .52652 L .639 .371 .81 r
F
.53362 .65341 m .54649 .65283 L .54389 .64965 L .75 .468 .801 r
F
.53153 .65145 m .53362 .65341 L .54389 .64965 L .753 .47 .8 r
F
.34058 .47572 m .34963 .42239 L .33044 .45841 L .804 .125 .619 r
F
.76356 .81293 m .75166 .89877 L .76313 .90402 L 1 .303 .595 r
F
.75165 .81433 m .75166 .89877 L .76356 .81293 L 1 .305 .598 r
F
.44178 .63567 m .43464 .62359 L .42984 .6312 L .77 .457 .79 r
F
.44178 .63567 m .4459 .62925 L .43464 .62359 L F
.3386 .78884 m .32992 .79093 L .31796 .78107 L .704 0 0 r
F
.33687 .52267 m .34058 .47572 L .32483 .53948 L 1 .307 .65 r
F
.33687 .52267 m .35092 .4866 L .34058 .47572 L F
.58693 .65935 m .58854 .66622 L .60116 .66792 L .665 .394 .807 r
F
.57458 .65912 m .58854 .66622 L .58693 .65935 L .698 .423 .805 r
F
.54852 .65613 m .56226 .6592 L .56036 .6547 L .736 .455 .801 r
F
.54649 .65283 m .54852 .65613 L .56036 .6547 L .739 .455 .801 r
F
.49726 .64593 m .49349 .63682 L .48928 .63836 L .762 .48 .801 r
F
.49726 .64593 m .50007 .64491 L .49349 .63682 L F
.47302 .52219 m .48246 .51451 L .46789 .51715 L .659 .553 .874 r
F
.47302 .52219 m .48594 .52005 L .48246 .51451 L F
.56036 .6547 m .56226 .6592 L .57458 .65912 L .721 .438 .801 r
F
.55198 .19575 m .59053 .22564 L .59385 .1962 L .921 .134 .588 r
F
.55032 .22673 m .59053 .22564 L .55198 .19575 L .924 .138 .591 r
F
.51295 .21679 m .55032 .22673 L .55198 .19575 L .982 .16 .589 r
F
.40268 .50383 m .40933 .49147 L .39335 .495 L .506 .209 .802 r
F
.40268 .50383 m .41744 .50082 L .40933 .49147 L F
.46839 .6401 m .46158 .63018 L .45715 .63474 L .763 .472 .797 r
F
.46839 .6401 m .47193 .63648 L .46158 .63018 L F
.60909 .8493 m .60491 .85658 L .61861 .85851 L .435 .205 .874 r
F
.60909 .8493 m .59671 .85095 L .60491 .85658 L F
.48227 .64267 m .47625 .63334 L .47193 .63648 L .763 .478 .8 r
F
.48227 .64267 m .48552 .64032 L .47625 .63334 L F
.7242 .65937 m .72521 .70923 L .73726 .69369 L 1 .55 .607 r
F
.53153 .65145 m .54389 .64965 L .54077 .64664 L .753 .47 .8 r
F
.52902 .64956 m .53153 .65145 L .54077 .64664 L .757 .472 .8 r
F
.42088 .88442 m .40463 .88339 L .39562 .89652 L 1 .908 .732 r
F
.42846 .87554 m .40463 .88339 L .42088 .88442 L 1 .879 .757 r
F
.43365 .51503 m .4408 .50911 L .42555 .50847 L .43 .194 .89 r
F
.43365 .51503 m .44753 .51395 L .4408 .50911 L F
.50007 .64491 m .49807 .63573 L .49349 .63682 L .762 .481 .801 r
F
.50007 .64491 m .50312 .64418 L .49807 .63573 L F
.42984 .6312 m .42336 .61776 L .4179 .62657 L .771 .447 .786 r
F
.42984 .6312 m .43464 .62359 L .42336 .61776 L F
.29414 .76326 m .28662 .7905 L .2738 .78891 L .665 0 .203 r
F
.30604 .7717 m .28663 .7905 L .29414 .76327 L .642 0 .151 r
F
.35092 .4866 m .35868 .44313 L .34058 .47572 L .806 .159 .643 r
F
.35092 .4866 m .36783 .46069 L .35868 .44313 L F
.45096 .86844 m .43605 .86731 L .42846 .87554 L 1 .898 .814 r
F
.45708 .86171 m .43605 .86731 L .45096 .86844 L 1 .843 .822 r
F
.47152 .86227 m .45708 .86171 L .45096 .86844 L .902 .807 .847 r
F
.35653 .26633 m .36142 .26768 L .35016 .23756 L .332 0 .591 r
F
.36142 .26768 m .3884 .19426 L .35683 .24435 L 1 .196 .581 r
F
.36142 .26768 m .39327 .22418 L .3884 .19426 L F
.35653 .26633 m .36244 .27227 L .36142 .26768 L .332 0 .591 r
F
.36294 .29462 m .36718 .29565 L .35653 .26633 L .332 0 .594 r
F
.36718 .29565 m .36722 .29554 L .36244 .27227 L 1 .196 .582 r
F
.36722 .29554 m .39327 .22418 L .36244 .27227 L F
.36244 .27227 m .39327 .22418 L .36142 .26768 L 1 .196 .581 r
F
.36718 .29565 m .39818 .2539 L .39327 .22418 L 1 .196 .582 r
F
.36294 .29462 m .36812 .29978 L .36718 .29565 L .332 0 .594 r
F
.36939 .32232 m .37304 .3231 L .36294 .29462 L .33 0 .596 r
F
.37304 .3231 m .39818 .2539 L .36815 .29974 L 1 .194 .584 r
F
.36871 .30254 m .36815 .29974 L .36812 .29978 L F
.37304 .3231 m .36815 .29974 L .36871 .30254 L F
.36812 .29978 m .39818 .2539 L .36718 .29565 L 1 .196 .582 r
F
.37304 .3231 m .4031 .28347 L .39818 .2539 L 1 .194 .584 r
F
.34778 .33655 m .37588 .34929 L .36939 .32232 L .392 0 .606 r
F
.37392 .3268 m .4031 .28347 L .37304 .3231 L 1 .194 .584 r
F
.35557 .36353 m .37588 .34929 L .34778 .33655 L .393 .001 .611 r
F
.35557 .36353 m .38241 .37535 L .37588 .34929 L F
.37588 .34929 m .37905 .34991 L .36939 .32232 L .326 0 .599 r
F
.37905 .34991 m .4031 .28347 L .37392 .3268 L 1 .19 .585 r
F
.37905 .34991 m .40805 .31296 L .4031 .28347 L F
.37588 .34929 m .37978 .35317 L .37905 .34991 L .326 0 .599 r
F
.37978 .35317 m .37988 .35327 L .37905 .34991 L F
.37905 .34991 m .37702 .34078 L .36939 .32232 L F
.37702 .34078 m .37392 .3268 L .37383 .32672 L F
.37702 .34078 m .37383 .32672 L .36939 .32232 L F
.36939 .32232 m .37392 .3268 L .37304 .3231 L .33 0 .596 r
F
.3691 .33396 m .37302 .32316 L .36258 .30824 L 1 .194 .584 r
F
.37302 .32316 m .37304 .3231 L .37299 .32304 L F
.37302 .32316 m .37299 .32304 L .36258 .30824 L F
.37465 .33027 m .37905 .34991 L .37392 .3268 L 1 .19 .585 r
F
.37892 .35028 m .37905 .34991 L .37465 .33027 L F
.38241 .37535 m .38528 .37591 L .37588 .34929 L .316 0 .601 r
F
.36343 .38911 m .38241 .37535 L .35557 .36353 L .39 .001 .619 r
F
.36343 .38911 m .38898 .40025 L .38241 .37535 L F
.3861 .37909 m .38612 .37907 L .38528 .37591 L 1 .183 .586 r
F
.38612 .37907 m .41301 .34248 L .38528 .37591 L F
.38528 .37591 m .41301 .34248 L .40805 .31296 L F
.38528 .37591 m .40805 .31296 L .37988 .35327 L F
.38593 .37603 m .37988 .35327 L .37899 .35239 L .316 0 .601 r
F
.38378 .37031 m .37899 .35239 L .37588 .34929 L F
.38593 .37603 m .37899 .35239 L .38378 .37031 L F
.37135 .41291 m .38898 .40025 L .36343 .38911 L .382 .001 .629 r
F
.37135 .41291 m .3956 .42365 L .38898 .40025 L F
.38898 .40025 m .39181 .40086 L .38241 .37535 L .298 0 .603 r
F
.39181 .40086 m .41301 .34248 L .38612 .37907 L 1 .172 .587 r
F
.38631 .37989 m .38612 .37907 L .3861 .37909 L F
.39181 .40086 m .38612 .37907 L .38631 .37989 L F
.39181 .40086 m .41799 .37224 L .41301 .34248 L F
.38898 .40025 m .39273 .40418 L .39181 .40086 L .298 0 .603 r
F
.3956 .42365 m .39875 .42453 L .38898 .40025 L .268 0 .604 r
F
.37923 .43426 m .3956 .42366 L .37135 .41291 L .366 .002 .643 r
F
.37923 .43426 m .40217 .4448 L .3956 .42366 L F
.39997 .4285 m .40008 .42837 L .39875 .42453 L .966 .153 .588 r
F
.40008 .42837 m .42297 .40253 L .39875 .42453 L F
.39875 .42453 m .42297 .40253 L .41799 .37224 L F
.39875 .42453 m .41799 .37224 L .39278 .40412 L F
.39324 .40591 m .39278 .40412 L .39273 .40418 L F
.39875 .42453 m .39278 .40412 L .39324 .40591 L F
.39273 .40418 m .41799 .37224 L .39181 .40086 L 1 .172 .587 r
F
.39181 .40086 m .39195 .40089 L .3861 .37909 L .298 0 .603 r
F
.39195 .40089 m .41192 .4052 L .38641 .3794 L F
.39195 .40089 m .38641 .3794 L .3861 .37909 L F
.39964 .42478 m .39273 .40418 L .39114 .40251 L .268 0 .604 r
F
.39571 .41575 m .39114 .40251 L .38898 .40025 L F
.39964 .42478 m .39114 .40251 L .39571 .41575 L F
.38718 .45318 m .40217 .4448 L .37923 .43426 L .34 .002 .664 r
F
.38718 .45318 m .40879 .46343 L .40217 .4448 L F
.40217 .4448 m .40601 .4464 L .3956 .42366 L .214 0 .603 r
F
.40601 .4464 m .40563 .44531 L .3956 .42366 L F
.40617 .44646 m .39997 .4285 L .3956 .42366 L F
.3956 .42365 m .39997 .4285 L .39875 .42453 L .268 0 .604 r
F
.3954 .43366 m .39859 .42499 L .38879 .40916 L .966 .153 .588 r
F
.39859 .42499 m .39875 .42453 L .39806 .42346 L F
.39859 .42499 m .39806 .42346 L .38879 .40916 L F
.40601 .4464 m .40617 .44646 L .40563 .44531 L .214 0 .603 r
F
.40617 .44646 m .42297 .40253 L .40008 .42838 L .9 .125 .588 r
F
.40096 .43138 m .40008 .42838 L .39997 .4285 L F
.40617 .44646 m .40008 .42838 L .40096 .43138 L F
.40617 .44646 m .42789 .4333 L .42297 .40253 L F
.40217 .4448 m .40804 .45183 L .40617 .44646 L .214 0 .603 r
F
.40879 .46343 m .41425 .46682 L .40217 .4448 L .116 0 .601 r
F
.40125 .47988 m .4161 .48017 L .39594 .47082 L .257 .004 .744 r
F
.40125 .47988 m .42053 .48815 L .4161 .48017 L F
.39594 .47082 m .41547 .4789 L .39519 .46944 L .269 .002 .723 r
F
.39594 .47082 m .4161 .48016 L .41547 .4789 L F
.39518 .46943 m .40879 .46343 L .38718 .45318 L .304 .002 .698 r
F
.39518 .46943 m .41547 .4789 L .40879 .46343 L F
.41547 .4789 m .42248 .48521 L .40879 .46343 L 0 0 .586 r
F
.41425 .46682 m .43282 .46539 L .42789 .4333 L .805 .088 .587 r
F
.41478 .4679 m .43282 .46539 L .41425 .46682 L F
.41425 .46682 m .42789 .4333 L .40828 .45161 L F
.40988 .45629 m .40828 .45161 L .40804 .45183 L F
.41425 .46682 m .40828 .45161 L .40988 .45629 L F
.40804 .45183 m .42789 .4333 L .40617 .44646 L .9 .125 .588 r
F
.40617 .44646 m .40658 .44664 L .39997 .4285 L .214 0 .603 r
F
.40658 .44664 m .42219 .45316 L .40063 .42924 L F
.40658 .44664 m .40063 .42924 L .39997 .4285 L F
.40291 .44008 m .40617 .44646 L .39997 .4285 L .9 .125 .588 r
F
.41054 .4585 m .40752 .45121 L .4049 .44807 L .116 0 .601 r
F
.40974 .45778 m .4049 .44807 L .40217 .4448 L F
.41148 .46076 m .4049 .44807 L .40974 .45778 L F
.41544 .46757 m .41054 .4585 L .41148 .46076 L F
.41054 .4585 m .4049 .44807 L .41148 .46076 L F
.40519 .44903 m .40291 .44008 L .3954 .43366 L .9 .125 .588 r
F
.40291 .44008 m .39997 .4285 L .39871 .42993 L F
.40291 .44008 m .39871 .42993 L .3954 .43366 L F
.40519 .44903 m .40587 .44723 L .40291 .44008 L F
.40587 .44723 m .40617 .44646 L .40291 .44008 L F
.41544 .46757 m .40804 .45183 L .40752 .45121 L .116 0 .601 r
F
.41544 .46757 m .40752 .45121 L .41054 .4585 L F
.40879 .46343 m .41773 .47506 L .41425 .46682 L F
.41773 .47506 m .43282 .46539 L .41375 .46804 L .805 .088 .587 r
F
.41744 .50082 m .42728 .49735 L .40933 .49147 L .255 .027 .846 r
F
.40933 .49147 m .42053 .48815 L .40125 .47988 L .24 .01 .795 r
F
.40933 .49147 m .42728 .49735 L .42053 .48815 L F
.42555 .50847 m .43405 .50391 L .41744 .50082 L .333 .078 .877 r
F
.42555 .50847 m .4408 .50911 L .43405 .50391 L F
.41744 .50082 m .43139 .50341 L .42728 .49735 L .255 .027 .846 r
F
.43139 .50341 m .43405 .50391 L .42728 .49735 L F
.44753 .51395 m .45752 .511 L .4408 .50911 L .289 .004 .855 r
F
.45047 .51074 m .45752 .511 L .45226 .51104 L .141 0 0 r
F
.4408 .50911 m .4552 .51074 L .45047 .51074 L F
.4552 .51074 m .45752 .511 L .45047 .51074 L F
.4392 .51075 m .44694 .51315 L .4416 .51344 L .654 0 0 r
F
.4408 .50911 m .45047 .51074 L .43405 .50391 L .141 0 0 r
F
.45047 .51074 m .45226 .51104 L .44778 .50929 L F
.45047 .51074 m .44778 .50929 L .43405 .50391 L F
.43405 .50391 m .45226 .51104 L .44694 .51315 L .499 0 0 r
F
.43252 .50243 m .43133 .50103 L .42991 .4999 L F
.44358 .51075 m .44694 .51315 L .42991 .4999 L F
.42991 .4999 m .44694 .51315 L .42728 .49735 L F
.43405 .50391 m .44358 .51075 L .43133 .50103 L F
.43405 .50391 m .43133 .50103 L .43252 .50243 L F
.42875 .499 m .44394 .51075 L .4392 .51075 L .654 0 0 r
F
.42728 .49735 m .43053 .49996 L .42875 .499 L F
.43053 .49996 m .44394 .51075 L .42875 .499 L F
.44394 .51075 m .44694 .51315 L .4392 .51075 L F
.43976 .51137 m .43798 .5091 L .42192 .48982 L F
.43976 .51137 m .42192 .48982 L .4218 .48968 L F
.42728 .49735 m .43976 .51137 L .42337 .49158 L F
.41568 .50558 m .43087 .5006 L .41506 .50355 L .675 .048 .588 r
F
.42653 .49537 m .4416 .51344 L .44106 .5128 L .548 0 0 r
F
.42653 .49537 m .44106 .5128 L .43716 .50814 L F
.43976 .51137 m .4416 .51344 L .43798 .50909 L .654 0 0 r
F
.42004 .51943 m .4415 .52149 L .43984 .51135 L .597 .031 .595 r
F
.42653 .49537 m .43751 .50856 L .43455 .50502 L .548 0 0 r
F
.43751 .50856 m .43909 .51045 L .43455 .50502 L F
.42004 .51943 m .43455 .50502 L .41568 .50559 L .597 .031 .595 r
F
.43457 .505 m .43821 .50138 L .43288 .50237 L F
.43716 .50814 m .44106 .5128 L .43984 .51135 L .548 0 0 r
F
.42004 .51943 m .43984 .51135 L .43455 .50502 L .597 .031 .595 r
F
.43917 .51054 m .43984 .51135 L .43967 .51114 L .548 0 0 r
F
.43716 .50814 m .43984 .51135 L .43917 .51054 L F
.43798 .5091 m .43047 .50008 L .42053 .48815 L .654 0 0 r
F
.42721 .49617 m .4416 .51344 L .42653 .49537 L .548 0 0 r
F
.43984 .51135 m .46222 .50718 L .43821 .50138 L .486 0 .477 r
F
.44694 .51315 m .45046 .54659 L .4416 .51344 L .698 .002 .45 r
F
.45715 .63474 m .46158 .63018 L .4512 .62372 L .762 .462 .795 r
F
.46158 .63018 m .45767 .61902 L .4512 .62372 L .755 .461 .797 r
F
.46158 .63018 m .46697 .62625 L .45767 .61902 L F
.4512 .62372 m .45767 .61902 L .44834 .61157 L .749 .446 .794 r
F
.46697 .62625 m .46518 .61524 L .45767 .61902 L .749 .463 .799 r
F
.45767 .61902 m .45711 .60726 L .44834 .61157 L .738 .447 .798 r
F
.45767 .61902 m .46518 .61524 L .45711 .60726 L F
.44834 .61157 m .45711 .60726 L .44901 .59898 L .726 .424 .795 r
F
.45711 .60726 m .46026 .59582 L .44901 .59898 L .706 .43 .804 r
F
.44901 .59898 m .45355 .58706 L .44089 .59025 L .681 .392 .8 r
F
.44901 .59898 m .46026 .59582 L .45355 .58706 L F
.44089 .59025 m .45355 .58706 L .44682 .57758 L .659 .341 .789 r
F
.46026 .59582 m .46736 .58628 L .45355 .58706 L .637 .404 .825 r
F
.45355 .58706 m .46217 .57824 L .44682 .57758 L .573 .334 .828 r
F
.45355 .58706 m .46736 .58628 L .46217 .57824 L F
.44682 .57758 m .45697 .56968 L .4401 .5668 L .503 .235 .82 r
F
.44682 .57758 m .46217 .57824 L .45697 .56968 L F
.4401 .5668 m .45176 .55948 L .43338 .55395 L .451 .13 .787 r
F
.4401 .5668 m .45697 .56968 L .45176 .55948 L F
.43338 .55395 m .44658 .54484 L .42669 .53825 L .45 .055 .712 r
F
.43338 .55395 m .45037 .55906 L .44658 .54484 L F
.45037 .55906 m .45176 .55948 L .44658 .54484 L F
.42669 .53825 m .44658 .54484 L .44185 .52312 L .507 .025 .63 r
F
.42955 .53501 m .44185 .52312 L .4415 .5215 L F
.42669 .53825 m .44185 .52312 L .42955 .53501 L F
.44658 .54484 m .46327 .67217 L .458 .63569 L .826 .01 .439 r
F
.44309 .53171 m .458 .63569 L .44285 .53081 L F
.44658 .54484 m .458 .63569 L .44309 .53171 L F
.44185 .52312 m .44285 .53081 L .4415 .5215 L F
.44658 .54484 m .44309 .53171 L .44185 .52312 L F
.44309 .53171 m .44285 .53081 L .44185 .52312 L F
.46217 .57824 m .46845 .57754 L .45697 .56968 L .268 .026 .871 r
F
.46845 .57754 m .47498 .57681 L .46604 .57327 L F
.46845 .57754 m .46604 .57327 L .45697 .56968 L F
.45097 .55144 m .44569 .54262 L .44277 .52181 L .698 .002 .45 r
F
.45046 .54659 m .45097 .55144 L .44277 .52181 L F
.45697 .56968 m .47498 .57681 L .47137 .57579 L .3 0 0 r
F
.45697 .56968 m .4636 .57249 L .45176 .55948 L F
.4636 .57249 m .45981 .56618 L .45176 .55948 L F
.46736 .58628 m .47855 .58093 L .46217 .57824 L .487 .289 .876 r
F
.46217 .57824 m .47855 .58093 L .47498 .57681 L .268 .026 .871 r
F
.45176 .55948 m .45981 .56618 L .45798 .56817 L .78 0 .089 r
F
.4505 .55593 m .45593 .56319 L .44658 .54484 L F
.4636 .57249 m .47137 .57579 L .45981 .56618 L .3 0 0 r
F
.45981 .56618 m .47137 .57579 L .45798 .56817 L .78 0 .089 r
F
.45593 .56319 m .46083 .56974 L .45299 .55603 L F
.45593 .56319 m .45299 .55603 L .44658 .54484 L F
.45798 .56817 m .47137 .57579 L .46768 .58172 L F
.45176 .55948 m .46502 .578 L .46083 .56974 L F
.45176 .55948 m .46083 .56974 L .4505 .55593 L F
.46502 .578 m .46768 .58172 L .46323 .57393 L F
.46502 .578 m .46323 .57393 L .46083 .56974 L F
.47193 .63648 m .46697 .62625 L .46158 .63018 L .76 .471 .798 r
F
.46697 .62625 m .47324 .62305 L .46518 .61524 L .749 .463 .799 r
F
.47324 .62305 m .47362 .61243 L .46518 .61524 L .745 .469 .803 r
F
.46518 .61524 m .46695 .60421 L .45711 .60726 L .728 .454 .804 r
F
.46518 .61524 m .47362 .61243 L .46695 .60421 L F
.45711 .60726 m .46695 .60421 L .46026 .59582 L .706 .43 .804 r
F
.46695 .60421 m .47253 .59426 L .46026 .59582 L .686 .446 .818 r
F
.46026 .59582 m .47253 .59426 L .46736 .58628 L .637 .404 .825 r
F
.47253 .59426 m .48209 .58678 L .46736 .58628 L .604 .425 .85 r
F
.46736 .58628 m .48209 .58678 L .47855 .58093 L .487 .289 .876 r
F
.44658 .54484 m .46768 .58172 L .46327 .67217 L .826 .01 .439 r
F
.45097 .55144 m .45328 .57327 L .44569 .54262 L .698 .002 .45 r
F
.45328 .57327 m .46319 .66732 L .45043 .57637 L F
.45328 .57327 m .45043 .57637 L .44569 .54262 L F
.46319 .66732 m .45958 .64176 L .44569 .54262 L F
.45046 .54659 m .44277 .52181 L .4416 .51344 L F
.45423 .51896 m .46273 .51324 L .44753 .51395 L .491 .266 .899 r
F
.45423 .51896 m .46789 .51715 L .46273 .51324 L F
.44753 .51395 m .46273 .51324 L .45752 .511 L .289 .004 .855 r
F
.44694 .51315 m .46814 .52195 L .4633 .66834 L .698 .002 .45 r
F
.44988 .57325 m .46331 .66656 L .44342 .52017 L .486 0 .477 r
F
.44278 .52223 m .45245 .59429 L .44997 .57396 L .321 0 .462 r
F
.44342 .52017 m .45311 .59147 L .46277 .58747 L .486 0 .477 r
F
.46273 .51324 m .47542 .50803 L .45752 .511 L .451 .065 .872 r
F
.4694 .5105 m .47887 .51013 L .47542 .50803 L F
.45752 .511 m .46917 .50907 L .47183 .51005 L .045 0 0 r
F
.46917 .50907 m .47542 .50803 L .47183 .51005 L F
.46917 .50907 m .47183 .51005 L .47183 .51005 L F
.46273 .51324 m .47887 .51013 L .4694 .5105 L .451 .065 .872 r
F
.47896 .51018 m .49407 .49781 L .47542 .50803 L .962 .849 .837 r
F
.47542 .50803 m .49407 .49781 L .49229 .49115 L 1 .966 .808 r
F
.47542 .50803 m .49229 .49115 L .47183 .51005 L F
.47183 .51005 m .49229 .49115 L .4905 .48235 L 1 .959 .729 r
F
.47183 .51005 m .4905 .48235 L .47434 .51097 L F
.46273 .51324 m .47896 .51018 L .47887 .51013 L .451 .065 .872 r
F
.46789 .51715 m .47896 .51018 L .46273 .51324 L .594 .455 .894 r
F
.46789 .51715 m .48246 .51451 L .47896 .51018 L F
.47183 .51005 m .47434 .51097 L .46814 .52195 L 1 .959 .729 r
F
.47183 .51005 m .47434 .51097 L .47183 .51005 L F
.45639 .51101 m .47183 .51005 L .45226 .51104 L .045 0 0 r
F
.45752 .511 m .45878 .51092 L .45639 .51101 L F
.45878 .51092 m .47183 .51005 L .45639 .51101 L F
.45226 .51104 m .46814 .52195 L .44694 .51315 L .492 0 .171 r
F
.45226 .51104 m .47183 .51005 L .46814 .52195 L F
.44342 .52017 m .46277 .58747 L .46222 .50718 L .486 0 .477 r
F
.47193 .63648 m .47625 .63334 L .46697 .62625 L .76 .471 .798 r
F
.47625 .63334 m .47324 .62305 L .46697 .62625 L .757 .473 .8 r
F
.47362 .61243 m .47768 .60234 L .46695 .60421 L .72 .468 .812 r
F
.46695 .60421 m .47768 .60234 L .47253 .59426 L .686 .446 .818 r
F
.48209 .58678 m .49563 .58171 L .47855 .58093 L .524 .355 .889 r
F
.47855 .58093 m .49381 .57893 L .47498 .57681 L .308 .019 .872 r
F
.47855 .58093 m .49563 .58171 L .49514 .58097 L F
.49381 .57893 m .51304 .56946 L .49846 .57661 L .681 .506 .881 r
F
.48873 .5796 m .49135 .58016 L .49381 .57893 L .308 .019 .872 r
F
.47498 .57681 m .48859 .57834 L .49197 .57979 L .203 0 0 r
F
.48859 .57834 m .49381 .57893 L .49197 .57979 L F
.49381 .57893 m .49846 .57661 L .49197 .57979 L .681 .506 .881 r
F
.49135 .58016 m .49514 .58097 L .49381 .57893 L .308 .019 .872 r
F
.47855 .58093 m .49514 .58097 L .48873 .5796 L F
.49563 .58171 m .51305 .57386 L .49381 .57893 L .701 .618 .881 r
F
.49381 .57893 m .51305 .57386 L .51304 .56946 L .681 .506 .881 r
F
.49197 .57979 m .51304 .56946 L .51303 .56561 L .735 .363 .831 r
F
.49197 .57979 m .51303 .56561 L .4952 .58118 L F
.48209 .58678 m .49742 .58683 L .49563 .58171 L .524 .355 .889 r
F
.49197 .57979 m .4952 .58118 L .4901 .58563 L .735 .363 .831 r
F
.47253 .57612 m .4847 .57842 L .47137 .57579 L .203 0 0 r
F
.4847 .57842 m .48414 .57827 L .47137 .57579 L F
.47498 .57681 m .47933 .57758 L .47253 .57612 L F
.47933 .57758 m .48584 .57872 L .47253 .57612 L F
.48584 .57872 m .49197 .57979 L .4847 .57842 L F
.48584 .57872 m .4847 .57842 L .47253 .57612 L F
.46814 .52195 m .4905 .48235 L .48873 .46653 L 1 .678 .615 r
F
.46814 .52195 m .48873 .46653 L .48869 .46683 L F
.47137 .57579 m .48121 .58096 L .46769 .58172 L .527 0 0 r
F
.48121 .58096 m .47855 .58362 L .46769 .58172 L F
.48595 .52005 m .49762 .51104 L .48247 .51451 L .796 .652 .842 r
F
.48247 .51451 m .49585 .5043 L .47896 .51018 L .859 .736 .843 r
F
.48247 .51451 m .49762 .51104 L .49585 .5043 L F
.47896 .51018 m .49585 .5043 L .49407 .49781 L .962 .849 .837 r
F
.4847 .57842 m .49197 .57979 L .48414 .57827 L .203 0 0 r
F
.47137 .57579 m .49197 .57979 L .4901 .58563 L .527 0 0 r
F
.48552 .64032 m .48127 .63074 L .47625 .63334 L .762 .478 .8 r
F
.47625 .63334 m .48127 .63074 L .47324 .62305 L .757 .473 .8 r
F
.48127 .63074 m .48026 .62058 L .47324 .62305 L .755 .477 .802 r
F
.48127 .63074 m .48689 .62871 L .48026 .62058 L F
.48689 .62871 m .48791 .61887 L .48026 .62058 L .755 .481 .804 r
F
.47324 .62305 m .48026 .62058 L .47362 .61243 L .745 .469 .803 r
F
.48026 .62058 m .48281 .61054 L .47362 .61243 L .742 .478 .807 r
F
.48026 .62058 m .48791 .61887 L .48281 .61054 L F
.48791 .61887 m .49258 .60947 L .48281 .61054 L .744 .487 .81 r
F
.47362 .61243 m .48281 .61054 L .47768 .60234 L .72 .468 .812 r
F
.48281 .61054 m .4891 .60136 L .47768 .60234 L .721 .485 .818 r
F
.48281 .61054 m .49258 .60947 L .4891 .60136 L F
.47768 .60234 m .4856 .59372 L .47253 .59426 L .678 .472 .831 r
F
.47768 .60234 m .4891 .60136 L .4856 .59372 L F
.4891 .60136 m .4992 .59344 L .48561 .59372 L .704 .51 .833 r
F
.47253 .59426 m .4856 .59372 L .48209 .58678 L .604 .425 .85 r
F
.48561 .59372 m .49742 .58683 L .48209 .58678 L .639 .487 .857 r
F
.48561 .59372 m .4992 .59344 L .49742 .58683 L F
.46769 .58172 m .4882 .59476 L .4882 .59476 L .583 0 .116 r
F
.5098 .56191 m .51301 .55732 L .51301 .5567 L 1 .281 .594 r
F
.46561 .62818 m .4882 .59476 L .48728 .59797 L .583 0 .116 r
F
.47432 .61873 m .48728 .59797 L .48453 .60765 L F
.46561 .62818 m .48728 .59797 L .47432 .61873 L F
.49742 .58683 m .51306 .5793 L .49563 .58171 L .735 .625 .859 r
F
.49563 .58171 m .51306 .5793 L .51305 .57386 L .701 .618 .881 r
F
.4901 .58563 m .51303 .56561 L .51302 .56117 L .882 .331 .732 r
F
.4901 .58563 m .51302 .56117 L .4882 .59476 L F
.50019 .57667 m .51302 .56117 L .51301 .55732 L 1 .302 .633 r
F
.4882 .59476 m .49842 .58092 L .50019 .57667 L F
.49842 .58092 m .51302 .56117 L .50019 .57667 L F
.49866 .57927 m .51301 .55732 L .50715 .56671 L F
.48823 .59472 m .50019 .57667 L .49866 .57927 L F
.50019 .57667 m .51301 .55732 L .49866 .57927 L F
.48694 .59909 m .4882 .59476 L .48694 .59909 L .714 0 .179 r
F
.46769 .58172 m .4882 .59476 L .46561 .62818 L .583 0 .116 r
F
.4758 .60947 m .47949 .61239 L .48487 .59833 L .377 0 .563 r
F
.47983 .62696 m .48515 .60661 L .48661 .60049 L .714 0 .179 r
F
.46495 .64307 m .48453 .60765 L .46319 .68259 L .583 0 .116 r
F
.46561 .62818 m .48453 .60765 L .46495 .64307 L F
.46841 .62412 m .46894 .61998 L .46843 .6241 L 1 .678 .615 r
F
.46894 .61998 m .47329 .5864 L .46896 .61998 L F
.46894 .61998 m .46896 .61998 L .46843 .6241 L F
.47804 .63421 m .48515 .60661 L .47983 .62696 L .714 0 .179 r
F
.48026 .62521 m .48661 .60049 L .48676 .59981 L F
.48024 .62527 m .48661 .60049 L .48026 .62521 L F
.47962 .62777 m .48661 .60049 L .48009 .62586 L F
.48928 .63836 m .48689 .62871 L .48127 .63074 L .761 .48 .801 r
F
.46336 .66312 m .46841 .62412 L .46334 .66359 L 1 .678 .615 r
F
.46841 .62412 m .46843 .6241 L .46334 .66359 L F
.46769 .58172 m .4901 .58563 L .4882 .59476 L .583 0 .116 r
F
.46628 .57702 m .47327 .58637 L .46336 .66312 L 1 .678 .615 r
F
.47327 .58637 m .47329 .5864 L .46336 .66312 L F
.46898 .61371 m .47288 .58927 L .47162 .59052 L 1 .226 .416 r
F
.46899 .61407 m .47288 .58927 L .46898 .61371 L F
.46892 .6199 m .46915 .61818 L .46879 .61537 L F
.46915 .61818 m .47288 .58927 L .46899 .61412 L F
.46915 .61818 m .46899 .61412 L .46879 .61537 L F
.46814 .52195 m .48869 .46683 L .47328 .58627 L 1 .678 .615 r
F
.46814 .52195 m .47329 .5864 L .46628 .57702 L F
.46335 .66308 m .48759 .45055 L .46222 .50717 L 1 .226 .416 r
F
.46122 .58318 m .46794 .58749 L .45781 .54972 L .377 0 .563 r
F
.47328 .58627 m .48869 .46683 L .47329 .5864 L 1 .678 .615 r
F
.47288 .58927 m .47462 .57577 L .47162 .59052 L 1 .226 .416 r
F
.47462 .57577 m .47369 .57552 L .47162 .59052 L F
.47162 .59052 m .47369 .57552 L .47334 .57543 L F
.46794 .58749 m .48487 .59833 L .46711 .56642 L .377 0 .563 r
F
.46794 .58749 m .46711 .56642 L .45781 .54972 L F
.46794 .58749 m .4758 .60947 L .48487 .59833 L F
.46122 .58318 m .46827 .5959 L .46794 .58749 L F
.46827 .5959 m .4758 .60947 L .46794 .58749 L F
.46879 .61537 m .46899 .61407 L .46898 .61371 L 1 .226 .416 r
F
.46335 .66308 m .46892 .6199 L .46879 .61537 L F
.46828 .59845 m .4784 .61717 L .47936 .61689 L .402 0 .56 r
F
.45311 .59147 m .46285 .5992 L .46277 .58747 L .486 0 .477 r
F
.46153 .5872 m .46831 .59924 L .46828 .59845 L .402 0 .56 r
F
.46831 .59924 m .4784 .61717 L .46828 .59845 L F
.45311 .59147 m .46331 .66656 L .46285 .5992 L .486 0 .477 r
F
.45945 .64085 m .46331 .66656 L .44988 .57325 L F
.46319 .66732 m .4633 .66834 L .45958 .64176 L .698 .002 .45 r
F
.45805 .63606 m .46325 .67478 L .46044 .65273 L .321 0 .462 r
F
.46044 .65273 m .46325 .67478 L .46319 .67189 L F
.46044 .65273 m .46319 .67189 L .46153 .5872 L F
.46316 .68599 m .46687 .67753 L .46633 .6684 L 1 .271 .578 r
F
.46305 .6795 m .46633 .6684 L .46153 .58721 L F
.46316 .68599 m .46633 .6684 L .46305 .6795 L F
.48689 .59922 m .4879 .59462 L .48516 .59903 L 1 .427 .606 r
F
.48689 .59922 m .48516 .59903 L .48514 .59908 L F
.48689 .59922 m .48513 .59907 L .48496 .59949 L F
.48071 .61964 m .48694 .59909 L .48259 .61329 L .77 0 .251 r
F
.48067 .6198 m .48694 .59909 L .48071 .61964 L F
.48047 .62047 m .48694 .59909 L .48049 .62041 L F
.48259 .61329 m .48645 .60069 L .48676 .59946 L F
.48645 .60069 m .48694 .59909 L .48676 .59946 L F
.48026 .62521 m .48694 .59909 L .48047 .62047 L .714 0 .179 r
F
.48676 .59946 m .48676 .59946 L .48495 .59949 L 1 .427 .606 r
F
.48676 .59946 m .4868 .59923 L .48495 .59949 L F
.48676 .59946 m .48495 .59949 L .48494 .5995 L F
.48515 .60661 m .48743 .59773 L .48694 .59909 L .714 0 .179 r
F
.48743 .59773 m .4882 .59476 L .48694 .59909 L F
.48743 .59773 m .48694 .59909 L .48694 .59909 L F
.48676 .59946 m .48694 .59909 L .48676 .59946 L .77 0 .251 r
F
.48694 .59909 m .48694 .59909 L .48676 .59946 L 1 .281 .594 r
F
.48823 .59472 m .50715 .56671 L .48694 .59909 L 1 .302 .633 r
F
.48695 .59907 m .48872 .59625 L .48883 .59602 L 1 .281 .594 r
F
.48694 .59909 m .48872 .59625 L .48695 .59907 L F
.48694 .59909 m .48872 .59625 L .48872 .59625 L F
.48883 .59602 m .50716 .5667 L .5098 .56191 L F
.48872 .59625 m .50716 .5667 L .48883 .59602 L F
.48694 .59909 m .5098 .56191 L .48687 .59928 L F
.48676 .59946 m .48694 .59909 L .48676 .59946 L .77 0 .251 r
F
.48694 .59909 m .48687 .59928 L .48676 .59946 L 1 .281 .594 r
F
.47462 .57577 m .48873 .46653 L .47369 .57552 L 1 .226 .416 r
F
.47334 .57543 m .48873 .46653 L .48759 .45055 L F
.47369 .57552 m .48873 .46653 L .47334 .57543 L F
.49938 .518 m .51307 .50833 L .49762 .51104 L .89 .642 .807 r
F
.49938 .518 m .51308 .51682 L .51307 .50833 L F
.49762 .51104 m .51307 .50833 L .51306 .49902 L 1 .696 .788 r
F
.49762 .51104 m .51306 .49902 L .49585 .5043 L F
.49585 .5043 m .51306 .49902 L .51305 .4884 L 1 .732 .759 r
F
.49546 .53792 m .51297 .51225 L .51296 .49716 L 1 .681 .599 r
F
.49585 .5043 m .51305 .4884 L .49407 .49781 L 1 .732 .759 r
F
.49407 .49781 m .51305 .4884 L .51304 .47572 L 1 .721 .718 r
F
.49407 .49781 m .51304 .47572 L .49229 .49115 L F
.49229 .49115 m .51304 .47572 L .51303 .46 L 1 .659 .674 r
F
.4905 .48235 m .51303 .46 L .51302 .44052 L 1 .573 .636 r
F
.49229 .49115 m .51303 .46 L .4905 .48235 L 1 .659 .674 r
F
.48873 .46653 m .51302 .44051 L .51302 .42561 L 1 .495 .617 r
F
.4905 .48235 m .51302 .44052 L .48873 .46653 L 1 .573 .636 r
F
.48595 .52005 m .49938 .518 L .49762 .51104 L .796 .652 .842 r
F
.49456 .52423 m .51296 .49716 L .51295 .48118 L 1 .684 .597 r
F
.49451 .52689 m .49443 .53194 L .49454 .52693 L .264 0 .6 r
F
.47768 .50366 m .49442 .53192 L .49444 .53044 L F
.47768 .50366 m .49444 .53044 L .49448 .52685 L F
.49451 .52417 m .49454 .52693 L .49456 .52423 L F
.47768 .50366 m .4945 .52688 L .49451 .52417 L F
.4945 .52688 m .49454 .52693 L .49451 .52417 L F
.47768 .50366 m .49455 .52422 L .47585 .48253 L F
.49455 .52422 m .49455 .52421 L .47585 .48253 L F
.49456 .52423 m .49464 .52232 L .47585 .48253 L F
.49464 .52232 m .49494 .51552 L .49477 .51523 L F
.49464 .52232 m .49477 .51523 L .47585 .48253 L F
.47585 .48253 m .49481 .5153 L .49485 .50702 L .246 0 .597 r
F
.46193 .50086 m .48743 .44798 L .48572 .41798 L 1 .393 .57 r
F
.46222 .50716 m .48743 .44798 L .46193 .50088 L 1 .446 .571 r
F
.46222 .50716 m .48759 .45054 L .48743 .44798 L F
.47402 .46167 m .49494 .49858 L .4949 .48983 L .232 0 .594 r
F
.4958 .4702 m .51292 .42956 L .49597 .46291 L 1 .67 .591 r
F
.4958 .4702 m .49597 .46291 L .49488 .46504 L F
.46193 .50086 m .48572 .41798 L .45874 .45029 L 1 .393 .57 r
F
.47402 .46167 m .4949 .48983 L .47219 .44091 L .232 0 .594 r
F
.4949 .48983 m .4951 .48937 L .49498 .48578 L 1 .676 .593 r
F
.4951 .48937 m .51293 .44726 L .49506 .48202 L F
.4951 .48937 m .49506 .48202 L .49487 .48238 L F
.49483 .5236 m .51295 .48118 L .49494 .51552 L 1 .684 .597 r
F
.49508 .50649 m .51294 .4645 L .49509 .49884 L 1 .681 .596 r
F
.49451 .53207 m .51296 .49716 L .49456 .52423 L 1 .684 .597 r
F
.49546 .53813 m .51297 .51225 L .49546 .53792 L 1 .681 .599 r
F
.49522 .53872 m .51297 .51225 L .49523 .53847 L F
.49493 .53943 m .51297 .51225 L .49494 .53915 L F
.4946 .54023 m .51297 .51225 L .4946 .53993 L F
.49423 .54106 m .51297 .51225 L .49424 .54077 L F
.49314 .55389 m .49333 .55198 L .4795 .5253 L .316 0 .608 r
F
.49333 .55198 m .49362 .54846 L .4795 .5253 L F
.4795 .5253 m .49388 .5416 L .47768 .50366 L .286 0 .604 r
F
.49388 .5416 m .49424 .54076 L .49391 .54123 L 1 .681 .599 r
F
.49388 .5416 m .49392 .54098 L .49392 .54097 L .286 0 .604 r
F
.49424 .54076 m .49503 .53108 L .49451 .53207 L 1 .681 .599 r
F
.49388 .5416 m .49392 .54097 L .47768 .50366 L .286 0 .604 r
F
.49424 .54076 m .51296 .49716 L .49503 .53108 L 1 .681 .599 r
F
.49368 .54855 m .51297 .51225 L .49422 .54108 L F
.49449 .54229 m .49544 .53364 L .49451 .53207 L .286 0 .604 r
F
.49392 .54098 m .49451 .53207 L .47768 .50366 L F
.49424 .54077 m .49451 .53207 L .49391 .54123 L 1 .681 .599 r
F
.49424 .54076 m .49451 .53207 L .49424 .54077 L F
.49424 .54077 m .4946 .54023 L .4946 .53993 L F
.49388 .5416 m .49423 .54106 L .49424 .54077 L F
.49449 .54229 m .49451 .53207 L .49392 .54098 L .286 0 .604 r
F
.49259 .55938 m .49312 .55816 L .49368 .54855 L 1 .666 .599 r
F
.49312 .55816 m .51297 .51225 L .49368 .54855 L F
.49368 .54855 m .49422 .54108 L .49388 .5416 L 1 .681 .599 r
F
.49485 .50702 m .49508 .50649 L .49495 .50376 L 1 .681 .596 r
F
.49485 .50702 m .49491 .50518 L .47402 .46167 L .246 0 .597 r
F
.49388 .5416 m .49368 .54855 L .49407 .54181 L .286 0 .604 r
F
.4795 .5253 m .49362 .54846 L .49388 .5416 L F
.49362 .54846 m .49368 .54855 L .49388 .5416 L F
.49391 .54123 m .49451 .53207 L .49423 .53259 L 1 .681 .599 r
F
.48132 .54787 m .49212 .5649 L .49243 .5616 L .316 0 .608 r
F
.49259 .55938 m .51298 .52619 L .51297 .51225 L 1 .666 .599 r
F
.49259 .55938 m .49243 .5616 L .49248 .56109 L .316 0 .608 r
F
.48132 .54787 m .49243 .5616 L .49259 .55938 L F
.48121 .58096 m .4901 .58563 L .47855 .58362 L .527 0 0 r
F
.4831 .57173 m .4899 .57765 L .48132 .54787 L .355 0 .612 r
F
.48726 .59431 m .513 .54871 L .51299 .53842 L 1 .541 .597 r
F
.48617 .59667 m .48717 .59489 L .48726 .59431 L F
.48717 .59489 m .513 .54871 L .48726 .59431 L F
.48607 .59718 m .513 .54871 L .48617 .59667 L F
.48523 .59885 m .513 .54871 L .48529 .59859 L F
.49018 .5779 m .48977 .58159 L .4904 .5774 L 1 .624 .598 r
F
.4831 .57173 m .48937 .58099 L .4899 .57765 L .355 0 .612 r
F
.48977 .58159 m .48991 .58134 L .49008 .57995 L 1 .624 .598 r
F
.48977 .58159 m .49008 .57995 L .4904 .5774 L F
.48991 .58134 m .51299 .53842 L .4904 .5774 L F
.49607 .58145 m .50343 .56666 L .48685 .596 L 1 .427 .606 r
F
.49607 .58145 m .48685 .596 L .48656 .59673 L F
.49607 .58145 m .48521 .5989 L .48513 .59907 L F
.5098 .56191 m .51301 .5567 L .51015 .56136 L 1 .281 .594 r
F
.5098 .56191 m .51015 .56136 L .48676 .59946 L F
.48676 .59946 m .51301 .5567 L .513 .54871 L 1 .427 .606 r
F
.4882 .59476 m .48823 .59472 L .48694 .59909 L 1 .302 .633 r
F
.48689 .59922 m .49607 .58145 L .4879 .59462 L 1 .427 .606 r
F
.50686 .5606 m .50817 .55744 L .48487 .5995 L F
.50449 .61757 m .5131 .60942 L .50274 .6091 L .771 .504 .805 r
F
.50449 .61757 m .51311 .61796 L .5131 .60942 L F
.50274 .6091 m .51309 .6011 L .50098 .60098 L .771 .524 .812 r
F
.50274 .6091 m .5131 .60942 L .51309 .6011 L F
.4891 .60136 m .50098 .60098 L .4992 .59344 L .704 .51 .833 r
F
.50098 .60098 m .51308 .59315 L .4992 .59344 L .768 .553 .822 r
F
.50098 .60098 m .51309 .6011 L .51308 .59315 L F
.4992 .59344 m .51307 .5858 L .49742 .58683 L .757 .59 .838 r
F
.4992 .59344 m .51308 .59315 L .51307 .5858 L F
.48937 .58099 m .48974 .58153 L .4899 .57765 L .355 0 .612 r
F
.48974 .58153 m .48979 .5811 L .4899 .57765 L F
.48977 .58159 m .49039 .57847 L .4899 .57765 L F
.48582 .5963 m .48774 .58801 L .4831 .57173 L .412 .003 .619 r
F
.48726 .59431 m .51299 .53842 L .48977 .58159 L 1 .541 .597 r
F
.48792 .58862 m .48977 .58159 L .4831 .57173 L .412 .003 .619 r
F
.48726 .59431 m .48977 .58159 L .48642 .59429 L 1 .541 .597 r
F
.48825 .58978 m .48977 .58159 L .48792 .58862 L .412 .003 .619 r
F
.48529 .59859 m .48726 .59431 L .48642 .59429 L 1 .541 .597 r
F
.48592 .59722 m .48825 .58978 L .48792 .58862 L .412 .003 .619 r
F
.48674 .59309 m .48792 .58862 L .48774 .58801 L F
.48592 .59722 m .48792 .58862 L .48674 .59309 L F
.48494 .5995 m .48525 .59881 L .48487 .59833 L .514 .027 .631 r
F
.48487 .59833 m .48525 .59881 L .48533 .59861 L .412 .003 .619 r
F
.48487 .59833 m .48533 .59861 L .4831 .57173 L F
.47949 .61239 m .48494 .5995 L .48487 .59833 L .377 0 .563 r
F
.45781 .54972 m .48487 .59833 L .4831 .57173 L .331 0 .57 r
F
.48487 .5995 m .48529 .59859 L .48299 .5942 L 1 .541 .597 r
F
.48592 .59722 m .48774 .58801 L .48582 .5963 L .412 .003 .619 r
F
.48533 .59861 m .48592 .59722 L .4831 .57173 L F
.48529 .59859 m .48642 .59429 L .48299 .5942 L 1 .541 .597 r
F
.48642 .59429 m .48977 .58159 L .48299 .5942 L F
.48299 .5942 m .49018 .5779 L .48111 .58591 L 1 .624 .598 r
F
.49018 .5779 m .49109 .57583 L .49223 .56507 L F
.49109 .57583 m .51298 .52619 L .49223 .56507 L F
.49109 .57583 m .49223 .56507 L .49223 .56507 L F
.49212 .5649 m .49223 .56507 L .49264 .55943 L .316 0 .608 r
F
.49223 .56507 m .51298 .52619 L .49259 .55938 L 1 .666 .599 r
F
.49128 .57541 m .51299 .53842 L .51298 .52619 L 1 .624 .598 r
F
.49126 .57553 m .51299 .53842 L .49128 .57541 L F
.49107 .57604 m .51299 .53842 L .49109 .57583 L F
.49074 .57681 m .51299 .53842 L .49077 .57657 L F
.49607 .58145 m .50686 .5606 L .50343 .56666 L 1 .427 .606 r
F
.49742 .58683 m .51307 .5858 L .51306 .5793 L .735 .625 .859 r
F
.49223 .56507 m .51298 .59776 L .4928 .55973 L .316 0 .608 r
F
.49223 .56507 m .4928 .55973 L .49264 .55943 L F
.49164 .5688 m .51298 .59777 L .49233 .56523 L .355 0 .612 r
F
.4899 .57765 m .49018 .5779 L .49164 .5688 L F
.49109 .57583 m .49126 .57553 L .49128 .57541 L 1 .624 .598 r
F
.49077 .57657 m .49107 .57604 L .49109 .57583 L F
.4904 .5774 m .49074 .57681 L .49077 .57657 L F
.49018 .5779 m .51298 .59777 L .49164 .5688 L .355 0 .612 r
F
.4899 .57765 m .49233 .56523 L .48132 .54787 L F
.49018 .5779 m .49223 .56507 L .49159 .56627 L 1 .624 .598 r
F
.4899 .57765 m .49016 .57808 L .49018 .5779 L .355 0 .612 r
F
.49018 .5779 m .49159 .56627 L .48111 .58591 L 1 .624 .598 r
F
.48974 .58153 m .48977 .58159 L .48979 .5811 L .355 0 .612 r
F
.48977 .58159 m .51299 .61588 L .49039 .57847 L F
.48299 .5942 m .48977 .58159 L .49018 .5779 L 1 .624 .598 r
F
.49018 .5779 m .51299 .61588 L .51298 .59777 L .355 0 .612 r
F
.49016 .57808 m .51299 .61588 L .49018 .5779 L F
.48529 .59859 m .48607 .59718 L .48617 .59667 L 1 .541 .597 r
F
.48487 .5995 m .48523 .59885 L .48529 .59859 L F
.48825 .58978 m .49048 .58263 L .48977 .58159 L .412 .003 .619 r
F
.48111 .5859 m .49223 .56507 L .49259 .55938 L 1 .666 .599 r
F
.49259 .55938 m .49248 .56109 L .49264 .55943 L .316 0 .608 r
F
.48132 .54787 m .49259 .55938 L .4795 .5253 L F
.49259 .55938 m .49264 .55943 L .49259 .55932 L F
.49259 .55938 m .49259 .55932 L .4795 .5253 L F
.49333 .55198 m .49368 .54855 L .49362 .54846 L F
.49264 .55943 m .49329 .55421 L .4795 .5253 L F
.49259 .55938 m .49368 .54855 L .49329 .54928 L 1 .666 .599 r
F
.45435 .5228 m .4831 .57173 L .48132 .54787 L .31 0 .579 r
F
.45781 .54972 m .4831 .57173 L .45435 .5228 L .331 0 .57 r
F
.49259 .55938 m .49329 .54928 L .47921 .57578 L 1 .666 .599 r
F
.4939 .54125 m .49423 .53259 L .47731 .5646 L 1 .681 .599 r
F
.49391 .54123 m .49423 .53259 L .4939 .54125 L F
.49485 .50702 m .51295 .48118 L .51294 .4645 L 1 .681 .596 r
F
.49481 .5153 m .49494 .51552 L .49485 .50702 L .246 0 .597 r
F
.45245 .59429 m .45945 .64085 L .44988 .57325 L .486 0 .477 r
F
.44281 .52219 m .45319 .5971 L .44372 .52131 L .321 0 .462 r
F
.44278 .52223 m .45319 .5971 L .44281 .52219 L F
.44342 .52017 m .44278 .52223 L .44372 .52131 L F
.4416 .51344 m .44272 .52179 L .44342 .52017 L F
.44272 .52179 m .44278 .52223 L .44342 .52017 L F
.4402 .51351 m .44101 .51424 L .43984 .51135 L .486 0 .477 r
F
.44271 .52066 m .44398 .52478 L .44342 .52017 L F
.4415 .52149 m .44398 .52478 L .44271 .52066 L F
.42669 .53825 m .4415 .5215 L .44149 .5215 L .507 .025 .63 r
F
.4222 .52554 m .44149 .5215 L .42004 .51944 L F
.42669 .53825 m .44149 .5215 L .4222 .52554 L F
.4415 .5215 m .45245 .59429 L .44398 .52478 L .486 0 .477 r
F
.4415 .52149 m .4415 .5215 L .4415 .5215 L F
.4415 .5215 m .45245 .59429 L .4415 .5215 L F
.45805 .63606 m .46044 .65273 L .44372 .52131 L .321 0 .462 r
F
.44372 .52131 m .46044 .65273 L .46153 .5872 L F
.4415 .52149 m .44247 .52083 L .4402 .51351 L .486 0 .477 r
F
.44142 .51323 m .44313 .51947 L .43984 .51135 L .321 0 .462 r
F
.4416 .51344 m .44342 .52017 L .44142 .51323 L F
.44247 .52083 m .44342 .52017 L .4402 .51351 L .486 0 .477 r
F
.44342 .52017 m .44313 .51947 L .44142 .51323 L .321 0 .462 r
F
.44342 .52017 m .44582 .51851 L .44101 .51424 L .486 0 .477 r
F
.44342 .52017 m .44101 .51424 L .4402 .51351 L F
.44342 .52017 m .44956 .54291 L .44313 .51947 L .321 0 .462 r
F
.43984 .51135 m .44956 .54291 L .43811 .5093 L F
.44313 .51947 m .44956 .54291 L .43984 .51135 L F
.44101 .51424 m .4446 .51743 L .43984 .51135 L .486 0 .477 r
F
.4446 .51743 m .44582 .51851 L .44471 .51718 L F
.4446 .51743 m .44471 .51718 L .43984 .51135 L F
.44582 .51851 m .46222 .50718 L .43984 .51135 L F
.43775 .49834 m .46193 .50087 L .45873 .4503 L .701 .029 .547 r
F
.43821 .50137 m .46193 .50088 L .43775 .49835 L .681 .018 .529 r
F
.43821 .50137 m .46222 .50716 L .46193 .50088 L F
.45088 .49798 m .48132 .54787 L .4795 .5253 L .296 0 .586 r
F
.45435 .5228 m .48132 .54787 L .45088 .49799 L .31 0 .579 r
F
.4754 .55275 m .49494 .51552 L .49485 .50702 L 1 .681 .596 r
F
.49494 .51552 m .51295 .48118 L .49485 .50702 L F
.49494 .51552 m .495 .51563 L .49485 .50702 L .246 0 .597 r
F
.49732 .51019 m .49791 .50381 L .49509 .49884 L F
.49491 .50518 m .49509 .49884 L .47402 .46167 L F
.49508 .50649 m .49509 .49884 L .49495 .50376 L 1 .681 .596 r
F
.49732 .51019 m .49509 .49884 L .49491 .50518 L .246 0 .597 r
F
.49495 .50376 m .49509 .49884 L .49475 .49951 L 1 .681 .596 r
F
.49485 .50702 m .49495 .50376 L .49488 .50225 L F
.47585 .48253 m .49485 .50702 L .47402 .46167 L .246 0 .597 r
F
.49485 .50702 m .49732 .51019 L .49491 .50518 L F
.49732 .51019 m .51294 .53032 L .49791 .50381 L F
.49264 .55943 m .51298 .59776 L .51297 .58019 L .316 0 .608 r
F
.50686 .5606 m .513 .54871 L .50817 .55744 L 1 .427 .606 r
F
.50716 .5667 m .51301 .55732 L .5098 .56191 L 1 .281 .594 r
F
.49407 .54181 m .51297 .58019 L .51296 .56321 L .286 0 .604 r
F
.49368 .54855 m .51297 .58019 L .49407 .54181 L F
.49443 .53194 m .49451 .53207 L .4946 .52428 L .264 0 .6 r
F
.49451 .53207 m .51296 .56321 L .49474 .52458 L F
.49451 .53207 m .49474 .52458 L .4946 .52428 L F
.49388 .5416 m .49449 .54229 L .49392 .54098 L .286 0 .604 r
F
.47921 .57578 m .49388 .5416 L .47731 .5646 L 1 .681 .599 r
F
.49388 .5416 m .49391 .54123 L .47731 .5646 L F
.49327 .55417 m .49368 .54855 L .49314 .55389 L .316 0 .608 r
F
.48111 .5859 m .49259 .55938 L .47921 .57578 L 1 .666 .599 r
F
.49347 .54895 m .49368 .54855 L .49388 .5416 L 1 .681 .599 r
F
.49877 .56569 m .50087 .56034 L .49368 .54855 L .316 0 .608 r
F
.49877 .56569 m .49368 .54855 L .49327 .55417 L F
.49494 .49858 m .49509 .49884 L .4949 .48983 L .232 0 .594 r
F
.49469 .49035 m .51294 .4645 L .51293 .44726 L 1 .676 .593 r
F
.47349 .5404 m .49467 .49966 L .49469 .49035 L F
.49467 .49966 m .51294 .4645 L .49469 .49035 L F
.48873 .46653 m .51302 .42561 L .48759 .45055 L 1 .495 .617 r
F
.45874 .45029 m .48404 .38609 L .45546 .41145 L 1 .267 .581 r
F
.45874 .45029 m .48572 .41798 L .48404 .38609 L F
.47219 .44091 m .49472 .47252 L .47035 .42017 L .22 0 .59 r
F
.49479 .4726 m .49488 .46504 L .49474 .46478 L F
.49484 .46861 m .49488 .46504 L .49471 .46539 L 1 .67 .591 r
F
.49496 .47162 m .49488 .46504 L .49484 .46861 L F
.49472 .47252 m .49479 .4726 L .49474 .46478 L .22 0 .59 r
F
.4958 .4702 m .49488 .46504 L .49496 .47162 L 1 .67 .591 r
F
.49472 .47252 m .49474 .46478 L .47035 .42017 L .22 0 .59 r
F
.4949 .48983 m .49506 .48202 L .47219 .44091 L .232 0 .594 r
F
.47219 .44091 m .49489 .48171 L .49479 .4726 L .22 0 .59 r
F
.43282 .46539 m .45873 .4503 L .45545 .41146 L .874 .094 .568 r
F
.43775 .49834 m .45873 .4503 L .43282 .46539 L .701 .029 .547 r
F
.44383 .44974 m .47768 .50366 L .47585 .48253 L .277 0 .591 r
F
.44735 .47369 m .47768 .50366 L .44383 .44974 L .286 0 .589 r
F
.44735 .47369 m .4795 .5253 L .47768 .50366 L F
.45088 .49798 m .4795 .5253 L .44735 .47369 L .296 0 .586 r
F
.47158 .52769 m .4958 .4702 L .46966 .51467 L 1 .67 .591 r
F
.49489 .48171 m .49506 .48202 L .49479 .4726 L .22 0 .59 r
F
.49456 .47315 m .51293 .44726 L .51292 .42956 L 1 .67 .591 r
F
.47158 .52769 m .4946 .4829 L .49456 .47315 L F
.4946 .4829 m .51293 .44726 L .49456 .47315 L F
.45546 .41145 m .48404 .38609 L .48235 .35398 L 1 .222 .583 r
F
.48743 .44798 m .51301 .39795 L .48572 .41798 L 1 .405 .606 r
F
.48743 .44798 m .51302 .42337 L .51301 .39795 L F
.48759 .45054 m .51302 .42337 L .48743 .44798 L 1 .444 .613 r
F
.48759 .45054 m .51302 .4256 L .51302 .42337 L F
.47035 .42017 m .49447 .45517 L .46852 .39938 L .21 0 .587 r
F
.49455 .45528 m .49596 .4519 L .49455 .45437 L 1 .664 .589 r
F
.49455 .45528 m .49461 .4479 L .49443 .44757 L .21 0 .587 r
F
.49455 .45528 m .49455 .45437 L .49453 .45441 L 1 .664 .589 r
F
.49447 .45517 m .49455 .45528 L .49443 .44757 L .21 0 .587 r
F
.49596 .4519 m .51291 .41147 L .4961 .44494 L 1 .664 .589 r
F
.49447 .45517 m .49443 .44757 L .46852 .39938 L .21 0 .587 r
F
.47035 .42017 m .49469 .4647 L .49455 .45528 L F
.49596 .4519 m .4961 .44494 L .46773 .50139 L 1 .664 .589 r
F
.49455 .45528 m .51292 .42956 L .51291 .41147 L F
.49469 .4647 m .49488 .46504 L .49455 .45528 L .21 0 .587 r
F
.46966 .51467 m .49488 .46504 L .49455 .45528 L 1 .664 .589 r
F
.49488 .46504 m .51292 .42956 L .49455 .45528 L F
.49488 .46504 m .49621 .46746 L .49455 .45528 L .21 0 .587 r
F
.49455 .45528 m .51291 .48193 L .49461 .4479 L F
.49479 .4726 m .51292 .49803 L .49488 .46504 L .22 0 .59 r
F
.4949 .48983 m .51293 .51414 L .49506 .48202 L .232 0 .594 r
F
.4949 .48983 m .49498 .48578 L .49487 .48238 L 1 .676 .593 r
F
.49506 .48202 m .49586 .48346 L .49501 .47492 L .22 0 .59 r
F
.49506 .48202 m .49501 .47492 L .49479 .4726 L F
.49479 .4726 m .49586 .48346 L .49596 .47425 L F
.49478 .47193 m .49471 .46539 L .46966 .51467 L 1 .67 .591 r
F
.49496 .47162 m .49471 .46539 L .49478 .47193 L F
.49477 .45561 m .49621 .46746 L .49631 .45784 L .21 0 .587 r
F
.49455 .45528 m .49479 .45708 L .49477 .45561 L F
.49479 .45708 m .49621 .46746 L .49477 .45561 L F
.46966 .51467 m .49455 .45528 L .46773 .50139 L 1 .664 .589 r
F
.49455 .45528 m .49453 .45441 L .46773 .50139 L F
.49455 .52422 m .49456 .52423 L .49455 .52421 L .264 0 .6 r
F
.49456 .52423 m .49483 .5236 L .49476 .51947 L 1 .684 .597 r
F
.49483 .5236 m .49494 .51552 L .49471 .51595 L F
.49456 .52423 m .51295 .54664 L .49494 .51552 L .264 0 .6 r
F
.49456 .52423 m .49476 .51947 L .49471 .51595 L 1 .684 .597 r
F
.49505 .50727 m .495 .51563 L .49514 .50739 L .246 0 .597 r
F
.49485 .50702 m .49496 .51337 L .49505 .50727 L F
.49496 .51337 m .495 .51563 L .49505 .50727 L F
.49467 .50745 m .49485 .50702 L .49475 .49951 L 1 .681 .596 r
F
.49485 .50702 m .49488 .50225 L .49475 .49951 L F
.49509 .49884 m .49547 .4995 L .4951 .49325 L .232 0 .594 r
F
.49509 .49884 m .4951 .49325 L .4949 .48983 L F
.4949 .48983 m .49547 .4995 L .49558 .49075 L F
.49463 .49049 m .4949 .48983 L .49465 .48281 L 1 .676 .593 r
F
.4949 .48983 m .49487 .48238 L .49465 .48281 L F
.47349 .5404 m .49463 .49049 L .47158 .52769 L F
.49463 .49049 m .49465 .48281 L .47158 .52769 L F
.4754 .55275 m .49467 .50745 L .47349 .5404 L 1 .681 .596 r
F
.49467 .50745 m .49475 .49951 L .47349 .5404 L F
.49448 .52685 m .49444 .53044 L .49451 .52689 L .264 0 .6 r
F
.49442 .53192 m .49443 .53194 L .49451 .52689 L F
.47731 .5646 m .49456 .52423 L .4754 .55275 L 1 .684 .597 r
F
.49456 .52423 m .49471 .51595 L .4754 .55275 L F
.47731 .5646 m .49451 .53207 L .49456 .52423 L F
.49456 .52423 m .49454 .52693 L .4946 .52428 L .264 0 .6 r
F
.49631 .45784 m .51292 .49803 L .51291 .48193 L .21 0 .587 r
F
.49621 .46746 m .51292 .49803 L .49631 .45784 L F
.49523 .53847 m .49546 .53813 L .49546 .53792 L 1 .681 .599 r
F
.49494 .53915 m .49522 .53872 L .49523 .53847 L F
.49596 .47425 m .51293 .51414 L .51292 .49803 L .22 0 .59 r
F
.49586 .48346 m .51293 .51414 L .49596 .47425 L F
.49558 .49075 m .51294 .53032 L .51293 .51414 L .232 0 .594 r
F
.49547 .4995 m .51294 .53032 L .49558 .49075 L F
.4946 .53993 m .49493 .53943 L .49494 .53915 L 1 .681 .599 r
F
.49514 .50739 m .51295 .54664 L .51294 .53032 L .246 0 .597 r
F
.495 .51563 m .51295 .54664 L .49514 .50739 L F
.4946 .52428 m .51296 .56321 L .51295 .54664 L .264 0 .6 r
F
.47921 .57578 m .49347 .54895 L .49388 .5416 L 1 .681 .599 r
F
.49449 .54229 m .51296 .56321 L .49544 .53364 L .286 0 .604 r
F
.49264 .55943 m .49877 .56569 L .49329 .55421 L .316 0 .608 r
F
.49877 .56569 m .51297 .58019 L .50087 .56034 L F
.48656 .59673 m .48685 .596 L .48521 .5989 L 1 .427 .606 r
F
.48513 .59907 m .48521 .5989 L .48487 .5995 L F
.48613 .59911 m .48779 .59285 L .48592 .59722 L .412 .003 .619 r
F
.48779 .59285 m .49048 .58263 L .48592 .59722 L F
.48928 .63836 m .49349 .63682 L .48689 .62871 L .761 .48 .801 r
F
.49349 .63682 m .493 .62728 L .48689 .62871 L .761 .482 .802 r
F
.49349 .63682 m .49807 .63573 L .493 .62728 L F
.49807 .63573 m .4995 .62644 L .493 .62728 L .761 .483 .802 r
F
.49807 .63573 m .50293 .6351 L .4995 .62644 L F
.50293 .6351 m .50624 .62622 L .4995 .62644 L .763 .483 .801 r
F
.50293 .6351 m .50798 .63494 L .50624 .62622 L F
.50798 .63494 m .51312 .6266 L .50624 .62622 L .766 .483 .8 r
F
.50798 .63494 m .51313 .63526 L .51312 .6266 L F
.48689 .62871 m .493 .62728 L .48791 .61887 L .755 .481 .804 r
F
.493 .62728 m .49605 .61787 L .48791 .61887 L .756 .485 .805 r
F
.493 .62728 m .4995 .62644 L .49605 .61787 L F
.4995 .62644 m .50449 .61757 L .49605 .61787 L .761 .489 .804 r
F
.4995 .62644 m .50624 .62622 L .50449 .61757 L F
.50624 .62622 m .51311 .61796 L .50449 .61757 L .769 .491 .802 r
F
.50624 .62622 m .51312 .6266 L .51311 .61796 L F
.48791 .61887 m .49605 .61787 L .49258 .60947 L .744 .487 .81 r
F
.49605 .61787 m .50274 .6091 L .49258 .60947 L .754 .497 .809 r
F
.49605 .61787 m .50449 .61757 L .50274 .6091 L F
.49258 .60947 m .50098 .60098 L .4891 .60136 L .738 .505 .818 r
F
.49258 .60947 m .50274 .6091 L .50098 .60098 L F
.48078 .61927 m .48132 .62089 L .48145 .62037 L .402 0 .56 r
F
.48083 .61913 m .48676 .59946 L .48085 .61858 L .77 0 .251 r
F
.48058 .61809 m .48085 .61857 L .48079 .61343 L .377 0 .563 r
F
.48085 .61857 m .48092 .61824 L .48079 .61343 L F
.48085 .61857 m .48676 .59946 L .48494 .5995 L .888 0 .353 r
F
.48093 .61872 m .48128 .61743 L .48079 .61343 L .377 0 .563 r
F
.48071 .61915 m .48069 .61961 L .48078 .61927 L .402 0 .56 r
F
.47936 .61689 m .48064 .6195 L .48071 .61915 L F
.48064 .6195 m .48069 .61961 L .48071 .61915 L F
.48105 .61364 m .48128 .61743 L .48207 .61444 L .377 0 .563 r
F
.48079 .61343 m .48099 .61509 L .48105 .61364 L F
.48099 .61509 m .48128 .61743 L .48105 .61364 L F
.4758 .60947 m .48058 .61809 L .48079 .61343 L F
.48078 .61927 m .4804 .6207 L .48049 .62041 L .77 0 .251 r
F
.48083 .61913 m .48049 .62041 L .48259 .61329 L F
.48078 .61927 m .48049 .62041 L .48083 .61913 L F
.4804 .62072 m .4804 .6207 L .48078 .61927 L F
.4804 .6207 m .48047 .62047 L .48049 .62041 L F
.48026 .62521 m .48047 .62047 L .4804 .62072 L .714 0 .179 r
F
.4801 .6257 m .4804 .62072 L .4804 .62072 L F
.4801 .6257 m .4804 .62072 L .47671 .63621 L F
.48026 .62521 m .4804 .62072 L .4801 .6257 L F
.46687 .67753 m .4804 .62072 L .46153 .58721 L 1 .271 .578 r
F
.46316 .68599 m .46548 .68302 L .46687 .67753 L F
.46577 .68185 m .47804 .63421 L .47983 .62696 L .714 0 .179 r
F
.46422 .68791 m .47804 .63421 L .46577 .68185 L F
.46548 .68302 m .46615 .68216 L .46687 .67753 L 1 .271 .578 r
F
.46687 .67753 m .47962 .62777 L .48009 .62586 L .714 0 .179 r
F
.46311 .69223 m .46652 .6789 L .46687 .67753 L F
.46652 .6789 m .47962 .62777 L .46687 .67753 L F
.46311 .69223 m .46687 .67753 L .46068 .68588 L F
.46687 .67753 m .48026 .62521 L .47013 .65659 L F
.46687 .67753 m .47013 .65659 L .46068 .68588 L F
.48552 .64032 m .48928 .63836 L .48127 .63074 L .762 .478 .8 r
F
.46687 .67753 m .48795 .65423 L .4868 .63209 L 1 .271 .578 r
F
.46615 .68216 m .48795 .65423 L .46687 .67753 L F
.46687 .67753 m .48107 .62191 L .4804 .62072 L F
.47671 .63621 m .4804 .62072 L .46068 .68588 L .714 0 .179 r
F
.4784 .61717 m .4804 .62071 L .47936 .61689 L .402 0 .56 r
F
.4804 .62071 m .48068 .62121 L .48042 .62036 L F
.4804 .62071 m .48042 .62036 L .47936 .61689 L F
.48068 .62121 m .4868 .63208 L .48076 .61975 L F
.48049 .62041 m .48067 .6198 L .48071 .61964 L .77 0 .251 r
F
.48068 .62121 m .48076 .61975 L .47936 .61689 L .402 0 .56 r
F
.47936 .61689 m .48078 .61927 L .47976 .61662 L F
.48083 .61913 m .48085 .61858 L .48085 .61858 L .77 0 .251 r
F
.48083 .61913 m .48085 .61858 L .48082 .61887 L F
.48083 .61913 m .48082 .61868 L .48079 .61926 L F
.48078 .61927 m .48083 .61913 L .48079 .61926 L F
.48078 .61927 m .48663 .629 L .48085 .61858 L .402 0 .56 r
F
.48078 .61927 m .48085 .61858 L .47976 .61662 L F
.48082 .61887 m .48085 .61858 L .48082 .61868 L .77 0 .251 r
F
.48079 .61926 m .48082 .61868 L .46034 .68489 L F
.47949 .61239 m .48277 .615 L .48494 .5995 L .377 0 .563 r
F
.46034 .68489 m .48082 .61868 L .48487 .5995 L .888 0 .353 r
F
.48082 .61868 m .48085 .61857 L .48103 .61773 L F
.48082 .61868 m .48103 .61773 L .48487 .5995 L F
.48085 .61857 m .48494 .5995 L .48487 .5995 L F
.48085 .61857 m .48093 .61872 L .48092 .61824 L .377 0 .563 r
F
.48093 .61872 m .48157 .61987 L .48128 .61743 L F
.46068 .68588 m .4804 .62072 L .48078 .61927 L .77 0 .251 r
F
.48069 .61961 m .48076 .61975 L .48078 .61927 L .402 0 .56 r
F
.48076 .61975 m .48132 .62089 L .48078 .61927 L F
.46068 .68588 m .48078 .61927 L .46034 .68489 L .77 0 .251 r
F
.48078 .61927 m .48079 .61926 L .46034 .68489 L F
.48663 .629 m .513 .63495 L .48525 .59881 L .514 .027 .631 r
F
.48514 .59908 m .48516 .59903 L .48513 .59907 L 1 .427 .606 r
F
.48663 .629 m .48525 .59881 L .48494 .5995 L .514 .027 .631 r
F
.48676 .59946 m .48689 .59922 L .4868 .59923 L 1 .427 .606 r
F
.48676 .59946 m .48676 .59946 L .48676 .59946 L .77 0 .251 r
F
.48676 .59981 m .48661 .60049 L .48694 .59909 L .714 0 .179 r
F
.48533 .59861 m .513 .63495 L .51299 .61588 L .412 .003 .619 r
F
.48525 .59881 m .513 .63495 L .48533 .59861 L F
.48496 .59949 m .48513 .59907 L .48487 .5995 L 1 .427 .606 r
F
.48533 .59861 m .48613 .59911 L .48592 .59722 L .412 .003 .619 r
F
.48613 .59911 m .51299 .61588 L .49048 .58263 L F
.48207 .61444 m .48157 .61987 L .48277 .615 L .377 0 .563 r
F
.48128 .61743 m .48157 .61987 L .48207 .61444 L F
.48277 .615 m .48663 .629 L .48598 .61754 L F
.48157 .61987 m .48663 .629 L .48277 .615 L F
.48009 .62586 m .48024 .62527 L .48026 .62521 L .714 0 .179 r
F
.48145 .62037 m .4868 .63208 L .48663 .629 L .402 0 .56 r
F
.48132 .62089 m .4868 .63208 L .48145 .62037 L F
.46153 .5872 m .47936 .61689 L .46122 .58319 L F
.47936 .61689 m .47976 .61662 L .46122 .58319 L F
.46687 .67753 m .4868 .63209 L .48107 .62191 L 1 .271 .578 r
F
.46311 .69223 m .46422 .68791 L .46577 .68185 L .714 0 .179 r
F
.48277 .615 m .48598 .61754 L .48525 .60491 L .377 0 .563 r
F
.48277 .615 m .48525 .60491 L .48494 .5995 L F
.48494 .5995 m .48495 .59949 L .48487 .5995 L 1 .427 .606 r
F
.44956 .54291 m .46153 .5872 L .44533 .53331 L .321 0 .462 r
F
.44956 .54291 m .44533 .53331 L .43811 .5093 L F
.44997 .57396 m .45805 .63606 L .45319 .5971 L F
.45245 .59429 m .45805 .63606 L .44997 .57396 L F
.43638 .5032 m .43984 .51135 L .43821 .50138 L .597 .031 .595 r
F
.43798 .5091 m .43798 .50909 L .43047 .50008 L .654 0 0 r
F
.43455 .50502 m .43915 .51053 L .43638 .5032 L .597 .031 .595 r
F
.43915 .51053 m .43984 .51135 L .43638 .5032 L F
.42054 .48816 m .42721 .49617 L .42653 .49537 L .548 0 0 r
F
.42053 .48815 m .42643 .49523 L .42054 .48816 L F
.42643 .49523 m .42721 .49617 L .42054 .48816 L F
.42053 .48815 m .43179 .50169 L .4161 .48017 L F
.43179 .50169 m .43427 .50467 L .4303 .49932 L F
.43179 .50169 m .4303 .49932 L .4161 .48017 L F
.43427 .50467 m .43409 .50439 L .43017 .49911 L F
.4303 .49932 m .43017 .49911 L .4161 .48017 L F
.43427 .50467 m .43017 .49911 L .4303 .49932 L F
.42248 .48521 m .42326 .48592 L .41652 .47348 L 0 0 .586 r
F
.42164 .48273 m .43282 .46539 L .4182 .47476 L .685 .049 .586 r
F
.42082 .48112 m .4182 .47476 L .41773 .47506 L F
.42164 .48273 m .4182 .47476 L .42082 .48112 L F
.42326 .48592 m .41951 .47855 L .41652 .47348 L 0 0 .586 r
F
.43154 .50038 m .43775 .49835 L .43121 .49985 L .675 .048 .588 r
F
.43153 .50039 m .43121 .49985 L .41547 .4789 L 0 0 .509 r
F
.43123 .49987 m .43121 .49985 L .43121 .49985 L .675 .048 .588 r
F
.43154 .50038 m .43121 .49985 L .43123 .49987 L F
.4161 .48016 m .43153 .50039 L .41547 .4789 L 0 0 .509 r
F
.43154 .50038 m .43121 .49985 L .43126 .49995 L .675 .048 .588 r
F
.43288 .50237 m .43821 .50137 L .43174 .5007 L F
.43455 .50502 m .43288 .50237 L .4161 .48017 L .548 0 0 r
F
.43153 .50039 m .43821 .50137 L .43775 .49835 L .675 .048 .588 r
F
.42867 .49673 m .43183 .50099 L .43228 .50149 L 0 0 .509 r
F
.4161 .48016 m .42895 .49717 L .42867 .49673 L F
.42895 .49717 m .43183 .50099 L .42867 .49673 L F
.427 .49246 m .43775 .49834 L .42326 .48592 L .685 .049 .586 r
F
.41547 .4789 m .43121 .49984 L .42326 .48592 L 0 0 .586 r
F
.4283 .49616 m .43228 .50149 L .43153 .50039 L 0 0 .509 r
F
.4161 .48016 m .42867 .49673 L .4283 .49616 L F
.42867 .49673 m .43228 .50149 L .4283 .49616 L F
.42215 .48832 m .42089 .48453 L .40848 .48098 L .685 .049 .586 r
F
.42089 .48453 m .42075 .48411 L .42059 .48407 L F
.42089 .48453 m .42059 .48407 L .40848 .48098 L F
.43038 .50003 m .43775 .49834 L .42159 .4895 L F
.42326 .48592 m .43121 .49984 L .42525 .48771 L 0 0 .586 r
F
.43121 .49984 m .43121 .49984 L .42326 .48592 L F
.42326 .48592 m .43775 .49834 L .43282 .46539 L .685 .049 .586 r
F
.42159 .4895 m .427 .49246 L .42326 .48592 L F
.42089 .48453 m .42267 .48718 L .42075 .48411 L F
.42215 .48832 m .42263 .48727 L .42089 .48453 L F
.42263 .48727 m .42267 .48718 L .42089 .48453 L F
.43087 .5006 m .43174 .5007 L .43153 .50039 L .675 .048 .588 r
F
.43174 .5007 m .43821 .50137 L .43153 .50039 L F
.43153 .50039 m .43228 .50149 L .43294 .50223 L 0 0 .509 r
F
.43153 .50039 m .43762 .50837 L .43121 .49985 L F
.42525 .48771 m .43762 .50837 L .43242 .49417 L 0 0 .586 r
F
.43121 .49984 m .43762 .50837 L .42525 .48771 L F
.43126 .49995 m .43121 .49985 L .4312 .49985 L .675 .048 .588 r
F
.42267 .48718 m .42326 .48592 L .42075 .48411 L .685 .049 .586 r
F
.42326 .48592 m .43282 .46539 L .42164 .48273 L F
.42248 .48521 m .41652 .47348 L .40879 .46343 L 0 0 .586 r
F
.42326 .48592 m .42164 .48273 L .42075 .48411 L .685 .049 .586 r
F
.41951 .47855 m .41773 .47506 L .41652 .47348 L 0 0 .586 r
F
.42453 .48706 m .41773 .47506 L .41951 .47855 L F
.41544 .46757 m .42729 .47492 L .4095 .45359 L .116 0 .601 r
F
.41388 .46425 m .4095 .45359 L .40804 .45183 L F
.41544 .46757 m .4095 .45359 L .41388 .46425 L F
.42326 .48592 m .42453 .48706 L .41951 .47855 L 0 0 .586 r
F
.42075 .48411 m .42164 .48273 L .41773 .47506 L .685 .049 .586 r
F
.42075 .48411 m .41773 .47506 L .41583 .47628 L F
.42075 .48411 m .41583 .47628 L .40848 .48098 L F
.43087 .5006 m .43154 .50038 L .43039 .50003 L .675 .048 .588 r
F
.43154 .50038 m .4312 .49985 L .43039 .50003 L F
.43427 .50467 m .43455 .50502 L .43409 .50439 L .548 0 0 r
F
.43455 .50502 m .43457 .505 L .43447 .50488 L .597 .031 .595 r
F
.43455 .50502 m .43951 .51096 L .43511 .50568 L .548 0 0 r
F
.43909 .51045 m .43951 .51096 L .43455 .50502 L F
.43511 .50568 m .43967 .51114 L .43521 .50581 L F
.43521 .50581 m .43967 .51114 L .43811 .5093 L F
.43455 .50502 m .43811 .5093 L .43288 .50237 L F
.43455 .50502 m .43447 .50488 L .43242 .50246 L .597 .031 .595 r
F
.43241 .50245 m .43288 .50237 L .43087 .5006 L .675 .048 .588 r
F
.43183 .50099 m .43288 .50237 L .43228 .50149 L 0 0 .509 r
F
.43288 .50237 m .43174 .5007 L .43087 .5006 L .675 .048 .588 r
F
.43228 .50149 m .43288 .50237 L .4324 .50162 L 0 0 .509 r
F
.43288 .50237 m .43288 .50237 L .43228 .50149 L F
.4324 .50162 m .43811 .5093 L .43294 .50223 L F
.43288 .50237 m .43811 .5093 L .4324 .50162 L F
.43951 .51096 m .43967 .51114 L .43511 .50568 L .548 0 0 r
F
.43294 .50223 m .43811 .5093 L .43762 .50837 L 0 0 .509 r
F
.43811 .5093 m .46153 .58719 L .46122 .58318 L .175 0 .49 r
F
.43811 .5093 m .44833 .54198 L .43762 .50837 L F
.44833 .54198 m .46122 .58318 L .44808 .54154 L F
.44833 .54198 m .44808 .54154 L .43762 .50837 L F
.43457 .505 m .43288 .50237 L .43242 .50246 L .597 .031 .595 r
F
.43455 .50502 m .43242 .50246 L .41568 .50559 L F
.41568 .50558 m .43241 .50245 L .43087 .5006 L .675 .048 .588 r
F
.43087 .5006 m .43039 .50003 L .41506 .50355 L F
.42728 .49735 m .42337 .49158 L .42053 .48815 L .654 0 0 r
F
.41506 .50354 m .43038 .50003 L .42159 .4895 L .685 .049 .586 r
F
.4218 .48968 m .42192 .48982 L .42053 .48815 L .654 0 0 r
F
.41506 .50354 m .42199 .48865 L .40848 .48098 L .685 .049 .586 r
F
.42199 .48865 m .42215 .48832 L .42144 .48793 L F
.42199 .48865 m .42144 .48793 L .40848 .48098 L F
.41518 .4674 m .43242 .49417 L .42729 .47492 L .116 0 .601 r
F
.41425 .46682 m .41573 .46905 L .41518 .4674 L F
.41573 .46905 m .43242 .49417 L .41518 .4674 L F
.41471 .46791 m .41478 .4679 L .41425 .46682 L .805 .088 .587 r
F
.41773 .47506 m .43242 .49417 L .41425 .46682 L .116 0 .601 r
F
.41375 .46804 m .41471 .46791 L .41425 .46682 L .805 .088 .587 r
F
.40848 .48098 m .41773 .47506 L .41375 .46804 L F
.42453 .48706 m .43242 .49417 L .41773 .47506 L 0 0 .586 r
F
.40848 .48098 m .41375 .46804 L .40193 .45753 L .805 .088 .587 r
F
.41375 .46804 m .41425 .46682 L .41244 .46546 L F
.41375 .46804 m .41244 .46546 L .40193 .45753 L F
.41425 .46682 m .41237 .46229 L .40217 .4448 L .116 0 .601 r
F
.41425 .46682 m .40804 .45183 L .40193 .45753 L .805 .088 .587 r
F
.41425 .46682 m .41544 .46757 L .41237 .46229 L .116 0 .601 r
F
.40587 .44723 m .40804 .45183 L .40617 .44646 L .9 .125 .588 r
F
.40193 .45753 m .40804 .45183 L .40587 .44723 L F
.40617 .44646 m .42729 .47492 L .42219 .45316 L .214 0 .603 r
F
.40804 .45183 m .42729 .47492 L .40617 .44646 L F
.39964 .42478 m .41704 .42965 L .39312 .40459 L .268 0 .604 r
F
.39485 .41051 m .39312 .40459 L .39273 .40418 L F
.39964 .42478 m .39312 .40459 L .39485 .41051 L F
.40617 .44646 m .39997 .4285 L .39997 .4285 L .9 .125 .588 r
F
.40193 .45753 m .40519 .44903 L .3954 .43366 L F
.39898 .4246 m .42219 .45316 L .41704 .42965 L .268 0 .604 r
F
.39875 .42453 m .39905 .4249 L .39898 .4246 L F
.39905 .4249 m .42219 .45316 L .39898 .4246 L F
.39997 .4285 m .42219 .45316 L .39875 .42453 L F
.3954 .43366 m .39997 .4285 L .39875 .42453 L .966 .153 .588 r
F
.39875 .42453 m .39709 .41891 L .38898 .40025 L .268 0 .604 r
F
.39875 .42453 m .39273 .40418 L .38879 .40916 L .966 .153 .588 r
F
.39875 .42453 m .39964 .42478 L .39709 .41891 L .268 0 .604 r
F
.39171 .40113 m .39273 .40418 L .39181 .40086 L 1 .172 .587 r
F
.38879 .40916 m .39273 .40418 L .39171 .40113 L F
.39181 .40086 m .41704 .42965 L .41192 .4052 L .298 0 .603 r
F
.39273 .40418 m .41704 .42965 L .39181 .40086 L F
.38593 .37603 m .40681 .38005 L .38015 .35355 L .316 0 .601 r
F
.38162 .35982 m .38015 .35355 L .37988 .35327 L F
.38593 .37603 m .38015 .35355 L .38162 .35982 L F
.39181 .40086 m .39161 .4001 L .38241 .37535 L .298 0 .603 r
F
.39161 .4001 m .38599 .37897 L .38241 .37535 L F
.38241 .37535 m .3861 .37909 L .38528 .37591 L .316 0 .601 r
F
.3822 .3844 m .38521 .37607 L .37564 .35934 L 1 .183 .586 r
F
.38521 .37607 m .38528 .37591 L .38508 .37557 L F
.38521 .37607 m .38508 .37557 L .37564 .35934 L F
.39161 .4001 m .3861 .37909 L .38599 .37897 L .298 0 .603 r
F
.39133 .40216 m .39181 .40086 L .3861 .37909 L 1 .172 .587 r
F
.38879 .40916 m .39133 .40216 L .3822 .3844 L F
.39133 .40216 m .3861 .37909 L .3822 .3844 L F
.38539 .37593 m .41192 .4052 L .40681 .38005 L .316 0 .601 r
F
.38528 .37591 m .38542 .37606 L .38539 .37593 L F
.38542 .37606 m .41192 .4052 L .38539 .37593 L F
.3861 .37909 m .41192 .4052 L .38528 .37591 L F
.3822 .3844 m .3861 .37909 L .38528 .37591 L 1 .183 .586 r
F
.38528 .37591 m .38422 .37148 L .37588 .34929 L .316 0 .601 r
F
.38528 .37591 m .37988 .35327 L .37564 .35934 L 1 .183 .586 r
F
.38528 .37591 m .38593 .37603 L .38422 .37148 L .316 0 .601 r
F
.37901 .35002 m .37988 .35327 L .37905 .34991 L 1 .19 .585 r
F
.37564 .35934 m .37988 .35327 L .37901 .35002 L F
.37988 .35327 m .40805 .31296 L .37905 .34991 L F
.37905 .34991 m .40681 .38005 L .40173 .35434 L .326 0 .599 r
F
.37988 .35327 m .40681 .38005 L .37905 .34991 L F
.37905 .34991 m .40173 .35434 L .37392 .3268 L F
.37564 .35934 m .37892 .35028 L .3691 .33396 L 1 .19 .585 r
F
.37892 .35028 m .37392 .3268 L .3691 .33396 L F
.37313 .32312 m .40173 .35434 L .39667 .32816 L .33 0 .596 r
F
.37304 .3231 m .37315 .32323 L .37313 .32312 L F
.37315 .32323 m .40173 .35434 L .37313 .32312 L F
.37392 .3268 m .40173 .35434 L .37304 .3231 L F
.3739 .32684 m .37392 .3268 L .37304 .3231 L 1 .194 .584 r
F
.3691 .33396 m .3739 .32684 L .37304 .3231 L F
.37309 .32311 m .37252 .32044 L .37229 .31985 L .33 0 .596 r
F
.37296 .32274 m .37229 .31985 L .36294 .29462 L F
.37309 .32311 m .37229 .31985 L .37296 .32274 L F
.36174 .26777 m .39163 .30157 L .38661 .27462 L .332 0 .591 r
F
.36151 .2677 m .36179 .26802 L .36174 .26777 L F
.36179 .26802 m .39163 .30157 L .36174 .26777 L F
.37304 .3231 m .37309 .32311 L .37297 .32278 L .33 0 .596 r
F
.37304 .3231 m .37297 .32278 L .36294 .29462 L F
.37354 .32321 m .36812 .29978 L .36294 .29462 L F
.37304 .3231 m .36812 .29978 L .36258 .30824 L 1 .194 .584 r
F
.36258 .30824 m .36717 .29566 L .35609 .28218 L 1 .196 .582 r
F
.36717 .29566 m .36718 .29565 L .36717 .29564 L F
.36717 .29566 m .36717 .29564 L .35609 .28218 L F
.37309 .32311 m .37354 .32321 L .37252 .32044 L .33 0 .596 r
F
.37354 .32321 m .39667 .32816 L .36812 .29978 L F
.36717 .29566 m .36812 .29978 L .36718 .29565 L 1 .196 .582 r
F
.36258 .30824 m .36812 .29978 L .36717 .29566 L F
.36718 .29565 m .39667 .32816 L .39163 .30157 L .332 0 .594 r
F
.36812 .29978 m .39667 .32816 L .36718 .29565 L F
.36142 .26768 m .36153 .2678 L .36151 .2677 L .332 0 .591 r
F
.36153 .2678 m .39163 .30157 L .36151 .2677 L F
.36718 .29565 m .39163 .30157 L .36244 .27227 L .332 0 .594 r
F
.36718 .29565 m .36244 .27227 L .35653 .26633 L F
.36718 .29565 m .36244 .27227 L .35609 .28218 L 1 .196 .582 r
F
.35609 .28218 m .36244 .27227 L .36142 .26768 L 1 .196 .581 r
F
.36244 .27227 m .39163 .30157 L .36142 .26768 L .332 0 .591 r
F
.36142 .26768 m .38661 .27462 L .35683 .24435 L F
.36142 .26768 m .35683 .24435 L .35016 .23756 L F
.35609 .28218 m .36142 .26768 L .34963 .25578 L 1 .196 .581 r
F
.36142 .26768 m .35683 .24435 L .34963 .25578 L F
.55315 .52529 m .57197 .52652 L .55824 .51778 L .639 .371 .81 r
F
.54022 .52024 m .55315 .52529 L .55824 .51778 L .749 .447 .794 r
F
.65493 .42786 m .68562 .40718 L .66263 .39504 L 1 .449 .578 r
F
.65493 .42786 m .67683 .44123 L .68562 .40718 L F
.34963 .42239 m .37135 .41291 L .36343 .38911 L .539 .033 .629 r
F
.35868 .44313 m .37135 .41291 L .34963 .42239 L .551 .047 .643 r
F
.34058 .47572 m .35868 .44313 L .34963 .42239 L .804 .125 .619 r
F
.33128 .961 m .30469 .87369 L .32115 .96531 L .698 .046 .577 r
F
.33128 .961 m .31575 .87016 L .30469 .87369 L F
.52902 .64956 m .54077 .64664 L .53699 .64376 L .757 .472 .8 r
F
.52621 .64788 m .52902 .64956 L .53699 .64376 L .76 .474 .799 r
F
.59931 .66001 m .60116 .66792 L .6138 .67018 L .622 .351 .809 r
F
.58693 .65935 m .60116 .66792 L .59931 .66001 L .665 .394 .807 r
F
.51678 .84853 m .50355 .85543 L .51729 .85397 L .755 .676 .869 r
F
.52877 .84682 m .51729 .85397 L .53096 .85182 L .729 .65 .873 r
F
.52877 .84682 m .51678 .84853 L .51729 .85397 L F
.47606 .85608 m .45708 .86171 L .47152 .86227 L .882 .779 .846 r
F
.48959 .85615 m .47606 .85608 L .47152 .86227 L .816 .736 .86 r
F
.54049 .84464 m .53096 .85182 L .54431 .84919 L .695 .61 .879 r
F
.54049 .84464 m .52877 .84682 L .53096 .85182 L F
.54649 .65283 m .56036 .6547 L .55765 .65023 L .739 .455 .801 r
F
.54389 .64965 m .54649 .65283 L .55765 .65023 L .744 .458 .8 r
F
.51296 .24873 m .55032 .22673 L .51295 .21679 L .992 .168 .591 r
F
.47728 .25654 m .51295 .21679 L .4756 .22393 L 1 .181 .587 r
F
.47728 .25654 m .51296 .24873 L .51295 .21679 L F
.67729 .54152 m .69898 .56277 L .68822 .5249 L 1 .375 .637 r
F
.67729 .54152 m .6873 .57453 L .69898 .56277 L F
.50312 .64418 m .50293 .6351 L .49807 .63573 L .762 .48 .801 r
F
.50312 .64418 m .50635 .64377 L .50293 .6351 L F
.66894 .55034 m .67831 .5768 L .68619 .57511 L .853 .28 .695 r
F
.4179 .62657 m .41207 .6118 L .40595 .62173 L .771 .439 .783 r
F
.4179 .62657 m .42336 .61776 L .41207 .6118 L F
.57222 .65345 m .57458 .65912 L .58693 .65935 L .699 .414 .801 r
F
.56036 .6547 m .57458 .65912 L .57222 .65345 L .721 .438 .801 r
F
.45715 .63474 m .4512 .62372 L .4459 .62925 L .762 .462 .795 r
F
.52621 .64788 m .53699 .64376 L .53278 .64122 L .76 .474 .799 r
F
.52316 .64645 m .52621 .64788 L .53278 .64122 L .763 .476 .799 r
F
.50635 .64377 m .50798 .63494 L .50293 .6351 L .762 .48 .801 r
F
.50635 .64377 m .50971 .64367 L .50798 .63494 L F
.51678 .84853 m .50473 .84966 L .50355 .85543 L .755 .676 .869 r
F
.50473 .84966 m .48959 .85615 L .50355 .85543 L .78 .7 .864 r
F
.54022 .52024 m .55824 .51778 L .54367 .51135 L .749 .447 .794 r
F
.52678 .51739 m .54022 .52024 L .54367 .51135 L .844 .519 .786 r
F
.4031 .28347 m .43551 .21468 L .39818 .2539 L 1 .182 .582 r
F
.4031 .28347 m .43881 .24664 L .43551 .21468 L F
.55765 .65023 m .56036 .6547 L .57222 .65345 L .726 .438 .799 r
F
.39335 .495 m .40125 .47988 L .38405 .48452 L .516 .153 .76 r
F
.39335 .495 m .40933 .49147 L .40125 .47988 L F
.52316 .64645 m .53278 .64122 L .5282 .63906 L .763 .476 .799 r
F
.51993 .6453 m .52316 .64645 L .5282 .63906 L .764 .477 .799 r
F
.58457 .53614 m .60519 .54437 L .59269 .53343 L .443 .185 .839 r
F
.57197 .52652 m .58457 .53614 L .59269 .53343 L .493 .219 .818 r
F
.50971 .64367 m .51313 .63526 L .50798 .63494 L .763 .479 .8 r
F
.50971 .64367 m .51314 .6439 L .51313 .63526 L F
.55172 .84214 m .54431 .84919 L .55712 .84644 L .658 .561 .884 r
F
.55172 .84214 m .54049 .84464 L .54431 .84919 L F
.44214 .27858 m .4756 .22393 L .43882 .24663 L 1 .182 .583 r
F
.44214 .27858 m .47728 .25654 L .4756 .22393 L F
.40595 .62173 m .40076 .60579 L .394 .61666 L .77 .436 .783 r
F
.40595 .62173 m .41207 .6118 L .40076 .60579 L F
.51993 .6453 m .5282 .63906 L .52333 .63733 L .764 .477 .799 r
F
.51656 .64444 m .51993 .6453 L .52333 .63733 L .764 .478 .799 r
F
.51314 .6439 m .51828 .63606 L .51313 .63526 L .764 .479 .8 r
F
.51314 .6439 m .51656 .64444 L .51828 .63606 L F
.51656 .64444 m .52333 .63733 L .51828 .63606 L .764 .478 .799 r
F
.52678 .51739 m .54367 .51135 L .52852 .50815 L .844 .519 .786 r
F
.51308 .51682 m .52678 .51739 L .52852 .50815 L .899 .585 .789 r
F
.54389 .64965 m .55765 .65023 L .55419 .64589 L .744 .458 .8 r
F
.54077 .64664 m .54389 .64965 L .55419 .64589 L .751 .462 .799 r
F
.61172 .66121 m .6138 .67018 L .62648 .6732 L .568 .292 .81 r
F
.59931 .66001 m .6138 .67018 L .61172 .66121 L .622 .351 .809 r
F
.66894 .55034 m .68619 .57511 L .67625 .5428 L .853 .28 .695 r
F
.67625 .5428 m .68619 .57511 L .6873 .57453 L 1 .297 .658 r
F
.67625 .5428 m .6873 .57453 L .67728 .54153 L F
.59385 .1962 m .63304 .2473 L .63798 .2201 L .864 .109 .586 r
F
.59053 .22564 m .63304 .2473 L .59385 .1962 L .863 .111 .588 r
F
.51308 .51682 m .52852 .50815 L .51307 .50833 L .899 .585 .789 r
F
.394 .61666 m .38944 .5999 L .38204 .61129 L .766 .443 .787 r
F
.394 .61666 m .40076 .60579 L .38944 .5999 L F
.42846 .87554 m .41361 .87242 L .40463 .88339 L 1 .879 .757 r
F
.43605 .86731 m .41361 .87242 L .42846 .87554 L 1 .845 .781 r
F
.4459 .62925 m .4408 .61706 L .43464 .62359 L .759 .45 .792 r
F
.4459 .62925 m .4512 .62372 L .4408 .61706 L F
.35868 .44313 m .37923 .43426 L .37135 .41291 L .551 .047 .643 r
F
.36783 .46069 m .37923 .43426 L .35868 .44313 L .553 .064 .664 r
F
.58411 .65247 m .58693 .65935 L .59931 .66001 L .669 .381 .801 r
F
.57222 .65345 m .58693 .65935 L .58411 .65247 L .699 .414 .801 r
F
.55032 .22673 m .5872 .25451 L .59053 .22564 L .924 .138 .591 r
F
.54864 .25715 m .5872 .25451 L .55032 .22673 L .928 .144 .594 r
F
.51296 .24873 m .54864 .25715 L .55032 .22673 L .992 .168 .591 r
F
.49249 .85013 m .47606 .85608 L .48959 .85615 L .814 .726 .857 r
F
.50473 .84966 m .49249 .85013 L .48959 .85615 L .78 .7 .864 r
F
.5996 .84233 m .59671 .85095 L .60909 .8493 L .555 .391 .87 r
F
.5996 .84233 m .58848 .8457 L .59671 .85095 L F
.38404 .48452 m .39594 .47082 L .37793 .47648 L .534 .119 .725 r
F
.38404 .48452 m .40125 .47988 L .39594 .47082 L F
.38204 .61129 m .37809 .59437 L .37009 .60556 L .754 .463 .798 r
F
.38204 .61129 m .38944 .5999 L .37809 .59437 L F
.54077 .64664 m .55419 .64589 L .55003 .64179 L .751 .462 .799 r
F
.53699 .64376 m .54077 .64664 L .55003 .64179 L .759 .468 .798 r
F
.55765 .65023 m .57222 .65345 L .56885 .64775 L .726 .438 .799 r
F
.55419 .64589 m .55765 .65023 L .56885 .64775 L .736 .443 .797 r
F
.59269 .53343 m .60519 .54437 L .61464 .54477 L .355 .083 .833 r
F
.57197 .52652 m .59269 .53343 L .57865 .52101 L .493 .219 .818 r
F
.55824 .51778 m .57197 .52652 L .57865 .52101 L .616 .311 .795 r
F
.37792 .47647 m .39519 .46944 L .37706 .47525 L .549 .11 .71 r
F
.37792 .47647 m .39594 .47082 L .39519 .46944 L F
.56885 .64775 m .57222 .65345 L .58411 .65247 L .708 .414 .797 r
F
.37706 .47525 m .38718 .45318 L .36783 .46069 L .543 .087 .692 r
F
.37706 .47525 m .39518 .46943 L .38718 .45318 L F
.36783 .46069 m .38718 .45318 L .37923 .43426 L .553 .064 .664 r
F
.56227 .83935 m .55712 .84644 L .56916 .84373 L .636 .532 .885 r
F
.56227 .83935 m .55172 .84214 L .55712 .84644 L F
.37009 .60556 m .36671 .58957 L .35814 .59933 L .724 .498 .821 r
F
.37009 .60556 m .37809 .59437 L .36671 .58957 L F
.33836 .58689 m .3466 .58494 L .33725 .58606 L .154 0 .763 r
F
.33725 .58606 m .3466 .58494 L .33496 .58682 L 0 0 0 r
F
.33836 .58689 m .34768 .58499 L .3466 .58494 L .154 0 .763 r
F
.34621 .59228 m .34768 .58499 L .33836 .58689 L .462 .179 .898 r
F
.62416 .66311 m .62648 .6732 L .6392 .67732 L .504 .213 .806 r
F
.61172 .66121 m .62648 .6732 L .62416 .66311 L .568 .292 .81 r
F
.35814 .59933 m .35527 .5861 L .34621 .59229 L .645 .512 .864 r
F
.35814 .59933 m .36671 .58957 L .35527 .5861 L F
.34621 .59228 m .35527 .5861 L .34768 .58499 L .462 .179 .898 r
F
.43464 .62359 m .43039 .61021 L .42336 .61776 L .757 .438 .788 r
F
.43464 .62359 m .4408 .61706 L .43039 .61021 L F
.53699 .64376 m .55003 .64179 L .545 .63786 L .759 .468 .798 r
F
.53278 .64122 m .53699 .64376 L .545 .63786 L .766 .473 .797 r
F
.45708 .86171 m .44366 .85974 L .43605 .86731 L 1 .843 .822 r
F
.46321 .85506 m .44366 .85974 L .45708 .86171 L .942 .796 .831 r
F
.47606 .85608 m .46321 .85506 L .45708 .86171 L .882 .779 .846 r
F
.76253 .51154 m .78974 .44043 L .77294 .49397 L 0 0 0 r
F
.76253 .51154 m .7789 .46065 L .78974 .44043 L F
.51297 .28022 m .54864 .25715 L .51296 .24873 L 1 .179 .594 r
F
.47896 .28903 m .51296 .24873 L .47728 .25654 L 1 .192 .589 r
F
.47896 .28903 m .51297 .28022 L .51296 .24873 L F
.30604 .7717 m .29925 .79261 L .28663 .7905 L .642 0 .151 r
F
.31796 .78107 m .29925 .79261 L .30604 .7717 L .6 0 .058 r
F
.55824 .51778 m .57865 .52101 L .56335 .50953 L .616 .311 .795 r
F
.54367 .51135 m .55824 .51778 L .56335 .50953 L .769 .41 .774 r
F
.65963 .52038 m .68497 .48459 L .66818 .47738 L 1 .644 .586 r
F
.65963 .52038 m .67514 .51256 L .68497 .48459 L F
.59603 .65185 m .59931 .66001 L .61172 .66121 L .634 .339 .799 r
F
.58411 .65247 m .59931 .66001 L .59603 .65185 L .669 .381 .801 r
F
.71239 .68537 m .72521 .70923 L .7242 .65937 L 1 .649 .62 r
F
.55419 .64589 m .56885 .64775 L .56452 .64216 L .736 .443 .797 r
F
.55003 .64179 m .55419 .64589 L .56452 .64216 L .748 .451 .796 r
F
.53278 .64122 m .545 .63786 L .53937 .63441 L .766 .473 .797 r
F
.5282 .63906 m .53278 .64122 L .53937 .63441 L .771 .477 .796 r
F
.48063 .8498 m .46321 .85506 L .47606 .85608 L .855 .749 .848 r
F
.49249 .85013 m .48063 .8498 L .47606 .85608 L .814 .726 .857 r
F
.59053 .22564 m .62807 .27398 L .63304 .2473 L .863 .111 .588 r
F
.5872 .25451 m .62807 .27398 L .59053 .22564 L .861 .113 .59 r
F
.40805 .31296 m .43881 .24664 L .4031 .28347 L 1 .18 .582 r
F
.40805 .31296 m .44213 .27859 L .43881 .24664 L F
.54367 .51135 m .56335 .50953 L .54712 .50127 L .769 .41 .774 r
F
.52852 .50815 m .54367 .51135 L .54712 .50127 L .903 .501 .762 r
F
.43605 .86731 m .42257 .86329 L .41361 .87242 L 1 .845 .781 r
F
.44366 .85974 m .42257 .86329 L .43605 .86731 L 1 .808 .802 r
F
.42336 .61776 m .41996 .60319 L .41207 .6118 L .758 .43 .785 r
F
.42336 .61776 m .43039 .61021 L .41996 .60319 L F
.5282 .63906 m .53937 .63441 L .53325 .63153 L .771 .477 .796 r
F
.52333 .63733 m .5282 .63906 L .53325 .63153 L .773 .48 .797 r
F
.4512 .62372 m .44834 .61157 L .4408 .61706 L .749 .446 .794 r
F
.44547 .31068 m .47728 .25654 L .44214 .27858 L 1 .186 .584 r
F
.44547 .31068 m .47896 .28903 L .47728 .25654 L F
.51627 .84294 m .50473 .84966 L .51678 .84853 L .755 .672 .867 r
F
.52658 .84156 m .51678 .84853 L .52877 .84682 L .732 .65 .871 r
F
.52658 .84156 m .51627 .84294 L .51678 .84853 L F
.58007 .64544 m .58411 .65247 L .59603 .65185 L .685 .382 .795 r
F
.56885 .64775 m .58411 .65247 L .58007 .64544 L .708 .414 .797 r
F
.56452 .64216 m .56885 .64775 L .58007 .64544 L .724 .421 .794 r
F
.62416 .66311 m .6392 .67732 L .63665 .66585 L .504 .213 .806 r
F
.53664 .83972 m .52877 .84682 L .54049 .84464 L .71 .626 .874 r
F
.53664 .83972 m .52658 .84156 L .52877 .84682 L F
.54864 .25715 m .58384 .28272 L .5872 .25451 L .928 .144 .594 r
F
.54696 .28692 m .58384 .28272 L .54864 .25715 L .934 .152 .597 r
F
.51297 .28022 m .54696 .28692 L .54864 .25715 L 1 .179 .594 r
F
.52333 .63733 m .53325 .63153 L .52675 .62925 L .773 .48 .797 r
F
.51828 .63606 m .52333 .63733 L .52675 .62925 L .772 .482 .798 r
F
.52852 .50815 m .54712 .50127 L .53025 .49763 L .903 .501 .762 r
F
.51307 .50833 m .52852 .50815 L .53025 .49763 L .995 .594 .764 r
F
.51313 .63526 m .52 .62761 L .51312 .6266 L .769 .483 .799 r
F
.51313 .63526 m .51828 .63606 L .52 .62761 L F
.51828 .63606 m .52675 .62925 L .52 .62761 L .772 .482 .798 r
F
.51627 .84294 m .50591 .84378 L .50473 .84966 L .755 .672 .867 r
F
.50591 .84378 m .49249 .85013 L .50473 .84966 L .778 .692 .862 r
F
.59269 .53343 m .61464 .54477 L .60087 .53181 L .355 .083 .833 r
F
.57865 .52101 m .59269 .53343 L .60087 .53181 L .419 .12 .805 r
F
.57196 .83608 m .56916 .84373 L .58023 .84075 L .65 .546 .878 r
F
.57196 .83608 m .56227 .83935 L .56916 .84373 L F
.5901 .83673 m .58848 .8457 L .5996 .84233 L .64 .506 .864 r
F
.55003 .64179 m .56452 .64216 L .55932 .63686 L .748 .451 .796 r
F
.545 .63786 m .55003 .64179 L .55932 .63686 L .763 .461 .794 r
F
.39562 .89652 m .36981 .9092 L .38658 .91172 L 1 .637 .641 r
F
.39562 .89652 m .38023 .88777 L .36981 .9092 L F
.40463 .88339 m .38023 .88777 L .39562 .89652 L 1 .663 .687 r
F
.38657 .91172 m .36283 .92738 L .38059 .92253 L 1 .657 .614 r
F
.38657 .91172 m .36981 .90921 L .36283 .92738 L F
.60798 .65166 m .61172 .66121 L .62416 .6631 L .594 .289 .795 r
F
.59603 .65185 m .61172 .66121 L .60798 .65166 L .634 .339 .799 r
F
.41207 .6118 m .40951 .59613 L .40076 .60579 L .762 .43 .783 r
F
.41207 .6118 m .41996 .60319 L .40951 .59613 L F
.51307 .50833 m .53025 .49763 L .51306 .49902 L .995 .594 .764 r
F
.54629 .83747 m .54049 .84464 L .55172 .84214 L .692 .604 .876 r
F
.54629 .83747 m .53664 .83972 L .54049 .84464 L F
.38059 .92253 m .36183 .93013 L .37974 .92409 L 1 .69 .605 r
F
.38059 .92253 m .36283 .92738 L .36183 .93013 L F
.64732 .46094 m .67683 .44124 L .65493 .42787 L 1 .406 .57 r
F
.64732 .46094 m .66818 .47738 L .67683 .44124 L F
.40463 .88339 m .39049 .87317 L .38023 .88777 L 1 .663 .687 r
F
.41361 .87242 m .39049 .87317 L .40463 .88339 L 1 .69 .731 r
F
.61974 .8425 m .61861 .85851 L .63034 .85093 L .641 .287 .772 r
F
.61974 .8425 m .60909 .8493 L .61861 .85851 L F
.4954 .84402 m .48063 .8498 L .49249 .85013 L .803 .71 .857 r
F
.50591 .84378 m .4954 .84402 L .49249 .85013 L .778 .692 .862 r
F
.4408 .61706 m .43899 .60385 L .43039 .61021 L .743 .429 .79 r
F
.4408 .61706 m .44834 .61157 L .43899 .60385 L F
.545 .63786 m .55932 .63686 L .55302 .63179 L .763 .461 .794 r
F
.53937 .63441 m .545 .63786 L .55302 .63179 L .776 .472 .793 r
F
.57865 .52101 m .60087 .53181 L .58535 .51547 L .419 .12 .805 r
F
.56335 .50953 m .57865 .52101 L .58535 .51547 L .587 .242 .776 r
F
.51298 .31118 m .54696 .28692 L .51297 .28022 L 1 .193 .598 r
F
.48066 .32148 m .51297 .28022 L .47896 .28903 L 1 .207 .591 r
F
.48066 .32148 m .51298 .31118 L .51297 .28022 L F
.56452 .64216 m .58007 .64544 L .57489 .63847 L .724 .421 .794 r
F
.55932 .63686 m .56452 .64216 L .57489 .63847 L .744 .434 .791 r
F
.40076 .60579 m .39904 .58925 L .38944 .5999 L .772 .444 .785 r
F
.40076 .60579 m .40951 .59613 L .39904 .58925 L F
.46321 .85506 m .45128 .85276 L .44366 .85974 L .942 .796 .831 r
F
.46937 .84857 m .45128 .85276 L .46321 .85506 L .887 .757 .839 r
F
.48063 .8498 m .46937 .84857 L .46321 .85506 L .855 .749 .848 r
F
.5872 .25451 m .62308 .30006 L .62807 .27398 L .861 .113 .59 r
F
.58384 .28272 m .62308 .30006 L .5872 .25451 L .859 .116 .593 r
F
.59133 .64336 m .59603 .65185 L .60798 .65166 L .659 .345 .791 r
F
.58007 .64544 m .59603 .65185 L .59133 .64336 L .685 .382 .795 r
F
.44366 .85974 m .43154 .85554 L .42257 .86329 L 1 .808 .802 r
F
.45128 .85276 m .43154 .85554 L .44366 .85974 L .96 .772 .82 r
F
.55534 .8348 m .55172 .84214 L .56227 .83935 L .686 .595 .876 r
F
.55534 .8348 m .54629 .83747 L .55172 .84214 L F
.56335 .50953 m .58535 .51547 L .56847 .50034 L .587 .242 .776 r
F
.54712 .50127 m .56335 .50953 L .56847 .50034 L .784 .361 .75 r
F
.60087 .53181 m .61464 .54477 L .6242 .54746 L .175 .002 .804 r
F
.57489 .63847 m .58007 .64544 L .59133 .64336 L .708 .393 .79 r
F
.41361 .87242 m .40067 .86286 L .39049 .87317 L 1 .69 .731 r
F
.42257 .86329 m .40067 .86286 L .41361 .87242 L 1 .705 .768 r
F
.54696 .28692 m .58047 .31016 L .58384 .28272 L .934 .152 .597 r
F
.54527 .31591 m .58047 .31016 L .54696 .28692 L .942 .161 .602 r
F
.51298 .31118 m .54527 .31591 L .54696 .28692 L 1 .193 .598 r
F
.53937 .63441 m .55302 .63179 L .54598 .62739 L .776 .472 .793 r
F
.53325 .63153 m .53937 .63441 L .54598 .62739 L .785 .48 .793 r
F
.60768 1.2919 m .56868 1.23383 L .61175 1.3159 L .203 0 .587 r
F
.60768 1.2919 m .56644 1.21505 L .56868 1.23383 L F
.54712 .50127 m .56847 .50034 L .55057 .48969 L .784 .361 .75 r
F
.53025 .49763 m .54712 .50127 L .55057 .48969 L .957 .467 .736 r
F
.61998 .65192 m .62416 .6631 L .63665 .66584 L .553 .232 .788 r
F
.60798 .65166 m .62416 .6631 L .61998 .65192 L .594 .289 .795 r
F
.31796 .78107 m .31188 .79528 L .29925 .79261 L .6 0 .058 r
F
.32992 .79093 m .31188 .79528 L .31796 .78107 L .528 0 0 r
F
.60916 .83602 m .60909 .8493 L .61974 .8425 L .692 .423 .807 r
F
.60916 .83602 m .5996 .84233 L .60909 .8493 L F
.41301 .34248 m .44213 .27859 L .40805 .31296 L 1 .176 .583 r
F
.41301 .34248 m .44547 .31069 L .44213 .27859 L F
.36283 .92738 m .3496 .85935 L .34839 .8669 L 1 .293 .523 r
F
.36981 .90921 m .34961 .85935 L .36283 .92738 L .732 .084 .609 r
F
.36981 .90921 m .35685 .857 L .34961 .85935 L F
.38944 .5999 m .38854 .58287 L .37809 .59436 L .791 .484 .792 r
F
.38944 .5999 m .39904 .58925 L .38854 .58287 L F
.48521 .84354 m .46937 .84857 L .48063 .8498 L .827 .723 .851 r
F
.4954 .84402 m .48521 .84354 L .48063 .8498 L .803 .71 .857 r
F
.43039 .61021 m .42963 .59583 L .41996 .60319 L .74 .412 .785 r
F
.43039 .61021 m .43899 .60385 L .42963 .59583 L F
.44881 .34321 m .47896 .28903 L .44547 .31068 L 1 .193 .584 r
F
.44881 .34321 m .48066 .32148 L .47896 .28903 L F
.53325 .63153 m .54598 .62739 L .53832 .62377 L .785 .48 .793 r
F
.52675 .62925 m .53325 .63153 L .53832 .62377 L .788 .487 .794 r
F
.55932 .63686 m .57489 .63847 L .56864 .63182 L .744 .434 .791 r
F
.55302 .63179 m .55932 .63686 L .56864 .63182 L .768 .451 .789 r
F
.53025 .49763 m .55057 .48969 L .53199 .48542 L .957 .467 .736 r
F
.51306 .49902 m .53025 .49763 L .53199 .48542 L 1 .583 .736 r
F
.60363 1.26857 m .56644 1.21505 L .60768 1.2919 L .193 0 .591 r
F
.60363 1.26857 m .5642 1.19709 L .56644 1.21505 L F
.65201 .60814 m .67514 .51256 L .65963 .52038 L .07 0 .237 r
F
.58058 .83201 m .57196 .83608 L .58023 .84075 L .694 .575 .861 r
F
.52675 .62925 m .53832 .62377 L .53018 .62101 L .788 .487 .794 r
F
.52 .62761 m .52675 .62925 L .53018 .62101 L .785 .49 .796 r
F
.51312 .6266 m .52173 .61909 L .51311 .61796 L .778 .491 .799 r
F
.51312 .6266 m .52 .62761 L .52173 .61909 L F
.42257 .86329 m .41082 .855 L .40067 .86286 L 1 .705 .768 r
F
.43154 .85554 m .41082 .855 L .42257 .86329 L .988 .709 .796 r
F
.52 .62761 m .53018 .62101 L .52173 .61909 L .785 .49 .796 r
F
.32123 .35646 m .34963 .25578 L .31323 .33456 L 1 .22 .582 r
F
.32123 .35646 m .35609 .28218 L .34963 .25578 L F
.60262 .64157 m .60798 .65166 L .61998 .65192 L .635 .308 .785 r
F
.59133 .64336 m .60798 .65166 L .60262 .64157 L .659 .345 .791 r
F
.58384 .28272 m .61807 .32545 L .62308 .30006 L .859 .116 .593 r
F
.58047 .31016 m .61807 .32545 L .58384 .28272 L .855 .119 .597 r
F
.38023 .88777 m .35685 .857 L .36981 .9092 L .772 .157 .653 r
F
.38023 .88777 m .36786 .85347 L .35685 .857 L F
.56365 .83164 m .56227 .83935 L .57196 .83608 L .699 .603 .87 r
F
.56365 .83164 m .55534 .8348 L .56227 .83935 L F
.59959 1.246 m .5642 1.19709 L .60363 1.26857 L .18 0 .596 r
F
.59959 1.246 m .56196 1.18014 L .5642 1.19709 L F
.51576 .83718 m .50591 .84378 L .51627 .84294 L .755 .668 .865 r
F
.52437 .83608 m .51627 .84294 L .52658 .84156 L .739 .653 .868 r
F
.52437 .83608 m .51576 .83718 L .51627 .84294 L F
.57489 .63847 m .59133 .64336 L .58528 .63485 L .708 .393 .79 r
F
.56864 .63182 m .57489 .63847 L .58528 .63485 L .738 .411 .785 r
F
.51306 .49902 m .53199 .48542 L .51305 .4884 L 1 .583 .736 r
F
.37809 .59436 m .37799 .57752 L .36671 .58957 L .82 .561 .806 r
F
.37809 .59436 m .38854 .58287 L .37799 .57752 L F
.53277 .83453 m .52658 .84156 L .53664 .83972 L .726 .64 .87 r
F
.53277 .83453 m .52437 .83608 L .52658 .84156 L F
.44834 .61157 m .44901 .59898 L .43899 .60385 L .726 .424 .795 r
F
.51299 .34146 m .54527 .31591 L .51298 .31118 L 1 .213 .602 r
F
.48235 .35397 m .51298 .31118 L .48066 .32148 L 1 .229 .594 r
F
.48235 .35397 m .51299 .34146 L .51298 .31118 L F
.58528 .63485 m .59133 .64336 L .60262 .64157 L .691 .36 .784 r
F
.51576 .83718 m .50711 .83779 L .50591 .84378 L .755 .668 .865 r
F
.5071 .83779 m .4954 .84402 L .50591 .84378 L .772 .681 .861 r
F
.55302 .63179 m .56864 .63182 L .56108 .62547 L .768 .451 .789 r
F
.54598 .62739 m .55302 .63179 L .56108 .62547 L .791 .47 .787 r
F
.59859 .83096 m .5996 .84233 L .60916 .83602 L .728 .524 .828 r
F
.59859 .83096 m .5901 .83673 L .5996 .84233 L F
.41996 .60319 m .42025 .58749 L .40951 .59613 L .746 .4 .778 r
F
.41996 .60319 m .42963 .59583 L .42025 .58749 L F
.54527 .31591 m .57708 .3367 L .58047 .31016 L .942 .161 .602 r
F
.54357 .34395 m .57708 .3367 L .54527 .31591 L .951 .174 .607 r
F
.51299 .34146 m .54357 .34395 L .54527 .31591 L 1 .213 .602 r
F
.60087 .53181 m .6242 .54746 L .60911 .5319 L .175 .002 .804 r
F
.58535 .51547 m .60087 .53181 L .60911 .5319 L .318 .03 .78 r
F
.36283 .92738 m .34839 .8669 L .36183 .93013 L 1 .293 .523 r
F
.61998 .65192 m .63665 .66584 L .63201 .65253 L .553 .232 .788 r
F
.45128 .85276 m .44051 .84879 L .43154 .85554 L .96 .772 .82 r
F
.45893 .84626 m .44051 .84879 L .45128 .85276 L .89 .739 .833 r
F
.46937 .84857 m .45893 .84626 L .45128 .85276 L .887 .757 .839 r
F
.54083 .83257 m .53664 .83972 L .54629 .83747 L .718 .63 .871 r
F
.54083 .83257 m .53277 .83453 L .53664 .83972 L F
.82132 .80228 m .82881 .73615 L .83471 .80529 L .748 0 .318 r
F
.82132 .80228 m .81603 .73739 L .82881 .73615 L F
.72792 .76631 m .72593 .73013 L .73874 .73405 L .839 0 .271 r
F
.71462 .75369 m .72593 .73013 L .72792 .76631 L .853 0 .235 r
F
.47555 .84227 m .45893 .84626 L .46937 .84857 L .842 .725 .846 r
F
.48521 .84354 m .47555 .84227 L .46937 .84857 L .827 .723 .851 r
F
.56847 .50034 m .59208 .50979 L .57359 .48992 L .559 .174 .75 r
F
.56847 .50034 m .58535 .51547 L .59208 .50979 L F
.55057 .48969 m .56847 .50034 L .57359 .48992 L .795 .305 .724 r
F
.55057 .48969 m .57359 .48992 L .55402 .47633 L F
.53199 .48542 m .55057 .48969 L .55402 .47633 L .995 .421 .71 r
F
.58535 .51547 m .60911 .5319 L .59208 .50979 L .318 .03 .78 r
F
.59556 1.22424 m .56196 1.18014 L .59959 1.246 L .162 0 .603 r
F
.59556 1.22424 m .55974 1.16444 L .56196 1.18014 L F
.49832 .83786 m .48521 .84354 L .4954 .84402 L .788 .693 .858 r
F
.5071 .83779 m .49832 .83786 L .4954 .84402 L .772 .681 .861 r
F
.80795 .79906 m .81603 .73739 L .82132 .80228 L .752 0 .314 r
F
.80795 .79906 m .80322 .7383 L .81603 .73739 L F
.36671 .58957 m .36738 .57388 L .35527 .5861 L .854 .689 .832 r
F
.36671 .58957 m .37799 .57752 L .36738 .57388 L F
.54598 .62739 m .56108 .62547 L .55262 .62004 L .791 .47 .787 r
F
.53832 .62377 m .54598 .62739 L .55262 .62004 L .808 .486 .787 r
F
.39049 .87317 m .36786 .85347 L .38023 .88777 L .808 .262 .701 r
F
.39049 .87317 m .3789 .84993 L .36786 .85347 L F
.40067 .86286 m .3789 .84993 L .39049 .87317 L .827 .379 .743 r
F
.43154 .85554 m .42096 .84857 L .41082 .855 L .988 .709 .796 r
F
.44051 .84879 m .42096 .84857 L .43154 .85554 L .91 .704 .818 r
F
.53199 .48542 m .55402 .47633 L .53373 .47108 L .995 .421 .71 r
F
.51305 .4884 m .53199 .48542 L .53373 .47108 L 1 .548 .705 r
F
.37889 .84993 m .35829 .81826 L .36786 .85346 L .359 .014 .707 r
F
.58047 .31016 m .61303 .35 L .61807 .32545 L .855 .119 .597 r
F
.57708 .3367 m .61303 .35 L .58047 .31016 L .851 .123 .602 r
F
.56864 .63182 m .58528 .63485 L .57799 .62664 L .738 .411 .785 r
F
.56108 .62547 m .56864 .63182 L .57799 .62664 L .773 .436 .782 r
F
.72792 .76631 m .73874 .73405 L .74114 .77514 L .839 0 .271 r
F
.74115 .77515 m .73875 .73405 L .75171 .73664 L .815 0 .286 r
F
.36986 .8258 m .36328 .81287 L .35108 .80651 L .264 .018 .803 r
F
.36328 .81287 m .35974 .81104 L .35108 .80651 L .206 .004 .855 r
F
.35829 .81826 m .35108 .80651 L .3429 .80223 L .014 0 .75 r
F
.36986 .8258 m .35108 .80651 L .35829 .81826 L .264 .018 .803 r
F
.3429 .80223 m .35108 .80651 L .33898 .79813 L .014 0 .75 r
F
.35108 .80651 m .33403 .80096 L .33898 .79813 L 0 0 .683 r
F
.33731 .80203 m .34669 .80434 L .33403 .80096 L F
.35108 .80651 m .34669 .80434 L .33731 .80203 L F
.35974 .81104 m .34669 .80434 L .35108 .80651 L .206 .004 .855 r
F
.36328 .81287 m .35938 .80741 L .34669 .80434 L F
.35938 .80741 m .35658 .80677 L .34669 .80434 L .278 0 .835 r
F
.34669 .80434 m .33249 .80485 L .33403 .80096 L .049 0 .648 r
F
.34669 .80434 m .34545 .80422 L .33249 .80485 L F
.35658 .80677 m .34545 .80422 L .34669 .80434 L .278 0 .835 r
F
.37889 .84993 m .36986 .8258 L .35829 .81826 L .359 .014 .707 r
F
.41799 .37224 m .44547 .31069 L .41301 .34248 L 1 .168 .582 r
F
.41799 .37224 m .44881 .34321 L .44547 .31069 L F
.79459 .79555 m .80322 .7383 L .80795 .79906 L .757 0 .31 r
F
.79459 .79555 m .79038 .7388 L .80322 .7383 L F
.40951 .59613 m .41085 .57892 L .39904 .58925 L .764 .396 .771 r
F
.40951 .59613 m .42025 .58749 L .41085 .57892 L F
.54839 .83018 m .54629 .83747 L .55534 .8348 L .719 .628 .869 r
F
.54839 .83018 m .54083 .83257 L .54629 .83747 L F
.61395 .64007 m .61998 .65192 L .63201 .65253 L .62 .278 .778 r
F
.60262 .64157 m .61998 .65192 L .61395 .64007 L .635 .308 .785 r
F
.32926 .37782 m .35609 .28218 L .32123 .35646 L 1 .221 .584 r
F
.32926 .37782 m .36258 .30824 L .35609 .28218 L F
.45216 .37665 m .48066 .32148 L .44881 .34321 L 1 .203 .584 r
F
.45216 .37665 m .48235 .35397 L .48066 .32148 L F
.43899 .60385 m .44089 .59025 L .42963 .59583 L .716 .396 .788 r
F
.43899 .60385 m .44901 .59898 L .44089 .59025 L F
.78123 .79164 m .79038 .7388 L .79459 .79555 L .765 0 .305 r
F
.78123 .79164 m .77752 .7388 L .79038 .7388 L F
.40067 .86286 m .38995 .84639 L .3789 .84993 L .827 .379 .743 r
F
.41082 .855 m .38995 .84639 L .40067 .86286 L .829 .481 .778 r
F
.75452 .78183 m .75171 .73664 L .76463 .73814 L .793 0 .295 r
F
.74115 .77515 m .75171 .73664 L .75452 .78183 L .815 0 .286 r
F
.53832 .62377 m .55262 .62004 L .54341 .61571 L .808 .486 .787 r
F
.53018 .62101 m .53832 .62377 L .54341 .61571 L .814 .499 .789 r
F
.54357 .34395 m .57367 .36217 L .57708 .3367 L .951 .174 .607 r
F
.54188 .37045 m .57367 .36218 L .54357 .34395 L .964 .191 .614 r
F
.513 .3704 m .54357 .34395 L .51299 .34147 L 1 .24 .608 r
F
.513 .3704 m .54188 .37045 L .54357 .34395 L F
.32992 .79093 m .32451 .79841 L .31188 .79528 L .528 0 0 r
F
.33104 .79185 m .32451 .79841 L .32992 .79093 L .525 0 0 r
F
.57104 .82787 m .57196 .83608 L .58058 .83201 L .726 .616 .86 r
F
.57104 .82787 m .56365 .83164 L .57196 .83608 L F
.76788 .78716 m .77752 .7388 L .78123 .79164 L .777 0 .3 r
F
.76788 .78716 m .76463 .73814 L .77752 .7388 L F
.75452 .78183 m .76463 .73814 L .76788 .78716 L .793 0 .295 r
F
.58528 .63485 m .60262 .64157 L .59571 .63133 L .691 .36 .784 r
F
.57799 .62664 m .58528 .63485 L .59571 .63133 L .728 .382 .778 r
F
.68891 .78293 m .68309 .81876 L .69097 .8187 L 1 .487 .659 r
F
.48982 .83733 m .47555 .84227 L .48521 .84354 L .802 .7 .854 r
F
.49832 .83786 m .48982 .83733 L .48521 .84354 L .788 .693 .858 r
F
.59154 1.20337 m .55974 1.16444 L .59556 1.22424 L .141 0 .613 r
F
.59154 1.20337 m .55751 1.15027 L .55974 1.16444 L F
.59571 .63133 m .60262 .64157 L .61395 .64007 L .673 .326 .777 r
F
.48404 .38609 m .51299 .34147 L .48235 .35398 L 1 .264 .597 r
F
.48404 .38609 m .513 .3704 L .51299 .34147 L F
.33104 .79185 m .32569 .79872 L .32451 .79841 L .525 0 0 r
F
.33897 .79813 m .32569 .79873 L .33104 .79185 L .413 0 0 r
F
.53018 .62101 m .54341 .61571 L .53363 .61256 L .814 .499 .789 r
F
.52173 .61909 m .53018 .62101 L .53363 .61256 L .807 .506 .794 r
F
.63967 .49448 m .66818 .47738 L .64732 .46094 L 1 .319 .554 r
F
.63967 .49448 m .65962 .52038 L .66818 .47738 L F
.59537 .30188 m .63828 .23364 L .5988 .27587 L 1 .598 .591 r
F
.59537 .30188 m .63336 .26252 L .63828 .23364 L F
.55402 .47633 m .57872 .47799 L .55747 .461 L .803 .253 .698 r
F
.55402 .47633 m .57359 .48992 L .57872 .47799 L F
.53373 .47108 m .55402 .47633 L .55747 .461 L 1 .368 .685 r
F
.51305 .4884 m .53373 .47108 L .51304 .47572 L 1 .548 .705 r
F
.51311 .61796 m .52346 .61052 L .5131 .60942 L .791 .507 .799 r
F
.51311 .61796 m .52173 .61909 L .52346 .61052 L F
.52173 .61909 m .53363 .61256 L .52346 .61052 L .807 .506 .794 r
F
.56108 .62547 m .57799 .62664 L .56916 .61881 L .773 .436 .782 r
F
.55262 .62004 m .56108 .62547 L .56916 .61881 L .81 .466 .78 r
F
.35527 .5861 m .36033 .57286 L .34769 .58499 L .845 .772 .859 r
F
.35527 .5861 m .36738 .57388 L .36033 .57286 L F
.57708 .3367 m .60796 .37355 L .61303 .35 L .851 .123 .602 r
F
.57367 .36217 m .60796 .37355 L .57708 .3367 L .846 .128 .608 r
F
.45893 .84626 m .4495 .84271 L .44051 .84879 L .89 .739 .833 r
F
.46659 .84014 m .4495 .84271 L .45893 .84626 L .84 .712 .843 r
F
.47555 .84227 m .46659 .84014 L .45893 .84626 L .842 .725 .846 r
F
.39904 .58925 m .40144 .57024 L .38854 .58287 L .801 .408 .763 r
F
.39904 .58925 m .41085 .57892 L .40144 .57024 L F
.38995 .84639 m .36986 .8258 L .37889 .84993 L .481 .128 .763 r
F
.55532 .82736 m .55534 .8348 L .56365 .83164 L .728 .632 .865 r
F
.55532 .82736 m .54839 .83018 L .55534 .8348 L F
.41082 .855 m .40103 .84285 L .38995 .84639 L .829 .481 .778 r
F
.42096 .84857 m .40103 .84285 L .41082 .855 L .82 .556 .805 r
F
.53373 .47108 m .55747 .461 L .53546 .45429 L 1 .368 .685 r
F
.51304 .47572 m .53373 .47108 L .53546 .45429 L 1 .496 .677 r
F
.67662 .7894 m .68309 .81876 L .6889 .78293 L 1 .535 .68 r
F
.67662 .7894 m .67111 .81859 L .68309 .81876 L F
.44051 .84879 m .43111 .84299 L .42096 .84857 L .91 .704 .818 r
F
.4495 .84271 m .43111 .84299 L .44051 .84879 L .854 .694 .833 r
F
.54188 .37045 m .57029 .38605 L .57367 .36218 L .964 .191 .614 r
F
.54018 .39552 m .57029 .38605 L .54188 .37045 L .979 .214 .623 r
F
.51301 .39795 m .54188 .37045 L .513 .3704 L 1 .278 .616 r
F
.51301 .39795 m .54018 .39552 L .54188 .37045 L F
.42963 .59583 m .43276 .58086 L .42025 .58749 L .713 .363 .776 r
F
.42963 .59583 m .44089 .59025 L .43276 .58086 L F
.33732 .39858 m .36258 .30824 L .32926 .37782 L 1 .222 .586 r
F
.33732 .39858 m .3691 .33396 L .36258 .30824 L F
.51525 .83127 m .50711 .83779 L .51576 .83718 L .755 .663 .863 r
F
.52215 .83042 m .51576 .83718 L .52437 .83608 L .745 .656 .865 r
F
.52215 .83042 m .51525 .83127 L .51576 .83718 L F
.62531 .6388 m .63201 .65253 L .64407 .65313 L .629 .269 .77 r
F
.61395 .64007 m .63201 .65253 L .62531 .6388 L .62 .278 .778 r
F
.48175 .83615 m .46659 .84014 L .47555 .84227 L .809 .7 .851 r
F
.48982 .83733 m .48175 .83615 L .47555 .84227 L .802 .7 .854 r
F
.52889 .82917 m .52437 .83608 L .53277 .83453 L .739 .649 .866 r
F
.52889 .82917 m .52215 .83042 L .52437 .83608 L F
.57799 .62664 m .59571 .63133 L .58737 .62133 L .728 .382 .778 r
F
.56916 .61881 m .57799 .62664 L .58737 .62133 L .776 .414 .773 r
F
.58753 1.18342 m .55751 1.15027 L .59154 1.20337 L .12 0 .63 r
F
.58753 1.18342 m .5553 1.13785 L .55751 1.15027 L F
.51525 .83127 m .5083 .8317 L .50711 .83779 L .755 .663 .863 r
F
.5083 .8317 m .49832 .83786 L .5071 .83779 L .765 .672 .861 r
F
.55262 .62004 m .56916 .61881 L .55928 .61222 L .81 .466 .78 r
F
.54341 .61571 m .55262 .62004 L .55928 .61222 L .839 .494 .779 r
F
.57367 .36217 m .60287 .39591 L .60796 .37355 L .846 .128 .608 r
F
.57029 .38605 m .60287 .39591 L .57367 .36218 L .84 .135 .615 r
F
.55747 .461 m .58383 .46428 L .56091 .44362 L .81 .21 .673 r
F
.55747 .461 m .57872 .47799 L .58383 .46428 L F
.53546 .45429 m .55747 .461 L .56091 .44362 L 1 .317 .664 r
F
.48572 .41798 m .513 .3704 L .48404 .38609 L 1 .321 .601 r
F
.48572 .41798 m .51301 .39795 L .513 .3704 L F
.34768 .58499 m .35932 .57282 L .3466 .58494 L .8 .72 .87 r
F
.34768 .58499 m .36033 .57286 L .35932 .57282 L F
.53535 .82754 m .53277 .83453 L .54083 .83257 L .736 .646 .866 r
F
.53535 .82754 m .52889 .82917 L .53277 .83453 L F
.53546 .45429 m .56091 .44362 L .53718 .43497 L 1 .317 .664 r
F
.51303 .46 m .53546 .45429 L .53718 .43497 L 1 .435 .654 r
F
.51304 .47572 m .53546 .45429 L .51303 .46 L 1 .496 .677 r
F
.54018 .39552 m .5669 .40846 L .57029 .38605 L .979 .214 .623 r
F
.53848 .41881 m .5669 .40846 L .54018 .39552 L .995 .244 .635 r
F
.51302 .42337 m .54018 .39552 L .51301 .39795 L 1 .327 .626 r
F
.51302 .42337 m .53848 .41881 L .54018 .39552 L F
.59571 .63133 m .61395 .64007 L .60617 .628 L .673 .326 .777 r
F
.58737 .62133 m .59571 .63133 L .60617 .628 L .712 .345 .77 r
F
.60617 .628 m .61395 .64007 L .62531 .6388 L .66 .298 .77 r
F
.3466 .58494 m .34851 .57442 L .33496 .58682 L .754 .529 .857 r
F
.3466 .58494 m .35932 .57282 L .34851 .57442 L F
.50126 .83168 m .48982 .83733 L .49832 .83786 L .775 .678 .859 r
F
.5083 .8317 m .50126 .83168 L .49832 .83786 L .765 .672 .861 r
F
.38854 .58287 m .392 .56169 L .37799 .57752 L .862 .438 .754 r
F
.38854 .58287 m .40144 .57024 L .392 .56169 L F
.5774 .82341 m .58058 .83201 L .588 .82686 L .758 .627 .849 r
F
.5774 .82341 m .57104 .82787 L .58058 .83201 L F
.42297 .40253 m .44881 .34321 L .41799 .37224 L .996 .155 .581 r
F
.42297 .40253 m .45216 .37665 L .44881 .34321 L F
.42096 .84857 m .41214 .83929 L .40103 .84285 L .82 .556 .805 r
F
.43111 .84299 m .41214 .83929 L .42096 .84857 L .804 .604 .824 r
F
.33897 .79813 m .33403 .80096 L .32569 .79873 L .413 0 0 r
F
.45546 .41145 m .48235 .35398 L .45216 .37665 L 1 .222 .583 r
F
.38995 .84639 m .38157 .8291 L .36986 .8258 L .481 .128 .763 r
F
.40103 .84284 m .38157 .8291 L .38995 .84639 L .584 .286 .799 r
F
.66427 .79482 m .67111 .81859 L .67662 .7894 L 1 .588 .706 r
F
.53848 .41881 m .56349 .42921 L .5669 .40846 L .995 .244 .635 r
F
.53832 .42089 m .56349 .42922 L .53848 .41882 L .988 .254 .642 r
F
.51302 .4256 m .53848 .41882 L .51302 .42337 L 1 .349 .633 r
F
.51302 .4256 m .53832 .42089 L .53848 .41882 L F
.57029 .38605 m .59783 .41654 L .60287 .39591 L .84 .135 .615 r
F
.5669 .40846 m .59783 .41654 L .57029 .38605 L .832 .145 .625 r
F
.51303 .46 m .53718 .43497 L .51302 .44052 L 1 .435 .654 r
F
.53719 .43496 m .56317 .43107 L .53832 .4209 L 1 .275 .648 r
F
.53719 .43496 m .56091 .44362 L .56317 .43107 L F
.51302 .44051 m .53719 .43496 L .53832 .4209 L 1 .379 .639 r
F
.53832 .42089 m .56317 .43106 L .56349 .42922 L .988 .254 .642 r
F
.51302 .44051 m .53832 .4209 L .51302 .42561 L 1 .379 .639 r
F
.23581 .67415 m .24901 .54891 L .22387 .66653 L 1 .277 .575 r
F
.24357 .5039 m .24901 .54891 L .2325 .48543 L .996 0 .124 r
F
.24901 .54891 m .24846 .54811 L .2325 .48543 L F
.24901 .54891 m .24975 .5419 L .24846 .54811 L 1 .277 .575 r
F
.24901 .54891 m .24846 .54811 L .22387 .66653 L F
.24901 .54891 m .24932 .5515 L .24846 .54811 L .996 0 .124 r
F
.56148 .82409 m .56365 .83164 L .57104 .82787 L .743 .639 .86 r
F
.56148 .82409 m .55532 .82736 L .56365 .83164 L F
.54341 .61571 m .55928 .61222 L .54852 .60719 L .839 .494 .779 r
F
.53363 .61256 m .54341 .61571 L .54852 .60719 L .851 .516 .783 r
F
.56091 .44362 m .5872 .45417 L .56317 .43107 L .809 .178 .654 r
F
.56091 .44362 m .58383 .46428 L .5872 .45417 L F
.59193 .32748 m .63336 .26252 L .59537 .30188 L 1 .6 .593 r
F
.59193 .32748 m .62842 .29109 L .63336 .26252 L F
.5414 .82555 m .54083 .83257 L .54839 .83018 L .738 .645 .865 r
F
.5414 .82555 m .53535 .82754 L .54083 .83257 L F
.42025 .58749 m .42463 .57057 L .41085 .57892 L .724 .33 .759 r
F
.42025 .58749 m .43276 .58086 L .42463 .57057 L F
.38157 .8291 m .36328 .81287 L .36986 .8258 L .402 .119 .823 r
F
.56317 .43106 m .58768 .45267 L .56349 .42922 L .803 .161 .646 r
F
.56317 .43106 m .5872 .45417 L .58768 .45267 L F
.56349 .42921 m .59276 .43553 L .5669 .40846 L .824 .161 .639 r
F
.56349 .42921 m .58768 .45266 L .59276 .43553 L F
.5669 .40846 m .59276 .43553 L .59783 .41654 L .832 .145 .625 r
F
.56916 .61881 m .58737 .62133 L .57726 .61172 L .776 .414 .773 r
F
.55928 .61222 m .56916 .61881 L .57726 .61172 L .833 .457 .769 r
F
.34541 .41866 m .3691 .33396 L .33732 .39858 L 1 .222 .589 r
F
.34541 .41866 m .37564 .35934 L .3691 .33396 L F
.4495 .84271 m .44127 .83792 L .43111 .84299 L .854 .694 .833 r
F
.45851 .83709 m .44127 .83792 L .4495 .84271 L .815 .683 .844 r
F
.46659 .84014 m .45851 .83709 L .4495 .84271 L .84 .712 .843 r
F
.49445 .83117 m .48175 .83615 L .48982 .83733 L .782 .682 .857 r
F
.50126 .83168 m .49445 .83117 L .48982 .83733 L .775 .678 .859 r
F
.53363 .61256 m .54852 .60719 L .53709 .60382 L .851 .516 .783 r
F
.52346 .61052 m .53363 .61256 L .53709 .60382 L .841 .531 .79 r
F
.47428 .83429 m .45851 .83709 L .46659 .84014 L .804 .691 .85 r
F
.48175 .83615 m .47428 .83429 L .46659 .84014 L .809 .7 .851 r
F
.62531 .6388 m .64407 .65313 L .63671 .63757 L .629 .269 .77 r
F
.52346 .61052 m .53709 .60382 L .52521 .60191 L .841 .531 .79 r
F
.5131 .60942 m .52346 .61052 L .52521 .60191 L .811 .534 .801 r
F
.58354 1.16439 m .5553 1.13785 L .58753 1.18342 L .114 0 .658 r
F
.58354 1.16439 m .55309 1.12715 L .5553 1.13785 L F
.5131 .60942 m .52521 .60191 L .51309 .6011 L .811 .534 .801 r
F
.58737 .62133 m .60617 .628 L .59677 .61594 L .712 .345 .77 r
F
.57726 .61172 m .58737 .62133 L .59677 .61594 L .77 .382 .763 r
F
.40103 .84284 m .39337 .82994 L .38157 .8291 L .584 .286 .799 r
F
.41213 .83929 m .39337 .82994 L .40103 .84284 L .656 .418 .821 r
F
.54695 .82321 m .54839 .83018 L .55532 .82736 L .743 .648 .863 r
F
.54695 .82321 m .5414 .82555 L .54839 .83018 L F
.37799 .57752 m .38253 .55351 L .36738 .57388 L .953 .485 .743 r
F
.37799 .57752 m .392 .56169 L .38253 .55351 L F
.43111 .84299 m .42326 .83573 L .41214 .83929 L .804 .604 .824 r
F
.44127 .83792 m .42326 .83573 L .43111 .84299 L .789 .63 .838 r
F
.44089 .59025 m .44682 .57758 L .43276 .58086 L .659 .341 .789 r
F
.66679 .77577 m .66427 .79482 L .67662 .7894 L 1 .882 .734 r
F
.61667 .62504 m .62531 .6388 L .63671 .63757 L .661 .288 .765 r
F
.60617 .628 m .62531 .6388 L .61667 .62504 L .66 .298 .77 r
F
.55928 .61222 m .57726 .61172 L .56595 .60375 L .833 .457 .769 r
F
.54852 .60719 m .55928 .61222 L .56595 .60375 L .881 .501 .769 r
F
.41085 .57892 m .41649 .55919 L .40144 .57024 L .753 .303 .737 r
F
.41085 .57892 m .42463 .57057 L .41649 .55919 L F
.59677 .61594 m .60617 .628 L .61667 .62504 L .683 .3 .761 r
F
.48798 .83016 m .47428 .83429 L .48175 .83615 L .784 .681 .855 r
F
.49445 .83117 m .48798 .83016 L .48175 .83615 L .782 .682 .857 r
F
.56677 .82037 m .57104 .82787 L .5774 .82341 L .759 .647 .855 r
F
.56677 .82037 m .56148 .82409 L .57104 .82787 L F
.58848 .35264 m .62842 .29109 L .59193 .32748 L 1 .601 .596 r
F
.58848 .35264 m .62345 .3193 L .62842 .29109 L F
.35354 .43799 m .37564 .35934 L .34541 .41866 L 1 .219 .592 r
F
.35354 .43799 m .3822 .3844 L .37564 .35934 L F
.58259 .81833 m .588 .82686 L .59407 .82066 L .787 .644 .843 r
F
.58259 .81833 m .5774 .82341 L .588 .82686 L F
.33496 .58682 m .34851 .57442 L .33753 .57975 L .647 .02 .738 r
F
.51473 .82525 m .5083 .8317 L .51525 .83127 L .754 .66 .862 r
F
.51992 .82463 m .51525 .83127 L .52215 .83042 L .749 .657 .863 r
F
.51992 .82463 m .51473 .82525 L .51525 .83127 L F
.20967 .78609 m .18918 .85256 L .19684 .78598 L .634 0 .295 r
F
.52499 .82368 m .52215 .83042 L .52889 .82917 L .746 .654 .864 r
F
.52499 .82368 m .51992 .82463 L .52215 .83042 L F
.51473 .82525 m .50951 .82555 L .5083 .8317 L .754 .66 .862 r
F
.50951 .82555 m .50126 .83168 L .5083 .8317 L .759 .664 .861 r
F
.54852 .60719 m .56595 .60375 L .55364 .59803 L .881 .501 .769 r
F
.53709 .60382 m .54852 .60719 L .55364 .59803 L .904 .539 .774 r
F
.55188 .82054 m .55532 .82736 L .56148 .82409 L .75 .651 .861 r
F
.55188 .82054 m .54695 .82321 L .55532 .82736 L F
.38157 .8291 m .37557 .81707 L .36328 .81287 L .402 .119 .823 r
F
.39337 .82994 m .37557 .81707 L .38157 .8291 L .498 .253 .836 r
F
.57726 .61172 m .59677 .61594 L .58539 .6041 L .77 .382 .763 r
F
.56595 .60375 m .57726 .61172 L .58539 .6041 L .855 .44 .757 r
F
.45851 .83709 m .45146 .83318 L .44127 .83792 L .815 .683 .844 r
F
.46754 .83177 m .45146 .83318 L .45851 .83709 L .788 .672 .851 r
F
.47428 .83429 m .46754 .83177 L .45851 .83709 L .804 .691 .85 r
F
.42789 .4333 m .45216 .37666 L .42297 .40253 L .954 .133 .577 r
F
.42789 .4333 m .45545 .41146 L .45216 .37666 L F
.41213 .83929 m .40523 .82934 L .39337 .82994 L .656 .418 .821 r
F
.42326 .83573 m .40523 .82934 L .41213 .83929 L .699 .51 .835 r
F
.20967 .78609 m .20274 .84712 L .18918 .85256 L .634 0 .295 r
F
.22249 .78627 m .20274 .84712 L .20967 .78609 L .619 0 .284 r
F
.52984 .82244 m .52889 .82917 L .53535 .82754 L .746 .653 .864 r
F
.52984 .82244 m .52499 .82368 L .52889 .82917 L F
.50421 .82549 m .49445 .83117 L .50126 .83168 L .764 .667 .86 r
F
.50951 .82555 m .50421 .82549 L .50126 .83168 L .759 .664 .861 r
F
.40144 .57024 m .40836 .54663 L .392 .56169 L .802 .286 .714 r
F
.40144 .57024 m .41649 .55919 L .40836 .54663 L F
.44127 .83792 m .43441 .83216 L .42326 .83573 L .789 .63 .838 r
F
.45146 .83318 m .43441 .83216 L .44127 .83792 L .775 .642 .847 r
F
.22249 .78627 m .21628 .84165 L .20274 .84712 L .619 0 .284 r
F
.23532 .78657 m .21628 .84165 L .22249 .78627 L .6 0 .271 r
F
.482 .82865 m .46754 .83177 L .47428 .83429 L .78 .675 .855 r
F
.48798 .83016 m .482 .82865 L .47428 .83429 L .784 .681 .855 r
F
.43276 .58086 m .4401 .5668 L .42463 .57057 L .646 .279 .767 r
F
.43276 .58086 m .44682 .57758 L .4401 .5668 L F
.5796 1.14649 m .55309 1.12714 L .58354 1.16438 L .148 0 .698 r
F
.5796 1.14649 m .55091 1.1179 L .55309 1.12714 L F
.59677 .61594 m .61667 .62504 L .60621 .61066 L .683 .3 .761 r
F
.58539 .6041 m .59677 .61594 L .60621 .61066 L .749 .334 .752 r
F
.36738 .57388 m .37627 .54839 L .36033 .57286 L 1 .529 .726 r
F
.36738 .57388 m .38253 .55351 L .37627 .54839 L F
.53439 .82092 m .53535 .82754 L .5414 .82555 L .747 .653 .864 r
F
.53439 .82092 m .52984 .82244 L .53535 .82754 L F
.53709 .60382 m .55364 .59803 L .54056 .59467 L .904 .539 .774 r
F
.52521 .60191 m .53709 .60382 L .54056 .59467 L .891 .567 .786 r
F
.23532 .78657 m .22979 .83615 L .21628 .84165 L .6 0 .271 r
F
.24815 .78705 m .22979 .83615 L .23532 .78657 L .578 0 .254 r
F
.36169 .45651 m .3822 .3844 L .35354 .43799 L 1 .214 .596 r
F
.36169 .45651 m .38879 .40916 L .3822 .3844 L F
.49909 .82507 m .48798 .83016 L .49445 .83117 L .767 .668 .859 r
F
.50421 .82549 m .49909 .82507 L .49445 .83117 L .764 .667 .86 r
F
.61667 .62504 m .63671 .63757 L .62722 .6228 L .661 .288 .765 r
F
.60621 .61066 m .61667 .62504 L .62722 .6228 L .634 .244 .755 r
F
.56595 .60375 m .58539 .6041 L .57264 .59442 L .855 .44 .757 r
F
.55364 .59803 m .56595 .60375 L .57264 .59442 L .932 .504 .755 r
F
.52521 .60191 m .54056 .59467 L .52696 .59329 L .891 .567 .786 r
F
.51309 .6011 m .52521 .60191 L .52696 .59329 L .841 .574 .803 r
F
.57109 .81627 m .5774 .82341 L .58259 .81833 L .774 .658 .852 r
F
.57109 .81627 m .56677 .82037 L .5774 .82341 L F
.58502 .37727 m .62345 .3193 L .58848 .35264 L 1 .602 .6 r
F
.58502 .37727 m .61846 .3471 L .62345 .3193 L F
.51309 .6011 m .52696 .59329 L .51308 .59315 L .841 .574 .803 r
F
.24815 .78705 m .24326 .83068 L .22979 .83615 L .578 0 .254 r
F
.26098 .78779 m .24326 .83068 L .24815 .78705 L .553 0 .231 r
F
.28921 .44703 m .31323 .33456 L .27975 .43022 L 1 .248 .582 r
F
.28921 .44703 m .32123 .35646 L .31323 .33456 L F
.55611 .81757 m .56148 .82409 L .56677 .82037 L .757 .655 .859 r
F
.55611 .81757 m .55188 .82054 L .56148 .82409 L F
.67065 .31668 m .71421 .38287 L .67721 .29289 L .776 .074 .582 r
F
.42326 .83573 m .41713 .82788 L .40523 .82934 L .699 .51 .835 r
F
.43441 .83216 m .41713 .82788 L .42326 .83573 L .723 .569 .845 r
F
.53855 .81913 m .5414 .82555 L .54695 .82321 L .749 .654 .863 r
F
.53855 .81913 m .53439 .82092 L .5414 .82555 L F
.39337 .82994 m .38794 .81943 L .37557 .81707 L .498 .253 .836 r
F
.40523 .82934 m .38794 .81943 L .39337 .82994 L .578 .376 .844 r
F
.392 .56169 m .40024 .53297 L .38253 .55351 L .869 .282 .69 r
F
.392 .56169 m .40836 .54663 L .40024 .53297 L F
.49424 .82428 m .482 .82865 L .48798 .83016 L .767 .667 .859 r
F
.49909 .82507 m .49424 .82428 L .48798 .83016 L .767 .668 .859 r
F
.26098 .78779 m .25671 .82532 L .24326 .83068 L .553 0 .231 r
F
.2738 .78891 m .25671 .82532 L .26098 .78779 L .524 0 .199 r
F
.58539 .6041 m .60621 .61066 L .59353 .59584 L .749 .334 .752 r
F
.57264 .59442 m .58539 .6041 L .59353 .59584 L .873 .412 .742 r
F
.58653 .81282 m .59407 .82066 L .59868 .81374 L .813 .674 .842 r
F
.58653 .81282 m .58259 .81833 L .59407 .82066 L F
.42463 .57057 m .43338 .55395 L .41649 .55919 L .649 .214 .733 r
F
.42463 .57057 m .4401 .5668 L .43338 .55395 L F
.46754 .83177 m .46168 .82864 L .45146 .83318 L .788 .672 .851 r
F
.47661 .82665 m .46168 .82864 L .46754 .83177 L .77 .664 .856 r
F
.482 .82865 m .47661 .82665 L .46754 .83177 L .78 .675 .855 r
F
.45146 .83318 m .44559 .82858 L .43441 .83216 L .775 .642 .847 r
F
.46168 .82864 m .44559 .82858 L .45146 .83318 L .765 .648 .853 r
F
.36986 .47421 m .38879 .40916 L .36169 .45651 L 1 .203 .601 r
F
.36986 .47421 m .3954 .43366 L .38879 .40916 L F
.36033 .57286 m .37538 .54768 L .35932 .57282 L 1 .543 .71 r
F
.36033 .57286 m .37627 .54838 L .37538 .54768 L F
.55364 .59803 m .57264 .59442 L .55878 .58798 L .932 .504 .755 r
F
.54056 .59467 m .55364 .59803 L .55878 .58798 L .974 .564 .761 r
F
.37557 .81707 m .35938 .80741 L .36328 .81287 L .387 .136 .884 r
F
.2738 .78891 m .27011 .82019 L .25671 .82532 L .524 0 .199 r
F
.28662 .7905 m .27011 .82019 L .2738 .78891 L .49 0 .153 r
F
.29871 .46311 m .32123 .35646 L .28921 .44703 L 1 .255 .584 r
F
.29871 .46311 m .32926 .37782 L .32123 .35646 L F
.54225 .81711 m .54695 .82321 L .55188 .82054 L .751 .655 .862 r
F
.54225 .81711 m .53855 .81913 L .54695 .82321 L F
.35932 .57282 m .36586 .5403 L .34851 .57442 L 1 .555 .709 r
F
.35932 .57282 m .37538 .54767 L .36586 .5403 L F
.67065 .31668 m .70609 .40262 L .71421 .38287 L .776 .074 .582 r
F
.66407 .33999 m .70609 .40262 L .67065 .31668 L .771 .073 .583 r
F
.60621 .61066 m .62722 .6228 L .61569 .60588 L .634 .244 .755 r
F
.59353 .59584 m .60621 .61066 L .61569 .60588 L .698 .265 .74 r
F
.48974 .82314 m .47661 .82665 L .482 .82865 L .764 .664 .859 r
F
.49424 .82428 m .48974 .82314 L .482 .82865 L .767 .667 .859 r
F
.43441 .83216 m .42906 .82588 L .41713 .82788 L .723 .569 .845 r
F
.44559 .82858 m .42906 .82588 L .43441 .83216 L .735 .603 .851 r
F
.51421 .81917 m .50951 .82555 L .51473 .82525 L .752 .657 .862 r
F
.51768 .81876 m .51473 .82525 L .51992 .82463 L .75 .656 .863 r
F
.51768 .81876 m .51421 .81917 L .51473 .82525 L F
.57567 1.12939 m .55091 1.1179 L .5796 1.14649 L .245 .002 .745 r
F
.57567 1.12939 m .54872 1.10926 L .55091 1.1179 L F
.52106 .81813 m .51992 .82463 L .52499 .82368 L .749 .655 .863 r
F
.52106 .81813 m .51768 .81876 L .51992 .82463 L F
.58154 .4013 m .61846 .3471 L .58502 .37727 L 1 .602 .604 r
F
.58154 .4013 m .61345 .37444 L .61846 .3471 L F
.51421 .81917 m .51072 .81936 L .50951 .82555 L .752 .657 .862 r
F
.51072 .81936 m .50421 .82549 L .50951 .82555 L .753 .658 .862 r
F
.28662 .7905 m .28348 .81547 L .27011 .82019 L .49 0 .153 r
F
.29925 .79261 m .28348 .81547 L .28663 .7905 L .452 0 .084 r
F
.55956 .81436 m .56677 .82037 L .57109 .81627 L .764 .661 .858 r
F
.55956 .81436 m .55611 .81757 L .56677 .82037 L F
.43282 .46539 m .45545 .41146 L .42789 .4333 L .874 .094 .568 r
F
.57264 .59442 m .59353 .59584 L .57934 .58391 L .873 .412 .742 r
F
.55878 .58798 m .57264 .59442 L .57934 .58391 L .991 .5 .737 r
F
.40523 .82934 m .40036 .82038 L .38794 .81943 L .578 .376 .844 r
F
.41713 .82788 m .40036 .82038 L .40523 .82934 L .638 .469 .85 r
F
.38253 .55351 m .39489 .52343 L .37627 .54839 L .951 .291 .67 r
F
.38253 .55351 m .40024 .53296 L .39489 .52343 L F
.41649 .55919 m .42669 .53825 L .40836 .54663 L .673 .164 .694 r
F
.41649 .55919 m .43338 .55395 L .42669 .53825 L F
.54056 .59467 m .55878 .58798 L .54405 .58495 L .974 .564 .761 r
F
.52696 .59329 m .54056 .59467 L .54405 .58495 L .963 .615 .779 r
F
.5243 .8173 m .52499 .82368 L .52984 .82244 L .749 .655 .863 r
F
.5243 .8173 m .52106 .81813 L .52499 .82368 L F
.50718 .8193 m .49909 .82507 L .50421 .82549 L .755 .659 .861 r
F
.51072 .81936 m .50718 .8193 L .50421 .82549 L .753 .658 .862 r
F
.61569 .60588 m .62722 .6228 L .63783 .62197 L .549 .168 .752 r
F
.30824 .47826 m .32926 .37782 L .29871 .46311 L 1 .262 .586 r
F
.30824 .47826 m .33732 .39858 L .32926 .37782 L F
.57436 .8119 m .58259 .81833 L .58653 .81282 L .787 .674 .852 r
F
.57436 .8119 m .57109 .81627 L .58259 .81833 L F
.37794 .49089 m .3954 .43366 L .36986 .47422 L .985 .188 .606 r
F
.37794 .49089 m .40193 .45753 L .3954 .43366 L F
.66407 .33999 m .69795 .42201 L .70609 .40262 L .771 .073 .583 r
F
.65746 .36274 m .69795 .42201 L .66407 .33999 L .765 .072 .585 r
F
.54542 .81489 m .55188 .82054 L .55611 .81757 L .753 .657 .861 r
F
.54542 .81489 m .54225 .81711 L .55188 .82054 L F
.52734 .81628 m .52984 .82244 L .53439 .82092 L .749 .655 .863 r
F
.52734 .81628 m .5243 .8173 L .52984 .82244 L F
.46168 .82864 m .45679 .82499 L .44559 .82858 L .765 .648 .853 r
F
.47192 .82421 m .45679 .82499 L .46168 .82864 L .757 .649 .857 r
F
.47661 .82665 m .47192 .82421 L .46168 .82864 L .77 .664 .856 r
F
.59353 .59584 m .61569 .60588 L .60168 .58676 L .698 .265 .74 r
F
.57934 .58391 m .59353 .59584 L .60168 .58676 L .888 .372 .723 r
F
.50376 .81901 m .49424 .82428 L .49909 .82507 L .756 .659 .861 r
F
.50718 .8193 m .50376 .81901 L .49909 .82507 L .755 .659 .861 r
F
.29925 .79261 m .2966 .81143 L .28348 .81547 L .452 0 .084 r
F
.31188 .79528 m .2966 .81143 L .29925 .79261 L .395 0 0 r
F
.52696 .59329 m .54405 .58495 L .52872 .58466 L .963 .615 .779 r
F
.51308 .59315 m .52696 .59329 L .52872 .58466 L .888 .636 .806 r
F
.40836 .54663 m .42004 .51944 L .40024 .53297 L .719 .139 .66 r
F
.40836 .54663 m .42669 .53825 L .42004 .51944 L F
.37557 .81707 m .3721 .80993 L .35938 .80741 L .387 .136 .884 r
F
.38794 .81943 m .3721 .80993 L .37557 .81707 L .485 .288 .878 r
F
.4857 .82165 m .47192 .82421 L .47661 .82665 L .758 .657 .859 r
F
.48974 .82314 m .4857 .82165 L .47661 .82665 L .764 .664 .859 r
F
.37627 .54838 m .39413 .52204 L .37538 .54768 L 1 .302 .658 r
F
.37627 .54838 m .39489 .52342 L .39413 .52204 L F
.31781 .49225 m .33732 .39858 L .30824 .47826 L 1 .27 .59 r
F
.31781 .49225 m .34541 .41866 L .33732 .39858 L F
.69491 1.03319 m .68153 1.12846 L .70486 1.05178 L 1 .232 .585 r
F
.69491 1.03319 m .67275 1.10601 L .68153 1.12846 L F
.53012 .81508 m .53439 .82092 L .53855 .81913 L .749 .655 .863 r
F
.53012 .81508 m .52734 .81628 L .53439 .82092 L F
.51308 .59315 m .52872 .58466 L .51307 .5858 L .888 .636 .806 r
F
.44559 .82858 m .44101 .82354 L .42906 .82588 L .735 .603 .851 r
F
.45679 .82499 m .44101 .82354 L .44559 .82858 L .741 .624 .856 r
F
.37538 .54767 m .38603 .50683 L .36586 .5403 L 1 .291 .655 r
F
.37538 .54767 m .39413 .52204 L .38603 .50683 L F
.55878 .58798 m .57934 .58391 L .56392 .57674 L .991 .5 .737 r
F
.54405 .58495 m .55878 .58798 L .56392 .57674 L 1 .586 .745 r
F
.41713 .82788 m .41282 .82032 L .40036 .82038 L .638 .469 .85 r
F
.42906 .82588 m .41282 .82032 L .41713 .82788 L .679 .535 .854 r
F
.65746 .36274 m .68979 .441 L .69795 .42201 L .765 .072 .585 r
F
.65083 .38482 m .68979 .441 L .65746 .36274 L .757 .071 .586 r
F
.50052 .81847 m .48974 .82314 L .49424 .82428 L .756 .658 .861 r
F
.50376 .81901 m .50052 .81847 L .49424 .82428 L .756 .659 .861 r
F
.58914 .80717 m .59868 .81374 L .60174 .80665 L .832 .711 .845 r
F
.58914 .80717 m .58653 .81282 L .59868 .81374 L F
.57806 .4246 m .61345 .37444 L .58154 .4013 L 1 .6 .608 r
F
.57806 .4246 m .60841 .40121 L .61345 .37444 L F
.54632 1.09967 m .52089 1.08832 L .54653 1.10051 L 0 0 .774 r
F
.54632 1.09967 m .52084 1.08811 L .52089 1.08832 L F
.38603 .50683 m .40193 .45753 L .37794 .49089 L .918 .169 .614 r
F
.38603 .50683 m .40848 .48098 L .40193 .45753 L F
.31188 .79528 m .30968 .8082 L .2966 .81143 L .395 0 0 r
F
.32451 .79841 m .30968 .8082 L .31188 .79528 L .298 0 0 r
F
.40024 .53296 m .41568 .50559 L .39489 .52343 L .789 .143 .638 r
F
.40024 .53296 m .42004 .51943 L .41568 .50559 L F
.58825 .49803 m .61742 .47699 L .59331 .47579 L 1 .425 .615 r
F
.61569 .60588 m .63783 .62197 L .62522 .60248 L .549 .168 .752 r
F
.60168 .58676 m .61569 .60588 L .62522 .60248 L .598 .165 .726 r
F
.32742 .50481 m .34541 .41866 L .31781 .49225 L 1 .279 .595 r
F
.32742 .50481 m .35354 .43799 L .34541 .41866 L F
.57934 .58391 m .60168 .58676 L .58604 .57181 L .888 .372 .723 r
F
.56392 .57674 m .57934 .58391 L .58604 .57181 L 1 .485 .716 r
F
.39163 .30157 m .42623 .3294 L .38661 .27462 L .29 0 .588 r
F
.56216 .81098 m .57109 .81627 L .57436 .8119 L .768 .668 .858 r
F
.56216 .81098 m .55956 .81436 L .57109 .81627 L F
.548 .81252 m .55611 .81757 L .55956 .81436 L .755 .659 .861 r
F
.548 .81252 m .54542 .81489 L .55611 .81757 L F
.53259 .81373 m .53855 .81913 L .54225 .81711 L .749 .655 .863 r
F
.53259 .81373 m .53012 .81508 L .53855 .81913 L F
.52084 1.08811 m .49529 1.08943 L .49518 1.08975 L .509 .235 .898 r
F
.52051 1.08579 m .49529 1.08943 L .52084 1.08811 L .602 .477 .891 r
F
.54487 1.09358 m .52084 1.08811 L .54632 1.09967 L .24 .019 .858 r
F
.54487 1.09358 m .52051 1.08579 L .52084 1.08811 L F
.70486 1.05178 m .69032 1.15088 L .7148 1.06984 L 1 .233 .585 r
F
.70486 1.05178 m .68153 1.12846 L .69032 1.15088 L F
.39489 .52342 m .41506 .50355 L .39413 .52204 L .845 .157 .629 r
F
.39489 .52342 m .41568 .50558 L .41506 .50355 L F
.39413 .52204 m .40848 .48098 L .38603 .50683 L .842 .149 .624 r
F
.39413 .52204 m .41506 .50354 L .40848 .48098 L F
.65083 .38482 m .68161 .45953 L .68979 .441 L .757 .071 .586 r
F
.64417 .40608 m .68161 .45953 L .65083 .38482 L .745 .068 .587 r
F
.49752 .81771 m .4857 .82165 L .48974 .82314 L .754 .656 .861 r
F
.50052 .81847 m .49752 .81771 L .48974 .82314 L .756 .658 .861 r
F
.33707 .51574 m .35354 .43799 L .32742 .50481 L 1 .287 .602 r
F
.33707 .51574 m .36169 .45651 L .35354 .43799 L F
.60168 .58676 m .62522 .60248 L .60983 .57643 L .598 .165 .726 r
F
.58604 .57181 m .60168 .58676 L .60983 .57643 L .904 .323 .698 r
F
.57174 1.11307 m .54872 1.10926 L .57567 1.12939 L .381 .062 .777 r
F
.57174 1.11307 m .54653 1.10051 L .54872 1.10926 L F
.47192 .82421 m .46801 .8214 L .45679 .82499 L .757 .649 .857 r
F
.48218 .81986 m .46801 .8214 L .47192 .82421 L .751 .649 .86 r
F
.4857 .82165 m .48218 .81986 L .47192 .82421 L .758 .657 .859 r
F
.52051 1.08579 m .49607 1.08634 L .49529 1.08943 L .602 .477 .891 r
F
.49606 1.08634 m .46926 1.10148 L .49529 1.08943 L 1 .734 .726 r
F
.36586 .5403 m .38603 .50683 L .37794 .49089 L 1 .297 .637 r
F
.34851 .57442 m .35631 .53297 L .33753 .57975 L 1 .541 .677 r
F
.34851 .57442 m .36586 .5403 L .35631 .53297 L F
.38794 .81943 m .38485 .81177 L .3721 .80993 L .485 .288 .878 r
F
.40036 .82038 m .38485 .81177 L .38794 .81943 L .559 .397 .871 r
F
.42906 .82588 m .42531 .81956 L .41282 .82032 L .679 .535 .854 r
F
.44101 .82354 m .42531 .81956 L .42906 .82588 L .706 .579 .857 r
F
.54405 .58495 m .56392 .57674 L .54754 .57445 L 1 .586 .745 r
F
.52872 .58466 m .54405 .58495 L .54754 .57445 L 1 .671 .768 r
F
.45679 .82499 m .45299 .82099 L .44101 .82354 L .741 .624 .856 r
F
.46801 .8214 m .45299 .82099 L .45679 .82499 L .743 .635 .859 r
F
.6241 .46208 m .65695 .51087 L .63076 .4452 L .663 .046 .591 r
F
.6241 .46208 m .64878 .52494 L .65695 .51087 L F
.34675 .52504 m .36169 .45651 L .33707 .51574 L 1 .294 .611 r
F
.34675 .52504 m .36986 .47421 L .36169 .45651 L F
.57651 .80744 m .58653 .81282 L .58914 .80717 L .796 .693 .854 r
F
.57651 .80744 m .57436 .8119 L .58653 .81282 L F
.64417 .40608 m .67341 .4775 L .68161 .45953 L .745 .068 .587 r
F
.63748 .42631 m .67341 .4775 L .64417 .40608 L .729 .063 .587 r
F
.35631 .53297 m .37794 .49089 L .36986 .47422 L 1 .298 .623 r
F
.36586 .5403 m .37794 .49089 L .35631 .53297 L 1 .297 .637 r
F
.3897 1.06988 m .35989 1.02858 L .38197 1.082 L .596 .063 .642 r
F
.3897 1.06988 m .3688 1.02356 L .35989 1.02858 L F
.32451 .79841 m .32271 .80592 L .30968 .8082 L .298 0 0 r
F
.32569 .79872 m .32271 .80592 L .32451 .79841 L .307 0 0 r
F
.7148 1.06984 m .69912 1.17341 L .72475 1.08763 L 1 .232 .585 r
F
.7148 1.06984 m .69032 1.15088 L .69912 1.17341 L F
.35631 .53297 m .36986 .47422 L .34675 .52504 L 1 .298 .623 r
F
.32569 .79872 m .32392 .80576 L .32271 .80592 L .307 0 0 r
F
.33403 .80096 m .32393 .80576 L .32569 .79873 L .188 0 0 r
F
.5347 .81226 m .54225 .81711 L .54542 .81489 L .749 .655 .863 r
F
.5347 .81226 m .53259 .81373 L .54225 .81711 L F
.63748 .42631 m .6652 .49473 L .67341 .4775 L .729 .063 .587 r
F
.63076 .4452 m .6652 .49473 L .63748 .42631 L .703 .056 .589 r
F
.63076 .4452 m .65695 .51087 L .6652 .49473 L F
.57456 .44706 m .60841 .40121 L .57806 .4246 L 1 .598 .613 r
F
.57456 .44706 m .60336 .42727 L .60841 .40121 L F
.51368 .81306 m .51072 .81936 L .51421 .81917 L .748 .653 .863 r
F
.51542 .81286 m .51421 .81917 L .51768 .81876 L F
.51542 .81286 m .51368 .81306 L .51421 .81917 L F
.51712 .81255 m .51768 .81876 L .52106 .81813 L .747 .653 .863 r
F
.51712 .81255 m .51542 .81286 L .51768 .81876 L F
.49482 .81672 m .48218 .81986 L .4857 .82165 L .751 .653 .861 r
F
.49752 .81771 m .49482 .81672 L .4857 .82165 L .754 .656 .861 r
F
.51368 .81306 m .51194 .81315 L .51072 .81936 L .748 .653 .863 r
F
.51194 .81315 m .50718 .8193 L .51072 .81936 L .749 .653 .863 r
F
.56392 .57674 m .58604 .57181 L .56906 .56395 L 1 .485 .716 r
F
.54754 .57445 m .56392 .57674 L .56906 .56395 L 1 .6 .726 r
F
.58604 .57181 m .60983 .57643 L .59272 .55755 L .904 .323 .698 r
F
.56906 .56395 m .58604 .57181 L .59272 .55755 L 1 .462 .691 r
F
.51874 .81213 m .52106 .81813 L .5243 .8173 L .747 .653 .863 r
F
.51874 .81213 m .51712 .81255 L .52106 .81813 L F
.58778 .50003 m .61091 .50259 L .58825 .49804 L 1 .438 .622 r
F
.58778 .50003 m .6103 .50486 L .61091 .50259 L F
.39163 .30157 m .42974 .35377 L .42623 .3294 L .29 0 .588 r
F
.39667 .32816 m .42974 .35377 L .39163 .30157 L .29 0 .59 r
F
.51016 .81312 m .50376 .81901 L .50718 .8193 L .749 .654 .862 r
F
.51194 .81315 m .51016 .81312 L .50718 .8193 L .749 .653 .863 r
F
.54995 .81003 m .55956 .81436 L .56216 .81098 L .756 .662 .862 r
F
.54995 .81003 m .548 .81252 L .55956 .81436 L F
.72475 1.08763 m .69912 1.17341 L .70795 1.19615 L 1 .231 .584 r
F
.58443 .51362 m .6103 .50486 L .58778 .50003 L 1 .423 .627 r
F
.58443 .51362 m .60598 .5201 L .6103 .50486 L F
.33403 .80096 m .33249 .80485 L .32393 .80576 L .188 0 0 r
F
.44101 .82354 m .43781 .81833 L .42531 .81956 L .706 .579 .857 r
F
.45299 .82099 m .43781 .81833 L .44101 .82354 L .722 .607 .859 r
F
.52027 .81162 m .5243 .8173 L .52734 .81628 L .746 .652 .863 r
F
.52027 .81162 m .51874 .81213 L .5243 .8173 L F
.40036 .82038 m .39763 .81293 L .38485 .81177 L .559 .397 .871 r
F
.41282 .82032 m .39763 .81293 L .40036 .82038 L .616 .475 .866 r
F
.52872 .58466 m .54754 .57445 L .53048 .57596 L 1 .671 .768 r
F
.51307 .5858 m .52872 .58466 L .53048 .57596 L .96 .722 .807 r
F
.50845 .81297 m .50052 .81847 L .50376 .81901 L .749 .653 .862 r
F
.51016 .81312 m .50845 .81297 L .50376 .81901 L .749 .654 .862 r
F
.56387 .80753 m .57436 .8119 L .57651 .80744 L .772 .677 .86 r
F
.56387 .80753 m .56216 .81098 L .57436 .8119 L F
.53641 .81069 m .54542 .81489 L .548 .81252 L .749 .656 .863 r
F
.53641 .81069 m .5347 .81226 L .54542 .81489 L F
.60983 .57643 m .63486 .6025 L .61796 .56359 L .433 .04 .703 r
F
.60983 .57643 m .62522 .60248 L .63486 .6025 L F
.59272 .55755 m .60983 .57643 L .61796 .56359 L .945 .278 .666 r
F
.65447 1.0029 m .64904 .97936 L .66505 1.00277 L .491 0 .236 r
F
.65447 1.0029 m .63988 .99278 L .64904 .97936 L F
.52166 .81103 m .52734 .81628 L .53012 .81508 L .746 .652 .863 r
F
.52166 .81103 m .52027 .81162 L .52734 .81628 L F
.48218 .81986 m .47926 .8178 L .46801 .8214 L .751 .649 .86 r
F
.46801 .8214 m .46498 .8183 L .45299 .82099 L .743 .635 .859 r
F
.47926 .8178 m .46498 .8183 L .46801 .8214 L .743 .642 .861 r
F
.59937 .54049 m .626 .54537 L .60598 .52011 L 1 .252 .627 r
F
.57932 .53254 m .60598 .52011 L .58443 .51363 L 1 .42 .642 r
F
.57932 .53254 m .59937 .54049 L .60598 .52011 L F
.50682 .8127 m .49752 .81771 L .50052 .81847 L .749 .653 .862 r
F
.50845 .81297 m .50682 .8127 L .50052 .81847 L F
.59035 .80172 m .60174 .80665 L .60318 .79995 L .839 .741 .852 r
F
.59035 .80172 m .58914 .80717 L .60174 .80665 L F
.59272 .55755 m .61796 .56359 L .59937 .54049 L .945 .278 .666 r
F
.5742 .5493 m .59272 .55755 L .59937 .54049 L 1 .437 .665 r
F
.56906 .56395 m .59272 .55755 L .5742 .5493 L 1 .462 .691 r
F
.49248 .81554 m .47926 .8178 L .48218 .81986 L .747 .649 .862 r
F
.49482 .81672 m .49248 .81554 L .48218 .81986 L .751 .653 .861 r
F
.51307 .5858 m .53048 .57596 L .51306 .5793 L .96 .722 .807 r
F
.5711 .4682 m .60335 .42728 L .57456 .44706 L 1 .594 .62 r
F
.5711 .4682 m .59835 .4521 L .60335 .42728 L F
.52 1.07996 m .49607 1.08634 L .52051 1.08579 L .753 .609 .845 r
F
.54266 1.08385 m .52051 1.08579 L .54487 1.09358 L .507 .304 .86 r
F
.54266 1.08385 m .52 1.07996 L .52051 1.08579 L F
.59937 .54049 m .61796 .56359 L .626 .54537 L 1 .252 .627 r
F
.52289 .81035 m .53012 .81508 L .53259 .81373 L .746 .652 .864 r
F
.52289 .81035 m .52166 .81103 L .53012 .81508 L F
.5742 .5493 m .59937 .54049 L .57932 .53254 L 1 .437 .665 r
F
.33753 .57975 m .35631 .53297 L .34675 .52504 L 1 .485 .641 r
F
.4927 1.14534 m .46277 1.17399 L .45992 1.17643 L 0 0 0 r
F
.49381 1.16168 m .46277 1.17399 L .4927 1.14534 L F
.52151 1.18626 m .49271 1.14534 L .52203 1.20007 L 1 .004 .28 r
F
.52151 1.18626 m .49382 1.16168 L .49271 1.14534 L F
.41282 .82032 m .41043 .81348 L .39763 .81293 L .616 .475 .866 r
F
.42531 .81956 m .41043 .81348 L .41282 .82032 L .659 .531 .863 r
F
.45299 .82099 m .45034 .81677 L .43781 .81833 L .722 .607 .859 r
F
.46498 .8183 m .45034 .81677 L .45299 .82099 L .732 .625 .861 r
F
.50532 .81232 m .49482 .81672 L .49752 .81771 L .747 .652 .863 r
F
.50682 .8127 m .50532 .81232 L .49752 .81771 L .749 .653 .862 r
F
.49606 1.08634 m .4712 1.09303 L .46926 1.10148 L 1 .734 .726 r
F
.52 1.07996 m .49725 1.07967 L .49607 1.08634 L .753 .609 .845 r
F
.49725 1.07967 m .4712 1.09303 L .49606 1.08634 L 1 .656 .743 r
F
.55104 .5629 m .56906 .56395 L .5742 .5493 L 1 .604 .704 r
F
.54754 .57445 m .56906 .56395 L .55104 .5629 L 1 .6 .726 r
F
.39741 1.05958 m .3688 1.02356 L .3897 1.06988 L .523 .054 .667 r
F
.39741 1.05958 m .3777 1.02091 L .3688 1.02356 L F
.39667 .32816 m .43325 .37796 L .42974 .35377 L .29 0 .59 r
F
.40173 .35434 m .43325 .37796 L .39667 .32816 L .29 0 .591 r
F
.53048 .57596 m .54754 .57445 L .55104 .5629 L 1 .727 .753 r
F
.46304 1.13873 m .42935 1.16749 L .45999 1.16715 L 1 .428 .626 r
F
.46304 1.13873 m .43412 1.14307 L .42935 1.16749 L F
.46603 1.11815 m .43412 1.14307 L .46304 1.13873 L 1 .478 .644 r
F
.53771 .80905 m .548 .81252 L .54995 .81003 L .749 .656 .863 r
F
.53771 .80905 m .53641 .81069 L .548 .81252 L F
.57137 1.11158 m .54653 1.10051 L .57174 1.11306 L .401 .075 .775 r
F
.57137 1.11158 m .54632 1.09967 L .54653 1.10051 L F
.55122 .8075 m .56216 .81098 L .56387 .80753 L .757 .665 .863 r
F
.55122 .8075 m .54995 .81003 L .56216 .81098 L F
.57751 .80306 m .58914 .80717 L .59035 .80172 L .799 .708 .858 r
F
.57751 .80306 m .57651 .80744 L .58914 .80717 L F
.46603 1.11815 m .43885 1.12178 L .43412 1.14307 L 1 .478 .644 r
F
.46898 1.10276 m .43885 1.12178 L .46603 1.11815 L 1 .506 .666 r
F
.52395 .80962 m .53259 .81373 L .5347 .81226 L .745 .652 .864 r
F
.52395 .80962 m .52289 .81035 L .53259 .81373 L F
.56879 1.10134 m .54632 1.09967 L .57137 1.11158 L .491 .162 .782 r
F
.56879 1.10134 m .54487 1.09358 L .54632 1.09967 L F
.50397 .81183 m .49248 .81554 L .49482 .81672 L .746 .65 .863 r
F
.50532 .81232 m .50397 .81183 L .49482 .81672 L .747 .652 .863 r
F
.56763 .48816 m .59835 .4521 L .5711 .4682 L 1 .591 .628 r
F
.56763 .48816 m .59331 .47579 L .59835 .4521 L F
.49248 .81554 m .49054 .81419 L .47926 .8178 L .747 .649 .862 r
F
.47926 .8178 m .477 .81552 L .46498 .8183 L .743 .642 .861 r
F
.49054 .81419 m .477 .81552 L .47926 .8178 L .743 .645 .862 r
F
.42531 .81956 m .42324 .81351 L .41043 .81348 L .659 .531 .863 r
F
.43781 .81833 m .42324 .81351 L .42531 .81956 L .69 .572 .862 r
F
.35938 .80741 m .35838 .80432 L .34545 .80422 L .278 0 .835 r
F
.3721 .80993 m .35838 .80432 L .35938 .80741 L .427 .127 .895 r
F
.63142 .53967 m .65335 .70633 L .65344 .67 L 1 .177 .476 r
F
.49023 1.19441 m .45362 1.24272 L .48885 1.2534 L 1 .251 .578 r
F
.49023 1.19441 m .45683 1.2033 L .45362 1.24272 L F
.52311 1.25187 m .49023 1.19442 L .48886 1.2534 L .754 .04 .545 r
F
.52256 1.22128 m .49023 1.19442 L .52311 1.25187 L .689 .011 .505 r
F
.46498 .8183 m .46288 .815 L .45034 .81677 L .732 .625 .861 r
F
.477 .81552 m .46288 .815 L .46498 .8183 L .737 .636 .862 r
F
.38101 1.21025 m .35042 1.14711 L .34244 1.16647 L .848 .12 .6 r
F
.38755 1.18574 m .35042 1.14711 L .38101 1.21025 L .849 .127 .606 r
F
.5248 .80884 m .5347 .81226 L .53641 .81069 L .745 .652 .864 r
F
.5248 .80884 m .52395 .80962 L .5347 .81226 L F
.56466 .80411 m .57651 .80744 L .57751 .80306 L .773 .684 .861 r
F
.56466 .80411 m .56387 .80753 L .57651 .80744 L F
.55454 .55007 m .5742 .5493 L .57932 .53254 L 1 .599 .683 r
F
.55104 .5629 m .5742 .5493 L .55454 .55007 L 1 .604 .704 r
F
.63221 .53967 m .66227 .62738 L .64055 .53548 L .822 .044 .526 r
F
.63221 .53967 m .65344 .66997 L .66227 .62738 L F
.36811 .9841 m .3538 .9795 L .34746 .9414 L 1 .11 .346 r
F
.5028 .81124 m .49054 .81419 L .49248 .81554 L .744 .649 .863 r
F
.50397 .81183 m .5028 .81124 L .49248 .81554 L .746 .65 .863 r
F
.33753 .57975 m .34675 .52504 L .32644 .58668 L 1 .485 .641 r
F
.32644 .58668 m .34675 .52504 L .33707 .51574 L 1 .423 .613 r
F
.37443 1.23579 m .34244 1.16647 L .33442 1.18667 L .847 .114 .596 r
F
.38101 1.21025 m .34244 1.16647 L .37443 1.23579 L .848 .12 .6 r
F
.40173 .35434 m .43677 .40198 L .43325 .37796 L .29 0 .591 r
F
.40681 .38005 m .43677 .40198 L .40173 .35434 L .287 0 .591 r
F
.53855 .80737 m .54995 .81003 L .55122 .8075 L .749 .657 .864 r
F
.53855 .80737 m .53771 .80905 L .54995 .81003 L F
.43781 .81833 m .43607 .81315 L .42324 .81351 L .69 .572 .862 r
F
.45034 .81677 m .43607 .81315 L .43781 .81833 L .711 .6 .862 r
F
.46898 1.10276 m .44354 1.10362 L .43885 1.12178 L 1 .506 .666 r
F
.46926 1.10148 m .44355 1.10361 L .46898 1.10276 L 1 .542 .68 r
F
.56416 .50678 m .59331 .47579 L .56763 .48816 L 1 .588 .638 r
F
.56416 .50678 m .58825 .49803 L .59331 .47579 L F
.46926 1.10148 m .44398 1.10206 L .44355 1.10361 L 1 .542 .68 r
F
.4712 1.09303 m .44398 1.10206 L .46926 1.10148 L 1 .528 .688 r
F
.51316 .80695 m .51194 .81315 L .51368 .81306 L .744 .649 .863 r
F
.51316 .80695 m .51368 .81306 L .51542 .81286 L .743 .649 .864 r
F
.51316 .80695 m .51316 .80695 L .51368 .81306 L F
.45999 1.16716 m .42935 1.1675 L .42447 1.19503 L 1 .355 .612 r
F
.51316 .80695 m .51542 .81286 L .51712 .81255 L .743 .649 .864 r
F
.51316 .80695 m .51316 .80695 L .51542 .81286 L F
.60299 .794 m .61599 .79757 L .6158 .79071 L .879 .798 .853 r
F
.60299 .794 m .60318 .79995 L .61599 .79757 L F
.51316 .80695 m .51316 .80695 L .51194 .81315 L .744 .649 .863 r
F
.51316 .80695 m .51016 .81312 L .51194 .81315 L .744 .65 .863 r
F
.3721 .80993 m .3713 .8049 L .35838 .80432 L .427 .127 .895 r
F
.38485 .81177 m .3713 .8049 L .3721 .80993 L .508 .311 .898 r
F
.53048 .57596 m .55104 .5629 L .53225 .56707 L 1 .727 .753 r
F
.51306 .5793 m .53048 .57596 L .53225 .56707 L 1 .83 .804 r
F
.51316 .80695 m .51712 .81255 L .51874 .81213 L .742 .648 .864 r
F
.51316 .80695 m .51316 .80695 L .51712 .81255 L F
.51316 .80695 m .50845 .81297 L .51016 .81312 L .744 .65 .863 r
F
.51316 .80695 m .51316 .80695 L .51016 .81312 L F
.52544 .80802 m .53641 .81069 L .53771 .80905 L .745 .652 .864 r
F
.52544 .80802 m .5248 .80884 L .53641 .81069 L F
.55804 .53574 m .57932 .53254 L .58443 .51363 L 1 .593 .664 r
F
.55454 .55007 m .57932 .53254 L .55804 .53574 L 1 .599 .683 r
F
.51316 .80695 m .51874 .81213 L .52027 .81162 L .742 .648 .864 r
F
.51316 .80695 m .51316 .80695 L .51874 .81213 L F
.36782 1.26218 m .33442 1.18667 L .32638 1.20759 L .845 .109 .593 r
F
.37443 1.23579 m .33442 1.18667 L .36782 1.26218 L .847 .114 .596 r
F
.55179 .80496 m .56387 .80753 L .56466 .80411 L .757 .668 .863 r
F
.55179 .80496 m .55122 .8075 L .56387 .80753 L F
.51316 .80695 m .50682 .8127 L .50845 .81297 L .744 .65 .863 r
F
.51316 .80695 m .51316 .80695 L .50845 .81297 L F
.41322 1.10364 m .38197 1.082 L .4069 1.12123 L .81 .17 .649 r
F
.41322 1.10364 m .3897 1.06988 L .38197 1.082 L F
.477 .81552 m .47543 .81309 L .46288 .815 L .737 .636 .862 r
F
.48903 .81269 m .47543 .81309 L .477 .81552 L .74 .642 .863 r
F
.49054 .81419 m .48903 .81269 L .477 .81552 L .743 .645 .862 r
F
.56383 .50845 m .58825 .49804 L .56416 .50679 L 1 .61 .645 r
F
.56383 .50845 m .58778 .50003 L .58825 .49804 L F
.56153 .51982 m .58778 .50003 L .56383 .50845 L 1 .598 .65 r
F
.56153 .51982 m .58443 .51362 L .58778 .50003 L F
.56486 1.08666 m .54487 1.09358 L .56878 1.10134 L .646 .303 .778 r
F
.56486 1.08666 m .54266 1.08385 L .54487 1.09358 L F
.45034 .81677 m .44891 .81248 L .43607 .81315 L .711 .6 .862 r
F
.46288 .815 m .44891 .81248 L .45034 .81677 L .725 .62 .862 r
F
.51316 .80695 m .52027 .81162 L .52166 .81103 L .742 .648 .864 r
F
.51316 .80695 m .51316 .80695 L .52027 .81162 L F
.5028 .81124 m .50183 .81057 L .49054 .81419 L .744 .649 .863 r
F
.50183 .81057 m .48903 .81269 L .49054 .81419 L .743 .647 .863 r
F
.55804 .53574 m .58443 .51363 L .56153 .51982 L 1 .593 .664 r
F
.53225 .56707 m .55104 .5629 L .55454 .55007 L 1 .77 .734 r
F
.51316 .80695 m .50532 .81232 L .50682 .8127 L .744 .65 .864 r
F
.51316 .80695 m .51316 .80695 L .50682 .8127 L .744 .65 .863 r
F
.59016 .79667 m .60318 .79995 L .60299 .794 L .83 .75 .858 r
F
.59016 .79667 m .59035 .80172 L .60318 .79995 L F
.51316 .80695 m .52166 .81103 L .52289 .81035 L .742 .648 .864 r
F
.51316 .80695 m .51316 .80695 L .52166 .81103 L F
.51316 .80695 m .50397 .81183 L .50532 .81232 L .743 .649 .864 r
F
.51316 .80695 m .51316 .80695 L .50532 .81232 L .744 .65 .864 r
F
.38485 .81177 m .38421 .80571 L .3713 .8049 L .508 .311 .898 r
F
.39763 .81293 m .38421 .80571 L .38485 .81177 L .567 .427 .888 r
F
.36119 1.28928 m .32638 1.20759 L .31832 1.2291 L .842 .105 .59 r
F
.36782 1.26218 m .32638 1.20759 L .36119 1.28928 L .845 .109 .593 r
F
.39813 1.05871 m .3777 1.02091 L .39741 1.05958 L .48 .041 .673 r
F
.39813 1.05871 m .37853 1.02077 L .3777 1.02091 L F
.52586 .80718 m .53771 .80905 L .53855 .80737 L .745 .653 .864 r
F
.52586 .80718 m .52544 .80802 L .53771 .80905 L F
.31521 .59063 m .33707 .51574 L .32742 .50481 L 1 .374 .596 r
F
.32644 .58668 m .33707 .51574 L .31521 .59063 L 1 .423 .613 r
F
.51316 .80695 m .52289 .81035 L .52395 .80962 L .742 .648 .864 r
F
.51316 .80695 m .51316 .80695 L .52289 .81035 L F
.40681 .38005 m .44029 .42588 L .43677 .40198 L .287 0 .591 r
F
.41192 .4052 m .44029 .42588 L .40681 .38005 L .28 0 .59 r
F
.46288 .815 m .46175 .81159 L .44891 .81248 L .725 .62 .862 r
F
.47543 .81309 m .46175 .81159 L .46288 .815 L .733 .632 .863 r
F
.53892 .80569 m .55122 .8075 L .55179 .80496 L .749 .658 .864 r
F
.53892 .80569 m .53855 .80737 L .55122 .8075 L F
.4712 1.09303 m .44706 1.09177 L .44398 1.10206 L 1 .528 .688 r
F
.47414 1.08143 m .44706 1.09176 L .4712 1.09303 L 1 .518 .707 r
F
.49725 1.07967 m .47414 1.08143 L .4712 1.09303 L 1 .656 .743 r
F
.51316 .80695 m .5028 .81124 L .50397 .81183 L .743 .649 .864 r
F
.51316 .80695 m .51316 .80695 L .50397 .81183 L F
.51949 1.07221 m .49725 1.07967 L .52 1.07996 L .835 .585 .809 r
F
.54044 1.07367 m .52 1.07996 L .54266 1.08385 L .699 .464 .819 r
F
.54044 1.07367 m .51949 1.07221 L .52 1.07996 L F
.40321 1.05296 m .37854 1.02077 L .39813 1.05871 L .459 .045 .693 r
F
.40321 1.05296 m .3844 1.02016 L .37854 1.02077 L F
.57733 .7989 m .59035 .80172 L .59016 .79667 L .795 .713 .862 r
F
.57733 .7989 m .57751 .80306 L .59035 .80172 L F
.51306 .5793 m .53225 .56707 L .51305 .57386 L 1 .83 .804 r
F
.48903 .81269 m .488 .81109 L .47543 .81309 L .74 .642 .863 r
F
.50108 .80983 m .488 .81109 L .48903 .81269 L .741 .645 .863 r
F
.50183 .81057 m .50108 .80983 L .48903 .81269 L .743 .647 .863 r
F
.51949 1.07221 m .49844 1.07151 L .49725 1.07967 L .835 .585 .809 r
F
.49844 1.07151 m .47414 1.08143 L .49725 1.07967 L 1 .598 .755 r
F
.41951 1.08814 m .3897 1.06988 L .41322 1.10364 L .785 .188 .668 r
F
.41951 1.08814 m .39741 1.05958 L .3897 1.06988 L F
.55504 .35795 m .5988 .27587 L .55682 .33557 L 1 .637 .593 r
F
.55504 .35795 m .59537 .30188 L .5988 .27587 L F
.51316 .80695 m .52395 .80962 L .5248 .80884 L .742 .649 .864 r
F
.51316 .80695 m .51316 .80695 L .52395 .80962 L F
.39763 .81293 m .39711 .80654 L .38421 .80571 L .567 .427 .888 r
F
.41043 .81348 m .39711 .80654 L .39763 .81293 L .616 .496 .878 r
F
.51316 .80695 m .50183 .81057 L .5028 .81124 L .742 .648 .864 r
F
.51316 .80695 m .51316 .80695 L .5028 .81124 L .743 .649 .864 r
F
.47543 .81309 m .4746 .81055 L .46175 .81159 L .733 .632 .863 r
F
.488 .81109 m .4746 .81055 L .47543 .81309 L .738 .64 .863 r
F
.56449 .8008 m .57751 .80306 L .57733 .7989 L .771 .686 .863 r
F
.56449 .8008 m .56466 .80411 L .57751 .80306 L F
.51316 .80695 m .5248 .80884 L .52544 .80802 L .743 .649 .864 r
F
.51316 .80695 m .51316 .80695 L .5248 .80884 L F
.36119 1.28928 m .31832 1.2291 L .35452 1.317 L .842 .105 .59 r
F
.52604 .80635 m .53855 .80737 L .53892 .80569 L .745 .653 .864 r
F
.52604 .80635 m .52586 .80718 L .53855 .80737 L F
.41043 .81348 m .41002 .80725 L .39711 .80654 L .616 .496 .878 r
F
.42324 .81351 m .41002 .80725 L .41043 .81348 L .654 .542 .872 r
F
.51316 .80695 m .51316 .80695 L .50183 .81057 L .742 .648 .864 r
F
.51316 .80695 m .50108 .80983 L .50183 .81057 L .741 .647 .864 r
F
.55166 .80249 m .56466 .80411 L .56449 .8008 L .756 .669 .864 r
F
.55166 .80249 m .55179 .80496 L .56466 .80411 L F
.41192 .4052 m .44382 .44974 L .44029 .42588 L .28 0 .59 r
F
.41704 .42965 m .44382 .44974 L .41192 .4052 L .268 0 .587 r
F
.51316 .80695 m .52544 .80802 L .52586 .80718 L .743 .65 .864 r
F
.51316 .80695 m .51316 .80695 L .52544 .80802 L F
.26055 .55377 m .27975 .43022 L .24975 .5419 L 1 .272 .579 r
F
.26055 .55377 m .28921 .44703 L .27975 .43022 L F
.488 .81109 m .48745 .8094 L .4746 .81055 L .738 .64 .863 r
F
.50057 .80903 m .48745 .8094 L .488 .81109 L .74 .644 .863 r
F
.50108 .80983 m .50057 .80903 L .488 .81109 L .741 .645 .863 r
F
.42324 .81351 m .42292 .80778 L .41002 .80725 L .654 .542 .872 r
F
.43607 .81315 m .42292 .80778 L .42324 .81351 L .684 .575 .867 r
F
.43885 1.12178 m .4069 1.12123 L .43412 1.14307 L 1 .299 .648 r
F
.43885 1.12178 m .41322 1.10364 L .4069 1.12123 L F
.44354 1.10362 m .41322 1.10364 L .43885 1.12178 L 1 .331 .666 r
F
.53403 .55772 m .55454 .55007 L .55804 .53574 L 1 .792 .712 r
F
.53225 .56707 m .55454 .55007 L .53403 .55772 L 1 .77 .734 r
F
.51316 .80695 m .50057 .80903 L .50108 .80983 L .741 .647 .864 r
F
.51316 .80695 m .51316 .80695 L .50108 .80983 L F
.59602 1.11787 m .57174 1.11307 L .57567 1.12939 L .618 .12 .686 r
F
.53882 .80404 m .55179 .80496 L .55166 .80249 L .748 .658 .865 r
F
.53882 .80404 m .53892 .80569 L .55179 .80496 L F
.64055 .53548 m .6716 .60743 L .64878 .52494 L .733 .04 .554 r
F
.64055 .53548 m .66227 .62738 L .6716 .60743 L F
.55326 .37989 m .59537 .30188 L .55504 .35795 L 1 .644 .596 r
F
.55326 .37989 m .59193 .32748 L .59537 .30188 L F
.43412 1.14307 m .40054 1.14081 L .42935 1.16749 L 1 .265 .633 r
F
.43412 1.14307 m .4069 1.12123 L .40054 1.14081 L F
.43607 .81315 m .43583 .80809 L .42292 .80778 L .684 .575 .867 r
F
.44891 .81248 m .43583 .80809 L .43607 .81315 L .706 .6 .865 r
F
.27137 .56492 m .28921 .44703 L .26055 .55377 L 1 .283 .58 r
F
.27137 .56492 m .29871 .46311 L .28921 .44703 L F
.51316 .80695 m .52586 .80718 L .52604 .80635 L .743 .65 .864 r
F
.51316 .80695 m .51316 .80695 L .52586 .80718 L F
.42935 1.1675 m .40054 1.14082 L .39406 1.1625 L 1 .232 .621 r
F
.43762 .50837 m .45781 .54971 L .43242 .49417 L .06 0 .48 r
F
.43762 .50837 m .46122 .58317 L .45781 .54971 L F
.68152 1.12847 m .66214 1.22366 L .69031 1.15089 L 1 .242 .586 r
F
.68152 1.12847 m .65472 1.19823 L .66214 1.22366 L F
.44891 .81248 m .44873 .8082 L .43583 .80809 L .706 .6 .865 r
F
.46175 .81159 m .44873 .8082 L .44891 .81248 L .721 .619 .864 r
F
.52599 .80552 m .53892 .80569 L .53882 .80404 L .745 .653 .864 r
F
.52599 .80552 m .52604 .80635 L .53892 .80569 L F
.44354 1.10362 m .41951 1.08814 L .41322 1.10364 L 1 .331 .666 r
F
.44398 1.10206 m .41951 1.08814 L .44355 1.10361 L 1 .338 .676 r
F
.50057 .80903 m .5003 .8082 L .48745 .8094 L .74 .644 .863 r
F
.51316 .80695 m .5003 .8082 L .50057 .80903 L .741 .646 .864 r
F
.51316 .80695 m .51316 .80695 L .50057 .80903 L .741 .647 .864 r
F
.28222 .57501 m .30824 .47826 L .29871 .46311 L 1 .297 .582 r
F
.4201 1.0868 m .39741 1.05958 L .41951 1.08814 L .752 .181 .676 r
F
.4201 1.0868 m .39813 1.05871 L .39741 1.05958 L F
.28222 .57501 m .29871 .46311 L .27137 .56492 L 1 .297 .582 r
F
.44398 1.10206 m .4201 1.0868 L .41951 1.08814 L 1 .338 .676 r
F
.44706 1.09177 m .4201 1.08679 L .44398 1.10206 L .999 .355 .684 r
F
.56094 1.07315 m .54266 1.08385 L .56486 1.08666 L .783 .408 .768 r
F
.56094 1.07315 m .54044 1.07367 L .54266 1.08385 L F
.70609 .40262 m .74831 .48729 L .71421 .38287 L .748 .064 .581 r
F
.51305 .57386 m .53225 .56707 L .53403 .55772 L 1 .935 .789 r
F
.46175 .81159 m .46162 .80814 L .44873 .8082 L .721 .619 .864 r
F
.4746 .81055 m .46162 .80814 L .46175 .81159 L .731 .631 .863 r
F
.42424 1.07783 m .39813 1.05871 L .4201 1.08679 L .75 .202 .688 r
F
.42424 1.07783 m .40321 1.05296 L .39813 1.05871 L F
.4746 .81055 m .47452 .80796 L .46162 .80814 L .731 .631 .863 r
F
.48745 .8094 m .47452 .80796 L .4746 .81055 L .737 .639 .863 r
F
.51316 .80695 m .52604 .80635 L .52599 .80552 L .743 .65 .864 r
F
.51316 .80695 m .51316 .80695 L .52604 .80635 L F
.47414 1.08143 m .45172 1.07803 L .44706 1.09176 L 1 .518 .707 r
F
.47708 1.0707 m .45172 1.07803 L .47414 1.08143 L 1 .513 .727 r
F
.49844 1.07151 m .47708 1.0707 L .47414 1.08143 L 1 .598 .755 r
F
.41704 .42965 m .44735 .47368 L .44382 .44974 L .268 0 .587 r
F
.42219 .45316 m .44735 .47368 L .41704 .42965 L .246 0 .579 r
F
.48745 .8094 m .4874 .80768 L .47452 .80796 L .737 .639 .863 r
F
.5003 .8082 m .4874 .80768 L .48745 .8094 L .74 .644 .864 r
F
.42447 1.19503 m .39406 1.1625 L .38755 1.18574 L .998 .203 .612 r
F
.42935 1.1675 m .39406 1.1625 L .42447 1.19503 L 1 .232 .621 r
F
.41091 1.04543 m .3844 1.02016 L .40321 1.05296 L .424 .054 .73 r
F
.41091 1.04543 m .39332 1.01997 L .3844 1.02016 L F
.5003 .8082 m .50028 .80733 L .4874 .80768 L .74 .644 .864 r
F
.51315 .80695 m .50028 .80733 L .5003 .8082 L .741 .646 .864 r
F
.51316 .80695 m .51315 .80695 L .5003 .8082 L F
.59549 1.11576 m .57174 1.11306 L .59602 1.11787 L .627 .131 .69 r
F
.59549 1.11576 m .57137 1.11158 L .57174 1.11306 L F
.64386 1.00364 m .63988 .99278 L .65447 1.0029 L .294 0 .049 r
F
.65496 1.00704 m .64386 1.00364 L .65447 1.0029 L .29 0 0 r
F
.65464 1.00691 m .64386 1.00364 L .65496 1.00704 L .121 0 .712 r
F
.64386 1.00364 m .63295 1.00032 L .63988 .99278 L .294 0 .049 r
F
.64325 1.00257 m .64386 1.00364 L .65464 1.00691 L .121 0 .712 r
F
.64386 1.00364 m .63058 1.00291 L .63295 1.00032 L .294 0 .049 r
F
.51315 .80695 m .51315 .80695 L .50028 .80733 L .741 .646 .864 r
F
.51316 .80695 m .51316 .80695 L .52599 .80552 L .743 .65 .864 r
F
.51315 .80695 m .50052 .80647 L .50028 .80733 L .741 .646 .864 r
F
.51315 .80695 m .51316 .80695 L .50052 .80647 L F
.51316 .80695 m .52599 .80552 L .5257 .80472 L .743 .65 .864 r
F
.51316 .80695 m .51316 .80695 L .5257 .80472 L .743 .649 .864 r
F
.51316 .80695 m .501 .80561 L .50052 .80647 L .741 .647 .864 r
F
.51316 .80695 m .51316 .80695 L .501 .80561 L F
.51316 .80695 m .5257 .80472 L .5252 .80399 L .743 .649 .864 r
F
.51316 .80695 m .51316 .80695 L .5252 .80399 L F
.51316 .80695 m .50171 .80478 L .501 .80561 L .742 .647 .864 r
F
.51316 .80695 m .51316 .80695 L .50171 .80478 L F
.51316 .80695 m .5252 .80399 L .52451 .80331 L .743 .649 .864 r
F
.51316 .80695 m .51316 .80695 L .52451 .80331 L .742 .648 .864 r
F
.51316 .80695 m .50263 .80401 L .50171 .80478 L .742 .647 .864 r
F
.51316 .80695 m .51316 .80695 L .50263 .80401 L F
.51316 .80695 m .52451 .80331 L .52362 .8027 L .742 .648 .864 r
F
.51316 .80695 m .51316 .80695 L .52362 .8027 L .741 .647 .864 r
F
.51316 .80695 m .50374 .80329 L .50263 .80401 L .742 .648 .864 r
F
.51316 .80695 m .51316 .80695 L .50374 .80329 L F
.51316 .80695 m .52362 .8027 L .52255 .80215 L .741 .647 .864 r
F
.51316 .80695 m .51316 .80695 L .52255 .80215 L F
.51316 .80695 m .50502 .80265 L .50374 .80329 L .742 .648 .864 r
F
.51316 .80695 m .51316 .80695 L .50502 .80265 L F
.51316 .80695 m .52255 .80215 L .52127 .80167 L .741 .647 .864 r
F
.51316 .80695 m .51316 .80695 L .52127 .80167 L .74 .646 .864 r
F
.51316 .80695 m .50646 .80208 L .50502 .80265 L .742 .648 .864 r
F
.51316 .80695 m .51316 .80695 L .50646 .80208 L F
.51316 .80695 m .52127 .80167 L .51983 .80128 L .74 .646 .864 r
F
.51316 .80695 m .51316 .80695 L .51983 .80128 L F
.51316 .80695 m .50802 .80161 L .50646 .80208 L .742 .648 .864 r
F
.51316 .80695 m .51316 .80695 L .50802 .80161 L F
.51316 .80695 m .51983 .80128 L .51827 .80099 L .74 .646 .864 r
F
.51316 .80695 m .51316 .80695 L .51827 .80099 L F
.51316 .80695 m .50968 .80123 L .50802 .80161 L .742 .648 .864 r
F
.51316 .80695 m .51316 .80695 L .50968 .80123 L F
.51316 .80695 m .51827 .80099 L .51662 .80081 L .74 .646 .864 r
F
.51316 .80695 m .51316 .80695 L .51662 .80081 L F
.51316 .80695 m .5114 .80096 L .50968 .80123 L .741 .647 .864 r
F
.51316 .80695 m .51316 .80695 L .5114 .80096 L F
.51316 .80695 m .51662 .80081 L .5149 .80075 L .74 .646 .864 r
F
.51316 .80695 m .51316 .80695 L .5149 .80075 L .74 .647 .864 r
F
.51316 .80695 m .51315 .8008 L .5114 .80096 L .741 .647 .864 r
F
.51316 .80695 m .51316 .80695 L .51315 .8008 L F
.51316 .80695 m .5149 .80075 L .51315 .8008 L .74 .647 .864 r
F
.59177 1.10143 m .57137 1.11158 L .59549 1.11575 L .719 .19 .693 r
F
.59177 1.10143 m .56879 1.10134 L .57137 1.11158 L F
.44706 1.09177 m .42424 1.07783 L .4201 1.08679 L .999 .355 .684 r
F
.45172 1.07803 m .42424 1.07782 L .44706 1.09176 L .967 .381 .703 r
F
.55147 .40134 m .59193 .32748 L .55326 .37989 L 1 .651 .6 r
F
.55147 .40134 m .58848 .35264 L .59193 .32748 L F
.70609 .40262 m .7387 .50233 L .74831 .48729 L .748 .064 .581 r
F
.69795 .42201 m .7387 .50233 L .70609 .40262 L .746 .064 .581 r
F
.5257 .80472 m .52599 .80552 L .53882 .80404 L .744 .652 .864 r
F
.60114 .78894 m .6158 .79071 L .61373 .78527 L .833 .766 .864 r
F
.60114 .78894 m .60299 .794 L .6158 .79071 L F
.53825 .80245 m .53882 .80404 L .55166 .80249 L .747 .657 .865 r
F
.5257 .80472 m .53882 .80404 L .53825 .80245 L .744 .652 .864 r
F
.50028 .80733 m .48786 .80594 L .4874 .80768 L .74 .644 .864 r
F
.50028 .80733 m .50052 .80647 L .48786 .80594 L F
.42219 .45316 m .45088 .49797 L .44735 .47368 L .246 0 .579 r
F
.42729 .47492 m .45088 .49798 L .42219 .45316 L .208 0 .564 r
F
.55081 .80012 m .55166 .80249 L .56449 .8008 L .753 .667 .865 r
F
.53825 .80245 m .55166 .80249 L .55081 .80012 L .747 .657 .865 r
F
.53582 .54754 m .55804 .53574 L .56153 .51982 L 1 .791 .69 r
F
.53403 .55772 m .55804 .53574 L .53582 .54754 L 1 .792 .712 r
F
.58855 .79217 m .60299 .794 L .60114 .78894 L .805 .735 .865 r
F
.58855 .79217 m .59016 .79667 L .60299 .794 L F
.64878 .52494 m .68102 .59108 L .65695 .51087 L .729 .048 .568 r
F
.64878 .52494 m .6716 .60743 L .68102 .59108 L F
.56338 .79768 m .56449 .8008 L .57733 .7989 L .765 .683 .866 r
F
.55081 .80012 m .56449 .8008 L .56338 .79768 L .753 .667 .865 r
F
.69031 1.15089 m .66958 1.24985 L .69912 1.17343 L 1 .233 .585 r
F
.69031 1.15089 m .66214 1.22366 L .66958 1.24985 L F
.69795 .42201 m .72908 .51719 L .7387 .50233 L .746 .064 .581 r
F
.68979 .441 m .72908 .51719 L .69795 .42201 L .744 .063 .582 r
F
.57596 .79506 m .59016 .79667 L .58855 .79217 L .782 .706 .865 r
F
.57596 .79506 m .57733 .7989 L .59016 .79667 L F
.5252 .80399 m .5257 .80472 L .53825 .80245 L .743 .651 .865 r
F
.56338 .79768 m .57733 .7989 L .57596 .79506 L .765 .683 .866 r
F
.41955 1.22465 m .38755 1.18574 L .38101 1.21025 L .973 .18 .604 r
F
.42447 1.19503 m .38755 1.18574 L .41955 1.22465 L .998 .203 .612 r
F
.43242 .49417 m .45435 .52279 L .42729 .47492 L .144 0 .534 r
F
.43242 .49417 m .45781 .54971 L .45435 .52279 L F
.51897 1.0633 m .49844 1.07151 L .51949 1.07221 L .87 .558 .79 r
F
.53821 1.06329 m .51949 1.07221 L .54044 1.07367 L .814 .513 .794 r
F
.53821 1.06329 m .51897 1.0633 L .51949 1.07221 L F
.58616 1.08214 m .56878 1.10134 L .59177 1.10143 L .849 .285 .698 r
F
.58616 1.08214 m .56486 1.08666 L .56878 1.10134 L F
.4874 .80768 m .47519 .80536 L .47452 .80796 L .736 .639 .864 r
F
.4874 .80768 m .48786 .80594 L .47519 .80536 L F
.4305 1.06579 m .40321 1.05296 L .42424 1.07782 L .732 .235 .713 r
F
.4305 1.06579 m .41091 1.04543 L .40321 1.05296 L F
.51897 1.0633 m .49964 1.0625 L .49844 1.07151 L .87 .558 .79 r
F
.49964 1.0625 m .47708 1.0707 L .49844 1.07151 L .965 .559 .762 r
F
.42729 .47492 m .45435 .52279 L .45088 .49798 L .208 0 .564 r
F
.50052 .80647 m .48881 .80423 L .48786 .80594 L .739 .644 .864 r
F
.50052 .80647 m .501 .80561 L .48881 .80423 L F
.54968 .4222 m .58848 .35264 L .55147 .40134 L 1 .66 .604 r
F
.54968 .4222 m .58502 .37727 L .58848 .35264 L F
.68979 .441 m .71947 .53189 L .72908 .51719 L .744 .063 .582 r
F
.68161 .45953 m .71947 .53189 L .68979 .441 L .741 .063 .582 r
F
.45172 1.07803 m .4305 1.06579 L .42424 1.07782 L .967 .381 .703 r
F
.5252 .80399 m .53825 .80245 L .53727 .80101 L .743 .651 .865 r
F
.52451 .80331 m .5252 .80399 L .53727 .80101 L .742 .649 .865 r
F
.47452 .80796 m .46251 .80471 L .46162 .80814 L .73 .632 .864 r
F
.47452 .80796 m .47519 .80536 L .46251 .80471 L F
.65695 .51087 m .69062 .57582 L .6652 .49473 L .732 .055 .575 r
F
.65695 .51087 m .68103 .59108 L .69062 .57582 L F
.53727 .80101 m .53825 .80245 L .55081 .80012 L .744 .655 .865 r
F
.501 .80561 m .49024 .80257 L .48881 .80423 L .739 .644 .864 r
F
.501 .80561 m .50171 .80478 L .49024 .80257 L F
.68161 .45953 m .70985 .54649 L .71947 .53189 L .741 .063 .582 r
F
.67341 .4775 m .70985 .54649 L .68161 .45953 L .738 .061 .581 r
F
.46162 .80814 m .44981 .80399 L .44873 .8082 L .72 .621 .865 r
F
.46162 .80814 m .46251 .80471 L .44981 .80399 L F
.52451 .80331 m .53727 .80101 L .53588 .79967 L .742 .649 .865 r
F
.52362 .8027 m .52451 .80331 L .53588 .79967 L .74 .647 .865 r
F
.45638 1.06609 m .4305 1.06579 L .45172 1.07803 L .921 .406 .726 r
F
.47708 1.0707 m .45638 1.06609 L .45172 1.07803 L 1 .513 .727 r
F
.6652 .49473 m .70023 .56107 L .67341 .4775 L .735 .059 .579 r
F
.6652 .49473 m .69062 .57582 L .70023 .56107 L F
.67341 .4775 m .70023 .56107 L .70985 .54649 L .738 .061 .581 r
F
.73967 .82687 m .74115 .77515 L .75452 .78183 L .877 0 .327 r
F
.51305 .57386 m .53403 .55772 L .51304 .56946 L 1 .935 .789 r
F
.53582 .54754 m .56153 .51982 L .5376 .53616 L 1 .791 .69 r
F
.5376 .53616 m .56153 .51982 L .56383 .50845 L 1 .787 .672 r
F
.48786 .80594 m .47661 .80281 L .47519 .80536 L .736 .64 .864 r
F
.48786 .80594 m .48881 .80423 L .47661 .80281 L F
.4146 1.25569 m .38101 1.21025 L .37443 1.23579 L .952 .161 .598 r
F
.41955 1.22465 m .38101 1.21025 L .4146 1.25569 L .973 .18 .604 r
F
.50171 .80478 m .49207 .80103 L .49025 .80257 L .739 .644 .864 r
F
.50171 .80478 m .50263 .80401 L .49207 .80103 L F
.44873 .8082 m .43709 .80317 L .43583 .80809 L .704 .605 .868 r
F
.44873 .8082 m .44981 .80399 L .43709 .80317 L F
.54789 .44238 m .58502 .37727 L .54968 .4222 L 1 .671 .609 r
F
.54789 .44238 m .58154 .4013 L .58502 .37727 L F
.69912 1.17343 m .67706 1.27671 L .70795 1.19616 L 1 .226 .584 r
F
.69912 1.17343 m .66958 1.24985 L .67706 1.27671 L F
.55701 1.06088 m .54044 1.07367 L .56094 1.07315 L .875 .477 .763 r
F
.55701 1.06088 m .53821 1.06329 L .54044 1.07367 L F
.54935 .79799 m .55081 .80012 L .56338 .79768 L .748 .662 .866 r
F
.53727 .80101 m .55081 .80012 L .54935 .79799 L .744 .655 .865 r
F
.52362 .8027 m .53588 .79967 L .53411 .79846 L .74 .647 .865 r
F
.52255 .80215 m .52362 .8027 L .53411 .79846 L .738 .645 .865 r
F
.48003 1.06048 m .45638 1.06609 L .47708 1.0707 L .972 .508 .745 r
F
.49964 1.0625 m .48003 1.06048 L .47708 1.0707 L .965 .559 .762 r
F
.58058 1.06625 m .56486 1.08666 L .58616 1.08214 L .946 .376 .707 r
F
.58058 1.06625 m .56094 1.07315 L .56486 1.08666 L F
.43583 .80809 m .42436 .80228 L .42292 .80778 L .683 .583 .872 r
F
.43583 .80809 m .43709 .80317 L .42436 .80228 L F
.53588 .79967 m .53727 .80101 L .54935 .79799 L .741 .651 .866 r
F
.50263 .80401 m .49429 .79961 L .49207 .80103 L .739 .644 .864 r
F
.50263 .80401 m .50374 .80329 L .49429 .79961 L F
.52255 .80215 m .53411 .79846 L .53198 .79738 L .738 .645 .865 r
F
.52127 .80167 m .52255 .80215 L .53198 .79738 L .736 .644 .865 r
F
.5376 .53616 m .56383 .50845 L .53878 .52786 L 1 .787 .672 r
F
.53878 .52785 m .56383 .50845 L .56416 .50679 L 1 .788 .664 r
F
.42292 .80778 m .41162 .80134 L .41002 .80725 L .656 .554 .877 r
F
.42292 .80778 m .42436 .80228 L .41162 .80134 L F
.53878 .52785 m .56416 .50679 L .53895 .52662 L 1 .788 .664 r
F
.53895 .52662 m .56416 .50678 L .56763 .48816 L 1 .76 .657 r
F
.51304 .56946 m .53403 .55772 L .53582 .54754 L 1 .987 .761 r
F
.49381 1.16168 m .46563 1.17356 L .46553 1.1729 L 0 0 0 r
F
.49497 1.16539 m .46563 1.17356 L .49381 1.16168 L .347 0 .749 r
F
.52099 1.17605 m .49382 1.16168 L .52151 1.18626 L .567 0 0 r
F
.50046 1.16519 m .49497 1.16539 L .49382 1.16168 L F
.52099 1.17605 m .49521 1.16549 L .50046 1.16519 L F
.49521 1.16549 m .49497 1.16539 L .50046 1.16519 L F
.49582 1.16439 m .49119 1.16572 L .49508 1.1654 L .589 .268 .879 r
F
.49497 1.16539 m .49268 1.16594 L .49497 1.16539 L .347 0 .749 r
F
.49119 1.16572 m .4807 1.16872 L .49452 1.16553 L .589 .268 .879 r
F
.49119 1.16572 m .49452 1.16553 L .49508 1.1654 L F
.49586 1.16434 m .46878 1.17148 L .4807 1.16872 L F
.49586 1.16434 m .4807 1.16872 L .49582 1.16439 L F
.49497 1.16539 m .47843 1.16937 L .46563 1.17356 L .347 0 .749 r
F
.47843 1.16937 m .46851 1.17176 L .46716 1.1726 L F
.47843 1.16937 m .46716 1.1726 L .46563 1.17356 L F
.49268 1.16594 m .46851 1.17176 L .49497 1.16539 L F
.52095 1.17518 m .49497 1.16539 L .52099 1.17605 L 0 0 .642 r
F
.52095 1.17518 m .49508 1.1654 L .49497 1.16539 L F
.49508 1.1654 m .46856 1.17175 L .49497 1.16539 L .514 .052 .842 r
F
.46856 1.17175 m .46851 1.17176 L .47891 1.16926 L F
.46856 1.17175 m .47891 1.16926 L .49497 1.16539 L F
.46851 1.17176 m .46573 1.17424 L .46563 1.17356 L 1 .976 .748 r
F
.46573 1.17424 m .43797 1.19901 L .46563 1.17356 L F
.46553 1.1729 m .46563 1.17356 L .46277 1.17399 L 0 0 0 r
F
.54609 .46174 m .58154 .4013 L .54789 .44238 L 1 .683 .615 r
F
.54609 .46174 m .57806 .4246 L .58154 .4013 L F
.56145 .79491 m .56338 .79768 L .57596 .79506 L .753 .672 .868 r
F
.54935 .79799 m .56338 .79768 L .56145 .79491 L .748 .662 .866 r
F
.50374 .80329 m .49686 .79832 L .49429 .79961 L .738 .644 .864 r
F
.50374 .80329 m .50502 .80265 L .49686 .79832 L F
.41002 .80725 m .39886 .80046 L .39711 .80654 L .625 .515 .884 r
F
.41002 .80725 m .41162 .80134 L .39886 .80046 L F
.43676 1.05536 m .41091 1.04543 L .4305 1.06579 L .709 .275 .74 r
F
.45638 1.06609 m .43676 1.05536 L .4305 1.06579 L .921 .406 .726 r
F
.47519 .80536 m .46438 .80135 L .46251 .80471 L .73 .634 .865 r
F
.47519 .80536 m .47661 .80281 L .46438 .80135 L F
.52127 .80167 m .53198 .79738 L .52941 .79641 L .736 .644 .865 r
F
.51983 .80128 m .52127 .80167 L .52941 .79641 L .735 .642 .866 r
F
.48881 .80423 m .47875 .80034 L .47661 .80281 L .736 .641 .864 r
F
.48881 .80423 m .49024 .80257 L .47875 .80034 L F
.39711 .80654 m .38609 .79978 L .38421 .80571 L .59 .458 .892 r
F
.39711 .80654 m .39886 .80046 L .38609 .79978 L F
.38421 .80571 m .37329 .79954 L .3713 .8049 L .553 .365 .898 r
F
.38421 .80571 m .38609 .79978 L .37329 .79954 L F
.50502 .80265 m .49974 .79719 L .49686 .79832 L .738 .644 .864 r
F
.50502 .80265 m .50646 .80208 L .49974 .79719 L F
.41862 1.03894 m .39332 1.01997 L .41091 1.04543 L .423 .087 .769 r
F
.43676 1.05536 m .41862 1.03894 L .41091 1.04543 L .709 .275 .74 r
F
.51983 .80128 m .52941 .79641 L .52653 .79564 L .735 .642 .866 r
F
.51827 .80099 m .51983 .80128 L .52653 .79564 L .734 .642 .866 r
F
.54429 .48009 m .57806 .4246 L .54609 .46174 L 1 .698 .622 r
F
.54429 .48009 m .57456 .44706 L .57806 .4246 L F
.54073 .51258 m .56763 .48816 L .5711 .4682 L 1 .737 .643 r
F
.53895 .52662 m .56763 .48816 L .54073 .51258 L 1 .76 .657 r
F
.3713 .8049 m .36045 .80004 L .35838 .80432 L .514 .212 .894 r
F
.3713 .8049 m .37329 .79954 L .36045 .80004 L F
.53588 .79967 m .54935 .79799 L .54728 .79602 L .741 .651 .866 r
F
.53411 .79846 m .53588 .79967 L .54728 .79602 L .736 .646 .866 r
F
.40961 1.28768 m .37443 1.23579 L .36782 1.26218 L .934 .147 .594 r
F
.4146 1.25569 m .37443 1.23579 L .40961 1.28768 L .952 .161 .598 r
F
.57357 .79172 m .57596 .79506 L .58855 .79217 L .761 .686 .869 r
F
.56145 .79491 m .57596 .79506 L .57357 .79172 L .753 .672 .868 r
F
.50646 .80208 m .50286 .79625 L .49974 .79719 L .738 .644 .865 r
F
.50646 .80208 m .50802 .80161 L .50286 .79625 L F
.41862 1.03894 m .40228 1.01961 L .39332 1.01997 L .423 .087 .769 r
F
.70795 1.19616 m .68457 1.30419 L .7168 1.21914 L 1 .22 .583 r
F
.70795 1.19616 m .67706 1.27671 L .68457 1.30419 L F
.35838 .80432 m .34756 .80169 L .34545 .80422 L .452 .037 .854 r
F
.35838 .80432 m .36045 .80004 L .34756 .80169 L F
.62112 1.0078 m .60731 1.02036 L .61557 1.01838 L .819 .431 .803 r
F
.61557 1.01839 m .59893 1.04785 L .60601 1.0615 L 1 .431 .639 r
F
.60731 1.02036 m .59893 1.04785 L .61557 1.01839 L 1 .621 .702 r
F
.51827 .80099 m .52653 .79564 L .52341 .79506 L .734 .642 .866 r
F
.51662 .80081 m .51827 .80099 L .52341 .79506 L F
.54251 .49702 m .57456 .44706 L .54429 .4801 L 1 .716 .631 r
F
.54251 .49702 m .5711 .4682 L .57456 .44706 L F
.54073 .51258 m .5711 .4682 L .54251 .49702 L 1 .737 .643 r
F
.54728 .79602 m .54935 .79799 L .56145 .79491 L .74 .654 .867 r
F
.50802 .80161 m .50618 .7955 L .50286 .79625 L .737 .643 .865 r
F
.50802 .80161 m .50968 .80123 L .50618 .7955 L F
.46103 1.05544 m .43676 1.05536 L .45638 1.06609 L .878 .43 .747 r
F
.48003 1.06048 m .46103 1.05544 L .45638 1.06609 L .972 .508 .745 r
F
.48885 1.2534 m .45362 1.24272 L .4504 1.28256 L 1 .178 .576 r
F
.51662 .80081 m .52341 .79506 L .52009 .7947 L .734 .642 .866 r
F
.5149 .80075 m .51662 .80081 L .52009 .7947 L .735 .642 .865 r
F
.34545 .80422 m .33461 .80492 L .33249 .80485 L .346 0 .741 r
F
.34545 .80422 m .34756 .80169 L .33461 .80492 L F
.50968 .80123 m .50963 .79496 L .50618 .7955 L .737 .643 .865 r
F
.50968 .80123 m .5114 .80096 L .50963 .79496 L F
.46251 .80471 m .45213 .79988 L .44981 .80399 L .72 .624 .867 r
F
.46251 .80471 m .46438 .80135 L .45213 .79988 L F
.5149 .80075 m .52009 .7947 L .51665 .79456 L .735 .642 .865 r
F
.51315 .8008 m .5149 .80075 L .51665 .79456 L F
.48885 1.2534 m .4504 1.28256 L .4875 1.3019 L 1 .178 .576 r
F
.52367 1.28837 m .48886 1.2534 L .48751 1.3019 L .832 .072 .56 r
F
.52311 1.25187 m .48886 1.2534 L .52367 1.28837 L .754 .04 .545 r
F
.5114 .80096 m .51314 .79465 L .50963 .79496 L .736 .643 .865 r
F
.5114 .80096 m .51315 .8008 L .51314 .79465 L F
.51315 .8008 m .51665 .79456 L .51314 .79465 L .735 .642 .865 r
F
.51845 1.05377 m .49964 1.0625 L .51897 1.0633 L .888 .547 .781 r
F
.53597 1.05297 m .51897 1.0633 L .53821 1.06329 L .876 .535 .781 r
F
.53597 1.05297 m .51845 1.05377 L .51897 1.0633 L F
.51845 1.05377 m .50085 1.05304 L .49964 1.0625 L .888 .547 .781 r
F
.50085 1.05304 m .48003 1.06048 L .49964 1.0625 L .924 .54 .768 r
F
.49025 .80257 m .48148 .79805 L .47875 .80034 L .736 .641 .865 r
F
.49025 .80257 m .49207 .80103 L .48148 .79805 L F
.5857 .78838 m .58855 .79217 L .60114 .78893 L .768 .698 .871 r
F
.57357 .79172 m .58855 .79217 L .5857 .78838 L .761 .686 .869 r
F
.7531 .83437 m .75452 .78183 L .76788 .78716 L .841 0 .32 r
F
.73967 .82687 m .75452 .78183 L .7531 .83437 L .877 0 .327 r
F
.57503 1.05344 m .56094 1.07315 L .58058 1.06625 L .999 .455 .721 r
F
.57503 1.05344 m .55701 1.06088 L .56094 1.07315 L F
.53411 .79846 m .54728 .79602 L .54462 .79424 L .736 .646 .866 r
F
.53198 .79738 m .53411 .79846 L .54462 .79424 L .732 .641 .867 r
F
.60601 1.0615 m .59177 1.10143 L .61323 1.08464 L 1 .286 .636 r
F
.60601 1.0615 m .58616 1.08214 L .59177 1.10143 L F
.59893 1.04785 m .58616 1.08214 L .60601 1.0615 L 1 .372 .658 r
F
.33249 .80485 m .32601 .80813 L .32393 .80576 L 0 0 0 r
F
.33249 .80485 m .3346 .80493 L .32601 .80813 L F
.59785 .78485 m .60114 .78893 L .61373 .78527 L .772 .701 .873 r
F
.5857 .78838 m .60114 .78893 L .59785 .78485 L .768 .698 .871 r
F
.47661 .80281 m .46722 .79811 L .46438 .80135 L .73 .636 .865 r
F
.47661 .80281 m .47875 .80034 L .46722 .79811 L F
.59893 1.04785 m .58058 1.06625 L .58616 1.08214 L 1 .372 .658 r
F
.32392 .80576 m .32479 .80866 L .32271 .80592 L 0 0 0 r
F
.32392 .80576 m .32601 .80813 L .32479 .80866 L F
.44981 .80399 m .43985 .7984 L .43709 .80317 L .705 .61 .87 r
F
.44981 .80399 m .45213 .79988 L .43985 .7984 L F
.55309 1.04975 m .53821 1.06329 L .55701 1.06088 L .926 .522 .762 r
F
.55309 1.04975 m .53597 1.05297 L .53821 1.06329 L F
.5587 .79237 m .56145 .79491 L .57357 .79172 L .738 .657 .87 r
F
.54728 .79602 m .56145 .79491 L .5587 .79237 L .74 .654 .867 r
F
.48299 1.05062 m .46103 1.05544 L .48003 1.06048 L .919 .508 .76 r
F
.50085 1.05304 m .48299 1.05062 L .48003 1.06048 L .924 .54 .768 r
F
.59785 .78485 m .61373 .78527 L .61001 .78112 L .772 .701 .873 r
F
.32271 .80592 m .31165 .81556 L .30968 .8082 L 0 0 0 r
F
.32271 .80592 m .32478 .80866 L .31165 .81556 L F
.49207 .80103 m .4848 .79592 L .48148 .79805 L .736 .641 .865 r
F
.49207 .80103 m .49429 .79961 L .4848 .79592 L F
.44302 1.04616 m .41862 1.03894 L .43676 1.05536 L .701 .323 .765 r
F
.46103 1.05544 m .44302 1.04616 L .43676 1.05536 L .878 .43 .747 r
F
.7168 1.21914 m .69212 1.33224 L .72567 1.24241 L 1 .216 .582 r
F
.7168 1.21914 m .68457 1.30419 L .69212 1.33224 L F
.54462 .79424 m .54728 .79602 L .5587 .79237 L .731 .644 .868 r
F
.40461 1.32033 m .36782 1.26218 L .36119 1.28928 L .919 .137 .591 r
F
.40961 1.28768 m .36782 1.26218 L .40461 1.32033 L .934 .147 .594 r
F
.53198 .79738 m .54462 .79424 L .54143 .79265 L .732 .641 .867 r
F
.52941 .79641 m .53198 .79738 L .54143 .79265 L .728 .637 .867 r
F
.5919 1.03898 m .58058 1.06625 L .59893 1.04785 L 1 .467 .689 r
F
.60731 1.02036 m .5919 1.03898 L .59893 1.04785 L 1 .621 .702 r
F
.5919 1.03898 m .57503 1.05344 L .58058 1.06625 L 1 .467 .689 r
F
.49429 .79961 m .48866 .79399 L .4848 .79592 L .735 .641 .865 r
F
.49429 .79961 m .49686 .79832 L .48866 .79399 L F
.43709 .80317 m .42756 .79693 L .42436 .80228 L .685 .591 .874 r
F
.43709 .80317 m .43985 .7984 L .42756 .79693 L F
.51303 .56561 m .53582 .54754 L .5376 .53616 L 1 .964 .724 r
F
.51304 .56946 m .53582 .54754 L .51303 .56561 L 1 .987 .761 r
F
.30968 .8082 m .29839 .82466 L .2966 .81143 L .088 0 0 r
F
.30968 .8082 m .31165 .81556 L .29839 .82466 L F
.42634 1.03305 m .40228 1.01961 L .41862 1.03894 L .468 .162 .799 r
F
.44302 1.04616 m .42634 1.03305 L .41862 1.03894 L .701 .323 .765 r
F
.52941 .79641 m .54143 .79265 L .53758 .79122 L .728 .637 .867 r
F
.52653 .79564 m .52941 .79641 L .53758 .79122 L .726 .635 .867 r
F
.6332 1.00377 m .63058 1.00291 L .64386 1.00364 L 0 0 0 r
F
.76659 .84177 m .76788 .78716 L .78123 .79164 L .819 0 .317 r
F
.7531 .83437 m .76788 .78716 L .76659 .84177 L .841 0 .32 r
F
.46438 .80135 m .45566 .79591 L .45213 .79988 L .721 .628 .868 r
F
.46438 .80135 m .46722 .79811 L .45566 .79591 L F
.47875 .80034 m .47085 .79509 L .46722 .79811 L .731 .638 .866 r
F
.47875 .80034 m .48148 .79805 L .47085 .79509 L F
.57014 .7887 m .57357 .79172 L .5857 .78838 L .735 .658 .873 r
F
.5587 .79237 m .57357 .79172 L .57014 .7887 L .738 .657 .87 r
F
.46569 1.04571 m .44302 1.04616 L .46103 1.05544 L .845 .455 .765 r
F
.48299 1.05062 m .46569 1.04571 L .46103 1.05544 L .919 .508 .76 r
F
.56949 1.04284 m .55701 1.06088 L .57503 1.05344 L 1 .518 .737 r
F
.56949 1.04284 m .55309 1.04975 L .55701 1.06088 L F
.68384 .77709 m .68932 .76001 L .69838 .7822 L 1 .021 .243 r
F
.49686 .79832 m .49298 .79229 L .48866 .79399 L .736 .641 .865 r
F
.49686 .79832 m .49974 .79719 L .49298 .79229 L F
.55149 1.21929 m .52256 1.22127 L .5538 1.24348 L .662 .081 .633 r
F
.55149 1.21929 m .52203 1.20007 L .52256 1.22127 L F
.5538 1.24348 m .52256 1.22128 L .52311 1.25187 L .72 .067 .596 r
F
.54462 .79424 m .5587 .79237 L .55517 .79007 L .731 .644 .868 r
F
.54143 .79265 m .54462 .79424 L .55517 .79007 L .722 .633 .869 r
F
.54921 1.19886 m .52203 1.20007 L .55149 1.21929 L .632 .147 .7 r
F
.54921 1.19886 m .52151 1.18626 L .52203 1.20007 L F
.52653 .79564 m .53758 .79122 L .53326 .79005 L .726 .635 .867 r
F
.52341 .79506 m .52653 .79564 L .53326 .79005 L .726 .634 .867 r
F
.42436 .80228 m .41523 .79551 L .41162 .80134 L .662 .566 .879 r
F
.42436 .80228 m .42756 .79693 L .41523 .79551 L F
.55517 .79007 m .5587 .79237 L .57014 .7887 L .722 .638 .872 r
F
.39957 1.3535 m .36119 1.28928 L .35452 1.317 L .908 .128 .588 r
F
.40461 1.32033 m .36119 1.28928 L .39957 1.3535 L .919 .137 .591 r
F
.2966 .81143 m .28501 .83557 L .28348 .81547 L .21 0 .006 r
F
.2966 .81143 m .29839 .82466 L .28501 .83557 L F
.51793 1.044 m .50085 1.05304 L .51845 1.05377 L .897 .547 .778 r
F
.53373 1.04285 m .51845 1.05377 L .53597 1.05297 L .906 .55 .777 r
F
.53373 1.04285 m .51793 1.044 L .51845 1.05377 L F
.49974 .79719 m .49768 .79085 L .49298 .79229 L .736 .641 .865 r
F
.49974 .79719 m .50286 .79625 L .49768 .79085 L F
.51793 1.044 m .50206 1.04342 L .50085 1.05304 L .897 .547 .778 r
F
.50206 1.04342 m .48299 1.05062 L .50085 1.05304 L .901 .536 .774 r
F
.66668 1.01235 m .66505 1.00277 L .67842 1.01892 L .532 0 0 r
F
.66668 1.01235 m .65447 1.0029 L .66505 1.00277 L F
.52341 .79506 m .53326 .79005 L .52857 .78917 L .726 .634 .867 r
F
.52009 .7947 m .52341 .79506 L .52857 .78917 L .727 .634 .867 r
F
.4113 1.01835 m .38795 1.00318 L .40228 1.01961 L .218 .01 .822 r
F
.42634 1.03305 m .4113 1.01835 L .40228 1.01961 L .468 .162 .799 r
F
.58161 .78503 m .5857 .78838 L .59785 .78485 L .728 .652 .877 r
F
.57014 .7887 m .5857 .78838 L .58161 .78503 L .735 .658 .873 r
F
.58486 1.03183 m .57503 1.05344 L .5919 1.03898 L 1 .553 .723 r
F
.58486 1.03183 m .56949 1.04284 L .57503 1.05344 L F
.48148 .79805 m .47528 .79227 L .47085 .79509 L .732 .639 .866 r
F
.48148 .79805 m .4848 .79592 L .47528 .79227 L F
.44929 1.0378 m .42634 1.03305 L .44302 1.04616 L .709 .377 .783 r
F
.46569 1.04571 m .44929 1.0378 L .44302 1.04616 L .845 .455 .765 r
F
.50286 .79625 m .50267 .78972 L .49768 .79085 L .736 .641 .865 r
F
.50286 .79625 m .50618 .7955 L .50267 .78972 L F
.41162 .80134 m .40288 .79422 L .39886 .80046 L .639 .536 .885 r
F
.41162 .80134 m .41523 .79551 L .40288 .79422 L F
.45213 .79988 m .44407 .79376 L .43985 .7984 L .708 .617 .871 r
F
.45213 .79988 m .45566 .79591 L .44407 .79376 L F
.52009 .7947 m .52857 .78917 L .52359 .7886 L .727 .634 .867 r
F
.51665 .79456 m .52009 .7947 L .52359 .7886 L .729 .636 .866 r
F
.54915 1.03954 m .53597 1.05297 L .55309 1.04975 L .946 .553 .766 r
F
.54915 1.03954 m .53373 1.04285 L .53597 1.05297 L F
.48595 1.04104 m .46569 1.04571 L .48299 1.05062 L .885 .515 .772 r
F
.50206 1.04342 m .48595 1.04104 L .48299 1.05062 L .901 .536 .774 r
F
.78012 .84911 m .78123 .79164 L .79459 .79555 L .805 0 .316 r
F
.76659 .84177 m .78123 .79164 L .78012 .84911 L .819 0 .317 r
F
.59895 1.01899 m .5919 1.03898 L .60731 1.02036 L 1 .719 .751 r
F
.59895 1.01899 m .58486 1.03183 L .5919 1.03898 L F
.50618 .7955 m .50785 .78892 L .50267 .78972 L .735 .641 .865 r
F
.50618 .7955 m .50963 .79496 L .50785 .78892 L F
.54143 .79265 m .55517 .79007 L .55092 .78801 L .722 .633 .869 r
F
.53758 .79122 m .54143 .79265 L .55092 .78801 L .715 .625 .87 r
F
.51665 .79456 m .52359 .7886 L .51841 .78836 L .729 .636 .866 r
F
.51314 .79465 m .51665 .79456 L .51841 .78836 L .732 .638 .866 r
F
.50963 .79496 m .51313 .78846 L .50785 .78892 L .734 .64 .865 r
F
.50963 .79496 m .51314 .79465 L .51313 .78846 L F
.51314 .79465 m .51841 .78836 L .51313 .78846 L .732 .638 .866 r
F
.46722 .79811 m .46019 .7922 L .45566 .79591 L .724 .633 .868 r
F
.46722 .79811 m .47085 .79509 L .46019 .7922 L F
.4875 1.3019 m .4504 1.28256 L .44716 1.32198 L 1 .155 .576 r
F
.61154 1.00878 m .60731 1.02036 L .62112 1.0078 L .957 .865 .844 r
F
.61154 1.00878 m .59895 1.01899 L .60731 1.02036 L F
.59311 .78135 m .59785 .78485 L .61001 .78112 L .712 .626 .882 r
F
.58161 .78503 m .59785 .78485 L .59311 .78135 L .728 .652 .877 r
F
.28348 .81547 m .27133 .84779 L .27011 .82019 L .306 0 .107 r
F
.28348 .81547 m .28501 .83558 L .27133 .84779 L F
.39886 .80046 m .39051 .79315 L .38609 .79978 L .619 .504 .89 r
F
.39886 .80046 m .40288 .79422 L .39051 .79315 L F
.55616 1.27167 m .52311 1.25187 L .52367 1.28837 L .777 .074 .582 r
F
.5538 1.24348 m .52311 1.25187 L .55616 1.27167 L .72 .067 .596 r
F
.51303 .56561 m .5376 .53616 L .51302 .56117 L 1 .964 .724 r
F
.51302 .56117 m .5376 .53616 L .53878 .52786 L 1 .902 .689 r
F
.54695 1.18187 m .52151 1.18626 L .54921 1.19886 L .679 .297 .762 r
F
.54695 1.18187 m .52099 1.17605 L .52151 1.18626 L F
.56394 1.03359 m .55309 1.04975 L .56949 1.04284 L 1 .564 .753 r
F
.56394 1.03359 m .54915 1.03954 L .55309 1.04975 L F
.56574 .78599 m .57014 .7887 L .58161 .78503 L .708 .626 .876 r
F
.55517 .79007 m .57014 .7887 L .56574 .78599 L .722 .638 .872 r
F
.4848 .79592 m .48043 .78968 L .47528 .79227 L .734 .641 .866 r
F
.4848 .79592 m .48866 .79399 L .48043 .78968 L F
.55092 .78801 m .55517 .79007 L .56574 .78599 L .706 .619 .873 r
F
.47036 1.03659 m .44929 1.0378 L .46569 1.04571 L .828 .48 .779 r
F
.48595 1.04104 m .47036 1.03659 L .46569 1.04571 L .885 .515 .772 r
F
.43409 1.02736 m .4113 1.01835 L .42634 1.03305 L .541 .27 .815 r
F
.44929 1.0378 m .43409 1.02736 L .42634 1.03305 L .709 .377 .783 r
F
.39957 1.3535 m .35452 1.317 L .39451 1.38712 L .908 .128 .588 r
F
.53758 .79122 m .55092 .78801 L .54578 .78614 L .715 .625 .87 r
F
.53326 .79005 m .53758 .79122 L .54578 .78614 L .711 .62 .87 r
F
.43985 .7984 m .43245 .7917 L .42756 .79693 L .69 .6 .875 r
F
.43985 .7984 m .44407 .79376 L .43245 .7917 L F
.79371 .85642 m .79459 .79555 L .80795 .79906 L .796 0 .318 r
F
.78012 .84911 m .79459 .79555 L .79371 .85642 L .805 0 .316 r
F
.59311 .78135 m .61001 .78112 L .60463 .77766 L .712 .626 .882 r
F
.38609 .79978 m .37809 .79249 L .37329 .79954 L .608 .473 .893 r
F
.38609 .79978 m .39051 .79315 L .37809 .79249 L F
.57781 1.02518 m .56949 1.04284 L .58486 1.03183 L 1 .608 .752 r
F
.57781 1.02518 m .56394 1.03359 L .56949 1.04284 L F
.49508 1.1654 m .46878 1.17148 L .46851 1.17176 L .514 .052 .842 r
F
.5206 1.16924 m .49508 1.1654 L .52095 1.17518 L .148 0 .825 r
F
.5206 1.16924 m .49586 1.16434 L .49508 1.1654 L F
.48866 .79399 m .48619 .78737 L .48043 .78968 L .736 .642 .865 r
F
.48866 .79399 m .49298 .79229 L .48619 .78737 L F
.47085 .79509 m .46573 .7887 L .46019 .7922 L .727 .637 .868 r
F
.47085 .79509 m .47528 .79227 L .46573 .7887 L F
.27011 .82019 m .25755 .86043 L .25671 .82532 L .381 0 .175 r
F
.27011 .82019 m .27133 .84779 L .25755 .86043 L F
.51741 1.03423 m .50206 1.04342 L .51793 1.044 L .9 .554 .779 r
F
.53147 1.03302 m .51793 1.044 L .53373 1.04285 L .917 .563 .777 r
F
.53147 1.03302 m .51741 1.03423 L .51793 1.044 L F
.53326 .79005 m .54578 .78614 L .54002 .78457 L .711 .62 .87 r
F
.52857 .78917 m .53326 .79005 L .54002 .78457 L .711 .619 .87 r
F
.51741 1.03423 m .50327 1.0338 L .50206 1.04342 L .9 .554 .779 r
F
.50327 1.0338 m .48595 1.04104 L .50206 1.04342 L .889 .542 .779 r
F
.4113 1.01835 m .3981 1.00601 L .38795 1.00318 L .218 .01 .822 r
F
.45557 1.02997 m .43409 1.02736 L .44929 1.0378 L .731 .431 .795 r
F
.47036 1.03659 m .45557 1.02997 L .44929 1.0378 L .828 .48 .779 r
F
.65496 1.00704 m .65447 1.0029 L .66668 1.01235 L .29 0 0 r
F
.45566 .79591 m .4495 .78942 L .44407 .79376 L .713 .625 .871 r
F
.45566 .79591 m .46019 .7922 L .4495 .78942 L F
.51302 .56117 m .53878 .52786 L .51301 .55732 L 1 .902 .689 r
F
.51301 .55732 m .53878 .52785 L .53895 .52662 L 1 .86 .671 r
F
.4875 1.3019 m .44716 1.32198 L .48616 1.34642 L 1 .155 .576 r
F
.52423 1.32732 m .48751 1.3019 L .48617 1.34642 L .88 .094 .567 r
F
.52367 1.28837 m .48751 1.3019 L .52423 1.32732 L .832 .072 .56 r
F
.57635 .78204 m .58161 .78503 L .59311 .78135 L .688 .601 .882 r
F
.56574 .78599 m .58161 .78503 L .57635 .78204 L .708 .626 .876 r
F
.51301 .55732 m .53895 .52662 L .51301 .5567 L 1 .86 .671 r
F
.51301 .5567 m .53895 .52662 L .54073 .51258 L 1 .854 .665 r
F
.54521 1.03 m .53373 1.04285 L .54915 1.03954 L .946 .573 .772 r
F
.54521 1.03 m .53147 1.03302 L .53373 1.04285 L F
.55092 .78801 m .56574 .78599 L .56044 .78354 L .706 .619 .873 r
F
.54578 .78614 m .55092 .78801 L .56044 .78354 L .694 .603 .874 r
F
.37329 .79954 m .36564 .79248 L .36045 .80004 L .609 .448 .894 r
F
.37329 .79954 m .37809 .79249 L .36564 .79248 L F
.59053 1.0157 m .58486 1.03183 L .59895 1.01899 L 1 .728 .779 r
F
.59053 1.0157 m .57781 1.02518 L .58486 1.03183 L F
.60758 1.18043 m .58429 1.23459 L .61325 1.20256 L 1 .286 .614 r
F
.60758 1.18043 m .58025 1.2109 L .58429 1.23459 L F
.60195 1.16119 m .58025 1.2109 L .60758 1.18043 L 1 .343 .626 r
F
.42756 .79693 m .4208 .78972 L .41523 .79551 L .671 .578 .88 r
F
.42756 .79693 m .43245 .7917 L .4208 .78972 L F
.49298 .79229 m .49247 .78542 L .48619 .78737 L .738 .643 .864 r
F
.49298 .79229 m .49768 .79085 L .49247 .78542 L F
.48893 1.03168 m .47036 1.03659 L .48595 1.04104 L .868 .527 .781 r
F
.50327 1.0338 m .48893 1.03168 L .48595 1.04104 L .889 .542 .779 r
F
.42037 1.01596 m .3981 1.00601 L .4113 1.01835 L .432 .185 .852 r
F
.43409 1.02736 m .42037 1.01596 L .4113 1.01835 L .541 .27 .815 r
F
.60195 1.16119 m .57625 1.19007 L .58025 1.2109 L 1 .343 .626 r
F
.59637 1.14553 m .57625 1.19007 L .60195 1.16119 L 1 .421 .642 r
F
.62247 1.00273 m .62112 1.0078 L .6332 1.00377 L .56 .11 .85 r
F
.62247 1.00273 m .61154 1.00878 L .62112 1.0078 L F
.80735 .8637 m .80795 .79906 L .82132 .80228 L .79 0 .319 r
F
.79371 .85642 m .80795 .79906 L .80735 .8637 L .796 0 .318 r
F
.52857 .78917 m .54002 .78457 L .53375 .78334 L .711 .619 .87 r
F
.52359 .7886 m .52857 .78917 L .53375 .78334 L .716 .623 .868 r
F
.56044 .78354 m .56574 .78599 L .57635 .78204 L .683 .594 .879 r
F
.61325 1.20256 m .58841 1.26122 L .61905 1.22731 L 1 .247 .606 r
F
.61325 1.20256 m .58429 1.2346 L .58841 1.26122 L F
.55837 1.02507 m .54915 1.03954 L .56394 1.03359 L .98 .591 .767 r
F
.55837 1.02507 m .54521 1.03 L .54915 1.03954 L F
.49768 .79085 m .49914 .78387 L .49247 .78542 L .739 .643 .864 r
F
.49768 .79085 m .50267 .78972 L .49914 .78387 L F
.54674 1.18044 m .52099 1.17605 L .54695 1.18187 L .66 .323 .781 r
F
.54674 1.18044 m .52095 1.17518 L .52099 1.17605 L F
.52359 .7886 m .53375 .78334 L .5271 .7825 L .716 .623 .868 r
F
.51841 .78836 m .52359 .7886 L .5271 .7825 L .723 .629 .867 r
F
.47505 1.02785 m .45557 1.02997 L .47036 1.03659 L .824 .506 .788 r
F
.48893 1.03168 m .47505 1.02785 L .47036 1.03659 L .868 .527 .781 r
F
.47528 .79227 m .47216 .78544 L .46573 .7887 L .732 .642 .867 r
F
.47528 .79227 m .48043 .78968 L .47216 .78544 L F
.25671 .82532 m .24371 .87302 L .24326 .83068 L .437 0 .219 r
F
.25671 .82532 m .25755 .86043 L .24371 .87302 L F
.44186 1.0216 m .42037 1.01596 L .43409 1.02736 L .624 .377 .819 r
F
.45557 1.02997 m .44186 1.0216 L .43409 1.02736 L .731 .431 .795 r
F
.54525 1.17101 m .52095 1.17518 L .54674 1.18044 L .755 .444 .791 r
F
.54525 1.17101 m .5206 1.16924 L .52095 1.17518 L F
.59637 1.14553 m .57227 1.1723 L .57625 1.19007 L 1 .421 .642 r
F
.59585 1.14426 m .57227 1.1723 L .59637 1.14552 L 1 .477 .652 r
F
.36045 .80004 m .35313 .79353 L .34756 .80169 L .626 .418 .888 r
F
.36045 .80004 m .36564 .79248 L .35313 .79353 L F
.50267 .78972 m .50606 .78278 L .49914 .78387 L .739 .642 .863 r
F
.50267 .78972 m .50785 .78892 L .50606 .78278 L F
.64892 1.14373 m .6262 1.14241 L .63365 1.17587 L .523 .014 .594 r
F
.55855 1.30293 m .52367 1.28837 L .52423 1.32732 L .829 .088 .578 r
F
.55616 1.27167 m .52367 1.28837 L .55855 1.30293 L .777 .074 .582 r
F
.59585 1.14426 m .5719 1.1708 L .57227 1.1723 L 1 .477 .652 r
F
.60188 1.0072 m .59895 1.01899 L .61154 1.00878 L .95 .835 .838 r
F
.60188 1.0072 m .59053 1.01569 L .59895 1.01899 L F
.59219 1.13641 m .5719 1.17079 L .59585 1.14426 L 1 .516 .661 r
F
.51841 .78836 m .5271 .7825 L .52017 .7821 L .723 .629 .867 r
F
.51313 .78846 m .51841 .78836 L .52017 .7821 L .73 .635 .865 r
F
.50785 .78892 m .51312 .78219 L .50606 .78278 L .736 .64 .864 r
F
.50785 .78892 m .51313 .78846 L .51312 .78219 L F
.51313 .78846 m .52017 .7821 L .51312 .78219 L .73 .635 .865 r
F
.54578 .78614 m .56044 .78354 L .55401 .78126 L .694 .603 .874 r
F
.54002 .78457 m .54578 .78614 L .55401 .78126 L .687 .594 .874 r
F
.58699 .77827 m .59311 .78135 L .60463 .77766 L .66 .554 .888 r
F
.57635 .78204 m .59311 .78135 L .58699 .77827 L .688 .601 .882 r
F
.41523 .79551 m .40911 .78781 L .40288 .79422 L .654 .556 .883 r
F
.41523 .79551 m .4208 .78972 L .40911 .78781 L F
.82104 .87099 m .82132 .80228 L .83471 .80529 L .786 0 .322 r
F
.80735 .8637 m .82132 .80228 L .82104 .87099 L .79 0 .319 r
F
.44407 .79376 m .43877 .78677 L .43245 .7917 L .698 .611 .875 r
F
.44407 .79376 m .4495 .78942 L .43877 .78677 L F
.57073 1.01853 m .56394 1.03359 L .57781 1.02518 L 1 .63 .772 r
F
.57073 1.01853 m .55837 1.02507 L .56394 1.03359 L F
.61905 1.22731 m .59257 1.29008 L .62488 1.2539 L 1 .22 .599 r
F
.61905 1.22731 m .58841 1.26122 L .59257 1.29008 L F
.48616 1.34642 m .44716 1.32198 L .44392 1.36098 L .984 .145 .577 r
F
.513 .54871 m .54073 .51258 L .54251 .49702 L 1 .805 .644 r
F
.51301 .5567 m .54073 .51258 L .513 .54871 L 1 .854 .665 r
F
.46019 .7922 m .45613 .78527 L .4495 .78942 L .72 .634 .871 r
F
.46019 .7922 m .46573 .7887 L .45613 .78527 L F
.46851 1.17176 m .44265 1.18773 L .43797 1.19901 L 1 .976 .748 r
F
.46878 1.17148 m .44265 1.18772 L .46851 1.17176 L 1 .973 .757 r
F
.42975 .35378 m .46852 .39938 L .42624 .32941 L .253 0 .587 r
F
.58025 1.2109 m .55149 1.21929 L .5538 1.24348 L .955 .203 .624 r
F
.57625 1.19007 m .55149 1.21929 L .58025 1.2109 L .992 .262 .645 r
F
.57625 1.19007 m .54921 1.19886 L .55149 1.21929 L F
.57227 1.1723 m .54921 1.19886 L .57625 1.19007 L 1 .354 .67 r
F
.57227 1.1723 m .54695 1.18187 L .54921 1.19886 L F
.46188 1.02238 m .44186 1.0216 L .45557 1.02997 L .76 .479 .801 r
F
.47505 1.02785 m .46188 1.02238 L .45557 1.02997 L .824 .506 .788 r
F
.49586 1.16434 m .47071 1.16894 L .46878 1.17148 L .589 .268 .879 r
F
.52009 1.16059 m .49586 1.16434 L .5206 1.16924 L .534 .357 .897 r
F
.52009 1.16059 m .49705 1.16006 L .49586 1.16434 L F
.49705 1.16006 m .47071 1.16894 L .49586 1.16434 L .756 .674 .876 r
F
.68384 .77709 m .69838 .7822 L .69228 .78561 L 1 .021 .243 r
F
.60651 1.09642 m .58667 1.12774 L .59219 1.13641 L 1 .733 .668 r
F
.59964 1.10137 m .6044 1.09974 L .60651 1.09642 L 1 .924 .735 r
F
.61672 1.09048 m .59964 1.10137 L .60651 1.09642 L 0 0 0 r
F
.60842 1.09636 m .59964 1.10137 L .61672 1.09048 L .38 0 .647 r
F
.60842 1.09636 m .59472 1.10305 L .59964 1.10137 L F
.59472 1.10305 m .59269 1.10404 L .59964 1.10137 L F
.59964 1.10137 m .58667 1.12774 L .6044 1.09974 L 1 .924 .735 r
F
.61672 1.09048 m .60651 1.09642 L .62477 1.0737 L 0 0 0 r
F
.46878 1.17148 m .44308 1.18672 L .44265 1.18772 L 1 .973 .757 r
F
.47071 1.16894 m .44308 1.18672 L .46878 1.17148 L 1 1 .771 r
F
.48043 .78968 m .47938 .78249 L .47216 .78544 L .739 .647 .865 r
F
.48043 .78968 m .48619 .78737 L .47938 .78249 L F
.51689 1.02459 m .50327 1.0338 L .51741 1.03423 L .9 .563 .782 r
F
.52921 1.02347 m .51741 1.03423 L .53147 1.03302 L .916 .574 .78 r
F
.52921 1.02347 m .51689 1.02459 L .51741 1.03423 L F
.51689 1.02459 m .50449 1.02428 L .50327 1.0338 L .9 .563 .782 r
F
.50449 1.02428 m .48893 1.03168 L .50327 1.0338 L .884 .553 .784 r
F
.59219 1.13641 m .56929 1.16096 L .5719 1.17079 L 1 .516 .661 r
F
.58667 1.12774 m .56929 1.16096 L .59219 1.13641 L 1 .611 .685 r
F
.58025 1.2109 m .5538 1.24348 L .58429 1.23459 L .955 .203 .624 r
F
.58429 1.2346 m .5538 1.24348 L .55616 1.27167 L .938 .17 .609 r
F
.56044 .78354 m .57635 .78204 L .56999 .77932 L .683 .594 .879 r
F
.55401 .78126 m .56044 .78354 L .56999 .77932 L .663 .567 .88 r
F
.64325 1.00257 m .6332 1.00377 L .64386 1.00364 L .121 0 .712 r
F
.42975 .35378 m .47035 .42017 L .46852 .39938 L .253 0 .587 r
F
.43326 .37796 m .47035 .42017 L .42975 .35378 L .258 0 .589 r
F
.41899 1.26443 m .37864 1.32893 L .41413 1.28713 L 1 .711 .613 r
F
.41899 1.26443 m .38533 1.30233 L .37864 1.32893 L F
.42381 1.24413 m .38533 1.30233 L .41899 1.26443 L 1 .739 .623 r
F
.56999 .77932 m .57635 .78204 L .58699 .77827 L .651 .552 .886 r
F
.34756 .80169 m .34053 .79629 L .33461 .80492 L .654 .339 .865 r
F
.34756 .80169 m .35313 .79353 L .34053 .79629 L F
.54126 1.02089 m .53147 1.03302 L .54521 1.03 L .936 .586 .778 r
F
.54126 1.02089 m .52921 1.02347 L .53147 1.03302 L F
.24326 .83068 m .22981 .88532 L .22979 .83615 L .482 0 .249 r
F
.24326 .83068 m .24371 .87302 L .22981 .88532 L F
.42381 1.24413 m .39198 1.27746 L .38533 1.30233 L 1 .739 .623 r
F
.4286 1.22651 m .39198 1.27746 L .42381 1.24413 L 1 .77 .636 r
F
.58206 1.01118 m .57781 1.02518 L .59053 1.0157 L .992 .701 .793 r
F
.58206 1.01118 m .57073 1.01853 L .57781 1.02518 L F
.54002 .78457 m .55401 .78126 L .54681 .77926 L .687 .594 .874 r
F
.53375 .78334 m .54002 .78457 L .54681 .77926 L .689 .594 .873 r
F
.82104 .87099 m .83471 .80529 L .83479 .87828 L .786 0 .322 r
F
.49192 1.02251 m .47505 1.02785 L .48893 1.03168 L .862 .543 .787 r
F
.50449 1.02428 m .49192 1.02251 L .48893 1.03168 L .884 .553 .784 r
F
.40288 .79422 m .39739 .78595 L .39051 .79315 L .644 .542 .885 r
F
.40288 .79422 m .40911 .78781 L .39739 .78595 L F
.41413 1.28713 m .3719 1.35709 L .40924 1.31184 L 1 .689 .606 r
F
.41413 1.28713 m .37864 1.32893 L .3719 1.35709 L F
.543 1.15865 m .5206 1.16924 L .54525 1.17101 L .88 .604 .8 r
F
.543 1.15865 m .52009 1.16059 L .5206 1.16924 L F
.62488 1.2539 m .59676 1.32079 L .63075 1.28198 L 1 .204 .594 r
F
.62488 1.2539 m .59257 1.29008 L .59676 1.32079 L F
.58699 .77827 m .60463 .77766 L .59767 .77468 L .66 .554 .888 r
F
.42037 1.01596 m .40835 1.00596 L .3981 1.00601 L .432 .185 .852 r
F
.42949 1.01253 m .40835 1.00596 L .42037 1.01596 L .571 .369 .845 r
F
.44186 1.0216 m .42949 1.01253 L .42037 1.01596 L .624 .377 .819 r
F
.5719 1.1708 m .54695 1.18187 L .57227 1.1723 L 1 .408 .686 r
F
.5719 1.1708 m .54674 1.18044 L .54695 1.18187 L F
.40835 1.00596 m .38692 1.00001 L .3981 1.00601 L .5 .314 .888 r
F
.43326 .37796 m .47219 .44091 L .47035 .42017 L .258 0 .589 r
F
.43678 .40199 m .47219 .44091 L .43326 .37796 L .264 0 .59 r
F
.55279 1.01689 m .54521 1.03 L .55837 1.02507 L .952 .602 .778 r
F
.55279 1.01689 m .54126 1.02089 L .54521 1.03 L F
.58429 1.2346 m .55616 1.27167 L .58841 1.26122 L .938 .17 .609 r
F
.56929 1.16096 m .54674 1.18044 L .5719 1.17079 L 1 .46 .696 r
F
.56929 1.16096 m .54525 1.17101 L .54674 1.18044 L F
.51299 .53842 m .54251 .49702 L .54429 .4801 L 1 .77 .63 r
F
.513 .54871 m .54251 .49702 L .51299 .53842 L 1 .805 .644 r
F
.48619 .78737 m .48724 .77994 L .47938 .78249 L .745 .65 .863 r
F
.48619 .78737 m .49247 .78542 L .48724 .77994 L F
.4286 1.22651 m .39859 1.25448 L .39198 1.27746 L 1 .77 .636 r
F
.4333 1.2117 m .39859 1.25447 L .4286 1.2265 L 1 .803 .652 r
F
.43245 .7917 m .428 .78424 L .4208 .78972 L .681 .592 .879 r
F
.43245 .7917 m .43877 .78677 L .428 .78424 L F
.47975 1.01933 m .46188 1.02238 L .47505 1.02785 L .829 .531 .794 r
F
.49192 1.02251 m .47975 1.01933 L .47505 1.02785 L .862 .543 .787 r
F
.46573 .7887 m .46386 .78134 L .45613 .78527 L .731 .645 .869 r
F
.46573 .7887 m .47216 .78544 L .46386 .78134 L F
.53375 .78334 m .54681 .77926 L .53896 .77761 L .689 .594 .873 r
F
.5271 .7825 m .53375 .78334 L .53896 .77761 L .7 .604 .87 r
F
.44967 1.01563 m .42949 1.01253 L .44186 1.0216 L .698 .46 .818 r
F
.46188 1.02238 m .44967 1.01563 L .44186 1.0216 L .76 .479 .801 r
F
.61169 1.00051 m .61154 1.00878 L .62247 1.00273 L .729 .645 .88 r
F
.61169 1.00051 m .60188 1.0072 L .61154 1.00878 L F
.58841 1.26122 m .55616 1.27167 L .55855 1.30293 L .936 .155 .599 r
F
.40924 1.31184 m .36511 1.38665 L .40432 1.33817 L 1 .669 .601 r
F
.40924 1.31184 m .3719 1.35709 L .36511 1.38665 L F
.43678 .40199 m .47402 .46167 L .47219 .44091 L .264 0 .59 r
F
.4403 .42589 m .47402 .46167 L .43678 .40199 L .27 0 .591 r
F
.4495 .78942 m .4465 .78203 L .43877 .78677 L .709 .626 .875 r
F
.4495 .78942 m .45613 .78527 L .4465 .78203 L F
.56363 1.01173 m .55837 1.02507 L .57073 1.01853 L .957 .63 .784 r
F
.56363 1.01173 m .55279 1.01689 L .55837 1.02507 L F
.49247 .78542 m .49559 .7779 L .48724 .77994 L .75 .652 .861 r
F
.49247 .78542 m .49914 .78387 L .49559 .7779 L F
.22979 .83615 m .21585 .89728 L .21628 .84165 L .519 0 .269 r
F
.22979 .83615 m .22981 .88532 L .21585 .89728 L F
.59216 1.00396 m .59053 1.01569 L .60188 1.0072 L .924 .756 .827 r
F
.59216 1.00396 m .58206 1.01117 L .59053 1.01569 L F
.55401 .78126 m .56999 .77932 L .56228 .77668 L .663 .567 .88 r
F
.54681 .77926 m .55401 .78126 L .56228 .77668 L .652 .552 .88 r
F
.3346 .80493 m .33216 .79954 L .32601 .80813 L .671 .173 .815 r
F
.3346 .80493 m .34053 .79629 L .33216 .79954 L F
.56535 1.14846 m .54525 1.17101 L .56929 1.16096 L 1 .567 .718 r
F
.56535 1.14846 m .543 1.15865 L .54525 1.17101 L F
.39051 .79315 m .38565 .78408 L .37809 .79249 L .649 .55 .884 r
F
.39051 .79315 m .39739 .78595 L .38565 .78408 L F
.58667 1.12774 m .56535 1.14846 L .56929 1.16096 L 1 .611 .685 r
F
.5271 .7825 m .53896 .77761 L .53062 .7764 L .7 .604 .87 r
F
.52017 .7821 m .5271 .7825 L .53062 .7764 L .715 .618 .867 r
F
.4403 .42589 m .47585 .48253 L .47402 .46167 L .27 0 .591 r
F
.44383 .44974 m .47585 .48253 L .4403 .42589 L .277 0 .591 r
F
.58841 1.26122 m .55855 1.30293 L .59257 1.29008 L .936 .155 .599 r
F
.51299 .53842 m .54429 .4801 L .51298 .52619 L 1 .77 .63 r
F
.51298 .52619 m .54429 .48009 L .54609 .46174 L 1 .744 .62 r
F
.65806 1.18417 m .63365 1.17587 L .64111 1.2081 L .462 .005 .597 r
F
.64892 1.14373 m .63365 1.17587 L .65806 1.18417 L .523 .014 .594 r
F
.48616 1.34642 m .44392 1.36098 L .48482 1.3891 L .984 .145 .577 r
F
.5248 1.36715 m .48617 1.34642 L .48483 1.3891 L .909 .109 .571 r
F
.52423 1.32732 m .48617 1.34642 L .5248 1.36715 L .88 .094 .567 r
F
.4333 1.2117 m .40506 1.23376 L .39859 1.25447 L 1 .803 .652 r
F
.43797 1.19901 m .40506 1.23376 L .4333 1.2117 L 1 .828 .671 r
F
.57959 .77543 m .58699 .77827 L .59767 .77468 L .614 .487 .892 r
F
.56999 .77932 m .58699 .77827 L .57959 .77543 L .651 .552 .886 r
F
.63075 1.28198 m .60098 1.35305 L .63665 1.3113 L 1 .193 .59 r
F
.63075 1.28198 m .59676 1.32079 L .60098 1.35305 L F
.49914 .78387 m .50427 .77648 L .49559 .77789 L .751 .649 .86 r
F
.49914 .78387 m .50606 .78278 L .50427 .77648 L F
.47071 1.16894 m .44617 1.17978 L .44308 1.18672 L 1 1 .771 r
F
.47364 1.16346 m .44617 1.17978 L .47071 1.16894 L 1 .957 .781 r
F
.49705 1.16006 m .47364 1.16346 L .47071 1.16894 L .756 .674 .876 r
F
.46821 1.01487 m .44967 1.01563 L .46188 1.02238 L .79 .519 .804 r
F
.47975 1.01933 m .46821 1.01487 L .46188 1.02238 L .829 .531 .794 r
F
.56096 1.33654 m .52423 1.32732 L .5248 1.36715 L .87 .102 .577 r
F
.55855 1.30293 m .52423 1.32732 L .56096 1.33654 L .829 .088 .578 r
F
.25995 .56774 m .27201 .62365 L .24932 .5515 L .979 0 .112 r
F
.58116 1.122 m .56535 1.14846 L .58667 1.12774 L 1 .734 .721 r
F
.59964 1.10137 m .58116 1.122 L .58667 1.12774 L 1 .924 .735 r
F
.52017 .7821 m .53062 .7764 L .52195 .77574 L .715 .618 .867 r
F
.51312 .78219 m .52017 .7821 L .52195 .77574 L .732 .632 .863 r
F
.40432 1.33817 m .35828 1.41744 L .39937 1.36582 L 1 .653 .597 r
F
.40432 1.33817 m .36511 1.38665 L .35828 1.41744 L F
.56228 .77668 m .56999 .77932 L .57959 .77543 L .622 .511 .887 r
F
.50606 .78278 m .51311 .77575 L .50427 .77648 L .745 .643 .861 r
F
.50606 .78278 m .51312 .78219 L .51311 .77575 L F
.51636 1.01512 m .50449 1.02428 L .51689 1.02459 L .896 .573 .786 r
F
.52695 1.01416 m .51689 1.02459 L .52921 1.02347 L .909 .582 .785 r
F
.52695 1.01416 m .51636 1.01512 L .51689 1.02459 L F
.51312 .78219 m .52195 .77574 L .51311 .77575 L .732 .632 .863 r
F
.51636 1.01512 m .50572 1.0149 L .50449 1.02428 L .896 .573 .786 r
F
.50571 1.0149 m .49192 1.02251 L .50449 1.02428 L .881 .566 .788 r
F
.63152 .99856 m .6332 1.00377 L .64325 1.00257 L .465 .133 .89 r
F
.63152 .99856 m .62247 1.00273 L .6332 1.00377 L F
.47216 .78544 m .47253 .77769 L .46386 .78134 L .744 .656 .866 r
F
.47216 .78544 m .47938 .78249 L .47253 .77769 L F
.57355 1.00583 m .57073 1.01853 L .58206 1.01118 L .942 .668 .799 r
F
.57355 1.00583 m .56363 1.01173 L .57073 1.01853 L F
.53729 1.01204 m .52921 1.02347 L .54126 1.02089 L .921 .592 .784 r
F
.53729 1.01204 m .52695 1.01416 L .52921 1.02347 L F
.48482 1.3891 m .44392 1.36098 L .44066 1.39974 L .969 .14 .577 r
F
.4208 .78972 m .41719 .78177 L .40911 .78781 L .664 .57 .883 r
F
.4208 .78972 m .428 .78424 L .41719 .78177 L F
.51297 .51225 m .54609 .46174 L .54789 .44238 L 1 .723 .613 r
F
.51298 .52619 m .54609 .46174 L .51297 .51225 L 1 .744 .62 r
F
.49492 1.01348 m .47975 1.01933 L .49192 1.02251 L .863 .559 .792 r
F
.50571 1.0149 m .49492 1.01348 L .49192 1.02251 L .881 .566 .788 r
F
.25995 .56774 m .282 .63551 L .27201 .62365 L .979 0 .112 r
F
.27057 .58464 m .282 .63551 L .25995 .56774 L .951 0 .091 r
F
.59257 1.29008 m .55855 1.30293 L .56096 1.33654 L .943 .148 .592 r
F
.32601 .80813 m .33097 .80012 L .32479 .80866 L .66 .061 .77 r
F
.32601 .80813 m .33216 .79954 L .33097 .80012 L F
.42949 1.01253 m .41867 1.00403 L .40835 1.00596 L .571 .369 .845 r
F
.43866 1.00823 m .41867 1.00403 L .42949 1.01253 L .68 .48 .833 r
F
.44967 1.01563 m .43866 1.00823 L .42949 1.01253 L .698 .46 .818 r
F
.21628 .84165 m .20183 .90893 L .20274 .84712 L .549 0 .284 r
F
.21628 .84165 m .21585 .89728 L .20183 .90893 L F
.54681 .77926 m .56228 .77668 L .55363 .77422 L .652 .552 .88 r
F
.53896 .77761 m .54681 .77926 L .55363 .77422 L .656 .554 .877 r
F
.5472 1.00884 m .54126 1.02089 L .55279 1.01689 L .927 .605 .786 r
F
.5472 1.00884 m .53729 1.01204 L .54126 1.02089 L F
.51957 1.15211 m .49705 1.16006 L .52009 1.16059 L .78 .689 .86 r
F
.54075 1.14813 m .52009 1.16059 L .543 1.15865 L .968 .709 .802 r
F
.54075 1.14813 m .51957 1.15211 L .52009 1.16059 L F
.37809 .79249 m .37387 .78214 L .36564 .79248 L .682 .592 .878 r
F
.37809 .79249 m .38565 .78408 L .37387 .78214 L F
.32478 .80866 m .31811 .80882 L .31165 .81556 L .655 .002 .681 r
F
.32478 .80866 m .33097 .80012 L .31811 .80882 L F
.51957 1.15211 m .49826 1.15381 L .49705 1.16006 L .78 .689 .86 r
F
.49825 1.15381 m .47364 1.16346 L .49705 1.16006 L .91 .815 .846 r
F
.59257 1.29008 m .56096 1.33654 L .59676 1.32079 L .943 .148 .592 r
F
.51296 .49716 m .54789 .44238 L .54968 .4222 L 1 .706 .607 r
F
.51297 .51225 m .54789 .44238 L .51296 .49716 L 1 .723 .613 r
F
.40835 1.00596 m .39823 .99903 L .38692 1.00001 L .5 .314 .888 r
F
.41867 1.00403 m .39823 .99903 L .40835 1.00596 L .638 .5 .862 r
F
.56142 1.13847 m .543 1.15865 L .56535 1.14846 L 1 .683 .745 r
F
.58116 1.122 m .56142 1.13847 L .56535 1.14846 L 1 .734 .721 r
F
.43797 1.19901 m .41151 1.21498 L .40506 1.23376 L 1 .828 .671 r
F
.44265 1.18773 m .41151 1.21498 L .43797 1.19901 L 1 .837 .69 r
F
.48447 1.01092 m .46821 1.01487 L .47975 1.01933 L .841 .553 .797 r
F
.49492 1.01348 m .48447 1.01092 L .47975 1.01933 L .863 .559 .792 r
F
.45751 1.00939 m .43866 1.00823 L .44967 1.01563 L .758 .517 .814 r
F
.46821 1.01487 m .45751 1.00939 L .44967 1.01563 L .79 .519 .804 r
F
.45613 .78527 m .45552 .77747 L .4465 .78203 L .726 .644 .872 r
F
.45613 .78527 m .46386 .78134 L .45552 .77747 L F
.56142 1.13847 m .54075 1.14813 L .543 1.15865 L 1 .683 .745 r
F
.39937 1.36582 m .3514 1.44935 L .39438 1.39457 L 1 .639 .594 r
F
.39937 1.36582 m .35828 1.41744 L .3514 1.44935 L F
.43877 .78677 m .43683 .77901 L .428 .78424 L .693 .608 .879 r
F
.43877 .78677 m .4465 .78203 L .43683 .77901 L F
.27057 .58464 m .29196 .64776 L .282 .63551 L .951 0 .091 r
F
.28116 .60256 m .29196 .64776 L .27057 .58464 L .915 0 .06 r
F
.47938 .78249 m .48198 .77443 L .47253 .77769 L .759 .665 .861 r
F
.47938 .78249 m .48724 .77994 L .48198 .77443 L F
.60087 .99732 m .60188 1.0072 L .61169 1.00051 L .819 .719 .853 r
F
.60087 .99732 m .59216 1.00396 L .60188 1.0072 L F
.51295 .48118 m .54968 .4222 L .55147 .40134 L 1 .692 .602 r
F
.51296 .49716 m .54968 .4222 L .51295 .48118 L 1 .706 .607 r
F
.63665 1.3113 m .60523 1.38661 L .64259 1.34169 L 1 .185 .587 r
F
.63665 1.3113 m .60098 1.35305 L .60523 1.38661 L F
.55649 1.00473 m .55279 1.01689 L .56363 1.01173 L .925 .622 .791 r
F
.55649 1.00473 m .5472 1.00884 L .55279 1.01689 L F
.57959 .77543 m .59767 .77468 L .58922 .77196 L .614 .487 .892 r
F
.5824 .99966 m .58206 1.01117 L .59216 1.00396 L .904 .695 .817 r
F
.5824 .99966 m .57356 1.00583 L .58206 1.01117 L F
.51294 .4645 m .55147 .40134 L .55326 .37989 L 1 .68 .598 r
F
.51295 .48118 m .55147 .40134 L .51294 .4645 L 1 .692 .602 r
F
.53896 .77761 m .55363 .77422 L .5442 .77202 L .656 .554 .877 r
F
.53062 .7764 m .53896 .77761 L .5442 .77202 L .676 .573 .872 r
F
.51293 .44726 m .55326 .37989 L .55504 .35795 L 1 .67 .595 r
F
.51294 .4645 m .55326 .37989 L .51293 .44726 L 1 .68 .598 r
F
.51292 .42956 m .55682 .33557 L .51291 .41147 L 1 .661 .592 r
F
.51292 .42956 m .55504 .35795 L .55682 .33557 L F
.51293 .44726 m .55504 .35795 L .51292 .42956 L 1 .67 .595 r
F
.56228 .77668 m .57959 .77543 L .57059 .77254 L .622 .511 .887 r
F
.55363 .77422 m .56228 .77668 L .57059 .77254 L .605 .486 .886 r
F
.40911 .78781 m .40635 .77922 L .3974 .78595 L .651 .552 .884 r
F
.40911 .78781 m .41719 .78177 L .40635 .77922 L F
.59269 1.10404 m .58116 1.122 L .59964 1.10137 L 1 .978 .799 r
F
.47456 1.00733 m .45751 1.00939 L .46821 1.01487 L .818 .55 .804 r
F
.48447 1.01092 m .47456 1.00733 L .46821 1.01487 L .841 .553 .797 r
F
.20274 .84712 m .18776 .92034 L .18918 .85256 L .573 0 .295 r
F
.20274 .84712 m .20183 .90893 L .18776 .92034 L F
.65806 1.18417 m .64111 1.2081 L .66716 1.22043 L .462 .005 .597 r
F
.66716 1.22043 m .64111 1.20811 L .64869 1.23999 L .433 .002 .599 r
F
.48724 .77994 m .49203 .77175 L .48198 .77443 L .771 .668 .857 r
F
.48724 .77994 m .49559 .7779 L .49203 .77175 L F
.57059 .77254 m .57959 .77543 L .58922 .77196 L .574 .427 .894 r
F
.36564 .79248 m .36206 .78003 L .35313 .79353 L .754 .662 .863 r
F
.36564 .79248 m .37387 .78214 L .36206 .78003 L F
.61978 .99471 m .62247 1.00273 L .63152 .99856 L .63 .521 .888 r
F
.61978 .99471 m .61169 1.00051 L .62247 1.00273 L F
.28116 .60256 m .30189 .66049 L .29196 .64776 L .915 0 .06 r
F
.29171 .62207 m .30189 .66049 L .28116 .60256 L .869 0 .011 r
F
.66991 1.16614 m .64892 1.14373 L .65806 1.18418 L .27 0 .557 r
F
.65963 1.13659 m .64892 1.14373 L .66991 1.16614 L .11 0 .496 r
F
.51583 1.0058 m .50572 1.0149 L .51636 1.01512 L .892 .582 .79 r
F
.52467 1.00502 m .51636 1.01512 L .52695 1.01416 L .901 .588 .789 r
F
.52467 1.00502 m .51583 1.0058 L .51636 1.01512 L F
.56501 .99992 m .56363 1.01173 L .57355 1.00583 L .913 .641 .8 r
F
.56501 .99992 m .55649 1.00473 L .56363 1.01173 L F
.53062 .7764 m .5442 .77202 L .53417 .77027 L .676 .573 .872 r
F
.52195 .77574 m .53062 .7764 L .53417 .77027 L .706 .602 .866 r
F
.51583 1.0058 m .50694 1.00566 L .50572 1.0149 L .892 .582 .79 r
F
.50694 1.00566 m .49492 1.01348 L .50571 1.0149 L .881 .578 .792 r
F
.57565 1.11774 m .56142 1.13847 L .58116 1.122 L 1 .832 .76 r
F
.59269 1.10404 m .57565 1.11774 L .58116 1.122 L 1 .978 .799 r
F
.59676 1.32079 m .56339 1.37189 L .60098 1.35305 L .953 .147 .588 r
F
.59676 1.32079 m .56096 1.33654 L .56339 1.37189 L F
.5333 1.00334 m .52695 1.01416 L .53729 1.01204 L .906 .594 .789 r
F
.5333 1.00334 m .52467 1.00502 L .52695 1.01416 L F
.56096 1.33654 m .5248 1.36715 L .56339 1.37189 L .87 .102 .577 r
F
.47364 1.16346 m .45086 1.16962 L .44617 1.17978 L 1 .957 .781 r
F
.4766 1.15651 m .45086 1.16962 L .47364 1.16346 L 1 .892 .786 r
F
.49825 1.15381 m .4766 1.15651 L .47364 1.16346 L .91 .815 .846 r
F
.38692 1.00001 m .37801 .99802 L .36577 1.00348 L .668 .348 .861 r
F
.39823 .99903 m .37801 .99802 L .38692 1.00001 L .757 .681 .876 r
F
.49559 .77789 m .50246 .7699 L .49203 .77175 L .774 .663 .854 r
F
.49559 .77789 m .50427 .77648 L .50246 .7699 L F
.44265 1.18773 m .41792 1.19807 L .41151 1.21498 L 1 .837 .69 r
F
.44308 1.18672 m .41793 1.19807 L .44265 1.18772 L 1 .869 .701 r
F
.43866 1.00823 m .42903 1.00086 L .41867 1.00403 L .68 .48 .833 r
F
.44786 1.00327 m .42903 1.00086 L .43866 1.00823 L .755 .539 .822 r
F
.45751 1.00939 m .44786 1.00327 L .43866 1.00823 L .758 .517 .814 r
F
.46386 .78134 m .46565 .77307 L .45552 .77747 L .749 .667 .868 r
F
.46386 .78134 m .47253 .77769 L .46565 .77307 L F
.49793 1.00455 m .48447 1.01092 L .49492 1.01348 L .868 .574 .795 r
F
.50694 1.00566 m .49793 1.00455 L .49492 1.01348 L .881 .578 .792 r
F
.69717 1.03574 m .69644 1.03494 L .69836 1.03696 L .582 0 0 r
F
.69644 1.03494 m .68727 1.0249 L .69739 1.03591 L F
.69644 1.03494 m .69739 1.03591 L .69836 1.03696 L F
.68879 1.02754 m .68879 1.02754 L .69716 1.03574 L .485 0 0 r
F
.68879 1.02754 m .68617 1.0241 L .69634 1.03486 L F
.68879 1.02754 m .69634 1.03486 L .69716 1.03574 L F
.68879 1.02754 m .67842 1.01892 L .68617 1.0241 L F
.68879 1.02754 m .68643 1.02559 L .68879 1.02754 L F
.68643 1.02559 m .67842 1.01892 L .68879 1.02754 L F
.67613 1.01656 m .67842 1.01892 L .68878 1.02754 L 0 0 .619 r
F
.67842 1.01892 m .67842 1.01892 L .67986 1.02012 L F
.67842 1.01892 m .67986 1.02012 L .68878 1.02754 L F
.68878 1.02754 m .67613 1.01656 L .68878 1.02754 L .131 0 .771 r
F
.68849 1.02686 m .68559 1.02444 L .68878 1.02754 L F
.68559 1.02444 m .67613 1.01656 L .68878 1.02754 L F
.69836 1.03697 m .68728 1.0249 L .69907 1.0343 L .584 0 0 r
F
.69717 1.03574 m .68617 1.02411 L .68727 1.0249 L .582 0 0 r
F
.68252 1.01293 m .67756 1.01575 L .68849 1.02686 L .131 0 .771 r
F
.67756 1.01575 m .67613 1.01656 L .68849 1.02686 L F
.69836 1.03696 m .69717 1.03574 L .69836 1.03696 L 0 0 .659 r
F
.69836 1.03697 m .69907 1.0343 L .71018 1.04962 L .584 0 0 r
F
.70467 1.03725 m .69723 1.03575 L .69836 1.03696 L 0 0 .659 r
F
.69723 1.03575 m .69717 1.03574 L .69836 1.03696 L F
.69836 1.03697 m .69836 1.03697 L .71113 1.05094 L .584 0 0 r
F
.69836 1.03697 m .71018 1.04962 L .71113 1.05094 L F
.52195 .77574 m .53417 .77027 L .52373 .7692 L .706 .602 .866 r
F
.51311 .77575 m .52195 .77574 L .52373 .7692 L .738 .63 .859 r
F
.44308 1.18672 m .41852 1.19658 L .41793 1.19807 L 1 .869 .701 r
F
.44617 1.17978 m .41853 1.19657 L .44308 1.18672 L 1 .844 .708 r
F
.5248 1.36715 m .48483 1.3891 L .52538 1.40738 L .909 .109 .571 r
F
.56339 1.37189 m .5248 1.36715 L .52538 1.40738 L .902 .113 .577 r
F
.31165 .81556 m .305 .82345 L .29839 .82466 L 0 0 0 r
F
.31165 .81556 m .31811 .80882 L .305 .82345 L F
.54158 1.0008 m .53729 1.01204 L .5472 1.00884 L .908 .602 .791 r
F
.54158 1.0008 m .5333 1.00334 L .53729 1.01204 L F
.41867 1.00403 m .40959 .99682 L .39823 .99903 L .638 .5 .862 r
F
.42903 1.00086 m .40959 .99682 L .41867 1.00403 L .732 .568 .841 r
F
.50427 .77648 m .5131 .76903 L .50246 .7699 L .763 .65 .855 r
F
.50427 .77648 m .51311 .77575 L .5131 .76903 L F
.55748 1.13035 m .54075 1.14813 L .56142 1.13847 L 1 .768 .769 r
F
.57565 1.11774 m .55748 1.13035 L .56142 1.13847 L 1 .832 .76 r
F
.67613 1.01656 m .66668 1.01235 L .67842 1.01892 L 0 0 .619 r
F
.51311 .77575 m .52373 .7692 L .5131 .76903 L .738 .63 .859 r
F
.46538 1.00289 m .44786 1.00327 L .45751 1.00939 L .802 .553 .81 r
F
.47456 1.00733 m .46538 1.00289 L .45751 1.00939 L .818 .55 .804 r
F
.48482 1.3891 m .44066 1.39974 L .48348 1.43093 L .969 .14 .577 r
F
.52538 1.40738 m .48483 1.3891 L .48349 1.43093 L .927 .118 .573 r
F
.428 .78424 m .42712 .77618 L .41719 .78177 L .67 .578 .884 r
F
.428 .78424 m .43683 .77901 L .42712 .77618 L F
.64259 1.34169 m .60951 1.42126 L .64857 1.373 L 1 .181 .585 r
F
.64259 1.34169 m .60523 1.38661 L .60951 1.42126 L F
.5385 1.13897 m .51957 1.15211 L .54075 1.14813 L 1 .768 .803 r
F
.55748 1.13035 m .5385 1.13897 L .54075 1.14813 L 1 .768 .769 r
F
.51905 1.14376 m .49826 1.15381 L .51957 1.15211 L .918 .773 .833 r
F
.5385 1.13897 m .51905 1.14376 L .51957 1.15211 L 1 .768 .803 r
F
.48348 1.43093 m .44066 1.39974 L .43739 1.43846 L .96 .136 .577 r
F
.4892 1.00254 m .47456 1.00733 L .48447 1.01092 L .853 .572 .799 r
F
.49793 1.00455 m .4892 1.00254 L .48447 1.01092 L .868 .574 .795 r
F
.55363 .77422 m .57059 .77254 L .56048 .76959 L .605 .486 .886 r
F
.5442 .77202 m .55363 .77422 L .56048 .76959 L .61 .491 .882 r
F
.6743 .75536 m .68384 .77709 L .69228 .78561 L .039 0 .674 r
F
.59 .99343 m .59216 1.00396 L .60087 .99732 L .853 .684 .83 r
F
.59 .99343 m .5824 .99966 L .59216 1.00396 L F
.4465 .78203 m .44714 .77393 L .43683 .77901 L .712 .633 .878 r
F
.4465 .78203 m .45552 .77747 L .44714 .77393 L F
.3974 .78595 m .39548 .77635 L .38565 .78408 L .65 .549 .881 r
F
.3974 .78595 m .40635 .77922 L .39548 .77635 L F
.29171 .62207 m .3118 .6738 L .30189 .66049 L .869 0 .011 r
F
.3022 .64398 m .3118 .6738 L .29171 .62207 L .816 0 0 r
F
.66354 1.00731 m .66668 1.01235 L .67613 1.01656 L .024 0 .788 r
F
.66354 1.00731 m .65496 1.00704 L .66668 1.01235 L F
.54933 .99753 m .5472 1.00884 L .55649 1.00473 L .905 .612 .794 r
F
.54933 .99753 m .54158 1.0008 L .5472 1.00884 L F
.57259 .99467 m .57356 1.00583 L .5824 .99966 L .893 .653 .809 r
F
.57259 .99467 m .56501 .99992 L .57356 1.00583 L F
.51905 1.14376 m .49947 1.14644 L .49826 1.15381 L .918 .773 .833 r
F
.49947 1.14644 m .4766 1.15651 L .49825 1.15381 L .983 .821 .825 r
F
.35313 .79353 m .35023 .77764 L .34053 .79629 L .875 .72 .833 r
F
.35313 .79353 m .36206 .78003 L .35023 .77764 L F
.47253 .77769 m .4767 .76894 L .46565 .77307 L .779 .687 .86 r
F
.47253 .77769 m .48198 .77443 L .4767 .76894 L F
.60802 .99088 m .61169 1.00051 L .61978 .99471 L .747 .633 .856 r
F
.60802 .99088 m .60087 .99732 L .61169 1.00051 L F
.44617 1.17978 m .42275 1.18649 L .41853 1.19657 L 1 .844 .708 r
F
.45086 1.16962 m .42275 1.18649 L .44617 1.17978 L 1 .812 .722 r
F
.48093 .9997 m .46538 1.00289 L .47456 1.00733 L .841 .571 .803 r
F
.4892 1.00254 m .48093 .9997 L .47456 1.00733 L .853 .572 .799 r
F
.57059 .77254 m .58922 .77196 L .57894 .769 L .574 .427 .894 r
F
.56048 .76959 m .57059 .77254 L .57894 .769 L .546 .387 .893 r
F
.65099 .99967 m .65496 1.00704 L .66354 1.00731 L .298 .046 .876 r
F
.65099 .99967 m .64325 1.00257 L .65496 1.00704 L F
.57894 .769 m .58922 .77196 L .5989 .76896 L .522 .311 .9 r
F
.67641 1.2554 m .64869 1.23999 L .65629 1.2715 L .416 .001 .6 r
F
.66716 1.22043 m .64869 1.23999 L .67641 1.2554 L .433 .002 .599 r
F
.60098 1.35305 m .56583 1.40854 L .60523 1.38661 L .964 .148 .585 r
F
.60098 1.35305 m .56339 1.37189 L .56583 1.40854 L F
.39823 .99903 m .39022 .99385 L .37801 .99802 L .757 .681 .876 r
F
.40959 .99682 m .39022 .99385 L .39823 .99903 L .808 .715 .856 r
F
.5442 .77202 m .56048 .76959 L .54946 .76668 L .61 .491 .882 r
F
.53417 .77027 m .5442 .77202 L .54946 .76668 L .641 .527 .874 r
F
.55644 .99363 m .55649 1.00473 L .56501 .99992 L .898 .621 .799 r
F
.55644 .99363 m .54933 .99753 L .55649 1.00473 L F
.44786 1.00327 m .43944 .99685 L .42903 1.00086 L .755 .539 .822 r
F
.4571 .99781 m .43944 .99685 L .44786 1.00327 L .805 .57 .814 r
F
.46538 1.00289 m .4571 .99781 L .44786 1.00327 L .802 .553 .81 r
F
.5153 .99661 m .50694 1.00566 L .51583 1.0058 L .888 .59 .793 r
F
.52239 .996 m .51583 1.0058 L .52467 1.00502 L .893 .592 .792 r
F
.52239 .996 m .5153 .99661 L .51583 1.0058 L F
.5153 .99661 m .50818 .99652 L .50694 1.00566 L .888 .59 .793 r
F
.50818 .99652 m .49793 1.00455 L .50694 1.00566 L .882 .587 .795 r
F
.42903 1.00086 m .42099 .99383 L .40959 .99682 L .732 .568 .841 r
F
.43944 .99685 m .42099 .99383 L .42903 1.00086 L .791 .593 .826 r
F
.52931 .99469 m .52467 1.00502 L .5333 1.00334 L .896 .596 .793 r
F
.52931 .99469 m .52239 .996 L .52467 1.00502 L F
.56339 1.37189 m .52538 1.40738 L .56583 1.40854 L .902 .113 .577 r
F
.48198 .77443 m .48845 .76539 L .4767 .76894 L .805 .693 .85 r
F
.48198 .77443 m .49203 .77175 L .48845 .76539 L F
.50095 .99569 m .4892 1.00254 L .49793 1.00455 L .873 .586 .797 r
F
.50818 .99652 m .50095 .99569 L .49793 1.00455 L .882 .587 .795 r
F
.38565 .78408 m .38459 .7728 L .37387 .78214 L .666 .557 .871 r
F
.38565 .78408 m .39548 .77635 L .38459 .7728 L F
.64857 1.373 m .61382 1.45688 L .65457 1.40514 L 1 .178 .583 r
F
.64857 1.373 m .60951 1.42126 L .61382 1.45688 L F
.41719 .78177 m .41737 .77342 L .40635 .77922 L .642 .535 .888 r
F
.41719 .78177 m .42712 .77618 L .41737 .77342 L F
.47327 .99614 m .4571 .99781 L .46538 1.00289 L .834 .576 .806 r
F
.48093 .9997 m .47327 .99614 L .46538 1.00289 L .841 .571 .803 r
F
.53593 .99274 m .5333 1.00334 L .54158 1.0008 L .896 .6 .794 r
F
.53593 .99274 m .52931 .99469 L .5333 1.00334 L F
.45552 .77747 m .45873 .76879 L .44714 .77393 L .749 .673 .872 r
F
.45552 .77747 m .46565 .77307 L .45873 .76879 L F
.57911 .98907 m .5824 .99966 L .59 .99343 L .868 .647 .815 r
F
.57911 .98907 m .57259 .99467 L .5824 .99966 L F
.4766 1.15651 m .45555 1.15972 L .45086 1.16962 L 1 .892 .786 r
F
.47958 1.14864 m .45555 1.15972 L .4766 1.15651 L 1 .836 .788 r
F
.49947 1.14644 m .47958 1.14864 L .4766 1.15651 L .983 .821 .825 r
F
.57011 1.11385 m .55748 1.13035 L .57565 1.11774 L 1 .873 .794 r
F
.58567 1.10413 m .57565 1.11774 L .59269 1.10404 L 1 .903 .836 r
F
.58567 1.10413 m .57011 1.11385 L .57565 1.11774 L F
.63846 .99341 m .64325 1.00257 L .65099 .99967 L .477 .275 .884 r
F
.63846 .99341 m .63152 .99856 L .64325 1.00257 L F
.53417 .77027 m .54946 .76668 L .53773 .7641 L .641 .527 .874 r
F
.52373 .7692 m .53417 .77027 L .53773 .7641 L .692 .578 .863 r
F
.55354 1.12341 m .5385 1.13897 L .55748 1.13035 L 1 .814 .79 r
F
.57011 1.11385 m .55354 1.12341 L .55748 1.13035 L 1 .873 .794 r
F
.69072 .6818 m .71834 .74126 L .70131 .66849 L .724 .074 .602 r
F
.70131 .66849 m .73031 .73742 L .71211 .65696 L .715 .064 .593 r
F
.70131 .66849 m .71834 .74126 L .73031 .73742 L F
.53624 1.13077 m .51905 1.14376 L .5385 1.13897 L 1 .797 .806 r
F
.55354 1.12341 m .53624 1.13077 L .5385 1.13897 L 1 .814 .79 r
F
.69072 .6818 m .70657 .74503 L .71834 .74126 L .724 .074 .602 r
F
.68022 .69847 m .70657 .74503 L .69072 .6818 L .743 .102 .622 r
F
.49396 .99415 m .48093 .9997 L .4892 1.00254 L .865 .585 .799 r
F
.50095 .99569 m .49396 .99415 L .4892 1.00254 L .873 .586 .797 r
F
.28863 .83263 m .29155 .84465 L .28501 .83557 L 0 0 0 r
F
.29839 .82466 m .29155 .84465 L .28863 .83263 L F
.28501 .83558 m .27942 .86153 L .27133 .84779 L .018 0 .07 r
F
.27942 .86153 m .27593 .86367 L .27557 .8666 L .804 .094 .593 r
F
.27942 .86153 m .27557 .8666 L .26835 .92486 L F
.28501 .83558 m .29155 .84467 L .28973 .84794 L .018 0 .07 r
F
.28162 .92835 m .27942 .86153 L .26835 .92486 L .804 .094 .593 r
F
.27942 .86153 m .28973 .84794 L .28685 .85313 L .018 0 .07 r
F
.28501 .83558 m .28973 .84794 L .27942 .86153 L F
.28685 .85313 m .29522 .71512 L .27874 .84099 L .86 .07 .548 r
F
.29103 .85939 m .29132 .84927 L .28996 .85779 L F
.29132 .84927 m .29132 .84927 L .29123 .85115 L 0 0 .095 r
F
.28162 .92835 m .29103 .85939 L .28996 .85779 L .804 .094 .593 r
F
.29467 .93268 m .29103 .8594 L .28162 .92835 L .681 .062 .604 r
F
.29123 .85115 m .29123 .85115 L .2882 .91238 L 0 0 .095 r
F
.29132 .84927 m .29123 .85115 L .29123 .85115 L F
.28456 .886 m .28996 .85779 L .28685 .85313 L .804 .094 .593 r
F
.28162 .92835 m .28996 .85779 L .28456 .886 L F
.27925 .85656 m .28685 .85313 L .27874 .84099 L F
.28162 .92835 m .28685 .85313 L .27925 .85656 L F
.28974 .85747 m .29002 .8504 L .28685 .85313 L .86 .07 .548 r
F
.28762 .85173 m .29132 .84927 L .28685 .85313 L 0 0 .095 r
F
.29155 .84467 m .29132 .84927 L .28762 .85173 L F
.29155 .84467 m .29155 .84466 L .29132 .84927 L F
.29155 .84467 m .29132 .84927 L .29132 .84927 L F
.29103 .85939 m .29252 .84847 L .29132 .84927 L .86 .07 .548 r
F
.29839 .82466 m .29156 .84466 L .29155 .84465 L 0 0 0 r
F
.29839 .82466 m .305 .82345 L .29931 .83242 L F
.2945 .83606 m .29931 .83242 L .29156 .84466 L F
.29839 .82466 m .29931 .83242 L .2945 .83606 L F
.30313 .8794 m .31441 .86859 L .31097 .82361 L .069 0 .413 r
F
.31811 .80882 m .31761 .76733 L .305 .82345 L 1 .472 .679 r
F
.305 .82345 m .30587 .7637 L .29156 .84466 L 1 .235 .616 r
F
.30587 .7637 m .30598 .75582 L .30081 .78766 L F
.30587 .7637 m .30081 .78766 L .29156 .84466 L F
.29155 .84466 m .29794 .80869 L .29187 .84595 L 0 0 .095 r
F
.29252 .84847 m .29794 .80869 L .29132 .84927 L .86 .07 .548 r
F
.30313 .8794 m .30581 .7625 L .29103 .8594 L .069 0 .413 r
F
.30581 .7625 m .30592 .75767 L .30086 .79224 L F
.30581 .7625 m .30086 .79224 L .29103 .8594 L F
.29467 .93268 m .30164 .88877 L .29103 .8594 L .681 .062 .604 r
F
.30164 .88877 m .30313 .8794 L .30182 .87724 L F
.30164 .88877 m .30182 .87724 L .29103 .8594 L F
.29576 1.07825 m .27709 1.05139 L .28217 1.10034 L 1 .588 .641 r
F
.29576 1.07825 m .2908 1.03751 L .27709 1.05139 L F
.2908 1.03751 m .27692 .99319 L .27709 1.05139 L 1 .434 .639 r
F
.2908 1.03751 m .29047 .98764 L .27692 .99319 L F
.29047 .98764 m .29467 .93268 L .28162 .92835 L 1 .261 .63 r
F
.29047 .98764 m .28162 .92835 L .27692 .99319 L F
.27692 .99319 m .28162 .92835 L .26835 .92486 L 1 .258 .617 r
F
.2882 .9124 m .28844 .93744 L .27441 .94487 L 1 .016 .378 r
F
.2837 1.06611 m .29218 .9547 L .28572 .98194 L .923 0 .243 r
F
.29218 .9547 m .29679 .89409 L .28572 .98193 L F
.29218 .9547 m .28572 .98193 L .28572 .98194 L F
.28217 1.10035 m .26309 1.06627 L .2683 1.12329 L 1 .527 .627 r
F
.28217 1.10035 m .27709 1.05139 L .26309 1.06627 L F
.27709 1.05139 m .27692 .99319 L .26311 .99961 L 1 .404 .626 r
F
.27709 1.05139 m .26311 .99961 L .26309 1.06627 L F
.26962 1.08406 m .28572 .98194 L .27127 1.02847 L 1 .216 .451 r
F
.2837 1.06611 m .28572 .98194 L .26962 1.08406 L .923 0 .243 r
F
.28572 .98193 m .28846 .97974 L .28025 1.00498 L 0 0 0 r
F
.28846 .97974 m .28454 .99378 L .28025 1.00498 L F
.28572 .98194 m .28025 1.00498 L .27127 1.02846 L F
.28572 .98193 m .28025 1.00498 L .28572 .98194 L F
.28212 .98207 m .28454 .99378 L .27788 1.00751 L .84 .001 .356 r
F
.28846 .97974 m .28886 .97943 L .28454 .99378 L 0 0 0 r
F
.30925 1.05714 m .2908 1.03751 L .29576 1.07825 L 1 .675 .661 r
F
.30925 1.05714 m .30444 1.02454 L .2908 1.03751 L F
.30444 1.02454 m .29047 .98764 L .2908 1.03751 L 1 .477 .656 r
F
.30444 1.02454 m .30396 .98275 L .29047 .98764 L F
.30396 .98275 m .29467 .93268 L .29047 .98764 L 1 .28 .647 r
F
.30396 .98275 m .30771 .93717 L .29467 .93268 L F
.30771 .93717 m .30313 .8794 L .29467 .93268 L .656 .075 .629 r
F
.29719 1.05714 m .3049 .78794 L .28371 1.06611 L .212 0 .428 r
F
.305 .82345 m .31761 .76733 L .30598 .75582 L 1 .235 .616 r
F
.30429 .82865 m .31097 .82361 L .30592 .75767 L .069 0 .413 r
F
.30313 .8794 m .31097 .82361 L .30429 .82865 L F
.31799 1.01269 m .30396 .98275 L .30444 1.02454 L 1 .535 .677 r
F
.31799 1.01269 m .31742 .97839 L .30506 .9824 L F
.30501 .98499 m .30506 .9824 L .30396 .98275 L F
.31799 1.01269 m .30506 .9824 L .30501 .98499 L F
.31742 .97839 m .30771 .93717 L .30396 .98275 L 1 .322 .668 r
F
.31742 .97839 m .32077 .94114 L .30771 .93717 L F
.31536 .89666 m .31441 .86859 L .3062 .87646 L .329 .005 .696 r
F
.30585 .88325 m .3062 .87646 L .30313 .8794 L F
.31536 .89666 m .3062 .87646 L .30585 .88325 L F
.30771 .93717 m .31536 .89666 L .30313 .8794 L .656 .075 .629 r
F
.32077 .94114 m .31536 .89666 L .30771 .93717 L .709 .14 .664 r
F
.31081 .98235 m .3076 .84917 L .30731 .86205 L .71 0 0 r
F
.3076 .84917 m .30757 .84808 L .30752 .8506 L F
.3076 .84917 m .30752 .8506 L .30731 .86205 L F
.32262 1.03781 m .30444 1.02454 L .30925 1.05714 L 1 .783 .687 r
F
.32262 1.03781 m .31799 1.01269 L .30444 1.02454 L F
.3104 1.05459 m .31091 1.05272 L .3108 .98235 L .591 .027 .591 r
F
.3326 1.02504 m .31926 1.01164 L .32387 1.03612 L 1 .864 .712 r
F
.3326 1.02504 m .32815 1.00465 L .31926 1.01164 L F
.32386 1.03613 m .318 1.01269 L .32262 1.03781 L 1 .789 .693 r
F
.32386 1.03613 m .31926 1.01164 L .318 1.01269 L F
.32815 1.00465 m .31868 .978 L .31926 1.01164 L 1 .586 .695 r
F
.31926 1.01164 m .31742 .97838 L .318 1.01269 L 1 .536 .679 r
F
.31926 1.01164 m .31868 .978 L .31742 .97838 L F
.31091 1.05272 m .32236 1.01058 L .31081 .98236 L .591 .027 .591 r
F
.31091 1.05272 m .31081 .98236 L .3108 .98235 L F
.32236 1.01058 m .3251 1.00337 L .31081 .98235 L .141 0 .828 r
F
.31081 .98235 m .3251 1.00337 L .31357 .99991 L .71 0 0 r
F
.32077 .94114 m .32776 .90939 L .31536 .89666 L .709 .14 .664 r
F
.31591 .92465 m .32519 .91542 L .31281 .93511 L 0 0 0 r
F
.31081 .98235 m .31357 .99991 L .3112 .93999 L .71 0 0 r
F
.31087 .94099 m .3112 .93999 L .31089 .93209 L F
.31081 .98235 m .3112 .93999 L .31087 .94099 L F
.31081 .98235 m .31089 .93209 L .31073 .93185 L F
.31081 .98235 m .31073 .92804 L .30757 .84808 L F
.31081 .98235 m .31073 .92804 L .31081 .98235 L F
.29719 1.05714 m .3108 .98235 L .30921 .92968 L .212 0 .428 r
F
.30048 .9424 m .30921 .92968 L .3049 .78794 L F
.29719 1.05714 m .30921 .92968 L .30048 .9424 L F
.31073 .93185 m .31089 .93209 L .31073 .92804 L .71 0 0 r
F
.30731 .86205 m .30757 .84808 L .30504 .78396 L F
.3104 1.05459 m .3108 .98235 L .29719 1.05714 L .591 .027 .591 r
F
.30243 .95069 m .31356 .99991 L .30156 1.00435 L 1 .106 .43 r
F
.31091 .93174 m .31356 .99991 L .30243 .95069 L F
.28572 .98193 m .29569 .96395 L .28886 .97943 L 0 0 0 r
F
.29679 .89409 m .2981 .87677 L .29433 .90883 L .923 0 .243 r
F
.29679 .89409 m .29433 .90883 L .28572 .98194 L F
.2981 .87677 m .29933 .86061 L .29613 .88919 L F
.2981 .87677 m .29613 .88919 L .28572 .98194 L F
.29933 .86061 m .29503 .89096 L .28572 .98194 L F
.30279 .81513 m .30291 .80749 L .28572 .98194 L F
.29267 .91089 m .29569 .96395 L .28572 .98193 L 1 .034 .423 r
F
.29933 .86061 m .30279 .81513 L .29503 .89096 L .923 0 .243 r
F
.30279 .81513 m .30493 .78699 L .30291 .80749 L F
.30514 .78354 m .29569 .96395 L .29267 .91089 L 1 .034 .423 r
F
.30518 .77986 m .30514 .78354 L .28572 .98193 L F
.30505 .78002 m .30156 1.00435 L .2882 .9124 L 1 .106 .43 r
F
.30521 .77871 m .30514 .78354 L .30505 .78002 L F
.30514 .78354 m .30156 1.00435 L .30505 .78002 L F
.30514 .78354 m .31091 .93174 L .30243 .95069 L F
.30518 .77986 m .30534 .78213 L .30525 .78279 L 1 .034 .423 r
F
.30534 .78213 m .31356 .99991 L .30514 .78354 L 1 .106 .43 r
F
.30518 .77986 m .30904 .93858 L .30514 .78354 L 1 .034 .423 r
F
.30525 .77972 m .30534 .78213 L .30514 .78354 L 1 .106 .43 r
F
.30525 .78279 m .31591 .92465 L .30904 .93858 L 1 .034 .423 r
F
.30534 .78213 m .31591 .92465 L .30525 .78279 L F
.30514 .78354 m .30904 .93858 L .30335 .95014 L F
.30514 .78354 m .29986 .95643 L .29569 .96395 L F
.29022 .9263 m .29569 .96395 L .28844 .93744 L 1 .016 .378 r
F
.29569 .96395 m .30156 1.00435 L .29652 .97867 L F
.29569 .96395 m .29652 .97867 L .28844 .93744 L F
.29346 .96303 m .29427 .96717 L .28886 .97943 L F
.28844 .93744 m .28922 1.01635 L .28212 .98207 L F
.28886 .97943 m .28562 .99097 L .28454 .99378 L 0 0 0 r
F
.27592 1.01178 m .28454 .99378 L .27608 1.01122 L .8 0 .365 r
F
.27127 1.02846 m .28426 .99452 L .27592 1.01178 L F
.28426 .99452 m .28454 .99378 L .27592 1.01178 L F
.2683 1.12329 m .24901 1.08185 L .25434 1.14661 L 1 .484 .617 r
F
.2683 1.12329 m .26309 1.06627 L .24901 1.08185 L F
.26962 1.08406 m .27127 1.02847 L .25517 1.10861 L 1 .216 .451 r
F
.26309 1.06627 m .26311 .99961 L .24924 1.0069 L 1 .384 .616 r
F
.26309 1.06627 m .24924 1.0069 L .24901 1.08185 L F
.24924 1.0069 m .25501 .92276 L .2416 .92217 L 1 .275 .6 r
F
.26311 .99961 m .25501 .92276 L .24924 1.0069 L 1 .265 .607 r
F
.24924 1.0069 m .2416 .92217 L .23529 1.01509 L 1 .275 .6 r
F
.24901 1.08185 m .24924 1.0069 L .23529 1.01509 L 1 .371 .608 r
F
.27286 1.01811 m .27304 1.01883 L .26328 1.03794 L .732 0 .342 r
F
.26321 1.03824 m .26373 1.03705 L .26328 1.03794 L .882 .002 .427 r
F
.25699 1.06495 m .27299 1.01897 L .26321 1.03824 L F
.27304 1.01883 m .26328 1.03794 L .26328 1.03794 L .732 0 .342 r
F
.27299 1.01897 m .27304 1.01883 L .26321 1.03824 L .882 .002 .427 r
F
.26311 .99961 m .26835 .92486 L .25501 .92276 L 1 .265 .607 r
F
.27692 .99319 m .26835 .92486 L .26311 .99961 L 1 .258 .617 r
F
.26073 .97026 m .27278 1.01782 L .26328 1.03794 L .732 0 .342 r
F
.27278 1.01782 m .27286 1.01811 L .26335 1.03779 L F
.27278 1.01782 m .26335 1.03779 L .26328 1.03794 L F
.24901 1.08185 m .23529 1.01509 L .23484 1.0981 L 1 .371 .608 r
F
.25434 1.14661 m .24901 1.08185 L .23484 1.0981 L 1 .454 .609 r
F
.24267 1.09773 m .26113 1.04266 L .25799 1.04863 L .918 .026 .457 r
F
.25032 1.06327 m .25799 1.04863 L .25035 1.06314 L F
.24267 1.09773 m .25799 1.04863 L .25032 1.06327 L F
.25434 1.14661 m .23484 1.0981 L .24029 1.17025 L 1 .454 .609 r
F
.24029 1.17025 m .23484 1.0981 L .22059 1.11498 L 1 .433 .604 r
F
.24267 1.09773 m .25032 1.06327 L .22824 1.12887 L .918 .026 .457 r
F
.25035 1.06314 m .26107 1.04245 L .25037 1.06352 L .671 0 .332 r
F
.24702 .99299 m .26096 1.04207 L .25035 1.06314 L F
.26096 1.04207 m .26107 1.04245 L .25035 1.06314 L F
.25032 1.06327 m .25035 1.06314 L .24884 1.06623 L .918 .026 .457 r
F
.25032 1.06327 m .24884 1.06623 L .22824 1.12887 L F
.23529 1.01509 m .2416 .92217 L .22811 .92299 L 1 .284 .595 r
F
.23529 1.01509 m .22811 .92299 L .22125 1.02414 L F
.23484 1.0981 m .23529 1.01509 L .22125 1.02414 L 1 .362 .603 r
F
.24702 .99299 m .25036 1.0633 L .23323 1.01452 L .671 0 .332 r
F
.25036 1.0633 m .25081 1.07275 L .24884 1.06623 L F
.25036 1.0633 m .24884 1.06623 L .23323 1.01452 L F
.24881 1.06615 m .24884 1.06623 L .2458 1.07191 L .636 0 .326 r
F
.23323 1.01452 m .24881 1.06615 L .2458 1.07191 L F
.23323 1.01452 m .24572 1.07157 L .23727 1.08786 L F
.24572 1.07157 m .2458 1.07191 L .23727 1.08786 L F
.23484 1.0981 m .22125 1.02414 L .22059 1.11498 L 1 .362 .603 r
F
.24029 1.17025 m .22059 1.11498 L .22615 1.19426 L 1 .433 .604 r
F
.22615 1.19426 m .22059 1.11498 L .20625 1.13246 L 1 .418 .599 r
F
.22615 1.19426 m .20625 1.13246 L .21191 1.21869 L F
.22824 1.12887 m .23726 1.08791 L .21368 1.15934 L .944 .054 .474 r
F
.23726 1.08791 m .23724 1.08795 L .21368 1.15934 L F
.22059 1.11498 m .22125 1.02414 L .20714 1.034 L 1 .357 .598 r
F
.23727 1.08786 m .23622 1.08992 L .21933 1.0355 L .636 0 .326 r
F
.23727 1.08786 m .23626 1.08981 L .23622 1.08992 L .944 .054 .474 r
F
.23727 1.08786 m .23622 1.08992 L .21368 1.15934 L F
.23323 1.01452 m .23727 1.08786 L .21933 1.0355 L .636 0 .326 r
F
.23726 1.08791 m .23727 1.08786 L .23724 1.08795 L .944 .054 .474 r
F
.24884 1.06623 m .23955 1.08359 L .23703 1.08894 L F
.23703 1.08894 m .23955 1.08359 L .23727 1.08786 L F
.22824 1.12887 m .24884 1.06623 L .23703 1.08894 L F
.23727 1.08786 m .23763 1.09447 L .23622 1.08992 L .636 0 .326 r
F
.21933 1.0355 m .23611 1.08957 L .22401 1.11257 L .614 0 .323 r
F
.23611 1.08957 m .23622 1.08992 L .22401 1.11257 L F
.21191 1.21869 m .20625 1.13246 L .19181 1.15055 L 1 .407 .596 r
F
.21191 1.21869 m .19181 1.15055 L .19758 1.24357 L F
.21368 1.15934 m .22401 1.11257 L .19895 1.18964 L .964 .076 .483 r
F
.20625 1.13246 m .20714 1.034 L .19294 1.0446 L 1 .353 .594 r
F
.22059 1.11498 m .20714 1.034 L .20625 1.13246 L 1 .357 .598 r
F
.21933 1.0355 m .22401 1.11257 L .2053 1.0563 L .614 0 .323 r
F
.22401 1.11257 m .22331 1.11391 L .19895 1.18964 L .964 .076 .483 r
F
.21368 1.15934 m .23622 1.08992 L .22401 1.11257 L F
.22401 1.11257 m .22428 1.11703 L .22331 1.11391 L .614 0 .323 r
F
.22401 1.11257 m .22331 1.11391 L .2053 1.0563 L F
.22401 1.11257 m .22332 1.11387 L .22331 1.11391 L .964 .076 .483 r
F
.22401 1.11257 m .2246 1.10991 L .22332 1.11387 L F
.22401 1.11257 m .23807 1.08423 L .2246 1.10991 L F
.23622 1.08992 m .23807 1.08423 L .22401 1.11257 L F
.22401 1.11257 m .23622 1.08992 L .22406 1.11343 L .614 0 .323 r
F
.22406 1.11343 m .23763 1.09447 L .22428 1.11703 L F
.23622 1.08992 m .23763 1.09447 L .22406 1.11343 L F
.23727 1.08786 m .23807 1.08423 L .23626 1.08981 L .944 .054 .474 r
F
.24884 1.06623 m .25139 1.05848 L .23955 1.08359 L F
.23727 1.08786 m .2458 1.07191 L .23729 1.08817 L .636 0 .326 r
F
.2458 1.07191 m .24884 1.06623 L .23729 1.08817 L F
.23727 1.08786 m .25139 1.05848 L .23807 1.08423 L .944 .054 .474 r
F
.23955 1.08359 m .25139 1.05848 L .23727 1.08786 L F
.25035 1.06314 m .25139 1.05848 L .24892 1.06597 L .918 .026 .457 r
F
.25035 1.06314 m .24892 1.06597 L .24884 1.06623 L F
.24884 1.06623 m .25081 1.07275 L .23857 1.08671 L .636 0 .326 r
F
.24884 1.06623 m .23857 1.08671 L .23729 1.08817 L F
.23729 1.08817 m .25081 1.07275 L .23763 1.09447 L F
.25699 1.06495 m .26321 1.03824 L .24267 1.09773 L .882 .002 .427 r
F
.26321 1.03824 m .26328 1.03794 L .26308 1.0385 L F
.26321 1.03824 m .26308 1.0385 L .24267 1.09773 L F
.26073 .97026 m .26328 1.03794 L .24702 .99299 L .732 0 .342 r
F
.26328 1.03794 m .26113 1.04266 L .24267 1.09773 L .882 .002 .427 r
F
.27304 1.01883 m .26373 1.03705 L .26321 1.03824 L F
.27127 1.02846 m .27591 1.01182 L .25699 1.06495 L .8 0 .365 r
F
.27591 1.01182 m .27589 1.01187 L .25699 1.06495 L F
.27592 1.01178 m .27304 1.01883 L .25699 1.06495 L F
.25517 1.10861 m .27127 1.02847 L .25698 1.06496 L 1 .206 .475 r
F
.26328 1.03794 m .26381 1.05209 L .26113 1.04266 L .732 0 .342 r
F
.26328 1.03794 m .26113 1.04266 L .24702 .99299 L F
.26328 1.03794 m .26132 1.04208 L .26113 1.04266 L .882 .002 .427 r
F
.25035 1.06314 m .26457 1.0324 L .25139 1.05848 L .918 .026 .457 r
F
.26107 1.04245 m .26113 1.04266 L .25639 1.05167 L .671 0 .332 r
F
.26113 1.04266 m .26457 1.0324 L .25035 1.06314 L .918 .026 .457 r
F
.25639 1.05167 m .26113 1.04266 L .25037 1.06352 L .671 0 .332 r
F
.26113 1.04266 m .26203 1.04585 L .25366 1.05853 L F
.26113 1.04266 m .25366 1.05853 L .25037 1.06352 L F
.26328 1.03794 m .26457 1.0324 L .26132 1.04208 L .882 .002 .427 r
F
.27441 .94487 m .28212 .98207 L .2775 1.00976 L .84 .001 .356 r
F
.27611 1.01246 m .2775 1.00976 L .27623 1.01739 L F
.27592 1.01178 m .27608 1.01122 L .27304 1.01883 L .8 0 .365 r
F
.27441 .94487 m .27742 1.00794 L .27608 1.01122 L .84 .001 .356 r
F
.27591 1.01182 m .27592 1.01178 L .27589 1.01187 L .8 0 .365 r
F
.27441 .94487 m .27662 1.03296 L .26073 .97026 L .84 .001 .356 r
F
.27608 1.01122 m .27762 1.00567 L .27349 1.01753 L .8 0 .365 r
F
.27608 1.01122 m .27349 1.01753 L .27304 1.01883 L F
.27608 1.01122 m .2775 1.00976 L .27611 1.01246 L .84 .001 .356 r
F
.27742 1.00794 m .2775 1.00976 L .27608 1.01122 L F
.27304 1.01883 m .27349 1.01753 L .26373 1.03705 L .882 .002 .427 r
F
.27349 1.01753 m .27762 1.00567 L .26558 1.03287 L F
.27349 1.01753 m .26558 1.03287 L .26373 1.03705 L F
.26328 1.03794 m .27662 1.03296 L .26381 1.05209 L .732 0 .342 r
F
.26328 1.03794 m .26328 1.03794 L .26328 1.03794 L F
.26328 1.03794 m .27662 1.03296 L .26328 1.03794 L F
.27304 1.01883 m .26559 1.03708 L .26328 1.03794 L F
.26328 1.03794 m .27762 1.00567 L .26457 1.0324 L .882 .002 .427 r
F
.26373 1.03705 m .27762 1.00567 L .26328 1.03794 L F
.25037 1.06352 m .26203 1.04585 L .25081 1.07275 L .671 0 .332 r
F
.26203 1.04585 m .26381 1.05209 L .25154 1.07159 L F
.26203 1.04585 m .25154 1.07159 L .25081 1.07275 L F
.27304 1.01883 m .27662 1.03296 L .26559 1.03708 L .732 0 .342 r
F
.28454 .99378 m .28562 .99097 L .27608 1.01122 L .8 0 .365 r
F
.29512 .97153 m .29009 .98184 L .28886 .97943 L 1 .016 .378 r
F
.28886 .97943 m .29009 .98184 L .28891 .98425 L F
.28886 .97943 m .29056 .97807 L .28562 .99097 L 0 0 0 r
F
.28562 .99097 m .29056 .97807 L .27905 1.00441 L .8 0 .365 r
F
.28562 .99097 m .27905 1.00441 L .27608 1.01122 L F
.29427 .96717 m .29512 .97153 L .28886 .97943 L 1 .016 .378 r
F
.29512 .97153 m .30156 1.00435 L .29009 .98184 L F
.28886 .97943 m .29986 .95643 L .28996 .97855 L 0 0 0 r
F
.29569 .96395 m .29986 .95643 L .28886 .97943 L F
.28996 .97855 m .30335 .95014 L .29056 .97807 L F
.29986 .95643 m .30335 .95014 L .28996 .97855 L F
.30521 .77871 m .30525 .77972 L .30514 .78354 L 1 .106 .43 r
F
.30514 .78354 m .30335 .95014 L .29986 .95643 L 1 .034 .423 r
F
.31165 .93329 m .31281 .93511 L .30335 .95014 L 0 0 0 r
F
.31591 .92465 m .31281 .93511 L .31165 .93329 L F
.30335 .95014 m .31281 .93511 L .31403 .93098 L .687 0 .427 r
F
.31281 .93511 m .32519 .91542 L .31427 .93065 L F
.31281 .93511 m .31427 .93065 L .31403 .93098 L F
.28891 .98425 m .30156 1.00435 L .28922 1.01635 L 1 .016 .378 r
F
.29009 .98184 m .30156 1.00435 L .28891 .98425 L F
.27654 1.00953 m .29056 .97807 L .27762 1.00567 L .8 0 .365 r
F
.27608 1.01122 m .27905 1.00441 L .27654 1.00953 L F
.27905 1.00441 m .29056 .97807 L .27654 1.00953 L F
.28844 .93744 m .29346 .96303 L .28886 .97943 L 1 .016 .378 r
F
.27788 1.00751 m .28454 .99378 L .27623 1.01739 L .84 .001 .356 r
F
.28454 .99378 m .28922 1.01635 L .278 1.01725 L F
.28454 .99378 m .278 1.01725 L .27623 1.01739 L F
.27623 1.01739 m .28922 1.01635 L .27662 1.03296 L F
.2882 .9124 m .29022 .9263 L .28844 .93744 L 1 .016 .378 r
F
.28844 .93744 m .28212 .98207 L .27441 .94487 L F
.2913 .84968 m .2947 .85761 L .2882 .91238 L 0 0 .095 r
F
.29132 .84927 m .29136 .84935 L .2913 .84968 L F
.29136 .84935 m .2947 .85761 L .2913 .84968 L F
.29155 .84466 m .29187 .84595 L .29132 .84927 L F
.29187 .84595 m .2947 .85761 L .29132 .84927 L F
.29794 .80869 m .3008 .7877 L .29132 .84927 L .86 .07 .548 r
F
.3008 .7877 m .30625 .74772 L .29939 .79438 L F
.3008 .7877 m .29939 .79438 L .29132 .84927 L F
.29187 .84595 m .30567 .76521 L .2947 .85761 L 0 0 .095 r
F
.29794 .80869 m .30567 .76521 L .29187 .84595 L F
.29132 .84927 m .30625 .74772 L .29522 .71512 L .86 .07 .548 r
F
.28998 .85733 m .29522 .71512 L .28974 .85747 L F
.29132 .84927 m .29522 .71512 L .28996 .85779 L F
.29132 .84927 m .29123 .85115 L .28685 .85313 L 0 0 .095 r
F
.28996 .85779 m .28998 .85733 L .28974 .85747 L .86 .07 .548 r
F
.29123 .85115 m .2882 .91238 L .28685 .85313 L 0 0 .095 r
F
.28685 .85313 m .2882 .91238 L .27766 .86966 L F
.29002 .8504 m .29008 .84867 L .28685 .85313 L .86 .07 .548 r
F
.29008 .84867 m .29522 .71512 L .28685 .85313 L F
.27885 .86416 m .28685 .85313 L .27766 .86966 L .018 0 .07 r
F
.27942 .86153 m .28685 .85313 L .27885 .86416 L F
.27942 .86153 m .27934 .86189 L .27921 .86166 L F
.27942 .86153 m .27921 .86166 L .27133 .84779 L F
.27934 .86189 m .2781 .86253 L .27133 .84779 L F
.27885 .86416 m .27649 .86561 L .27133 .84779 L F
.27942 .86153 m .27874 .84099 L .27593 .86367 L .804 .094 .593 r
F
.27133 .84779 m .26725 .87233 L .25755 .86043 L .23 0 .182 r
F
.26725 .87233 m .26031 .87547 L .25755 .86043 L F
.25755 .86043 m .25451 .88173 L .24371 .87302 L .363 0 .24 r
F
.25451 .88173 m .24557 .88636 L .24371 .87302 L F
.24371 .87302 m .24143 .89053 L .22981 .88532 L .44 0 .27 r
F
.24143 .89053 m .23107 .89631 L .22981 .88532 L F
.22981 .88532 m .22813 .8991 L .21585 .89728 L .49 0 .287 r
F
.22813 .8991 m .21668 .90572 L .21585 .89728 L F
.21585 .89728 m .21466 .90761 L .20183 .90893 L .525 0 .297 r
F
.21466 .90761 m .20235 .91484 L .20183 .90893 L F
.20183 .90893 m .20104 .91614 L .18776 .92034 L .551 0 .305 r
F
.20089 .92804 m .20104 .91614 L .18717 .93186 L 1 .269 .58 r
F
.20104 .91614 m .18806 .9242 L .18803 .92384 L .551 0 .305 r
F
.20104 .91614 m .18803 .92384 L .18776 .92034 L F
.20104 .91614 m .20245 .80043 L .18806 .9242 L 1 .269 .58 r
F
.20104 .91614 m .18806 .9242 L .18717 .93186 L F
.19294 1.0446 m .20089 .92804 L .18717 .93186 L 1 .301 .586 r
F
.20104 .91614 m .19303 .98855 L .18806 .9242 L .551 0 .305 r
F
.20089 .92804 m .20236 .91535 L .20104 .91614 L 1 .269 .58 r
F
.20236 .91535 m .20238 .9152 L .20104 .91614 L F
.21454 .92502 m .21466 .90761 L .20089 .92804 L 1 .261 .58 r
F
.21466 .90761 m .21466 .9065 L .2135 .90833 L F
.21466 .90761 m .2135 .90833 L .20089 .92804 L F
.21466 .90761 m .21211 .90918 L .20235 .91484 L .525 0 .297 r
F
.2135 .90833 m .20238 .9152 L .20089 .92804 L 1 .261 .58 r
F
.21211 .90918 m .20238 .9152 L .20235 .91484 L .525 0 .297 r
F
.21466 .9065 m .20238 .9152 L .2135 .90833 L 1 .261 .58 r
F
.21464 .90771 m .20238 .9152 L .21211 .90918 L .525 0 .297 r
F
.21466 .90761 m .21464 .90771 L .21211 .90918 L F
.20714 1.034 m .21454 .92502 L .20089 .92804 L 1 .297 .589 r
F
.20714 1.034 m .20089 .92804 L .19294 1.0446 L F
.20103 .91615 m .20729 .97152 L .19303 .98855 L .551 0 .305 r
F
.20183 .90893 m .20238 .9152 L .20103 .91615 L F
.20238 .9152 m .20729 .97152 L .20103 .91615 L F
.21466 .9065 m .21536 .80318 L .20238 .9152 L 1 .261 .58 r
F
.20104 .91614 m .20238 .9152 L .20104 .91602 L 1 .269 .58 r
F
.20104 .91602 m .21536 .80318 L .20245 .80043 L F
.20238 .9152 m .21536 .80318 L .20104 .91602 L F
.21464 .90771 m .20729 .97152 L .20238 .9152 L .525 0 .297 r
F
.21454 .92502 m .21669 .90641 L .21466 .90761 L 1 .261 .58 r
F
.21669 .90641 m .21673 .90612 L .21466 .90761 L F
.22811 .92299 m .22813 .8991 L .21454 .92502 L 1 .248 .581 r
F
.22813 .8991 m .22813 .89787 L .22724 .89965 L F
.22813 .8991 m .22724 .89965 L .21454 .92502 L F
.22813 .8991 m .22673 .89996 L .21668 .90572 L .49 0 .287 r
F
.22724 .89965 m .21673 .90612 L .21454 .92502 L 1 .248 .581 r
F
.22673 .89996 m .21673 .90612 L .21668 .90572 L .49 0 .287 r
F
.22813 .89787 m .21673 .90612 L .22724 .89965 L 1 .248 .581 r
F
.22813 .89916 m .21673 .90612 L .22673 .89996 L .49 0 .287 r
F
.22813 .8991 m .22813 .89916 L .22673 .89996 L F
.22125 1.02414 m .22811 .92299 L .21454 .92502 L 1 .291 .591 r
F
.22125 1.02414 m .21454 .92502 L .20714 1.034 L F
.21466 .90762 m .22147 .95395 L .20729 .97152 L .525 0 .297 r
F
.21585 .89728 m .21673 .90612 L .21466 .90762 L F
.21673 .90612 m .22147 .95395 L .21466 .90762 L F
.22813 .89787 m .22822 .80672 L .21673 .90612 L 1 .248 .581 r
F
.21466 .90761 m .21673 .90612 L .21466 .90738 L 1 .261 .58 r
F
.21466 .90738 m .22822 .80672 L .21536 .80318 L F
.21673 .90612 m .22822 .80672 L .21466 .90738 L F
.22813 .89916 m .22147 .95395 L .21673 .90612 L .49 0 .287 r
F
.22811 .92299 m .23107 .8974 L .22813 .8991 L 1 .248 .581 r
F
.23107 .8974 m .23113 .89685 L .22813 .8991 L F
.2416 .92217 m .24143 .89053 L .22811 .92299 L 1 .228 .582 r
F
.24143 .89053 m .24143 .88907 L .24067 .89099 L F
.24143 .89053 m .24067 .89099 L .22811 .92299 L F
.24143 .89053 m .24029 .89123 L .23107 .89631 L .44 0 .27 r
F
.24067 .89099 m .23113 .89685 L .22811 .92299 L 1 .228 .582 r
F
.24029 .89123 m .23113 .89685 L .23107 .89631 L .44 0 .27 r
F
.24143 .88907 m .23113 .89685 L .24067 .89099 L 1 .228 .582 r
F
.24142 .8906 m .23113 .89685 L .24029 .89123 L .44 0 .27 r
F
.24143 .89053 m .24142 .8906 L .24029 .89123 L F
.22813 .89912 m .23559 .93549 L .22147 .95395 L .49 0 .287 r
F
.22981 .88532 m .23113 .89685 L .22813 .89912 L F
.23113 .89685 m .23559 .93549 L .22813 .89912 L F
.24143 .88907 m .24102 .81145 L .23113 .89685 L 1 .228 .582 r
F
.22813 .8991 m .23113 .89685 L .22813 .89867 L 1 .248 .581 r
F
.22813 .89867 m .24102 .81145 L .22822 .80672 L F
.23113 .89685 m .24102 .81145 L .22813 .89867 L F
.24142 .8906 m .23559 .93549 L .23113 .89685 L .44 0 .27 r
F
.2416 .92217 m .24555 .88823 L .24143 .89053 L 1 .228 .582 r
F
.24555 .88823 m .24568 .88714 L .24143 .89053 L F
.25501 .92276 m .25451 .88173 L .2416 .92217 L 1 .197 .584 r
F
.25451 .88173 m .25304 .88262 L .24557 .88636 L .363 0 .24 r
F
.25451 .88173 m .25448 .87994 L .25381 .88215 L 1 .197 .584 r
F
.25451 .88173 m .25381 .88215 L .2416 .92217 L F
.25381 .88215 m .24568 .88714 L .2416 .92217 L F
.25304 .88262 m .24568 .88714 L .24557 .88636 L .363 0 .24 r
F
.25448 .87994 m .24568 .88714 L .25381 .88215 L 1 .197 .584 r
F
.25448 .8819 m .24568 .88714 L .25304 .88262 L .363 0 .24 r
F
.25451 .88173 m .25448 .8819 L .25304 .88262 L F
.24142 .89061 m .24965 .91566 L .23559 .93549 L .44 0 .27 r
F
.24371 .87302 m .24568 .88714 L .24142 .89061 L F
.24568 .88714 m .24965 .91566 L .24142 .89061 L F
.25448 .87994 m .25372 .81799 L .24568 .88714 L 1 .197 .584 r
F
.24143 .89053 m .24568 .88714 L .24143 .88966 L 1 .228 .582 r
F
.24143 .88966 m .25372 .81799 L .24102 .81145 L F
.24568 .88714 m .25372 .81799 L .24143 .88966 L F
.25448 .8819 m .24965 .91566 L .24568 .88714 L .363 0 .24 r
F
.25501 .92276 m .26022 .87876 L .25451 .88173 L 1 .197 .584 r
F
.26022 .87876 m .26049 .87646 L .25451 .88173 L F
.26835 .92486 m .26725 .87233 L .25501 .92276 L .961 .15 .587 r
F
.26725 .87233 m .26566 .8733 L .26031 .87547 L .23 0 .182 r
F
.26725 .87233 m .2672 .87025 L .26663 .8727 L .961 .15 .587 r
F
.26725 .87233 m .26663 .8727 L .25501 .92276 L F
.26663 .8727 m .26049 .87646 L .25501 .92276 L F
.26566 .8733 m .26049 .87646 L .26031 .87547 L .23 0 .182 r
F
.2672 .87025 m .26049 .87646 L .26663 .8727 L .961 .15 .587 r
F
.26719 .87268 m .26049 .87646 L .26566 .8733 L .23 0 .182 r
F
.26725 .87233 m .26719 .87268 L .26566 .8733 L F
.25446 .88205 m .26367 .89382 L .24965 .91566 L .363 0 .24 r
F
.25755 .86043 m .26049 .87646 L .25446 .88205 L F
.26049 .87646 m .26367 .89382 L .25446 .88205 L F
.2672 .87025 m .26631 .82737 L .26049 .87646 L .961 .15 .587 r
F
.25451 .88173 m .26049 .87646 L .25448 .87986 L 1 .197 .584 r
F
.25448 .87986 m .26631 .82737 L .25372 .81799 L F
.26049 .87646 m .26631 .82737 L .25448 .87986 L F
.26719 .87268 m .26367 .89382 L .26049 .87646 L .23 0 .182 r
F
.26835 .92486 m .27531 .86868 L .26725 .87233 L .961 .15 .587 r
F
.27531 .86868 m .27593 .86367 L .26725 .87233 L F
.27133 .84779 m .27766 .86966 L .26367 .89382 L .23 0 .182 r
F
.26725 .87233 m .27593 .86367 L .26716 .86826 L .961 .15 .587 r
F
.26716 .86826 m .27874 .84099 L .26631 .82737 L F
.27593 .86367 m .27874 .84099 L .26716 .86826 L F
.27934 .86189 m .27885 .86416 L .2781 .86253 L .018 0 .07 r
F
.27885 .86416 m .27766 .86966 L .27649 .86561 L F
.49203 .77175 m .50065 .7629 L .48845 .76539 L .813 .682 .844 r
F
.49203 .77175 m .50246 .7699 L .50065 .7629 L F
.56276 .98924 m .56501 .99992 L .57259 .99467 L .887 .626 .804 r
F
.56276 .98924 m .55644 .99363 L .56501 .99992 L F
.51852 1.13556 m .49947 1.14644 L .51905 1.14376 L .979 .794 .819 r
F
.53624 1.13077 m .51852 1.13556 L .51905 1.14376 L 1 .797 .806 r
F
.59624 .98703 m .60087 .99732 L .60802 .99088 L .811 .636 .832 r
F
.59624 .98703 m .59 .99343 L .60087 .99732 L F
.43683 .77901 m .43872 .77082 L .42712 .77618 L .684 .593 .884 r
F
.43683 .77901 m .44714 .77393 L .43872 .77082 L F
.71211 .65696 m .74231 .73358 L .72296 .64644 L .71 .058 .589 r
F
.71211 .65696 m .73031 .73742 L .74231 .73358 L F
.34053 .79629 m .34241 .77582 L .33216 .79954 L 1 .711 .786 r
F
.34053 .79629 m .35022 .77764 L .34241 .77582 L F
.6 1.09755 m .59269 1.10404 L .60842 1.09636 L .558 .078 .838 r
F
.6 1.09755 m .58567 1.10413 L .59269 1.10404 L F
.52373 .7692 m .53773 .7641 L .52553 .76234 L .692 .578 .863 r
F
.5131 .76903 m .52373 .7692 L .52553 .76234 L .749 .624 .852 r
F
.54215 .99018 m .54158 1.0008 L .54933 .99753 L .894 .605 .796 r
F
.54215 .99018 m .53593 .99274 L .54158 1.0008 L F
.45086 1.16962 m .42914 1.17252 L .42275 1.18649 L 1 .812 .722 r
F
.45555 1.15972 m .42914 1.17252 L .45086 1.16962 L 1 .786 .739 r
F
.50246 .7699 m .51309 .76186 L .50065 .7629 L .793 .659 .845 r
F
.50246 .7699 m .5131 .76903 L .51309 .76186 L F
.40959 .99682 m .40244 .99023 L .39022 .99385 L .808 .715 .856 r
F
.42099 .99383 m .40244 .99023 L .40959 .99682 L .835 .688 .838 r
F
.52538 1.40738 m .48349 1.43093 L .52595 1.44794 L .927 .118 .573 r
F
.56583 1.40854 m .52538 1.40738 L .52595 1.44794 L .925 .122 .577 r
F
.6743 .75536 m .69228 .78561 L .68201 .75289 L .039 0 .674 r
F
.68201 .75289 m .69228 .78561 L .69348 .78693 L .209 0 .651 r
F
.5131 .76903 m .52553 .76234 L .51309 .76186 L .749 .624 .852 r
F
.56048 .76959 m .57894 .769 L .56737 .76556 L .546 .387 .893 r
F
.54946 .76668 m .56048 .76959 L .56737 .76556 L .549 .397 .888 r
F
.48348 1.43093 m .43739 1.43846 L .48213 1.47241 L .96 .136 .577 r
F
.72296 .64644 m .75433 .72973 L .73383 .63641 L .707 .055 .586 r
F
.72296 .64644 m .74231 .73358 L .75433 .72973 L F
.48733 .99196 m .47327 .99614 L .48093 .9997 L .859 .586 .801 r
F
.49396 .99415 m .48733 .99196 L .48093 .9997 L .865 .585 .799 r
F
.62596 .98824 m .63152 .99856 L .63846 .99341 L .609 .456 .862 r
F
.62596 .98824 m .61978 .99471 L .63152 .99856 L F
.51852 1.13556 m .50069 1.13849 L .49947 1.14644 L .979 .794 .819 r
F
.50068 1.13849 m .47958 1.14864 L .49947 1.14644 L 1 .805 .813 r
F
.68201 .75289 m .69348 .78693 L .68311 .75254 L .209 0 .651 r
F
.68311 .75254 m .69349 .78694 L .70637 .80028 L .26 0 .653 r
F
.4571 .99781 m .44989 .99229 L .43944 .99685 L .805 .57 .814 r
F
.46637 .99198 m .44989 .99229 L .4571 .99781 L .838 .587 .808 r
F
.47327 .99614 m .46637 .99198 L .4571 .99781 L .834 .576 .806 r
F
.43944 .99685 m .43242 .99031 L .42099 .99383 L .791 .593 .826 r
F
.44989 .99229 m .43242 .99031 L .43944 .99685 L .828 .602 .816 r
F
.52595 1.44794 m .48349 1.43093 L .48214 1.47242 L .938 .124 .575 r
F
.60523 1.38661 m .5683 1.44623 L .60951 1.42126 L .974 .149 .583 r
F
.60523 1.38661 m .56583 1.40854 L .5683 1.44623 L F
.6803 1.19816 m .65806 1.18418 L .66717 1.22043 L .339 0 .58 r
F
.66991 1.16614 m .65806 1.18418 L .6803 1.19816 L .27 0 .557 r
F
.54784 .9871 m .54933 .99753 L .55644 .99363 L .89 .609 .798 r
F
.54784 .9871 m .54215 .99018 L .54933 .99753 L F
.68567 1.28962 m .65629 1.2715 L .66392 1.30297 L .404 .001 .6 r
F
.67641 1.2554 m .65629 1.2715 L .68567 1.28962 L .416 .001 .6 r
F
.37387 .78214 m .37369 .76804 L .36206 .78003 L .701 .541 .846 r
F
.37387 .78214 m .38459 .7728 L .37369 .76804 L F
.57894 .769 m .5989 .76896 L .58734 .76628 L .522 .311 .9 r
F
.46565 .77307 m .47139 .76358 L .45873 .76879 L .804 .717 .859 r
F
.46565 .77307 m .4767 .76894 L .47139 .76358 L F
.73383 .63641 m .76638 .72588 L .74473 .62661 L .705 .054 .584 r
F
.73383 .63641 m .75433 .72973 L .76638 .72588 L F
.56737 .76556 m .57894 .769 L .58734 .76628 L .474 .246 .898 r
F
.56818 .98443 m .56276 .98924 L .57259 .99467 L .876 .622 .806 r
F
.40635 .77922 m .40758 .77052 L .39548 .77635 L .609 .485 .892 r
F
.40635 .77922 m .41737 .77342 L .40758 .77052 L F
.51477 .98749 m .50818 .99652 L .5153 .99661 L .886 .595 .795 r
F
.52009 .98703 m .5153 .99661 L .52239 .996 L .889 .596 .795 r
F
.52009 .98703 m .51477 .98749 L .5153 .99661 L F
.51477 .98749 m .50941 .98743 L .50818 .99652 L .886 .595 .795 r
F
.50941 .98743 m .50095 .99569 L .50818 .99652 L .883 .595 .796 r
F
.4812 .98918 m .46637 .99198 L .47327 .99614 L .856 .589 .803 r
F
.48733 .99196 m .4812 .98918 L .47327 .99614 L .859 .586 .801 r
F
.68311 .75254 m .70637 .80028 L .69483 .74878 L .26 0 .653 r
F
.27874 .84099 m .29522 .71512 L .28339 .70589 L 1 .232 .557 r
F
.52529 .98607 m .52239 .996 L .52931 .99469 L .89 .597 .795 r
F
.52529 .98607 m .52009 .98703 L .52239 .996 L F
.33216 .79954 m .3413 .77554 L .33097 .80012 L 1 .663 .748 r
F
.33216 .79954 m .34241 .77582 L .3413 .77554 L F
.61347 .98389 m .61978 .99471 L .62596 .98824 L .714 .539 .839 r
F
.61347 .98389 m .60802 .99088 L .61978 .99471 L F
.54946 .76668 m .56737 .76556 L .55475 .76168 L .549 .397 .888 r
F
.53773 .7641 m .54946 .76668 L .55475 .76168 L .593 .458 .876 r
F
.42099 .99383 m .41468 .98685 L .40244 .99023 L .835 .688 .838 r
F
.43242 .99031 m .41468 .98685 L .42099 .99383 L .852 .66 .824 r
F
.50398 .98684 m .49396 .99415 L .50095 .99569 L .879 .594 .797 r
F
.50941 .98743 m .50398 .98684 L .50095 .99569 L .883 .595 .796 r
F
.26631 .82737 m .28339 .70589 L .27153 .69758 L 1 .248 .564 r
F
.27874 .84099 m .28339 .70589 L .26631 .82737 L 1 .232 .557 r
F
.35184 1.05765 m .3397 1.07527 L .33174 1.07283 L .617 0 .165 r
F
.56583 1.40854 m .52595 1.44794 L .5683 1.44623 L .925 .122 .577 r
F
.74473 .62661 m .77846 .72201 L .75563 .61688 L .704 .052 .583 r
F
.74473 .62661 m .76638 .72588 L .77846 .72201 L F
.53027 .98462 m .52931 .99469 L .53593 .99274 L .89 .599 .795 r
F
.53027 .98462 m .52529 .98607 L .52931 .99469 L F
.33097 .80012 m .32945 .77214 L .31811 .80882 L 1 .627 .741 r
F
.33097 .80012 m .3413 .77554 L .32945 .77214 L F
.55289 .98356 m .55644 .99363 L .56276 .98924 L .886 .611 .8 r
F
.55289 .98356 m .54784 .9871 L .55644 .99363 L F
.40506 1.23376 m .37064 1.26317 L .39859 1.25447 L 1 .629 .635 r
F
.40506 1.23376 m .3788 1.23878 L .37064 1.26317 L F
.41151 1.21498 m .3788 1.23878 L .40506 1.23376 L 1 .627 .646 r
F
.41151 1.21498 m .3869 1.21648 L .3788 1.23878 L F
.41792 1.19807 m .3869 1.21648 L .41151 1.21498 L 1 .624 .659 r
F
.47958 1.14864 m .46027 1.15003 L .45555 1.15972 L 1 .836 .788 r
F
.48257 1.14025 m .46027 1.15003 L .47958 1.14864 L 1 .797 .791 r
F
.50068 1.13849 m .48257 1.14025 L .47958 1.14864 L 1 .805 .813 r
F
.49873 .98573 m .48733 .99196 L .49396 .99415 L .875 .595 .799 r
F
.50398 .98684 m .49873 .98573 L .49396 .99415 L .879 .594 .797 r
F
.4767 .76894 m .48485 .75875 L .47139 .76358 L .857 .728 .841 r
F
.4767 .76894 m .48845 .76539 L .48485 .75875 L F
.39859 1.25448 m .3623 1.2898 L .39198 1.27746 L 1 .629 .626 r
F
.39859 1.25448 m .37063 1.26318 L .3623 1.2898 L F
.25372 .81799 m .27153 .69758 L .25963 .68963 L 1 .256 .569 r
F
.26631 .82737 m .27153 .69758 L .25372 .81799 L 1 .248 .564 r
F
.45555 1.15972 m .43552 1.16 L .42914 1.17252 L 1 .786 .739 r
F
.46027 1.15003 m .43552 1.16 L .45555 1.15972 L 1 .763 .755 r
F
.44714 .77393 m .45178 .76511 L .43872 .77082 L .729 .652 .879 r
F
.44714 .77393 m .45873 .76879 L .45178 .76511 L F
.54959 1.11709 m .53624 1.13077 L .55354 1.12341 L 1 .827 .807 r
F
.56454 1.10972 m .55354 1.12341 L .57011 1.11385 L 1 .861 .817 r
F
.56454 1.10972 m .54959 1.11709 L .55354 1.12341 L F
.53398 1.12318 m .51852 1.13556 L .53624 1.13077 L 1 .806 .81 r
F
.54959 1.11709 m .53398 1.12318 L .53624 1.13077 L 1 .827 .807 r
F
.53494 .98273 m .53593 .99274 L .54215 .99018 L .889 .6 .796 r
F
.53494 .98273 m .53027 .98462 L .53593 .99274 L F
.61286 1.09484 m .60842 1.09636 L .62263 1.09763 L .19 0 .681 r
F
.61286 1.09484 m .6 1.09755 L .60842 1.09636 L F
.39022 .99385 m .37169 .99274 L .37801 .99802 L .992 .893 .839 r
F
.42712 .77618 m .43025 .76825 L .41737 .77342 L .633 .496 .892 r
F
.42712 .77618 m .43872 .77082 L .43025 .76825 L F
.41792 1.19807 m .39496 1.19647 L .3869 1.21648 L 1 .624 .659 r
F
.41852 1.19658 m .39496 1.19647 L .41793 1.19807 L 1 .648 .67 r
F
.44989 .99229 m .44388 .98645 L .43242 .99031 L .828 .602 .816 r
F
.46037 .98736 m .44388 .98645 L .44989 .99229 L .852 .605 .809 r
F
.46637 .99198 m .46037 .98736 L .44989 .99229 L .838 .587 .808 r
F
.41852 1.19658 m .39571 1.19473 L .39496 1.19647 L 1 .648 .67 r
F
.42275 1.18649 m .39571 1.19472 L .41853 1.19657 L 1 .633 .675 r
F
.518 1.12753 m .50069 1.13849 L .51852 1.13556 L .999 .796 .814 r
F
.53398 1.12318 m .518 1.12753 L .51852 1.13556 L 1 .806 .81 r
F
.75563 .61688 m .79056 .71813 L .76656 .60715 L .703 .051 .582 r
F
.75563 .61688 m .77846 .72201 L .79056 .71813 L F
.57858 1.1023 m .57011 1.11385 L .58567 1.10413 L .915 .836 .851 r
F
.57858 1.1023 m .56454 1.10972 L .57011 1.11385 L F
.53773 .7641 m .55475 .76168 L .54131 .75788 L .593 .458 .876 r
F
.52553 .76234 m .53773 .7641 L .54131 .75788 L .672 .539 .859 r
F
.36206 .78003 m .36281 .7613 L .35023 .77763 L .74 .455 .8 r
F
.36206 .78003 m .37369 .76804 L .36281 .7613 L F
.47567 .98589 m .46037 .98736 L .46637 .99198 L .859 .596 .804 r
F
.4812 .98918 m .47567 .98589 L .46637 .99198 L .856 .589 .803 r
F
.24102 .81145 m .25963 .68963 L .24773 .68185 L 1 .262 .572 r
F
.25372 .81799 m .25963 .68963 L .24102 .81145 L 1 .256 .569 r
F
.49375 .98413 m .4812 .98918 L .48733 .99196 L .872 .595 .8 r
F
.49873 .98573 m .49375 .98413 L .48733 .99196 L .875 .595 .799 r
F
.39198 1.27746 m .3539 1.3181 L .38533 1.30233 L 1 .626 .618 r
F
.39198 1.27746 m .3623 1.2898 L .3539 1.3181 L F
.48845 .76539 m .49883 .75527 L .48485 .75875 L .873 .701 .829 r
F
.48845 .76539 m .50065 .7629 L .49883 .75527 L F
.69483 .74878 m .71921 .80976 L .70657 .74503 L .466 .012 .623 r
F
.69483 .74878 m .70637 .80028 L .71921 .80976 L F
.65706 1.12031 m .64212 1.10585 L .65201 1.11907 L 0 0 .564 r
F
.66824 1.13704 m .65201 1.11907 L .65867 1.13411 L 0 0 .575 r
F
.42275 1.18649 m .401 1.18303 L .39571 1.19472 L 1 .633 .675 r
F
.42914 1.17252 m .401 1.18303 L .42275 1.18649 L 1 .627 .691 r
F
.53921 .98042 m .54215 .99018 L .54784 .9871 L .888 .602 .797 r
F
.53921 .98042 m .53494 .98273 L .54215 .99018 L F
.43242 .99031 m .42693 .98355 L .41468 .98685 L .852 .66 .824 r
F
.44388 .98645 m .42693 .98355 L .43242 .99031 L .864 .64 .815 r
F
.52553 .76234 m .54131 .75788 L .52733 .75502 L .672 .539 .859 r
F
.51309 .76186 m .52553 .76234 L .52733 .75502 L .765 .609 .841 r
F
.39022 .99385 m .38457 .98704 L .37169 .99274 L .992 .893 .839 r
F
.40244 .99023 m .38457 .98704 L .39022 .99385 L .958 .834 .835 r
F
.55723 .97963 m .56276 .98924 L .56818 .98443 L .881 .608 .8 r
F
.55723 .97963 m .55289 .98356 L .56276 .98924 L F
.64599 1.1079 m .64212 1.10585 L .65706 1.12031 L 0 0 .562 r
F
.50065 .7629 m .51308 .75398 L .49883 .75527 L .839 .661 .829 r
F
.50065 .7629 m .51309 .76186 L .51308 .75398 L F
.60951 1.42126 m .57078 1.48479 L .61382 1.45688 L .983 .15 .581 r
F
.60951 1.42126 m .5683 1.44623 L .57078 1.48479 L F
.22822 .80672 m .24773 .68185 L .2358 .67417 L 1 .265 .574 r
F
.24102 .81145 m .24773 .68185 L .22822 .80672 L 1 .262 .572 r
F
.76656 .60715 m .80269 .71425 L .77749 .59736 L .702 .05 .581 r
F
.76656 .60715 m .79056 .71813 L .80269 .71425 L F
.518 1.12753 m .50191 1.13028 L .50069 1.13849 L .999 .796 .814 r
F
.50191 1.13028 m .48257 1.14025 L .50068 1.13849 L 1 .79 .809 r
F
.51309 .76186 m .52733 .75502 L .51308 .75398 L .765 .609 .841 r
F
.69498 1.32365 m .66392 1.30297 L .67158 1.33463 L .396 0 .599 r
F
.68567 1.28962 m .66392 1.30297 L .69498 1.32365 L .404 .001 .6 r
F
.56737 .76556 m .58734 .76628 L .57431 .76238 L .474 .246 .898 r
F
.55475 .76168 m .56737 .76556 L .57431 .76238 L .472 .263 .892 r
F
.39548 .77635 m .39776 .76711 L .38459 .7728 L .577 .438 .892 r
F
.39548 .77635 m .40758 .77052 L .39776 .76711 L F
.52595 1.44794 m .48214 1.47242 L .52653 1.48883 L .938 .124 .575 r
F
.5683 1.44623 m .52595 1.44794 L .52653 1.48883 L .942 .129 .577 r
F
.48915 .98207 m .47567 .98589 L .4812 .98918 L .871 .597 .801 r
F
.49375 .98413 m .48915 .98207 L .4812 .98918 L .872 .595 .8 r
F
.5915 1.09625 m .58567 1.10413 L .6 1.09755 L .663 .479 .883 r
F
.5915 1.09625 m .57858 1.1023 L .58567 1.10413 L F
.74282 .85735 m .73967 .82688 L .7531 .83437 L .823 0 .33 r
F
.7367 .85366 m .73967 .82688 L .74282 .85735 L F
.732 .81584 m .74282 .85735 L .74496 .81999 L .654 .038 .583 r
F
.74282 .85735 m .75592 .90763 L .75019 .86179 L F
.75642 .86447 m .7531 .83437 L .76659 .84178 L .819 0 .322 r
F
.75632 .86441 m .7531 .83437 L .75642 .86447 L F
.75008 .86091 m .7531 .83437 L .75632 .86441 L F
.75008 .86091 m .75012 .86122 L .75642 .86447 L .664 .041 .583 r
F
.75012 .86122 m .75592 .90763 L .75642 .86447 L F
.75642 .86447 m .75592 .90763 L .76958 .91558 L F
.74282 .85735 m .74229 .89916 L .75592 .90763 L .654 .038 .583 r
F
.73669 .85377 m .7367 .85366 L .74282 .85735 L .823 0 .33 r
F
.732 .81584 m .73669 .85377 L .74282 .85735 L .654 .038 .583 r
F
.73678 .85449 m .74229 .89916 L .74282 .85735 L F
.73414 .87672 m .74282 .85735 L .74737 .88466 L .823 0 .33 r
F
.74282 .85735 m .7531 .83437 L .75009 .86078 L F
.75622 .86371 m .75008 .86091 L .75642 .86447 L .664 .041 .583 r
F
.74282 .85735 m .75009 .86078 L .75008 .86091 L .823 0 .33 r
F
.74496 .81999 m .75008 .86091 L .75622 .86371 L .664 .041 .583 r
F
.74282 .85735 m .75019 .86179 L .75008 .86091 L .654 .038 .583 r
F
.74286 .85761 m .75008 .86091 L .74737 .88466 L .823 0 .33 r
F
.74282 .85735 m .75008 .86091 L .74286 .85761 L F
.73669 .85377 m .73678 .85449 L .74282 .85735 L .654 .038 .583 r
F
.73414 .87672 m .73669 .85377 L .74282 .85735 L .823 0 .33 r
F
.74737 .88466 m .75642 .86447 L .76072 .89396 L .819 0 .322 r
F
.75642 .86447 m .76659 .84178 L .76362 .86819 L F
.75642 .86447 m .76958 .91558 L .76366 .86856 L .664 .041 .583 r
F
.75642 .86447 m .76366 .86856 L .76362 .8682 L F
.75642 .86447 m .76362 .86819 L .76362 .8682 L .819 0 .322 r
F
.75642 .86447 m .76362 .8682 L .75793 .82309 L .664 .041 .583 r
F
.75642 .86447 m .76362 .8682 L .76072 .89396 L .819 0 .322 r
F
.75008 .86091 m .75632 .86441 L .75634 .86464 L F
.74496 .81999 m .75642 .86447 L .75793 .82309 L .664 .041 .583 r
F
.75634 .86464 m .75632 .86441 L .75642 .86447 L .819 0 .322 r
F
.74737 .88466 m .75008 .86091 L .75634 .86464 L F
.74286 .85661 m .75008 .86091 L .74496 .81999 L .654 .038 .583 r
F
.74282 .85735 m .75008 .86091 L .74286 .85661 L F
.38533 1.30233 m .34544 1.34789 L .37864 1.32893 L 1 .621 .612 r
F
.38533 1.30233 m .3539 1.3181 L .34544 1.34789 L F
.21536 .80318 m .2358 .67417 L .22387 .66655 L 1 .267 .575 r
F
.22822 .80672 m .2358 .67417 L .21536 .80318 L 1 .265 .574 r
F
.543 .97775 m .54784 .9871 L .55289 .98356 L .887 .602 .797 r
F
.543 .97775 m .53921 .98042 L .54784 .9871 L F
.40244 .99023 m .39742 .9827 L .38457 .98704 L .958 .834 .835 r
F
.41468 .98685 m .39742 .9827 L .40244 .99023 L .929 .762 .827 r
F
.66824 1.13704 m .65867 1.13411 L .67567 1.15048 L 0 0 .575 r
F
.67568 1.15048 m .65867 1.13411 L .65963 1.13658 L .066 0 .586 r
F
.51423 .97839 m .50941 .98743 L .51477 .98749 L .886 .599 .796 r
F
.51779 .97808 m .51477 .98749 L .52009 .98703 L .887 .599 .796 r
F
.51779 .97808 m .51423 .97839 L .51477 .98749 L F
.45873 .76879 m .46605 .75857 L .45178 .76511 L .828 .752 .86 r
F
.45873 .76879 m .47139 .76358 L .46605 .75857 L F
.51423 .97839 m .51066 .97836 L .50941 .98743 L .886 .599 .796 r
F
.51066 .97836 m .50398 .98684 L .50941 .98743 L .885 .599 .797 r
F
.42914 1.17252 m .40898 1.16736 L .401 1.18303 L 1 .627 .691 r
F
.43552 1.16 m .40898 1.16736 L .42914 1.17252 L 1 .635 .713 r
F
.31762 .76732 m .32302 .6965 L .30658 .73807 L .748 .076 .595 r
F
.46037 .98736 m .45537 .98234 L .44388 .98645 L .852 .605 .809 r
F
.47087 .98216 m .45537 .98234 L .46037 .98736 L .867 .606 .804 r
F
.47567 .98589 m .47087 .98216 L .46037 .98736 L .859 .596 .804 r
F
.52126 .97744 m .52009 .98703 L .52529 .98607 L .888 .599 .796 r
F
.52126 .97744 m .51779 .97808 L .52009 .98703 L F
.67568 1.15048 m .65963 1.13658 L .67673 1.15253 L .066 0 .586 r
F
.67674 1.15253 m .65963 1.13659 L .66991 1.16614 L .115 0 .578 r
F
.57431 .76238 m .58734 .76628 L .59579 .76465 L .363 .078 .889 r
F
.50703 .97798 m .49873 .98573 L .50398 .98684 L .883 .6 .798 r
F
.51066 .97836 m .50703 .97798 L .50398 .98684 L .885 .599 .797 r
F
.35023 .77763 m .35567 .75524 L .34242 .77582 L .779 .343 .745 r
F
.35023 .77763 m .36281 .7613 L .35567 .75524 L F
.70657 .74503 m .732 .81583 L .71834 .74126 L .578 .031 .604 r
F
.70657 .74503 m .71921 .80976 L .732 .81583 L F
.46027 1.15003 m .4419 1.14872 L .43552 1.16 L 1 .763 .755 r
F
.46499 1.14059 m .4419 1.14872 L .46027 1.15003 L 1 .746 .77 r
F
.48257 1.14025 m .46499 1.14059 L .46027 1.15003 L 1 .797 .791 r
F
.52459 .97647 m .52529 .98607 L .53027 .98462 L .888 .599 .796 r
F
.52459 .97647 m .52126 .97744 L .52529 .98607 L F
.44388 .98645 m .43919 .98026 L .42693 .98355 L .864 .64 .815 r
F
.45537 .98234 m .43919 .98026 L .44388 .98645 L .873 .626 .808 r
F
.21536 .80318 m .22387 .66655 L .20245 .80043 L 1 .267 .575 r
F
.33126 1.09 m .30524 1.10788 L .31858 1.13868 L 1 .649 .592 r
F
.34606 1.15973 m .33126 1.09001 L .31858 1.13869 L 1 .27 .548 r
F
.3569 1.13669 m .33126 1.09001 L .34606 1.15973 L 1 .19 .503 r
F
.485 .97961 m .47087 .98216 L .47567 .98589 L .873 .601 .801 r
F
.48915 .98207 m .485 .97961 L .47567 .98589 L .871 .597 .801 r
F
.56076 .97535 m .56818 .98443 L .5726 .97924 L .877 .6 .8 r
F
.56076 .97535 m .55723 .97963 L .56818 .98443 L F
.50352 .97726 m .49375 .98413 L .49873 .98573 L .882 .6 .798 r
F
.50703 .97798 m .50352 .97726 L .49873 .98573 L .883 .6 .798 r
F
.6803 1.19816 m .66717 1.22043 L .69076 1.23076 L .339 0 .58 r
F
.69076 1.23077 m .66717 1.22044 L .67641 1.2554 L .371 0 .589 r
F
.48557 1.13166 m .46499 1.14059 L .48257 1.14025 L 1 .774 .796 r
F
.50191 1.13028 m .48557 1.13166 L .48257 1.14025 L 1 .79 .809 r
F
.5683 1.44623 m .52653 1.48883 L .57078 1.48479 L .942 .129 .577 r
F
.52771 .97521 m .53027 .98462 L .53494 .98273 L .888 .6 .796 r
F
.52771 .97521 m .52459 .97647 L .53027 .98462 L F
.41468 .98685 m .41026 .97923 L .39742 .9827 L .929 .762 .827 r
F
.42693 .98355 m .41026 .97923 L .41468 .98685 L .91 .707 .818 r
F
.55475 .76168 m .57431 .76238 L .56007 .7572 L .472 .263 .892 r
F
.54131 .75788 m .55475 .76168 L .56007 .7572 L .529 .359 .877 r
F
.54625 .97475 m .55289 .98356 L .55723 .97963 L .885 .601 .797 r
F
.54625 .97475 m .543 .97775 L .55289 .98356 L F
.32302 .69649 m .34136 .71629 L .33153 .70202 L 0 0 .517 r
F
.33337 .72168 m .34139 .71632 L .32302 .6965 L .039 0 .71 r
F
.33337 .72168 m .35112 .72964 L .34139 .71632 L F
.34392 .74097 m .35112 .72964 L .33337 .72168 L .284 .016 .775 r
F
.33153 .70202 m .34546 .73358 L .3217 .68775 L .803 0 0 r
F
.33153 .70202 m .3217 .68775 L .32167 .6877 L F
.34136 .71629 m .34139 .71632 L .33153 .70202 L 0 0 .517 r
F
.31762 .76732 m .33337 .72168 L .32302 .6965 L .748 .076 .595 r
F
.63498 1.09894 m .63237 1.10056 L .64599 1.1079 L .022 0 .76 r
F
.65617 .99232 m .65099 .99967 L .66354 1.00731 L .412 .128 .821 r
F
.6431 .98522 m .65099 .99967 L .65617 .99232 L .517 .255 .823 r
F
.6431 .98522 m .63846 .99341 L .65099 .99967 L F
.41737 .77342 m .42173 .76621 L .40758 .77052 L .562 .32 .895 r
F
.41737 .77342 m .43025 .76825 L .42173 .76621 L F
.57595 .97367 m .58443 .98314 L .58846 .97676 L .856 .585 .802 r
F
.57595 .97367 m .5726 .97924 L .58443 .98314 L F
.53171 1.11593 m .518 1.12753 L .53398 1.12318 L 1 .803 .815 r
F
.54561 1.11098 m .53398 1.12318 L .54959 1.11709 L 1 .818 .818 r
F
.54561 1.11098 m .53171 1.11593 L .53398 1.12318 L F
.5002 .9762 m .48915 .98207 L .49375 .98413 L .881 .601 .799 r
F
.50352 .97726 m .5002 .9762 L .49375 .98413 L .882 .6 .798 r
F
.63008 .97978 m .63846 .99341 L .6431 .98522 L .618 .367 .818 r
F
.63008 .97978 m .62596 .98824 L .63846 .99341 L F
.37864 1.32893 m .33692 1.37901 L .3719 1.35709 L 1 .615 .607 r
F
.37864 1.32893 m .34544 1.34789 L .33692 1.37901 L F
.55894 1.10516 m .54959 1.11709 L .56454 1.10972 L .974 .831 .829 r
F
.55894 1.10516 m .54561 1.11098 L .54959 1.11709 L F
.43872 .77082 m .44478 .7624 L .43025 .76825 L .672 .536 .886 r
F
.43872 .77082 m .45178 .76511 L .44478 .7624 L F
.6693 1.00147 m .66354 1.00731 L .67613 1.01656 L .288 .029 .807 r
F
.65617 .99232 m .66354 1.00731 L .6693 1.00147 L .412 .128 .821 r
F
.31811 .80882 m .32945 .77214 L .31761 .76733 L 1 .472 .679 r
F
.47139 .76358 m .48123 .75179 L .46605 .75857 L .931 .773 .828 r
F
.47139 .76358 m .48485 .75875 L .48123 .75179 L F
.53055 .97366 m .53494 .98273 L .53921 .98042 L .888 .6 .796 r
F
.53055 .97366 m .52771 .97521 L .53494 .98273 L F
.34241 .77582 m .35465 .75425 L .34131 .77554 L .821 .298 .712 r
F
.34241 .77582 m .35566 .75524 L .35465 .75425 L F
.51747 1.11965 m .50191 1.13028 L .518 1.12753 L .996 .791 .814 r
F
.53171 1.11593 m .51747 1.11965 L .518 1.12753 L 1 .803 .815 r
F
.43552 1.16 m .41693 1.15401 L .40898 1.16736 L 1 .635 .713 r
F
.4419 1.14872 m .41693 1.15401 L .43552 1.16 L 1 .649 .737 r
F
.38459 .7728 m .38792 .7627 L .37369 .76804 L .543 .387 .886 r
F
.38459 .7728 m .39776 .76711 L .38792 .7627 L F
.61708 .97561 m .62596 .98824 L .63008 .97978 L .705 .449 .812 r
F
.61708 .97561 m .61347 .98389 L .62596 .98824 L F
.3413 .77554 m .34392 .74097 L .32945 .77214 L .747 .201 .689 r
F
.3413 .77554 m .35465 .75425 L .34392 .74097 L F
.6693 1.00147 m .67613 1.01656 L .68252 1.01293 L .288 .029 .807 r
F
.49712 .97484 m .485 .97961 L .48915 .98207 L .881 .601 .799 r
F
.5002 .9762 m .49712 .97484 L .48915 .98207 L F
.57145 1.09913 m .56454 1.10972 L .57858 1.1023 L .885 .803 .852 r
F
.57145 1.09913 m .55894 1.10516 L .56454 1.10972 L F
.42693 .98355 m .42309 .97629 L .41026 .97923 L .91 .707 .818 r
F
.43919 .98026 m .42309 .97629 L .42693 .98355 L .899 .668 .812 r
F
.47087 .98216 m .46688 .97806 L .45537 .98234 L .867 .606 .804 r
F
.4814 .97679 m .46688 .97806 L .47087 .98216 L .878 .605 .801 r
F
.485 .97961 m .4814 .97679 L .47087 .98216 L .873 .601 .801 r
F
.71834 .74126 m .74496 .81999 L .73031 .73742 L .633 .04 .594 r
F
.71834 .74126 m .732 .81584 L .74496 .81999 L F
.45537 .98234 m .45148 .97697 L .43919 .98026 L .873 .626 .808 r
F
.46688 .97806 m .45148 .97697 L .45537 .98234 L .879 .617 .804 r
F
.54131 .75788 m .56007 .7572 L .54491 .75162 L .529 .359 .877 r
F
.52733 .75502 m .54131 .75788 L .54491 .75162 L .641 .48 .852 r
F
.70433 1.35783 m .67158 1.33463 L .67927 1.36663 L .39 0 .598 r
F
.69498 1.32365 m .67158 1.33463 L .70433 1.35783 L .396 0 .599 r
F
.53308 .97187 m .53921 .98042 L .543 .97775 L .888 .6 .796 r
F
.53308 .97187 m .53055 .97366 L .53921 .98042 L F
.60305 1.09172 m .6 1.09755 L .61286 1.09484 L .537 .222 .889 r
F
.60305 1.09172 m .5915 1.09625 L .6 1.09755 L F
.48485 .75875 m .497 .74669 L .48124 .75178 L .957 .71 .805 r
F
.48485 .75875 m .49883 .75527 L .497 .74669 L F
.65354 .73287 m .67338 .67472 L .68295 .65998 L 0 0 .084 r
F
.51747 1.11965 m .50314 1.12203 L .50191 1.13028 L .996 .791 .814 r
F
.50314 1.12203 m .48557 1.13166 L .50191 1.13028 L 1 .779 .809 r
F
.54889 .97149 m .55723 .97963 L .56076 .97535 L .884 .597 .797 r
F
.54889 .97149 m .54625 .97475 L .55723 .97963 L F
.65354 .73287 m .68295 .65998 L .66195 .7167 L 0 0 .084 r
F
.66195 .7167 m .68296 .65997 L .69268 .64524 L 0 0 .045 r
F
.52733 .75502 m .54491 .75162 L .52914 .74706 L .641 .48 .852 r
F
.51308 .75398 m .52733 .75502 L .52914 .74706 L .781 .576 .824 r
F
.56342 .97076 m .5726 .97924 L .57595 .97367 L .872 .589 .798 r
F
.56342 .97076 m .56076 .97535 L .5726 .97924 L F
.49883 .75527 m .51307 .74506 L .497 .74669 L .899 .644 .805 r
F
.49883 .75527 m .51308 .75398 L .51307 .74506 L F
.67055 .70264 m .69268 .64524 L .70241 .63063 L 0 0 .024 r
F
.66195 .7167 m .69268 .64524 L .67055 .70264 L 0 0 .045 r
F
.51308 .75398 m .52914 .74706 L .51307 .74506 L .781 .576 .824 r
F
.6792 .68997 m .70241 .63063 L .71215 .61609 L 0 0 .017 r
F
.67055 .70264 m .70241 .63063 L .6792 .68997 L 0 0 .024 r
F
.49436 .9732 m .4814 .97679 L .485 .97961 L .882 .603 .799 r
F
.49712 .97484 m .49436 .9732 L .485 .97961 L .881 .601 .799 r
F
.59112 .96982 m .60097 .98012 L .6041 .97238 L .818 .539 .8 r
F
.59112 .96982 m .58846 .97676 L .60097 .98012 L F
.68252 1.01293 m .68878 1.02754 L .69583 1.02681 L .131 0 .771 r
F
.69583 1.02682 m .68879 1.02754 L .69716 1.03574 L 0 0 .711 r
F
.46499 1.14059 m .44829 1.13847 L .4419 1.14872 L 1 .746 .77 r
F
.46973 1.13142 m .44829 1.13847 L .46499 1.14059 L 1 .737 .784 r
F
.48557 1.13166 m .46973 1.13142 L .46499 1.14059 L 1 .774 .796 r
F
.43919 .98026 m .43593 .97368 L .42309 .97629 L .899 .668 .812 r
F
.45148 .97697 m .43593 .97368 L .43919 .98026 L .893 .643 .807 r
F
.68789 .67815 m .71215 .61609 L .72189 .60162 L 0 0 .017 r
F
.6792 .68997 m .71215 .61609 L .68789 .67815 L F
.5137 .96927 m .51066 .97836 L .51423 .97839 L .888 .602 .797 r
F
.51548 .96911 m .51423 .97839 L .51779 .97808 L .889 .602 .796 r
F
.51548 .96911 m .5137 .96927 L .51423 .97839 L F
.53524 .96985 m .543 .97775 L .54625 .97475 L .888 .599 .796 r
F
.53524 .96985 m .53308 .97187 L .543 .97775 L F
.57431 .76238 m .59579 .76465 L .58129 .7604 L .363 .078 .889 r
F
.56007 .7572 m .57431 .76238 L .58129 .7604 L .362 .102 .886 r
F
.5137 .96927 m .5119 .96926 L .51066 .97836 L .888 .602 .797 r
F
.5119 .96926 m .50703 .97798 L .51066 .97836 L .888 .603 .797 r
F
.51722 .96879 m .51779 .97808 L .52126 .97744 L .889 .602 .796 r
F
.51722 .96879 m .51548 .96911 L .51779 .97808 L F
.3719 1.35709 m .32833 1.41135 L .36511 1.38665 L 1 .608 .603 r
F
.3719 1.35709 m .33692 1.37901 L .32833 1.41135 L F
.51009 .96908 m .50352 .97726 L .50703 .97798 L .887 .603 .797 r
F
.5119 .96926 m .51009 .96908 L .50703 .97798 L .888 .603 .797 r
F
.69661 .66689 m .72189 .60162 L .73164 .58718 L 0 0 .022 r
F
.68789 .67815 m .72189 .60162 L .69661 .66689 L 0 0 .017 r
F
.51889 .9683 m .52126 .97744 L .52459 .97647 L .889 .601 .796 r
F
.51889 .9683 m .51722 .96879 L .52126 .97744 L F
.58295 1.09352 m .57858 1.1023 L .5915 1.09625 L .757 .684 .875 r
F
.58295 1.09352 m .57145 1.09913 L .57858 1.1023 L F
.32945 .77214 m .33337 .72168 L .31762 .76732 L .73 .109 .632 r
F
.32945 .77214 m .34392 .74097 L .33337 .72168 L F
.4419 1.14872 m .42486 1.14264 L .41693 1.15401 L 1 .649 .737 r
F
.44829 1.13847 m .42486 1.14264 L .4419 1.14872 L 1 .664 .76 r
F
.4814 .97679 m .47841 .97367 L .46688 .97806 L .878 .605 .801 r
F
.46688 .97806 m .46378 .97364 L .45148 .97697 L .879 .617 .804 r
F
.47841 .97367 m .46378 .97364 L .46688 .97806 L .884 .611 .801 r
F
.401 1.18303 m .37527 1.17687 L .39571 1.19472 L 1 .428 .649 r
F
.401 1.18303 m .3815 1.16516 L .37527 1.17687 L F
.40898 1.16736 m .3815 1.16516 L .401 1.18303 L 1 .436 .671 r
F
.39571 1.19473 m .37438 1.17868 L .39496 1.19647 L 1 .436 .642 r
F
.39571 1.19473 m .37526 1.17688 L .37438 1.17868 L F
.50833 .96872 m .5002 .9762 L .50352 .97726 L .887 .603 .797 r
F
.51009 .96908 m .50833 .96872 L .50352 .97726 L F
.39496 1.19647 m .36484 1.20009 L .3869 1.21648 L 1 .429 .632 r
F
.39496 1.19647 m .37438 1.17868 L .36484 1.20009 L F
.70537 .65602 m .73164 .58718 L .74139 .57278 L 0 0 .029 r
F
.69661 .66689 m .73164 .58718 L .70537 .65602 L 0 0 .022 r
F
.37369 .76804 m .37808 .75676 L .36281 .7613 L .505 .31 .868 r
F
.37369 .76804 m .38792 .7627 L .37808 .75676 L F
.68813 1.17628 m .66991 1.16614 L .6803 1.19816 L .241 0 .588 r
F
.67674 1.15253 m .66991 1.16614 L .68813 1.17628 L .115 0 .578 r
F
.52044 .96766 m .52459 .97647 L .52771 .97521 L .89 .601 .796 r
F
.52044 .96766 m .51889 .9683 L .52459 .97647 L F
.57815 .96772 m .58846 .97676 L .59112 .96982 L .849 .562 .797 r
F
.57815 .96772 m .57595 .97367 L .58846 .97676 L F
.73031 .73742 m .75793 .82309 L .74231 .73358 L .659 .044 .589 r
F
.73031 .73742 m .74496 .81999 L .75793 .82309 L F
.48859 1.12307 m .46973 1.13142 L .48557 1.13166 L 1 .762 .802 r
F
.50314 1.12203 m .48859 1.12307 L .48557 1.13166 L 1 .779 .809 r
F
.45178 .76511 m .46067 .75434 L .44478 .7624 L .832 .765 .865 r
F
.45178 .76511 m .46605 .75857 L .46067 .75434 L F
.624 1.09229 m .62263 1.09763 L .63498 1.09894 L .381 .082 .89 r
F
.69583 1.02682 m .69716 1.03574 L .70467 1.03724 L 0 0 .711 r
F
.71415 .64542 m .74139 .57278 L .75114 .55839 L 0 0 .037 r
F
.70537 .65602 m .74139 .57278 L .71415 .64542 L 0 0 .029 r
F
.49196 .97131 m .47841 .97367 L .4814 .97679 L .884 .605 .799 r
F
.49436 .9732 m .49196 .97131 L .4814 .97679 L .882 .603 .799 r
F
.55088 .96799 m .56076 .97535 L .56342 .97076 L .882 .592 .796 r
F
.55088 .96799 m .54889 .97149 L .56076 .97535 L F
.50667 .9682 m .49712 .97484 L .5002 .9762 L .887 .603 .798 r
F
.50833 .96872 m .50667 .9682 L .5002 .9762 L .887 .603 .797 r
F
.70467 1.03725 m .69836 1.03696 L .70593 1.0388 L 0 0 .659 r
F
.70593 1.0388 m .69836 1.03697 L .71113 1.05094 L 0 0 .644 r
F
.40898 1.16736 m .39088 1.1507 L .3815 1.16516 L 1 .436 .671 r
F
.41693 1.15401 m .39088 1.1507 L .40898 1.16736 L 1 .464 .703 r
F
.52187 .96688 m .52771 .97521 L .53055 .97366 L .89 .601 .796 r
F
.52187 .96688 m .52044 .96766 L .52771 .97521 L F
.3869 1.21648 m .35521 1.22484 L .3788 1.23878 L 1 .445 .62 r
F
.3869 1.21648 m .36484 1.20009 L .35521 1.22484 L F
.45148 .97697 m .44878 .97127 L .43593 .97368 L .893 .643 .807 r
F
.46378 .97364 m .44878 .97127 L .45148 .97697 L .891 .627 .803 r
F
.537 .96765 m .54625 .97475 L .54889 .97149 L .888 .597 .795 r
F
.537 .96765 m .53524 .96985 L .54625 .97475 L F
.71415 .64542 m .75114 .55839 L .72297 .63501 L 0 0 .037 r
F
.40758 .77052 m .41316 .76459 L .39776 .76711 L .463 .106 .884 r
F
.40758 .77052 m .42173 .76621 L .41316 .76459 L F
.38457 .98704 m .36821 .9815 L .37169 .99274 L 1 .895 .808 r
F
.38457 .98704 m .38144 .97679 L .36821 .9815 L F
.39742 .9827 m .38144 .97679 L .38457 .98704 L 1 .83 .813 r
F
.50513 .96751 m .49436 .9732 L .49712 .97484 L .887 .603 .798 r
F
.50667 .9682 m .50513 .96751 L .49712 .97484 L F
.39742 .9827 m .39465 .9732 L .38144 .97679 L 1 .83 .813 r
F
.41026 .97923 m .39465 .9732 L .39742 .9827 L .979 .769 .813 r
F
.56517 .96592 m .57595 .97367 L .57815 .96772 L .869 .577 .795 r
F
.56517 .96592 m .56342 .97076 L .57595 .97367 L F
.37169 .99274 m .35492 .98761 L .35876 1.00048 L 1 .948 .795 r
F
.37169 .99274 m .36821 .9815 L .35492 .98761 L F
.52313 .96598 m .53055 .97366 L .53308 .97187 L .89 .6 .796 r
F
.52313 .96598 m .52187 .96688 L .53055 .97366 L F
.52943 1.10884 m .51747 1.11965 L .53171 1.11593 L .978 .793 .819 r
F
.54162 1.10484 m .53171 1.11593 L .54561 1.11098 L .967 .801 .825 r
F
.54162 1.10484 m .52943 1.10884 L .53171 1.11593 L F
.70143 1.26407 m .67641 1.2554 L .68568 1.28962 L .387 0 .593 r
F
.69076 1.23077 m .67641 1.2554 L .70143 1.26407 L .371 0 .589 r
F
.3815 1.16516 m .36488 1.1263 L .3579 1.13506 L .971 .21 .623 r
F
.39088 1.1507 m .36489 1.1263 L .3815 1.16516 L .794 .189 .666 r
F
.39088 1.1507 m .37533 1.11994 L .36489 1.1263 L F
.41026 .97923 m .40783 .97046 L .39465 .9732 L .979 .769 .813 r
F
.42309 .97629 m .40783 .97046 L .41026 .97923 L .945 .718 .811 r
F
.3815 1.16516 m .3579 1.13506 L .37527 1.17687 L .971 .21 .623 r
F
.37526 1.17688 m .3579 1.13506 L .3569 1.13669 L 1 .23 .609 r
F
.55331 1.10014 m .54561 1.11098 L .55894 1.10516 L .937 .803 .834 r
F
.55331 1.10014 m .54162 1.10484 L .54561 1.11098 L F
.37526 1.17688 m .3569 1.13669 L .37438 1.17868 L 1 .23 .609 r
F
.37438 1.17868 m .3569 1.13669 L .34606 1.15973 L 1 .256 .596 r
F
.51694 1.11188 m .50314 1.12203 L .51747 1.11965 L .981 .783 .816 r
F
.52943 1.10884 m .51694 1.11188 L .51747 1.11965 L .978 .793 .819 r
F
.56007 .7572 m .58129 .7604 L .56542 .75346 L .362 .102 .886 r
F
.54491 .75162 m .56007 .7572 L .56542 .75346 L .452 .231 .874 r
F
.43025 .76825 m .43772 .76114 L .42173 .76621 L .57 .205 .874 r
F
.43025 .76825 m .44478 .7624 L .43772 .76114 L F
.41693 1.15401 m .40021 1.13958 L .39088 1.1507 L 1 .464 .703 r
F
.42486 1.14264 m .40021 1.13958 L .41693 1.15401 L .998 .505 .737 r
F
.49196 .97131 m .48997 .9692 L .47841 .97367 L .884 .605 .799 r
F
.47841 .97367 m .4761 .9703 L .46378 .97364 L .884 .611 .801 r
F
.48997 .9692 m .4761 .9703 L .47841 .97367 L .887 .608 .799 r
F
.50374 .96669 m .49196 .97131 L .49436 .9732 L .887 .604 .798 r
F
.50513 .96751 m .50374 .96669 L .49436 .9732 L .887 .603 .798 r
F
.71373 1.39233 m .67927 1.36663 L .687 1.39907 L .385 0 .596 r
F
.70433 1.35783 m .67927 1.36663 L .71373 1.39233 L .39 0 .598 r
F
.36281 .7613 m .3716 .75178 L .35567 .75524 L .454 .207 .846 r
F
.36281 .7613 m .37808 .75676 L .3716 .75178 L F
.3788 1.23878 m .34549 1.25209 L .37064 1.26317 L 1 .466 .613 r
F
.3788 1.23878 m .35521 1.22484 L .34549 1.25209 L F
.46378 .97364 m .46163 .96896 L .44878 .97127 L .891 .627 .803 r
F
.4761 .9703 m .46163 .96896 L .46378 .97364 L .89 .616 .8 r
F
.52421 .96497 m .53308 .97187 L .53524 .96985 L .89 .6 .796 r
F
.52421 .96497 m .52313 .96598 L .53308 .97187 L F
.42309 .97629 m .42101 .96835 L .40783 .97046 L .945 .718 .811 r
F
.43593 .97368 m .42101 .96835 L .42309 .97629 L .923 .68 .808 r
F
.53832 .96531 m .54889 .97149 L .55088 .96799 L .888 .596 .795 r
F
.53832 .96531 m .537 .96765 L .54889 .97149 L F
.46605 .75857 m .4776 .74444 L .46067 .75434 L 1 .826 .811 r
F
.46605 .75857 m .48123 .75179 L .4776 .74444 L F
.35876 1.00048 m .34157 .99531 L .34574 1.01106 L 1 .971 .773 r
F
.35876 1.00048 m .35492 .98761 L .34157 .99531 L F
.74231 .73358 m .77093 .82567 L .75433 .72973 L .671 .045 .587 r
F
.74231 .73358 m .75793 .82309 L .77093 .82567 L F
.36511 1.38665 m .31968 1.44481 L .35828 1.41744 L 1 .6 .599 r
F
.36511 1.38665 m .32833 1.41135 L .31968 1.44481 L F
.55218 .96433 m .56342 .97076 L .56517 .96592 L .881 .587 .795 r
F
.55218 .96433 m .55088 .96799 L .56342 .97076 L F
.56428 1.09509 m .55894 1.10516 L .57145 1.09913 L .882 .785 .848 r
F
.56428 1.09509 m .55331 1.10014 L .55894 1.10516 L F
.51694 1.11188 m .50437 1.11383 L .50314 1.12203 L .981 .783 .816 r
F
.50437 1.11383 m .48859 1.12307 L .50314 1.12203 L .984 .771 .812 r
F
.44829 1.13847 m .43279 1.13281 L .42486 1.14264 L 1 .664 .76 r
F
.45469 1.12906 m .43279 1.13281 L .44829 1.13847 L 1 .679 .78 r
F
.46973 1.13142 m .45469 1.12906 L .44829 1.13847 L 1 .737 .784 r
F
.47449 1.12257 m .45469 1.12906 L .46973 1.13142 L 1 .734 .796 r
F
.48859 1.12307 m .47449 1.12257 L .46973 1.13142 L 1 .762 .802 r
F
.71944 1.05653 m .71113 1.05094 L .72398 1.06644 L 0 0 .548 r
F
.50255 .96574 m .48997 .9692 L .49196 .97131 L .888 .605 .797 r
F
.50374 .96669 m .50255 .96574 L .49196 .97131 L .887 .604 .798 r
F
.35967 .74135 m .36088 .74138 L .35112 .72964 L .284 .016 .775 r
F
.35465 .75425 m .36088 .74138 L .34392 .74097 L .401 .108 .812 r
F
.35465 .75425 m .37068 .75099 L .36088 .74138 L F
.37808 .75676 m .3882 .75914 L .3716 .75178 L 0 0 .639 r
F
.3882 .75914 m .38996 .75955 L .38652 .7581 L F
.3882 .75914 m .38652 .7581 L .3716 .75178 L F
.38996 .75955 m .38809 .75873 L .3716 .75178 L F
.39018 .75961 m .39001 .75953 L .3716 .75178 L F
.38996 .75955 m .39018 .75961 L .38809 .75873 L F
.3716 .75178 m .39018 .75961 L .38937 .75934 L .319 0 0 r
F
.37422 .75288 m .39018 .75961 L .3716 .75178 L F
.3716 .75177 m .37422 .75288 L .3716 .75178 L F
.3716 .75177 m .38936 .75934 L .37068 .75099 L F
.38936 .75934 m .38937 .75934 L .38746 .75849 L F
.38936 .75934 m .38746 .75849 L .37068 .75099 L F
.37068 .75099 m .37367 .75233 L .37086 .75108 L .315 0 0 r
F
.37068 .75099 m .37106 .75116 L .37068 .75099 L F
.37106 .75116 m .37367 .75233 L .37068 .75099 L F
.37086 .75108 m .38811 .75878 L .38067 .75596 L F
.38811 .75878 m .38936 .75934 L .38067 .75596 L F
.38792 .7627 m .3959 .76123 L .37808 .75676 L .091 0 .766 r
F
.37808 .75676 m .3959 .76123 L .39018 .75961 L 0 0 .639 r
F
.38067 .75596 m .39581 .78051 L .37331 .75317 L .728 0 .064 r
F
.37367 .75233 m .38936 .75934 L .37086 .75108 L .315 0 0 r
F
.37068 .75099 m .37968 .75547 L .36088 .74138 L F
.37968 .75547 m .37774 .7538 L .36088 .74138 L F
.37968 .75547 m .38067 .75596 L .37774 .7538 L F
.36351 .74379 m .38067 .75596 L .37196 .75152 L .507 0 0 r
F
.36088 .74138 m .36761 .74634 L .36351 .74379 L F
.36761 .74634 m .38067 .75596 L .36351 .74379 L F
.36088 .74138 m .37196 .75152 L .35583 .73531 L F
.34392 .74097 m .35967 .74135 L .35112 .72964 L .284 .016 .775 r
F
.34318 .7196 m .36323 .74617 L .35436 .74007 L .74 0 0 r
F
.35112 .72964 m .34272 .71815 L .34139 .71632 L .648 0 0 r
F
.34139 .71632 m .34648 .72327 L .34318 .7196 L .74 0 0 r
F
.35583 .73531 m .37072 .75028 L .35112 .72964 L .507 0 0 r
F
.37072 .75028 m .36986 .74932 L .35112 .72964 L F
.35371 .73317 m .37196 .75152 L .36323 .74617 L .648 0 0 r
F
.35112 .72964 m .35795 .73682 L .35371 .73317 L F
.37072 .75028 m .37196 .75152 L .36986 .74932 L .507 0 0 r
F
.35795 .73682 m .37196 .75152 L .35371 .73317 L .648 0 0 r
F
.35112 .72964 m .36323 .74617 L .34272 .71815 L F
.34648 .72327 m .36323 .74617 L .34318 .7196 L .74 0 0 r
F
.38067 .75596 m .37211 .7517 L .37196 .75152 L .728 0 .064 r
F
.38067 .75596 m .37331 .75317 L .37211 .7517 L F
.39018 .75961 m .39018 .75961 L .39001 .75953 L 0 0 .639 r
F
.43593 .97368 m .43417 .96666 L .42101 .96835 L .923 .68 .808 r
F
.44878 .97127 m .43417 .96666 L .43593 .97368 L .909 .652 .804 r
F
.35566 .75524 m .37068 .75099 L .35465 .75425 L .408 .137 .834 r
F
.35566 .75524 m .3716 .75177 L .37068 .75099 L F
.54491 .75162 m .56542 .75346 L .54852 .74534 L .452 .231 .874 r
F
.52914 .74706 m .54491 .75162 L .54852 .74534 L .596 .395 .842 r
F
.77029 .87184 m .76659 .84178 L .78012 .84912 L .816 0 .319 r
F
.77027 .87189 m .77026 .87183 L .77029 .87184 L F
.77026 .87183 m .76659 .84178 L .77029 .87184 L F
.79834 .88709 m .79371 .85643 L .80735 .86371 L .813 0 .319 r
F
.79829 .88721 m .79827 .88705 L .79834 .88709 L F
.79827 .88705 m .79371 .85643 L .79834 .88709 L F
.82649 .90297 m .82104 .871 L .83479 .87829 L .813 0 .322 r
F
.82642 .90294 m .82479 .94744 L .82649 .90297 L .661 .039 .581 r
F
.81856 .89854 m .82104 .871 L .82649 .90297 L .813 0 .322 r
F
.81243 .8949 m .82104 .871 L .81856 .89854 L .813 0 .32 r
F
.81853 .89832 m .81856 .89854 L .82643 .90274 L .661 .039 .581 r
F
.81856 .89854 m .82479 .94744 L .82641 .90321 L F
.81856 .89854 m .82641 .90321 L .82642 .90294 L F
.82649 .90297 m .82479 .94744 L .83876 .95587 L F
.81243 .89529 m .81089 .93924 L .82479 .94744 L .663 .04 .582 r
F
.81238 .89504 m .81237 .89525 L .81243 .89529 L F
.81237 .89525 m .81089 .93924 L .81243 .89529 L F
.82646 .90305 m .81856 .89854 L .82649 .90297 L .813 0 .322 r
F
.81243 .8949 m .80735 .86371 L .82104 .871 L .813 0 .32 r
F
.81235 .89486 m .80735 .86371 L .81243 .8949 L F
.80473 .8908 m .80735 .86371 L .81238 .89504 L F
.79829 .88721 m .81089 .93924 L .80473 .8908 L .666 .041 .583 r
F
.79834 .88709 m .80735 .86371 L .80473 .8908 L .813 0 .319 r
F
.79834 .88709 m .80473 .8908 L .80472 .89091 L F
.79834 .88741 m .79706 .93124 L .81089 .93924 L .666 .041 .583 r
F
.79829 .88721 m .79829 .88738 L .79834 .88741 L F
.79829 .88738 m .79706 .93124 L .79834 .88741 L F
.80473 .8908 m .81232 .89521 L .81233 .89487 L .663 .04 .582 r
F
.81233 .89502 m .81089 .93924 L .81238 .89504 L F
.81235 .89511 m .80473 .8908 L .81238 .89504 L .813 0 .32 r
F
.80473 .8908 m .81089 .93924 L .81232 .89521 L .663 .04 .582 r
F
.80137 .92558 m .80472 .89091 L .81235 .89511 L .813 0 .32 r
F
.80472 .89091 m .80473 .8908 L .81235 .89511 L F
.79835 .88724 m .80472 .89091 L .80137 .92558 L .813 0 .319 r
F
.79834 .88709 m .80472 .89091 L .79835 .88724 L F
.79826 .88719 m .79371 .85643 L .79829 .88721 L F
.79096 .88317 m .79706 .93124 L .79829 .88721 L .666 .041 .583 r
F
.78429 .87939 m .78012 .84912 L .79371 .85643 L .814 0 .318 r
F
.78425 .87948 m .78423 .87936 L .78429 .87939 L F
.78423 .87936 m .78012 .84912 L .78429 .87939 L F
.79096 .88317 m .79371 .85643 L .79826 .88719 L .813 0 .319 r
F
.78428 .87959 m .78329 .92339 L .79706 .93124 L .667 .042 .583 r
F
.78427 .87959 m .78329 .92339 L .78428 .87959 L F
.78425 .87948 m .77726 .8757 L .78427 .87958 L F
.77725 .87563 m .77726 .8757 L .78425 .87948 L F
.77726 .8757 m .78329 .92339 L .78427 .87958 L F
.77027 .87189 m .78329 .92339 L .77726 .8757 L F
.77724 .87572 m .77725 .87563 L .78425 .87948 L .814 0 .318 r
F
.77725 .87563 m .78012 .84912 L .78425 .87948 L F
.77027 .87189 m .77726 .8757 L .77725 .87563 L .667 .042 .583 r
F
.77027 .87189 m .77029 .87184 L .7703 .8719 L .816 0 .319 r
F
.77029 .87184 m .78012 .84912 L .77725 .87563 L F
.77029 .87184 m .77725 .87563 L .77725 .87568 L F
.77027 .87189 m .76958 .91558 L .78329 .92339 L .667 .042 .583 r
F
.7703 .8719 m .77725 .87568 L .77417 .90405 L .816 0 .319 r
F
.77029 .87184 m .77725 .87568 L .7703 .8719 L F
.76362 .8682 m .76362 .86827 L .77027 .87189 L .667 .042 .583 r
F
.76361 .86825 m .76362 .8682 L .77027 .87189 L .816 0 .319 r
F
.76362 .8682 m .76659 .84178 L .77027 .87189 L F
.75793 .82309 m .76362 .8682 L .77027 .87189 L .667 .042 .583 r
F
.76362 .86827 m .76958 .91558 L .77027 .87189 L F
.77027 .87189 m .77725 .87563 L .77093 .82567 L F
.76072 .89396 m .77027 .87189 L .77417 .90405 L .816 0 .319 r
F
.77027 .87189 m .7703 .8719 L .77417 .90405 L F
.78178 .87809 m .77725 .87563 L .78425 .87948 L .667 .042 .583 r
F
.77724 .87554 m .77725 .87563 L .78178 .87809 L F
.77093 .82567 m .77724 .87554 L .78425 .87948 L F
.78425 .87948 m .79706 .93124 L .79096 .88317 L F
.78425 .87948 m .79096 .88317 L .79095 .88325 L .814 0 .318 r
F
.78427 .87958 m .78427 .87959 L .78428 .87959 L .667 .042 .583 r
F
.78425 .87948 m .79095 .88325 L .78772 .91463 L .814 0 .318 r
F
.77417 .90405 m .78425 .87948 L .78772 .91463 L F
.78425 .87948 m .79371 .85643 L .79096 .88317 L F
.78425 .87948 m .79096 .88317 L .79095 .88308 L .667 .042 .583 r
F
.78396 .82802 m .79093 .88297 L .79553 .88562 L .666 .041 .583 r
F
.79828 .88714 m .79553 .88562 L .79829 .88721 L F
.78396 .82802 m .79553 .88562 L .79828 .88714 L F
.77093 .82567 m .78425 .87948 L .78396 .82802 L .667 .042 .583 r
F
.78425 .87948 m .79095 .88308 L .78396 .82802 L F
.77417 .90405 m .77724 .87572 L .78425 .87948 L .814 0 .318 r
F
.79095 .88325 m .79096 .88317 L .79827 .88726 L .813 0 .319 r
F
.79096 .88317 m .79826 .88719 L .79827 .88726 L F
.79093 .88297 m .79096 .88317 L .79829 .88721 L .666 .041 .583 r
F
.79829 .88721 m .80473 .8908 L .80471 .89063 L F
.78772 .91463 m .79829 .88721 L .80137 .92558 L .813 0 .319 r
F
.79829 .88721 m .79834 .88709 L .79835 .88724 L F
.79829 .88721 m .79835 .88724 L .80137 .92558 L F
.80471 .89063 m .80473 .8908 L .81233 .89487 L .663 .04 .582 r
F
.79703 .83029 m .81238 .89504 L .81015 .83257 L F
.81238 .89504 m .82479 .94744 L .81856 .89854 L F
.81238 .89504 m .81243 .8949 L .81244 .89508 L .813 0 .32 r
F
.81243 .8949 m .81856 .89854 L .81511 .9368 L F
.81238 .89504 m .81235 .89486 L .81243 .8949 L F
.81238 .89504 m .81856 .89854 L .81015 .83257 L .663 .04 .582 r
F
.80137 .92558 m .81238 .89504 L .81511 .9368 L .813 0 .32 r
F
.81238 .89504 m .81244 .89508 L .81511 .9368 L F
.81511 .9368 m .81855 .89867 L .82646 .90305 L .813 0 .322 r
F
.81855 .89867 m .81856 .89854 L .82646 .90305 L F
.81511 .9368 m .82649 .90297 L .82894 .94826 L F
.81015 .83257 m .82649 .90297 L .82331 .83489 L .661 .039 .581 r
F
.82649 .90297 m .83876 .95587 L .83244 .90639 L F
.82649 .90297 m .83479 .87829 L .83244 .90639 L .813 0 .322 r
F
.82649 .90297 m .83244 .90639 L .82331 .83489 L .661 .039 .581 r
F
.82649 .90297 m .83244 .90639 L .83243 .90653 L .813 0 .322 r
F
.82649 .90297 m .83243 .90653 L .82894 .94826 L F
.82338 .90111 m .82642 .90294 L .82643 .90274 L .661 .039 .581 r
F
.81856 .89854 m .82642 .90294 L .82338 .90111 L F
.82643 .90274 m .82642 .90294 L .82649 .90297 L F
.81015 .83257 m .81853 .89832 L .82643 .90274 L F
.81233 .89487 m .81233 .89502 L .81238 .89504 L .663 .04 .582 r
F
.79703 .83029 m .80471 .89063 L .81233 .89487 L F
.78396 .82802 m .79829 .88721 L .79703 .83029 L .666 .041 .583 r
F
.79829 .88721 m .80471 .89063 L .79703 .83029 L F
.79827 .88726 m .79826 .88719 L .79829 .88721 L .813 0 .319 r
F
.78772 .91463 m .79095 .88325 L .79827 .88726 L F
.75793 .82309 m .77027 .87189 L .77093 .82567 L .667 .042 .583 r
F
.76072 .89396 m .76361 .86825 L .77027 .87189 L .816 0 .319 r
F
.48124 .75178 m .49517 .73666 L .47761 .74444 L 1 .692 .772 r
F
.48124 .75178 m .497 .74669 L .49517 .73666 L F
.5932 1.0883 m .5915 1.09625 L .60305 1.09172 L .686 .595 .884 r
F
.5932 1.0883 m .58295 1.09351 L .5915 1.09625 L F
.52509 .96386 m .53524 .96985 L .537 .96765 L .89 .6 .795 r
F
.52509 .96386 m .52421 .96497 L .53524 .96985 L F
.63202 .96866 m .63008 .97978 L .6431 .98522 L .649 .309 .779 r
F
.497 .74669 m .51306 .73464 L .49517 .73666 L .962 .598 .774 r
F
.497 .74669 m .51307 .74506 L .51306 .73464 L F
.59235 .96231 m .6041 .97238 L .60556 .96367 L .818 .51 .791 r
F
.59235 .96231 m .59112 .96982 L .6041 .97238 L F
.51307 .74506 m .53095 .73826 L .51306 .73464 L .787 .515 .803 r
F
.51307 .74506 m .52914 .74706 L .53095 .73826 L F
.52914 .74706 m .54852 .74534 L .53095 .73826 L .596 .395 .842 r
F
.36251 1.08413 m .35173 1.0819 L .3397 1.07527 L .502 0 0 r
F
.4761 .9703 m .4745 .96672 L .46163 .96896 L .89 .616 .8 r
F
.48843 .96692 m .4745 .96672 L .4761 .9703 L .89 .61 .798 r
F
.48997 .9692 m .48843 .96692 L .4761 .9703 L .887 .608 .799 r
F
.51316 .96011 m .5119 .96926 L .5137 .96927 L .892 .605 .796 r
F
.51316 .96011 m .5137 .96927 L .51548 .96911 L F
.51316 .96011 m .51316 .96011 L .5137 .96927 L F
.57915 .96144 m .59112 .96982 L .59235 .96231 L .848 .544 .792 r
F
.57915 .96144 m .57815 .96772 L .59112 .96982 L F
.51316 .96011 m .51316 .96011 L .5119 .96926 L .892 .605 .796 r
F
.51316 .96011 m .51009 .96908 L .5119 .96926 L .891 .605 .797 r
F
.51316 .96011 m .51548 .96911 L .51722 .96879 L .892 .605 .796 r
F
.51316 .96011 m .51316 .96011 L .51548 .96911 L F
.6453 .97287 m .6431 .98522 L .65617 .99232 L .573 .215 .768 r
F
.63202 .96866 m .6431 .98522 L .6453 .97287 L .649 .309 .779 r
F
.44878 .97127 m .44733 .96527 L .43417 .96666 L .909 .652 .804 r
F
.46163 .96896 m .44733 .96527 L .44878 .97127 L .9 .633 .802 r
F
.51316 .96011 m .50833 .96872 L .51009 .96908 L .891 .605 .797 r
F
.51316 .96011 m .51316 .96011 L .51009 .96908 L F
.40021 1.13958 m .37533 1.11994 L .39088 1.1507 L .667 .202 .719 r
F
.51316 .96011 m .51722 .96879 L .51889 .9683 L .893 .604 .796 r
F
.51316 .96011 m .51316 .96011 L .51722 .96879 L F
.40021 1.13958 m .38573 1.11695 L .37533 1.11994 L .667 .202 .719 r
F
.53918 .96286 m .55088 .96799 L .55218 .96433 L .888 .594 .795 r
F
.53918 .96286 m .53832 .96531 L .55088 .96799 L F
.45664 .67534 m .48487 .5995 L .48299 .5942 L 1 .197 .493 r
F
.46034 .68489 m .48487 .5995 L .45664 .67534 L .888 0 .353 r
F
.51316 .96011 m .50667 .9682 L .50833 .96872 L .891 .605 .797 r
F
.51316 .96011 m .51316 .96011 L .50833 .96872 L F
.50255 .96574 m .50155 .96468 L .48997 .9692 L .888 .605 .797 r
F
.50155 .96468 m .48843 .96692 L .48997 .9692 L .89 .606 .797 r
F
.42486 1.14264 m .40951 1.13076 L .40021 1.13958 L .998 .505 .737 r
F
.43279 1.13281 m .40951 1.13076 L .42486 1.14264 L .942 .553 .767 r
F
.37438 1.17868 m .34606 1.15973 L .36484 1.20009 L 1 .256 .596 r
F
.51316 .96011 m .51889 .9683 L .52044 .96766 L .892 .604 .796 r
F
.51316 .96011 m .51316 .96011 L .51889 .9683 L F
.52575 .96269 m .537 .96765 L .53832 .96531 L .89 .599 .795 r
F
.52575 .96269 m .52509 .96386 L .537 .96765 L F
.61302 1.08707 m .61286 1.09484 L .624 1.09229 L .566 .419 .894 r
F
.61302 1.08707 m .60305 1.09172 L .61286 1.09484 L F
.56596 .96089 m .57815 .96772 L .57915 .96144 L .869 .568 .793 r
F
.56596 .96089 m .56517 .96592 L .57815 .96772 L F
.34574 1.01106 m .32815 1.00464 L .33261 1.02504 L 1 .945 .743 r
F
.34574 1.01106 m .34157 .99531 L .32815 1.00464 L F
.51316 .96011 m .50513 .96751 L .50667 .9682 L .891 .604 .797 r
F
.51316 .96011 m .51316 .96011 L .50667 .9682 L .891 .605 .797 r
F
.37063 1.26318 m .33555 1.28162 L .3623 1.2898 L 1 .488 .608 r
F
.37063 1.26318 m .34549 1.25209 L .33555 1.28162 L F
.51316 .96011 m .52044 .96766 L .52187 .96688 L .892 .604 .796 r
F
.51316 .96011 m .51316 .96011 L .52044 .96766 L F
.49162 1.11459 m .47449 1.12257 L .48859 1.12307 L .985 .755 .808 r
F
.50437 1.11383 m .49162 1.11459 L .48859 1.12307 L .984 .771 .812 r
F
.46163 .96896 m .46049 .96407 L .44733 .96527 L .9 .633 .802 r
F
.4745 .96672 m .46049 .96407 L .46163 .96896 L .895 .62 .8 r
F
.51316 .96011 m .50374 .96669 L .50513 .96751 L .891 .604 .797 r
F
.51316 .96011 m .51316 .96011 L .50513 .96751 L F
.51316 .96011 m .52187 .96688 L .52313 .96598 L .892 .603 .796 r
F
.51316 .96011 m .51316 .96011 L .52187 .96688 L F
.57435 1.08994 m .57145 1.09913 L .58295 1.09352 L .821 .744 .86 r
F
.57435 1.08994 m .56428 1.09509 L .57145 1.09913 L F
.65863 .97882 m .65617 .99232 L .6693 1.00147 L .495 .126 .753 r
F
.6453 .97287 m .65617 .99232 L .65863 .97882 L .573 .215 .768 r
F
.55276 .96056 m .56517 .96592 L .56596 .96089 L .881 .583 .793 r
F
.55276 .96056 m .55218 .96433 L .56517 .96592 L F
.75433 .72973 m .78396 .82802 L .76638 .72588 L .677 .046 .585 r
F
.75433 .72973 m .77093 .82567 L .78396 .82802 L F
.39776 .76711 m .40455 .76308 L .38792 .7627 L .304 .001 .844 r
F
.39776 .76711 m .41259 .76469 L .40455 .76308 L F
.38792 .7627 m .40455 .76308 L .3959 .76123 L .091 0 .766 r
F
.40455 .76308 m .41612 .76914 L .39654 .76148 L .329 0 0 r
F
.40455 .76308 m .39654 .76148 L .3959 .76123 L F
.41259 .76469 m .41316 .76459 L .40455 .76308 L .304 .001 .844 r
F
.34606 1.15973 m .31858 1.13869 L .33501 1.18922 L 1 .27 .548 r
F
.36484 1.20009 m .34606 1.15973 L .33501 1.18922 L 1 .303 .586 r
F
.51316 .96011 m .50255 .96574 L .50374 .96669 L .891 .604 .796 r
F
.51316 .96011 m .51316 .96011 L .50374 .96669 L .891 .604 .797 r
F
.51316 .96011 m .52313 .96598 L .52421 .96497 L .892 .603 .796 r
F
.51316 .96011 m .51316 .96011 L .52313 .96598 L F
.48843 .96692 m .48737 .96451 L .4745 .96672 L .89 .61 .798 r
F
.50079 .96353 m .48737 .96451 L .48843 .96692 L .891 .607 .797 r
F
.50155 .96468 m .50079 .96353 L .48843 .96692 L .89 .606 .797 r
F
.56542 .75346 m .58129 .7604 L .58833 .76007 L .181 .002 .848 r
F
.52618 .96147 m .53832 .96531 L .53918 .96286 L .89 .599 .795 r
F
.52618 .96147 m .52575 .96269 L .53832 .96531 L F
.40951 1.13076 m .38573 1.11695 L .40021 1.13958 L .654 .278 .763 r
F
.4745 .96672 m .47365 .963 L .46049 .96407 L .895 .62 .8 r
F
.48737 .96451 m .47365 .963 L .4745 .96672 L .893 .613 .798 r
F
.51316 .96011 m .50155 .96468 L .50255 .96574 L .891 .604 .796 r
F
.51316 .96011 m .51316 .96011 L .50255 .96574 L F
.31839 1.07517 m .30925 1.05714 L .29576 1.07825 L 1 .802 .647 r
F
.51316 .96011 m .52421 .96497 L .52509 .96386 L .892 .603 .796 r
F
.51316 .96011 m .51316 .96011 L .52421 .96497 L F
.69963 1.20269 m .6803 1.19816 L .69076 1.23076 L .316 0 .595 r
F
.68813 1.17628 m .6803 1.19816 L .69963 1.20269 L .241 0 .588 r
F
.53956 .96035 m .55218 .96433 L .55276 .96056 L .888 .593 .794 r
F
.53956 .96035 m .53918 .96286 L .55218 .96433 L F
.44478 .7624 m .45526 .75173 L .43772 .76114 L .758 .598 .867 r
F
.44478 .7624 m .46067 .75434 L .45526 .75173 L F
.36484 1.20009 m .33501 1.18922 L .35521 1.22484 L 1 .303 .586 r
F
.35828 1.41744 m .31097 1.47932 L .3514 1.44935 L 1 .593 .596 r
F
.35828 1.41744 m .31968 1.44481 L .31097 1.47932 L F
.51316 .96011 m .51316 .96011 L .50155 .96468 L .891 .604 .796 r
F
.51316 .96011 m .50079 .96353 L .50155 .96468 L .892 .604 .796 r
F
.45469 1.12906 m .44073 1.12408 L .43279 1.13281 L 1 .679 .78 r
F
.4611 1.12029 m .44073 1.12408 L .45469 1.12906 L .972 .694 .797 r
F
.47449 1.12257 m .4611 1.12029 L .45469 1.12906 L 1 .734 .796 r
F
.51316 .96011 m .52509 .96386 L .52575 .96269 L .891 .603 .796 r
F
.51316 .96011 m .51316 .96011 L .52509 .96386 L F
.31858 1.13868 m .30524 1.10788 L .29202 1.13971 L 1 .548 .59 r
F
.31833 1.07739 m .30754 1.11128 L .29419 1.12516 L .22 0 .143 r
F
.3306 1.07276 m .30754 1.11128 L .31833 1.07739 L .288 0 .14 r
F
.7232 1.4273 m .687 1.39907 L .69477 1.43202 L .381 0 .595 r
F
.71373 1.39233 m .687 1.39907 L .7232 1.4273 L .385 0 .596 r
F
.52714 1.10177 m .51694 1.11188 L .52943 1.10884 L .955 .78 .823 r
F
.53761 1.09856 m .52943 1.10884 L .54162 1.10484 L .942 .784 .828 r
F
.53761 1.09856 m .52714 1.10177 L .52943 1.10884 L F
.48737 .96451 m .48682 .96201 L .47365 .963 L .893 .613 .798 r
F
.50026 .96231 m .48682 .96201 L .48737 .96451 L .892 .608 .797 r
F
.50079 .96353 m .50026 .96231 L .48737 .96451 L .891 .607 .797 r
F
.52636 .96021 m .53918 .96286 L .53956 .96035 L .891 .599 .795 r
F
.52636 .96021 m .52618 .96147 L .53918 .96286 L F
.5164 1.1042 m .50437 1.11383 L .51694 1.11188 L .962 .773 .82 r
F
.52714 1.10177 m .5164 1.1042 L .51694 1.11188 L .955 .78 .823 r
F
.43279 1.13281 m .41882 1.12328 L .40951 1.13076 L .942 .553 .767 r
F
.44073 1.12408 m .41882 1.12328 L .43279 1.13281 L .908 .599 .79 r
F
.48663 .629 m .51301 .65487 L .513 .63495 L .514 .027 .631 r
F
.4868 .63208 m .51301 .65488 L .48663 .629 L .531 .032 .631 r
F
.51316 .96011 m .50026 .96231 L .50079 .96353 L .892 .605 .796 r
F
.51316 .96011 m .51316 .96011 L .50079 .96353 L .892 .604 .796 r
F
.54765 1.09473 m .54162 1.10484 L .55331 1.10014 L .919 .783 .835 r
F
.54765 1.09473 m .53761 1.09856 L .54162 1.10484 L F
.51316 .96011 m .52575 .96269 L .52618 .96147 L .891 .603 .796 r
F
.51316 .96011 m .51316 .96011 L .52575 .96269 L F
.47926 1.11401 m .4611 1.12029 L .47449 1.12257 L .974 .735 .807 r
F
.49162 1.11459 m .47926 1.11401 L .47449 1.12257 L .985 .755 .808 r
F
.42101 .96835 m .40747 .96055 L .40783 .97046 L .958 .701 .803 r
F
.42101 .96835 m .42072 .95971 L .40747 .96055 L F
.43417 .96666 m .42072 .95971 L .42101 .96835 L .934 .674 .803 r
F
.43417 .96666 m .43395 .95923 L .42072 .95971 L F
.44733 .96527 m .43395 .95923 L .43417 .96666 L .917 .652 .802 r
F
.44733 .96527 m .44716 .95904 L .43395 .95923 L F
.46049 .96407 m .44716 .95904 L .44733 .96527 L .906 .635 .8 r
F
.4868 .63208 m .51301 .65677 L .51301 .65488 L .531 .032 .631 r
F
.48795 .65423 m .51301 .65677 L .4868 .63209 L .648 .083 .641 r
F
.40783 .97046 m .39421 .96181 L .39465 .9732 L .991 .729 .801 r
F
.40783 .97046 m .40747 .96055 L .39421 .96181 L F
.3623 1.2898 m .32553 1.3126 L .3539 1.3181 L 1 .506 .605 r
F
.3623 1.2898 m .33555 1.28162 L .32553 1.3126 L F
.46049 .96407 m .46037 .95905 L .44716 .95904 L .906 .635 .8 r
F
.47365 .963 m .46037 .95905 L .46049 .96407 L .899 .622 .799 r
F
.71216 1.29764 m .68568 1.28962 L .69498 1.32366 L .396 0 .595 r
F
.70143 1.26407 m .68568 1.28962 L .71216 1.29764 L .387 0 .593 r
F
.31536 .89666 m .31895 .89298 L .31441 .86859 L .329 .005 .696 r
F
.31895 .89298 m .32607 .88569 L .31441 .86859 L F
.31895 .89298 m .31441 .86859 L .31441 .86859 L F
.31441 .8686 m .31591 .92465 L .31061 .84818 L .644 0 .317 r
F
.31441 .86858 m .31061 .84818 L .30541 .77308 L F
.31441 .8686 m .31061 .84818 L .31441 .86858 L F
.42173 .76621 m .4306 .76184 L .41316 .76459 L .351 0 .754 r
F
.42173 .76621 m .43772 .76114 L .4306 .76184 L F
.57894 .95493 m .57915 .96144 L .59235 .96231 L .855 .538 .788 r
F
.56577 .95575 m .57915 .96144 L .57894 .95493 L .873 .565 .791 r
F
.56577 .95575 m .56596 .96089 L .57915 .96144 L F
.50026 .96231 m .49998 .96105 L .48682 .96201 L .892 .608 .797 r
F
.51315 .96011 m .49998 .96105 L .50026 .96231 L .893 .605 .796 r
F
.51316 .96011 m .51315 .96011 L .50026 .96231 L .892 .605 .796 r
F
.59212 .95435 m .59235 .96231 L .60556 .96367 L .831 .5 .784 r
F
.57894 .95493 m .59235 .96231 L .59212 .95435 L .855 .538 .788 r
F
.39616 1.11431 m .37364 1.09465 L .38573 1.11695 L .307 .031 .793 r
F
.40951 1.13076 m .39616 1.11431 L .38573 1.11695 L .654 .278 .763 r
F
.51316 .96011 m .52618 .96147 L .52636 .96021 L .891 .603 .796 r
F
.51316 .96011 m .51316 .96011 L .52618 .96147 L F
.55261 .95674 m .56596 .96089 L .56577 .95575 L .883 .583 .793 r
F
.55261 .95674 m .55276 .96056 L .56596 .96089 L F
.3306 1.07276 m .32075 1.10101 L .30754 1.11128 L .288 0 .14 r
F
.33174 1.07283 m .32075 1.10101 L .33061 1.07276 L .345 0 .154 r
F
.39465 .9732 m .38093 .96355 L .38144 .97679 L 1 .754 .795 r
F
.39465 .9732 m .39421 .96181 L .38093 .96355 L F
.47365 .963 m .47358 .95921 L .46037 .95905 L .899 .622 .799 r
F
.48682 .96201 m .47358 .95921 L .47365 .963 L .895 .614 .798 r
F
.76638 .72588 m .79703 .83029 L .77846 .72201 L .679 .045 .583 r
F
.76638 .72588 m .78396 .82802 L .79703 .83029 L F
.5164 1.1042 m .50561 1.10573 L .50437 1.11383 L .962 .773 .82 r
F
.50561 1.10573 m .49162 1.11459 L .50437 1.11383 L .964 .764 .817 r
F
.60531 .95412 m .60556 .96367 L .61878 .9657 L .797 .448 .778 r
F
.59212 .95435 m .60556 .96367 L .60531 .95412 L .831 .5 .784 r
F
.53946 .95783 m .55276 .96056 L .55261 .95674 L .889 .594 .794 r
F
.53946 .95783 m .53956 .96035 L .55276 .96056 L F
.49517 .73666 m .51305 .7222 L .49334 .72427 L 1 .521 .739 r
F
.49517 .73666 m .51306 .73464 L .51305 .7222 L F
.47761 .74444 m .49517 .73666 L .49334 .72427 L 1 .627 .728 r
F
.51306 .73464 m .53277 .72848 L .51305 .7222 L .773 .427 .779 r
F
.51306 .73464 m .53095 .73826 L .53277 .72848 L F
.41882 1.12328 m .39616 1.11431 L .40951 1.13076 L .691 .385 .794 r
F
.33174 1.07283 m .32198 1.10024 L .32075 1.10101 L .345 0 .154 r
F
.3397 1.07527 m .32198 1.10024 L .33174 1.07283 L .308 0 .077 r
F
.48682 .96201 m .48677 .95946 L .47358 .95921 L .895 .614 .798 r
F
.49998 .96105 m .48677 .95946 L .48682 .96201 L .893 .609 .797 r
F
.56542 .75346 m .58833 .76007 L .57081 .75068 L .181 .002 .848 r
F
.54852 .74534 m .56542 .75346 L .57081 .75068 L .356 .1 .861 r
F
.52631 .95896 m .53956 .96035 L .53946 .95783 L .891 .6 .795 r
F
.52631 .95896 m .52636 .96021 L .53956 .96035 L F
.58331 1.08468 m .58295 1.09351 L .5932 1.0883 L .788 .708 .863 r
F
.58331 1.08468 m .57435 1.08994 L .58295 1.09351 L F
.55707 1.09046 m .55331 1.10014 L .56428 1.09509 L .888 .773 .843 r
F
.55707 1.09046 m .54765 1.09473 L .55331 1.10014 L F
.49998 .96105 m .49997 .95977 L .48677 .95946 L .893 .609 .797 r
F
.51315 .96011 m .49997 .95977 L .49998 .96105 L .893 .605 .796 r
F
.51315 .96011 m .51315 .96011 L .49998 .96105 L F
.60531 .95412 m .61878 .9657 L .61851 .95434 L .797 .448 .778 r
F
.51316 .96011 m .52636 .96021 L .52631 .95896 L .892 .604 .796 r
F
.51316 .96011 m .51316 .96011 L .52636 .96021 L F
.46067 .75434 m .47396 .73666 L .45526 .75173 L 1 .879 .786 r
F
.46067 .75434 m .4776 .74444 L .47396 .73666 L F
.38144 .97679 m .36763 .9658 L .36821 .9815 L 1 .768 .785 r
F
.38144 .97679 m .38093 .96355 L .36763 .9658 L F
.60204 1.08275 m .60305 1.09172 L .61302 1.08707 L .701 .608 .871 r
F
.60204 1.08275 m .5932 1.0883 L .60305 1.09172 L F
.53095 .73826 m .55215 .73911 L .53277 .72848 L .536 .286 .827 r
F
.53095 .73826 m .54852 .74534 L .55215 .73911 L F
.47761 .74444 m .49334 .72427 L .47396 .73666 L 1 .627 .728 r
F
.51315 .96011 m .51315 .96011 L .49997 .95977 L .893 .605 .796 r
F
.51315 .96011 m .50021 .9585 L .49997 .95977 L .893 .606 .796 r
F
.51315 .96011 m .51315 .96011 L .50021 .9585 L F
.51316 .96011 m .51316 .96011 L .52631 .95896 L .892 .604 .796 r
F
.51316 .96011 m .52631 .95896 L .52601 .95773 L F
.51316 .96011 m .51316 .96011 L .52601 .95773 L .893 .605 .796 r
F
.51315 .96011 m .5007 .95725 L .50021 .9585 L .894 .606 .796 r
F
.51315 .96011 m .51316 .96011 L .5007 .95725 L F
.51316 .96011 m .52601 .95773 L .5255 .95659 L .893 .605 .796 r
F
.51316 .96011 m .51316 .96011 L .5255 .95659 L F
.51316 .96011 m .50144 .95606 L .5007 .95725 L .893 .606 .796 r
F
.51316 .96011 m .51316 .96011 L .50144 .95606 L F
.51316 .96011 m .5255 .95659 L .52479 .95551 L .893 .605 .796 r
F
.51316 .96011 m .51316 .96011 L .52479 .95551 L .894 .605 .796 r
F
.51316 .96011 m .50237 .95498 L .50144 .95606 L .893 .606 .796 r
F
.51316 .96011 m .51316 .96011 L .50237 .95498 L F
.51316 .96011 m .52479 .95551 L .52387 .95451 L .894 .605 .796 r
F
.51316 .96011 m .51316 .96011 L .52387 .95451 L F
.51316 .96011 m .50351 .95399 L .50237 .95498 L .893 .606 .796 r
F
.51316 .96011 m .51316 .96011 L .50351 .95399 L F
.51316 .96011 m .52387 .95451 L .52278 .9536 L .894 .605 .796 r
F
.51316 .96011 m .51316 .96011 L .52278 .9536 L F
.51316 .96011 m .50483 .95311 L .50351 .95399 L .893 .606 .796 r
F
.51316 .96011 m .51316 .96011 L .50483 .95311 L F
.51316 .96011 m .52278 .9536 L .52146 .95277 L .894 .605 .796 r
F
.51316 .96011 m .51316 .96011 L .52146 .95277 L F
.51316 .96011 m .5063 .95236 L .50483 .95311 L .892 .606 .796 r
F
.51316 .96011 m .51316 .96011 L .5063 .95236 L F
.51316 .96011 m .52146 .95277 L .51999 .95208 L .894 .605 .796 r
F
.51316 .96011 m .51316 .96011 L .51999 .95208 L F
.51316 .96011 m .5079 .95175 L .5063 .95236 L .892 .605 .796 r
F
.51316 .96011 m .51316 .96011 L .5079 .95175 L F
.51316 .96011 m .51999 .95208 L .5184 .95153 L .894 .605 .796 r
F
.51316 .96011 m .51316 .96011 L .5184 .95153 L F
.51316 .96011 m .50959 .95129 L .5079 .95175 L .892 .605 .796 r
F
.51316 .96011 m .51316 .96011 L .50959 .95129 L F
.51316 .96011 m .5184 .95153 L .5167 .95115 L .894 .605 .796 r
F
.51316 .96011 m .51316 .96011 L .5167 .95115 L .893 .604 .796 r
F
.51316 .96011 m .51135 .951 L .50959 .95129 L .892 .605 .796 r
F
.51316 .96011 m .51316 .96011 L .51135 .951 L F
.51316 .96011 m .5167 .95115 L .51494 .95093 L .893 .604 .796 r
F
.51316 .96011 m .51316 .96011 L .51494 .95093 L F
.51316 .96011 m .51315 .95088 L .51135 .951 L F
.51316 .96011 m .51316 .96011 L .51315 .95088 L F
.51316 .96011 m .51494 .95093 L .51315 .95088 L F
.33501 1.18922 m .31858 1.13869 L .30608 1.17776 L 1 .344 .566 r
F
.31858 1.13868 m .29202 1.13971 L .30607 1.17775 L 1 .548 .59 r
F
.54852 .74534 m .57081 .75068 L .55215 .73911 L .356 .1 .861 r
F
.65711 1.10417 m .64599 1.1079 L .65706 1.12031 L .363 .04 .761 r
F
.6451 1.09401 m .64599 1.1079 L .65711 1.10417 L .441 .148 .81 r
F
.6451 1.09401 m .63498 1.09894 L .64599 1.1079 L F
.49997 .95977 m .48725 .95692 L .48677 .95946 L .894 .609 .797 r
F
.49997 .95977 m .50021 .9585 L .48725 .95692 L F
.52601 .95773 m .52631 .95896 L .53946 .95783 L .893 .601 .795 r
F
.66919 1.11713 m .65706 1.12031 L .66824 1.13704 L .324 .006 .705 r
F
.65711 1.10417 m .65706 1.12031 L .66919 1.11713 L .363 .04 .761 r
F
.48677 .95946 m .47427 .9554 L .47358 .95921 L .896 .614 .798 r
F
.48677 .95946 m .48725 .95692 L .47427 .9554 L F
.49465 1.10627 m .47926 1.11401 L .49162 1.11459 L .96 .752 .815 r
F
.50561 1.10573 m .49465 1.10627 L .49162 1.11459 L .964 .764 .817 r
F
.53887 .95534 m .53946 .95783 L .55261 .95674 L .891 .595 .794 r
F
.52601 .95773 m .53946 .95783 L .53887 .95534 L .893 .601 .795 r
F
.35521 1.22484 m .32386 1.221 L .34549 1.25209 L 1 .352 .586 r
F
.35521 1.22484 m .33501 1.18922 L .32386 1.221 L F
.36821 .9815 m .35429 .96855 L .35492 .98761 L 1 .761 .768 r
F
.36821 .9815 m .36763 .9658 L .35429 .96855 L F
.5255 .95659 m .52601 .95773 L .53887 .95534 L .894 .602 .795 r
F
.50021 .9585 m .48823 .95443 L .48725 .95692 L .894 .61 .797 r
F
.50021 .9585 m .5007 .95725 L .48823 .95443 L F
.47358 .95921 m .46129 .95398 L .46037 .95905 L .9 .622 .799 r
F
.47358 .95921 m .47427 .9554 L .46129 .95398 L F
.55174 .95297 m .55261 .95674 L .56577 .95575 L .888 .585 .792 r
F
.53887 .95534 m .55261 .95674 L .55174 .95297 L .891 .595 .794 r
F
.63314 1.08625 m .63498 1.09894 L .6451 1.09401 L .547 .315 .835 r
F
.63314 1.08625 m .624 1.09229 L .63498 1.09894 L F
.44073 1.12408 m .42813 1.11653 L .41882 1.12328 L .908 .599 .79 r
F
.44868 1.11608 m .42813 1.11653 L .44073 1.12408 L .89 .639 .806 r
F
.4611 1.12029 m .44868 1.11608 L .44073 1.12408 L .972 .694 .797 r
F
.56571 1.08586 m .56428 1.09509 L .57435 1.08994 L .86 .757 .848 r
F
.56571 1.08586 m .55707 1.09046 L .56428 1.09509 L F
.46753 1.11199 m .44868 1.11608 L .4611 1.12029 L .941 .707 .809 r
F
.47926 1.11401 m .46753 1.11199 L .4611 1.12029 L .974 .735 .807 r
F
.5255 .95659 m .53887 .95534 L .53786 .95304 L .894 .602 .795 r
F
.52479 .95551 m .5255 .95659 L .53786 .95304 L .895 .604 .795 r
F
.48795 .65423 m .51302 .6701 L .51301 .65677 L .648 .083 .641 r
F
.46037 .95905 m .44829 .95268 L .44716 .95904 L .908 .632 .799 r
F
.46037 .95905 m .46129 .95398 L .44829 .95268 L F
.48972 .68503 m .51302 .6701 L .48795 .65423 L .855 .205 .656 r
F
.46664 .71924 m .48795 .65423 L .46308 .69597 L 1 .332 .582 r
F
.46664 .71924 m .48972 .68503 L .48795 .65423 L F
.56462 .95063 m .56577 .95575 L .57894 .95493 L .881 .568 .789 r
F
.55174 .95297 m .56577 .95575 L .56462 .95063 L .888 .585 .792 r
F
.5007 .95725 m .48969 .95205 L .48823 .95443 L .894 .61 .797 r
F
.5007 .95725 m .50144 .95606 L .48969 .95205 L F
.77846 .72201 m .81015 .83257 L .79056 .71813 L .679 .045 .582 r
F
.77846 .72201 m .79703 .83029 L .81015 .83257 L F
.66919 1.11713 m .66824 1.13704 L .68135 1.13304 L .324 .006 .705 r
F
.68135 1.13304 m .66824 1.13704 L .67567 1.15048 L .327 .001 .669 r
F
.45293 .6666 m .48299 .5942 L .48111 .58591 L 1 .452 .551 r
F
.45664 .67534 m .48299 .5942 L .45293 .6666 L 1 .197 .493 r
F
.53786 .95304 m .53887 .95534 L .55174 .95297 L .895 .598 .794 r
F
.48725 .95692 m .47573 .95166 L .47427 .9554 L .896 .614 .798 r
F
.48725 .95692 m .48823 .95443 L .47573 .95166 L F
.3397 1.07527 m .33062 1.0957 L .32198 1.10024 L .308 0 .077 r
F
.35173 1.0819 m .33062 1.0957 L .3397 1.07527 L .172 0 0 r
F
.44716 .95904 m .43527 .95155 L .43395 .95923 L .921 .645 .799 r
F
.44716 .95904 m .44829 .95268 L .43527 .95155 L F
.57751 .94836 m .57894 .95493 L .59212 .95435 L .871 .543 .785 r
F
.56462 .95063 m .57894 .95493 L .57751 .94836 L .881 .568 .789 r
F
.52479 .95551 m .53786 .95304 L .53643 .95086 L .895 .604 .795 r
F
.52387 .95451 m .52479 .95551 L .53643 .95086 L .897 .605 .795 r
F
.50144 .95606 m .49156 .94987 L .48969 .95205 L .894 .609 .797 r
F
.50144 .95606 m .50237 .95498 L .49156 .94987 L F
.33501 1.18922 m .30608 1.17776 L .32386 1.221 L 1 .344 .566 r
F
.41882 1.12328 m .40663 1.11114 L .39616 1.11431 L .691 .385 .794 r
F
.42813 1.11653 m .40663 1.11114 L .41882 1.12328 L .738 .489 .812 r
F
.39616 1.11431 m .38498 1.09879 L .37364 1.09465 L .307 .031 .793 r
F
.38498 1.09879 m .37606 1.09045 L .36384 1.08742 L .249 .023 .859 r
F
.37606 1.09045 m .37118 1.09006 L .36384 1.08742 L .4 .029 .864 r
F
.37364 1.09464 m .36384 1.08742 L .35695 1.08494 L 0 0 .721 r
F
.38498 1.09879 m .36384 1.08742 L .37364 1.09464 L .249 .023 .859 r
F
.37118 1.09006 m .35663 1.08892 L .36384 1.08742 L .4 .029 .864 r
F
.35695 1.08494 m .36384 1.08742 L .35173 1.0819 L 0 0 .721 r
F
.3539 1.3181 m .31544 1.34478 L .34544 1.34789 L 1 .52 .602 r
F
.3539 1.3181 m .32553 1.3126 L .31544 1.34478 L F
.35492 .98761 m .34093 .97176 L .34157 .99531 L 1 .724 .746 r
F
.35492 .98761 m .35429 .96855 L .34093 .97176 L F
.52387 .95451 m .53643 .95086 L .53461 .94884 L .897 .605 .795 r
F
.52278 .9536 m .52387 .95451 L .53461 .94884 L .898 .606 .795 r
F
.43395 .95923 m .42224 .95062 L .42072 .95971 L .937 .659 .798 r
F
.43395 .95923 m .43527 .95155 L .42224 .95062 L F
.7232 1.4273 m .69477 1.43202 L .73272 1.46281 L .381 0 .595 r
F
.59042 .94619 m .59212 .95435 L .60531 .95412 L .856 .509 .779 r
F
.57751 .94836 m .59212 .95435 L .59042 .94619 L .871 .543 .785 r
F
.50237 .95498 m .49384 .94788 L .49156 .94987 L .894 .609 .797 r
F
.50237 .95498 m .50351 .95399 L .49384 .94788 L F
.40663 1.11114 m .38498 1.09879 L .39616 1.11431 L .474 .215 .831 r
F
.48404 1.10571 m .46753 1.11199 L .47926 1.11401 L .947 .738 .815 r
F
.49465 1.10627 m .48404 1.10571 L .47926 1.11401 L .96 .752 .815 r
F
.49334 .72427 m .51304 .70723 L .49152 .70793 L 1 .424 .703 r
F
.49334 .72427 m .51305 .7222 L .51304 .70723 L F
.47396 .73666 m .49334 .72427 L .49152 .70793 L 1 .516 .675 r
F
.51305 .7222 m .53459 .7177 L .51304 .70723 L .726 .319 .753 r
F
.51305 .7222 m .53277 .72848 L .53459 .7177 L F
.55023 .94947 m .55174 .95297 L .56462 .95063 L .895 .59 .791 r
F
.53786 .95304 m .55174 .95297 L .55023 .94947 L .895 .598 .794 r
F
.52278 .9536 m .53461 .94884 L .53243 .94701 L .898 .606 .795 r
F
.52146 .95277 m .52278 .9536 L .53243 .94701 L .899 .606 .795 r
F
.47427 .9554 m .46322 .94896 L .46129 .95398 L .901 .619 .798 r
F
.47427 .9554 m .47573 .95166 L .46322 .94896 L F
.53643 .95086 m .53786 .95304 L .55023 .94947 L .898 .601 .793 r
F
.50351 .95399 m .49647 .94611 L .49384 .94788 L .895 .609 .797 r
F
.50351 .95399 m .50483 .95311 L .49647 .94611 L F
.52483 1.09467 m .5164 1.1042 L .52714 1.10177 L .937 .769 .826 r
F
.53358 1.09212 m .52714 1.10177 L .53761 1.09856 L .926 .77 .829 r
F
.53358 1.09212 m .52483 1.09467 L .52714 1.10177 L F
.48823 .95443 m .47793 .94807 L .47573 .95166 L .896 .613 .797 r
F
.48823 .95443 m .48969 .95205 L .47793 .94807 L F
.42072 .95971 m .40919 .9499 L .40747 .96055 L .958 .672 .796 r
F
.42072 .95971 m .42224 .95062 L .40919 .9499 L F
.62121 1.08039 m .624 1.09229 L .63314 1.08625 L .657 .47 .84 r
F
.62121 1.08039 m .61302 1.08707 L .624 1.09229 L F
.60334 .94415 m .60531 .95412 L .61851 .95434 L .839 .466 .771 r
F
.59042 .94619 m .60531 .95412 L .60334 .94415 L .856 .509 .779 r
F
.51587 1.09657 m .50561 1.10573 L .5164 1.1042 L .943 .765 .823 r
F
.52483 1.09467 m .51587 1.09657 L .5164 1.1042 L .937 .769 .826 r
F
.69963 1.20269 m .69076 1.23076 L .71124 1.23095 L .316 0 .595 r
F
.71124 1.23096 m .69076 1.23077 L .70143 1.26407 L .36 0 .597 r
F
.52146 .95277 m .53243 .94701 L .5298 .94535 L .899 .606 .795 r
F
.51999 .95208 m .52146 .95277 L .5298 .94535 L F
.50483 .95311 m .49942 .9446 L .49647 .94611 L .895 .609 .797 r
F
.50483 .95311 m .5063 .95236 L .49942 .9446 L F
.54197 1.08902 m .53761 1.09856 L .54765 1.09473 L .912 .769 .834 r
F
.54197 1.08902 m .53358 1.09212 L .53761 1.09856 L F
.68135 1.13304 m .67567 1.15048 L .68943 1.14509 L .327 .001 .669 r
F
.68943 1.1451 m .67568 1.15048 L .67673 1.15253 L .344 .001 .656 r
F
.59103 1.079 m .5932 1.0883 L .60204 1.08275 L .793 .685 .853 r
F
.59103 1.079 m .58331 1.08468 L .5932 1.0883 L F
.57081 .75068 m .58833 .76007 L .59545 .76193 L 0 0 .739 r
F
.51999 .95208 m .5298 .94535 L .52685 .94396 L .899 .606 .795 r
F
.5184 .95153 m .51999 .95208 L .52685 .94396 L F
.5063 .95236 m .50262 .94337 L .49942 .9446 L .895 .608 .796 r
F
.5063 .95236 m .5079 .95175 L .50262 .94337 L F
.56262 .94586 m .56462 .95063 L .57751 .94836 L .894 .577 .788 r
F
.55023 .94947 m .56462 .95063 L .56262 .94586 L .895 .59 .791 r
F
.68943 1.1451 m .67673 1.15253 L .69058 1.1469 L .344 .001 .656 r
F
.69058 1.1469 m .67674 1.15253 L .68813 1.17628 L .342 0 .643 r
F
.40747 .96055 m .39612 .94934 L .39421 .96181 L .981 .679 .791 r
F
.40747 .96055 m .40919 .9499 L .39612 .94934 L F
.51587 1.09657 m .50685 1.09775 L .50561 1.10573 L .943 .765 .823 r
F
.50685 1.09775 m .49465 1.10627 L .50561 1.10573 L .944 .758 .821 r
F
.57339 1.08096 m .57435 1.08994 L .58331 1.08468 L .847 .739 .848 r
F
.57339 1.08096 m .56571 1.08586 L .57435 1.08994 L F
.46129 .95398 m .45069 .94634 L .44829 .95268 L .909 .626 .797 r
F
.46129 .95398 m .46322 .94896 L .45069 .94634 L F
.43772 .76114 m .44977 .75236 L .4306 .76184 L .556 .005 .763 r
F
.43772 .76114 m .44565 .75689 L .44169 .75825 L F
.42613 .76361 m .44419 .7591 L .42339 .76469 L .028 0 0 r
F
.4306 .76184 m .4322 .76152 L .42613 .76361 L F
.4322 .76152 m .44419 .7591 L .42613 .76361 L F
.44977 .75236 m .46664 .71925 L .44899 .75057 L 1 .881 .7 r
F
.44169 .75825 m .4505 .75402 L .44977 .75236 L .556 .005 .763 r
F
.44565 .75689 m .45526 .75173 L .44169 .75825 L F
.4306 .76184 m .44612 .75417 L .44419 .7591 L .028 0 0 r
F
.44612 .75417 m .44977 .75236 L .44419 .7591 L F
.42339 .76469 m .43845 .77406 L .41612 .76914 L .39 0 .173 r
F
.42339 .76469 m .44419 .7591 L .43845 .77406 L F
.41611 .76914 m .43845 .77407 L .43694 .77885 L .561 0 .266 r
F
.41611 .76914 m .43694 .77885 L .43562 .77974 L F
.42653 .78577 m .42762 .7836 L .42591 .78624 L 1 .377 .601 r
F
.41128 .77238 m .42614 .78258 L .41059 .77283 L .678 0 .284 r
F
.42614 .78258 m .42762 .7836 L .42604 .7826 L F
.42614 .78258 m .42604 .7826 L .41059 .77283 L F
.42762 .7836 m .4276 .7836 L .42613 .78267 L F
.42614 .78266 m .42613 .78267 L .41059 .77283 L F
.42762 .7836 m .42613 .78267 L .42614 .78266 L F
.41059 .77283 m .41784 .78577 L .40322 .77723 L .696 0 .267 r
F
.41784 .78577 m .4167 .78598 L .40322 .77723 L F
.39581 .78051 m .39958 .78875 L .38837 .78259 L .943 0 .222 r
F
.39958 .78875 m .39977 .78918 L .39912 .7888 L F
.39958 .78875 m .39912 .7888 L .38837 .78259 L F
.38836 .78259 m .39132 .78935 L .38078 .78369 L .988 0 .205 r
F
.39132 .78935 m .39154 .78984 L .3908 .78942 L F
.39132 .78935 m .3908 .78942 L .38078 .78369 L F
.34227 .78266 m .34729 .79606 L .33443 .78221 L 1 .003 .203 r
F
.34143 .81323 m .34729 .79606 L .3334 .81774 L 1 .612 .584 r
F
.34729 .79606 m .34722 .79608 L .3334 .81774 L F
.34729 .79606 m .34153 .79746 L .33443 .78221 L 1 .003 .203 r
F
.34227 .78266 m .34849 .7956 L .34729 .79606 L F
.34736 .79587 m .34163 .79721 L .34114 .79844 L 1 .612 .584 r
F
.34721 .79609 m .34114 .79844 L .3334 .81774 L F
.34736 .79587 m .34114 .79844 L .34721 .79609 L F
.34938 .80917 m .35436 .79463 L .34143 .81323 L 1 .628 .588 r
F
.35436 .79463 m .35441 .79449 L .3543 .79464 L F
.35436 .79463 m .3543 .79464 L .34143 .81323 L F
.35441 .79449 m .35433 .79451 L .34143 .81323 L F
.35441 .79449 m .34855 .79573 L .34227 .78266 L 1 .002 .198 r
F
.35726 .80565 m .36149 .79331 L .34938 .80917 L 1 .646 .593 r
F
.36149 .79331 m .36155 .79315 L .36141 .79333 L F
.36149 .79331 m .36141 .79333 L .34938 .80917 L F
.35007 .78315 m .3555 .79409 L .35441 .79449 L 1 .002 .198 r
F
.35447 .79431 m .34976 .79529 L .34927 .79635 L 1 .628 .588 r
F
.35432 .79452 m .34927 .79635 L .34143 .81323 L F
.35447 .79431 m .34927 .79635 L .35432 .79452 L F
.34976 .79529 m .34855 .79573 L .34143 .81323 L F
.36155 .79315 m .36147 .79316 L .34938 .80917 L 1 .646 .593 r
F
.36155 .79315 m .35556 .7942 L .35537 .79382 L 1 .001 .194 r
F
.36086 .79255 m .35537 .79382 L .35007 .78315 L F
.36155 .79315 m .35537 .79382 L .36086 .79255 L F
.34736 .79587 m .34743 .79566 L .34163 .79721 L 1 .612 .584 r
F
.35007 .78315 m .35431 .79423 L .34227 .78266 L 1 .002 .198 r
F
.35431 .79423 m .35417 .79426 L .34227 .78266 L F
.35781 .78363 m .36143 .79286 L .35007 .78315 L 1 .001 .194 r
F
.36143 .79286 m .36126 .7929 L .35007 .78315 L F
.37196 .75152 m .38837 .78259 L .36323 .74617 L .817 0 .084 r
F
.36323 .74617 m .38078 .78369 L .35436 .74007 L .879 0 .098 r
F
.36323 .74617 m .38836 .78259 L .38078 .78369 L F
.35436 .74007 m .37317 .78407 L .34546 .73358 L .924 0 .113 r
F
.35436 .74007 m .38078 .78369 L .37317 .78407 L F
.34546 .73358 m .36551 .78398 L .33654 .72691 L .959 0 .126 r
F
.34546 .73358 m .37317 .78407 L .36551 .78398 L F
.33654 .72691 m .35781 .78363 L .32758 .72023 L .987 0 .139 r
F
.33654 .72691 m .36551 .78398 L .35781 .78363 L F
.32758 .72023 m .35007 .78315 L .31858 .71363 L 1 0 .151 r
F
.32758 .72023 m .35781 .78363 L .35007 .78315 L F
.31858 .71363 m .35007 .78315 L .34227 .78266 L 1 0 .162 r
F
.34743 .79566 m .37693 .70922 L .34172 .79699 L 1 .612 .584 r
F
.34743 .79566 m .34172 .79699 L .34163 .79721 L F
.36506 .80281 m .36868 .79225 L .35726 .80565 L 1 .667 .597 r
F
.36868 .79225 m .36875 .79204 L .36856 .79226 L F
.36868 .79225 m .36856 .79226 L .35726 .80565 L F
.35781 .78363 m .36255 .79281 L .36155 .79315 L 1 .001 .194 r
F
.3616 .79298 m .35641 .79392 L .35589 .79505 L 1 .646 .593 r
F
.36145 .79318 m .35589 .79505 L .34938 .80917 L F
.3616 .79298 m .35589 .79505 L .36145 .79318 L F
.35641 .79392 m .35556 .7942 L .34938 .80917 L F
.36875 .79204 m .36867 .79205 L .35726 .80565 L 1 .667 .597 r
F
.36875 .79204 m .3626 .7929 L .36239 .79251 L 1 .001 .192 r
F
.36785 .79135 m .36239 .79251 L .35781 .78363 L F
.36875 .79204 m .36239 .79251 L .36785 .79135 L F
.35431 .79423 m .35441 .79449 L .35417 .79426 L 1 .002 .198 r
F
.35447 .79431 m .35451 .79418 L .34863 .79552 L 1 .628 .588 r
F
.36551 .78398 m .36862 .79171 L .35781 .78363 L 1 .001 .192 r
F
.36862 .79171 m .36838 .79175 L .35781 .78363 L F
.35451 .79418 m .38291 .71126 L .34867 .79542 L 1 .628 .588 r
F
.35451 .79418 m .34867 .79542 L .34863 .79552 L F
.37279 .80086 m .376 .79144 L .36506 .80281 L 1 .689 .602 r
F
.376 .79144 m .37609 .79116 L .37581 .79146 L F
.376 .79144 m .37581 .79146 L .36506 .80281 L F
.36551 .78398 m .36969 .79174 L .36875 .79204 L 1 .001 .192 r
F
.3688 .79188 m .3629 .79282 L .36236 .79404 L 1 .667 .597 r
F
.36865 .79207 m .36236 .79404 L .35726 .80565 L F
.3688 .79188 m .36236 .79404 L .36865 .79207 L F
.3629 .79282 m .3626 .7929 L .35726 .80565 L F
.37609 .79116 m .37599 .79117 L .36506 .80281 L 1 .689 .602 r
F
.37609 .79116 m .36973 .79182 L .36551 .78398 L 1 0 .191 r
F
.37317 .78407 m .37702 .79088 L .37609 .79116 L F
.37614 .79101 m .3697 .7919 L .36916 .79318 L 1 .689 .602 r
F
.37597 .79119 m .36916 .79318 L .36506 .80281 L F
.37614 .79101 m .36916 .79318 L .37597 .79119 L F
.38043 .80009 m .38353 .79089 L .37279 .80086 L 1 .71 .607 r
F
.38353 .79089 m .38366 .79048 L .38322 .7909 L F
.38353 .79089 m .38322 .7909 L .37279 .80086 L F
.37317 .78407 m .37593 .79076 L .36551 .78398 L 1 0 .191 r
F
.37593 .79076 m .37609 .79116 L .37559 .79081 L F
.37593 .79076 m .37559 .79081 L .36551 .78398 L F
.37614 .79101 m .37646 .79009 L .3697 .7919 L 1 .689 .602 r
F
.38078 .78369 m .38346 .78999 L .37317 .78407 L 1 0 .195 r
F
.38346 .78999 m .38298 .79006 L .37317 .78407 L F
.38366 .79048 m .37706 .79095 L .37317 .78407 L F
.38936 .75934 m .40322 .77723 L .38067 .75596 L .61 0 .028 r
F
.38067 .75596 m .40322 .77723 L .39581 .78051 L .728 0 .064 r
F
.37196 .75152 m .39581 .78051 L .38837 .78259 L .817 0 .084 r
F
.37646 .79009 m .40058 .71925 L .36973 .79182 L 1 .689 .602 r
F
.37646 .79009 m .36973 .79182 L .3697 .7919 L F
.36969 .79174 m .36973 .79182 L .36875 .79204 L 1 .001 .192 r
F
.38366 .79048 m .38354 .79049 L .37279 .80086 L 1 .71 .607 r
F
.38078 .78369 m .38469 .79019 L .38366 .79048 L 1 0 .195 r
F
.38372 .79031 m .37697 .79117 L .37638 .79252 L 1 .71 .607 r
F
.3835 .79052 m .37638 .79252 L .37279 .80086 L F
.38372 .79031 m .37638 .79252 L .3835 .79052 L F
.38469 .79019 m .38473 .79025 L .38366 .79048 L 1 0 .195 r
F
.38366 .79048 m .38473 .79025 L .38372 .79031 L 1 .71 .607 r
F
.38043 .80009 m .38473 .79025 L .38366 .79048 L F
.388 .80085 m .39159 .78995 L .38043 .80009 L 1 .724 .612 r
F
.39159 .78995 m .3914 .78996 L .38043 .80009 L F
.39154 .78984 m .39141 .78984 L .38078 .78369 L .988 0 .205 r
F
.39159 .78995 m .38473 .79025 L .38078 .78369 L F
.39977 .78918 m .39947 .7892 L .38837 .78259 L .943 0 .222 r
F
.3999 .78945 m .39296 .78963 L .38837 .78259 L F
.3959 .76123 m .41128 .77238 L .39018 .75961 L .51 0 0 r
F
.3959 .76123 m .41611 .76914 L .41128 .77238 L F
.39018 .75961 m .41059 .77283 L .38937 .75934 L .6 0 .037 r
F
.39018 .75961 m .41128 .77238 L .41059 .77283 L F
.38936 .75934 m .41059 .77283 L .40322 .77723 L .61 0 .028 r
F
.39292 .78956 m .39296 .78963 L .39159 .78995 L .988 0 .205 r
F
.38836 .78259 m .39292 .78956 L .39159 .78995 L F
.39159 .78995 m .39296 .78963 L .39166 .78972 L 1 .724 .612 r
F
.388 .80085 m .39296 .78963 L .39159 .78995 L F
.39296 .78963 m .39296 .78963 L .39159 .78995 L F
.39537 .80359 m .3999 .78945 L .388 .80085 L 1 .714 .615 r
F
.3999 .78945 m .39958 .78946 L .388 .80085 L F
.40322 .77723 m .40844 .78795 L .39581 .78051 L .853 0 .246 r
F
.40844 .78795 m .40772 .78804 L .39581 .78051 L F
.40839 .78847 m .40199 .78888 L .39581 .78051 L F
.40883 .78874 m .40199 .78888 L .40839 .78847 L F
.39537 .80359 m .40199 .78888 L .3999 .78945 L 1 .714 .615 r
F
.40265 .80881 m .40883 .78874 L .39537 .80359 L 1 .646 .616 r
F
.40883 .78874 m .40818 .78875 L .39537 .80359 L F
.40844 .78795 m .40883 .78874 L .40772 .78804 L .853 0 .246 r
F
.40322 .77723 m .41239 .78716 L .40883 .78874 L F
.40918 .7876 m .40214 .78856 L .40036 .79251 L 1 .646 .616 r
F
.40779 .7892 m .40036 .79251 L .39537 .80359 L F
.40918 .7876 m .40036 .79251 L .40779 .7892 L F
.41239 .78716 m .41266 .78745 L .40883 .78874 L .853 0 .246 r
F
.40883 .78874 m .41266 .78745 L .40918 .7876 L 1 .646 .616 r
F
.40265 .80881 m .41266 .78745 L .40883 .78874 L F
.40986 .81692 m .41867 .78725 L .40265 .80881 L 1 .48 .612 r
F
.41867 .78725 m .41728 .7873 L .40265 .80881 L F
.4186 .78721 m .41266 .78745 L .41239 .78716 L .696 0 .267 r
F
.41745 .78646 m .41239 .78716 L .40322 .77723 L F
.4186 .78721 m .41239 .78716 L .41745 .78646 L F
.41867 .78725 m .41266 .78745 L .4186 .78721 L F
.41784 .78577 m .41867 .78725 L .4167 .78598 L F
.41059 .77283 m .42585 .78271 L .41867 .78725 L F
.41971 .78372 m .41397 .78467 L .41027 .79256 L 1 .48 .612 r
F
.4163 .78875 m .41027 .79256 L .40265 .80881 L F
.41971 .78372 m .41027 .79256 L .4163 .78875 L F
.41524 .82491 m .4287 .78865 L .41053 .81783 L 1 .298 .602 r
F
.4287 .78865 m .4306 .78352 L .42765 .78857 L F
.4287 .78865 m .42765 .78857 L .41053 .81783 L F
.4306 .78352 m .43045 .78353 L .41053 .81783 L F
.43086 .78283 m .42808 .78485 L .41053 .81783 L F
.41053 .81783 m .4253 .78824 L .40986 .81692 L 1 .377 .601 r
F
.4253 .78824 m .42653 .78577 L .42521 .78824 L F
.4253 .78824 m .42521 .78824 L .40986 .81692 L F
.41283 .78745 m .41308 .78771 L .41266 .78745 L .696 0 .267 r
F
.42653 .78577 m .42591 .78624 L .42487 .78823 L 1 .377 .601 r
F
.42521 .78824 m .42487 .78823 L .40986 .81692 L F
.42653 .78577 m .42487 .78823 L .42521 .78824 L F
.42762 .7836 m .42728 .78363 L .42591 .78624 L F
.41611 .76914 m .43495 .77937 L .43065 .78264 L .561 0 .266 r
F
.41611 .76914 m .42944 .78151 L .41128 .77238 L F
.42944 .78151 m .43086 .78283 L .42863 .78166 L F
.43086 .78283 m .43082 .78283 L .42863 .78166 L F
.43086 .78283 m .42907 .783 L .42808 .78485 L 1 .298 .602 r
F
.42765 .78363 m .42728 .78363 L .42719 .78357 L .678 0 .284 r
F
.42765 .78363 m .42719 .78357 L .4276 .7836 L F
.41053 .81783 m .42871 .78366 L .42762 .7836 L 1 .377 .601 r
F
.41524 .82491 m .43828 .78829 L .43724 .78355 L 1 .298 .602 r
F
.43065 .78264 m .43174 .78219 L .43086 .78283 L .561 0 .266 r
F
.43174 .78219 m .43651 .78022 L .43086 .78283 L F
.43495 .77937 m .43651 .78022 L .43065 .78264 L F
.43562 .77974 m .43694 .77885 L .43651 .78022 L F
.43086 .78283 m .43724 .78355 L .43651 .78022 L 1 .298 .602 r
F
.41524 .82491 m .43724 .78355 L .43086 .78283 L F
.43828 .78829 m .44037 .77869 L .43651 .78022 L 1 .4 .548 r
F
.43845 .77407 m .44037 .77869 L .43651 .78022 L .554 0 .441 r
F
.44977 .75236 m .44899 .75057 L .44419 .7591 L 1 .881 .7 r
F
.4505 .75402 m .45526 .75173 L .44977 .75236 L .556 .005 .763 r
F
.45526 .75173 m .47396 .73666 L .47031 .72836 L 1 .912 .751 r
F
.45526 .75173 m .47031 .72836 L .44977 .75236 L F
.44977 .75236 m .47031 .72836 L .46664 .71925 L 1 .881 .7 r
F
.44419 .7591 m .46664 .71925 L .46364 .71126 L 1 .778 .637 r
F
.46172 .71273 m .46364 .71126 L .46296 .70944 L F
.44419 .7591 m .46364 .71126 L .46172 .71273 L F
.45342 .71907 m .46299 .70569 L .46068 .6859 L 1 .4 .548 r
F
.43828 .78829 m .45091 .74606 L .44037 .77869 L F
.45105 .77652 m .44155 .77875 L .43828 .7883 L .675 .011 .51 r
F
.46259 .71737 m .45813 .72981 L .43828 .7883 L F
.43832 .77951 m .44148 .78135 L .43651 .78022 L .554 0 .441 r
F
.44037 .77869 m .4405 .779 L .43832 .77951 L F
.4405 .779 m .44148 .78135 L .43832 .77951 L F
.44356 .81492 m .45105 .77652 L .43828 .7883 L .675 .011 .51 r
F
.45105 .77652 m .46259 .71737 L .44155 .77875 L F
.46259 .71737 m .46291 .71573 L .45813 .72981 L F
.44356 .81492 m .46585 .82319 L .46291 .71573 L F
.44829 .95268 m .43814 .94382 L .43527 .95155 L .921 .634 .796 r
F
.44829 .95268 m .45069 .94634 L .43814 .94382 L F
.43527 .95155 m .43814 .94382 L .42556 .94141 L .936 .642 .794 r
F
.45069 .94634 m .44248 .93628 L .43814 .94382 L .918 .622 .794 r
F
.45069 .94634 m .45432 .94018 L .44248 .93628 L F
.43814 .94382 m .43062 .9324 L .42556 .94141 L .932 .626 .79 r
F
.43814 .94382 m .44248 .93628 L .43062 .9324 L F
.45432 .94018 m .44806 .92932 L .44248 .93628 L .914 .611 .792 r
F
.44248 .93628 m .43712 .92407 L .43062 .9324 L .926 .61 .788 r
F
.44248 .93628 m .44806 .92932 L .43712 .92407 L F
.44806 .92932 m .44506 .91643 L .43712 .92407 L .918 .594 .786 r
F
.44806 .92932 m .45487 .92297 L .44506 .91643 L F
.43712 .92407 m .44506 .91643 L .43522 .90977 L .931 .591 .781 r
F
.45487 .92297 m .45429 .90973 L .44506 .91643 L .906 .579 .785 r
F
.44506 .91643 m .44577 .90176 L .43522 .90977 L .916 .565 .778 r
F
.44506 .91643 m .45429 .90973 L .44577 .90176 L F
.45429 .90973 m .45762 .8953 L .44577 .90176 L .894 .542 .777 r
F
.43522 .90977 m .44577 .90176 L .43724 .89347 L .932 .554 .77 r
F
.44577 .90176 m .45058 .88561 L .43724 .89347 L .902 .509 .765 r
F
.44577 .90176 m .45762 .8953 L .45058 .88561 L F
.43724 .89347 m .45058 .88561 L .44353 .875 L .921 .472 .748 r
F
.45058 .88561 m .4597 .86911 L .44353 .875 L .853 .417 .75 r
F
.44353 .875 m .45428 .85527 L .43647 .8633 L .858 .335 .717 r
F
.44353 .875 m .4597 .86911 L .45428 .85527 L F
.43647 .8633 m .45428 .85527 L .4489 .83774 L .874 .251 .674 r
F
.45428 .85527 m .46332 .84833 L .4489 .83774 L .625 .182 .725 r
F
.46332 .84833 m .4695 .84358 L .46182 .84141 L F
.46332 .84833 m .46182 .84141 L .4489 .83774 L F
.4489 .83774 m .45971 .82846 L .44356 .81492 L .599 .077 .657 r
F
.45971 .82846 m .46585 .82319 L .45858 .8205 L F
.45971 .82846 m .45858 .8205 L .44356 .81492 L F
.45971 .82846 m .4695 .84358 L .46585 .82319 L F
.4489 .83774 m .46182 .84141 L .45971 .82846 L F
.46182 .84141 m .4695 .84358 L .45971 .82846 L F
.45626 .80399 m .4553 .79987 L .45519 .80083 L .802 .026 .5 r
F
.42234 .83734 m .43828 .7883 L .41524 .82491 L 1 .198 .606 r
F
.42234 .83734 m .44356 .81492 L .43828 .7883 L F
.42941 .85055 m .44356 .81492 L .42234 .83734 L .909 .193 .632 r
F
.42941 .85055 m .4489 .83774 L .44356 .81492 L F
.43405 .78802 m .44517 .82135 L .42818 .80424 L 1 .008 .336 r
F
.45601 .80586 m .45551 .80279 L .45473 .80901 L .802 .026 .5 r
F
.45556 .8093 m .45452 .81067 L .45383 .81613 L F
.45455 .81699 m .4536 .81795 L .45303 .82253 L F
.45392 .82175 m .45303 .82253 L .43625 .95622 L F
.45455 .81699 m .45303 .82253 L .45392 .82175 L F
.45551 .80279 m .45479 .80407 L .43625 .95622 L F
.4557 .81309 m .4553 .81126 L .43625 .95622 L F
.44196 .95782 m .4557 .81309 L .43625 .95622 L F
.45432 .94018 m .45898 .93452 L .44806 .92932 L .914 .611 .792 r
F
.45898 .93452 m .45487 .92297 L .44806 .92932 L .909 .6 .79 r
F
.45898 .93452 m .46465 .92935 L .45487 .92297 L F
.46465 .92935 m .46278 .9174 L .45487 .92297 L .902 .592 .79 r
F
.46465 .92935 m .47124 .9248 L .46278 .9174 L F
.47124 .9248 m .47164 .91281 L .46278 .9174 L .894 .588 .791 r
F
.45487 .92297 m .46278 .9174 L .45429 .90973 L .906 .579 .785 r
F
.46278 .9174 m .46464 .9043 L .45429 .90973 L .892 .568 .786 r
F
.46278 .9174 m .47164 .91281 L .46464 .9043 L F
.47164 .91281 m .47592 .90038 L .46464 .9043 L .875 .568 .791 r
F
.45429 .90973 m .46464 .9043 L .45762 .8953 L .894 .542 .777 r
F
.46464 .9043 m .47052 .89094 L .45762 .8953 L .864 .534 .784 r
F
.46464 .9043 m .47592 .90038 L .47052 .89094 L F
.45762 .8953 m .46511 .8807 L .45058 .88561 L .856 .484 .771 r
F
.45762 .8953 m .47052 .89094 L .46511 .8807 L F
.45058 .88561 m .46511 .8807 L .4597 .86911 L .853 .417 .75 r
F
.46511 .8807 m .47688 .86917 L .4597 .86911 L .736 .412 .786 r
F
.4597 .86911 m .47319 .85768 L .45428 .85527 L .68 .305 .765 r
F
.4597 .86911 m .47688 .86917 L .47319 .85768 L F
.45428 .85527 m .47319 .85768 L .4695 .84358 L .625 .182 .725 r
F
.44196 .95782 m .46516 .91443 L .46272 .73904 L .802 .026 .5 r
F
.43625 .95622 m .45243 .82313 L .45892 .89011 L .39 0 .427 r
F
.45243 .82313 m .45249 .82331 L .45892 .89011 L F
.45245 .82295 m .46009 .84344 L .45892 .89011 L F
.48558 .92897 m .48666 .91801 L .47862 .921 L .892 .603 .796 r
F
.47862 .921 m .4813 .90933 L .47164 .91281 L .884 .59 .794 r
F
.47862 .921 m .48666 .91801 L .4813 .90933 L F
.47164 .91281 m .4813 .90933 L .47592 .90038 L .875 .568 .791 r
F
.4813 .90933 m .48791 .898 L .47592 .90038 L .854 .577 .8 r
F
.4548 .81507 m .45383 .81613 L .4536 .81795 L .802 .026 .5 r
F
.4548 .81507 m .4536 .81795 L .45455 .81699 L F
.45556 .8093 m .45383 .81613 L .4548 .81507 L F
.45579 .80751 m .45473 .80901 L .45452 .81067 L F
.45579 .80751 m .45452 .81067 L .45556 .8093 L F
.45601 .80586 m .45473 .80901 L .45579 .80751 L F
.45551 .80279 m .45519 .80083 L .45479 .80407 L F
.45626 .80399 m .45519 .80083 L .45601 .80586 L F
.45734 .79572 m .45559 .79929 L .45626 .80399 L F
.45559 .79929 m .4553 .79987 L .45626 .80399 L F
.4557 .81309 m .45734 .79572 L .4553 .81126 L F
.45734 .79572 m .46272 .73904 L .4553 .79987 L F
.45245 .82295 m .45593 .79439 L .46009 .84344 L .39 0 .427 r
F
.45593 .79439 m .45839 .80692 L .4592 .82426 L F
.45809 .81985 m .4592 .82426 L .46009 .84344 L F
.45593 .79439 m .4592 .82426 L .45809 .81985 L F
.48057 .87935 m .48655 .87675 L .47689 .86917 L .577 .384 .849 r
F
.48655 .87675 m .49477 .87316 L .48519 .87102 L F
.48655 .87675 m .48519 .87102 L .47689 .86917 L F
.48057 .87935 m .49665 .88046 L .49477 .87316 L F
.47689 .86917 m .49288 .86712 L .47319 .85768 L .4 .151 .864 r
F
.47689 .86917 m .49477 .87316 L .49288 .86712 L F
.47319 .85768 m .49097 .86369 L .4695 .84359 L 0 0 .767 r
F
.47319 .85768 m .49288 .86712 L .49097 .86369 L F
.48049 .85619 m .49097 .86369 L .48902 .86598 L .703 0 0 r
F
.4695 .84359 m .48086 .85423 L .48049 .85619 L F
.48086 .85423 m .49097 .86369 L .48049 .85619 L F
.48558 .92897 m .492 .92654 L .48666 .91801 L .892 .603 .796 r
F
.492 .92654 m .4952 .91587 L .48666 .91801 L .888 .607 .798 r
F
.48666 .91801 m .49156 .90697 L .4813 .90933 L .875 .597 .799 r
F
.48666 .91801 m .4952 .91587 L .49156 .90697 L F
.4813 .90933 m .49156 .90697 L .48791 .898 L .854 .577 .8 r
F
.4695 .84359 m .48902 .86598 L .46585 .8232 L .703 0 0 r
F
.47968 .85929 m .48902 .86598 L .48702 .87845 L 1 .007 .222 r
F
.46585 .8232 m .47887 .84723 L .47968 .85929 L F
.47887 .84723 m .48902 .86598 L .47968 .85929 L F
.46585 .8232 m .47968 .85929 L .46293 .73045 L F
.4791 .85779 m .48011 .86565 L .47898 .85746 L .825 0 .02 r
F
.47124 .9248 m .47862 .921 L .47164 .91281 L .894 .588 .791 r
F
.47592 .90038 m .48425 .88885 L .47052 .89094 L .825 .544 .8 r
F
.47592 .90038 m .48791 .898 L .48425 .88885 L F
.47052 .89094 m .48057 .87935 L .46511 .8807 L .785 .49 .796 r
F
.47052 .89094 m .48425 .88885 L .48057 .87935 L F
.48425 .88885 m .49665 .88046 L .48057 .87935 L .702 .504 .832 r
F
.46511 .8807 m .48057 .87935 L .47688 .86917 L .736 .412 .786 r
F
.46516 .91443 m .48685 .91863 L .47462 .82567 L .379 .015 .693 r
F
.4791 .85779 m .47898 .85746 L .47485 .82748 L .825 0 .02 r
F
.4757 .83106 m .4791 .85779 L .47485 .82748 L F
.48153 .87686 m .48158 .87723 L .48179 .8802 L F
.48169 .87812 m .48685 .91863 L .48193 .88126 L F
.48164 .88253 m .48685 .91863 L .48556 .91436 L F
.47922 .86292 m .48066 .87343 L .48164 .88253 L F
.48066 .87343 m .48685 .91863 L .48164 .88253 L F
.46516 .91443 m .47462 .82567 L .46378 .8116 L .379 .015 .693 r
F
.45892 .89012 m .47904 .89312 L .45851 .89552 L .668 0 .306 r
F
.47904 .89312 m .47925 .89395 L .45851 .89552 L F
.46378 .8116 m .47462 .82567 L .46275 .73548 L .379 .015 .693 r
F
.47863 .89045 m .47864 .8905 L .47873 .89149 L 1 .057 .275 r
F
.46626 .7578 m .47892 .8915 L .47873 .89149 L F
.47631 .89271 m .47881 .89192 L .47904 .89312 L .668 0 .306 r
F
.45892 .89012 m .47873 .89149 L .47631 .89271 L F
.47873 .89149 m .47892 .89151 L .47875 .89158 L F
.47873 .89149 m .47875 .89158 L .47631 .89271 L F
.45851 .89553 m .47637 .89457 L .48337 .91713 L .633 0 .306 r
F
.47637 .89457 m .48281 .91396 L .48337 .91713 L F
.47937 .89441 m .48334 .91565 L .48337 .91713 L F
.47953 .89392 m .47917 .89236 L .47949 .89348 L .807 0 0 r
F
.47981 .89488 m .47949 .89348 L .48538 .91413 L F
.47953 .89392 m .47949 .89348 L .47981 .89488 L F
.47949 .89348 m .48556 .91436 L .48539 .91414 L F
.47947 .89338 m .48556 .91436 L .47949 .89348 L F
.47915 .89229 m .48556 .91436 L .47917 .89236 L F
.47894 .89156 m .48539 .91414 L .48538 .91413 L F
.48254 .88983 m .48556 .91436 L .47893 .8915 L .825 0 .02 r
F
.47931 .89316 m .48538 .91413 L .47937 .8944 L .807 0 0 r
F
.47937 .89441 m .48538 .91413 L .48141 .90231 L .887 0 .04 r
F
.48141 .90231 m .48538 .91413 L .48466 .91492 L F
.48141 .90231 m .48466 .91492 L .48345 .91625 L F
.4831 .91434 m .48345 .91625 L .48338 .91633 L F
.48141 .90231 m .48345 .91625 L .4831 .91434 L F
.48322 .90968 m .48382 .91225 L .48345 .91625 L .633 0 .306 r
F
.4794 .862 m .48685 .91863 L .47922 .86292 L .825 0 .02 r
F
.49942 .9446 m .49732 .93498 L .49251 .93682 L .896 .61 .796 r
F
.49942 .9446 m .50262 .94337 L .49732 .93498 L F
.49251 .93682 m .492 .92654 L .48558 .92897 L .896 .609 .796 r
F
.49251 .93682 m .49732 .93498 L .492 .92654 L F
.49732 .93498 m .49882 .92474 L .492 .92654 L .895 .611 .797 r
F
.492 .92654 m .49882 .92474 L .4952 .91587 L .888 .607 .798 r
F
.48809 .93909 m .48558 .92897 L .47968 .93201 L .897 .607 .796 r
F
.48809 .93909 m .49251 .93682 L .48558 .92897 L F
.47968 .93201 m .47862 .921 L .47124 .9248 L .895 .601 .794 r
F
.47968 .93201 m .48558 .92897 L .47862 .921 L F
.46516 .91443 m .48876 .9329 L .48685 .91863 L .379 .015 .693 r
F
.48969 .95205 m .49156 .94987 L .48073 .94478 L .896 .611 .797 r
F
.49156 .94987 m .48414 .94176 L .48073 .94478 L .896 .61 .797 r
F
.49156 .94987 m .49384 .94788 L .48414 .94176 L F
.49384 .94788 m .48809 .93909 L .48414 .94176 L .896 .61 .796 r
F
.49384 .94788 m .49647 .94611 L .48809 .93909 L F
.49647 .94611 m .49251 .93682 L .48809 .93909 L F
.49647 .94611 m .49942 .9446 L .49251 .93682 L F
.49066 .94992 m .51302 .96067 L .48876 .9329 L .133 0 .769 r
F
.49066 .94992 m .51303 .96614 L .51302 .96067 L F
.5079 .95175 m .50602 .94246 L .50262 .94337 L .895 .608 .796 r
F
.5079 .95175 m .50959 .95129 L .50602 .94246 L F
.50262 .94337 m .50243 .93361 L .49732 .93498 L .897 .611 .797 r
F
.50262 .94337 m .50602 .94246 L .50243 .93361 L F
.49732 .93498 m .50243 .93361 L .49882 .92474 L .895 .611 .797 r
F
.48876 .9329 m .51301 .95828 L .48685 .91863 L 0 0 .559 r
F
.50668 .95166 m .51302 .96067 L .51301 .95842 L F
.51272 .95798 m .51301 .95842 L .51301 .95828 L F
.51166 .95679 m .51301 .95828 L .513 .95885 L .644 0 0 r
F
.48685 .91863 m .51138 .95581 L .51166 .95679 L F
.51138 .95581 m .51301 .95828 L .51166 .95679 L F
.50668 .95166 m .51301 .95842 L .51272 .95798 L 0 0 .559 r
F
.50827 .95157 m .513 .95885 L .50851 .95156 L .644 0 0 r
F
.50775 .95051 m .51172 .95698 L .50763 .95033 L .727 0 0 r
F
.51172 .95698 m .513 .95908 L .51172 .95699 L F
.51172 .95698 m .51172 .95699 L .50763 .95033 L F
.48685 .91863 m .50827 .95157 L .48556 .91436 L .644 0 0 r
F
.50827 .95157 m .50851 .95156 L .48556 .91436 L F
.48556 .91436 m .50775 .95051 L .48538 .91413 L .727 0 0 r
F
.50775 .95051 m .50763 .95033 L .48538 .91413 L F
.48876 .9329 m .50522 .95173 L .50668 .95166 L 0 0 .559 r
F
.50522 .95173 m .51302 .96067 L .50668 .95166 L F
.48538 .91413 m .51299 .96354 L .48672 .92166 L .796 0 0 r
F
.49256 .96497 m .51303 .96614 L .49066 .94992 L .409 .126 .821 r
F
.49256 .96497 m .51304 .97336 L .51303 .96614 L F
.48973 .93476 m .51298 .9713 L .49076 .93787 L .874 0 .025 r
F
.48934 .93145 m .51298 .9713 L .48973 .93476 L F
.48706 .92316 m .51298 .9713 L .48773 .92873 L F
.50959 .95129 m .50954 .94187 L .50602 .94246 L .896 .608 .796 r
F
.50959 .95129 m .51135 .951 L .50954 .94187 L F
.51135 .951 m .51314 .94161 L .50954 .94187 L F
.51135 .951 m .51315 .95088 L .51314 .94161 L F
.50602 .94246 m .50773 .93272 L .50243 .93361 L .897 .611 .797 r
F
.50602 .94246 m .50954 .94187 L .50773 .93272 L F
.50954 .94187 m .51313 .93233 L .50773 .93272 L F
.50954 .94187 m .51314 .94161 L .51313 .93233 L F
.50773 .93272 m .51313 .93233 L .51312 .92309 L .895 .615 .798 r
F
.48556 .91436 m .513 .95885 L .513 .95908 L .727 0 0 r
F
.48538 .91413 m .513 .95908 L .51299 .96354 L .796 0 0 r
F
.48872 .92626 m .51299 .96354 L .51298 .9713 L .874 0 .025 r
F
.48538 .91413 m .48381 .91701 L .48375 .91688 L .796 0 0 r
F
.48351 .91618 m .48375 .91688 L .48345 .91625 L F
.48538 .91413 m .48375 .91688 L .48351 .91618 L F
.48377 .91696 m .48826 .92411 L .4839 .9173 L .874 0 .025 r
F
.48469 .9154 m .48672 .92166 L .48381 .91701 L .796 0 0 r
F
.48538 .91413 m .48672 .92166 L .48469 .9154 L F
.49882 .92474 m .50407 .91455 L .4952 .91587 L .885 .613 .801 r
F
.49882 .92474 m .5059 .9236 L .50407 .91455 L F
.5059 .9236 m .51311 .91398 L .50407 .91455 L .886 .618 .802 r
F
.5059 .9236 m .51312 .92309 L .51311 .91398 L F
.4952 .91587 m .50223 .90562 L .49157 .90697 L .867 .608 .805 r
F
.4952 .91587 m .50407 .91455 L .50223 .90562 L F
.50407 .91455 m .5131 .9051 L .50223 .90562 L .867 .619 .808 r
F
.50407 .91455 m .51311 .91398 L .5131 .9051 L F
.50223 .90562 m .5131 .9051 L .51309 .89661 L .832 .614 .818 r
F
.48383 .91714 m .51299 .904 L .51298 .91737 L .468 0 .194 r
F
.48337 .91713 m .48377 .91696 L .4838 .91705 L F
.48337 .91713 m .4838 .91705 L .48381 .91714 L F
.48345 .91625 m .48377 .91696 L .48337 .91713 L .567 0 .176 r
F
.48345 .91625 m .48381 .91701 L .48377 .91696 L .796 0 0 r
F
.48346 .91614 m .48377 .91696 L .48345 .91625 L .567 0 .176 r
F
.48345 .91625 m .48377 .91696 L .48338 .91633 L .796 0 0 r
F
.48335 .91602 m .48345 .91625 L .48337 .91713 L .633 0 .306 r
F
.47441 .9356 m .47124 .9248 L .46465 .92935 L .899 .602 .793 r
F
.47441 .9356 m .47968 .93201 L .47124 .9248 L F
.47573 .95166 m .47793 .94807 L .46614 .94411 L .9 .616 .797 r
F
.47793 .94807 m .46987 .93967 L .46614 .94411 L .899 .612 .796 r
F
.47793 .94807 m .48073 .94478 L .46987 .93967 L F
.48073 .94478 m .47441 .9356 L .46987 .93967 L .899 .609 .796 r
F
.48073 .94478 m .48414 .94176 L .47441 .9356 L F
.46614 .94411 m .46987 .93967 L .45898 .93452 L .905 .612 .794 r
F
.48414 .94176 m .47968 .93201 L .47441 .9356 L .898 .608 .795 r
F
.48414 .94176 m .48809 .93909 L .47968 .93201 L F
.46987 .93967 m .46465 .92935 L .45898 .93452 L .902 .606 .794 r
F
.46987 .93967 m .47441 .9356 L .46465 .92935 L F
.46879 .94559 m .48876 .9329 L .46516 .91443 L .716 .18 .688 r
F
.46322 .94896 m .45432 .94018 L .45069 .94634 L .907 .619 .796 r
F
.46322 .94896 m .46614 .94411 L .45432 .94018 L F
.46614 .94411 m .45898 .93452 L .45432 .94018 L .905 .612 .794 r
F
.44757 .96684 m .46516 .91443 L .44196 .95782 L 1 .209 .593 r
F
.47573 .95166 m .46614 .94411 L .46322 .94896 L .9 .616 .797 r
F
.44757 .96684 m .46879 .94559 L .46516 .91443 L 1 .209 .593 r
F
.45851 .89553 m .48337 .91713 L .45422 .9359 L .633 0 .306 r
F
.48969 .95205 m .48073 .94478 L .47793 .94807 L .896 .611 .797 r
F
.46879 .94559 m .49066 .94992 L .48876 .9329 L .716 .18 .688 r
F
.48337 .91713 m .48365 .91714 L .48126 .93922 L .468 0 .194 r
F
.48365 .91714 m .48376 .91756 L .48126 .93922 L F
.48381 .91714 m .4884 .9343 L .48126 .93922 L F
.48126 .93922 m .4884 .9343 L .48876 .93735 L .409 0 .198 r
F
.4888 .93734 m .4884 .9343 L .48969 .93896 L .952 0 .101 r
F
.4884 .9343 m .48879 .93727 L .48876 .93735 L .409 0 .198 r
F
.45422 .9359 m .48337 .91713 L .48126 .93922 L .465 0 .28 r
F
.48133 .92367 m .4884 .9343 L .4888 .93734 L .952 0 .101 r
F
.4884 .9343 m .51298 .9713 L .48969 .93896 L F
.48773 .92873 m .48934 .93145 L .48973 .93476 L .874 0 .025 r
F
.48397 .91742 m .49076 .93787 L .48133 .92367 L F
.4884 .9343 m .49038 .93294 L .48879 .93727 L .409 0 .198 r
F
.4888 .93734 m .49038 .93294 L .49158 .93664 L F
.48876 .93735 m .4888 .93726 L .4888 .93734 L F
.4888 .93726 m .49038 .93294 L .4888 .93734 L F
.48133 .92367 m .4888 .93734 L .47926 .93339 L .952 0 .101 r
F
.47251 .96495 m .49066 .94992 L .46879 .94559 L .83 .301 .711 r
F
.47251 .96495 m .49256 .96497 L .49066 .94992 L F
.49827 .99752 m .51306 .98925 L .49637 .98816 L .764 .594 .836 r
F
.49827 .99752 m .51308 .99717 L .51306 .98925 L F
.49637 .98816 m .51305 .98125 L .49447 .97752 L .687 .49 .833 r
F
.49637 .98816 m .51306 .98925 L .51305 .98125 L F
.49447 .97752 m .51304 .97336 L .49256 .96497 L .57 .335 .83 r
F
.49447 .97752 m .51305 .98125 L .51304 .97336 L F
.49271 .95757 m .51297 .98158 L .51296 .99397 L 1 0 .147 r
F
.49218 .95662 m .49268 .95722 L .49271 .95757 L F
.49268 .95722 m .51297 .98158 L .49271 .95757 L F
.49217 .95655 m .51297 .98158 L .49218 .95662 L F
.49088 .95001 m .51297 .98158 L .49208 .95644 L F
.49044 .94034 m .51297 .98158 L .49088 .95001 L .952 0 .101 r
F
.49135 .94201 m .51298 .9713 L .51297 .98158 L F
.49044 .94034 m .49128 .9415 L .49135 .94201 L F
.49128 .9415 m .51298 .9713 L .49135 .94201 L F
.49038 .93993 m .51298 .9713 L .49044 .94034 L F
.48826 .92411 m .51299 .96354 L .48872 .92626 L .874 0 .025 r
F
.48126 .93922 m .48855 .9374 L .47911 .95998 L .409 0 .198 r
F
.48855 .9374 m .48861 .93777 L .47911 .95998 L F
.4888 .93734 m .49088 .95001 L .47911 .95998 L F
.49122 .95491 m .49088 .95001 L .49208 .95644 L 1 0 .147 r
F
.49111 .95495 m .49117 .95411 L .49122 .95491 L .372 0 .198 r
F
.47911 .95998 m .49088 .95001 L .49111 .95495 L F
.49088 .95001 m .49088 .95001 L .49122 .95491 L 1 0 .147 r
F
.49088 .95001 m .49148 .9495 L .49111 .95495 L .372 0 .198 r
F
.47926 .93339 m .49088 .95001 L .49122 .95491 L 1 0 .147 r
F
.49117 .95411 m .49121 .95354 L .49122 .95491 L .372 0 .198 r
F
.49122 .95491 m .49148 .9495 L .49208 .95455 L F
.49121 .95354 m .49148 .9495 L .49122 .95491 L F
.45313 .97747 m .4725 .96495 L .46879 .94559 L 1 .345 .655 r
F
.45313 .97747 m .46879 .94559 L .44757 .96684 L F
.45422 .9359 m .48126 .93922 L .44998 .96416 L .465 0 .28 r
F
.44998 .96416 m .48126 .93922 L .47911 .95998 L .413 0 .258 r
F
.47926 .93339 m .49122 .95491 L .47712 .94455 L 1 0 .147 r
F
.48 .99045 m .49447 .97752 L .47625 .97913 L .894 .539 .777 r
F
.47625 .97913 m .49256 .96497 L .47251 .96495 L .877 .427 .745 r
F
.47625 .97913 m .49447 .97752 L .49256 .96497 L F
.50204 1.01402 m .5131 1.01267 L .51309 1.00496 L .847 .705 .838 r
F
.50204 1.01402 m .51309 1.00496 L .50016 1.00603 L F
.50016 1.00603 m .51308 .99717 L .49827 .99752 L .814 .662 .838 r
F
.50016 1.00603 m .51309 1.00496 L .51308 .99717 L F
.49341 .97337 m .51296 .99397 L .51294 1.00793 L 1 0 .176 r
F
.4934 .97319 m .51296 .99397 L .49341 .97337 L F
.49232 .96551 m .51296 .99397 L .49317 .97294 L F
.49218 .95662 m .51296 .99397 L .49232 .96551 L 1 0 .147 r
F
.48747 1.00857 m .50016 1.00603 L .49827 .99752 L .894 .68 .816 r
F
.47911 .95998 m .49111 .95496 L .47692 .98021 L .372 0 .198 r
F
.49111 .95496 m .49112 .95509 L .47692 .98021 L F
.49122 .95491 m .49232 .96551 L .47692 .98021 L F
.47692 .98021 m .49232 .96551 L .49241 .97178 L .348 0 .199 r
F
.49249 .97174 m .49232 .96551 L .49317 .97294 L 1 0 .176 r
F
.49232 .96551 m .49278 .96507 L .49247 .97084 L .348 0 .199 r
F
.49232 .96551 m .49247 .97084 L .49241 .97178 L F
.49241 .97178 m .4925 .97023 L .49249 .97174 L F
.47712 .94455 m .49232 .96551 L .49249 .97174 L 1 0 .176 r
F
.44215 .99951 m .45313 .97747 L .43487 .99413 L 1 .678 .741 r
F
.44215 .99951 m .45869 .98756 L .45313 .97747 L F
.45869 .98756 m .4725 .96495 L .45313 .97747 L 1 .473 .708 r
F
.45869 .98756 m .47625 .97913 L .4725 .96495 L F
.43487 .99413 m .45313 .97747 L .44757 .96684 L 1 .688 .717 r
F
.44998 .96416 m .47911 .95998 L .44571 .98849 L .413 0 .258 r
F
.46423 .99673 m .47625 .97913 L .45869 .98756 L 1 .578 .751 r
F
.46423 .99673 m .48 .99045 L .47625 .97913 L F
.44571 .9885 m .47911 .95998 L .47692 .98021 L .387 0 .244 r
F
.47712 .94455 m .49249 .97174 L .47496 .95659 L 1 0 .176 r
F
.48 .99045 m .49637 .98816 L .49447 .97752 L .894 .539 .777 r
F
.49309 .97281 m .51294 1.00793 L .4931 .98111 L 1 0 .176 r
F
.46975 1.00505 m .48374 1.00005 L .48 .99045 L .985 .652 .783 r
F
.48374 1.00005 m .49637 .98816 L .48 .99045 L .897 .624 .8 r
F
.4747 1.0001 m .4931 .98111 L .4931 .98841 L .333 0 .2 r
F
.46975 1.00505 m .48 .99045 L .46423 .99673 L .985 .652 .783 r
F
.50578 1.02917 m .51312 1.02798 L .51311 1.02034 L .885 .747 .837 r
F
.50578 1.02917 m .51311 1.02034 L .50391 1.02169 L F
.50391 1.02169 m .51311 1.02034 L .5131 1.01267 L .87 .731 .838 r
F
.50391 1.02169 m .5131 1.01267 L .50204 1.01402 L F
.48374 1.00005 m .49827 .99752 L .49637 .98816 L .897 .624 .8 r
F
.49371 .98947 m .51294 1.00793 L .51293 1.02319 L 1 .001 .196 r
F
.49371 .98941 m .51294 1.00793 L .49371 .98947 L F
.4931 .98111 m .51294 1.00793 L .49363 .98934 L F
.47091 1.02432 m .47526 1.01271 L .46376 1.01821 L .945 .743 .817 r
F
.47091 1.02432 m .48074 1.01987 L .47526 1.01271 L F
.48074 1.01987 m .48747 1.00857 L .47526 1.01271 L .927 .725 .818 r
F
.46376 1.01821 m .47526 1.01271 L .46975 1.00505 L .978 .733 .805 r
F
.47526 1.01271 m .48374 1.00005 L .46975 1.00505 L .951 .699 .804 r
F
.47526 1.01271 m .48747 1.00857 L .48374 1.00005 L F
.48747 1.00857 m .49827 .99752 L .48374 1.00005 L .894 .68 .816 r
F
.4747 1.0001 m .4931 .98841 L .47244 1.02001 L .333 0 .2 r
F
.4931 .98841 m .49352 .98914 L .49327 .99254 L 1 .001 .196 r
F
.49119 1.0164 m .50016 1.00603 L .48747 1.00857 L .893 .715 .826 r
F
.49119 1.0164 m .50204 1.01402 L .50016 1.00603 L F
.49352 .98914 m .51293 1.02319 L .49345 .99708 L 1 .001 .196 r
F
.4931 .98841 m .49345 .99708 L .47244 1.02001 L .333 0 .2 r
F
.49352 .98914 m .49345 .99708 L .49298 .99645 L 1 .001 .196 r
F
.49363 .98934 m .49371 .98941 L .49371 .98947 L F
.4931 .98841 m .4931 .98111 L .49363 .98934 L F
.47692 .98021 m .49249 .97174 L .4747 1.0001 L .348 0 .199 r
F
.49249 .97174 m .4931 .98111 L .4747 1.0001 L F
.4931 .98841 m .4931 .98841 L .4931 .98841 L .333 0 .2 r
F
.47496 .95659 m .49267 .98053 L .4931 .98841 L 1 .001 .196 r
F
.49267 .98053 m .4931 .98111 L .4931 .98841 L F
.4931 .98841 m .51293 .97582 L .49357 .99695 L .333 0 .2 r
F
.4931 .98841 m .49357 .99695 L .49345 .99708 L F
.4931 .98841 m .49327 .99254 L .49298 .99645 L 1 .001 .196 r
F
.50949 1.04391 m .51314 1.04328 L .51313 1.03563 L .901 .758 .834 r
F
.50949 1.04391 m .51313 1.03563 L .50764 1.03656 L F
.50764 1.03656 m .51313 1.03563 L .51312 1.02798 L .895 .755 .835 r
F
.50764 1.03656 m .51312 1.02798 L .50578 1.02917 L F
.49858 1.03092 m .50391 1.02169 L .49489 1.02379 L .896 .748 .833 r
F
.49858 1.03092 m .50578 1.02917 L .50391 1.02169 L F
.49489 1.02379 m .50204 1.01402 L .49119 1.0164 L .894 .736 .831 r
F
.49489 1.02379 m .50391 1.02169 L .50204 1.01402 L F
.49373 1.00602 m .51293 1.02319 L .51292 1.03958 L 1 .001 .211 r
F
.49373 1.00567 m .51293 1.02319 L .49373 1.00602 L F
.49345 .99708 m .51293 1.02319 L .49331 1.00529 L F
.49217 1.04173 m .49706 1.03964 L .49164 1.03323 L .904 .755 .833 r
F
.49706 1.03964 m .49858 1.03092 L .49164 1.03323 L .902 .755 .833 r
F
.49706 1.03964 m .50225 1.0379 L .49858 1.03092 L F
.50225 1.0379 m .50578 1.02917 L .49858 1.03092 L .899 .755 .834 r
F
.50225 1.0379 m .50764 1.03656 L .50578 1.02917 L F
.48074 1.01987 m .49119 1.0164 L .48747 1.00857 L .927 .725 .818 r
F
.47244 1.02001 m .49345 .99708 L .49331 1.00529 L .324 0 .203 r
F
.44451 1.01985 m .44939 1.00563 L .43577 1.01535 L 1 .791 .807 r
F
.43577 1.01535 m .44939 1.00563 L .44215 .99951 L 1 .828 .801 r
F
.44939 1.00563 m .45869 .98756 L .44215 .99951 L 1 .697 .766 r
F
.44939 1.00563 m .46423 .99673 L .45869 .98756 L F
.44571 .9885 m .47692 .98021 L .44133 1.01163 L .387 0 .244 r
F
.44451 1.01985 m .45659 1.01195 L .44939 1.00563 L 1 .791 .807 r
F
.45659 1.01195 m .46423 .99673 L .44939 1.00563 L 1 .717 .788 r
F
.45659 1.01195 m .46975 1.00505 L .46423 .99673 L F
.44133 1.01163 m .47692 .98021 L .4747 1.0001 L .373 0 .235 r
F
.47375 1.04291 m .47051 1.03442 L .46381 1.03905 L .911 .761 .832 r
F
.47375 1.04291 m .47911 1.0393 L .47051 1.03442 L F
.47911 1.0393 m .47803 1.03025 L .47051 1.03442 L .912 .757 .831 r
F
.47051 1.03442 m .47803 1.03025 L .47091 1.02432 L .926 .759 .827 r
F
.47803 1.03025 m .48074 1.01987 L .47091 1.02432 L .923 .749 .825 r
F
.47803 1.03025 m .4862 1.02667 L .48074 1.01987 L F
.4862 1.02667 m .49119 1.0164 L .48074 1.01987 L .912 .741 .826 r
F
.47244 1.02001 m .49331 1.00529 L .47016 1.0402 L .324 0 .203 r
F
.49331 1.00529 m .49362 1.00583 L .49332 1.00552 L 1 .001 .211 r
F
.49362 1.00583 m .51292 1.03958 L .49352 1.01357 L F
.47911 1.0393 m .48511 1.03604 L .47803 1.03025 L .912 .757 .831 r
F
.48511 1.03604 m .4862 1.02667 L .47803 1.03025 L .91 .753 .83 r
F
.49331 1.00529 m .49343 1.01013 L .47016 1.0402 L .324 0 .203 r
F
.49343 1.01013 m .49352 1.01357 L .49348 1.01361 L F
.49343 1.01013 m .49348 1.01361 L .47016 1.0402 L F
.4862 1.02667 m .49489 1.02379 L .49119 1.0164 L .912 .741 .826 r
F
.48511 1.03604 m .49164 1.03323 L .4862 1.02667 L .91 .753 .83 r
F
.49164 1.03323 m .49489 1.02379 L .4862 1.02667 L .905 .75 .831 r
F
.47016 1.0402 m .49348 1.01361 L .49327 1.02197 L .318 0 .206 r
F
.49325 1.02257 m .49327 1.02197 L .49326 1.02257 L F
.47016 1.0402 m .49327 1.02197 L .49325 1.02257 L F
.49164 1.03323 m .49858 1.03092 L .49489 1.02379 L .905 .75 .831 r
F
.4936 1.02318 m .49371 1.03111 L .49337 1.03065 L 1 .002 .222 r
F
.43574 1.03879 m .44382 1.03158 L .43376 1.02811 L .949 .807 .831 r
F
.44382 1.03158 m .44451 1.01985 L .43376 1.02811 L .967 .799 .824 r
F
.44382 1.03158 m .45322 1.02464 L .44451 1.01985 L F
.45322 1.02464 m .45659 1.01195 L .44451 1.01985 L .98 .772 .814 r
F
.45322 1.02464 m .46376 1.01821 L .45659 1.01195 L F
.43376 1.02811 m .44451 1.01985 L .43577 1.01535 L .993 .827 .823 r
F
.46376 1.01821 m .46975 1.00505 L .45659 1.01195 L .978 .733 .805 r
F
.44133 1.01163 m .4747 1.0001 L .43691 1.03425 L .373 0 .235 r
F
.45383 1.03525 m .45322 1.02464 L .44382 1.03158 L .943 .78 .827 r
F
.45383 1.03525 m .46188 1.02952 L .45322 1.02464 L F
.46188 1.02952 m .46376 1.01821 L .45322 1.02464 L .948 .763 .821 r
F
.46188 1.02952 m .47091 1.02432 L .46376 1.01821 L F
.43691 1.03425 m .4747 1.0001 L .47244 1.02001 L .364 0 .231 r
F
.47294 1.06238 m .47364 1.05916 L .46043 1.05939 L .893 .755 .836 r
F
.47364 1.05916 m .46239 1.05511 L .46043 1.05939 L .896 .758 .836 r
F
.47364 1.05916 m .47512 1.05593 L .46239 1.05511 L F
.47512 1.05593 m .46535 1.05085 L .46239 1.05511 L .899 .76 .836 r
F
.47512 1.05593 m .47735 1.05272 L .46535 1.05085 L F
.47735 1.05272 m .46914 1.04679 L .46535 1.05085 L .901 .76 .835 r
F
.47735 1.05272 m .48019 1.04969 L .46914 1.04679 L F
.48019 1.04969 m .47375 1.04291 L .46914 1.04679 L .902 .759 .834 r
F
.48019 1.04969 m .48366 1.04681 L .47375 1.04291 L F
.48366 1.04681 m .47911 1.0393 L .47375 1.04291 L .904 .758 .833 r
F
.48366 1.04681 m .48767 1.04414 L .47911 1.0393 L F
.48767 1.04414 m .48511 1.03604 L .47911 1.0393 L .904 .756 .833 r
F
.46914 1.04679 m .47375 1.04291 L .46381 1.03905 L .908 .765 .834 r
F
.47016 1.0402 m .49326 1.02257 L .46784 1.06083 L .318 0 .206 r
F
.4935 1.02307 m .49337 1.03065 L .49326 1.02282 L 1 .002 .222 r
F
.4936 1.02318 m .49337 1.03065 L .4935 1.02307 L F
.51316 1.0586 m .51133 1.05126 L .50954 1.05171 L .905 .756 .833 r
F
.51316 1.0586 m .51316 1.0586 L .51133 1.05126 L F
.51316 1.0586 m .51315 1.05094 L .51133 1.05126 L .905 .756 .832 r
F
.50954 1.05171 m .50949 1.04391 L .5059 1.04482 L .904 .758 .833 r
F
.50954 1.05171 m .51133 1.05126 L .50949 1.04391 L F
.51133 1.05126 m .51315 1.05094 L .51314 1.04328 L F
.51133 1.05126 m .51314 1.04328 L .50949 1.04391 L F
.50245 1.04597 m .50225 1.0379 L .49706 1.03964 L .902 .757 .834 r
F
.50245 1.04597 m .5059 1.04482 L .50225 1.0379 L F
.5059 1.04482 m .50764 1.03656 L .50225 1.0379 L .902 .758 .834 r
F
.5059 1.04482 m .50949 1.04391 L .50764 1.03656 L F
.49356 1.0231 m .51292 1.03958 L .51291 1.057 L 1 .002 .222 r
F
.49357 1.02283 m .51292 1.03958 L .49356 1.0231 L F
.49348 1.01361 m .49352 1.01357 L .49326 1.02257 L .318 0 .206 r
F
.49316 1.01309 m .51292 1.03958 L .49326 1.02257 L 1 .002 .222 r
F
.49353 1.05073 m .4962 1.04896 L .48767 1.04414 L .902 .757 .834 r
F
.4962 1.04896 m .49217 1.04173 L .48767 1.04414 L F
.4962 1.04896 m .49919 1.04736 L .49217 1.04173 L F
.49919 1.04736 m .49706 1.03964 L .49217 1.04173 L F
.47021 1.08203 m .46615 1.07889 L .45445 1.08362 L .868 .72 .835 r
F
.48091 1.0763 m .46615 1.07889 L .47021 1.08203 L .883 .735 .834 r
F
.46615 1.07889 m .45049 1.07927 L .45445 1.08362 L .865 .723 .837 r
F
.48091 1.0763 m .47787 1.07397 L .46615 1.07889 L .883 .735 .834 r
F
.46615 1.07889 m .46299 1.07541 L .45049 1.07927 L .865 .723 .837 r
F
.47787 1.07397 m .46299 1.07541 L .46615 1.07889 L .882 .736 .835 r
F
.47787 1.07397 m .47551 1.07136 L .46299 1.07541 L F
.47551 1.07136 m .4608 1.07167 L .46299 1.07541 L .883 .739 .835 r
F
.47551 1.07136 m .47388 1.06853 L .4608 1.07167 L F
.48804 1.06719 m .47388 1.06853 L .47551 1.07136 L .893 .746 .834 r
F
.48804 1.06719 m .48697 1.06529 L .47388 1.06853 L F
.47388 1.06853 m .45963 1.06772 L .4608 1.07167 L .886 .745 .836 r
F
.47388 1.06853 m .47302 1.06552 L .45963 1.06772 L F
.48697 1.06529 m .47302 1.06552 L .47388 1.06853 L .894 .748 .834 r
F
.48697 1.06529 m .4864 1.06326 L .47302 1.06552 L F
.4864 1.06326 m .47294 1.06238 L .47302 1.06552 L .896 .751 .834 r
F
.4864 1.06326 m .48635 1.06114 L .47294 1.06238 L F
.47302 1.06552 m .45951 1.06361 L .45963 1.06772 L .89 .75 .836 r
F
.47302 1.06552 m .47294 1.06238 L .45951 1.06361 L F
.48635 1.06114 m .47364 1.05916 L .47294 1.06238 L .898 .753 .834 r
F
.48635 1.06114 m .48683 1.05898 L .47364 1.05916 L F
.47294 1.06238 m .46043 1.05939 L .45951 1.06361 L .893 .755 .836 r
F
.48683 1.05898 m .47512 1.05593 L .47364 1.05916 L .899 .755 .834 r
F
.48683 1.05898 m .48782 1.0568 L .47512 1.05593 L F
.48782 1.0568 m .47735 1.05272 L .47512 1.05593 L .9 .756 .834 r
F
.48782 1.0568 m .48931 1.05466 L .47735 1.05272 L F
.48931 1.05466 m .48019 1.04969 L .47735 1.05272 L .9 .757 .834 r
F
.48931 1.05466 m .49122 1.05264 L .48019 1.04969 L F
.49122 1.05264 m .48366 1.04681 L .48019 1.04969 L .901 .757 .834 r
F
.49122 1.05264 m .49353 1.05073 L .48366 1.04681 L F
.49353 1.05073 m .48767 1.04414 L .48366 1.04681 L .902 .757 .834 r
F
.48767 1.04414 m .49217 1.04173 L .48511 1.03604 L .904 .756 .833 r
F
.49217 1.04173 m .49164 1.03323 L .48511 1.03604 L .904 .755 .833 r
F
.46784 1.06083 m .49296 1.04041 L .46549 1.082 L .315 0 .21 r
F
.49296 1.04041 m .49296 1.04045 L .46549 1.082 L F
.49301 1.04037 m .49307 1.04838 L .46549 1.082 L F
.5 1.0588 m .48782 1.0568 L .48683 1.05898 L .902 .755 .833 r
F
.5 1.0588 m .5005 1.05771 L .48782 1.0568 L F
.5005 1.05771 m .48931 1.05466 L .48782 1.0568 L .903 .755 .833 r
F
.5005 1.05771 m .50125 1.05663 L .48931 1.05466 L F
.50125 1.05663 m .49122 1.05264 L .48931 1.05466 L .903 .756 .833 r
F
.50125 1.05663 m .5022 1.05562 L .49122 1.05264 L F
.5022 1.05562 m .49353 1.05073 L .49122 1.05264 L F
.48961 1.06893 m .47551 1.07136 L .47787 1.07397 L .892 .745 .834 r
F
.48961 1.06893 m .48804 1.06719 L .47551 1.07136 L F
.50006 1.06197 m .4864 1.06326 L .48697 1.06529 L .9 .752 .833 r
F
.50006 1.06197 m .49978 1.06095 L .4864 1.06326 L F
.49978 1.06095 m .48635 1.06114 L .4864 1.06326 L .901 .753 .833 r
F
.49978 1.06095 m .49976 1.05989 L .48635 1.06114 L F
.49976 1.05989 m .48683 1.05898 L .48635 1.06114 L .902 .754 .833 r
F
.49976 1.05989 m .5 1.0588 L .48683 1.05898 L F
.46549 1.082 m .49293 1.04855 L .49263 1.05876 L .314 0 .214 r
F
.49293 1.04855 m .49307 1.04838 L .49263 1.05876 L F
.49326 1.02257 m .49337 1.03065 L .46784 1.06083 L .318 0 .206 r
F
.46784 1.06083 m .49328 1.03076 L .49316 1.03515 L .315 0 .21 r
F
.49296 1.04041 m .49316 1.03515 L .49301 1.04037 L F
.46784 1.06083 m .49316 1.03515 L .49296 1.04041 L F
.47051 1.03442 m .47091 1.02432 L .46188 1.02952 L .926 .759 .827 r
F
.43394 1.06013 m .43684 1.05387 L .42401 1.05355 L .892 .782 .844 r
F
.44963 1.05441 m .44124 1.04749 L .43684 1.05387 L .903 .777 .839 r
F
.44963 1.05441 m .45331 1.04909 L .44124 1.04749 L F
.43684 1.05387 m .42914 1.0461 L .42401 1.05355 L .907 .788 .84 r
F
.43684 1.05387 m .44124 1.04749 L .42914 1.0461 L F
.45331 1.04909 m .44691 1.0413 L .44124 1.04749 L .912 .778 .836 r
F
.45331 1.04909 m .45804 1.04398 L .44691 1.0413 L F
.45804 1.04398 m .45383 1.03525 L .44691 1.0413 L .919 .775 .833 r
F
.45804 1.04398 m .46381 1.03905 L .45383 1.03525 L F
.44124 1.04749 m .43574 1.03879 L .42914 1.04609 L .921 .791 .836 r
F
.44124 1.04749 m .44691 1.0413 L .43574 1.03879 L F
.46381 1.03905 m .46188 1.02952 L .45383 1.03525 L .924 .768 .83 r
F
.46381 1.03905 m .47051 1.03442 L .46188 1.02952 L F
.44691 1.0413 m .44382 1.03158 L .43574 1.03879 L .933 .789 .832 r
F
.44691 1.0413 m .45383 1.03525 L .44382 1.03158 L F
.43691 1.03425 m .47244 1.02001 L .43242 1.05691 L .364 0 .231 r
F
.4472 1.05969 m .43684 1.05387 L .43394 1.06013 L .892 .772 .841 r
F
.4472 1.05969 m .44963 1.05441 L .43684 1.05387 L F
.46535 1.05085 m .45804 1.04398 L .45331 1.04909 L .904 .767 .836 r
F
.46535 1.05085 m .46914 1.04679 L .45804 1.04398 L F
.46914 1.04679 m .46381 1.03905 L .45804 1.04398 L .908 .765 .834 r
F
.43242 1.05691 m .47244 1.02001 L .47016 1.0402 L .36 0 .231 r
F
.46601 1.01151 m .49228 1.05815 L .46369 1.02683 L 1 .003 .239 r
F
.49228 1.05815 m .49263 1.05876 L .49228 1.05837 L F
.49228 1.05815 m .49228 1.05837 L .46369 1.02683 L F
.51533 1.08897 m .50685 1.09775 L .51587 1.09657 L .927 .758 .826 r
F
.51533 1.08897 m .5081 1.08985 L .50685 1.09775 L F
.51479 1.08138 m .5081 1.08985 L .51533 1.08897 L .917 .754 .828 r
F
.51479 1.08138 m .50936 1.08201 L .5081 1.08985 L F
.50936 1.08201 m .50077 1.09011 L .5081 1.08985 L .917 .752 .828 r
F
.50936 1.08201 m .50385 1.08219 L .50077 1.09011 L F
.51425 1.07379 m .50936 1.08201 L .51479 1.08138 L .911 .753 .83 r
F
.51425 1.07379 m .51062 1.0742 L .50936 1.08201 L F
.51062 1.0742 m .50385 1.08219 L .50936 1.08201 L .91 .752 .83 r
F
.50694 1.07432 m .49851 1.0819 L .50385 1.08219 L .908 .751 .83 r
F
.51062 1.0742 m .50694 1.07432 L .50385 1.08219 L .91 .752 .83 r
F
.50337 1.07414 m .49346 1.08114 L .49851 1.0819 L .906 .75 .831 r
F
.50694 1.07432 m .50337 1.07414 L .49851 1.0819 L .908 .751 .83 r
F
.50337 1.07414 m .5 1.07364 L .49346 1.08114 L .906 .75 .831 r
F
.51371 1.0662 m .51062 1.0742 L .51425 1.07379 L .908 .754 .831 r
F
.51371 1.0662 m .51189 1.06641 L .51062 1.0742 L F
.51189 1.06641 m .50694 1.07432 L .51062 1.0742 L .907 .753 .831 r
F
.51004 1.06647 m .50337 1.07414 L .50694 1.07432 L .906 .753 .831 r
F
.51189 1.06641 m .51004 1.06647 L .50694 1.07432 L .907 .753 .831 r
F
.50826 1.06638 m .5 1.07364 L .50337 1.07414 L .905 .753 .832 r
F
.51004 1.06647 m .50826 1.06638 L .50337 1.07414 L .906 .753 .831 r
F
.50657 1.06614 m .49688 1.07286 L .5 1.07364 L .904 .752 .832 r
F
.50826 1.06638 m .50657 1.06614 L .5 1.07364 L .905 .753 .832 r
F
.505 1.06575 m .49407 1.07179 L .49688 1.07286 L .902 .751 .832 r
F
.50657 1.06614 m .505 1.06575 L .49688 1.07286 L .904 .752 .832 r
F
.5036 1.06522 m .49163 1.07047 L .49407 1.07179 L .901 .751 .833 r
F
.505 1.06575 m .5036 1.06522 L .49407 1.07179 L .902 .751 .832 r
F
.50238 1.06457 m .48961 1.06893 L .49163 1.07047 L .9 .75 .833 r
F
.5036 1.06522 m .50238 1.06457 L .49163 1.07047 L .901 .751 .833 r
F
.51316 1.05861 m .505 1.06575 L .50657 1.06614 L .906 .756 .832 r
F
.50238 1.06457 m .50137 1.0638 L .48961 1.06893 L .9 .75 .833 r
F
.50137 1.0638 m .48804 1.06719 L .48961 1.06893 L .899 .75 .833 r
F
.51316 1.05861 m .5036 1.06522 L .505 1.06575 L .905 .755 .832 r
F
.51316 1.05861 m .51316 1.05861 L .505 1.06575 L .906 .756 .832 r
F
.51316 1.05861 m .50238 1.06457 L .5036 1.06522 L .905 .755 .832 r
F
.51316 1.05861 m .51316 1.05861 L .5036 1.06522 L F
.51316 1.05861 m .50137 1.0638 L .50238 1.06457 L .904 .755 .832 r
F
.51316 1.05861 m .51316 1.05861 L .50238 1.06457 L .905 .755 .832 r
F
.50059 1.06293 m .48697 1.06529 L .48804 1.06719 L .9 .751 .833 r
F
.50137 1.0638 m .50059 1.06293 L .48804 1.06719 L .899 .75 .833 r
F
.51316 1.05861 m .51316 1.05861 L .50137 1.0638 L .904 .755 .832 r
F
.51316 1.05861 m .50059 1.06293 L .50137 1.0638 L .904 .754 .832 r
F
.50059 1.06293 m .50006 1.06197 L .48697 1.06529 L .9 .751 .833 r
F
.51316 1.05861 m .50006 1.06197 L .50059 1.06293 L .904 .754 .832 r
F
.51316 1.05861 m .51316 1.05861 L .50059 1.06293 L F
.51315 1.05861 m .49978 1.06095 L .50006 1.06197 L .905 .755 .832 r
F
.51316 1.05861 m .51315 1.05861 L .50006 1.06197 L .904 .754 .832 r
F
.51315 1.05861 m .51315 1.05861 L .49978 1.06095 L .905 .755 .832 r
F
.51315 1.05861 m .49976 1.05989 L .49978 1.06095 L F
.51315 1.05861 m .51315 1.05861 L .49976 1.05989 L F
.51315 1.05861 m .5 1.0588 L .49976 1.05989 L .906 .755 .832 r
F
.51315 1.05861 m .51315 1.05861 L .5 1.0588 L F
.51315 1.05861 m .5005 1.05771 L .5 1.0588 L .906 .756 .832 r
F
.5022 1.05562 m .50336 1.05466 L .49353 1.05073 L .903 .756 .833 r
F
.50336 1.05466 m .4962 1.04896 L .49353 1.05073 L .903 .757 .833 r
F
.49263 1.05876 m .51289 1.07539 L .51288 1.09471 L 1 .003 .239 r
F
.46601 1.01151 m .49274 1.04794 L .49263 1.05876 L F
.49274 1.04794 m .51289 1.07539 L .49263 1.05876 L F
.46464 1.10124 m .44684 1.10379 L .45665 1.10853 L .883 .696 .824 r
F
.47398 1.10402 m .46464 1.10124 L .45665 1.10853 L .921 .719 .818 r
F
.48045 1.09628 m .46464 1.10124 L .47398 1.10402 L .91 .729 .824 r
F
.46464 1.10124 m .45623 1.09749 L .44684 1.10379 L .883 .696 .824 r
F
.47266 1.09409 m .45623 1.09749 L .46464 1.10124 L .887 .715 .828 r
F
.48045 1.09628 m .47266 1.09409 L .46464 1.10124 L .91 .729 .824 r
F
.46565 1.09116 m .44889 1.09302 L .45623 1.09749 L .863 .703 .832 r
F
.47266 1.09409 m .46565 1.09116 L .45623 1.09749 L .887 .715 .828 r
F
.48071 1.087 m .46565 1.09116 L .47266 1.09409 L .891 .73 .83 r
F
.46565 1.09116 m .45954 1.08762 L .44889 1.09302 L .863 .703 .832 r
F
.47509 1.08476 m .45954 1.08762 L .46565 1.09116 L .877 .723 .833 r
F
.48071 1.087 m .47509 1.08476 L .46565 1.09116 L .891 .73 .83 r
F
.48878 1.07993 m .47509 1.08476 L .48071 1.087 L .895 .74 .832 r
F
.47021 1.08203 m .45445 1.08362 L .45954 1.08762 L .868 .72 .835 r
F
.47509 1.08476 m .47021 1.08203 L .45954 1.08762 L .877 .723 .833 r
F
.48457 1.07831 m .47021 1.08203 L .47509 1.08476 L .888 .736 .833 r
F
.48878 1.07993 m .48457 1.07831 L .47509 1.08476 L .895 .74 .832 r
F
.48457 1.07831 m .48091 1.0763 L .47021 1.08203 L .888 .736 .833 r
F
.49407 1.07179 m .48091 1.0763 L .48457 1.07831 L .895 .745 .833 r
F
.49163 1.07047 m .47787 1.07397 L .48091 1.0763 L .893 .744 .833 r
F
.49407 1.07179 m .49163 1.07047 L .48091 1.0763 L .895 .745 .833 r
F
.49163 1.07047 m .48961 1.06893 L .47787 1.07397 L .893 .744 .833 r
F
.46549 1.082 m .49263 1.05876 L .4631 1.10381 L .314 0 .214 r
F
.49263 1.05876 m .4929 1.05924 L .49263 1.05894 L 1 .003 .239 r
F
.49263 1.05876 m .49255 1.06691 L .4631 1.10381 L .314 0 .214 r
F
.49263 1.05876 m .49263 1.05894 L .49263 1.05894 L 1 .003 .239 r
F
.50385 1.08219 m .49367 1.08972 L .50077 1.09011 L .914 .75 .828 r
F
.50385 1.08219 m .49851 1.0819 L .49367 1.08972 L F
.5 1.07364 m .48878 1.07993 L .49346 1.08114 L .902 .748 .831 r
F
.5 1.07364 m .49688 1.07286 L .48878 1.07993 L F
.4929 1.05924 m .51288 1.09471 L .49287 1.0671 L 1 .003 .239 r
F
.49263 1.05876 m .49265 1.06678 L .49255 1.06691 L .314 0 .214 r
F
.4929 1.05924 m .49287 1.0671 L .46369 1.02683 L 1 .003 .239 r
F
.51316 1.05861 m .50657 1.06614 L .50826 1.06638 L .906 .756 .832 r
F
.51316 1.05861 m .51316 1.05861 L .50657 1.06614 L F
.51315 1.05861 m .51316 1.05861 L .5005 1.05771 L F
.51316 1.05861 m .50125 1.05663 L .5005 1.05771 L .907 .756 .832 r
F
.51316 1.05861 m .51316 1.05861 L .50125 1.05663 L F
.51316 1.05861 m .5022 1.05562 L .50125 1.05663 L .907 .757 .832 r
F
.50336 1.05466 m .5047 1.05378 L .4962 1.04896 L .903 .757 .833 r
F
.5047 1.05378 m .49919 1.04736 L .4962 1.04896 L F
.49321 1.04073 m .51289 1.07539 L .49307 1.04838 L 1 .003 .231 r
F
.51316 1.0586 m .50954 1.05171 L .50781 1.05228 L .905 .757 .833 r
F
.51316 1.0586 m .51316 1.0586 L .50954 1.05171 L F
.50781 1.05228 m .5059 1.04482 L .50245 1.04597 L .904 .758 .833 r
F
.50781 1.05228 m .50954 1.05171 L .5059 1.04482 L F
.4936 1.02318 m .51291 1.057 L .49371 1.03111 L 1 .002 .222 r
F
.5047 1.05378 m .50619 1.05298 L .49919 1.04736 L .903 .757 .833 r
F
.50619 1.05298 m .50245 1.04597 L .49919 1.04736 L F
.50619 1.05298 m .50781 1.05228 L .50245 1.04597 L F
.49328 1.03076 m .49337 1.03065 L .49301 1.04037 L .315 0 .21 r
F
.51316 1.0586 m .50781 1.05228 L .50619 1.05298 L .906 .757 .832 r
F
.51316 1.0586 m .51316 1.0586 L .50781 1.05228 L F
.49919 1.04736 m .50245 1.04597 L .49706 1.03964 L .902 .757 .834 r
F
.49302 1.04004 m .51291 1.057 L .49301 1.04037 L 1 .003 .231 r
F
.49261 1.02963 m .51291 1.057 L .49264 1.03972 L F
.49337 1.03065 m .49369 1.03028 L .49301 1.04037 L .315 0 .21 r
F
.51316 1.05861 m .51189 1.06641 L .51371 1.0662 L .908 .756 .832 r
F
.51316 1.05861 m .51316 1.05861 L .51189 1.06641 L F
.51316 1.05861 m .51004 1.06647 L .51189 1.06641 L .907 .756 .832 r
F
.51316 1.05861 m .50826 1.06638 L .51004 1.06647 L F
.51316 1.05861 m .51316 1.05861 L .51004 1.06647 L F
.51316 1.05861 m .51316 1.05861 L .50826 1.06638 L F
.51316 1.05861 m .51316 1.0586 L .5022 1.05562 L .907 .757 .832 r
F
.51316 1.0586 m .50336 1.05466 L .5022 1.05562 L F
.51316 1.0586 m .51316 1.0586 L .50336 1.05466 L F
.51316 1.0586 m .5047 1.05378 L .50336 1.05466 L .906 .757 .832 r
F
.51316 1.0586 m .51316 1.0586 L .5047 1.05378 L F
.51316 1.0586 m .50619 1.05298 L .5047 1.05378 L F
.51316 1.0586 m .51316 1.0586 L .50619 1.05298 L F
.49301 1.04037 m .51291 1.057 L .51289 1.07539 L 1 .003 .231 r
F
.49264 1.03972 m .49302 1.04004 L .49301 1.04037 L F
.46829 .99682 m .49261 1.02963 L .49264 1.03972 L F
.49263 1.05876 m .4927 1.0587 L .49265 1.06678 L .314 0 .214 r
F
.4927 1.0587 m .51288 1.04143 L .49273 1.06668 L F
.4927 1.0587 m .49273 1.06668 L .49265 1.06678 L F
.49263 1.05876 m .49307 1.04838 L .49287 1.05856 L F
.49263 1.05876 m .49263 1.05894 L .46369 1.02683 L 1 .003 .239 r
F
.49296 1.04041 m .49301 1.04037 L .49296 1.04045 L .315 0 .21 r
F
.49301 1.04037 m .49321 1.04073 L .49304 1.04387 L 1 .003 .231 r
F
.49301 1.04037 m .51289 1.02421 L .49307 1.04838 L .315 0 .21 r
F
.49301 1.04037 m .49304 1.04387 L .4928 1.04801 L 1 .003 .231 r
F
.49321 1.04073 m .49307 1.04838 L .4928 1.04801 L F
.49287 1.05856 m .49325 1.04816 L .49312 1.05835 L .314 0 .214 r
F
.49307 1.04838 m .49325 1.04816 L .49287 1.05856 L F
.49312 1.05835 m .51289 1.02421 L .51288 1.04143 L F
.49325 1.04816 m .51289 1.02421 L .49312 1.05835 L F
.49326 1.02257 m .49357 1.02283 L .49356 1.0231 L 1 .002 .222 r
F
.47054 .98277 m .49316 1.01309 L .49326 1.02257 L F
.49326 1.02257 m .4936 1.02318 L .49325 1.02281 L F
.49326 1.02257 m .51291 1.00756 L .49337 1.03065 L .318 0 .206 r
F
.49326 1.02282 m .49337 1.03065 L .46829 .99682 L 1 .002 .222 r
F
.49321 1.04021 m .49369 1.03028 L .49367 1.03983 L .315 0 .21 r
F
.49301 1.04037 m .49327 1.03645 L .49321 1.04021 L F
.49327 1.03645 m .49369 1.03028 L .49321 1.04021 L F
.49263 1.0397 m .49301 1.04037 L .49235 1.04741 L 1 .003 .231 r
F
.49301 1.04037 m .4928 1.04801 L .49235 1.04741 L F
.46829 .99682 m .49263 1.0397 L .46601 1.01151 L F
.49263 1.0397 m .49235 1.04741 L .46601 1.01151 L F
.49326 1.02257 m .49352 1.01357 L .4934 1.02246 L .318 0 .206 r
F
.47054 .98277 m .49326 1.02257 L .46829 .99682 L 1 .002 .222 r
F
.49326 1.02257 m .49325 1.02281 L .46829 .99682 L F
.49362 1.00583 m .49352 1.01357 L .47054 .98277 L 1 .001 .211 r
F
.49331 1.00529 m .49373 1.00567 L .49373 1.00602 L F
.49331 1.00529 m .51292 .99145 L .49352 1.01357 L .324 0 .203 r
F
.47276 .96935 m .49331 1.00529 L .47054 .98277 L 1 .001 .211 r
F
.49331 1.00529 m .49332 1.00552 L .47054 .98277 L F
.4934 1.02246 m .49404 1.01298 L .49416 1.02188 L .318 0 .206 r
F
.49352 1.01357 m .49404 1.01298 L .4934 1.02246 L F
.49367 1.03983 m .51291 1.00756 L .51289 1.02421 L .315 0 .21 r
F
.49369 1.03028 m .51291 1.00756 L .49367 1.03983 L F
.47276 .96935 m .49345 .99708 L .49331 1.00529 L 1 .001 .211 r
F
.49331 1.00529 m .49345 .99708 L .49339 1.00523 L .324 0 .203 r
F
.49339 1.00523 m .49427 .99619 L .49458 1.00439 L F
.49345 .99708 m .49427 .99619 L .49339 1.00523 L F
.49416 1.02188 m .51292 .99145 L .51291 1.00756 L .318 0 .206 r
F
.49404 1.01298 m .51292 .99145 L .49416 1.02188 L F
.49249 .97174 m .49309 .97281 L .49279 .97633 L 1 0 .176 r
F
.49309 .97281 m .4931 .98111 L .49245 .98023 L F
.49317 .97294 m .4934 .97319 L .49341 .97337 L F
.49249 .97174 m .51295 .96062 L .4931 .98111 L .348 0 .199 r
F
.49249 .97174 m .49279 .97633 L .49245 .98023 L 1 0 .176 r
F
.47496 .95659 m .4931 .98841 L .47276 .96935 L 1 .001 .196 r
F
.4931 .98841 m .49298 .99645 L .47276 .96935 L F
.4931 .98841 m .49435 .97982 L .4949 .98727 L .333 0 .2 r
F
.4931 .98841 m .49435 .97982 L .4931 .98841 L F
.4931 .98111 m .49435 .97982 L .4931 .98841 L F
.49249 .97174 m .49245 .98023 L .47496 .95659 L 1 0 .176 r
F
.49249 .97174 m .49278 .96507 L .49322 .97135 L .348 0 .199 r
F
.4925 .97023 m .49278 .96507 L .49249 .97174 L F
.49458 1.00439 m .51293 .97582 L .51292 .99145 L .324 0 .203 r
F
.49427 .99619 m .51293 .97582 L .49458 1.00439 L F
.49111 .95496 m .49122 .95491 L .49112 .95509 L .372 0 .198 r
F
.49122 .95491 m .49218 .95662 L .49133 .95594 L 1 0 .147 r
F
.49218 .95662 m .49232 .96551 L .47712 .94455 L F
.49208 .95644 m .49217 .95655 L .49218 .95662 L F
.49122 .95491 m .51296 .9458 L .49232 .96551 L .372 0 .198 r
F
.49122 .95491 m .49133 .95594 L .49124 .95586 L 1 0 .147 r
F
.49122 .95491 m .49124 .95586 L .47712 .94455 L F
.49502 .97037 m .51296 .9458 L .51295 .96062 L .348 0 .199 r
F
.49322 .97135 m .49487 .96921 L .49502 .97037 L F
.49487 .96921 m .51296 .9458 L .49502 .97037 L F
.4949 .98727 m .51295 .96062 L .51293 .97582 L .333 0 .2 r
F
.49435 .97982 m .51295 .96062 L .4949 .98727 L F
.49278 .96507 m .51296 .9458 L .49322 .97135 L .348 0 .199 r
F
.48855 .9374 m .4888 .93734 L .48861 .93777 L .409 0 .198 r
F
.4888 .93734 m .49044 .94034 L .48916 .93954 L .952 0 .101 r
F
.49044 .94034 m .49088 .95001 L .47926 .93339 L F
.48969 .93896 m .49038 .93993 L .49044 .94034 L F
.50243 .93361 m .50773 .93272 L .5059 .9236 L .894 .613 .798 r
F
.50773 .93272 m .51312 .92309 L .5059 .9236 L .895 .615 .798 r
F
.4888 .93734 m .51297 .9313 L .49088 .95001 L .409 0 .198 r
F
.4888 .93734 m .48916 .93954 L .48889 .93937 L .952 0 .101 r
F
.4888 .93734 m .48889 .93937 L .47926 .93339 L F
.49148 .9495 m .49162 .94939 L .49208 .95455 L .372 0 .198 r
F
.49162 .94939 m .51297 .9313 L .49226 .95435 L F
.49162 .94939 m .49226 .95435 L .49208 .95455 L F
.48365 .91714 m .48381 .91714 L .48376 .91756 L .468 0 .194 r
F
.48381 .91714 m .48397 .91742 L .48392 .91754 L .874 0 .025 r
F
.4839 .9173 m .48826 .92411 L .48872 .92626 L F
.48397 .91742 m .48706 .92316 L .48773 .92873 L F
.50243 .93361 m .5059 .9236 L .49882 .92474 L .894 .613 .798 r
F
.48381 .91714 m .51298 .91737 L .4884 .9343 L .468 0 .194 r
F
.48381 .91714 m .48392 .91754 L .48387 .91765 L .874 0 .025 r
F
.48338 .91633 m .48381 .91714 L .48133 .92367 L F
.48381 .91714 m .48387 .91765 L .48133 .92367 L F
.48338 .91633 m .48377 .91696 L .4839 .9173 L F
.48381 .91714 m .4838 .91705 L .48383 .91714 L .468 0 .194 r
F
.48377 .91696 m .51299 .904 L .48383 .91714 L F
.48407 .90941 m .48462 .91658 L .48377 .91696 L .567 0 .176 r
F
.48407 .90941 m .48377 .91696 L .48346 .91614 L F
.49463 .95348 m .51297 .9313 L .51296 .9458 L .372 0 .198 r
F
.49208 .95455 m .49432 .95206 L .49463 .95348 L F
.49432 .95206 m .51297 .9313 L .49463 .95348 L F
.49158 .93664 m .51298 .91737 L .51297 .9313 L .409 0 .198 r
F
.49038 .93294 m .51298 .91737 L .49158 .93664 L F
.48334 .91565 m .48345 .91625 L .48335 .91602 L .633 0 .306 r
F
.48322 .90968 m .48345 .91625 L .48334 .91565 L F
.48547 .89408 m .48465 .91585 L .48407 .90941 L .567 0 .176 r
F
.48465 .91585 m .48462 .91658 L .48452 .91531 L F
.48465 .91585 m .48452 .91531 L .48407 .90941 L F
.47917 .89236 m .47947 .89338 L .47949 .89348 L .807 0 0 r
F
.47894 .89156 m .47915 .89229 L .47917 .89236 L F
.47937 .89441 m .48141 .90231 L .48014 .89853 L .887 0 .04 r
F
.47937 .89441 m .48014 .89853 L .47938 .89445 L F
.47637 .89457 m .47937 .89441 L .48281 .91396 L .633 0 .306 r
F
.47875 .89158 m .47881 .89192 L .47631 .89271 L .668 0 .306 r
F
.47925 .89395 m .47937 .8944 L .45851 .89552 L F
.45729 .78321 m .46085 .81315 L .4605 .82692 L .39 0 .427 r
F
.45907 .82148 m .4605 .82692 L .46009 .84344 L F
.45729 .78321 m .4605 .82692 L .45907 .82148 L F
.47892 .89151 m .4799 .89157 L .47881 .89192 L .668 0 .306 r
F
.45729 .78321 m .46272 .73852 L .46085 .81315 L .39 0 .427 r
F
.46277 .73366 m .47873 .89149 L .46042 .82921 L 1 .057 .275 r
F
.46412 .84061 m .47893 .89151 L .47931 .89316 L .807 0 0 r
F
.45949 .82459 m .46391 .83981 L .46412 .84061 L F
.46391 .83981 m .47893 .89151 L .46412 .84061 L F
.46042 .82921 m .47873 .89149 L .45892 .8901 L 1 .057 .275 r
F
.47112 .87164 m .47996 .89798 L .48338 .91633 L .887 0 .04 r
F
.47996 .89798 m .48141 .90231 L .48324 .91536 L F
.47996 .89798 m .48324 .91536 L .48338 .91633 L F
.47892 .89151 m .47881 .89192 L .47875 .89158 L .668 0 .306 r
F
.47937 .89441 m .47964 .89439 L .48334 .91565 L .633 0 .306 r
F
.47964 .89439 m .4829 .89422 L .48322 .90968 L F
.47964 .89439 m .48322 .90968 L .48334 .91565 L F
.49157 .90697 m .50038 .89689 L .48792 .898 L .836 .594 .811 r
F
.49157 .90697 m .50223 .90562 L .50038 .89689 L F
.50223 .90562 m .51309 .89661 L .50038 .89689 L .832 .614 .818 r
F
.48792 .898 m .49852 .88846 L .48425 .88885 L .784 .564 .82 r
F
.48792 .898 m .50038 .89689 L .49852 .88846 L F
.48547 .89408 m .51299 .904 L .4848 .9165 L .567 0 .176 r
F
.48465 .91585 m .4848 .9165 L .48462 .91658 L F
.48547 .89408 m .4848 .9165 L .48465 .91585 L F
.4829 .89422 m .48407 .90941 L .48382 .91225 L .633 0 .306 r
F
.4829 .89422 m .48382 .91225 L .48322 .90968 L F
.47931 .89316 m .47894 .89156 L .47917 .89236 L .807 0 0 r
F
.47931 .89316 m .47917 .89236 L .47953 .89392 L F
.47938 .89445 m .48014 .89853 L .47996 .89798 L .887 0 .04 r
F
.47919 .8939 m .47996 .89798 L .47112 .87164 L F
.47937 .89441 m .47996 .89798 L .47919 .8939 L F
.46485 .84672 m .47914 .89364 L .47112 .87164 L F
.47914 .89364 m .47937 .89441 L .47919 .8939 L F
.47914 .89364 m .47919 .8939 L .47112 .87164 L F
.47904 .89312 m .47901 .89186 L .47931 .89316 L .668 0 .306 r
F
.47881 .89192 m .47901 .89186 L .47904 .89312 L F
.47893 .89151 m .47894 .89156 L .47931 .89316 L .807 0 0 r
F
.47901 .89186 m .4799 .89157 L .47931 .89316 L .668 0 .306 r
F
.46277 .73366 m .46626 .7578 L .47864 .8905 L 1 .057 .275 r
F
.46277 .73366 m .47864 .8905 L .47863 .89045 L F
.46626 .7578 m .48254 .88983 L .47738 .87524 L .825 0 .02 r
F
.48254 .88983 m .47893 .8915 L .45949 .82458 L F
.48158 .87723 m .48169 .87812 L .48184 .88053 L F
.48169 .87812 m .48193 .88126 L .48184 .88053 L F
.48158 .87723 m .48184 .88053 L .48179 .8802 L F
.48011 .86565 m .48153 .87686 L .48034 .8692 L F
.48153 .87686 m .48179 .8802 L .48034 .8692 L F
.48011 .86565 m .48034 .8692 L .47485 .82748 L F
.47485 .82748 m .4794 .862 L .47922 .86292 L F
.47968 .85929 m .48702 .87845 L .46293 .73045 L 1 .007 .222 r
F
.46626 .7578 m .4757 .83106 L .47485 .82748 L .825 0 .02 r
F
.46498 .74686 m .4757 .83106 L .46626 .7578 L F
.48425 .88885 m .49852 .88846 L .49665 .88046 L .702 .504 .832 r
F
.46626 .7578 m .48702 .87846 L .48566 .89197 L 1 .057 .275 r
F
.46277 .73366 m .46498 .74686 L .46626 .7578 L F
.46498 .74686 m .48702 .87846 L .46626 .7578 L F
.4633 .73369 m .46498 .74686 L .46626 .7578 L .825 0 .02 r
F
.4628 .72975 m .4633 .73369 L .46626 .7578 L F
.46626 .7578 m .48566 .89197 L .48269 .89176 L 1 .057 .275 r
F
.46626 .7578 m .48269 .89176 L .47892 .8915 L F
.4628 .72975 m .46626 .7578 L .45949 .82458 L .825 0 .02 r
F
.46626 .7578 m .47738 .87524 L .45949 .82458 L F
.47931 .89316 m .48269 .89177 L .48284 .89368 L .668 0 .306 r
F
.4799 .89157 m .48269 .89177 L .47931 .89316 L F
.47904 .89312 m .48284 .89368 L .47925 .89395 L F
.47931 .89316 m .47937 .8944 L .47914 .89363 L .807 0 0 r
F
.47931 .89316 m .47914 .89363 L .46484 .8467 L F
.46412 .84061 m .47931 .89316 L .46484 .8467 L F
.48284 .89368 m .4829 .89421 L .47937 .8944 L .668 0 .306 r
F
.48284 .89368 m .47937 .8944 L .47925 .89395 L F
.48284 .89368 m .48547 .89407 L .4829 .89421 L F
.4829 .89422 m .48547 .89408 L .48407 .90941 L .633 0 .306 r
F
.48284 .89368 m .48566 .89197 L .48547 .89407 L .668 0 .306 r
F
.48269 .89177 m .48566 .89197 L .48284 .89368 L F
.46293 .73045 m .48702 .87845 L .46282 .72709 L 1 .007 .222 r
F
.4591 .82784 m .46485 .84672 L .47112 .87164 L .887 0 .04 r
F
.4591 .82784 m .47112 .87164 L .45501 .85085 L F
.47112 .87164 m .48338 .91633 L .47701 .90164 L F
.47112 .87164 m .47701 .90164 L .45501 .85085 L F
.45593 .79439 m .45729 .78321 L .45839 .80692 L .39 0 .427 r
F
.45949 .82459 m .46412 .84061 L .4591 .82783 L .807 0 0 r
F
.46412 .84061 m .46484 .8467 L .4591 .82783 L F
.45501 .85085 m .47701 .90164 L .48133 .92367 L 1 0 .128 r
F
.47701 .90164 m .48338 .91633 L .48255 .91931 L F
.47701 .90164 m .48255 .91931 L .48133 .92367 L F
.45243 .82313 m .45245 .82295 L .45249 .82331 L .39 0 .427 r
F
.43724 .89347 m .44353 .875 L .42868 .88495 L .921 .472 .748 r
F
.42868 .88495 m .43647 .8633 L .4201 .87644 L .956 .439 .727 r
F
.42868 .88495 m .44353 .875 L .43647 .8633 L F
.4201 .87644 m .42941 .85055 L .41148 .86838 L 1 .422 .705 r
F
.4201 .87644 m .43647 .8633 L .42941 .85055 L F
.43647 .8633 m .4489 .83774 L .42941 .85055 L .874 .251 .674 r
F
.41148 .86838 m .42941 .85055 L .42234 .83734 L 1 .439 .688 r
F
.42533 .84673 m .44688 .87734 L .44271 .88802 L 1 .003 .227 r
F
.41148 .86838 m .42234 .83734 L .40282 .86138 L 1 .439 .688 r
F
.40282 .86138 m .42234 .83734 L .41524 .82491 L 1 .508 .677 r
F
.41641 .82553 m .42767 .84469 L .42533 .84673 L 1 .003 .227 r
F
.42767 .84469 m .44688 .87734 L .42533 .84673 L F
.43187 .84011 m .45095 .86553 L .44688 .87734 L 1 .004 .246 r
F
.4223 .81638 m .43454 .83738 L .43187 .84011 L F
.43454 .83738 m .45095 .86553 L .43187 .84011 L F
.4223 .81638 m .43187 .84011 L .41641 .82553 L F
.43187 .84011 m .44688 .87734 L .42767 .84469 L F
.43187 .84011 m .42767 .84469 L .41641 .82553 L F
.43845 .83189 m .45501 .85084 L .45095 .86553 L 1 .008 .279 r
F
.42818 .80424 m .44166 .82765 L .43845 .83189 L F
.44166 .82765 m .45501 .85084 L .43845 .83189 L F
.42818 .80424 m .43845 .83189 L .4223 .81638 L F
.43845 .83189 m .45095 .86553 L .43454 .83738 L F
.43845 .83189 m .43454 .83738 L .4223 .81638 L F
.44517 .82135 m .45501 .85084 L .44166 .82765 L 1 .008 .336 r
F
.44517 .82135 m .44166 .82765 L .42818 .80424 L F
.43651 .78022 m .45112 .80842 L .4346 .78631 L .554 0 .441 r
F
.45112 .80842 m .45948 .82457 L .4502 .81029 L F
.45112 .80842 m .4502 .81029 L .4346 .78631 L F
.4405 .779 m .46288 .71917 L .45948 .82457 L F
.44037 .77869 m .44486 .76683 L .4405 .779 L F
.44486 .76683 m .46288 .71917 L .4405 .779 L F
.43845 .77407 m .45091 .74606 L .44037 .77869 L F
.45091 .74606 m .46288 .71917 L .44037 .77869 L F
.44419 .7591 m .46167 .71286 L .44231 .76388 L 1 .778 .637 r
F
.46167 .71286 m .45765 .72344 L .44231 .76388 L F
.44037 .77869 m .46064 .71356 L .45342 .71907 L 1 .4 .548 r
F
.46167 .71286 m .46172 .71273 L .45765 .72344 L 1 .778 .637 r
F
.46172 .71273 m .46296 .70944 L .4578 .72304 L F
.46172 .71273 m .4578 .72304 L .45765 .72344 L F
.45091 .74606 m .45779 .72308 L .44037 .77869 L 1 .4 .548 r
F
.45779 .72308 m .46064 .71356 L .45717 .72472 L F
.45779 .72308 m .45717 .72472 L .44037 .77869 L F
.46064 .71356 m .46299 .70569 L .45342 .71907 L F
.44037 .77869 m .44106 .77558 L .43651 .78022 L F
.44148 .78135 m .45948 .82457 L .43651 .78022 L .554 0 .441 r
F
.43219 .77924 m .43651 .78022 L .43478 .77227 L 1 .298 .602 r
F
.43086 .78283 m .43651 .78022 L .43219 .77924 L F
.43092 .78289 m .43078 .78289 L .43062 .78281 L .561 0 .266 r
F
.43075 .78282 m .43062 .78281 L .43037 .78267 L F
.43092 .78289 m .43062 .78281 L .43075 .78282 L F
.42762 .7836 m .4346 .78631 L .43405 .78802 L .678 0 .284 r
F
.42591 .78624 m .42714 .78389 L .41724 .79204 L 1 .48 .612 r
F
.41128 .77238 m .42899 .78296 L .42762 .7836 L .678 0 .284 r
F
.4285 .7816 m .42841 .78161 L .41128 .77238 L .561 0 .266 r
F
.42944 .78151 m .42863 .78166 L .41128 .77238 L F
.43111 .78307 m .42907 .783 L .42899 .78295 L F
.41397 .78467 m .41413 .78433 L .40986 .78537 L 1 .646 .616 r
F
.42841 .78161 m .42715 .78185 L .41128 .77238 L .561 0 .266 r
F
.4276 .7836 m .42719 .78357 L .41059 .77283 L .678 0 .284 r
F
.41316 .76459 m .4306 .76184 L .42339 .76469 L .026 0 0 r
F
.41316 .76459 m .42339 .76469 L .40455 .76308 L F
.40455 .76308 m .42339 .76469 L .41612 .76914 L .329 0 0 r
F
.41413 .78433 m .42888 .75284 L .41001 .78511 L 1 .646 .616 r
F
.41413 .78433 m .41001 .78511 L .40986 .78537 L F
.43078 .78289 m .42899 .78295 L .42715 .78185 L .561 0 .266 r
F
.43078 .78289 m .42715 .78185 L .42841 .78161 L F
.43111 .78307 m .42899 .78295 L .43078 .78289 L F
.42585 .78271 m .42727 .78363 L .41867 .78725 L .696 0 .267 r
F
.42714 .78389 m .4276 .783 L .42132 .78683 L 1 .48 .612 r
F
.4276 .783 m .43428 .77025 L .42421 .78312 L F
.4276 .783 m .42421 .78312 L .42132 .78683 L F
.42714 .78389 m .42132 .78683 L .41724 .79204 L F
.42899 .78296 m .42906 .783 L .42815 .78338 L .678 0 .284 r
F
.42899 .78296 m .42815 .78338 L .42762 .7836 L F
.42871 .78366 m .42906 .783 L .42762 .7836 L 1 .377 .601 r
F
.42906 .783 m .4346 .78631 L .42762 .7836 L .678 0 .284 r
F
.43047 .78266 m .43037 .78267 L .42841 .78161 L .561 0 .266 r
F
.43092 .78289 m .42841 .78161 L .4285 .7816 L F
.42906 .783 m .43478 .77227 L .42762 .7836 L 1 .377 .601 r
F
.42762 .7836 m .42793 .78296 L .42728 .78363 L F
.42793 .78296 m .43428 .77025 L .42761 .783 L F
.42793 .78296 m .42761 .783 L .42728 .78363 L F
.43092 .78289 m .43037 .78267 L .43047 .78266 L .561 0 .266 r
F
.40994 .78513 m .42888 .75284 L .4234 .74137 L 1 .646 .616 r
F
.40986 .78537 m .41001 .78511 L .40994 .78513 L F
.41001 .78511 m .42888 .75284 L .40994 .78513 L F
.43086 .78283 m .43478 .77227 L .42907 .783 L 1 .298 .602 r
F
.43086 .78283 m .43092 .78289 L .43082 .78283 L .561 0 .266 r
F
.41971 .78372 m .41985 .78328 L .41397 .78467 L 1 .48 .612 r
F
.41985 .78328 m .42888 .75284 L .41413 .78433 L F
.41985 .78328 m .41413 .78433 L .41397 .78467 L F
.41985 .78328 m .43428 .77025 L .42888 .75284 L F
.41971 .78372 m .42021 .78327 L .41985 .78328 L F
.42021 .78327 m .43428 .77025 L .41985 .78328 L F
.43092 .78289 m .43111 .78307 L .43078 .78289 L .561 0 .266 r
F
.4306 .78352 m .43086 .78283 L .43045 .78353 L 1 .298 .602 r
F
.43111 .78307 m .4346 .78631 L .42907 .783 L .561 0 .266 r
F
.42793 .78296 m .43478 .77227 L .43428 .77025 L 1 .377 .601 r
F
.42762 .7836 m .42801 .78297 L .42793 .78296 L F
.42801 .78297 m .43478 .77227 L .42793 .78296 L F
.42781 .78373 m .42747 .78375 L .42728 .78363 L .678 0 .284 r
F
.42781 .78373 m .42728 .78363 L .42765 .78363 L F
.41867 .78725 m .42193 .7837 L .41971 .78372 L 1 .48 .612 r
F
.42193 .7837 m .43428 .77025 L .41971 .78372 L F
.41724 .79204 m .42212 .7858 L .41867 .78725 L F
.42212 .7858 m .43428 .77025 L .41867 .78725 L F
.40986 .81692 m .42591 .78624 L .41724 .79204 L F
.42727 .78363 m .43405 .78802 L .41867 .78725 L .696 0 .267 r
F
.41904 .78792 m .41907 .78797 L .41283 .78745 L F
.41907 .78797 m .42818 .80424 L .41308 .78771 L F
.41907 .78797 m .41308 .78771 L .41283 .78745 L F
.41308 .78771 m .42818 .80424 L .4129 .7877 L F
.41308 .78771 m .4129 .7877 L .41266 .78745 L F
.41867 .78725 m .41904 .78792 L .41283 .78745 L F
.41867 .78725 m .43405 .78802 L .42818 .80424 L F
.41266 .78745 m .42818 .80424 L .40883 .78874 L .853 0 .246 r
F
.40883 .78874 m .42818 .80424 L .4223 .81638 L F
.3999 .78945 m .4223 .81638 L .41641 .82553 L .943 0 .222 r
F
.39581 .78051 m .40191 .78878 L .3999 .78945 L F
.40004 .78901 m .39284 .78992 L .39186 .79214 L 1 .714 .615 r
F
.39944 .7896 m .39186 .79214 L .388 .80085 L F
.39977 .78918 m .3999 .78945 L .39947 .7892 L .943 0 .222 r
F
.40004 .78901 m .39186 .79214 L .39944 .7896 L 1 .714 .615 r
F
.40191 .78878 m .40199 .78888 L .3999 .78945 L .943 0 .222 r
F
.40199 .78888 m .4223 .81638 L .3999 .78945 L F
.3999 .78945 m .40199 .78888 L .40004 .78901 L 1 .714 .615 r
F
.40004 .78901 m .40214 .78856 L .40006 .78893 L F
.40199 .78888 m .40214 .78856 L .40004 .78901 L F
.40004 .78901 m .41784 .73344 L .39284 .78992 L F
.39296 .78963 m .41641 .82553 L .39159 .78995 L .988 0 .205 r
F
.40282 .86138 m .41524 .82491 L .3941 .85612 L 1 .508 .677 r
F
.39409 .85612 m .41524 .82491 L .41053 .81783 L 1 .602 .67 r
F
.39409 .85612 m .41053 .81783 L .3883 .85388 L F
.3883 .85388 m .41053 .81783 L .40986 .81692 L 1 .647 .665 r
F
.3883 .85388 m .40986 .81692 L .38747 .85365 L F
.38747 .85365 m .40986 .81692 L .40265 .80881 L 1 .72 .671 r
F
.38747 .85365 m .40265 .80881 L .37859 .85259 L F
.37859 .85259 m .40265 .80881 L .39537 .80359 L 1 .81 .665 r
F
.39159 .78995 m .41641 .82553 L .4104 .83293 L .988 0 .205 r
F
.39166 .78972 m .38458 .79059 L .38389 .79217 L 1 .724 .612 r
F
.39133 .79002 m .38389 .79217 L .38043 .80009 L F
.39166 .78972 m .38389 .79217 L .39133 .79002 L F
.39166 .78972 m .41214 .72751 L .38458 .79059 L F
.36961 .85407 m .39537 .80359 L .388 .80085 L 1 .83 .655 r
F
.37859 .85259 m .39537 .80359 L .36961 .85407 L 1 .81 .665 r
F
.38473 .79025 m .4104 .83293 L .38366 .79048 L 1 0 .195 r
F
.38366 .79048 m .4104 .83293 L .40436 .83921 L F
.37609 .79116 m .40638 .72293 L .40058 .71925 L 1 .689 .602 r
F
.37279 .80086 m .37706 .79095 L .37609 .79116 L F
.37702 .79088 m .37706 .79095 L .37609 .79116 L 1 0 .191 r
F
.37706 .79095 m .40638 .72293 L .37609 .79116 L 1 .689 .602 r
F
.38346 .78999 m .38366 .79048 L .38298 .79006 L 1 0 .195 r
F
.38372 .79031 m .38403 .7894 L .37697 .79117 L 1 .71 .607 r
F
.38403 .7894 m .40638 .72293 L .37706 .79095 L F
.38403 .7894 m .37706 .79095 L .37697 .79117 L F
.36961 .85407 m .388 .80085 L .36051 .85788 L 1 .83 .655 r
F
.36051 .85788 m .388 .80085 L .38043 .80009 L 1 .795 .642 r
F
.37706 .79095 m .40436 .83921 L .3761 .79117 L 1 0 .191 r
F
.37706 .79095 m .3761 .79117 L .37609 .79116 L F
.36506 .80281 m .40058 .71925 L .39473 .71618 L 1 .667 .597 r
F
.35116 .86376 m .38043 .80009 L .37279 .80086 L 1 .736 .628 r
F
.36051 .85788 m .38043 .80009 L .35116 .86376 L 1 .795 .642 r
F
.36973 .79182 m .39827 .84486 L .36877 .79207 L 1 .001 .192 r
F
.36973 .79182 m .36877 .79207 L .36875 .79204 L F
.37592 .79117 m .39827 .84486 L .36973 .79182 L 1 0 .191 r
F
.37609 .79116 m .3761 .79117 L .37592 .79117 L F
.3761 .79117 m .39827 .84486 L .37592 .79117 L F
.37609 .79116 m .40436 .83921 L .39827 .84486 L F
.3417 .87127 m .37279 .80086 L .36506 .80281 L 1 .677 .615 r
F
.35116 .86376 m .37279 .80086 L .3417 .87127 L 1 .736 .628 r
F
.36806 .79214 m .39214 .85019 L .3626 .7929 L 1 .001 .192 r
F
.36875 .79204 m .36877 .79207 L .36806 .79214 L F
.36877 .79207 m .39214 .85019 L .36806 .79214 L F
.36875 .79204 m .39827 .84486 L .39214 .85019 L F
.3629 .79282 m .36262 .79286 L .3626 .7929 L 1 .667 .597 r
F
.36864 .88036 m .38747 .85365 L .36768 .88053 L 1 .964 .748 r
F
.36864 .88036 m .3883 .85388 L .38747 .85365 L F
.36768 .88053 m .38747 .85365 L .37859 .85259 L 1 .993 .751 r
F
.36155 .79315 m .39473 .71618 L .38884 .71355 L 1 .646 .593 r
F
.35726 .80565 m .3626 .7929 L .36155 .79315 L F
.36255 .79281 m .3626 .7929 L .36155 .79315 L 1 .001 .194 r
F
.3626 .7929 m .39473 .71618 L .36155 .79315 L 1 .646 .593 r
F
.3626 .7929 m .39214 .85019 L .36155 .79315 L 1 .001 .194 r
F
.36157 .79321 m .39214 .85019 L .38596 .85541 L F
.36155 .79315 m .36158 .7932 L .36157 .79321 L F
.36158 .7932 m .39214 .85019 L .36157 .79321 L F
.33213 .88004 m .36506 .80281 L .35726 .80565 L 1 .627 .603 r
F
.3417 .87127 m .36506 .80281 L .33213 .88004 L 1 .677 .615 r
F
.36004 .79341 m .38596 .85541 L .35556 .7942 L 1 .001 .194 r
F
.36155 .79315 m .36157 .79321 L .36004 .79341 L F
.36157 .79321 m .38596 .85541 L .36004 .79341 L F
.35641 .79392 m .35561 .79407 L .35556 .7942 L 1 .646 .593 r
F
.36768 .88053 m .37859 .85259 L .35734 .88416 L 1 .993 .751 r
F
.35734 .88416 m .37859 .85259 L .36961 .85407 L 1 .91 .731 r
F
.35441 .79449 m .38884 .71355 L .38291 .71126 L 1 .628 .588 r
F
.34938 .80917 m .35556 .7942 L .35441 .79449 L F
.3555 .79409 m .35556 .7942 L .35441 .79449 L 1 .002 .198 r
F
.35556 .7942 m .38884 .71355 L .35441 .79449 L 1 .628 .588 r
F
.35556 .7942 m .38596 .85541 L .35441 .79449 L 1 .002 .198 r
F
.35444 .79457 m .38596 .85541 L .37973 .86063 L F
.35441 .79449 m .35445 .79457 L .35444 .79457 L F
.35445 .79457 m .38596 .85541 L .35444 .79457 L F
.32776 .90939 m .32607 .88569 L .31536 .89666 L .518 .168 .769 r
F
.32776 .90939 m .33631 .89807 L .32607 .88569 L F
.32607 .8857 m .32794 .90661 L .31627 .87384 L .437 0 .103 r
F
.32607 .88569 m .31627 .87384 L .31441 .8686 L F
.32607 .8857 m .31627 .87384 L .32607 .88569 L F
.33631 .89807 m .33796 .89589 L .32608 .8857 L .518 .168 .769 r
F
.33631 .89807 m .32608 .8857 L .32607 .88569 L F
.32244 .88977 m .35726 .80565 L .34938 .80917 L 1 .588 .594 r
F
.32893 .91037 m .33907 .89666 L .33796 .89589 L .582 .268 .791 r
F
.33719 .91638 m .33908 .89666 L .32893 .91037 L .676 .353 .787 r
F
.33719 .91638 m .34696 .9015 L .33908 .89666 L F
.33908 .89666 m .35106 .89399 L .33796 .89589 L .186 0 .717 r
F
.34696 .9015 m .35212 .89391 L .33908 .89666 L .533 .191 .884 r
F
.33908 .89666 m .35212 .89391 L .35106 .89399 L .186 0 .717 r
F
.33796 .89589 m .34204 .8953 L .33962 .8972 L 0 0 0 r
F
.34204 .8953 m .35106 .89399 L .33962 .8972 L F
.33796 .89589 m .33962 .8972 L .32607 .8857 L F
.33962 .8972 m .34685 .89131 L .33964 .89714 L .449 0 .552 r
F
.32893 .91037 m .33796 .89589 L .32776 .90939 L .582 .268 .791 r
F
.32607 .8857 m .33962 .8972 L .32794 .90661 L .437 0 .103 r
F
.33962 .8972 m .33964 .89714 L .33756 .89883 L .449 0 .552 r
F
.33962 .8972 m .33756 .89883 L .32794 .90661 L F
.33213 .88004 m .35726 .80565 L .32244 .88977 L 1 .627 .603 r
F
.35168 .79507 m .37973 .86063 L .34855 .79573 L 1 .002 .198 r
F
.35441 .79449 m .35444 .79457 L .35168 .79507 L F
.35444 .79457 m .37973 .86063 L .35168 .79507 L F
.34976 .79529 m .34863 .79552 L .34855 .79573 L 1 .628 .588 r
F
.35734 .88416 m .36961 .85407 L .34685 .89131 L 1 .91 .731 r
F
.34685 .89131 m .36961 .85407 L .36051 .85788 L 1 .727 .697 r
F
.34729 .79606 m .38291 .71126 L .37693 .70922 L 1 .612 .584 r
F
.34143 .81323 m .34855 .79573 L .34729 .79606 L F
.34849 .7956 m .34855 .79573 L .34729 .79606 L 1 .003 .203 r
F
.34855 .79573 m .38291 .71126 L .34729 .79606 L 1 .612 .584 r
F
.34855 .79573 m .37973 .86063 L .34729 .79606 L 1 .003 .203 r
F
.34733 .79617 m .37973 .86063 L .37343 .86596 L F
.34729 .79606 m .34734 .79616 L .34733 .79617 L F
.34734 .79616 m .37973 .86063 L .34733 .79617 L F
.31441 .8686 m .32794 .90661 L .31591 .92465 L .644 0 .317 r
F
.31265 .90024 m .34938 .80917 L .34143 .81323 L 1 .558 .586 r
F
.32244 .88977 m .34938 .80917 L .31265 .90024 L 1 .588 .594 r
F
.3428 .79715 m .37343 .86596 L .34153 .79746 L 1 .003 .203 r
F
.34729 .79606 m .34733 .79617 L .3428 .79715 L F
.34733 .79617 m .37343 .86596 L .3428 .79715 L F
.34729 .79606 m .34736 .79587 L .34722 .79608 L 1 .612 .584 r
F
.35441 .79449 m .35447 .79431 L .35433 .79451 L 1 .628 .588 r
F
.36143 .79286 m .36155 .79315 L .36126 .7929 L 1 .001 .194 r
F
.36155 .79315 m .3616 .79298 L .36147 .79316 L 1 .646 .593 r
F
.3616 .79298 m .38884 .71355 L .35561 .79407 L F
.36862 .79171 m .36875 .79204 L .36838 .79175 L 1 .001 .192 r
F
.36875 .79204 m .3688 .79188 L .36867 .79205 L 1 .667 .597 r
F
.3688 .79188 m .39473 .71618 L .36262 .79286 L F
.37609 .79116 m .37614 .79101 L .37599 .79117 L 1 .689 .602 r
F
.38366 .79048 m .40436 .83921 L .37706 .79095 L 1 0 .195 r
F
.38366 .79048 m .38372 .79031 L .38354 .79049 L 1 .71 .607 r
F
.38372 .79031 m .41214 .72751 L .40638 .72293 L F
.38473 .79025 m .41214 .72751 L .38372 .79031 L F
.39154 .78984 m .39159 .78995 L .39141 .78984 L .988 0 .205 r
F
.39159 .78995 m .4104 .83293 L .38473 .79025 L F
.39159 .78995 m .39166 .78972 L .3914 .78996 L 1 .724 .612 r
F
.39166 .78972 m .41784 .73343 L .41214 .72751 L F
.39296 .78963 m .41784 .73343 L .39166 .78972 L F
.3999 .78945 m .41641 .82553 L .39296 .78963 L .943 0 .222 r
F
.3999 .78945 m .40004 .78901 L .39958 .78946 L 1 .714 .615 r
F
.40883 .78874 m .4223 .81638 L .40199 .78888 L .853 0 .246 r
F
.40883 .78874 m .40918 .7876 L .40818 .78875 L 1 .646 .616 r
F
.40918 .7876 m .4234 .74137 L .40214 .78856 L F
.40918 .7876 m .41397 .78467 L .40986 .78537 L F
.41266 .78745 m .41397 .78467 L .40918 .7876 L F
.40006 .78893 m .4234 .74137 L .41784 .73344 L 1 .714 .615 r
F
.40214 .78856 m .4234 .74137 L .40006 .78893 L F
.41867 .78725 m .41971 .78372 L .41728 .7873 L 1 .48 .612 r
F
.42762 .7836 m .42781 .78373 L .4276 .7836 L .678 0 .284 r
F
.42781 .78373 m .43405 .78802 L .42747 .78375 L F
.43086 .78283 m .43651 .78022 L .43248 .78434 L .561 0 .266 r
F
.43248 .78434 m .43651 .78022 L .4346 .78631 L F
.44419 .7591 m .44231 .76388 L .43845 .77406 L 1 .778 .637 r
F
.43651 .78022 m .44541 .75567 L .43636 .77951 L 1 .4 .548 r
F
.44106 .77558 m .44541 .75567 L .43651 .78022 L F
.43636 .77951 m .46068 .6859 L .43478 .77227 L F
.44541 .75567 m .46068 .6859 L .43636 .77951 L F
.5184 .95153 m .52685 .94396 L .52365 .94288 L .899 .606 .795 r
F
.5167 .95115 m .5184 .95153 L .52365 .94288 L .898 .607 .795 r
F
.53643 .95086 m .55023 .94947 L .5481 .94615 L .898 .601 .793 r
F
.53461 .94884 m .53643 .95086 L .5481 .94615 L .902 .604 .793 r
F
.60334 .94415 m .61851 .95434 L .61628 .94223 L .839 .466 .771 r
F
.79056 .71813 m .82331 .83489 L .80269 .71425 L .679 .044 .581 r
F
.79056 .71813 m .81015 .83257 L .82331 .83489 L F
.53277 .72848 m .55581 .73301 L .53459 .7177 L .468 .172 .806 r
F
.53277 .72848 m .55215 .73911 L .55581 .73301 L F
.5167 .95115 m .52365 .94288 L .52026 .94212 L .898 .607 .795 r
F
.51494 .95093 m .5167 .95115 L .52026 .94212 L .897 .607 .795 r
F
.34157 .99531 m .32753 .97539 L .32815 1.00464 L 1 .662 .721 r
F
.34157 .99531 m .34093 .97176 L .32753 .97539 L F
.51494 .95093 m .52026 .94212 L .51673 .9417 L .897 .607 .795 r
F
.51315 .95088 m .51494 .95093 L .51673 .9417 L .896 .607 .796 r
F
.51315 .95088 m .51673 .9417 L .51314 .94161 L F
.72295 1.33161 m .69498 1.32366 L .70433 1.35783 L .401 0 .595 r
F
.71216 1.29764 m .69498 1.32366 L .72295 1.33161 L .396 0 .595 r
F
.69925 1.01372 m .69583 1.02682 L .70467 1.03724 L .245 0 .704 r
F
.34549 1.25209 m .31245 1.25403 L .33555 1.28162 L 1 .395 .588 r
F
.34549 1.25209 m .32385 1.22101 L .31245 1.25403 L F
.54983 1.08546 m .54765 1.09473 L .55707 1.09046 L .897 .765 .838 r
F
.54983 1.08546 m .54197 1.08902 L .54765 1.09473 L F
.5481 .94615 m .55023 .94947 L .56262 .94586 L .902 .597 .791 r
F
.48972 .68503 m .51303 .68964 L .51302 .6701 L .855 .205 .656 r
F
.49152 .70793 m .51303 .68964 L .48972 .68503 L .983 .321 .675 r
F
.47031 .72835 m .48972 .68503 L .46664 .71924 L 1 .394 .621 r
F
.47031 .72835 m .49152 .70793 L .48972 .68503 L F
.44868 1.11608 m .43747 1.1101 L .42813 1.11653 L .89 .639 .806 r
F
.45665 1.10853 m .43747 1.1101 L .44868 1.11608 L .884 .671 .817 r
F
.46753 1.11199 m .45665 1.10853 L .44868 1.11608 L .941 .707 .809 r
F
.47396 .73666 m .49152 .70793 L .47031 .72835 L 1 .516 .675 r
F
.49152 .70793 m .51304 .70723 L .51303 .68964 L .983 .321 .675 r
F
.39421 .96181 m .38304 .94886 L .38093 .96355 L 1 .674 .783 r
F
.39421 .96181 m .39612 .94934 L .38304 .94886 L F
.57503 .94221 m .57751 .94836 L .59042 .94619 L .892 .558 .783 r
F
.56262 .94586 m .57751 .94836 L .57503 .94221 L .894 .577 .788 r
F
.53461 .94884 m .5481 .94615 L .54538 .94308 L .902 .604 .793 r
F
.53243 .94701 m .53461 .94884 L .54538 .94308 L .904 .607 .793 r
F
.42813 1.11653 m .41714 1.10733 L .40663 1.11114 L .738 .489 .812 r
F
.43747 1.1101 m .41714 1.10733 L .42813 1.11653 L .781 .572 .823 r
F
.47398 1.10402 m .45665 1.10853 L .46753 1.11199 L .921 .719 .818 r
F
.48404 1.10571 m .47398 1.10402 L .46753 1.11199 L .947 .738 .815 r
F
.49771 1.09813 m .48404 1.10571 L .49465 1.10627 L .94 .751 .82 r
F
.50685 1.09775 m .49771 1.09813 L .49465 1.10627 L .944 .758 .821 r
F
.51304 .70723 m .53642 .70608 L .51303 .68964 L .647 .205 .729 r
F
.51304 .70723 m .53459 .7177 L .53642 .70608 L F
.60928 1.07595 m .61302 1.08707 L .62121 1.08039 L .749 .58 .838 r
F
.60928 1.07595 m .60204 1.08275 L .61302 1.08707 L F
.55215 .73911 m .57625 .74905 L .55581 .73301 L .234 .016 .831 r
F
.55215 .73911 m .57081 .75068 L .57625 .74905 L F
.57081 .75068 m .59545 .76193 L .57625 .74905 L 0 0 .739 r
F
.72888 .88945 m .74908 .99022 L .74229 .89917 L .784 .067 .572 r
F
.58746 .9385 m .59042 .94619 L .60334 .94415 L .89 .533 .776 r
F
.57503 .94221 m .59042 .94619 L .58746 .9385 L .892 .558 .783 r
F
.38093 .96355 m .36994 .94828 L .36763 .9658 L 1 .65 .771 r
F
.38093 .96355 m .38304 .94886 L .36994 .94828 L F
.53243 .94701 m .54538 .94308 L .5421 .94032 L .904 .607 .793 r
F
.5298 .94535 m .53243 .94701 L .5421 .94032 L .906 .608 .793 r
F
.40663 1.11114 m .39643 1.09953 L .38498 1.09879 L .474 .215 .831 r
F
.41714 1.10733 m .39643 1.09953 L .40663 1.11114 L .6 .398 .841 r
F
.55979 .94134 m .56262 .94586 L .57503 .94221 L .908 .589 .787 r
F
.5481 .94615 m .56262 .94586 L .55979 .94134 L .902 .597 .791 r
F
.34544 1.34789 m .30526 1.37802 L .33692 1.37901 L 1 .529 .6 r
F
.34544 1.34789 m .31544 1.34478 L .30526 1.37802 L F
.54538 .94308 m .5481 .94615 L .55979 .94134 L .91 .603 .791 r
F
.55704 1.0815 m .55707 1.09046 L .56571 1.08586 L .885 .758 .84 r
F
.55704 1.0815 m .54983 1.08546 L .55707 1.09046 L F
.43527 .95155 m .42556 .94141 L .42224 .95062 L .936 .642 .794 r
F
.35173 1.0819 m .34365 1.09132 L .33062 1.0957 L .172 0 0 r
F
.36384 1.08742 m .34365 1.09132 L .35173 1.0819 L 0 0 0 r
F
.5298 .94535 m .5421 .94032 L .53815 .93782 L .906 .608 .793 r
F
.52685 .94396 m .5298 .94535 L .53815 .93782 L .906 .609 .793 r
F
.48885 1.09764 m .47398 1.10402 L .48404 1.10571 L .929 .741 .821 r
F
.49771 1.09813 m .48885 1.09764 L .48404 1.10571 L .94 .751 .82 r
F
.45293 .6666 m .48111 .58591 L .44919 .65824 L 1 .452 .551 r
F
.44919 .65824 m .48111 .5859 L .47921 .57578 L 1 .574 .574 r
F
.32815 1.00465 m .32753 .97539 L .31868 .978 L 1 .586 .695 r
F
.5999 .9347 m .60334 .94415 L .61628 .94223 L .89 .503 .767 r
F
.58746 .9385 m .60334 .94415 L .5999 .9347 L .89 .533 .776 r
F
.39643 1.09953 m .37606 1.09045 L .38498 1.09879 L .449 .228 .878 r
F
.51303 .68964 m .53825 .69396 L .51302 .6701 L .55 .106 .706 r
F
.51303 .68964 m .53642 .70608 L .53825 .69396 L F
.36763 .9658 m .35683 .94738 L .35429 .96855 L 1 .602 .754 r
F
.36763 .9658 m .36994 .94828 L .35683 .94738 L F
.58 1.07563 m .58331 1.08468 L .59103 1.079 L .849 .718 .841 r
F
.58 1.07563 m .57339 1.08096 L .58331 1.08468 L F
.42224 .95062 m .41297 .93908 L .40919 .9499 L .952 .646 .79 r
F
.42224 .95062 m .42556 .94141 L .41297 .93908 L F
.52685 .94396 m .53815 .93782 L .53373 .93575 L .906 .609 .793 r
F
.52365 .94288 m .52685 .94396 L .53373 .93575 L .905 .61 .794 r
F
.5715 .93638 m .57503 .94221 L .58746 .9385 L .915 .577 .782 r
F
.55979 .94134 m .57503 .94221 L .5715 .93638 L .908 .589 .787 r
F
.54538 .94308 m .55979 .94134 L .55616 .93717 L .91 .603 .791 r
F
.5421 .94032 m .54538 .94308 L .55616 .93717 L .915 .609 .791 r
F
.70292 1.16755 m .68813 1.17628 L .69963 1.20269 L .37 .001 .627 r
F
.69058 1.1469 m .68813 1.17628 L .70292 1.16755 L .342 0 .643 r
F
.45665 1.10853 m .44684 1.10379 L .43747 1.1101 L .884 .671 .817 r
F
.55616 .93717 m .55979 .94134 L .5715 .93638 L .921 .601 .787 r
F
.52365 .94288 m .53373 .93575 L .52893 .93416 L .905 .61 .794 r
F
.52026 .94212 m .52365 .94288 L .52893 .93416 L .903 .61 .795 r
F
.52252 1.08752 m .51587 1.09657 L .52483 1.09467 L .924 .76 .828 r
F
.52954 1.08554 m .52483 1.09467 L .53358 1.09212 L .917 .761 .83 r
F
.52954 1.08554 m .52252 1.08752 L .52483 1.09467 L F
.61235 .93077 m .61628 .94223 L .62923 .94038 L .895 .472 .756 r
F
.5999 .9347 m .61628 .94223 L .61235 .93077 L .89 .503 .767 r
F
.32385 1.22101 m .29341 1.21375 L .31245 1.25403 L 1 .394 .577 r
F
.32385 1.22101 m .30607 1.17777 L .29341 1.21375 L F
.43747 1.1101 m .42769 1.10297 L .41714 1.10733 L .781 .572 .823 r
F
.44684 1.10379 m .42769 1.10297 L .43747 1.1101 L .816 .632 .829 r
F
.52252 1.08752 m .51533 1.08897 L .51587 1.09657 L .924 .76 .828 r
F
.51302 .6701 m .53946 .68588 L .51301 .65677 L .461 .04 .684 r
F
.51302 .6701 m .53825 .69396 L .53946 .68588 L F
.59735 1.07252 m .60204 1.08275 L .60928 1.07595 L .816 .65 .834 r
F
.59735 1.07252 m .59103 1.079 L .60204 1.08275 L F
.56344 1.0772 m .56571 1.08586 L .57339 1.08096 L .88 .748 .839 r
F
.56344 1.0772 m .55704 1.0815 L .56571 1.08586 L F
.53459 .7177 m .55948 .72711 L .53642 .70608 L .401 .078 .779 r
F
.53459 .7177 m .55581 .73301 L .55948 .72711 L F
.53626 1.08309 m .53358 1.09212 L .54197 1.08902 L .91 .761 .832 r
F
.53626 1.08309 m .52954 1.08554 L .53358 1.09212 L F
.52026 .94212 m .52893 .93416 L .52383 .93305 L .903 .61 .795 r
F
.51673 .9417 m .52026 .94212 L .52383 .93305 L .9 .611 .796 r
F
.35429 .96855 m .34372 .94588 L .34093 .97176 L 1 .531 .734 r
F
.35429 .96855 m .35683 .94738 L .34372 .94588 L F
.5081 1.08985 m .49771 1.09813 L .50685 1.09775 L .928 .754 .825 r
F
.51301 .65677 m .53963 .68473 L .51301 .65488 L .415 .017 .671 r
F
.51301 .65677 m .53946 .68588 L .53963 .68473 L F
.40919 .9499 m .40035 .93675 L .39612 .94934 L .968 .644 .785 r
F
.40919 .9499 m .41297 .93908 L .40035 .93675 L F
.51673 .9417 m .52383 .93305 L .51853 .93244 L .9 .611 .796 r
F
.51314 .94161 m .51673 .9417 L .51853 .93244 L .899 .611 .796 r
F
.51301 .65487 m .54147 .6726 L .513 .63495 L .406 .014 .67 r
F
.51301 .65487 m .53963 .68473 L .54147 .6726 L F
.33555 1.28162 m .30097 1.28747 L .32553 1.3126 L 1 .43 .59 r
F
.33555 1.28162 m .31245 1.25403 L .30097 1.28747 L F
.5421 .94032 m .55616 .93717 L .55181 .93346 L .915 .609 .791 r
F
.53815 .93782 m .5421 .94032 L .5518 .93345 L .918 .613 .791 r
F
.51314 .94161 m .51853 .93244 L .51313 .93233 L .899 .611 .796 r
F
.58323 .93121 m .58746 .9385 L .5999 .9347 L .925 .561 .774 r
F
.5715 .93638 m .58746 .9385 L .58323 .93121 L .915 .577 .782 r
F
.48885 1.09764 m .48045 1.09628 L .47398 1.10402 L .929 .741 .821 r
F
.41714 1.10733 m .40795 1.09822 L .39643 1.09953 L .6 .398 .841 r
F
.42769 1.10297 m .40795 1.09822 L .41714 1.10733 L .697 .527 .842 r
F
.61235 .93077 m .62923 .94038 L .62482 .92661 L .895 .472 .756 r
F
.54256 1.08022 m .54197 1.08902 L .54983 1.08546 L .904 .759 .834 r
F
.54256 1.08022 m .53626 1.08309 L .54197 1.08902 L F
.72311 1.261 m .70143 1.26407 L .71216 1.29764 L .387 0 .598 r
F
.71124 1.23096 m .70143 1.26407 L .72311 1.261 L .36 0 .597 r
F
.30607 1.17776 m .27855 1.17084 L .2934 1.21374 L 1 .509 .591 r
F
.30607 1.17776 m .29201 1.13971 L .27855 1.17084 L F
.65276 1.08195 m .6451 1.09401 L .65711 1.10417 L .604 .198 .744 r
F
.64007 1.07554 m .6451 1.09401 L .65276 1.08195 L .671 .311 .771 r
F
.64007 1.07554 m .63314 1.08625 L .6451 1.09401 L F
.66548 1.09038 m .65711 1.10417 L .66919 1.11713 L .551 .116 .714 r
F
.65276 1.08195 m .65711 1.10417 L .66548 1.09038 L .604 .198 .744 r
F
.513 .63495 m .54332 .66077 L .51299 .61588 L .349 .001 .652 r
F
.513 .63495 m .54147 .6726 L .54332 .66077 L F
.50077 1.09011 m .48885 1.09764 L .49771 1.09813 L .925 .75 .825 r
F
.5081 1.08985 m .50077 1.09011 L .49771 1.09813 L .928 .754 .825 r
F
.73382 1.36608 m .70433 1.35783 L .71374 1.39233 L .403 0 .595 r
F
.72295 1.33161 m .70433 1.35783 L .73382 1.36608 L .401 0 .595 r
F
.34139 .71632 m .35436 .74007 L .33153 .70202 L .74 0 0 r
F
.55616 .93717 m .5715 .93638 L .56698 .93104 L .921 .601 .787 r
F
.55181 .93346 m .55616 .93717 L .56698 .93104 L .931 .612 .787 r
F
.56698 .93104 m .5715 .93638 L .58323 .93121 L .937 .598 .781 r
F
.62742 1.07081 m .63314 1.08625 L .64007 1.07554 L .74 .432 .792 r
F
.62742 1.07081 m .62121 1.08039 L .63314 1.08625 L F
.39612 .94934 m .38771 .93429 L .38304 .94886 L .979 .63 .778 r
F
.39612 .94934 m .40035 .93675 L .38771 .93429 L F
.34093 .97176 m .33062 .94355 L .32753 .97539 L 1 .448 .71 r
F
.34093 .97176 m .34372 .94588 L .33062 .94355 L F
.53815 .93782 m .5518 .93345 L .54654 .93013 L .918 .613 .791 r
F
.53373 .93575 m .53815 .93782 L .54654 .93013 L .917 .616 .792 r
F
.33692 1.37901 m .29501 1.41224 L .32833 1.41135 L 1 .535 .598 r
F
.33692 1.37901 m .30526 1.37802 L .29501 1.41224 L F
.59498 .92578 m .5999 .9347 L .61235 .93077 L .937 .542 .765 r
F
.58323 .93121 m .5999 .9347 L .59498 .92578 L .925 .561 .774 r
F
.33153 .70202 m .35436 .74007 L .34546 .73358 L .803 0 0 r
F
.54833 1.07699 m .54983 1.08546 L .55704 1.0815 L .9 .756 .834 r
F
.54833 1.07699 m .54256 1.08022 L .54983 1.08546 L F
.67828 1.10106 m .66919 1.11713 L .68135 1.13304 L .517 .067 .685 r
F
.66548 1.09038 m .66919 1.11713 L .67828 1.10106 L .551 .116 .714 r
F
.32167 .6877 m .33654 .72691 L .3118 .6738 L .859 0 .017 r
F
.32167 .6877 m .34546 .73358 L .33654 .72691 L F
.51299 .61588 m .54518 .6493 L .51298 .59777 L .302 0 .638 r
F
.51299 .61588 m .54332 .66077 L .54518 .6493 L F
.39643 1.09953 m .38835 1.09131 L .37606 1.09045 L .449 .228 .878 r
F
.40795 1.09822 m .38835 1.09131 L .39643 1.09953 L .577 .423 .869 r
F
.56894 1.07252 m .57339 1.08096 L .58 1.07563 L .882 .735 .835 r
F
.56894 1.07252 m .56344 1.0772 L .57339 1.08096 L F
.7423 .89917 m .76304 1.00019 L .75592 .90765 L .735 .058 .578 r
F
.7423 .89917 m .74908 .99022 L .76304 1.00019 L F
.55581 .73301 m .58173 .74864 L .55948 .72711 L .106 0 .784 r
F
.55581 .73301 m .57625 .74905 L .58173 .74864 L F
.5854 1.06977 m .59103 1.079 L .59735 1.07252 L .861 .694 .831 r
F
.5854 1.06977 m .58 1.07563 L .59103 1.079 L F
.49367 1.08972 m .48045 1.09628 L .48885 1.09764 L .917 .744 .826 r
F
.50077 1.09011 m .49367 1.08972 L .48885 1.09764 L .925 .75 .825 r
F
.3696 1.08737 m .36337 1.08774 L .35663 1.08892 L .583 .139 .851 r
F
.36384 1.08742 m .35663 1.08892 L .35044 1.09001 L 0 0 0 r
F
.36337 1.08774 m .35243 1.08837 L .35663 1.08892 L .583 .139 .851 r
F
.35044 1.09001 m .35663 1.08892 L .34365 1.09132 L 0 0 0 r
F
.53373 .93575 m .54654 .93013 L .54064 .92743 L .917 .616 .792 r
F
.52893 .93416 m .53373 .93575 L .54064 .92743 L .914 .617 .793 r
F
.44684 1.10379 m .43828 1.09816 L .42769 1.10297 L .816 .632 .829 r
F
.45623 1.09749 m .43828 1.09816 L .44684 1.10379 L .843 .674 .831 r
F
.61478 1.06742 m .62121 1.08039 L .62742 1.07081 L .801 .539 .806 r
F
.61478 1.06742 m .60928 1.07595 L .62121 1.08039 L F
.44538 .64998 m .47921 .57578 L .47731 .5646 L 1 .626 .583 r
F
.44919 .65824 m .47921 .57578 L .44538 .64998 L 1 .574 .574 r
F
.38304 .94886 m .37507 .93146 L .36994 .94828 L .979 .597 .769 r
F
.38304 .94886 m .38771 .93429 L .37507 .93146 L F
.3118 .6738 m .32758 .72023 L .30189 .66049 L .908 0 .061 r
F
.3118 .6738 m .33654 .72691 L .32758 .72023 L F
.42556 .94141 m .41873 .92854 L .41297 .93908 L .947 .628 .787 r
F
.42556 .94141 m .43062 .9324 L .41873 .92854 L F
.55181 .93346 m .56698 .93104 L .56153 .92634 L .931 .612 .787 r
F
.54654 .93013 m .5518 .93345 L .56153 .92634 L .937 .621 .788 r
F
.60674 .92002 m .61235 .93077 L .62482 .92661 L .954 .523 .755 r
F
.59498 .92578 m .61235 .93077 L .60674 .92002 L .937 .542 .765 r
F
.32753 .97539 m .32199 .94147 L .31868 .978 L 1 .376 .686 r
F
.32753 .97539 m .33062 .94355 L .32199 .94147 L F
.57781 .92459 m .58323 .93121 L .59498 .92578 L .956 .591 .774 r
F
.56698 .93104 m .58323 .93121 L .57781 .92459 L .937 .598 .781 r
F
.53642 .70608 m .56317 .72149 L .53825 .69396 L .337 .022 .748 r
F
.53642 .70608 m .55948 .72711 L .56317 .72149 L F
.52893 .93416 m .54064 .92743 L .53423 .92538 L .914 .617 .793 r
F
.52383 .93305 m .52893 .93416 L .53423 .92538 L .908 .617 .795 r
F
.42769 1.10297 m .41952 1.09561 L .40795 1.09822 L .697 .527 .842 r
F
.43828 1.09816 m .41952 1.09561 L .42769 1.10297 L .766 .61 .84 r
F
.71537 1.1904 m .69963 1.20269 L .71124 1.23095 L .395 .001 .617 r
F
.70292 1.16755 m .69963 1.20269 L .71537 1.1904 L .37 .001 .627 r
F
.30189 .66049 m .31858 .71363 L .29196 .64776 L .948 0 .093 r
F
.30189 .66049 m .32758 .72023 L .31858 .71363 L F
.56153 .92634 m .56698 .93104 L .57781 .92459 L .954 .617 .782 r
F
.55345 1.07344 m .55704 1.0815 L .56344 1.0772 L .899 .751 .833 r
F
.55345 1.07344 m .54833 1.07699 L .55704 1.0815 L F
.51298 .59776 m .54708 .63802 L .51297 .58019 L .263 0 .627 r
F
.51298 .59776 m .54518 .6493 L .54708 .63802 L F
.69917 .89581 m .70856 .87068 L .72125 .87136 L .534 0 .194 r
F
.68692 .8906 m .70856 .87068 L .69917 .89581 L .053 0 0 r
F
.67828 1.10106 m .68135 1.13304 L .69115 1.11409 L .517 .067 .685 r
F
.69115 1.1141 m .68135 1.13304 L .68943 1.14509 L .507 .046 .665 r
F
.52383 .93305 m .53423 .92538 L .52741 .92398 L .908 .617 .795 r
F
.51853 .93244 m .52383 .93305 L .52741 .92398 L .902 .617 .797 r
F
.36994 .94828 m .36242 .92792 L .35683 .94738 L .963 .54 .757 r
F
.36994 .94828 m .37507 .93146 L .36242 .92792 L F
.48694 1.08867 m .47266 1.09409 L .48045 1.09628 L .905 .737 .828 r
F
.49367 1.08972 m .48694 1.08867 L .48045 1.09628 L .917 .744 .826 r
F
.60214 1.06501 m .60928 1.07595 L .61478 1.06742 L .847 .62 .814 r
F
.60214 1.06501 m .59735 1.07252 L .60928 1.07595 L F
.31868 .978 m .32077 .94114 L .31742 .97838 L 1 .34 .67 r
F
.31868 .978 m .32199 .94147 L .32077 .94114 L F
.5202 1.08032 m .51533 1.08897 L .52252 1.08752 L .915 .755 .829 r
F
.52547 1.07886 m .52252 1.08752 L .52954 1.08554 L .913 .756 .83 r
F
.52547 1.07886 m .5202 1.08032 L .52252 1.08752 L F
.5202 1.08032 m .51479 1.08138 L .51533 1.08897 L .915 .755 .829 r
F
.61851 .91393 m .62482 .92661 L .6373 .92203 L .981 .512 .744 r
F
.60674 .92002 m .62482 .92661 L .61851 .91393 L .954 .523 .755 r
F
.51853 .93244 m .52741 .92398 L .52033 .92322 L .902 .617 .797 r
F
.51313 .93233 m .51853 .93244 L .52033 .92322 L .898 .616 .798 r
F
.41297 .93908 m .40681 .92467 L .40035 .93675 L .96 .628 .783 r
F
.41297 .93908 m .41873 .92854 L .40681 .92467 L F
.29196 .64776 m .30955 .70715 L .282 .63551 L .98 0 .116 r
F
.29196 .64776 m .31858 .71363 L .30955 .70715 L F
.51313 .93233 m .52033 .92322 L .51312 .92309 L .898 .616 .798 r
F
.53052 1.07703 m .52954 1.08554 L .53626 1.08309 L .91 .756 .831 r
F
.53052 1.07703 m .52547 1.07886 L .52954 1.08554 L F
.54654 .93013 m .56153 .92634 L .55494 .92222 L .937 .621 .788 r
F
.54064 .92743 m .54654 .93013 L .55494 .92222 L .936 .627 .79 r
F
.58866 .91774 m .59498 .92578 L .60674 .92002 L .977 .58 .765 r
F
.57781 .92459 m .59498 .92578 L .58866 .91774 L .956 .591 .774 r
F
.32553 1.3126 m .28942 1.32132 L .31544 1.34478 L 1 .455 .592 r
F
.32553 1.3126 m .30097 1.28747 L .28942 1.32132 L F
.57343 1.06748 m .58 1.07563 L .5854 1.06977 L .889 .722 .829 r
F
.57343 1.06748 m .56894 1.07252 L .58 1.07563 L F
.40795 1.09822 m .40071 1.09058 L .38835 1.09131 L .577 .423 .869 r
F
.41952 1.09561 m .40071 1.09058 L .40795 1.09822 L .679 .547 .859 r
F
.35683 .94738 m .34978 .92314 L .34372 .94588 L .924 .454 .741 r
F
.35683 .94738 m .36242 .92792 L .34978 .92314 L F
.53525 1.07487 m .53626 1.08309 L .54256 1.08022 L .908 .756 .831 r
F
.53525 1.07487 m .53052 1.07703 L .53626 1.08309 L F
.61851 .91393 m .6373 .92203 L .6303 .90756 L .981 .512 .744 r
F
.51297 .58019 m .54898 .62703 L .51296 .56321 L .232 0 .617 r
F
.51297 .58019 m .54708 .63802 L .54898 .62703 L F
.45623 1.09749 m .44889 1.09302 L .43828 1.09816 L .843 .674 .831 r
F
.31245 1.25403 m .28071 1.24813 L .30097 1.28747 L 1 .426 .583 r
F
.31245 1.25403 m .29341 1.21375 L .28071 1.24813 L F
.282 .63551 m .30047 .70081 L .27201 .62365 L 1 0 .134 r
F
.282 .63551 m .30955 .70715 L .30047 .70081 L F
.55785 1.06959 m .56344 1.0772 L .56894 1.07252 L .901 .745 .831 r
F
.55785 1.06959 m .55345 1.07344 L .56344 1.0772 L F
.56153 .92634 m .57781 .92459 L .57128 .91887 L .954 .617 .782 r
F
.55494 .92222 m .56153 .92634 L .57128 .91887 L .963 .633 .784 r
F
.69115 1.1141 m .68943 1.14509 L .69969 1.12397 L .507 .046 .665 r
F
.69969 1.12398 m .68943 1.1451 L .69058 1.1469 L .511 .041 .656 r
F
.57128 .91887 m .57781 .92459 L .58866 .91774 L .982 .621 .775 r
F
.32833 1.41135 m .28468 1.4474 L .31968 1.44481 L 1 .538 .596 r
F
.32833 1.41135 m .29501 1.41224 L .28468 1.4474 L F
.43478 .77227 m .46068 .6859 L .46033 .68491 L 1 .524 .536 r
F
.37606 1.09045 m .3696 1.08737 L .35663 1.08892 L .4 .029 .864 r
F
.38835 1.09131 m .3696 1.08737 L .37606 1.09045 L .538 .332 .899 r
F
.69969 1.12398 m .69058 1.1469 L .7009 1.12546 L .511 .041 .656 r
F
.7009 1.12546 m .69058 1.1469 L .70292 1.16755 L .495 .031 .648 r
F
.54064 .92743 m .55494 .92222 L .54757 .91896 L .936 .627 .79 r
F
.53423 .92538 m .54064 .92743 L .54757 .91896 L .928 .63 .793 r
F
.43828 1.09816 m .43113 1.09213 L .41952 1.09561 L .766 .61 .84 r
F
.44889 1.09302 m .43113 1.09213 L .43828 1.09816 L .814 .663 .838 r
F
.48694 1.08867 m .48071 1.087 L .47266 1.09409 L .905 .737 .828 r
F
.40035 .93675 m .39487 .92076 L .38771 .93429 L .968 .624 .78 r
F
.40035 .93675 m .40681 .92467 L .39487 .92076 L F
.58949 1.06332 m .59735 1.07252 L .60214 1.06501 L .879 .676 .82 r
F
.58949 1.06332 m .5854 1.06977 L .59735 1.07252 L F
.34372 .94588 m .33719 .91638 L .33062 .94355 L .858 .341 .719 r
F
.34372 .94588 m .34978 .92314 L .33719 .91638 L F
.43478 .77227 m .46033 .68491 L .43428 .77025 L 1 .524 .536 r
F
.43428 .77025 m .46033 .68491 L .45664 .67535 L 1 .519 .536 r
F
.53959 1.07241 m .54256 1.08022 L .54833 1.07699 L .908 .755 .831 r
F
.53959 1.07241 m .53525 1.07487 L .54256 1.08022 L F
.43062 .9324 m .42615 .9188 L .41873 .92853 L .94 .612 .784 r
F
.43062 .9324 m .43712 .92407 L .42615 .9188 L F
.73507 1.29216 m .71216 1.29764 L .72295 1.33161 L .404 .001 .598 r
F
.72311 1.261 m .71216 1.29764 L .73507 1.29216 L .387 0 .598 r
F
.59952 .91041 m .60674 .92002 L .61851 .91393 L .997 .565 .756 r
F
.58866 .91774 m .60674 .92002 L .59952 .91041 L .977 .58 .765 r
F
.49851 1.0819 m .48694 1.08867 L .49367 1.08972 L .909 .747 .829 r
F
.74476 1.40113 m .71374 1.39233 L .7232 1.4273 L .405 0 .594 r
F
.73382 1.36608 m .71374 1.39233 L .74476 1.40113 L .403 0 .595 r
F
.44155 .64187 m .47731 .5646 L .4754 .55275 L 1 .648 .587 r
F
.44538 .64998 m .47731 .5646 L .44155 .64187 L 1 .626 .583 r
F
.53825 .69396 m .56562 .71795 L .53946 .68588 L .28 .002 .716 r
F
.53825 .69396 m .56318 .72149 L .56562 .71795 L F
.71158 .90426 m .72125 .87136 L .73414 .87671 L .693 0 .266 r
F
.69917 .89581 m .72125 .87136 L .71158 .90426 L .534 0 .194 r
F
.75592 .90765 m .7771 1.01144 L .76958 .9156 L .704 .051 .582 r
F
.75592 .90765 m .76304 1.00019 L .7771 1.01144 L F
.65777 1.06389 m .65276 1.08195 L .66548 1.09038 L .747 .248 .714 r
F
.64464 1.06072 m .65276 1.08195 L .65777 1.06389 L .788 .339 .741 r
F
.64464 1.06072 m .64007 1.07554 L .65276 1.08195 L F
.33062 .94355 m .32893 .91037 L .32199 .94147 L .799 .241 .693 r
F
.33062 .94355 m .33719 .91638 L .32893 .91037 L F
.63152 1.0586 m .64007 1.07554 L .64464 1.06072 L .829 .442 .766 r
F
.63152 1.0586 m .62742 1.07081 L .64007 1.07554 L F
.32199 .94147 m .32776 .90939 L .32077 .94114 L .786 .2 .675 r
F
.32199 .94147 m .32893 .91037 L .32776 .90939 L F
.53423 .92538 m .54757 .91896 L .53954 .91656 L .928 .63 .793 r
F
.52741 .92398 m .53423 .92538 L .53954 .91656 L .916 .629 .796 r
F
.67093 1.06843 m .66548 1.09038 L .67828 1.10106 L .71 .177 .688 r
F
.65777 1.06389 m .66548 1.09038 L .67093 1.06843 L .747 .248 .714 r
F
.51296 .56321 m .55089 .61627 L .51295 .54664 L .208 0 .609 r
F
.51296 .56321 m .54898 .62703 L .55089 .61627 L F
.54343 1.0697 m .54833 1.07699 L .55345 1.07344 L .908 .753 .831 r
F
.54343 1.0697 m .53959 1.07241 L .54833 1.07699 L F
.55948 .72711 m .58726 .74935 L .56317 .72149 L 0 0 .728 r
F
.55948 .72711 m .58173 .74864 L .58726 .74935 L F
.61841 1.0573 m .62742 1.07081 L .63152 1.0586 L .863 .539 .786 r
F
.61841 1.0573 m .61478 1.06742 L .62742 1.07081 L F
.41952 1.09561 m .41311 1.08872 L .40071 1.09058 L .679 .547 .859 r
F
.43113 1.09213 m .41311 1.08872 L .41952 1.09561 L .753 .624 .85 r
F
.55494 .92222 m .57128 .91887 L .56337 .91398 L .963 .633 .784 r
F
.54757 .91896 m .55494 .92222 L .56337 .91398 L .963 .645 .787 r
F
.38771 .93429 m .38291 .91671 L .37507 .93146 L .966 .614 .778 r
F
.38771 .93429 m .39487 .92076 L .38291 .91671 L F
.58104 .91091 m .58866 .91774 L .59952 .91041 L 1 .621 .767 r
F
.57128 .91887 m .58866 .91774 L .58104 .91091 L .982 .621 .775 r
F
.49346 1.08114 m .48071 1.087 L .48694 1.08867 L .903 .743 .83 r
F
.49851 1.0819 m .49346 1.08114 L .48694 1.08867 L .909 .747 .829 r
F
.6104 .90257 m .61851 .91393 L .6303 .90756 L 1 .544 .746 r
F
.59952 .91041 m .61851 .91393 L .6104 .90257 L .997 .565 .756 r
F
.52741 .92398 m .53954 .91656 L .53101 .91497 L .916 .629 .796 r
F
.52033 .92322 m .52741 .92398 L .53101 .91497 L .903 .627 .799 r
F
.56143 1.06549 m .56894 1.07252 L .57343 1.06748 L .904 .739 .828 r
F
.56143 1.06549 m .55785 1.06959 L .56894 1.07252 L F
.56337 .91398 m .57128 .91887 L .58104 .91091 L .999 .648 .778 r
F
.57682 1.0621 m .5854 1.06977 L .58949 1.06332 L .899 .713 .823 r
F
.57682 1.0621 m .57343 1.06748 L .5854 1.06977 L F
.27766 .86966 m .27441 .94486 L .26367 .89382 L .431 0 .32 r
F
.27766 .86966 m .2882 .91238 L .27441 .94486 L F
.71537 1.1904 m .71124 1.23095 L .72792 1.21511 L .395 .001 .617 r
F
.72793 1.21512 m .71124 1.23096 L .72311 1.261 L .415 .002 .611 r
F
.41873 .92853 m .41515 .91356 L .40681 .92467 L .956 .618 .781 r
F
.41873 .92853 m .42615 .9188 L .41515 .91356 L F
.2934 1.21374 m .26503 1.20119 L .28071 1.24812 L 1 .49 .592 r
F
.2934 1.21374 m .27855 1.17084 L .26503 1.20119 L F
.68414 1.07467 m .67828 1.10106 L .69115 1.11409 L .679 .126 .666 r
F
.67093 1.06843 m .67828 1.10106 L .68414 1.07467 L .71 .177 .688 r
F
.52033 .92322 m .53101 .91497 L .52215 .91412 L .903 .627 .799 r
F
.51312 .92309 m .52033 .92322 L .52215 .91412 L .892 .623 .801 r
F
.44889 1.09302 m .44278 1.08807 L .43113 1.09213 L .814 .663 .838 r
F
.45954 1.08762 m .44278 1.08807 L .44889 1.09302 L .846 .698 .837 r
F
.38835 1.09131 m .38258 1.08596 L .3696 1.08737 L .538 .332 .899 r
F
.40071 1.09058 m .38258 1.08596 L .38835 1.09131 L .634 .528 .885 r
F
.6053 1.05661 m .61478 1.06742 L .61841 1.0573 L .888 .619 .802 r
F
.6053 1.05661 m .60214 1.06501 L .61478 1.06742 L F
.51312 .92309 m .52215 .91412 L .51311 .91398 L .892 .623 .801 r
F
.53946 .68588 m .56597 .71746 L .53963 .68473 L .25 0 .696 r
F
.53946 .68588 m .56562 .71795 L .56597 .71746 L F
.51786 1.07309 m .51479 1.08138 L .5202 1.08032 L .911 .753 .83 r
F
.52138 1.07212 m .5202 1.08032 L .52547 1.07886 L .91 .754 .83 r
F
.52138 1.07212 m .51786 1.07309 L .5202 1.08032 L F
.51786 1.07309 m .51425 1.07379 L .51479 1.08138 L .911 .753 .83 r
F
.54672 1.06677 m .55345 1.07344 L .55785 1.06959 L .909 .751 .83 r
F
.54672 1.06677 m .54343 1.0697 L .55345 1.07344 L F
.52476 1.0709 m .52547 1.07886 L .53052 1.07703 L .91 .754 .83 r
F
.52476 1.0709 m .52138 1.07212 L .52547 1.07886 L F
.53963 .68473 m .56971 .71236 L .54147 .6726 L .238 0 .694 r
F
.53963 .68473 m .56597 .71746 L .56971 .71236 L F
.37507 .93146 m .37094 .91235 L .36242 .92792 L .946 .592 .777 r
F
.37507 .93146 m .38291 .91671 L .37094 .91235 L F
.6104 .90257 m .6303 .90756 L .62129 .89433 L 1 .544 .746 r
F
.71394 1.14249 m .70292 1.16755 L .71537 1.1904 L .494 .023 .634 r
F
.7009 1.12546 m .70292 1.16755 L .71394 1.14249 L .495 .031 .648 r
F
.49346 1.08114 m .48878 1.07993 L .48071 1.087 L .903 .743 .83 r
F
.54757 .91896 m .56337 .91398 L .55452 .91029 L .963 .645 .787 r
F
.53954 .91656 m .54757 .91896 L .55452 .91029 L .95 .65 .792 r
F
.43712 .92407 m .43522 .90977 L .42615 .9188 L .931 .591 .781 r
F
.51295 .54664 m .55282 .60566 L .51294 .53032 L .188 0 .601 r
F
.51295 .54664 m .55089 .61627 L .55282 .60566 L F
.52792 1.06945 m .53052 1.07703 L .53525 1.07487 L .91 .755 .831 r
F
.52792 1.06945 m .52476 1.0709 L .53052 1.07703 L F
.59083 .90234 m .59952 .91041 L .6104 .90257 L 1 .614 .757 r
F
.58104 .91091 m .59952 .91041 L .59083 .90234 L 1 .621 .767 r
F
.31544 1.34478 m .27778 1.35566 L .30526 1.37802 L 1 .472 .592 r
F
.31544 1.34478 m .28942 1.32132 L .27778 1.35566 L F
.43113 1.09213 m .42554 1.08607 L .41311 1.08872 L .753 .624 .85 r
F
.44278 1.08807 m .42554 1.08607 L .43113 1.09213 L .805 .672 .844 r
F
.59218 1.05638 m .60214 1.06501 L .6053 1.05661 L .904 .676 .812 r
F
.59218 1.05638 m .58949 1.06332 L .60214 1.06501 L F
.4377 .63385 m .4754 .55275 L .47349 .5404 L 1 .656 .589 r
F
.44155 .64187 m .4754 .55275 L .4377 .63385 L 1 .648 .587 r
F
.42888 .75284 m .45664 .67535 L .45292 .66662 L 1 .58 .56 r
F
.43428 .77025 m .45664 .67535 L .42888 .75284 L 1 .519 .536 r
F
.31968 1.44481 m .27427 1.48346 L .31097 1.47932 L 1 .539 .594 r
F
.31968 1.44481 m .28468 1.4474 L .27427 1.48346 L F
.53081 1.0678 m .53525 1.07487 L .53959 1.07241 L .91 .755 .83 r
F
.53081 1.0678 m .52792 1.06945 L .53525 1.07487 L F
.68414 1.07467 m .69115 1.11409 L .69742 1.08294 L .679 .126 .666 r
F
.69743 1.08294 m .69115 1.1141 L .69969 1.12397 L .663 .099 .649 r
F
.40681 .92467 m .40412 .90847 L .39488 .92076 L .97 .631 .781 r
F
.40681 .92467 m .41515 .91356 L .40412 .90847 L F
.36242 .92792 m .35895 .90743 L .34978 .92314 L .897 .55 .779 r
F
.36242 .92792 m .37094 .91235 L .35895 .90743 L F
.56413 1.06119 m .57343 1.06748 L .57682 1.0621 L .909 .735 .826 r
F
.56413 1.06119 m .56143 1.06549 L .57343 1.06748 L F
.57182 .9053 m .58104 .91091 L .59082 .90233 L 1 .663 .77 r
F
.56337 .91398 m .58104 .91091 L .57182 .9053 L .999 .648 .778 r
F
.55452 .91029 m .56337 .91398 L .57182 .9053 L 1 .67 .783 r
F
.40071 1.09058 m .39558 1.08433 L .38258 1.08596 L .634 .528 .885 r
F
.41311 1.08872 m .39558 1.08433 L .40071 1.09058 L .713 .62 .869 r
F
.76958 .9156 m .79126 1.02357 L .78329 .9234 L .684 .047 .583 r
F
.76958 .9156 m .7771 1.01144 L .79126 1.02357 L F
.54941 1.06367 m .55785 1.06959 L .56143 1.06549 L .911 .749 .829 r
F
.54941 1.06367 m .54672 1.06677 L .55785 1.06959 L F
.53954 .91656 m .55452 .91029 L .54488 .90772 L .95 .65 .792 r
F
.53101 .91497 m .53954 .91656 L .54488 .90772 L .927 .649 .798 r
F
.71158 .90426 m .73414 .87671 L .72414 .91495 L .693 0 .266 r
F
.72414 .91495 m .73414 .87672 L .74737 .88466 L .763 0 .29 r
F
.45954 1.08762 m .45445 1.08362 L .44278 1.08807 L .846 .698 .837 r
F
.69894 .98938 m .70004 1.04112 L .70889 1.04307 L .964 .189 .613 r
F
.68594 1.00172 m .70004 1.04112 L .69893 .98938 L 1 .272 .641 r
F
.53338 1.06598 m .53959 1.07241 L .54343 1.0697 L .911 .754 .83 r
F
.53338 1.06598 m .53081 1.0678 L .53959 1.07241 L F
.66007 1.04208 m .65777 1.06389 L .67093 1.06843 L .898 .328 .702 r
F
.64676 1.04349 m .65777 1.06389 L .66007 1.04208 L .92 .419 .73 r
F
.64676 1.04349 m .64464 1.06072 L .65777 1.06389 L F
.60062 .89299 m .6104 .90257 L .62129 .89433 L 1 .592 .747 r
F
.59083 .90234 m .6104 .90257 L .60062 .89299 L 1 .614 .757 r
F
.34978 .92314 m .34696 .9015 L .33719 .91638 L .807 .471 .782 r
F
.34978 .92314 m .35895 .90743 L .34696 .9015 L F
.30097 1.28747 m .26795 1.28185 L .28942 1.32132 L 1 .446 .587 r
F
.30097 1.28747 m .28071 1.24813 L .26795 1.28185 L F
.63344 1.04489 m .64464 1.06072 L .64676 1.04349 L .934 .51 .756 r
F
.63344 1.04489 m .63152 1.0586 L .64464 1.06072 L F
.67338 1.04083 m .67093 1.06843 L .68414 1.07467 L .868 .247 .674 r
F
.66007 1.04208 m .67093 1.06843 L .67338 1.04083 L .898 .328 .702 r
F
.57905 1.05647 m .58949 1.06332 L .59218 1.05638 L .913 .714 .819 r
F
.57905 1.05647 m .57682 1.0621 L .58949 1.06332 L F
.75579 1.43683 m .7232 1.4273 L .73272 1.46282 L .405 0 .593 r
F
.74476 1.40113 m .7232 1.4273 L .75579 1.43683 L .405 0 .594 r
F
.51294 .53032 m .55475 .59516 L .51293 .51414 L .172 0 .595 r
F
.51294 .53032 m .55282 .60566 L .55475 .59516 L F
.44278 1.08807 m .43801 1.08287 L .42554 1.08607 L .805 .672 .844 r
F
.45445 1.08362 m .43801 1.08287 L .44278 1.08807 L .841 .703 .84 r
F
.42615 .9188 m .42535 .90307 L .41515 .91356 L .948 .595 .777 r
F
.42615 .9188 m .43522 .90977 L .42535 .90307 L F
.74713 1.32429 m .72295 1.33161 L .73382 1.36608 L .415 .001 .597 r
F
.73507 1.29216 m .72295 1.33161 L .74713 1.32429 L .404 .001 .598 r
F
.53101 .91497 m .54488 .90772 L .53463 .9061 L .927 .649 .798 r
F
.52215 .91412 m .53101 .91497 L .53463 .9061 L .9 .642 .804 r
F
.69743 1.08294 m .69969 1.12397 L .70623 1.08962 L .663 .099 .649 r
F
.70623 1.08962 m .69969 1.12398 L .7009 1.12546 L .663 .09 .642 r
F
.62011 1.04629 m .63152 1.0586 L .63344 1.04489 L .939 .59 .778 r
F
.62011 1.04629 m .61841 1.0573 L .63152 1.0586 L F
.68669 1.04021 m .68414 1.07467 L .69742 1.08294 L .834 .184 .65 r
F
.67338 1.04083 m .68414 1.07467 L .68669 1.04021 L .868 .247 .674 r
F
.70623 1.08962 m .7009 1.12546 L .70748 1.09065 L .663 .09 .642 r
F
.70748 1.09065 m .7009 1.12546 L .71394 1.14249 L .638 .075 .637 r
F
.54147 .6726 m .57346 .70753 L .54332 .66077 L .195 0 .668 r
F
.54147 .6726 m .56971 .71236 L .57346 .70753 L F
.53557 1.06402 m .54343 1.0697 L .54672 1.06677 L .912 .754 .83 r
F
.53557 1.06402 m .53338 1.06598 L .54343 1.0697 L F
.39488 .92076 m .39306 .90369 L .38291 .9167 L .979 .655 .785 r
F
.39488 .92076 m .40412 .90847 L .39306 .90369 L F
.41311 1.08872 m .4086 1.08237 L .39558 1.08433 L .713 .62 .869 r
F
.42554 1.08607 m .4086 1.08237 L .41311 1.08872 L .772 .668 .857 r
F
.52215 .91412 m .53463 .9061 L .52397 .90526 L .9 .642 .804 r
F
.51311 .91398 m .52215 .91412 L .52397 .90526 L .878 .631 .808 r
F
.49688 1.07286 m .48457 1.07831 L .48878 1.07993 L .899 .747 .832 r
F
.56318 .72149 m .59094 .75032 L .56562 .71795 L 0 0 .682 r
F
.56318 .72149 m .58726 .74935 L .59094 .75032 L F
.58029 .896 m .59082 .90233 L .60062 .89299 L 1 .675 .76 r
F
.57182 .9053 m .59082 .90233 L .58029 .896 L 1 .663 .77 r
F
.55452 .91029 m .57182 .9053 L .56149 .90134 L 1 .67 .783 r
F
.54488 .90772 m .55452 .91029 L .56149 .90134 L .981 .681 .791 r
F
.60678 1.04772 m .61841 1.0573 L .62011 1.04629 L .939 .653 .796 r
F
.60678 1.04772 m .6053 1.05661 L .61841 1.0573 L F
.61042 .88271 m .62129 .89433 L .6322 .88608 L 1 .544 .738 r
F
.60062 .89299 m .62129 .89433 L .61042 .88271 L 1 .592 .747 r
F
.55143 1.06046 m .56143 1.06549 L .56413 1.06119 L .913 .748 .828 r
F
.55143 1.06046 m .54941 1.06367 L .56143 1.06549 L F
.51311 .91398 m .52397 .90526 L .5131 .9051 L .878 .631 .808 r
F
.34365 1.09132 m .32533 1.10251 L .33062 1.0957 L 0 0 0 r
F
.33062 1.0957 m .31631 1.10927 L .32198 1.10024 L F
.32955 1.09994 m .33892 1.09436 L .32533 1.10251 L F
.34365 1.09132 m .33892 1.09436 L .32955 1.09994 L F
.35663 1.08892 m .33892 1.09436 L .34365 1.09132 L .48 0 .729 r
F
.35243 1.08837 m .34888 1.08843 L .33892 1.09436 L .749 .387 .829 r
F
.34888 1.08843 m .33777 1.0886 L .33892 1.09436 L F
.33892 1.09436 m .33627 1.09482 L .32533 1.10251 L .754 .232 .782 r
F
.33062 1.0957 m .32533 1.10251 L .31803 1.10764 L 0 0 0 r
F
.33627 1.09482 m .324 1.09699 L .32533 1.10251 L .754 .232 .782 r
F
.33627 1.09482 m .32533 1.10251 L .32533 1.10251 L F
.31803 1.10764 m .32533 1.10251 L .31631 1.10927 L 0 0 0 r
F
.32533 1.10251 m .32533 1.10251 L .31803 1.10764 L F
.56591 1.05677 m .57682 1.0621 L .57905 1.05647 L .916 .737 .824 r
F
.56591 1.05677 m .56413 1.06119 L .57682 1.0621 L F
.72708 1.16156 m .71537 1.1904 L .72792 1.21511 L .497 .019 .623 r
F
.71394 1.14249 m .71537 1.1904 L .72708 1.16156 L .494 .023 .634 r
F
.56149 .90134 m .57182 .9053 L .58029 .896 L 1 .701 .777 r
F
.51552 1.06585 m .51425 1.07379 L .51786 1.07309 L .909 .754 .831 r
F
.51728 1.06536 m .51786 1.07309 L .52138 1.07212 L F
.51728 1.06536 m .51552 1.06585 L .51786 1.07309 L F
.51552 1.06585 m .51371 1.0662 L .51425 1.07379 L F
.63724 .76794 m .66195 .7167 L .67055 .70264 L 0 0 0 r
F
.74077 1.24179 m .72311 1.261 L .73507 1.29216 L .431 .003 .607 r
F
.72793 1.21512 m .72311 1.261 L .74077 1.24179 L .415 .002 .611 r
F
.43383 .62588 m .47349 .5404 L .47158 .52769 L 1 .658 .588 r
F
.4377 .63385 m .47349 .5404 L .43383 .62588 L 1 .656 .589 r
F
.68669 1.04021 m .69742 1.08294 L .70004 1.04112 L .834 .184 .65 r
F
.70004 1.04112 m .69743 1.08294 L .70623 1.08962 L .81 .145 .632 r
F
.51897 1.06475 m .52138 1.07212 L .52476 1.0709 L .909 .754 .831 r
F
.51897 1.06475 m .51728 1.06536 L .52138 1.07212 L F
.32198 1.10024 m .31503 1.11032 L .32075 1.10101 L 0 0 0 r
F
.32533 1.10251 m .32476 1.10258 L .31631 1.10927 L .765 .134 .734 r
F
.32198 1.10024 m .31631 1.10927 L .31508 1.11024 L 0 0 0 r
F
.32075 1.10101 m .30124 1.12305 L .30754 1.11128 L F
.30473 1.11911 m .31502 1.11032 L .30124 1.12305 L F
.32075 1.10101 m .31507 1.11025 L .30473 1.11911 L F
.31508 1.11024 m .31631 1.10927 L .31503 1.11032 L F
.31631 1.10927 m .31631 1.10927 L .31508 1.11024 L F
.31631 1.10927 m .31628 1.10921 L .31503 1.11032 L .771 .102 .711 r
F
.31507 1.11025 m .31502 1.11032 L .30473 1.11911 L 0 0 0 r
F
.31628 1.10921 m .31355 1.10483 L .31503 1.11032 L .771 .102 .711 r
F
.31628 1.10921 m .31503 1.11032 L .31503 1.11032 L F
.32476 1.10258 m .32389 1.10269 L .31631 1.10927 L .765 .134 .734 r
F
.32389 1.10269 m .31485 1.10378 L .31629 1.1092 L F
.32389 1.10269 m .31629 1.1092 L .31631 1.10927 L F
.32476 1.10258 m .31631 1.10927 L .31631 1.10927 L F
.59343 1.04921 m .6053 1.05661 L .60678 1.04772 L .936 .698 .808 r
F
.59343 1.04921 m .59218 1.05638 L .6053 1.05661 L F
.53735 1.06195 m .54672 1.06677 L .54941 1.06367 L .912 .754 .83 r
F
.53735 1.06195 m .53557 1.06402 L .54672 1.06677 L F
.45445 1.08362 m .45049 1.07927 L .43801 1.08287 L .841 .703 .84 r
F
.68594 1.00172 m .68669 1.04021 L .70004 1.04112 L 1 .272 .641 r
F
.67285 1.01234 m .68669 1.04021 L .68594 1.00172 L 1 .386 .675 r
F
.67285 1.01234 m .67338 1.04083 L .68669 1.04021 L F
.70004 1.04112 m .70623 1.08962 L .70889 1.04307 L .81 .145 .632 r
F
.52056 1.06402 m .52476 1.0709 L .52792 1.06945 L .909 .755 .831 r
F
.52056 1.06402 m .51897 1.06475 L .52476 1.0709 L F
.51293 .51414 m .55669 .58471 L .51292 .49803 L .159 0 .59 r
F
.51293 .51414 m .55475 .59516 L .55669 .58471 L F
.35663 1.08892 m .35243 1.08837 L .33892 1.09436 L .48 0 .729 r
F
.49688 1.07286 m .49407 1.07179 L .48457 1.07831 L .899 .747 .832 r
F
.42554 1.08607 m .42163 1.08008 L .4086 1.08237 L .772 .668 .857 r
F
.43801 1.08287 m .42163 1.08008 L .42554 1.08607 L .815 .697 .848 r
F
.66959 .99293 m .67285 1.01234 L .68594 1.00172 L 1 .805 .7 r
F
.65968 1.02039 m .67338 1.04083 L .67285 1.01234 L 1 .492 .707 r
F
.65968 1.02039 m .66007 1.04208 L .67338 1.04083 L F
.70889 1.04308 m .70748 1.09065 L .71015 1.04346 L .804 .131 .624 r
F
.70889 1.04308 m .70623 1.08962 L .70748 1.09065 L F
.41515 .91356 m .41546 .89652 L .40412 .90847 L .972 .612 .775 r
F
.41515 .91356 m .42535 .90307 L .41546 .89652 L F
.4234 .74137 m .45292 .66662 L .44919 .65825 L 1 .621 .575 r
F
.42888 .75284 m .45292 .66662 L .4234 .74137 L 1 .58 .56 r
F
.71015 1.04346 m .72092 1.10288 L .72366 1.04926 L .772 .114 .621 r
F
.71015 1.04346 m .70748 1.09065 L .72092 1.10288 L F
.522 1.0632 m .52792 1.06945 L .53081 1.0678 L .91 .755 .831 r
F
.522 1.0632 m .52056 1.06402 L .52792 1.06945 L F
.61042 .88271 m .6322 .88608 L .62021 .87126 L 1 .544 .738 r
F
.38291 .9167 m .38195 .89944 L .37094 .91235 L .974 .695 .797 r
F
.38291 .9167 m .39306 .90369 L .38195 .89944 L F
.54488 .90772 m .56149 .90134 L .55023 .89887 L .981 .681 .791 r
F
.53463 .9061 m .54488 .90772 L .55023 .89887 L .942 .679 .802 r
F
.30526 1.37802 m .26606 1.39056 L .29501 1.41224 L 1 .484 .592 r
F
.30526 1.37802 m .27778 1.35566 L .26606 1.39056 L F
.58877 .88583 m .60062 .89299 L .61042 .88271 L 1 .675 .747 r
F
.58029 .896 m .60062 .89299 L .58877 .88583 L 1 .675 .76 r
F
.64455 .75841 m .67055 .70264 L .6792 .68997 L 0 0 0 r
F
.63724 .76794 m .67055 .70264 L .64455 .75841 L F
.58008 1.05075 m .59218 1.05638 L .59343 1.04921 L .931 .728 .817 r
F
.58008 1.05075 m .57905 1.05647 L .59218 1.05638 L F
.64644 1.02651 m .66007 1.04208 L .65968 1.02039 L 1 .575 .735 r
F
.64644 1.02651 m .64676 1.04349 L .66007 1.04208 L F
.78329 .9234 m .80551 1.03641 L .79706 .93125 L .67 .043 .584 r
F
.78329 .9234 m .79126 1.02357 L .80551 1.03641 L F
.52329 1.06229 m .53081 1.0678 L .53338 1.06598 L .91 .755 .831 r
F
.52329 1.06229 m .522 1.0632 L .53081 1.0678 L F
.70748 1.09065 m .71394 1.14249 L .72092 1.10288 L .638 .075 .637 r
F
.43522 .90977 m .43724 .89347 L .42535 .90307 L .932 .554 .77 r
F
.55275 1.05718 m .56413 1.06119 L .56591 1.05677 L .916 .75 .827 r
F
.55275 1.05718 m .55143 1.06046 L .56413 1.06119 L F
.3696 1.08737 m .36588 1.08403 L .35243 1.08837 L .583 .139 .851 r
F
.38258 1.08596 m .36588 1.08403 L .3696 1.08737 L .649 .456 .885 r
F
.5387 1.05982 m .54941 1.06367 L .55143 1.06046 L .913 .754 .83 r
F
.5387 1.05982 m .53735 1.06195 L .54941 1.06367 L F
.72092 1.10288 m .71394 1.14249 L .72708 1.16156 L .62 .059 .626 r
F
.30754 1.11128 m .29064 1.134 L .29419 1.12516 L 0 0 0 r
F
.29064 1.134 m .30124 1.12305 L .28732 1.13846 L F
.30754 1.11128 m .30124 1.12305 L .29064 1.134 L F
.30514 1.11945 m .30483 1.11934 L .30124 1.12305 L .79 .084 .683 r
F
.30483 1.11934 m .29955 1.11744 L .30124 1.12305 L F
.31502 1.11032 m .31357 1.11099 L .30514 1.11945 L F
.31357 1.11099 m .29955 1.11744 L .30514 1.11945 L F
.29064 1.134 m .28732 1.13846 L .28853 1.13612 L 0 0 0 r
F
.29064 1.134 m .28853 1.13612 L .29419 1.12516 L F
.28071 1.24812 m .25144 1.23118 L .26795 1.28184 L 1 .479 .592 r
F
.28071 1.24812 m .26503 1.20119 L .25144 1.23118 L F
.63316 1.03135 m .64676 1.04349 L .64644 1.02651 L 1 .637 .759 r
F
.63316 1.03135 m .63344 1.04489 L .64676 1.04349 L F
.43801 1.08287 m .43468 1.0775 L .42163 1.08008 L .815 .697 .848 r
F
.45049 1.07927 m .43468 1.0775 L .43801 1.08287 L .846 .717 .842 r
F
.52438 1.06131 m .53338 1.06598 L .53557 1.06402 L .91 .755 .831 r
F
.52438 1.06131 m .52329 1.06229 L .53338 1.06598 L F
.54332 .66077 m .57724 .70292 L .54518 .6493 L .161 0 .647 r
F
.54332 .66077 m .57346 .70753 L .57724 .70292 L F
.72366 1.04926 m .72092 1.10288 L .73446 1.1173 L .737 .089 .612 r
F
.73702 .92727 m .74737 .88466 L .76072 .89396 L .796 0 .301 r
F
.72414 .91495 m .74737 .88466 L .73702 .92727 L .763 0 .29 r
F
.56848 .892 m .58029 .896 L .58877 .88583 L 1 .735 .768 r
F
.56149 .90134 m .58029 .896 L .56848 .892 L 1 .701 .777 r
F
.53463 .9061 m .55023 .89887 L .53826 .8975 L .942 .679 .802 r
F
.52397 .90526 m .53463 .9061 L .53826 .8975 L .893 .663 .812 r
F
.55023 .89887 m .56149 .90134 L .56848 .892 L 1 .724 .789 r
F
.56671 1.05233 m .57905 1.05647 L .58008 1.05075 L .926 .745 .823 r
F
.56671 1.05233 m .56591 1.05677 L .57905 1.05647 L F
.38258 1.08596 m .3793 1.08081 L .36588 1.08403 L .649 .456 .885 r
F
.39558 1.08433 m .3793 1.08081 L .38258 1.08596 L .715 .629 .882 r
F
.56562 .71795 m .59146 .75048 L .56597 .71746 L 0 0 .66 r
F
.56562 .71795 m .59094 .75032 L .59146 .75048 L F
.61985 1.0354 m .63344 1.04489 L .63316 1.03135 L 1 .682 .779 r
F
.61985 1.0354 m .62011 1.04629 L .63344 1.04489 L F
.51292 .49803 m .55864 .5743 L .51291 .48193 L .148 0 .585 r
F
.51292 .49803 m .55669 .58471 L .55864 .5743 L F
.59726 .87444 m .61042 .88271 L .62021 .87126 L 1 .655 .73 r
F
.58877 .88583 m .61042 .88271 L .59726 .87444 L 1 .675 .747 r
F
.65192 .75002 m .6792 .68997 L .68789 .67815 L 0 0 0 r
F
.64455 .75841 m .6792 .68997 L .65192 .75002 L F
.37094 .91235 m .3708 .89605 L .35895 .90743 L .936 .746 .821 r
F
.37094 .91235 m .38195 .89944 L .3708 .89605 L F
.52527 1.06027 m .53557 1.06402 L .53735 1.06195 L .91 .756 .831 r
F
.52527 1.06027 m .52438 1.06131 L .53557 1.06402 L F
.56597 .71746 m .59708 .75252 L .56971 .71236 L 0 0 .65 r
F
.56597 .71746 m .59147 .75048 L .59708 .75252 L F
.65669 1.00405 m .67285 1.01234 L .66959 .99293 L 1 .815 .728 r
F
.65669 1.00405 m .65968 1.02039 L .67285 1.01234 L F
.45049 1.07927 m .44774 1.07468 L .43468 1.0775 L .846 .717 .842 r
F
.46299 1.07541 m .44774 1.07468 L .45049 1.07927 L .868 .73 .838 r
F
.75579 1.43683 m .73272 1.46282 L .76689 1.47321 L .405 0 .593 r
F
.40412 .90847 m .40553 .89044 L .39306 .90369 L 1 .651 .778 r
F
.40412 .90847 m .41546 .89652 L .40553 .89044 L F
.42994 .61793 m .47158 .52769 L .46966 .51467 L 1 .656 .587 r
F
.43383 .62588 m .47158 .52769 L .42994 .61793 L 1 .658 .588 r
F
.60654 1.03893 m .62011 1.04629 L .61985 1.0354 L .996 .715 .795 r
F
.60654 1.03893 m .60678 1.04772 L .62011 1.04629 L F
.52397 .90526 m .53826 .8975 L .5258 .89683 L .893 .663 .812 r
F
.5131 .9051 m .52397 .90526 L .5258 .89683 L .852 .638 .818 r
F
.53957 1.05766 m .55143 1.06046 L .55275 1.05718 L .914 .756 .83 r
F
.53957 1.05766 m .5387 1.05982 L .55143 1.06046 L F
.39558 1.08433 m .3927 1.07826 L .3793 1.08081 L .715 .629 .882 r
F
.4086 1.08237 m .3927 1.07826 L .39558 1.08433 L .766 .693 .87 r
F
.5131 .9051 m .5258 .89683 L .51309 .89661 L .852 .638 .818 r
F
.55334 1.05392 m .56591 1.05677 L .56671 1.05233 L .921 .754 .827 r
F
.55334 1.05392 m .55275 1.05718 L .56591 1.05677 L F
.28942 1.32132 m .25512 1.31542 L .27778 1.35566 L 1 .458 .588 r
F
.28942 1.32132 m .26795 1.28185 L .25512 1.31542 L F
.72092 1.10288 m .72708 1.16156 L .73446 1.1173 L .62 .059 .626 r
F
.59321 1.04214 m .60678 1.04772 L .60654 1.03893 L .971 .737 .808 r
F
.59321 1.04214 m .59343 1.04921 L .60678 1.04772 L F
.60573 .86124 m .62021 .87126 L .62999 .8582 L 1 .607 .707 r
F
.59726 .87444 m .62021 .87126 L .60573 .86124 L 1 .655 .73 r
F
.75929 1.35732 m .73382 1.36608 L .74476 1.40113 L .423 .001 .596 r
F
.74713 1.32429 m .73382 1.36608 L .75929 1.35732 L .415 .001 .597 r
F
.52594 1.05921 m .53735 1.06195 L .5387 1.05982 L .91 .756 .831 r
F
.52594 1.05921 m .52527 1.06027 L .53735 1.06195 L F
.72708 1.16156 m .72792 1.21511 L .74033 1.18246 L .497 .019 .623 r
F
.74033 1.18246 m .72793 1.21512 L .74077 1.24179 L .499 .017 .616 r
F
.42535 .90307 m .42868 .88495 L .41546 .89652 L .96 .552 .762 r
F
.42535 .90307 m .43724 .89347 L .42868 .88495 L F
.4086 1.08237 m .40609 1.07606 L .3927 1.07826 L .766 .693 .87 r
F
.42163 1.08008 m .40609 1.07606 L .4086 1.08237 L .805 .717 .858 r
F
.51316 1.05861 m .51371 1.0662 L .51552 1.06585 L .908 .756 .832 r
F
.51316 1.05861 m .51552 1.06585 L .51728 1.06536 L F
.51316 1.05861 m .51316 1.05861 L .51552 1.06585 L F
.51316 1.05861 m .51316 1.05861 L .51371 1.0662 L F
.30124 1.12305 m .29872 1.12458 L .28732 1.13846 L .813 .05 .632 r
F
.29419 1.12516 m .27637 1.15174 L .28069 1.14213 L 0 0 0 r
F
.29419 1.12516 m .28732 1.13846 L .28683 1.13909 L F
.27616 1.15205 m .28683 1.13909 L .27325 1.15639 L F
.29419 1.12516 m .28683 1.13909 L .27616 1.15205 L F
.29881 1.12453 m .29955 1.11744 L .28542 1.13267 L .813 .05 .632 r
F
.30124 1.12305 m .30092 1.12197 L .29881 1.12453 L F
.30092 1.12197 m .29955 1.11744 L .29881 1.12453 L F
.29872 1.12458 m .28542 1.13267 L .28731 1.13844 L F
.29872 1.12458 m .28731 1.13844 L .28732 1.13846 L F
.27637 1.15174 m .27325 1.15639 L .27448 1.15404 L 0 0 0 r
F
.27637 1.15174 m .27448 1.15404 L .28069 1.14213 L F
.51316 1.05861 m .51728 1.06536 L .51897 1.06475 L .907 .755 .832 r
F
.51316 1.05861 m .51316 1.05861 L .51728 1.06536 L F
.46299 1.07541 m .4608 1.07167 L .44774 1.07468 L .868 .73 .838 r
F
.35895 .90743 m .35958 .89404 L .34697 .9015 L .807 .734 .863 r
F
.35895 .90743 m .3708 .89605 L .35958 .89404 L F
.51316 1.05861 m .51897 1.06475 L .52056 1.06402 L .907 .755 .832 r
F
.51316 1.05861 m .51316 1.05861 L .51897 1.06475 L F
.57987 1.04514 m .59343 1.04921 L .59321 1.04214 L .952 .751 .817 r
F
.57987 1.04514 m .58008 1.05075 L .59343 1.04921 L F
.61418 .8453 m .63972 .8424 L .62255 .82516 L 1 .525 .674 r
F
.61418 .8453 m .62999 .8582 L .63972 .8424 L F
.55023 .89887 m .56848 .892 L .55561 .89002 L 1 .724 .789 r
F
.53826 .8975 m .55023 .89887 L .55561 .89002 L .965 .723 .806 r
F
.57549 .88209 m .58877 .88583 L .59726 .87444 L 1 .767 .754 r
F
.56848 .892 m .58877 .88583 L .57549 .88209 L 1 .735 .768 r
F
.26367 .89382 m .26073 .97025 L .24965 .91566 L .522 0 .326 r
F
.26367 .89382 m .27441 .94486 L .26073 .97025 L F
.60573 .86124 m .62999 .8582 L .61418 .8453 L 1 .607 .707 r
F
.65933 .74251 m .68789 .67815 L .69661 .66689 L 0 0 0 r
F
.65192 .75002 m .68789 .67815 L .65933 .74251 L F
.51316 1.05861 m .52056 1.06402 L .522 1.0632 L .907 .755 .832 r
F
.51316 1.05861 m .51316 1.05861 L .52056 1.06402 L F
.64371 1.01258 m .65968 1.02039 L .65669 1.00405 L 1 .802 .751 r
F
.64371 1.01258 m .64644 1.02651 L .65968 1.02039 L F
.19294 1.0446 m .18717 .93186 L .17866 1.05587 L 1 .301 .586 r
F
.53996 1.05551 m .55275 1.05718 L .55334 1.05392 L .916 .758 .83 r
F
.53996 1.05551 m .53957 1.05766 L .55275 1.05718 L F
.4234 .74137 m .44919 .65825 L .41784 .73344 L 1 .621 .575 r
F
.41784 .73343 m .44919 .65825 L .44538 .64999 L 1 .643 .584 r
F
.42163 1.08008 m .41948 1.074 L .40609 1.07606 L .805 .717 .858 r
F
.43468 1.0775 m .41948 1.074 L .42163 1.08008 L .834 .728 .849 r
F
.52637 1.05814 m .5387 1.05982 L .53957 1.05766 L .911 .757 .831 r
F
.52637 1.05814 m .52594 1.05921 L .5387 1.05982 L F
.51316 1.05861 m .522 1.0632 L .52329 1.06229 L .906 .755 .832 r
F
.51316 1.05861 m .51316 1.05861 L .522 1.0632 L F
.56654 1.04799 m .58008 1.05075 L .57987 1.04514 L .937 .758 .823 r
F
.56654 1.04799 m .56671 1.05233 L .58008 1.05075 L F
.73446 1.1173 m .72708 1.16156 L .74033 1.18246 L .605 .047 .618 r
F
.75373 1.26985 m .73507 1.29216 L .74713 1.32429 L .443 .004 .603 r
F
.74077 1.24179 m .73507 1.29216 L .75373 1.26985 L .431 .003 .607 r
F
.79706 .93125 m .81986 1.04985 L .81089 .93925 L .66 .04 .584 r
F
.79706 .93125 m .80551 1.03641 L .81986 1.04985 L F
.55561 .89002 m .56848 .892 L .57549 .88209 L 1 .78 .785 r
F
.51316 1.05861 m .52329 1.06229 L .52438 1.06131 L .906 .755 .832 r
F
.51316 1.05861 m .51316 1.05861 L .52329 1.06229 L F
.54518 .6493 m .58111 .69843 L .54708 .63802 L .135 0 .63 r
F
.54518 .6493 m .57724 .70292 L .58111 .69843 L F
.43468 1.0775 m .43286 1.07195 L .41948 1.074 L .834 .728 .849 r
F
.44774 1.07468 m .43286 1.07195 L .43468 1.0775 L .857 .735 .843 r
F
.39306 .90369 m .39555 .88526 L .38195 .89944 L 1 .723 .787 r
F
.39306 .90369 m .40553 .89044 L .39555 .88526 L F
.34696 .9015 m .35957 .89404 L .35212 .89391 L .533 .191 .884 r
F
.51316 1.05861 m .52438 1.06131 L .52527 1.06027 L .906 .756 .832 r
F
.51316 1.05861 m .51316 1.05861 L .52438 1.06131 L F
.5532 1.05074 m .56671 1.05233 L .56654 1.04799 L .926 .761 .827 r
F
.5532 1.05074 m .55334 1.05392 L .56671 1.05233 L F
.63068 1.01959 m .64644 1.02651 L .64371 1.01258 L 1 .79 .769 r
F
.63068 1.01959 m .63316 1.03135 L .64644 1.02651 L F
.29501 1.41224 m .25426 1.42608 L .28468 1.4474 L 1 .491 .591 r
F
.29501 1.41224 m .26606 1.39056 L .25426 1.42608 L F
.52656 1.05707 m .53957 1.05766 L .53996 1.05551 L .912 .758 .831 r
F
.52656 1.05707 m .52637 1.05814 L .53957 1.05766 L F
.44774 1.07468 m .44625 1.06987 L .43286 1.07195 L .857 .735 .843 r
F
.4608 1.07167 m .44625 1.06987 L .44774 1.07468 L .874 .74 .839 r
F
.53826 .8975 m .55561 .89002 L .54191 .8893 L .965 .723 .806 r
F
.5258 .89683 m .53826 .8975 L .54191 .8893 L .88 .691 .824 r
F
.42604 .60999 m .46966 .51467 L .46773 .50139 L 1 .652 .585 r
F
.42994 .61793 m .46966 .51467 L .42604 .60999 L 1 .656 .587 r
F
.51316 1.05861 m .52527 1.06027 L .52594 1.05921 L .906 .756 .832 r
F
.51316 1.05861 m .51316 1.05861 L .52527 1.06027 L F
.58252 .87137 m .59726 .87444 L .60573 .86124 L 1 .785 .733 r
F
.57549 .88209 m .59726 .87444 L .58252 .87137 L 1 .767 .754 r
F
.53985 1.05342 m .55334 1.05392 L .5532 1.05074 L .918 .761 .83 r
F
.53985 1.05342 m .53996 1.05551 L .55334 1.05392 L F
.61763 1.02557 m .63316 1.03135 L .63068 1.01959 L 1 .784 .785 r
F
.61763 1.02557 m .61985 1.0354 L .63316 1.03135 L F
.66679 .73566 m .69661 .66689 L .70537 .65602 L 0 0 .014 r
F
.65933 .74251 m .69661 .66689 L .66679 .73566 L 0 0 0 r
F
.41546 .89652 m .4201 .87644 L .40553 .89044 L 1 .568 .755 r
F
.41546 .89652 m .42868 .88495 L .4201 .87644 L F
.4608 1.07167 m .45963 1.06772 L .44625 1.06987 L .874 .74 .839 r
F
.51316 1.05861 m .52594 1.05921 L .52637 1.05814 L .907 .756 .832 r
F
.51316 1.05861 m .51316 1.05861 L .52594 1.05921 L F
.73446 1.1173 m .74033 1.18246 L .74812 1.1337 L .605 .047 .618 r
F
.60457 1.03082 m .61985 1.0354 L .61763 1.02557 L 1 .782 .799 r
F
.60457 1.03082 m .60654 1.03893 L .61985 1.0354 L F
.52651 1.05604 m .53996 1.05551 L .53985 1.05342 L .912 .76 .831 r
F
.52651 1.05604 m .52656 1.05707 L .53996 1.05551 L F
.5258 .89683 m .54191 .8893 L .52764 .88905 L .88 .691 .824 r
F
.51309 .89661 m .5258 .89683 L .52764 .88905 L .804 .638 .835 r
F
.51316 1.05861 m .52637 1.05814 L .52656 1.05707 L .907 .757 .832 r
F
.51316 1.05861 m .51316 1.05861 L .52637 1.05814 L F
.50038 .89689 m .51308 .88876 L .49852 .88846 L .77 .592 .833 r
F
.50038 .89689 m .51309 .89661 L .51308 .88876 L F
.59657 .84641 m .62255 .82516 L .6036 .83196 L 1 .744 .665 r
F
.59657 .84641 m .61418 .8453 L .62255 .82516 L F
.75003 .94056 m .76072 .89396 L .77417 .90405 L .813 0 .307 r
F
.73702 .92727 m .76072 .89396 L .75003 .94056 L .796 0 .301 r
F
.59151 1.03553 m .60654 1.03893 L .60457 1.03082 L 1 .78 .809 r
F
.59151 1.03553 m .59321 1.04214 L .60654 1.03893 L F
.58955 .85956 m .60573 .86124 L .61418 .8453 L 1 .779 .704 r
F
.58252 .87137 m .60573 .86124 L .58955 .85956 L 1 .785 .733 r
F
.51309 .89661 m .52764 .88905 L .51308 .88876 L .804 .638 .835 r
F
.28732 1.13846 m .28446 1.1406 L .27325 1.15639 L .83 .031 .589 r
F
.28069 1.14213 m .26185 1.1721 L .26685 1.16186 L 0 0 0 r
F
.26185 1.1721 m .27325 1.1564 L .25882 1.17692 L F
.28069 1.14213 m .27325 1.1564 L .26185 1.1721 L F
.27325 1.1564 m .27325 1.1564 L .26185 1.1721 L F
.28446 1.1406 m .27321 1.15627 L .27325 1.15639 L .83 .031 .589 r
F
.28446 1.1406 m .27111 1.15053 L .27321 1.15627 L F
.26185 1.1721 m .25882 1.17692 L .26006 1.17459 L 0 0 0 r
F
.26185 1.1721 m .26006 1.17459 L .26685 1.16186 L F
.57844 1.03985 m .59321 1.04214 L .59151 1.03553 L .971 .777 .818 r
F
.57844 1.03985 m .57987 1.04514 L .59321 1.04214 L F
.51316 1.0586 m .52656 1.05707 L .52651 1.05604 L .908 .757 .832 r
F
.51316 1.0586 m .51316 1.05861 L .52656 1.05707 L F
.56537 1.04388 m .57987 1.04514 L .57844 1.03985 L .948 .773 .824 r
F
.56537 1.04388 m .56654 1.04799 L .57987 1.04514 L F
.65145 .99471 m .66959 .99293 L .66403 .98652 L 1 .989 .751 r
F
.65145 .99471 m .65669 1.00404 L .66959 .99293 L F
.55561 .89002 m .57549 .88209 L .56101 .88115 L 1 .78 .785 r
F
.54191 .8893 m .55561 .89002 L .56101 .88115 L .997 .784 .812 r
F
.56971 .71236 m .60275 .75493 L .57346 .70753 L 0 0 .623 r
F
.56971 .71236 m .59708 .75252 L .60275 .75493 L F
.56101 .88115 m .57549 .88209 L .58252 .87137 L 1 .844 .778 r
F
.55231 1.04772 m .56654 1.04799 L .56537 1.04388 L .931 .769 .827 r
F
.55231 1.04772 m .5532 1.05074 L .56654 1.04799 L F
.26795 1.28184 m .23777 1.26113 L .25512 1.31541 L 1 .471 .592 r
F
.26795 1.28184 m .25144 1.23118 L .23777 1.26113 L F
.58955 .85956 m .61418 .8453 L .59657 .84641 L 1 .779 .704 r
F
.38195 .89944 m .38551 .88155 L .3708 .89605 L 1 .828 .806 r
F
.38195 .89944 m .39555 .88526 L .38551 .88155 L F
.53925 1.05143 m .5532 1.05074 L .55231 1.04772 L .92 .765 .83 r
F
.53925 1.05143 m .53985 1.05342 L .5532 1.05074 L F
.5262 1.05505 m .53985 1.05342 L .53925 1.05143 L .913 .761 .831 r
F
.5262 1.05505 m .52651 1.05604 L .53985 1.05342 L F
.51316 1.0586 m .52651 1.05604 L .5262 1.05505 L .908 .758 .832 r
F
.51316 1.0586 m .51316 1.0586 L .52651 1.05604 L F
.51316 1.0586 m .51316 1.0586 L .5262 1.05505 L .909 .758 .832 r
F
.51316 1.0586 m .5262 1.05505 L .52569 1.05416 L F
.51316 1.0586 m .51316 1.0586 L .52569 1.05416 L F
.51316 1.0586 m .52569 1.05416 L .52496 1.05336 L F
.51316 1.0586 m .51316 1.0586 L .52496 1.05336 L .909 .757 .832 r
F
.51316 1.0586 m .52496 1.05336 L .52404 1.05264 L F
.51316 1.0586 m .51316 1.0586 L .52404 1.05264 L F
.51316 1.0586 m .52404 1.05264 L .52293 1.05202 L F
.51316 1.0586 m .51316 1.0586 L .52293 1.05202 L .908 .757 .832 r
F
.51316 1.0586 m .52293 1.05202 L .52159 1.0515 L F
.51316 1.0586 m .51316 1.0586 L .52159 1.0515 L .908 .756 .832 r
F
.51316 1.0586 m .52159 1.0515 L .5201 1.0511 L F
.51316 1.0586 m .51316 1.0586 L .5201 1.0511 L .907 .756 .832 r
F
.51316 1.0586 m .5201 1.0511 L .51848 1.05085 L F
.51316 1.0586 m .51316 1.0586 L .51848 1.05085 L .906 .756 .832 r
F
.51316 1.0586 m .51848 1.05085 L .51676 1.05073 L F
.51316 1.0586 m .51316 1.0586 L .51676 1.05073 L F
.51316 1.0586 m .51676 1.05073 L .51497 1.05076 L F
.51316 1.0586 m .51316 1.0586 L .51497 1.05076 L .905 .756 .832 r
F
.51316 1.0586 m .51497 1.05076 L .51315 1.05094 L F
.51316 1.0586 m .51316 1.0586 L .51315 1.05094 L F
.75389 1.20532 m .74077 1.24179 L .75373 1.26985 L .502 .015 .61 r
F
.74033 1.18246 m .74077 1.24179 L .75389 1.20532 L .499 .017 .616 r
F
.67429 .72932 m .70537 .65602 L .71415 .64542 L 0 0 .032 r
F
.66679 .73566 m .70537 .65602 L .67429 .72932 L 0 0 .014 r
F
.52569 1.05416 m .5262 1.05505 L .53925 1.05143 L .914 .762 .831 r
F
.54708 .63802 m .58499 .69409 L .54898 .62703 L .115 0 .616 r
F
.54708 .63802 m .58111 .69843 L .58499 .69409 L F
.74812 1.13371 m .74033 1.18246 L .75389 1.20532 L .592 .039 .611 r
F
.81089 .93925 m .8343 1.06385 L .82479 .94746 L .652 .038 .583 r
F
.81089 .93925 m .81986 1.04985 L .8343 1.06385 L F
.41214 .72751 m .44538 .64999 L .44155 .64188 L 1 .654 .588 r
F
.41784 .73343 m .44538 .64999 L .41214 .72751 L 1 .643 .584 r
F
.45963 1.06772 m .44607 1.06486 L .44625 1.06987 L .881 .75 .839 r
F
.45963 1.06772 m .45951 1.06361 L .44607 1.06486 L F
.42604 .60999 m .46773 .50139 L .42211 .60204 L 1 .652 .585 r
F
.44625 1.06987 m .43261 1.06617 L .43286 1.07195 L .869 .751 .843 r
F
.44625 1.06987 m .44607 1.06486 L .43261 1.06617 L F
.77154 1.39122 m .74476 1.40113 L .75579 1.43683 L .427 .002 .594 r
F
.75929 1.35732 m .74476 1.40113 L .77154 1.39122 L .423 .001 .596 r
F
.27778 1.35566 m .24221 1.34915 L .26606 1.39056 L 1 .465 .589 r
F
.27778 1.35566 m .25512 1.31542 L .24221 1.34915 L F
.43286 1.07195 m .41915 1.0676 L .41948 1.074 L .855 .753 .849 r
F
.43286 1.07195 m .43261 1.06617 L .41915 1.0676 L F
.40553 .89044 m .41148 .86838 L .39555 .88526 L 1 .615 .75 r
F
.40553 .89044 m .4201 .87644 L .41148 .86838 L F
.41948 1.074 m .40567 1.06925 L .40609 1.07606 L .838 .754 .856 r
F
.41948 1.074 m .41915 1.0676 L .40567 1.06925 L F
.53823 1.04966 m .53925 1.05143 L .55231 1.04772 L .922 .767 .83 r
F
.52569 1.05416 m .53925 1.05143 L .53823 1.04966 L .914 .762 .831 r
F
.40609 1.07606 m .39217 1.07128 L .3927 1.07826 L .819 .75 .864 r
F
.40609 1.07606 m .40567 1.06925 L .39217 1.07128 L F
.52496 1.05336 m .52569 1.05416 L .53823 1.04966 L .914 .762 .831 r
F
.63888 1.00291 m .65669 1.00404 L .65145 .99471 L 1 .939 .769 r
F
.63888 1.00291 m .6437 1.01258 L .65669 1.00404 L F
.3927 1.07826 m .37864 1.07391 L .3793 1.08081 L .799 .729 .87 r
F
.3927 1.07826 m .39217 1.07128 L .37864 1.07391 L F
.3793 1.08081 m .36508 1.07744 L .36588 1.08403 L .778 .669 .871 r
F
.3793 1.08081 m .37864 1.07391 L .36508 1.07744 L F
.55079 1.04504 m .55231 1.04772 L .56537 1.04388 L .935 .775 .828 r
F
.53823 1.04966 m .55231 1.04772 L .55079 1.04504 L .922 .767 .83 r
F
.52496 1.05336 m .53823 1.04966 L .53679 1.04804 L .914 .762 .831 r
F
.52404 1.05264 m .52496 1.05336 L .53679 1.04804 L F
.54191 .8893 m .56101 .88115 L .54558 .88168 L .997 .784 .812 r
F
.52764 .88905 m .54191 .8893 L .54558 .88168 L .855 .721 .84 r
F
.36588 1.08403 m .35146 1.08221 L .35243 1.08837 L .759 .551 .859 r
F
.36588 1.08403 m .36508 1.07744 L .35146 1.08221 L F
.74812 1.13371 m .75389 1.20532 L .7621 1.15213 L .592 .039 .611 r
F
.56336 1.04027 m .56537 1.04388 L .57844 1.03985 L .955 .786 .824 r
F
.55079 1.04504 m .56537 1.04388 L .56336 1.04027 L .935 .775 .828 r
F
.7668 1.29914 m .74713 1.32429 L .75929 1.35732 L .451 .004 .6 r
F
.75373 1.26985 m .74713 1.32429 L .7668 1.29914 L .443 .004 .603 r
F
.6263 1.01061 m .6437 1.01258 L .63888 1.00291 L 1 .89 .782 r
F
.6263 1.01061 m .63068 1.01959 L .6437 1.01258 L F
.53679 1.04804 m .53823 1.04966 L .55079 1.04504 L .923 .769 .83 r
F
.52404 1.05264 m .53679 1.04804 L .53494 1.04661 L .914 .762 .831 r
F
.52293 1.05202 m .52404 1.05264 L .53494 1.04661 L .913 .762 .831 r
F
.56643 .87227 m .58252 .87137 L .58955 .85956 L 1 .909 .766 r
F
.56101 .88115 m .58252 .87137 L .56643 .87227 L 1 .844 .778 r
F
.68588 .9051 m .69917 .89581 L .71158 .90426 L .687 0 .075 r
F
.57594 1.03525 m .57844 1.03985 L .59151 1.03553 L .984 .799 .819 r
F
.56336 1.04027 m .57844 1.03985 L .57594 1.03525 L .955 .786 .824 r
F
.68184 .7234 m .71415 .64542 L .72297 .63501 L 0 0 .048 r
F
.67429 .72932 m .71415 .64542 L .68184 .7234 L 0 0 .032 r
F
.58853 1.02989 m .59151 1.03553 L .60457 1.03082 L 1 .816 .812 r
F
.57594 1.03525 m .59151 1.03553 L .58853 1.02989 L .984 .799 .819 r
F
.35243 1.08837 m .35146 1.08221 L .33777 1.0886 L .749 .387 .829 r
F
.61371 1.01766 m .63068 1.01959 L .6263 1.01061 L 1 .858 .793 r
F
.61371 1.01766 m .61763 1.02557 L .63068 1.01959 L F
.3708 .89605 m .37538 .87995 L .35958 .89404 L 1 .904 .834 r
F
.3708 .89605 m .38551 .88155 L .37538 .87995 L F
.52293 1.05202 m .53494 1.04661 L .53273 1.04539 L .913 .762 .831 r
F
.52159 1.0515 m .52293 1.05202 L .53273 1.04539 L .911 .761 .832 r
F
.28468 1.4474 m .24235 1.46229 L .27427 1.48346 L 1 .496 .59 r
F
.28468 1.4474 m .25426 1.42608 L .24235 1.46229 L F
.60112 1.02406 m .60457 1.03082 L .61763 1.02557 L 1 .835 .803 r
F
.58853 1.02989 m .60457 1.03082 L .60112 1.02406 L 1 .816 .812 r
F
.60112 1.02406 m .61763 1.02557 L .61371 1.01766 L 1 .835 .803 r
F
.49852 .88846 m .51307 .88187 L .49665 .88046 L .667 .525 .857 r
F
.49852 .88846 m .51308 .88876 L .51307 .88187 L F
.54558 .88168 m .56101 .88115 L .56643 .87227 L 1 .859 .818 r
F
.52159 1.0515 m .53273 1.04539 L .53005 1.04435 L .911 .761 .832 r
F
.5201 1.0511 m .52159 1.0515 L .53005 1.04435 L .91 .76 .832 r
F
.45951 1.06361 m .4472 1.05969 L .44607 1.06486 L .888 .759 .839 r
F
.45951 1.06361 m .46043 1.05939 L .4472 1.05969 L F
.52764 .88905 m .54558 .88168 L .52949 .88225 L .855 .721 .84 r
F
.51308 .88876 m .52764 .88905 L .52949 .88225 L .724 .607 .858 r
F
.54863 1.04262 m .55079 1.04504 L .56336 1.04027 L .936 .779 .828 r
F
.53679 1.04804 m .55079 1.04504 L .54863 1.04262 L .923 .769 .83 r
F
.53494 1.04661 m .53679 1.04804 L .54863 1.04262 L .922 .769 .831 r
F
.27325 1.1564 m .27048 1.15883 L .25882 1.17692 L .84 .017 .552 r
F
.26685 1.16186 m .24711 1.1947 L .25287 1.18358 L 0 0 0 r
F
.26685 1.16186 m .25882 1.17692 L .25589 1.18144 L F
.24616 1.19628 m .25589 1.18144 L .24422 1.19951 L F
.26685 1.16186 m .25589 1.18144 L .24616 1.19628 L F
.27105 1.15833 m .27111 1.15053 L .25641 1.1712 L .84 .017 .552 r
F
.27325 1.1564 m .27291 1.15548 L .27105 1.15833 L F
.27291 1.15548 m .27111 1.15053 L .27105 1.15833 L F
.27048 1.15883 m .25641 1.1712 L .25877 1.17681 L F
.27048 1.15883 m .25877 1.17681 L .25882 1.17692 L F
.24711 1.1947 m .24422 1.19951 L .24544 1.19726 L 0 0 0 r
F
.24711 1.1947 m .24544 1.19726 L .25287 1.18358 L F
.5201 1.0511 m .53005 1.04435 L .52707 1.04357 L .91 .76 .832 r
F
.51848 1.05085 m .5201 1.0511 L .52707 1.04357 L .908 .759 .832 r
F
.51308 .88876 m .52949 .88225 L .51307 .88187 L .724 .607 .858 r
F
.79126 1.02357 m .80816 1.13292 L .80551 1.03641 L .658 .043 .588 r
F
.51848 1.05085 m .52707 1.04357 L .52382 1.04308 L .908 .759 .832 r
F
.51676 1.05073 m .51848 1.05085 L .52382 1.04308 L .906 .759 .833 r
F
.33892 1.09436 m .33777 1.0886 L .324 1.09699 L .754 .232 .782 r
F
.44607 1.06486 m .43394 1.06013 L .43261 1.06617 L .881 .764 .842 r
F
.44607 1.06486 m .4472 1.05969 L .43394 1.06013 L F
.39555 .88526 m .40282 .86138 L .38551 .88155 L 1 .703 .75 r
F
.39555 .88526 m .41148 .86838 L .40282 .86138 L F
.51676 1.05073 m .52382 1.04308 L .52037 1.04286 L .906 .759 .833 r
F
.51497 1.05076 m .51676 1.05073 L .52037 1.04286 L .905 .758 .833 r
F
.56049 1.03704 m .56336 1.04027 L .57594 1.03525 L .957 .794 .826 r
F
.54863 1.04262 m .56336 1.04027 L .56049 1.03704 L .936 .779 .828 r
F
.54898 .62703 m .5889 .68986 L .55089 .61627 L .099 0 .605 r
F
.54898 .62703 m .58499 .69409 L .5889 .68986 L F
.53494 1.04661 m .54863 1.04262 L .54587 1.04049 L .922 .769 .831 r
F
.53273 1.04539 m .53494 1.04661 L .54587 1.04049 L .919 .768 .831 r
F
.51497 1.05076 m .52037 1.04286 L .51679 1.04293 L .905 .758 .833 r
F
.51315 1.05094 m .51497 1.05076 L .51679 1.04293 L .904 .758 .833 r
F
.76316 .95452 m .77417 .90405 L .78772 .91463 L .823 0 .311 r
F
.75003 .94056 m .77417 .90405 L .76316 .95452 L .813 0 .307 r
F
.51315 1.05094 m .51679 1.04293 L .51314 1.04328 L .904 .758 .833 r
F
.57187 .86336 m .58955 .85956 L .59657 .84641 L 1 .958 .749 r
F
.56643 .87227 m .58955 .85956 L .57187 .86336 L 1 .909 .766 r
F
.82479 .94746 m .84884 1.07835 L .83876 .95589 L .645 .036 .583 r
F
.82479 .94746 m .8343 1.06385 L .84884 1.07835 L F
.43261 1.06617 m .42067 1.06077 L .41915 1.0676 L .874 .771 .847 r
F
.43261 1.06617 m .43394 1.06013 L .42067 1.06077 L F
.24965 .91566 m .24702 .99298 L .23559 .93549 L .554 0 .324 r
F
.24965 .91566 m .26073 .97025 L .24702 .99298 L F
.57346 .70753 m .60846 .75751 L .57724 .70292 L 0 0 .605 r
F
.57346 .70753 m .60275 .75493 L .60846 .75751 L F
.54587 1.04049 m .54863 1.04262 L .56049 1.03704 L .934 .78 .829 r
F
.68184 .7234 m .72297 .63501 L .68944 .7178 L 0 0 .048 r
F
.40638 .72293 m .44155 .64188 L .4377 .63386 L 1 .657 .59 r
F
.41214 .72751 m .44155 .64188 L .40638 .72293 L 1 .654 .588 r
F
.57237 1.03122 m .57594 1.03525 L .58853 1.02989 L .987 .814 .822 r
F
.56049 1.03704 m .57594 1.03525 L .57237 1.03122 L .957 .794 .826 r
F
.75389 1.20532 m .75373 1.26985 L .76757 1.22965 L .502 .015 .61 r
F
.7621 1.15213 m .75389 1.20532 L .76757 1.22965 L .581 .033 .606 r
F
.53273 1.04539 m .54587 1.04049 L .54255 1.03869 L .919 .768 .831 r
F
.53005 1.04435 m .53273 1.04539 L .54255 1.03869 L .916 .767 .832 r
F
.76757 1.22965 m .75373 1.26985 L .7668 1.29914 L .504 .014 .605 r
F
.41915 1.0676 m .40736 1.06168 L .40567 1.06925 L .868 .779 .852 r
F
.41915 1.0676 m .42067 1.06077 L .40736 1.06168 L F
.46043 1.05939 m .44963 1.05441 L .4472 1.05969 L .894 .764 .838 r
F
.46043 1.05939 m .46239 1.05511 L .44963 1.05441 L F
.32533 1.10251 m .32399 1.09699 L .31485 1.10378 L .765 .134 .734 r
F
.58427 1.02506 m .58853 1.02989 L .60112 1.02406 L 1 .839 .817 r
F
.57237 1.03122 m .58853 1.02989 L .58427 1.02506 L .987 .814 .822 r
F
.25512 1.31541 m .22401 1.29125 L .24221 1.34914 L 1 .465 .591 r
F
.25512 1.31541 m .23777 1.26113 L .22401 1.29125 L F
.19181 1.15055 m .19294 1.0446 L .17866 1.05587 L 1 .35 .591 r
F
.20625 1.13246 m .19294 1.0446 L .19181 1.15055 L 1 .353 .594 r
F
.35957 .89404 m .36864 .88036 L .35212 .89391 L .848 .686 .849 r
F
.35957 .89404 m .37538 .87995 L .36864 .88036 L F
.54558 .88168 m .56643 .87227 L .54927 .87482 L 1 .859 .818 r
F
.52949 .88225 m .54558 .88168 L .54927 .87482 L .81 .73 .861 r
F
.7621 1.15213 m .76757 1.22965 L .7762 1.1721 L .581 .033 .606 r
F
.53005 1.04435 m .54255 1.03869 L .53854 1.03717 L .916 .767 .832 r
F
.52707 1.04357 m .53005 1.04435 L .53854 1.03717 L .911 .765 .833 r
F
.55682 1.03424 m .56049 1.03704 L .57237 1.03122 L .953 .797 .828 r
F
.54587 1.04049 m .56049 1.03704 L .55682 1.03424 L .934 .78 .829 r
F
.57733 .85449 m .59657 .84641 L .6036 .83196 L 1 .971 .729 r
F
.57187 .86336 m .59657 .84641 L .57733 .85449 L 1 .958 .749 r
F
.54255 1.03869 m .54587 1.04049 L .55682 1.03424 L .929 .779 .831 r
F
.40567 1.06925 m .39403 1.06297 L .39217 1.07128 L .865 .788 .855 r
F
.40567 1.06925 m .40736 1.06168 L .39403 1.06297 L F
.7839 1.42597 m .75579 1.43683 L .76689 1.47321 L .43 .002 .593 r
F
.77154 1.39122 m .75579 1.43683 L .7839 1.42597 L .427 .002 .594 r
F
.59617 1.01846 m .60112 1.02406 L .61371 1.01766 L 1 .866 .81 r
F
.58427 1.02506 m .60112 1.02406 L .59617 1.01846 L 1 .839 .817 r
F
.54927 .87482 m .56643 .87227 L .57187 .86336 L 1 .929 .822 r
F
.26606 1.39056 m .22921 1.38323 L .25426 1.42608 L 1 .469 .589 r
F
.26606 1.39056 m .24221 1.34915 L .22921 1.38323 L F
.52707 1.04357 m .53854 1.03717 L .53406 1.03605 L .911 .765 .833 r
F
.52382 1.04308 m .52707 1.04357 L .53406 1.03605 L .907 .762 .834 r
F
.60809 1.01133 m .61371 1.01766 L .6263 1.01061 L 1 .894 .803 r
F
.59617 1.01846 m .61371 1.01766 L .60809 1.01133 L 1 .866 .81 r
F
.31631 1.10927 m .31485 1.10378 L .31355 1.10483 L .771 .102 .711 r
F
.49665 .88046 m .51306 .87643 L .49477 .87316 L .516 .341 .885 r
F
.49665 .88046 m .51307 .88187 L .51306 .87643 L F
.62001 1.00364 m .6263 1.01061 L .63888 1.00291 L 1 .921 .797 r
F
.60809 1.01133 m .6263 1.01061 L .62001 1.00364 L 1 .894 .803 r
F
.39217 1.07128 m .38066 1.06474 L .37864 1.07391 L .872 .8 .857 r
F
.39217 1.07128 m .39403 1.06297 L .38066 1.06474 L F
.65582 .97997 m .66403 .98652 L .67663 .97977 L .988 .891 .84 r
F
.64386 .98731 m .66403 .98652 L .65582 .97997 L 1 .962 .803 r
F
.64386 .98731 m .65145 .99471 L .66403 .98652 L F
.63193 .99551 m .65145 .99471 L .64386 .98731 L 1 .945 .795 r
F
.63193 .99551 m .63888 1.00291 L .65145 .99471 L F
.62001 1.00364 m .63888 1.00291 L .63193 .99551 L 1 .921 .797 r
F
.31502 1.11032 m .31354 1.10483 L .29955 1.11744 L .79 .084 .683 r
F
.38551 .88155 m .3941 .85612 L .37538 .87995 L 1 .829 .754 r
F
.38551 .88155 m .40282 .86138 L .3941 .85612 L F
.52382 1.04308 m .53406 1.03605 L .52918 1.03532 L .907 .762 .834 r
F
.52037 1.04286 m .52382 1.04308 L .52918 1.03532 L .903 .761 .834 r
F
.77999 1.32954 m .75929 1.35732 L .77154 1.39122 L .457 .005 .598 r
F
.7668 1.29914 m .75929 1.35732 L .77999 1.32954 L .451 .004 .6 r
F
.5678 1.02781 m .57237 1.03122 L .58427 1.02506 L .98 .821 .826 r
F
.55682 1.03424 m .57237 1.03122 L .5678 1.02781 L .953 .797 .828 r
F
.54255 1.03869 m .55682 1.03424 L .55241 1.03191 L .929 .779 .831 r
F
.53854 1.03717 m .54255 1.03869 L .5524 1.03191 L .921 .775 .832 r
F
.52949 .88225 m .54927 .87482 L .53135 .87679 L .81 .73 .861 r
F
.51307 .88187 m .52949 .88225 L .53135 .87679 L .604 .483 .887 r
F
.58281 .84583 m .6036 .83196 L .61062 .81673 L 1 .89 .706 r
F
.57733 .85449 m .6036 .83196 L .58281 .84583 L 1 .971 .729 r
F
.46239 1.05511 m .45331 1.04909 L .44963 1.05441 L .9 .767 .837 r
F
.46239 1.05511 m .46535 1.05085 L .45331 1.04909 L F
.65582 .97997 m .67663 .97977 L .66786 .97514 L .988 .891 .84 r
F
.69781 .92493 m .71158 .90426 L .72414 .91495 L .788 0 .219 r
F
.68588 .9051 m .71158 .90426 L .69781 .92493 L .687 0 .075 r
F
.55089 .61627 m .59283 .68571 L .55282 .60566 L .087 0 .595 r
F
.55089 .61627 m .5889 .68986 L .59283 .68571 L F
.80551 1.03641 m .82272 1.15156 L .81986 1.04985 L .644 .038 .587 r
F
.80551 1.03641 m .80816 1.13292 L .82272 1.15156 L F
.25882 1.17692 m .25653 1.1792 L .24422 1.19951 L .843 .008 .52 r
F
.25287 1.18358 m .23221 1.21919 L .23877 1.20692 L 0 0 0 r
F
.25287 1.18358 m .24422 1.19951 L .22946 1.22392 L F
.25653 1.1792 m .24153 1.19419 L .2442 1.19947 L .843 .008 .52 r
F
.25653 1.1792 m .2442 1.19947 L .24422 1.19951 L F
.23221 1.21919 m .22946 1.22392 L .23064 1.22177 L 0 0 0 r
F
.23221 1.21919 m .23064 1.22177 L .23877 1.20692 L F
.52037 1.04286 m .52918 1.03532 L .524 1.03501 L .903 .761 .834 r
F
.51679 1.04293 m .52037 1.04286 L .524 1.03501 L .901 .76 .835 r
F
.51307 .88187 m .53135 .87679 L .51306 .87643 L .604 .483 .887 r
F
.55241 1.03191 m .55682 1.03424 L .5678 1.02781 L .943 .795 .831 r
F
.43394 1.06013 m .42401 1.05355 L .42067 1.06077 L .892 .782 .844 r
F
.35212 .89391 m .36768 .88053 L .35106 .89399 L .729 .381 .838 r
F
.35212 .89391 m .36864 .88036 L .36768 .88053 L F
.51679 1.04293 m .524 1.03501 L .51862 1.03511 L .901 .76 .835 r
F
.51314 1.04328 m .51679 1.04293 L .51862 1.03511 L .901 .759 .835 r
F
.37864 1.07391 m .36726 1.06712 L .36508 1.07744 L .895 .822 .855 r
F
.37864 1.07391 m .38066 1.06474 L .36726 1.06712 L F
.51314 1.04328 m .51862 1.03511 L .51313 1.03563 L .901 .759 .835 r
F
.35106 .89399 m .35734 .88416 L .33962 .8972 L .665 .081 .779 r
F
.35106 .89399 m .36768 .88053 L .35734 .88416 L F
.58281 .84583 m .61062 .81673 L .58833 .83765 L 1 .89 .706 r
F
.57879 1.02111 m .58427 1.02506 L .59617 1.01846 L 1 .85 .823 r
F
.5678 1.02781 m .58427 1.02506 L .57879 1.02111 L .98 .821 .826 r
F
.53854 1.03717 m .5524 1.03191 L .54706 1.02998 L .921 .775 .832 r
F
.53406 1.03605 m .53854 1.03717 L .54706 1.02998 L .91 .77 .834 r
F
.40058 .71925 m .4377 .63386 L .43383 .62589 L 1 .655 .589 r
F
.40638 .72293 m .4377 .63386 L .40058 .71925 L 1 .657 .59 r
F
.19181 1.15055 m .17866 1.05587 L .17727 1.16921 L 1 .35 .591 r
F
.77642 .96901 m .78772 .91463 L .80137 .92558 L .829 0 .314 r
F
.76316 .95452 m .78772 .91463 L .77642 .96901 L .823 0 .311 r
F
.42067 1.06077 m .41116 1.05346 L .40736 1.06168 L .893 .792 .846 r
F
.42067 1.06077 m .42401 1.05355 L .41116 1.05346 L F
.76757 1.22965 m .7668 1.29914 L .78137 1.25529 L .504 .014 .605 r
F
.7762 1.1721 m .76757 1.22965 L .78137 1.25529 L .573 .028 .602 r
F
.36508 1.07744 m .3538 1.0703 L .35146 1.08221 L .945 .859 .847 r
F
.36508 1.07744 m .36726 1.06712 L .3538 1.0703 L F
.57724 .70292 m .6143 .76019 L .58111 .69843 L 0 0 .592 r
F
.57724 .70292 m .60846 .75751 L .6143 .76019 L F
.4346 .78631 m .45909 .82782 L .43405 .78802 L .947 .009 .379 r
F
.4346 .78631 m .45948 .82458 L .45909 .82782 L F
.55298 .8689 m .57187 .86336 L .57733 .85449 L 1 .931 .82 r
F
.54927 .87482 m .57187 .86336 L .55298 .8689 L 1 .929 .822 r
F
.58981 1.01407 m .59617 1.01846 L .60809 1.01133 L 1 .882 .819 r
F
.57879 1.02111 m .59617 1.01846 L .58981 1.01407 L 1 .85 .823 r
F
.55241 1.03191 m .5678 1.02781 L .56228 1.02504 L .943 .795 .831 r
F
.54706 1.02998 m .5524 1.03191 L .56228 1.02504 L .927 .789 .834 r
F
.53406 1.03605 m .54706 1.02998 L .54108 1.02857 L .91 .77 .834 r
F
.52918 1.03532 m .53406 1.03605 L .54108 1.02857 L .901 .765 .836 r
F
.56228 1.02504 m .5678 1.02781 L .57879 1.02111 L .962 .818 .83 r
F
.53135 .87679 m .54927 .87482 L .55298 .8689 L .734 .646 .879 r
F
.7762 1.1721 m .78137 1.25529 L .79041 1.19342 L .573 .028 .602 r
F
.78137 1.25529 m .7668 1.29914 L .77999 1.32954 L .505 .013 .601 r
F
.43405 .78802 m .45909 .82783 L .45501 .85084 L 1 .008 .336 r
F
.52918 1.03532 m .54108 1.02857 L .53457 1.02766 L .901 .765 .836 r
F
.524 1.03501 m .52918 1.03532 L .53457 1.02766 L .894 .76 .837 r
F
.60084 1.00658 m .60809 1.01133 L .62001 1.00364 L 1 .912 .814 r
F
.58981 1.01407 m .60809 1.01133 L .60084 1.00658 L 1 .882 .819 r
F
.40736 1.06168 m .39827 1.05361 L .39403 1.06297 L .899 .804 .847 r
F
.40736 1.06168 m .41116 1.05346 L .39827 1.05361 L F
.37538 .87995 m .3883 .85388 L .36864 .88036 L 1 .934 .753 r
F
.37538 .87995 m .39409 .85612 L .3883 .85388 L F
.35146 1.08221 m .34029 1.07451 L .33777 1.0886 L 1 .911 .832 r
F
.35146 1.08221 m .3538 1.0703 L .34029 1.07451 L F
.55282 .60566 m .59679 .68163 L .55475 .59516 L .076 0 .587 r
F
.55282 .60566 m .59283 .68571 L .59679 .68163 L F
.49477 .87316 m .51304 .87315 L .49288 .86712 L .288 .03 .876 r
F
.49477 .87316 m .51306 .87643 L .51304 .87315 L F
.24221 1.34914 m .21015 1.32168 L .2292 1.38322 L 1 .46 .59 r
F
.24221 1.34914 m .22401 1.29125 L .21015 1.32168 L F
.7839 1.42597 m .76689 1.47321 L .79637 1.46158 L .43 .002 .593 r
F
.524 1.03501 m .53457 1.02766 L .52765 1.02725 L .894 .76 .837 r
F
.51862 1.03511 m .524 1.03501 L .52765 1.02725 L .891 .757 .837 r
F
.54706 1.02998 m .56228 1.02504 L .55561 1.02281 L .927 .789 .834 r
F
.54108 1.02857 m .54706 1.02998 L .55561 1.02281 L .908 .778 .837 r
F
.57219 1.01805 m .57879 1.02111 L .58981 1.01407 L .987 .848 .83 r
F
.56228 1.02504 m .57879 1.02111 L .57219 1.01805 L .962 .818 .83 r
F
.61188 .99853 m .62001 1.00364 L .63193 .99551 L 1 .933 .81 r
F
.60084 1.00658 m .62001 1.00364 L .61188 .99853 L 1 .912 .814 r
F
.81986 1.04985 m .8374 1.17102 L .8343 1.06385 L .632 .035 .586 r
F
.81986 1.04985 m .82272 1.15156 L .8374 1.17102 L F
.25426 1.42608 m .2161 1.41778 L .24235 1.46229 L 1 .47 .589 r
F
.25426 1.42608 m .22921 1.38323 L .2161 1.41778 L F
.51862 1.03511 m .52765 1.02725 L .52045 1.02735 L .891 .757 .837 r
F
.51313 1.03563 m .51862 1.03511 L .52045 1.02735 L .892 .756 .837 r
F
.23559 .93549 m .23323 1.01451 L .22147 .95395 L .568 0 .321 r
F
.23559 .93549 m .24702 .99298 L .23323 1.01451 L F
.53135 .87679 m .55298 .8689 L .53323 .87308 L .734 .646 .879 r
F
.51306 .87643 m .53135 .87679 L .53323 .87308 L .464 .179 .898 r
F
.55561 1.02281 m .56228 1.02504 L .57219 1.01805 L .936 .807 .836 r
F
.51313 1.03563 m .52045 1.02735 L .51312 1.02798 L .892 .756 .837 r
F
.62293 .9898 m .63193 .99551 L .64386 .98731 L 1 .934 .809 r
F
.61188 .99853 m .63193 .99551 L .62293 .9898 L 1 .933 .81 r
F
.39403 1.06297 m .38535 1.05395 L .38066 1.06474 L .915 .818 .846 r
F
.39403 1.06297 m .39827 1.05361 L .38535 1.05395 L F
.23877 1.20692 m .21715 1.2453 L .22452 1.2316 L 0 0 0 r
F
.21715 1.2453 m .22946 1.22392 L .21454 1.24995 L F
.23877 1.20692 m .22946 1.22392 L .21715 1.2453 L F
.23069 1.22189 m .23065 1.22187 L .22946 1.22392 L .84 .002 .492 r
F
.23065 1.22187 m .22645 1.21927 L .22946 1.22392 L F
.24422 1.19951 m .24257 1.20134 L .23069 1.22189 L F
.24257 1.20134 m .22645 1.21927 L .23069 1.22189 L F
.21715 1.2453 m .21454 1.24995 L .21567 1.24786 L 0 0 0 r
F
.21715 1.2453 m .21567 1.24786 L .22452 1.2316 L F
.51306 .87643 m .53323 .87308 L .51304 .87315 L .464 .179 .898 r
F
.79329 1.36099 m .77154 1.39122 L .7839 1.42597 L .461 .005 .596 r
F
.77999 1.32954 m .77154 1.39122 L .79329 1.36099 L .457 .005 .598 r
F
.34685 .89131 m .36051 .85788 L .33922 .89638 L 1 .727 .697 r
F
.33962 .8972 m .35474 .88607 L .34685 .89131 L .449 0 .552 r
F
.32794 .90661 m .34685 .89131 L .33618 .90186 L 0 0 0 r
F
.34685 .89131 m .33922 .89638 L .33618 .90186 L 1 .727 .697 r
F
.35474 .88607 m .35734 .88416 L .34685 .89131 L .449 0 .552 r
F
.55298 .8689 m .57733 .85449 L .55672 .86408 L 1 .931 .82 r
F
.39473 .71618 m .43383 .62589 L .42994 .61795 L 1 .65 .588 r
F
.40058 .71925 m .43383 .62589 L .39473 .71618 L 1 .655 .589 r
F
.54108 1.02857 m .55561 1.02281 L .54812 1.0212 L .908 .778 .837 r
F
.53457 1.02766 m .54108 1.02857 L .54812 1.0212 L .889 .766 .84 r
F
.63398 .98024 m .64386 .98731 L .65582 .97997 L 1 .887 .815 r
F
.62293 .9898 m .64386 .98731 L .63398 .98024 L 1 .934 .809 r
F
.42401 1.05355 m .41699 1.04489 L .41116 1.05346 L .913 .8 .841 r
F
.42401 1.05355 m .42914 1.0461 L .41699 1.04489 L F
.33777 1.0886 m .3267 1.08009 L .324 1.09699 L 1 .961 .808 r
F
.33777 1.0886 m .34029 1.07451 L .3267 1.08009 L F
.58212 1.01087 m .58981 1.01407 L .60084 1.00658 L 1 .882 .828 r
F
.57219 1.01805 m .58981 1.01407 L .58212 1.01087 L .987 .848 .83 r
F
.69781 .92493 m .72414 .91495 L .70983 .9439 L .788 0 .219 r
F
.70984 .9439 m .72414 .91495 L .73702 .92727 L .822 0 .267 r
F
.19758 1.24357 m .19181 1.15055 L .17727 1.16921 L 1 .399 .593 r
F
.76757 1.1164 m .76675 1.12406 L .78154 1.15129 L 0 0 .465 r
F
.28732 1.13846 m .28542 1.13267 L .27111 1.15053 L .83 .031 .589 r
F
.64502 .9697 m .65582 .97997 L .66786 .97514 L .883 .688 .822 r
F
.63398 .98024 m .65582 .97997 L .64502 .9697 L 1 .887 .815 r
F
.38066 1.06474 m .37239 1.05439 L .36726 1.06712 L .946 .836 .839 r
F
.38066 1.06474 m .38535 1.05395 L .37239 1.05439 L F
.78137 1.25529 m .77999 1.32954 L .79529 1.28213 L .505 .013 .601 r
F
.79041 1.19342 m .78137 1.25529 L .79529 1.28213 L .565 .025 .599 r
F
.53323 .87308 m .55298 .8689 L .55672 .86408 L .637 .349 .874 r
F
.53457 1.02766 m .54812 1.0212 L .53997 1.02016 L .889 .766 .84 r
F
.52765 1.02725 m .53457 1.02766 L .53997 1.02016 L .876 .755 .842 r
F
.55561 1.02281 m .57219 1.01805 L .56418 1.01569 L .936 .807 .836 r
F
.54812 1.0212 m .55561 1.02281 L .56418 1.01569 L .901 .787 .842 r
F
.56418 1.01569 m .57219 1.01805 L .58212 1.01087 L .947 .831 .838 r
F
.79041 1.19342 m .79529 1.28213 L .80475 1.21592 L .565 .025 .599 r
F
.58111 .69843 m .62019 .76288 L .58499 .69409 L 0 0 .582 r
F
.58111 .69843 m .6143 .76019 L .62019 .76288 L F
.78979 .98393 m .80137 .92558 L .81511 .9368 L .833 0 .317 r
F
.77642 .96901 m .80137 .92558 L .78979 .98393 L .829 0 .314 r
F
.55475 .59516 m .60078 .6776 L .55669 .58471 L .068 0 .581 r
F
.55475 .59516 m .59679 .68163 L .60078 .6776 L F
.59207 1.00342 m .60084 1.00658 L .61188 .99853 L 1 .916 .825 r
F
.58212 1.01087 m .60084 1.00658 L .59207 1.00342 L 1 .882 .828 r
F
.41116 1.05346 m .40481 1.04384 L .39827 1.05361 L .921 .81 .841 r
F
.41116 1.05346 m .41699 1.04489 L .40481 1.04384 L F
.79529 1.28213 m .77999 1.32954 L .79329 1.36099 L .506 .012 .598 r
F
.52765 1.02725 m .53997 1.02016 L .53131 1.01965 L .876 .755 .842 r
F
.52045 1.02735 m .52765 1.02725 L .53131 1.01965 L .872 .749 .842 r
F
.49288 .86712 m .51303 .87288 L .49097 .86369 L 0 0 .639 r
F
.48935 .86559 m .51302 .87644 L .48902 .86598 L .546 0 0 r
F
.49097 .86369 m .49991 .86886 L .48935 .86559 L F
.49288 .86712 m .51304 .87315 L .51304 .87292 L 0 0 .639 r
F
.49288 .86712 m .51304 .87292 L .51166 .87249 L F
.49991 .86886 m .51302 .87644 L .48935 .86559 L .546 0 0 r
F
.51166 .87249 m .51304 .87292 L .51303 .87288 L 0 0 .639 r
F
.65606 .95832 m .66786 .97514 L .68004 .97499 L .566 .262 .796 r
F
.64502 .9697 m .66786 .97514 L .65606 .95832 L .883 .688 .822 r
F
.32399 1.09699 m .31768 1.08476 L .31485 1.10378 L 1 .987 .781 r
F
.32399 1.09699 m .32669 1.08009 L .31768 1.08476 L F
.36726 1.06712 m .3594 1.05478 L .3538 1.0703 L .997 .848 .827 r
F
.36726 1.06712 m .37239 1.05439 L .3594 1.05478 L F
.52045 1.02735 m .53131 1.01965 L .5223 1.01969 L .872 .749 .842 r
F
.51312 1.02798 m .52045 1.02735 L .5223 1.01969 L .876 .747 .84 r
F
.8343 1.06385 m .85219 1.19123 L .84884 1.07835 L .624 .032 .585 r
F
.8343 1.06385 m .8374 1.17102 L .85219 1.19123 L F
.54812 1.0212 m .56418 1.01569 L .5552 1.01405 L .901 .787 .842 r
F
.53997 1.02016 m .54812 1.0212 L .5552 1.01405 L .868 .762 .847 r
F
.60204 .99554 m .61188 .99853 L .62293 .9898 L 1 .947 .818 r
F
.59207 1.00342 m .61188 .99853 L .60204 .99554 L 1 .916 .825 r
F
.51312 1.02798 m .5223 1.01969 L .51311 1.02034 L .876 .747 .84 r
F
.42914 1.04609 m .42453 1.03648 L .41699 1.04489 L .932 .805 .837 r
F
.42914 1.04609 m .43574 1.03879 L .42453 1.03648 L F
.31858 .71363 m .34227 .78266 L .30955 .70715 L 1 0 .162 r
F
.57278 1.00863 m .58212 1.01087 L .59207 1.00342 L .963 .859 .84 r
F
.56418 1.01569 m .58212 1.01087 L .57278 1.00863 L .947 .831 .838 r
F
.38884 .71355 m .42994 .61795 L .42603 .61001 L 1 .645 .586 r
F
.39473 .71618 m .42994 .61795 L .38884 .71355 L 1 .65 .588 r
F
.5552 1.01405 m .56418 1.01569 L .57278 1.00863 L .892 .796 .848 r
F
.2292 1.38322 m .19619 1.35254 L .2161 1.41778 L 1 .455 .589 r
F
.2292 1.38322 m .21015 1.32168 L .19619 1.35254 L F
.39827 1.05361 m .39259 1.0428 L .38535 1.05395 L .931 .815 .839 r
F
.39827 1.05361 m .40481 1.04384 L .39259 1.0428 L F
.53323 .87308 m .53971 .8706 L .53513 .87144 L .637 .349 .874 r
F
.51304 .87315 m .53323 .87308 L .53513 .87144 L .235 0 .807 r
F
.53079 .87225 m .53513 .87144 L .53705 .87202 L .049 0 0 r
F
.51304 .87315 m .53513 .87144 L .51303 .87288 L .235 0 .807 r
F
.51303 .87288 m .53513 .87144 L .53079 .87225 L .049 0 0 r
F
.53971 .8706 m .55672 .86408 L .53513 .87144 L .637 .349 .874 r
F
.61203 .98692 m .62293 .9898 L .63398 .98024 L 1 .972 .807 r
F
.60204 .99554 m .62293 .9898 L .61203 .98692 L 1 .947 .818 r
F
.19565 1.28437 m .18663 1.30172 L .18101 1.31224 L .638 0 .298 r
F
.18663 1.30172 m .16874 1.33613 L .17902 1.31611 L F
.18663 1.30172 m .17902 1.31611 L .18101 1.31224 L F
.17104 1.3317 m .18418 1.30617 L .16874 1.33613 L F
.19565 1.28437 m .18418 1.30617 L .17104 1.3317 L F
.20227 1.27208 m .18585 1.30302 L .19565 1.28437 L .63 0 .302 r
F
.18585 1.30302 m .18418 1.30617 L .18524 1.30415 L F
.18585 1.30302 m .18524 1.30415 L .19565 1.28437 L F
.20436 1.26832 m .18657 1.30168 L .20227 1.27208 L F
.18657 1.30168 m .18418 1.30617 L .18585 1.30302 L F
.18657 1.30168 m .18585 1.30302 L .20227 1.27208 L F
.21015 1.25746 m .20436 1.26832 L .20227 1.27208 L F
.21015 1.25746 m .20207 1.27251 L .19552 1.2849 L F
.20811 1.26158 m .21087 1.25662 L .19944 1.27741 L 0 0 0 r
F
.22452 1.2316 m .21123 1.25596 L .20811 1.26158 L F
.21123 1.25596 m .21087 1.25662 L .21062 1.25706 L F
.21123 1.25596 m .21062 1.25706 L .20811 1.26158 L F
.22946 1.22392 m .22761 1.22617 L .21454 1.24995 L .834 0 .468 r
F
.22452 1.2316 m .21454 1.24995 L .21087 1.25662 L 0 0 0 r
F
.22452 1.2316 m .19944 1.27741 L .21015 1.25746 L F
.22761 1.22617 m .21118 1.24618 L .21454 1.24995 L .834 0 .468 r
F
.21087 1.25662 m .1957 1.2747 L .19944 1.27741 L .826 0 .447 r
F
.21454 1.24995 m .2143 1.25026 L .21087 1.25662 L F
.2143 1.25026 m .1957 1.2747 L .21087 1.25662 L F
.19944 1.27741 m .19777 1.27976 L .18418 1.30617 L .816 0 .428 r
F
.19777 1.27976 m .18003 1.30467 L .18418 1.30617 L F
.19552 1.2849 m .19944 1.27741 L .18418 1.30617 L .63 0 .302 r
F
.20207 1.27251 m .19944 1.27741 L .19552 1.2849 L F
.31485 1.10378 m .3164 1.0855 L .31355 1.10483 L 1 .992 .764 r
F
.31485 1.10378 m .31768 1.08476 L .3164 1.0855 L F
.53997 1.02016 m .5552 1.01405 L .54541 1.01296 L .868 .762 .847 r
F
.53131 1.01965 m .53997 1.02016 L .54541 1.01296 L .844 .741 .849 r
F
.19758 1.24357 m .17727 1.16921 L .18315 1.26895 L 1 .399 .593 r
F
.3538 1.0703 m .34638 1.05496 L .34029 1.07451 L 1 .836 .806 r
F
.3538 1.0703 m .3594 1.05478 L .34638 1.05496 L F
.31354 1.10483 m .30261 1.09479 L .29955 1.11744 L 1 .964 .75 r
F
.31354 1.10483 m .31639 1.0855 L .30261 1.09479 L F
.8067 1.39342 m .7839 1.42597 L .79637 1.46158 L .464 .005 .594 r
F
.79329 1.36099 m .7839 1.42597 L .8067 1.39342 L .461 .005 .596 r
F
.55669 .58471 m .60479 .67362 L .55864 .5743 L .061 0 .575 r
F
.55669 .58471 m .60078 .6776 L .60479 .67362 L F
.65606 .95832 m .68004 .97499 L .66713 .94809 L .566 .262 .796 r
F
.66713 .94809 m .68004 .97499 L .68819 .97835 L .387 .031 .725 r
F
.62202 .97695 m .63398 .98024 L .64502 .9697 L 1 .988 .79 r
F
.61203 .98692 m .63398 .98024 L .62202 .97695 L 1 .972 .807 r
F
.58142 1.00163 m .59207 1.00342 L .60204 .99554 L .988 .888 .839 r
F
.57278 1.00863 m .59207 1.00342 L .58142 1.00163 L .963 .859 .84 r
F
.53513 .87144 m .55672 .86408 L .56049 .86044 L .541 .018 .798 r
F
.32794 .90661 m .33618 .90186 L .31591 .92465 L 0 0 0 r
F
.41699 1.04489 m .41328 1.03437 L .40481 1.04384 L .939 .818 .837 r
F
.41699 1.04489 m .42453 1.03648 L .41328 1.03437 L F
.22147 .95395 m .21932 1.03549 L .20729 .97152 L .575 0 .32 r
F
.22147 .95395 m .23323 1.01451 L .21932 1.03549 L F
.53131 1.01965 m .54541 1.01296 L .53499 1.01233 L .844 .741 .849 r
F
.5223 1.01969 m .53131 1.01965 L .53499 1.01233 L .838 .729 .849 r
F
.80475 1.21592 m .80933 1.31006 L .81922 1.23949 L .559 .022 .596 r
F
.80475 1.21592 m .79529 1.28213 L .80933 1.31006 L F
.79529 1.28213 m .79329 1.36099 L .80933 1.31006 L .506 .012 .598 r
F
.63197 .96439 m .64502 .9697 L .65606 .95832 L 1 .947 .766 r
F
.62202 .97695 m .64502 .9697 L .63197 .96439 L 1 .988 .79 r
F
.38535 1.05395 m .38034 1.04153 L .37239 1.05439 L .944 .809 .834 r
F
.38535 1.05395 m .39259 1.0428 L .38034 1.04153 L F
.58499 .69409 m .62612 .76558 L .5889 .68986 L 0 0 .575 r
F
.58499 .69409 m .62019 .76288 L .62612 .76558 L F
.5552 1.01405 m .57278 1.00863 L .5623 1.0072 L .892 .796 .848 r
F
.54541 1.01296 m .5552 1.01405 L .5623 1.0072 L .835 .75 .856 r
F
.43574 1.03879 m .43376 1.02811 L .42453 1.03648 L .949 .807 .831 r
F
.72213 .96243 m .73702 .92727 L .75003 .94056 L .837 0 .289 r
F
.70984 .9439 m .73702 .92727 L .72213 .96243 L .822 0 .267 r
F
.80329 .99926 m .81511 .9368 L .82894 .94826 L .836 0 .32 r
F
.78979 .98393 m .81511 .9368 L .80329 .99926 L .833 0 .317 r
F
.30955 .70715 m .33443 .78221 L .30047 .70081 L 1 .001 .171 r
F
.30955 .70715 m .34227 .78266 L .33443 .78221 L F
.5223 1.01969 m .53499 1.01233 L .52415 1.01218 L .838 .729 .849 r
F
.51311 1.02034 m .5223 1.01969 L .52415 1.01218 L .848 .728 .844 r
F
.5623 1.0072 m .57278 1.00863 L .58142 1.00163 L .878 .801 .854 r
F
.34029 1.07451 m .33334 1.05481 L .3267 1.08009 L 1 .781 .775 r
F
.34029 1.07451 m .34638 1.05496 L .33334 1.05481 L F
.78267 1.14688 m .78154 1.15129 L .79647 1.17922 L 0 0 .414 r
F
.76757 1.1164 m .78154 1.15129 L .78267 1.14688 L 0 0 .465 r
F
.51311 1.02034 m .52415 1.01218 L .5131 1.01267 L .848 .728 .844 r
F
.80933 1.31006 m .79329 1.36099 L .8067 1.39342 L .506 .011 .596 r
F
.66713 .94809 m .68819 .97835 L .67453 .9449 L .387 .031 .725 r
F
.49097 .86369 m .51303 .87288 L .51302 .87644 L .546 0 0 r
F
.59008 .99464 m .60204 .99554 L .61203 .98692 L 1 .915 .832 r
F
.58142 1.00163 m .60204 .99554 L .59008 .99464 L .988 .888 .839 r
F
.38291 .71126 m .42603 .61001 L .4221 .60206 L 1 .638 .584 r
F
.38884 .71355 m .42603 .61001 L .38291 .71126 L 1 .645 .586 r
F
.67453 .9449 m .68819 .97835 L .68936 .97907 L .339 .005 .688 r
F
.37239 1.05439 m .36807 1.03964 L .3594 1.05478 L .956 .778 .822 r
F
.37239 1.05439 m .38034 1.04153 L .36807 1.03964 L F
.54541 1.01296 m .5623 1.0072 L .55087 1.00623 L .835 .75 .856 r
F
.53499 1.01233 m .54541 1.01296 L .55087 1.00623 L .794 .709 .86 r
F
.40481 1.04384 m .40198 1.03238 L .39259 1.0428 L .94 .824 .838 r
F
.40481 1.04384 m .41328 1.03437 L .40198 1.03238 L F
.29955 1.11744 m .28866 1.10709 L .28542 1.13267 L 1 .893 .712 r
F
.29955 1.11744 m .30261 1.09479 L .28866 1.10709 L F
.67453 .9449 m .68936 .97907 L .67559 .94483 L .339 .005 .688 r
F
.42453 1.03648 m .42366 1.02495 L .41328 1.03437 L .961 .828 .833 r
F
.42453 1.03648 m .43376 1.02811 L .42366 1.02495 L F
.25882 1.17692 m .25641 1.1712 L .24153 1.19419 L .843 .008 .52 r
F
.59877 .98756 m .61203 .98692 L .62201 .97695 L 1 .933 .811 r
F
.59008 .99464 m .61203 .98692 L .59877 .98756 L 1 .915 .832 r
F
.56944 1.0008 m .58142 1.00163 L .59008 .99464 L .861 .792 .86 r
F
.5623 1.0072 m .58142 1.00163 L .56944 1.0008 L .878 .801 .854 r
F
.53513 .87144 m .56049 .86044 L .53705 .87202 L .541 .018 .798 r
F
.32669 1.08009 m .32473 1.05458 L .31768 1.08476 L 1 .698 .738 r
F
.32669 1.08009 m .33334 1.05481 L .32473 1.05458 L F
.55087 1.00623 m .5623 1.0072 L .56944 1.0008 L .785 .715 .868 r
F
.53499 1.01233 m .55087 1.00623 L .53869 1.00546 L .794 .709 .86 r
F
.52415 1.01218 m .53499 1.01233 L .53869 1.00546 L .783 .689 .859 r
F
.3594 1.05478 m .35579 1.03652 L .34638 1.05496 L .957 .693 .801 r
F
.3594 1.05478 m .36807 1.03964 L .35579 1.03652 L F
.8067 1.39342 m .79637 1.46158 L .82024 1.4268 L .464 .005 .594 r
F
.53705 .87202 m .56049 .86044 L .56429 .85801 L .388 0 .623 r
F
.52415 1.01218 m .53869 1.00546 L .52601 1.00493 L .783 .689 .859 r
F
.5131 1.01267 m .52415 1.01218 L .52601 1.00493 L .804 .693 .851 r
F
.51303 .87288 m .53705 .87202 L .51302 .87644 L .049 0 0 r
F
.39259 1.0428 m .39065 1.03039 L .38034 1.04153 L .93 .819 .84 r
F
.39259 1.0428 m .40198 1.03238 L .39065 1.03039 L F
.81922 1.23949 m .8235 1.33902 L .83381 1.26402 L .554 .02 .594 r
F
.81922 1.23949 m .80933 1.31006 L .8235 1.33902 L F
.60749 .98021 m .62201 .97695 L .63197 .96439 L 1 .921 .766 r
F
.59877 .98756 m .62201 .97695 L .60749 .98021 L 1 .933 .811 r
F
.5131 1.01267 m .52601 1.00493 L .51309 1.00496 L .804 .693 .851 r
F
.80933 1.31006 m .8067 1.39342 L .8235 1.33902 L .506 .011 .596 r
F
.5889 .68986 m .6321 .7683 L .59283 .68571 L 0 0 .568 r
F
.5889 .68986 m .62612 .76558 L .6321 .7683 L F
.31768 1.08476 m .3235 1.05455 L .3164 1.0855 L 1 .638 .713 r
F
.31768 1.08476 m .32472 1.05458 L .3235 1.05455 L F
.80329 .99926 m .82894 .94826 L .81692 1.01497 L .836 0 .32 r
F
.38291 .71126 m .4221 .60206 L .37693 .70922 L 1 .638 .584 r
F
.60749 .98021 m .63197 .96439 L .61623 .97249 L 1 .921 .766 r
F
.31639 1.0855 m .3104 1.05459 L .30261 1.09479 L 1 .648 .71 r
F
.31639 1.0855 m .3235 1.05455 L .3104 1.05459 L F
.55087 1.00623 m .56944 1.0008 L .55635 1.00017 L .785 .715 .868 r
F
.53869 1.00546 m .55087 1.00623 L .55635 1.00017 L .718 .638 .875 r
F
.43376 1.02811 m .43577 1.01535 L .42366 1.02495 L .993 .827 .823 r
F
.41328 1.03437 m .41351 1.02222 L .40198 1.03238 L .96 .846 .837 r
F
.41328 1.03437 m .42366 1.02495 L .41351 1.02222 L F
.34638 1.05496 m .34355 1.03121 L .33334 1.05481 L .924 .531 .766 r
F
.34638 1.05496 m .35579 1.03652 L .34355 1.03121 L F
.57661 .99498 m .59008 .99464 L .59877 .98756 L .838 .742 .862 r
F
.56944 1.0008 m .59008 .99464 L .57661 .99498 L .861 .792 .86 r
F
.20729 .97152 m .2053 1.05629 L .19303 .98855 L .58 0 .32 r
F
.20729 .97152 m .21932 1.03549 L .2053 1.05629 L F
.28542 1.13267 m .27451 1.12286 L .27111 1.15053 L 1 .774 .674 r
F
.28542 1.13267 m .28866 1.10709 L .27451 1.12286 L F
.73454 .98068 m .75003 .94056 L .76316 .95452 L .845 0 .299 r
F
.72213 .96243 m .75003 .94056 L .73454 .98068 L .837 0 .289 r
F
.8235 1.33902 m .8067 1.39342 L .82024 1.4268 L .505 .01 .593 r
F
.55635 1.00017 m .56944 1.0008 L .57661 .99498 L .715 .629 .882 r
F
.56718 .85696 m .59807 .82528 L .57104 .85653 L .618 0 .527 r
F
.38034 1.04153 m .37928 1.02813 L .36807 1.03964 L .903 .795 .843 r
F
.38034 1.04153 m .39065 1.03039 L .37928 1.02813 L F
.53869 1.00546 m .55635 1.00017 L .54241 .99926 L .718 .638 .875 r
F
.52601 1.00493 m .53869 1.00546 L .54241 .99926 L .701 .61 .873 r
F
.79792 1.17751 m .79647 1.17922 L .81154 1.20781 L 0 0 .372 r
F
.78267 1.14688 m .79647 1.17922 L .79792 1.17751 L 0 0 .414 r
F
.31591 .92465 m .33469 .90354 L .32519 .91542 L 0 0 0 r
F
.32519 .91542 m .3417 .87127 L .31581 .92714 L 1 .457 .626 r
F
.32519 .91542 m .31581 .92714 L .31403 .93098 L F
.33469 .90354 m .33618 .90187 L .32519 .91542 L 0 0 0 r
F
.63812 .81173 m .67522 .88368 L .64591 .82195 L 0 0 .346 r
F
.48902 .86598 m .51301 .88395 L .48702 .87845 L .67 0 .033 r
F
.48902 .86598 m .51302 .87644 L .51301 .88395 L F
.33334 1.05481 m .33551 1.02575 L .32473 1.05458 L .878 .357 .719 r
F
.33334 1.05481 m .34354 1.03121 L .33551 1.02575 L F
.24422 1.19951 m .24153 1.19419 L .22645 1.21927 L .84 .002 .492 r
F
.52601 1.00493 m .54241 .99926 L .52789 .99807 L .701 .61 .873 r
F
.51309 1.00496 m .52601 1.00493 L .52789 .99807 L .738 .631 .859 r
F
.40198 1.03238 m .40331 1.02005 L .39065 1.03039 L .931 .845 .847 r
F
.40198 1.03238 m .41351 1.02222 L .40331 1.02005 L F
.51309 1.00496 m .52789 .99807 L .51308 .99717 L .738 .631 .859 r
F
.6499 .97161 m .66943 .91738 L .68059 .94848 L .9 .006 .388 r
F
.64065 .96119 m .66943 .91738 L .6499 .97161 L .979 .032 .442 r
F
.58383 .98994 m .59877 .98756 L .60749 .98021 L .801 .596 .85 r
F
.57661 .99498 m .59877 .98756 L .58383 .98994 L .838 .742 .862 r
F
.42366 1.02495 m .42698 1.01143 L .41351 1.02222 L 1 .865 .827 r
F
.42366 1.02495 m .43577 1.01535 L .42698 1.01143 L F
.30261 1.09479 m .29719 1.05714 L .28866 1.10709 L 1 .642 .676 r
F
.30261 1.09479 m .3104 1.05459 L .29719 1.05714 L F
.36807 1.03964 m .36788 1.02523 L .3558 1.03652 L .85 .738 .846 r
F
.36807 1.03964 m .37928 1.02813 L .36788 1.02523 L F
.32472 1.05458 m .33438 1.0248 L .3235 1.05455 L .876 .282 .688 r
F
.32472 1.05458 m .33551 1.02575 L .33438 1.0248 L F
.3235 1.05455 m .32236 1.01058 L .3104 1.05459 L .746 .161 .665 r
F
.3235 1.05455 m .33437 1.0248 L .32236 1.01058 L F
.53705 .87202 m .56429 .85801 L .53899 .8747 L .388 0 .623 r
F
.53899 .8747 m .56429 .85801 L .56682 .85706 L 0 0 0 r
F
.51302 .87644 m .53705 .87202 L .53899 .8747 L .225 0 0 r
F
.55635 1.00017 m .57661 .99498 L .56188 .99509 L .715 .629 .882 r
F
.54241 .99926 m .55635 1.00017 L .56188 .99509 L .615 .491 .892 r
F
.83381 1.26402 m .8378 1.36893 L .84853 1.28946 L .55 .018 .591 r
F
.83381 1.26402 m .8235 1.33902 L .8378 1.36893 L F
.59283 .68571 m .63813 .77105 L .59679 .68163 L 0 0 .562 r
F
.59283 .68571 m .6321 .7683 L .63813 .77105 L F
.8235 1.33902 m .82024 1.4268 L .8378 1.36893 L .505 .01 .593 r
F
.56188 .99509 m .57661 .99498 L .58383 .98994 L .623 .429 .89 r
F
.57494 .85711 m .60369 .81963 L .60935 .81501 L 0 0 0 r
F
.57104 .85653 m .60369 .81963 L .57494 .85711 L F
.3558 1.03652 m .35648 1.02122 L .34355 1.03121 L .76 .63 .849 r
F
.3558 1.03652 m .36788 1.02523 L .35648 1.02122 L F
.27111 1.15053 m .25993 1.14245 L .25641 1.1712 L 1 .623 .637 r
F
.27111 1.15053 m .27451 1.12286 L .25993 1.14245 L F
.51302 .87644 m .53899 .8747 L .51301 .88395 L .225 0 0 r
F
.33618 .90187 m .36051 .85788 L .35116 .86376 L 1 .56 .659 r
F
.43577 1.01535 m .44215 .99951 L .42698 1.01143 L 1 .828 .801 r
F
.54241 .99926 m .56188 .99509 L .54616 .99404 L .615 .491 .892 r
F
.52789 .99807 m .54241 .99926 L .54616 .99404 L .59 .461 .889 r
F
.39065 1.03039 m .39306 1.01856 L .37928 1.02813 L .854 .783 .862 r
F
.39065 1.03039 m .40331 1.02005 L .39306 1.01856 L F
.32236 1.01058 m .3365 1.01045 L .3251 1.00337 L .141 0 .828 r
F
.33437 1.02479 m .3365 1.01045 L .32236 1.01058 L .483 .261 .855 r
F
.41351 1.02222 m .41814 1.00853 L .40331 1.02005 L .999 .892 .836 r
F
.41351 1.02222 m .42698 1.01143 L .41814 1.00853 L F
.52789 .99807 m .54616 .99404 L .52977 .99179 L .59 .461 .889 r
F
.51308 .99717 m .52789 .99807 L .52977 .99179 L .643 .523 .871 r
F
.34355 1.03121 m .34896 1.01774 L .33551 1.02575 L .626 .465 .855 r
F
.34355 1.03121 m .35647 1.02122 L .34896 1.01774 L F
.51308 .99717 m .52977 .99179 L .51306 .98925 L .643 .523 .871 r
F
.33551 1.02574 m .34789 1.01719 L .33438 1.02479 L .51 .314 .865 r
F
.33551 1.02574 m .34896 1.01774 L .34789 1.01719 L F
.33437 1.02479 m .34772 1.01728 L .3365 1.01045 L .483 .261 .855 r
F
.3365 1.01045 m .34328 1.02643 L .3253 1.00362 L .498 0 .003 r
F
.3365 1.01045 m .3253 1.00362 L .3251 1.00337 L F
.34772 1.01728 m .34789 1.01719 L .3365 1.01045 L .483 .261 .855 r
F
.33618 .90187 m .35116 .86376 L .32519 .91542 L 1 .56 .659 r
F
.74707 .99897 m .76316 .95452 L .77642 .96901 L .851 0 .306 r
F
.73454 .98068 m .76316 .95452 L .74707 .99897 L .845 0 .299 r
F
.53899 .8747 m .56682 .85706 L .54029 .87747 L 0 0 0 r
F
.54029 .87747 m .56682 .85706 L .56718 .85696 L F
.28866 1.10709 m .28371 1.06611 L .27451 1.12286 L 1 .707 .644 r
F
.28866 1.10709 m .29719 1.05714 L .28371 1.06611 L F
.66558 .86611 m .70163 .94688 L .67522 .88368 L 0 0 .414 r
F
.66558 .86611 m .69039 .92553 L .70163 .94688 L F
.54029 .87747 m .56718 .85696 L .54047 .87792 L 0 0 0 r
F
.54047 .87792 m .56718 .85696 L .57104 .85653 L F
.56188 .99509 m .58383 .98994 L .56744 .99131 L .623 .429 .89 r
F
.54616 .99404 m .56188 .99509 L .56744 .99131 L .497 .227 .899 r
F
.22946 1.22392 m .22645 1.21927 L .21118 1.24618 L .834 0 .468 r
F
.56744 .99131 m .58383 .98994 L .59109 .98598 L .512 .099 .866 r
F
.37928 1.02813 m .38274 1.01785 L .36788 1.02523 L .71 .56 .878 r
F
.37928 1.02813 m .39306 1.01856 L .38274 1.01785 L F
.81332 1.20851 m .81154 1.20781 L .82676 1.23707 L 0 0 .337 r
F
.79792 1.17751 m .81154 1.20781 L .81332 1.20851 L 0 0 .372 r
F
.59679 .68163 m .6442 .77387 L .60078 .6776 L 0 0 .557 r
F
.59679 .68163 m .63813 .77105 L .6442 .77387 L F
.42698 1.01143 m .43487 .99413 L .41814 1.00853 L 1 .895 .799 r
F
.42698 1.01143 m .44215 .99951 L .43487 .99413 L F
.57494 .85711 m .60935 .81501 L .57888 .8586 L 0 0 0 r
F
.57888 .8586 m .60935 .81501 L .61514 .8113 L F
.77837 1.13223 m .78267 1.14688 L .79792 1.17751 L 0 0 .379 r
F
.64591 .82195 m .68493 .90028 L .65376 .83186 L 0 0 .414 r
F
.64591 .82195 m .67522 .88368 L .68493 .90028 L F
.40331 1.02005 m .40923 1.00715 L .39306 1.01856 L .911 .81 .85 r
F
.40331 1.02005 m .41814 1.00853 L .40923 1.00715 L F
.54616 .99404 m .56744 .99131 L .54993 .99015 L .497 .227 .899 r
F
.52977 .99179 m .54616 .99404 L .54993 .99015 L .46 .218 .898 r
F
.51301 .88396 m .53899 .8747 L .54029 .87747 L .269 0 0 r
F
.51306 .98925 m .53167 .9864 L .51305 .98125 L .519 .346 .882 r
F
.51306 .98925 m .52977 .99179 L .53167 .9864 L F
.52977 .99179 m .54993 .99015 L .53167 .9864 L .46 .218 .898 r
F
.25641 1.1712 m .24512 1.16525 L .24153 1.19419 L 1 .464 .604 r
F
.25641 1.1712 m .25993 1.14245 L .24512 1.16525 L F
.6058 .9836 m .625 .96485 L .63386 .95988 L 0 0 0 r
F
.5984 .9836 m .625 .96485 L .6058 .9836 L .611 0 .66 r
F
.36788 1.02523 m .37235 1.01806 L .35648 1.02122 L .529 .11 .864 r
F
.36788 1.02523 m .38274 1.01785 L .37235 1.01806 L F
.48702 .87846 m .513 .89072 L .48566 .89197 L .645 0 .13 r
F
.48702 .87846 m .51301 .88396 L .513 .89072 L F
.32519 .91542 m .35116 .86376 L .3417 .87127 L 1 .457 .626 r
F
.30335 .95014 m .31403 .93098 L .29056 .97807 L .687 0 .427 r
F
.45501 .85085 m .48133 .92367 L .45096 .86553 L 1 0 .128 r
F
.41641 .82553 m .44271 .88802 L .4104 .83293 L 1 .003 .227 r
F
.57516 .98957 m .59109 .98598 L .57305 .98924 L .512 .099 .866 r
F
.57305 .98924 m .58026 .98763 L .57871 .98933 L .279 0 .725 r
F
.58026 .98763 m .5984 .9836 L .57871 .98933 L F
.57724 .99093 m .57871 .98933 L .58444 .99199 L .318 0 0 r
F
.57105 .98893 m .57305 .98924 L .57871 .98933 L 0 0 .665 r
F
.55373 .98802 m .57305 .98924 L .57105 .98893 L F
.56744 .99131 m .57516 .98957 L .57305 .98924 L .512 .099 .866 r
F
.54993 .99015 m .56744 .99131 L .57305 .98924 L .305 .003 .851 r
F
.54993 .99015 m .57305 .98924 L .55373 .98802 L F
.55373 .98802 m .56078 .98839 L .55758 .98805 L 0 0 .665 r
F
.56078 .98839 m .57871 .98933 L .55758 .98805 L F
.54761 .98565 m .55373 .98802 L .55758 .98805 L 0 0 .726 r
F
.53358 .98229 m .54842 .98651 L .54761 .98565 L F
.54842 .98651 m .55373 .98802 L .54761 .98565 L F
.53358 .98229 m .55758 .98805 L .53551 .97997 L F
.53551 .97997 m .55758 .98805 L .55455 .98772 L .362 0 0 r
F
.53551 .97997 m .54192 .98258 L .53746 .97997 L F
.51303 .96614 m .53746 .97997 L .51302 .96067 L 0 0 .65 r
F
.52498 .9729 m .53551 .97997 L .53746 .97997 L F
.51303 .96614 m .52314 .97236 L .52498 .9729 L F
.52314 .97236 m .53551 .97997 L .52498 .9729 L F
.53125 .97584 m .53746 .97997 L .53323 .97749 L .534 0 0 r
F
.51302 .96067 m .53031 .97432 L .53125 .97584 L F
.53031 .97432 m .53746 .97997 L .53125 .97584 L F
.51302 .96067 m .52923 .97416 L .51301 .95828 L F
.51301 .95828 m .5323 .97754 L .513 .95885 L .682 0 0 r
F
.53167 .9864 m .55373 .98802 L .53358 .98229 L .259 .01 .866 r
F
.51304 .97336 m .53551 .97997 L .51303 .96614 L .112 0 .822 r
F
.51304 .97336 m .53358 .98229 L .53551 .97997 L F
.5323 .97754 m .54076 .98598 L .53258 .97799 L .682 0 0 r
F
.5323 .97754 m .53258 .97799 L .513 .95885 L F
.53323 .97749 m .53746 .97997 L .53944 .98266 L .534 0 0 r
F
.52923 .97416 m .53944 .98266 L .53069 .97459 L F
.52923 .97416 m .53069 .97459 L .51301 .95828 L F
.54192 .98258 m .54645 .98442 L .53746 .97997 L .362 0 0 r
F
.55455 .98772 m .55758 .98805 L .56147 .99053 L F
.54645 .98442 m .56147 .99053 L .54564 .98357 L F
.54645 .98442 m .54564 .98357 L .53746 .97997 L F
.55758 .98805 m .57871 .98933 L .57724 .99093 L .318 0 0 r
F
.27451 1.12286 m .2837 1.06611 L .26962 1.08406 L 1 .716 .61 r
F
.27451 1.12286 m .26962 1.08406 L .25993 1.14245 L F
.41814 1.00853 m .42754 .99043 L .40923 1.00715 L 1 .972 .805 r
F
.41814 1.00853 m .43487 .99413 L .42754 .99043 L F
.54246 .88348 m .57104 .85653 L .57494 .85711 L 0 0 0 r
F
.54047 .87792 m .57104 .85653 L .54246 .88348 L F
.51301 .88396 m .54029 .87747 L .513 .89072 L .269 0 0 r
F
.39306 1.01856 m .40024 1.00781 L .38274 1.01785 L .718 .375 .842 r
F
.39306 1.01856 m .40923 1.00715 L .40024 1.00781 L F
.35647 1.02122 m .36546 1.01883 L .34896 1.01774 L .18 0 .693 r
F
.35647 1.02122 m .37235 1.01806 L .36546 1.01883 L F
.75973 1.01748 m .77642 .96901 L .78979 .98393 L .855 0 .311 r
F
.74707 .99897 m .77642 .96901 L .75973 1.01748 L .851 0 .306 r
F
.21454 1.24995 m .21118 1.24618 L .1957 1.2747 L .826 0 .447 r
F
.60078 .6776 m .65033 .77675 L .60479 .67362 L 0 0 .553 r
F
.60078 .6776 m .6442 .77387 L .65033 .77675 L F
.58291 .86093 m .61514 .8113 L .62098 .80844 L 0 0 0 r
F
.57888 .8586 m .61514 .8113 L .58291 .86093 L F
.43487 .99413 m .44757 .96684 L .42754 .99043 L 1 .688 .717 r
F
.6058 .9836 m .63386 .95988 L .61329 .98695 L 0 0 0 r
F
.61329 .98695 m .63386 .95988 L .6398 .96071 L .337 0 .133 r
F
.51305 .98125 m .53358 .98229 L .51304 .97336 L .366 .113 .879 r
F
.51305 .98125 m .53167 .9864 L .53358 .98229 L F
.53167 .9864 m .54993 .99015 L .55373 .98802 L .259 .01 .866 r
F
.513 .89072 m .54029 .87747 L .54047 .87792 L .259 0 0 r
F
.34896 1.01774 m .36546 1.01883 L .36448 1.01899 L .133 0 0 r
F
.34896 1.01774 m .36448 1.01899 L .34789 1.01719 L F
.65938 .98822 m .68059 .94848 L .69171 .9728 L .89 .002 .353 r
F
.6499 .97161 m .68059 .94848 L .65938 .98822 L .9 .006 .388 r
F
.34789 1.01719 m .35394 1.02161 L .3365 1.01045 L .196 0 0 r
F
.34789 1.01719 m .36448 1.01899 L .35394 1.02161 L F
.513 .89072 m .54047 .87792 L .513 .89177 L .259 0 0 r
F
.513 .89177 m .54047 .87792 L .54246 .88348 L .291 0 0 r
F
.82889 1.24 m .82676 1.23707 L .84213 1.26701 L 0 0 .309 r
F
.81332 1.20851 m .82676 1.23707 L .82889 1.24 L 0 0 .337 r
F
.43625 .95622 m .45892 .89011 L .43237 .96166 L .39 0 .427 r
F
.4126 .99307 m .43625 .95622 L .43237 .96166 L .654 0 .391 r
F
.4126 .99307 m .43237 .96166 L .43236 .96168 L F
.40024 1.00781 m .4126 .99307 L .39115 1.01089 L .716 .029 .699 r
F
.40398 1.00023 m .41098 .99442 L .40756 .99776 L 0 0 0 r
F
.41098 .99442 m .4126 .99307 L .40757 .99775 L F
.41098 .99442 m .40757 .99775 L .40756 .99776 L F
.40368 1.00086 m .40398 1.00023 L .40756 .99776 L F
.39115 1.01089 m .39675 1.00624 L .40368 1.00086 L F
.39843 1.00494 m .40398 1.00023 L .40368 1.00086 L F
.39707 1.00598 m .40398 1.00023 L .39843 1.00494 L F
.40684 .99858 m .40756 .99776 L .40685 .99857 L F
.4061 .99884 m .40756 .99776 L .40684 .99858 L F
.40756 .99776 m .40709 .99822 L .40685 .99857 L F
.40684 .99857 m .40709 .99822 L .40744 .99795 L F
.38274 1.01785 m .39115 1.01089 L .37235 1.01806 L .494 0 .718 r
F
.37782 1.01647 m .39115 1.01089 L .3851 1.01435 L 0 0 0 r
F
.37235 1.01806 m .37427 1.01733 L .37782 1.01647 L F
.37427 1.01733 m .39115 1.01089 L .37782 1.01647 L F
.37235 1.01806 m .3851 1.01435 L .36546 1.01883 L F
.36546 1.01883 m .3851 1.01435 L .38423 1.01493 L .066 0 0 r
F
.36546 1.01883 m .38368 1.01505 L .36448 1.01899 L F
.38368 1.01505 m .38423 1.01493 L .38372 1.01504 L F
.38368 1.01505 m .38372 1.01504 L .36448 1.01899 L F
.39675 1.00624 m .39707 1.00598 L .39843 1.00494 L 0 0 0 r
F
.39115 1.01089 m .40368 1.00086 L .3851 1.01435 L F
.40756 .99776 m .40756 .99776 L .40709 .99822 L F
.42055 .97952 m .43236 .96168 L .4283 .96759 L .654 0 .391 r
F
.42055 .97952 m .4283 .96759 L .40756 .99776 L F
.4126 .99307 m .43236 .96168 L .40992 .99556 L F
.40756 .99776 m .43237 .96166 L .43182 .9628 L 0 0 0 r
F
.40756 .99776 m .43182 .9628 L .40745 .99771 L F
.40756 .99776 m .40745 .99771 L .40709 .99822 L F
.40368 1.00086 m .40756 .99776 L .40609 .99884 L F
.40368 1.00086 m .40609 .99884 L .3851 1.01435 L F
.40756 .99776 m .40756 .99776 L .40685 .99857 L F
.40709 .99822 m .40745 .99771 L .40744 .99795 L F
.40745 .99771 m .43182 .9628 L .40782 .99739 L F
.40745 .99771 m .40782 .99739 L .40744 .99795 L F
.3851 1.01435 m .4061 .99884 L .40684 .99858 L F
.3851 1.01435 m .40541 .99961 L .38423 1.01493 L F
.40541 .99961 m .40685 .99857 L .40548 .99956 L F
.40541 .99961 m .40548 .99956 L .38423 1.01493 L F
.40756 .99776 m .4126 .99307 L .40756 .99776 L F
.40992 .99556 m .42055 .97952 L .40756 .99776 L .654 0 .391 r
F
.42012 .98969 m .44196 .95782 L .43625 .95622 L 1 .779 .691 r
F
.42012 .98969 m .43625 .95622 L .4126 .99307 L F
.40744 .99795 m .43182 .9628 L .42579 .97867 L 0 0 0 r
F
.43237 .96166 m .43237 .96166 L .43182 .9628 L .324 0 .356 r
F
.43237 .96166 m .45892 .89013 L .45851 .89552 L F
.43237 .96166 m .45851 .89552 L .43246 .96118 L F
.43237 .96166 m .43246 .96118 L .43182 .9628 L F
.43182 .9628 m .43246 .96118 L .45422 .93591 L .213 0 .294 r
F
.43246 .96118 m .45851 .89554 L .45526 .92609 L F
.43246 .96118 m .45526 .92609 L .45422 .93591 L F
.57871 .98933 m .5984 .9836 L .6058 .9836 L .086 0 0 r
F
.3365 1.01045 m .35394 1.02161 L .34328 1.02643 L .498 0 .003 r
F
.24153 1.19419 m .23008 1.1907 L .22645 1.21927 L 1 .32 .573 r
F
.24153 1.19419 m .24512 1.16525 L .23008 1.1907 L F
.42754 .99043 m .44757 .96684 L .44196 .95782 L 1 .807 .705 r
F
.67522 .88368 m .71298 .96767 L .68493 .90028 L 0 0 .435 r
F
.67522 .88368 m .70163 .94688 L .71298 .96767 L F
.40923 1.00715 m .42012 .98969 L .40024 1.00781 L 1 .792 .805 r
F
.40923 1.00715 m .42754 .99043 L .42012 .98969 L F
.38274 1.01785 m .40024 1.00781 L .39115 1.01089 L .494 0 .718 r
F
.79354 1.16351 m .79792 1.17751 L .81332 1.20851 L 0 0 .362 r
F
.77837 1.13223 m .79792 1.17751 L .79354 1.16351 L 0 0 .379 r
F
.65376 .83186 m .69473 .91639 L .66168 .84158 L 0 0 .447 r
F
.65376 .83186 m .68493 .90028 L .69473 .91639 L F
.61329 .98695 m .6398 .96071 L .6183 .99134 L .337 0 .133 r
F
.6183 .99135 m .6398 .96071 L .64065 .96119 L .453 0 .218 r
F
.6183 .99135 m .64065 .96119 L .61901 .99211 L F
.61901 .99212 m .64065 .96119 L .6499 .97161 L .578 0 .276 r
F
.42754 .99043 m .44196 .95782 L .42012 .98969 L 1 .807 .705 r
F
.3251 1.00337 m .33247 1.03412 L .31357 .99991 L .657 0 .184 r
F
.3251 1.00337 m .34328 1.02643 L .33247 1.03412 L F
.31403 .93098 m .3417 .87127 L .33213 .88004 L 1 .405 .602 r
F
.48566 .89197 m .513 .89177 L .48547 .89407 L .564 0 .155 r
F
.48566 .89197 m .513 .89072 L .513 .89177 L F
.25993 1.14245 m .25517 1.10861 L .24512 1.16525 L 1 .617 .58 r
F
.25993 1.14245 m .26962 1.08406 L .25517 1.10861 L F
.58699 .86398 m .62098 .80844 L .62687 .80632 L 0 0 0 r
F
.58291 .86093 m .62098 .80844 L .58699 .86398 L F
.54447 .89017 m .57494 .85711 L .57888 .8586 L .018 0 0 r
F
.54246 .88348 m .57494 .85711 L .54447 .89017 L 0 0 0 r
F
.4104 .83293 m .43851 .89812 L .40436 .83921 L 1 .002 .218 r
F
.4104 .83293 m .44271 .88802 L .43851 .89812 L F
.48547 .89408 m .513 .89177 L .51299 .904 L .567 0 .176 r
F
.513 .89177 m .54246 .88348 L .51299 .904 L .291 0 0 r
F
.19944 1.27741 m .1957 1.2747 L .18003 1.30467 L .816 0 .428 r
F
.77252 1.03633 m .78979 .98393 L .80329 .99926 L .859 0 .314 r
F
.75973 1.01748 m .78979 .98393 L .77252 1.03633 L .855 0 .311 r
F
.31356 .99991 m .32133 1.04522 L .30156 1.00435 L .739 0 .263 r
F
.31356 .99991 m .33247 1.03412 L .32133 1.04522 L F
.45096 .86553 m .47926 .93339 L .44688 .87735 L 1 .002 .168 r
F
.45096 .86553 m .48133 .92367 L .47926 .93339 L F
.58444 .99199 m .6058 .9836 L .61329 .98695 L .374 0 0 r
F
.57871 .98933 m .6058 .9836 L .58444 .99199 L .086 0 0 r
F
.40024 1.00781 m .42012 .98969 L .4126 .99307 L .716 .029 .699 r
F
.29056 .97807 m .30272 .94781 L .27762 1.00567 L .826 0 .475 r
F
.29056 .97807 m .31403 .93098 L .30272 .94781 L F
.84464 1.2721 m .84213 1.26701 L .85766 1.29765 L .633 0 0 r
F
.82889 1.24 m .84213 1.26701 L .84464 1.2721 L 0 0 .309 r
F
.31403 .93098 m .33213 .88004 L .30272 .94781 L 1 .405 .602 r
F
.51299 .904 m .54246 .88348 L .54447 .89017 L .282 0 .048 r
F
.22645 1.21927 m .21481 1.21824 L .21118 1.24618 L 1 .205 .546 r
F
.22645 1.21927 m .23008 1.1907 L .21481 1.21824 L F
.59111 .86769 m .62687 .80632 L .6328 .80483 L 0 0 .032 r
F
.58699 .86398 m .62687 .80632 L .59111 .86769 L 0 0 0 r
F
.36448 1.01899 m .37494 1.02261 L .35394 1.02161 L .134 0 0 r
F
.36448 1.01899 m .38423 1.01494 L .37494 1.02261 L F
.65938 .98822 m .69171 .9728 L .66901 1.00736 L .89 .002 .353 r
F
.66902 1.00736 m .69171 .9728 L .70306 .99508 L .886 .001 .332 r
F
.66168 .84158 m .70463 .93231 L .66968 .8512 L 0 0 .465 r
F
.66168 .84158 m .69473 .91639 L .70463 .93231 L F
.62673 1.00249 m .6499 .97161 L .65938 .98822 L .719 0 .312 r
F
.61901 .99212 m .6499 .97161 L .62673 1.00249 L .578 0 .276 r
F
.24512 1.16525 m .24044 1.1365 L .23008 1.1907 L 1 .482 .558 r
F
.24512 1.16525 m .25517 1.10861 L .24044 1.1365 L F
.55758 .98805 m .58444 .99199 L .56147 .99053 L .318 0 0 r
F
.30272 .94781 m .33213 .88004 L .32244 .88977 L 1 .379 .585 r
F
.54447 .89017 m .57888 .8586 L .5465 .89773 L .018 0 0 r
F
.5465 .89774 m .57888 .8586 L .58291 .86093 L .059 0 0 r
F
.30156 1.00435 m .30999 1.05956 L .28922 1.01635 L .742 0 .295 r
F
.30156 1.00435 m .32133 1.04522 L .30999 1.05956 L F
.80888 1.19505 m .81332 1.20851 L .82889 1.24 L 0 0 .347 r
F
.79354 1.16351 m .81332 1.20851 L .80888 1.19505 L 0 0 .362 r
F
.68493 .90028 m .72445 .98837 L .69473 .91639 L 0 0 .445 r
F
.68493 .90028 m .71298 .96767 L .72445 .98837 L F
.18418 1.30617 m .16416 1.33594 L .16874 1.33613 L .806 0 .411 r
F
.18418 1.30617 m .18003 1.30467 L .16416 1.33594 L F
.25517 1.10861 m .25698 1.06496 L .24044 1.1365 L 1 .206 .475 r
F
.40436 .83921 m .43427 .90801 L .39827 .84486 L 1 .002 .214 r
F
.40436 .83921 m .43851 .89812 L .43427 .90801 L F
.78545 1.0556 m .80329 .99926 L .81692 1.01497 L .862 0 .317 r
F
.77252 1.03633 m .80329 .99926 L .78545 1.0556 L .859 0 .314 r
F
.58444 .99199 m .61329 .98695 L .59025 .9975 L .374 0 0 r
F
.59025 .99751 m .61329 .98695 L .6183 .99134 L .506 0 .086 r
F
.56147 .99053 m .58444 .99199 L .59025 .9975 L .509 0 0 r
F
.51299 .904 m .54447 .89017 L .51298 .91737 L .282 0 .048 r
F
.59527 .87199 m .6328 .80483 L .63879 .80386 L .021 0 .06 r
F
.59111 .86769 m .6328 .80483 L .59527 .87199 L 0 0 .032 r
F
.35394 1.02161 m .36551 1.03288 L .34328 1.02643 L .333 0 .027 r
F
.35394 1.02161 m .37494 1.02261 L .36551 1.03288 L F
.84464 1.2721 m .85766 1.29765 L .86056 1.30486 L .633 0 0 r
F
.78389 1.13907 m .79354 1.1635 L .80888 1.19504 L 0 0 .346 r
F
.21118 1.24618 m .19933 1.24747 L .1957 1.2747 L .98 .122 .521 r
F
.21118 1.24618 m .21481 1.21824 L .19933 1.24747 L F
.44688 .87735 m .47712 .94455 L .44272 .88803 L 1 .002 .187 r
F
.44688 .87735 m .47926 .93339 L .47712 .94455 L F
.51298 .91737 m .54447 .89017 L .5465 .89773 L .269 0 .087 r
F
.43182 .9628 m .45422 .93591 L .42579 .97867 L .213 0 .294 r
F
.53746 .97997 m .56541 .99566 L .53944 .98266 L .565 0 0 r
F
.53746 .97997 m .56147 .99053 L .56541 .99566 L F
.30272 .94781 m .32244 .88977 L .29128 .96541 L 1 .379 .585 r
F
.27762 1.00567 m .30272 .94781 L .29128 .96541 L .895 .028 .498 r
F
.38423 1.01494 m .39909 1.00935 L .37494 1.02261 L 0 0 0 r
F
.38423 1.01494 m .40684 .99857 L .39909 1.00935 L F
.56147 .99053 m .59025 .9975 L .56541 .99566 L .509 0 0 r
F
.54858 .90613 m .58291 .86093 L .58699 .86398 L .088 0 .039 r
F
.5465 .89774 m .58291 .86093 L .54858 .90613 L .059 0 0 r
F
.28922 1.01635 m .29846 1.07669 L .27662 1.03296 L .707 0 .305 r
F
.28922 1.01635 m .30999 1.05956 L .29846 1.07669 L F
.59025 .99751 m .6183 .99134 L .59413 1.00275 L .506 0 .086 r
F
.59413 1.00275 m .6183 .99135 L .61901 .99211 L .553 0 .132 r
F
.51301 .95828 m .53944 .98266 L .54076 .98598 L .682 0 0 r
F
.29128 .96541 m .32244 .88977 L .31265 .90024 L 1 .367 .574 r
F
.59413 1.00275 m .61901 .99211 L .59468 1.0036 L .553 0 .132 r
F
.59468 1.0036 m .61901 .99212 L .62673 1.00249 L .617 0 .178 r
F
.23008 1.1907 m .2255 1.16598 L .21481 1.21824 L 1 .354 .541 r
F
.23008 1.1907 m .24044 1.1365 L .2255 1.16598 L F
.27762 1.00567 m .29128 .96541 L .26457 1.0324 L .895 .028 .498 r
F
.66968 .8512 m .71463 .94824 L .67775 .86081 L 0 0 .475 r
F
.66968 .8512 m .70463 .93231 L .71463 .94824 L F
.24044 1.1365 m .25698 1.06496 L .24266 1.09774 L 1 .172 .483 r
F
.42579 .97867 m .45422 .93591 L .44997 .96416 L .266 0 .26 r
F
.78545 1.0556 m .81692 1.01497 L .79853 1.07532 L .862 0 .317 r
F
.30275 .91131 m .34143 .81323 L .3334 .81774 L 1 .536 .579 r
F
.31265 .90024 m .34143 .81323 L .30275 .91131 L 1 .558 .586 r
F
.8244 1.22706 m .82889 1.24 L .84464 1.2721 L 0 0 .332 r
F
.80888 1.19505 m .82889 1.24 L .8244 1.22706 L 0 0 .347 r
F
.39827 .84486 m .42999 .91792 L .39214 .85019 L 1 .002 .213 r
F
.39827 .84486 m .43427 .90801 L .42999 .91792 L F
.63458 1.01631 m .65938 .98822 L .66901 1.00736 L .789 0 .314 r
F
.62673 1.00249 m .65938 .98822 L .63458 1.01631 L .719 0 .312 r
F
.40684 .99857 m .42579 .97867 L .39909 1.00935 L 0 0 0 r
F
.34328 1.02643 m .35594 1.04564 L .33247 1.03412 L .435 0 .138 r
F
.34328 1.02643 m .36551 1.03288 L .35594 1.04564 L F
.59948 .87683 m .63879 .80386 L .64483 .80336 L .046 0 .083 r
F
.59527 .87199 m .63879 .80386 L .59948 .87683 L .021 0 .06 r
F
.69473 .91639 m .73605 1.00921 L .70463 .93231 L 0 0 .451 r
F
.69473 .91639 m .72445 .98837 L .73605 1.00921 L F
.67893 1.02794 m .70306 .99508 L .71451 1.01652 L .886 0 .32 r
F
.66902 1.00736 m .70306 .99508 L .67893 1.02794 L .886 .001 .332 r
F
.56541 .99566 m .59025 .99751 L .59413 1.00275 L .6 0 .005 r
F
.24044 1.1365 m .24266 1.09774 L .2255 1.16598 L 1 .172 .483 r
F
.513 .95885 m .54094 .98655 L .513 .95908 L .724 0 0 r
F
.513 .95885 m .54076 .98598 L .54094 .98655 L F
.513 .95908 m .54297 .99413 L .51299 .96354 L .763 0 0 r
F
.513 .95908 m .54095 .98655 L .54297 .99413 L F
.1957 1.2747 m .18364 1.2781 L .18003 1.30467 L .94 .067 .499 r
F
.1957 1.2747 m .19933 1.24747 L .18364 1.2781 L F
.53944 .98266 m .56804 1.00049 L .54076 .98598 L .659 0 0 r
F
.53944 .98266 m .56541 .99566 L .56804 1.00049 L F
.37494 1.02261 m .3912 1.02327 L .36551 1.03288 L .157 0 .027 r
F
.37494 1.02261 m .39909 1.00935 L .3912 1.02327 L F
.51298 .91737 m .5465 .89773 L .51297 .9313 L .269 0 .087 r
F
.51297 .9313 m .5465 .89774 L .54858 .90613 L .259 0 .112 r
F
.55069 .91515 m .58699 .86398 L .59111 .86769 L .11 0 .07 r
F
.54858 .90613 m .58699 .86398 L .55069 .91515 L .088 0 .039 r
F
.56541 .99566 m .59413 1.00275 L .56804 1.00049 L .6 0 .005 r
F
.78389 1.13907 m .80888 1.19504 L .79877 1.16906 L 0 0 .346 r
F
.44272 .88803 m .47496 .95659 L .43852 .89813 L 1 .002 .198 r
F
.44272 .88803 m .47712 .94455 L .47496 .95659 L F
.79877 1.16906 m .80888 1.19504 L .8244 1.22706 L 0 0 .349 r
F
.27662 1.03296 m .28673 1.09612 L .26381 1.05209 L .667 0 .309 r
F
.27662 1.03296 m .29846 1.07669 L .28673 1.09612 L F
.29128 .96541 m .31265 .90024 L .2797 .98353 L 1 .367 .574 r
F
.26457 1.0324 m .29128 .96541 L .2797 .98353 L .944 .078 .509 r
F
.2797 .98353 m .31265 .90024 L .30275 .91131 L 1 .362 .565 r
F
.30275 .91131 m .3334 .81774 L .29274 .92288 L 1 .536 .579 r
F
.42579 .97867 m .44997 .96416 L .41965 .99788 L .266 0 .26 r
F
.39909 1.00935 m .42579 .97867 L .41965 .99788 L .104 0 .113 r
F
.60373 .88216 m .64483 .80336 L .65092 .80327 L .065 0 .1 r
F
.59948 .87683 m .64483 .80336 L .60373 .88216 L .046 0 .083 r
F
.56804 1.00049 m .59413 1.00275 L .59468 1.0036 L .638 0 .047 r
F
.60065 1.01417 m .62673 1.00249 L .63458 1.01631 L .711 0 .227 r
F
.59468 1.0036 m .62673 1.00249 L .60065 1.01417 L .617 0 .178 r
F
.33247 1.03412 m .34607 1.06097 L .32133 1.04522 L .488 0 .2 r
F
.33247 1.03412 m .35594 1.04564 L .34607 1.06097 L F
.21481 1.21824 m .21035 1.19641 L .19933 1.24747 L 1 .248 .525 r
F
.21481 1.21824 m .2255 1.16598 L .21035 1.19641 L F
.67775 .86081 m .72474 .96431 L .68589 .87049 L 0 0 .48 r
F
.67775 .86081 m .71463 .94824 L .72474 .96431 L F
.39214 .85019 m .42566 .928 L .38596 .85541 L 1 .003 .215 r
F
.39214 .85019 m .42999 .91792 L .42566 .928 L F
.56804 1.00049 m .59468 1.0036 L .56842 1.00126 L .638 0 .047 r
F
.56842 1.00127 m .59468 1.0036 L .60065 1.01417 L .686 0 .097 r
F
.39909 1.00935 m .41965 .99788 L .3912 1.02327 L .104 0 .113 r
F
.84011 1.25967 m .84464 1.2721 L .86056 1.30486 L 0 0 .319 r
F
.8244 1.22706 m .84464 1.2721 L .84011 1.25967 L 0 0 .332 r
F
.54076 .98598 m .56842 1.00126 L .54094 .98655 L .694 0 0 r
F
.54076 .98598 m .56804 1.00049 L .56842 1.00126 L F
.26457 1.0324 m .2797 .98353 L .25139 1.05848 L .944 .078 .509 r
F
.54095 .98655 m .57247 1.01093 L .54297 .99413 L .737 0 .014 r
F
.54095 .98655 m .56842 1.00127 L .57247 1.01093 L F
.70463 .93231 m .74779 1.03033 L .71463 .94824 L 0 0 .453 r
F
.70463 .93231 m .73605 1.00921 L .74779 1.03033 L F
.63458 1.01631 m .66901 1.00736 L .64256 1.03278 L .789 0 .314 r
F
.64257 1.03278 m .66902 1.00736 L .67893 1.02794 L .831 0 .309 r
F
.51299 .96354 m .54503 1.00422 L .51298 .9713 L .843 0 .035 r
F
.51299 .96354 m .54297 .99413 L .54503 1.00422 L F
.2255 1.16598 m .24266 1.09774 L .22824 1.12888 L 1 .142 .486 r
F
.68899 1.04932 m .71451 1.01652 L .72608 1.03782 L .888 0 .314 r
F
.67893 1.02794 m .71451 1.01652 L .68899 1.04932 L .886 0 .32 r
F
.56842 1.00127 m .60065 1.01417 L .57247 1.01093 L .686 0 .097 r
F
.2255 1.16598 m .22824 1.12888 L .21035 1.19641 L 1 .142 .486 r
F
.18003 1.30467 m .16772 1.30998 L .16416 1.33594 L .914 .034 .479 r
F
.18003 1.30467 m .18364 1.2781 L .16772 1.30998 L F
.36551 1.03288 m .38318 1.03958 L .35594 1.04564 L .282 0 .122 r
F
.36551 1.03288 m .3912 1.02327 L .38318 1.03958 L F
.55283 .92474 m .59111 .86769 L .59527 .87199 L .128 0 .094 r
F
.55069 .91515 m .59111 .86769 L .55283 .92474 L .11 0 .07 r
F
.60373 .88216 m .65092 .80327 L .60802 .88796 L .065 0 .1 r
F
.41965 .99788 m .44997 .96416 L .44571 .9885 L .306 0 .245 r
F
.51296 .9458 m .54858 .90613 L .55069 .91515 L .252 0 .13 r
F
.51297 .9313 m .54858 .90613 L .51296 .9458 L .259 0 .112 r
F
.32133 1.04522 m .33604 1.07852 L .30999 1.05956 L .519 0 .236 r
F
.32133 1.04522 m .34607 1.06097 L .33604 1.07852 L F
.43852 .89813 m .47276 .96935 L .43428 .90802 L 1 .002 .207 r
F
.43852 .89813 m .47496 .95659 L .47276 .96935 L F
.26798 1.00205 m .30275 .91131 L .29274 .92288 L 1 .359 .559 r
F
.2797 .98353 m .30275 .91131 L .26798 1.00205 L 1 .362 .565 r
F
.26381 1.05209 m .27481 1.1174 L .25081 1.07275 L .634 0 .31 r
F
.26381 1.05209 m .28673 1.09612 L .27481 1.1174 L F
.38596 .85541 m .42128 .93833 L .37973 .86063 L 1 .003 .218 r
F
.38596 .85541 m .42566 .928 L .42128 .93833 L F
.81385 1.19975 m .8244 1.22706 L .8401 1.25967 L 0 0 .347 r
F
.79877 1.16906 m .8244 1.22706 L .81385 1.19975 L 0 0 .349 r
F
.78303 1.12915 m .79877 1.16906 L .81385 1.19975 L 0 0 .379 r
F
.25139 1.05848 m .2797 .98353 L .26798 1.00205 L .986 .121 .515 r
F
.68589 .87049 m .73497 .9806 L .69412 .88028 L 0 0 .482 r
F
.68589 .87049 m .72474 .96431 L .73497 .9806 L F
.19933 1.24747 m .19501 1.22757 L .18364 1.2781 L 1 .169 .51 r
F
.19933 1.24747 m .21035 1.19641 L .19501 1.22757 L F
.60671 1.02732 m .63458 1.01631 L .64256 1.03278 L .778 0 .251 r
F
.60065 1.01417 m .63458 1.01631 L .60671 1.02732 L .711 0 .227 r
F
.57247 1.01093 m .60065 1.01417 L .60671 1.02732 L .763 0 .156 r
F
.41965 .99788 m .44571 .9885 L .41341 1.0183 L .306 0 .245 r
F
.3912 1.02327 m .41965 .99788 L .41341 1.0183 L .226 0 .167 r
F
.84011 1.25967 m .86056 1.30486 L .85601 1.29297 L 0 0 .319 r
F
.3912 1.02327 m .41341 1.0183 L .38318 1.03958 L .226 0 .167 r
F
.54297 .99413 m .57657 1.02296 L .54503 1.00422 L .814 0 .091 r
F
.54297 .99413 m .57247 1.01093 L .57657 1.02296 L F
.51298 .9713 m .54712 1.01652 L .51297 .98158 L .909 0 .103 r
F
.51298 .9713 m .54503 1.00422 L .54712 1.01652 L F
.71463 .94824 m .75967 1.05182 L .72474 .96431 L 0 0 .455 r
F
.71463 .94824 m .74779 1.03033 L .75967 1.05182 L F
.57247 1.01093 m .60671 1.02732 L .57657 1.02296 L .763 0 .156 r
F
.55499 .93488 m .59527 .87199 L .59948 .87683 L .141 0 .113 r
F
.55283 .92474 m .59527 .87199 L .55499 .93488 L .128 0 .094 r
F
.25139 1.05848 m .26798 1.00205 L .23807 1.08423 L .986 .121 .515 r
F
.35594 1.04564 m .37492 1.05807 L .34607 1.06097 L .355 0 .176 r
F
.35594 1.04564 m .38318 1.03958 L .37492 1.05807 L F
.6508 1.05154 m .67893 1.02794 L .68899 1.04932 L .859 0 .305 r
F
.64257 1.03278 m .67893 1.02794 L .6508 1.05154 L .831 0 .309 r
F
.78303 1.12915 m .81385 1.19975 L .7973 1.15731 L 0 0 .379 r
F
.69918 1.07143 m .72608 1.03782 L .73779 1.05931 L .893 0 .311 r
F
.68899 1.04932 m .72608 1.03782 L .69918 1.07143 L .888 0 .314 r
F
.21035 1.19641 m .21367 1.15935 L .19501 1.22757 L 1 .119 .487 r
F
.21035 1.19641 m .22824 1.12888 L .21367 1.15935 L F
.51295 .96062 m .55069 .91515 L .55283 .92474 L .248 0 .144 r
F
.51296 .9458 m .55069 .91515 L .51295 .96062 L .252 0 .13 r
F
.37973 .86063 m .41685 .94898 L .37343 .86596 L 1 .004 .222 r
F
.37973 .86063 m .42128 .93833 L .41685 .94898 L F
.30999 1.05956 m .32585 1.09807 L .29846 1.07669 L .533 0 .258 r
F
.30999 1.05956 m .33604 1.07852 L .32585 1.09807 L F
.26798 1.00205 m .29274 .92288 L .25613 1.02092 L 1 .359 .559 r
F
.43428 .90802 m .47054 .98277 L .42999 .91793 L 1 .002 .214 r
F
.43428 .90802 m .47276 .96935 L .47054 .98277 L F
.25081 1.07275 m .26269 1.14023 L .23763 1.09447 L .609 0 .31 r
F
.25081 1.07275 m .27481 1.1174 L .26269 1.14023 L F
.23807 1.08423 m .26798 1.00205 L .25613 1.02092 L 1 .153 .518 r
F
.18364 1.2781 m .17947 1.25942 L .16772 1.30998 L .996 .114 .497 r
F
.18364 1.2781 m .19501 1.22757 L .17947 1.25942 L F
.82912 1.23119 m .8401 1.25967 L .85601 1.29297 L 0 0 .343 r
F
.81385 1.19975 m .8401 1.25967 L .82912 1.23119 L 0 0 .347 r
F
.60671 1.02732 m .64256 1.03278 L .61287 1.04274 L .778 0 .251 r
F
.57657 1.02296 m .60671 1.02732 L .61287 1.04274 L .822 0 .193 r
F
.7973 1.15731 m .81385 1.19975 L .82912 1.23119 L 0 0 .377 r
F
.61287 1.04274 m .64257 1.03278 L .6508 1.05154 L .827 0 .264 r
F
.41341 1.0183 m .4457 .9885 L .44133 1.01163 L .332 0 .238 r
F
.54503 1.00422 m .58075 1.0371 L .54712 1.01652 L .872 0 .142 r
F
.54503 1.00422 m .57657 1.02296 L .58075 1.0371 L F
.55718 .94555 m .59948 .87683 L .60373 .88216 L .153 0 .129 r
F
.55499 .93488 m .59948 .87683 L .55718 .94555 L .141 0 .113 r
F
.38318 1.03958 m .40699 1.03975 L .37492 1.05807 L .298 0 .196 r
F
.38318 1.03958 m .41341 1.0183 L .40699 1.03975 L F
.51297 .98158 m .54928 1.03095 L .51296 .99397 L .956 0 .147 r
F
.51297 .98158 m .54713 1.01652 L .54928 1.03095 L F
.72474 .96431 m .7717 1.07374 L .73497 .9806 L 0 0 .455 r
F
.72474 .96431 m .75967 1.05182 L .7717 1.07374 L F
.41341 1.0183 m .44133 1.01163 L .40699 1.03975 L .332 0 .238 r
F
.57657 1.02296 m .61287 1.04274 L .58075 1.0371 L .822 0 .193 r
F
.34607 1.06097 m .36652 1.07822 L .33604 1.07852 L .4 0 .21 r
F
.34607 1.06097 m .37492 1.05807 L .36652 1.07822 L F
.23807 1.08423 m .25613 1.02092 L .2246 1.10991 L 1 .153 .518 r
F
.7973 1.15731 m .82912 1.23119 L .81176 1.18628 L 0 0 .377 r
F
.70952 1.09429 m .73779 1.05931 L .74964 1.08122 L .898 0 .31 r
F
.69918 1.07143 m .73779 1.05931 L .70952 1.09429 L .893 0 .311 r
F
.65917 1.07193 m .68899 1.04932 L .69918 1.07143 L .879 0 .302 r
F
.6508 1.05154 m .68899 1.04932 L .65917 1.07193 L .859 0 .305 r
F
.29846 1.07669 m .31549 1.11942 L .28673 1.09612 L .537 0 .271 r
F
.29846 1.07669 m .32585 1.09807 L .31549 1.11942 L F
.51293 .97582 m .55283 .92474 L .55499 .93488 L .246 0 .156 r
F
.51295 .96062 m .55283 .92474 L .51293 .97582 L .248 0 .144 r
F
.19501 1.22757 m .19895 1.18965 L .17947 1.25942 L .993 .102 .485 r
F
.19501 1.22757 m .21367 1.15935 L .19895 1.18965 L F
.42999 .91793 m .46829 .99682 L .42566 .92801 L 1 .003 .221 r
F
.42999 .91793 m .47054 .98277 L .46829 .99682 L F
.23763 1.09447 m .25039 1.16437 L .22428 1.11703 L .591 0 .31 r
F
.23763 1.09447 m .26269 1.14023 L .25039 1.16437 L F
.82912 1.23119 m .85601 1.29297 L .8446 1.2634 L 0 0 .343 r
F
.55939 .95674 m .60373 .88216 L .60802 .88796 L .163 0 .142 r
F
.55718 .94555 m .60373 .88216 L .55939 .95674 L .153 0 .129 r
F
.61287 1.04274 m .6508 1.05154 L .61923 1.06039 L .827 0 .264 r
F
.58075 1.03711 m .61287 1.04274 L .61923 1.06039 L .866 0 .218 r
F
.81176 1.18628 m .82912 1.23119 L .8446 1.2634 L 0 0 .373 r
F
.61923 1.06039 m .6508 1.05154 L .65917 1.07193 L .863 0 .271 r
F
.54713 1.01652 m .58506 1.0534 L .54928 1.03095 L .914 0 .177 r
F
.54713 1.01652 m .58075 1.03711 L .58506 1.0534 L F
.37492 1.05807 m .40048 1.06191 L .36652 1.07822 L .343 0 .216 r
F
.37492 1.05807 m .40699 1.03975 L .40048 1.06191 L F
.51296 .99397 m .55148 1.04708 L .51294 1.00793 L .987 0 .178 r
F
.51296 .99397 m .54928 1.03095 L .55148 1.04708 L F
.40699 1.03975 m .44133 1.01163 L .4369 1.03426 L .35 0 .236 r
F
.58075 1.03711 m .61923 1.06039 L .58506 1.0534 L .866 0 .218 r
F
.33604 1.07852 m .35798 1.09985 L .32585 1.09807 L .427 0 .232 r
F
.33604 1.07852 m .36652 1.07822 L .35798 1.09985 L F
.40699 1.03975 m .4369 1.03426 L .40048 1.06191 L .35 0 .236 r
F
.51292 .99145 m .55499 .93488 L .55718 .94555 L .246 0 .165 r
F
.51293 .97582 m .55499 .93488 L .51292 .99145 L .246 0 .156 r
F
.28673 1.09612 m .30495 1.14237 L .27481 1.1174 L .536 0 .28 r
F
.28673 1.09612 m .31549 1.11942 L .30495 1.14237 L F
.42566 .92801 m .46601 1.01151 L .42128 .93834 L 1 .003 .227 r
F
.42566 .92801 m .46829 .99682 L .46601 1.01151 L F
.72001 1.11794 m .74964 1.08122 L .76165 1.10364 L .904 0 .31 r
F
.70952 1.09429 m .74964 1.08122 L .72001 1.11794 L .898 0 .31 r
F
.81176 1.18628 m .8446 1.2634 L .82643 1.21606 L 0 0 .373 r
F
.7884 1.12568 m .81176 1.18628 L .82643 1.21606 L 0 0 .408 r
F
.66768 1.0937 m .69918 1.07143 L .70952 1.09429 L .896 0 .301 r
F
.65917 1.07193 m .69918 1.07143 L .66768 1.0937 L .879 0 .302 r
F
.7884 1.12568 m .82643 1.21606 L .80191 1.152 L 0 0 .408 r
F
.55939 .95674 m .60802 .88796 L .56163 .96846 L .163 0 .142 r
F
.61923 1.06039 m .65917 1.07193 L .62569 1.07979 L .863 0 .271 r
F
.58506 1.0534 m .61923 1.06039 L .62569 1.07979 L .899 0 .235 r
F
.54928 1.03095 m .58943 1.07144 L .55148 1.04708 L .945 0 .201 r
F
.54928 1.03095 m .58506 1.0534 L .58943 1.07144 L F
.62569 1.07979 m .65917 1.07193 L .66768 1.0937 L .891 0 .276 r
F
.51294 1.00793 m .5537 1.06472 L .51293 1.02319 L 1 0 .201 r
F
.51294 1.00793 m .55148 1.04708 L .5537 1.06472 L F
.36652 1.07822 m .39386 1.08485 L .35798 1.09985 L .373 0 .229 r
F
.36652 1.07822 m .40048 1.06191 L .39386 1.08485 L F
.32585 1.09807 m .3493 1.12287 L .31549 1.11942 L .445 0 .248 r
F
.32585 1.09807 m .35798 1.09985 L .3493 1.12287 L F
.58506 1.0534 m .62569 1.07979 L .58943 1.07144 L .899 0 .235 r
F
.51291 1.00756 m .55718 .94555 L .55939 .95674 L .247 0 .174 r
F
.51292 .99145 m .55718 .94555 L .51291 1.00756 L .246 0 .165 r
F
.42128 .93834 m .46369 1.02683 L .41685 .94899 L 1 .004 .232 r
F
.42128 .93834 m .46601 1.01151 L .46369 1.02683 L F
.40048 1.06191 m .4369 1.03426 L .43241 1.05692 L .363 0 .237 r
F
.27481 1.1174 m .29424 1.16678 L .26269 1.14023 L .533 0 .286 r
F
.27481 1.1174 m .30495 1.14237 L .29424 1.16678 L F
.73066 1.14239 m .76165 1.10364 L .77381 1.12665 L .91 0 .311 r
F
.72001 1.11794 m .76165 1.10364 L .73066 1.14239 L .904 0 .31 r
F
.40048 1.06191 m .43241 1.05692 L .39386 1.08485 L .363 0 .237 r
F
.67632 1.11669 m .70952 1.09429 L .72001 1.11794 L .909 0 .301 r
F
.66768 1.0937 m .70952 1.09429 L .67632 1.11669 L .896 0 .301 r
F
.62569 1.07979 m .66768 1.0937 L .63225 1.10076 L .891 0 .276 r
F
.58943 1.07144 m .62569 1.07979 L .63225 1.10076 L .925 0 .247 r
F
.55148 1.04708 m .59388 1.09105 L .5537 1.06472 L .969 0 .22 r
F
.55148 1.04708 m .58943 1.07144 L .59388 1.09105 L F
.63225 1.10076 m .66768 1.0937 L .67632 1.11669 L .912 0 .281 r
F
.51293 1.02319 m .55597 1.08372 L .51292 1.03958 L 1 .001 .217 r
F
.51293 1.02319 m .5537 1.06472 L .55597 1.08372 L F
.51289 1.02421 m .55939 .95674 L .56163 .96846 L .249 0 .182 r
F
.51291 1.00756 m .55939 .95674 L .51289 1.02421 L .247 0 .174 r
F
.31549 1.11942 m .34048 1.14718 L .30495 1.14237 L .456 0 .259 r
F
.31549 1.11942 m .3493 1.12287 L .34048 1.14718 L F
.35798 1.09985 m .38714 1.10863 L .3493 1.12287 L .393 0 .24 r
F
.35798 1.09985 m .39386 1.08485 L .38714 1.10863 L F
.58943 1.07144 m .63225 1.10076 L .59388 1.09105 L .925 0 .247 r
F
.26269 1.14023 m .28335 1.19253 L .25039 1.16437 L .53 0 .291 r
F
.26269 1.14023 m .29424 1.16678 L .28335 1.19253 L F
.73066 1.14239 m .77381 1.12665 L .74147 1.16768 L .91 0 .311 r
F
.43242 1.05691 m .47016 1.0402 L .42786 1.07994 L .36 0 .231 r
F
.39386 1.08485 m .43241 1.05692 L .42786 1.07994 L .373 0 .239 r
F
.39386 1.08485 m .42786 1.07994 L .38714 1.10863 L F
.6851 1.14084 m .72001 1.11794 L .73066 1.14239 L .92 0 .302 r
F
.67632 1.11669 m .72001 1.11794 L .6851 1.14084 L .909 0 .301 r
F
.63225 1.10076 m .67632 1.11669 L .63894 1.12315 L .912 0 .281 r
F
.59388 1.09105 m .63225 1.10076 L .63894 1.12315 L .946 0 .256 r
F
.5537 1.06472 m .59841 1.11211 L .55597 1.08372 L .987 0 .234 r
F
.5537 1.06472 m .59388 1.09105 L .59841 1.11211 L F
.42786 1.07994 m .47016 1.0402 L .46784 1.06083 L .358 0 .232 r
F
.51292 1.03958 m .55827 1.10397 L .51291 1.057 L 1 .001 .23 r
F
.51292 1.03958 m .55597 1.08372 L .55827 1.10397 L F
.51289 1.02421 m .56163 .96846 L .51288 1.04143 L .249 0 .182 r
F
.63894 1.12315 m .67632 1.11669 L .6851 1.14084 L .929 0 .284 r
F
.30495 1.14237 m .33151 1.17273 L .29424 1.16678 L .464 0 .267 r
F
.30495 1.14237 m .34048 1.14718 L .33151 1.17273 L F
.3493 1.12287 m .38032 1.13333 L .34048 1.14718 L .407 0 .248 r
F
.3493 1.12287 m .38714 1.10863 L .38032 1.13333 L F
.59388 1.09105 m .63894 1.12315 L .59841 1.11211 L .946 0 .256 r
F
.42786 1.07994 m .46784 1.06083 L .42324 1.10351 L .358 0 .232 r
F
.38714 1.10863 m .42786 1.07994 L .42323 1.10352 L .38 0 .243 r
F
.69403 1.16608 m .73066 1.14239 L .74147 1.16768 L .93 .001 .303 r
F
.6851 1.14084 m .73066 1.14239 L .69403 1.16608 L .92 0 .302 r
F
.38714 1.10863 m .42323 1.10352 L .38032 1.13333 L .38 0 .243 r
F
.55597 1.08372 m .60302 1.13451 L .55827 1.10397 L 1 0 .245 r
F
.55597 1.08372 m .59841 1.11211 L .60302 1.13451 L F
.63894 1.12315 m .6851 1.14084 L .64573 1.14686 L .929 0 .284 r
F
.59841 1.11211 m .63894 1.12315 L .64573 1.14686 L .963 0 .264 r
F
.42324 1.10351 m .46784 1.06083 L .46549 1.082 L .358 0 .234 r
F
.51291 1.057 m .56062 1.12541 L .51289 1.07539 L 1 .002 .24 r
F
.51291 1.057 m .55827 1.10397 L .56062 1.12541 L F
.64573 1.14686 m .6851 1.14084 L .69403 1.16608 L .944 0 .287 r
F
.29424 1.16678 m .32238 1.19949 L .28335 1.19253 L .469 0 .274 r
F
.29424 1.16678 m .33151 1.17273 L .32238 1.19949 L F
.34048 1.14718 m .37337 1.15898 L .33151 1.17273 L .417 0 .255 r
F
.34048 1.14718 m .38032 1.13333 L .37337 1.15898 L F
.59841 1.11211 m .64573 1.14686 L .60302 1.13451 L .963 0 .264 r
F
.69403 1.16608 m .74147 1.16768 L .7031 1.1924 L .93 .001 .303 r
F
.42324 1.10351 m .46549 1.082 L .41854 1.12777 L .358 0 .234 r
F
.38032 1.13333 m .42323 1.10352 L .41853 1.12777 L .386 0 .247 r
F
.38032 1.13333 m .41853 1.12777 L .37337 1.15898 L F
.55827 1.10397 m .6077 1.15818 L .56062 1.12541 L 1 .001 .253 r
F
.55827 1.10397 m .60302 1.13451 L .6077 1.15818 L F
.64573 1.14686 m .69403 1.16608 L .65264 1.17183 L .944 0 .287 r
F
.60302 1.13451 m .64573 1.14686 L .65264 1.17183 L .977 .001 .27 r
F
.51289 1.07539 m .563 1.14797 L .51288 1.09471 L 1 .002 .248 r
F
.51289 1.07539 m .56062 1.12541 L .563 1.14797 L F
.41854 1.12777 m .46549 1.082 L .4631 1.10381 L .358 0 .237 r
F
.65264 1.17183 m .69403 1.16608 L .7031 1.1924 L .956 .001 .291 r
F
.33151 1.17273 m .36631 1.18561 L .32238 1.19949 L .423 0 .261 r
F
.33151 1.17273 m .37337 1.15898 L .36631 1.18561 L F
.60302 1.13451 m .65264 1.17183 L .6077 1.15818 L .977 .001 .27 r
F
.41854 1.12777 m .4631 1.10381 L .41376 1.15279 L .358 0 .237 r
F
.37337 1.15898 m .41853 1.12777 L .41376 1.1528 L .39 0 .251 r
F
.37337 1.15898 m .41376 1.1528 L .36631 1.18561 L F
.56062 1.12541 m .61247 1.18307 L .563 1.14797 L 1 .002 .261 r
F
.56062 1.12541 m .6077 1.15818 L .61247 1.18307 L F
.65264 1.17183 m .7031 1.1924 L .65967 1.198 L .956 .001 .291 r
F
.6077 1.15818 m .65264 1.17183 L .65967 1.198 L .989 .001 .276 r
F
.6077 1.15818 m .65967 1.198 L .61247 1.18307 L F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{326.25, 529.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005600024B000`400?l00000o`00003oo`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom7
0?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00o`3ooom70?ooo`00X03oool60?lXU0<0obBDW@3o
ool009T0oooo3@3o:9@60?lTU9X0oooo002H0?ooo`030?l/U03o:9@0obRD00/0obRD2@3o99BG0?oo
o`00UP3oool30?l/U0d0obRD303o99BD0?ooo`00U@3oool40?l/U0d0obRD3P3o99BB0?ooo`00T`3o
ool60?l/U0d0obRD3P3o99@20>hPU900oooo002B0?ooo`L0obbD3@3o:9@>0?lTU0<0kR2DS`3oool0
0900oooo2@3o;9@=0?lXU0h0obBD103^89B>0?ooo`00S`3oool:0?l/U0d0obRD3P3o99@60>hPU8`0
oooo002=0?ooo``0obbD3@3o:9@>0?lTU0L0kR2DR`3oool008/0oooo3P3o;9@=0?lXU0h0obBD203^
89B:0?ooo`00R`3oool>0?l/U0d0obRD3P3o99@90>hPU8T0oooo002:0?ooo`l0obbD3@3o:9@>0?lT
U0/0kR2DQ`3oool008T0oooo4@3o;9@<0?lXU0h0obBD303^89B60?ooo`00R03ooolB0?l/U0`0obRD
3P3o99@=0>hPU8D0oooo00270?oooa<0obbD303o:9@>0?lTU0h0kR2DQ03oool008H0oooo503o;9@<
0?lXU0h0obBD3P3^89@00`3N69@0oooo0?ooo`210?ooo`00Q@3ooolE0?l/U0`0obRD3P3o99@>0>hP
U080gQRDPP3oool008@0oooo5P3o;9@<0?lXU0h0obBD3P3^89@30=hHU840oooo00230?oooaL0obbD
303o:9@>0?lTU0h0kR2D103N69B00?ooo`00PP3ooolH0?l/U0`0obRD3P3o99@>0>hPU0@0gQRDP03o
ool00840oooo6@3o;9@<0?lXU0h0obBD3P3^89@50=hHU7l0oooo00200?oooaX0obbD1P3o:9@60?l/
U0@0obRD2P3o99@>0>hPU0H0gQRDOP3oool007l0oooo9`3o;9@70?lXU0L0obBD3P3^89@70=hHU7d0
oooo001n0?ooobP0obbD2P3o:9@40?lTU0h0kR2D1`3N69Am0?ooo`00OP3oool00`3o<9@0obbD0?l/
U00U0?l/U0d0obRD3P3^89@90=hHU7`0oooo001m0?ooo`80oc2D9`3o;9@=0?lXU0h0kR2D00<0gQbD
0=hHU03N69@01`3N69Ak0?ooo`00O@3oool20?l`U2L0obbD3@3o:9@>0>hPU080gQbD2@3N69Aj0?oo
o`00O03oool30?l`U2L0obbD3@3o:9@>0>hPU0<0gQbD203N69@E0?ooo`D0ohFD0`3oPIAM0?ooo`00
N`3oool40?l`U2L0obbD3@3o:9@>0>hPU0<0gQbD2@3N69@>0?ooo`/0ohFD1@3oPIAK0?ooo`00N`3o
ool40?l`U2L0obbD3@3o:9@>0>hPU0@0gQbD2@3N69@<0?ooo`030?n=U03oQI@0ohFD00T0ohFD1`3o
PIAI0?ooo`00NP3oool50?l`U2L0obbD3@3o:9@>0>hPU0D0gQbD2@3N69@:0?ooo`80ohfD2P3oQI@:
0?n1U5L0oooo001i0?ooo`H0oc2D9`3o;9@=0?lXU0h0kR2D1P3N79@80=hHU0P0oooo103oSI@:0?n5
U0X0oh6D00<0ogfD0?ooo`3oool0E03oool005d0oooo2`1Z09@00`1R09@0oooo0?ooo`0>0?ooo`H0
oc2D9`3o;9@=0?lXU0h0kR2D1P3N79@80=hHU0030=DDU03oool0oooo00@0oooo1@3oSI@:0?n5U0X0
oh6D0P3oOIAE0?ooo`00G03oool207<0U0X0JP2D0`1R09@=0?ooo`L0oc2D9`3o;9@=0?lXU0d0kR2D
203N79@70=hHU0030=DDU03oool0oooo0080oooo1P3oSI@:0?n5U0/0oh6D0`3oOIAD0?ooo`00F`3o
ool307<0U0X0JP2D101R09@<0?ooo`P0oc2D9P3o;9@<0?lXU0h0kR2D2@3N79@60=hHU080eABD0P3o
ool70?n=U0X0ohFD2`3oPI@40?mmU5<0oooo001J0?ooo`@0L`2D2P1Z09@60680U0T0oooo2@3o<9@V
0?l/U0`0obRD0P3^99`<0>hPU0X0gQbD1@3N69@20=DDU0T0ohfD2P3oQI@:0?n1U0H0ogfDDP3oool0
05T0oooo1P1c09@906X0U0P0HP2D1P3oool:0?l`U2H0obbD303o:9@30>hTW0/0kR2D2P3N79@40=hH
U0040=DDU03oSI@0ohfD0=DDU0P0ohfD2@3oQI@;0?n1U0L0ogfDD@3oool005P0oooo1`1c09@:06X0
U0P0HP2D1@3oool:0?l`U2H0obbD303o:9@40>hTW0X0kR2D2`3N79@30=hHU0030=DDU03oSI@0ohfD
0080eABD1`3oSI@90?n5U0/0oh6D203oOIA@0?ooo`00E`3oool807<0U0X0JP2D2@1R09@00`1B09@0
oooo0?ooo`0<0?l`U2D0obbD303o:9@60>hTW0L0kR2D3@3N79@20=hHU0030?nIU03oSI@0ohfD0080
eABD1P3oSI@:0?n5U0/0oh6D2@3oOIA?0?ooo`00E@3oool;07<0U0T0JP2D2@1R09@20580U0d0oc2D
9@3o;9@<0?lXU0L0kRBL1P3^89@>0=hLU080oiVD0P3oSI@30=DDU0D0ohfD2P3oQI@;0?n1U0T0ogfD
00<0ogVD0?ooo`3oool0C03oool005D0oooo2`1c09@906X0U0T0HP2D0P1B09@=0?l`U2D0obbD303o
:9@80>hTW0D0kR2D3@3N79@30?nIU080ohfD0`3E59@50?n=U0X0ohFD2P3oPI@:0?mmU0030?miU03o
ool0oooo04`0oooo001D0?ooo``0L`2D2@1Z09@90680U0040580U03o<9@0oc2D0580U0/0oc2D9@3o
;9@<0?lXU0X0kRBL0`3^89@<0=hLU0@0oiVD0P3oSI@40=DDU0@0ohfD2P3oQI@:0?n1U0X0ogfD0P3o
NIA=0?ooo`00E03oool<07<0U0X0L`2L00<0HP2L0680U01R09@01@1R09@30?l`U080DP2D2P3o<9@P
0?l/U0D0oc2D1P3o;9`60?lXU0/0kRBL0P3^89@;0=hLU0D0oiVD0P3oSI@40=DDU0@0ohfD2@3oQI@;
0?n1U0T0ogfD0`3oNIA=0?ooo`00D`3oool<07<0U080N`2D2@1c09`30680W0@0HP2D103o<9@30580
U0X0oc2D6@3o;9@;0?l`U0`0obbL303^99`;0=hLU0H0oiVD00<0ohfD0=DDU03E59@0103E59@20?n=
U0X0ohFD2`3oPI@90?mmU0@0ogVDC03oool005<0oooo2`1c09@307/0U0T0L`2L1@1R09`20680U004
0?lhU03o<9@0oc2D0?l`U0@0DP2D2@3o<9@I0?l/U0/0oc2D303o;9`<0>hTW0X0gQbD1`3oVI@70=DD
U080ohfD2P3oQI@:0?n1U0X0ogfD103oNIA<0?ooo`00DP3oool;07<0U0@0N`2D2P1c09`60680W004
0?lhU03o<9@0oc2D0?l`U0D0DP2D203o<9@I0?l/U0/0oc2D303o;9`<0>hTW0T0gQbD1`3oVI@00`3o
SI@0cABD0=DDU0060=DDU0030?n=U03oQI@0ohFD00P0ohFD2P3oPI@90?mmU0H0ogVDB`3oool00540
oooo2`1c09@607/0U0T0L`2L1@1R09`20?lhU0<0oc2D1P1B09@70?l`U1T0obbD2`3o<9@<0?l/W0`0
kRBL203N79@80?nIU0030?n=U03=59@0cABD00L0eABD2P3oQI@:0?n1U0T0ogfD1P3oNIA;0?ooo`00
D@3oool:07<0U0L0N`2D2@1c09`50680W080ocRD0`3o<9@70580U0H0oc2D6@3o;9@;0?l`U0`0obbL
303^99`70=hLU0T0oiVD00<0ohfD0<dDU03=59@01`3E59@90?n5U0X0oh6D2P3oOI@70?miU4X0oooo
001@0?ooo`X0L`2D201k09@:07<0W0<0HP2L103o>9@20?l`U0P0DP2D1P3o<9@H0?l/U0/0oc2D303o
;9`<0>hTW0H0gQbD2P3oVI@0103oSI@0cABD0<dDU03=59@70=DDU0P0oh6D0`3oOI@70?n1U0T0ogfD
203oNIA:0?ooo`00D03oool807<0U0/0N`2D2@1c09`30680W0@0ocRD0`3o<9@70580U0H0oc2D603o
;9@;0?l`U0`0obbL303^99`50=hLU0/0oiVD00@0ohfD0<dDU03=59@0cABD1`3E59@80?n1U0H0ogfD
103oPI@90?mmU0T0ogVDB@3oool004l0oooo2@1c09@;07/0U0T0L`2L0P1R09`50?lhU0<0oc2D00<0
DP2L0580U01B09@01@1B09@50?l`U1P0obbD2`3o<9@<0?l/W0`0kRBL103N79@;0?nIU080ohfD103=
59@70=DDU0L0oh6D4`3oOI@90?miU4T0oooo001>0?ooo`T0L`2D301k09@907<0W080HP2L1@3o>9@3
0?l`U080DP2L1P1B09@00`1:09@0oc2D0?l`U0020?l`U1P0obbD2`3o<9@<0?l/W0`0kRBL103N79@;
0?nIU0030?n=U03=59@0cABD00@0cABD1P3E59@60?n1U1@0ogfD2P3oNIA80?ooo`00CP3oool00`1Z
09@0L`2D07<0U00607<0U0`0N`2D2P1c09`60?lhU0<0oc2D0`1B09`50580U080BP2D0`3o<9@H0?l/
U0P0oc2D0`3o=9@60?l`W0H0obbL2`3^99`40=hLU0030?nQU03oVI@0oiVD00T0oiVD00<0ohfD0<dD
U03=59@0103=59@70=DDU0D0oh6D4`3oOI@;0?miU4P0oooo001>0?ooo`0306X0U01c09@0L`2D00D0
L`2D301k09@208<0U0T0L`2L1`3o>9@30?l`U0<0DP2L101B09@204X0U0@0oc2D5`3o;9@40?l`U0L0
ocBD2`3o<9`<0>hTW0030=hLW03N79@0gQbD0080oj6D2`3oVI@00`3oSI@0cABD0<dDU0050<dDU0H0
eABD1@3oPI@C0?mmU0/0ogVD00<0og6D0?ooo`3oool0A@3oool004h0oooo0P1Z09@607<0U0/0N`2D
0`2309@807<0W0P0ocRD0`3o<9@40580W0@0DP2D0P1:09@30?l`U1L0obbD2`3o=9@;0?l`W080mRRL
2P3^99`20=hLW0030=hLU03oXI@0oj6D00/0oiVD00<0ohfD0<dDU03=59@01@3=59@70=DDU0<0oh6D
503oOI@;0?miU0030?maU03oool0oooo04D0oooo001=0?ooo`<0JP2D1@1c09@;07/0U0@0P`2D201c
09`80?lhU0<0oc2D1@1B09`30580U0<0BP2D0P3o<9@F0?l/U080oc2D2P3o=9@;0?l`W0<0mRRL2@3^
99`20=hLW0<0oj6D2P3oVI@20?n=U0P0cABD1P3E59@30?n1U1<0ogfD2`3oNI@20?maU4L0oooo001=
0?ooo`<0JP2D1@1c09@:07/0U0H0P`2D1P1c09`90?lhU0<0oc2D1P1B09`20580U0@0BP2D00<0oc2D
0?l/U03o;9@04P3o;9@40?l`U0X0ocBD2`3o<9`50?HXW0L0kRBL00<0gQbL0?nQU03oXI@00P3oXI@9
0?nIU0030?nIW03oSI@0ohfD00P0cABD1P3E59@00`3549@0oh6D0?n1U00C0?mmU0/0ogVD0`3oLIA6
0?ooo`00C@3oool406X0U0<0L`2D2P1k09@708<0U0H0L`2L2P3o>9@20?l`U0L0DP2L00<0DP2D04X0
U01:09@00P1:09@00`3o<9@0obbD0?l/U00A0?l/U0D0oc2D2P3o=9@;0?l`W0H0mRRL1P3^99`00`3N
79`0oj6D0?nQU0020?nQU0P0oiVD0P3oVI`20?n=U0T0cABD1@3E59@00`3549@0oh6D0?mmU00C0?mm
U0/0ogVD0`3oLIA60?ooo`00C03oool506X0U0<0L`2D2@1k09@808<0U0H0L`2L2P3o>9@30?l`U0L0
DP2L1@1:09@A0?l/U0L0oc2D2P3o=9@;0?l`W0L0mRRL1@3^99`40?nQU0P0oiVD0`3oVI`20?n=U0X0
cABD103E59@20<D@U1<0ogfD2`3oNI@40?maU4H0oooo001<0?ooo`H0JP2D00<0L`2D07/0U01k09@0
1`1k09@:08<0U0@0L`2L2`3o>9@30?l`U0P0DP2L1@1:09@?0?l/U0P0oc2D2P3o=9@;0?l`W0T0mRRL
0P3^99`50?nQU0L0oiVD103oVI`20?n=U0X0cABD0`3E59@30<D@U1<0ogfD2`3oNI@40?maU4H0oooo
001<0?ooo`H0JP2D00<0L`2D07/0U01k09@01P1k09@;08<0U0@0L`2L2`3o>9@30?l`U0P0DP2L1@1:
09@=0?l/U0X0oc2D2P3o=9@;0?l`W0X0mRRL00<0kRBL0?nQU03oXI@00P3oXI@00`3oYI`0oiVD0?nI
U0040?nIU0@0oiVL0P3oSI@<0<dDU080eABD103549@B0?mmU0/0ogVD1@3oLIA50?ooo`00B`3oool7
06X0U0X0N`2D2P2309@307<0W0d0ocRD0P3o<9@80580W0H0BP2D2P3o;9@<0?l`U0X0ocBD2`3o<9`:
0?HXW0@0oj6D0P3oYI`50?nIU0D0oiVL0P3oSI@<0<dDU080eABD103549@B0?mmU0X0ogVD1P3oLIA5
0?ooo`00B`3oool806X0U0T0N`2D2P2309@307/0W0d0ocRD0`3o<9@70580W0L0BP2D203o;9@20?lX
U0/0oc2D1`3o=9@30?lhW0H0ocBL1@3o<9`90?HXW0D0oj6D0P3oYI`40?nIU0H0oiVL0P3oSI@=0<dD
U0030=DDU03549@0aA2D0080aA2D4@3oOI@;0?miU0H0og6DA@3oool004/0oooo201Z09@907/0U0T0
P`2D0P2;19@00`1k09`0ocRD0?lhU00=0?lhU080oc2D201B09`704X0U0H0obbD0`3o:9@;0?l`U0@0
ocBD1P3o>9`;0?ldW0T0mRRL103oXI@30?nUW0<0oiVD1`3oVI`00`3oSI@0ohVD0<dDU00<0<dDU0H0
aA2D403oOI@;0?miU0L0og6DA03oool004X0oooo2@1Z09@:07/0U0L0P`2D0`2;19@00`1k09`0ocRD
0?lhU00=0?lhU080oc2D201B09`704X0U0D0obbD103o:9@;0?l`U0X0ocRL2`3o=9`20?H/W0H0mRRL
103oXI@40?nUW080oiVD1`3oVI`30?n9U0d0cABD1P3549@@0?mmU0X0ogVD203oLIA40?ooo`00BP3o
ool:06X0U0T0N`2D1P2309@408/4U100ocRD0P3o<9@80580W0P0BP2D0`3o;9@50?lXU0/0oc2D2P3o
>9`;0?ldW0@0mRbL0`3f:9`40?nQU0D0ojFL00<0oiVD0?nIW03oVI`01P3oVI`30?n9U0d0cABD1`35
49@>0?mmU0/0ogVD203oLIA40?ooo`00BP3oool:06X0U0T0N`2D1@2309@508/4U140ocRD00<0oc2D
0580W01B09`01P1B09`904X0U0030?l/U03o:9@0obRD00@0obRD2`3o<9@:0?lhW0/0ocBL1@3f;9`2
0?HXW0@0oj6D103oYI`:0?nIW0<0ohVD303=59@80<D@U0h0ogfD2P3oNI@90?maU4@0oooo00190?oo
o`/0JP2D2P1k09@308<0U0D0R`BD4P3o>9@20?l`U0L0DP2L2@1:09@70?lXU0/0oc2D2P3o>9`;0?ld
W0H0mRbL103oXI@50?nUW0X0oiVL0`3oRI@<0<dDU0P0aA2D3P3oOI@:0?miU0X0og6D@`3oool004T0
oooo2`1Z09@:07/0U080P`2D1P2;19@B0?lhU080oc2D201B09`904X0U0H0obRD2`3o<9@:0?lhW0/0
ocBL1@3f;9`40?nQU0H0ojFL2P3oVI`30?n9U0/0cABD2P3549@<0?mmU0/0ogVD2P3oLIA30?ooo`00
B@3oool<06X0U0T0N`2D00<0P`2D08/4U02;19@0102;19@D0?lhU0030?l`U01B09`0DP2L00H0DP2L
2@1:09@00`1109@0obRD0?lXU0030?lXU0/0oc2D2P3o>9`;0?ldW0@0mRbL1@3oXI@60?nUW0X0oiVL
0P3oRI@<0<dDU0X0aA2D303oOI@:0?miU0/0og6D@`3oool004T0oooo301Z09@907/0U0L0R`BD00<0
ocbD0?lhU03o>9@04@3o>9@00`3o<9@0DP2L0580W0060580W0T0BP2D00<0@@2D0?lXU03o:9@00`3o
:9@;0?l`U0X0ocRL2`3o=9`40?H/W0@0oj6D1`3oYI`:0?nIW080ohVD2`3=59@<0<D@U0/0ogfD2P3o
NI@;0?maU4<0oooo00190?ooo``0JP2D2@1k09@00`2;09@0R`BD08/4U00408/4U0030?llU03o>9@0
ocRD0140ocRD0P3o<9@70580W0T0BP2D0P1109@40?lXU0/0oc2D2P3o>9`;0?ldW0<0mRbL00@0ojZD
0?nQU03oXI@0oj6D203oYI`:0?nIW080ohVD2`3=59@<0<D@U0030?miU03oOI@0ogfD00P0ogfD2@3o
NI@<0?maU0030?m]U03oool0oooo0400oooo00190?ooo``0JP2D201k09@208/0U0D0R`BD0`3o?9@B
0?lhU080oc2D1`1B09`904X0U0<0@@2D0P3o:9@20?lTU0X0oc2D203o>9`20?m0W0X0ocbL103f;9`0
0`3oZY@0oj6D0?nQU0090?nUW0X0oiVL00<0ohVD0?n9W03=59@02P3=59@=0<D@U0030?n1U03oOI@0
ogfD00H0ogfD2P3oNI@<0?maU0030?m]U03oool0oooo0400oooo00190?ooo``0JP2D00<0HP2D07/0
U01k09@01@1k09@208/0U0D0R`BD0`3o?9@C0?lhU0030?l`U01B09`0DP2L00D0DP2L2@1:09@30440
U0040?lXU03o99@0obBD0?lTU0X0oc2D1@3o>9`50?m0W0X0ocbL0P3f<9`00`3f;9`0ojZD0?nZU002
0?nQU0T0ojFL2@3oVI`30?n9W0/0cABD3@3549@20?n1U0L0ogfD2P3oNI@;0?maU080offD@P3oool0
04P0oooo3@1Z09@00`1R09@0N`2D07/0U00407/0U0@0R`2D102;19@40?llU180ocRD00<0oc2D0580
W01B09`01@1B09`904X0U0@0@@2D0`3o99@:0?l`U0<0ocRL1`3o@9`:0?llW080mS2L0`3oZY@00`3o
XI@0ojFL0?nUW0080?nUW0T0oiVL0`3oRI`:0<dDU0h0aA2D0`3oPI@60?mmU0T0ogVD303oLI@20?m]
U480oooo00180?ooo``0JP2D0P1R09@607/0U0@0R`2D0`2;19@50?llU180ocRD00<0oc2D0580W01B
09`01@1B09`904X0U0@0@@2D0`3o99@:0?l`U0X0od2L2P3o?9`20?H`W0<0ojZD2P3oYI`:0?nIW0<0
ohVL2P3=59@?0<D@U0<0oh6D103oOI@:0?miU0`0og6D0`3oKIA10?ooo`00B03oool<06X0U0<0HP2D
101k09@508/0U0<0R`BD1@3o?9@B0?lhU0030?l`U03o;9@0DP2L00H0DP2L2@1:09@40440U080obBD
2@3o<9@20?lhU0T0od2L2P3o?9`0103f<9`0ojZD0?nZU03oZY@;0?nUW0X0oiVL0`3oRI`:0<dDU0l0
aA2D103oPI@30?mmU0X0ogVD2`3oLI@40?m]U440oooo00180?ooo``0JP2D0`1R09@407/0U0D0R`2D
0`2;19@50?llU0030?m0U03o>9@0ocRD00l0ocRD0P3o;9@70580W0T0BP2D1@1109@20?lTU0L0oc2D
0`3o>9@90?m0W0X0ocbL00@0mS2L0?nZU03oZY@0ojZD2P3oYI`00`3oZY`0oiVL0?nIW0080?nIW080
ohVL2`3=59@@0<D@U0@0oh6D0P3oOI@90?miU0`0og6D103oKI@00`3oool000000?ooo`0n0?ooo`00
A@3oool30<d000/0JP2D101R09@307/0U0L0R`2D00<0R`BD0?llU03o?9@0103o?9@00`3o@9@0ocRD
0?lhU00@0?lhU0030?l/U01B09`0DP2L00D0DP2L2@1:09@50440U080obBD1P3o<9@40?lhU0T0od2L
2P3o?9`30?nZU0030?nZW03oYI`0ojFL00L0ojFL0P3oZY`90?nIW0<0ohVL2P3=59@A0<D@U0D0oh6D
2P3oNI@<0?maU0@0offD0P00000o0?ooo`00A@3oool00`3N0000c@000<d0000;06X0U0D0HP2D0P1k
09@708/0U00308/4U03o?9@0ocbD00<0ocbD0`3o@9@A0?lhU080obbD1P1B09`904X0U0H0@@2D00<0
obBD0?l`U03o<9@00P3o<9@60?lhU0T0od2L2@3o?9`40?nZU0030?nZW03oYI`0ojFL00H0ojFL0`3o
ZY`90?nIW0<0ohVL2P3=59@A0<D@U0D0oh6D00<0ogfD0?miU03oNI@01`3oNI@;0?maU0D0offD0P00
000o0?ooo`00A@3oool20=h000`0JP2D1@1R09@00`1k09@0R`2D08/0U00608/0U00308/4U03o?9@0
ocbD00<0ocbD0`3o@9@A0?lhU080obbD1`1B09`804X0U0H0@@2D00@0obBD0?l`U03o<9@0oc2D1`3o
>9@90?m0W0T0ocbL0`3oZY@20?nZW0L0ojFL103oZY`90?nIW080ohVL2`3=59@B0<D@U0@0oh6D0P3o
OI@70?miU0`0og6D1P3oKI@00`000000oooo0?ooo`0m0?ooo`00A@3oool20=h000/0JP2D1P1R09@0
0`1k09@0R`2D08/0U00608/0U0H0ocbD103o@9@@0?lhU0030?l/U01B09`0DP2L00H0DP2L201:09@7
0440U080oc2D203o>9@80?m0W0030?m@W03oA9`0odBL00H0odBL103oZY@20?nZW0L0ojFL103oZY`9
0?nIW0030?n9W03oQI`0aABL00X0cABD4P3549@40?n1U080ogfD1`3oNI@<0?maU0H0offD00<00000
0?ooo`3oool0?@3oool004D0oooo0P3N000;06X0U0H0HP2D2@2;09@50?llU0D0od2D4@3o>9@00`3o
;9@0DP2L0580W0050580W0P0BP2D201109@90?lhU0H0od2L0`3oD9`80?m4W0<0ojZD0`3oZY`60?nU
W0D0ojZL203oVI`30?n5W080aABL203=59@D0<D@U080oh6D103oOI@60?miU0/0og6D1`3oKI@00`00
0000oooo0?ooo`0m0?ooo`00A@3oool20=h000/0JP2D1P1R09@00`1J09@0R`2D08/0U00608/0U0D0
ocbD1@3o@9@A0?lhU0030?l/U01B09`0DP2L00D0DP2L201:09@80440U0T0ocRD103o@9`50?m@W0L0
odBL0`3oZY@30?nZW0H0ojFL1@3oZY`90?nIW0<0ohFL0P3559`80<dDU1@0aA2D0P3oPI@40?mmU0D0
ogVD303oLI@70?m]U0030000003oool0oooo03d0oooo00150?ooo`80gP002P1Z09@70680U00305X0
U02;09@0R`2D00D0R`2D1P3o?9@60?m0U100ocRD0P3o;9@70580W0P0BP2D201109@80?lhU080od2L
1`3oD9`60?m4W0@0ojZD0`3oZY`50?nUW0H0ojZL2@3oVI`30?n5W0<0aABL1`3=59@D0<D@U080oh6D
1@3oOI@40?miU0/0og6D203oKIA00?ooo`00A@3oool20=h000X0JP2D1`1R09@00`1J09@0R`2D08/0
U00508/0U0D0ocbD1`3o@9@@0?lhU080obbD00<0BP2L0580W01B09`0101B09`00`1109@0BP2D04X0
U00504X0U0P0@@2D203o>9@90?m@W0H0odBL0`3oZY@30?nZW0030?n^W03oYI`0ojFL0080ojFL1`3o
ZY`90?nIW0<0ohFL0`3559`60<dDU1D0aA2D00<0_A2D0?mmU03oOI@0103oOI@40?miU0/0og6D2@3o
KI@o0?ooo`00A@3oool00`3N0000JP2D06X0U00806X0U0L0HP2D0P1J09@608/0U0H0ocbD1`3o@9@@
0?lhU0040?ldW03o;9@0BP2L04X0W0D0DP2L0P1109@604X0U0T0@@2D1P3o>9@00`3oA9@0oe2L0?m@
W0070?m@W0D0odBL103oZY@30?nZW0030?n^W03oYI`0ojFL0080ojFL1`3oZY`80?nIW0@0ohFL1035
59`50<dDU0030;d@U03549@0aA2D0180aA2D00<0_A2D0?mmU03oOI@01@3oOI@20?miU0/0og6D203o
KI@00`000000offD0?ooo`0n0?ooo`00AP3oool:06X0U0L0HP2D0`1J09@508/0U0H0ocbD203o@9@>
0?lhU080ocBL0P3o;9@204X0W0@0DP2L0P1109@604X0U0X0@@2D103o>9@20?m4U0T0oe2L1@3oA9`3
0?nZU0<0ojZL0P3o[Y`30?nUW0P0ojZL203oVI`40?n5W0D0aABL103=59@00`2m49@0aA2D0<D@U00A
0<D@U080_A2D1`3oOI@20?miU0/0og6D1`3oKI@00`000000offD0?m]U00o0?ooo`00A@3oool;06X0
U0L0HP2D0`1J09@408/0U00309`4U03o?9@0ocbD00<0ocbD2@3o@9@>0?lhU080ocBL0P3o;9@304X0
W0<0DP2L0`1109@604X0U0T0@@2D0`3o>9@30?m4U0T0oe2L103oA9`30?nZU0@0ojZL0P3o[Y`20?nU
W0T0ojZL203oVI`40?n5W0D0aABL103=59@20;d@U180aA2D0`2m49@70?mmU0030?miU03oLI@0og6D
00P0og6D203oKI@00`000000offD0?m]U00o0?ooo`00A@3oool00`1k09@0JP2D0?H0600806X0U0H0
HP2D101J09@408/0U0H0ocbD2@3o@9@=0?lhU0<0ocBL0P3o;9@404X0W080DP2L101109@504X0U0X0
@@2D00<0ocRD0?m4U03oA9@00P3oA9@90?m@W0<0oe2T103oZY@30?nZW0<0ojjL00<0ojFL0?nZW03o
ZY`0203oZY`80?nIW0@0ohFL1P3559`20<dDU0<0_A2D4@3549@40;d@U0L0ogfD2`3oLI@80?m]U003
0000003oKI@0offD03l0oooo00150?ooo`80N`2D00<0mP0H06X0U01Z09@01P1Z09@60680U0@0FP2D
0`2;09@00`2L19@0ocbD0?llU0040?llU0T0od2D00<0odBD0?lhU03o>9@02P3o>9@40?ldW0030?l/
U01:09`0BP2L00<0BP2L00<0DP2L0440U01109@00`1109@404X0U0X0@@2D1@3oA9@80?m@W0040?mU
W03oD:@0oe2T0?m@Y0<0ojZD0`3oZY`40?n^W0X0ojZL203oVI`50?mmW0H0aABL0P3=59@40;d@U100
aA2D102m49@70?mmU0/0og6D1`3oKI@010000000offD0?m]U03oKI@o0?ooo`00A@3oool207/0U080
mP0H1P1Z09@70680U0D0FP2D0P2;09@00`2L19@0ocbD0?llU0030?llU0X0od2D00<0odBD0?lhU03o
>9@02@3o>9@50?ldW0030?l/U01:09`0BP2L00@0BP2L1@1109@404X0U0X0@@2D00<0<@2D0?m4U03o
A9@00P3oA9@70?m@W080ofFL0P3oD:@40?nZU0<0ojZL103o[Y`:0?nZW0P0oiVL1@3oOI`70<DDW003
0<dDU02m49@0_A2D0080_A2D3`3549@60;d@U0H0ogfD2P3oLI@80?m]U0040000003oKI@0offD0?m]
U3l0oooo00150?ooo`80N`2D0P3f01P606X0U0H0HP2D1P1J09@00`2;09@0W0BD0?llU0050?llU0T0
od2D0`3oA9@90?lhU0H0ocBL00<0obbD0?HTU01:09`0101:09`60440U0@0BP2D2@1109@20340U0<0
odBD1P3oD9`30?mUW080oe2T0`3oZY@30?nZW0@0ojjL00<0ok:L0?nZW03oZY`01`3oZY`00`3o[Y`0
oiVL0?nIW0060?nIW0D0ogfL1`3559`50;d@U0l0aA2D1P2m49@50?mmU0/0og6D1`3oKI@2000000<0
offD?`3oool004D0oooo0P1k09@20?H060H0JP2D1P1R09@605X0U00308/0U02L19@0ocbD00D0ocbD
2@3o@9@30?m4U0T0ocRD1P3o=9`20?HTU0030440W01:09`0BP2L00<0BP2L1P1109@304X0U0T0@@2D
0P0a09@30?m4U0@0oe2L1@3oII`00`3oD:@0ojZD0?nZU0020?nZU0<0ojZL103o[Y`00`3o/Y`0ojZL
0?nZW0060?nZW080ojjL203oVI`40?mmW0P0aABL1P2m49@>0<D@U0H0_A2D1@3oOI@;0?maU0L0offD
0P0000030?m]U3l0oooo00150?ooo`80N`2D0`3f01P506X0U0H0HP2D1P1J09@209`4U0D0ocbD2P3o
@9@40?m4U0L0ocRD1`3o=9`0103o<9`0mRBD0440W01109`404X0W0L0@@2D0P1:09@90440U0<0<@2D
0P3oA9@30?m@W0H0ofFL103oZY@30?nZW0@0ojjL0P3o/Y`70?nZW0<0ojjL203oVI`40?mmW0P0aABL
1P2m49@=0<D@U0P0_A2D0`3oOI@;0?maU0L0offD0P0000040?m]U0030?mYU03oool0oooo03`0oooo
00150?ooo`80N`2D0`3f01P506X0U0D0HP2D1`1J09@00`1:08/0ocbD0?llU0040?llU0T0od2D1@3o
A9@70?lhU0H0ocBL0P3o<9`20?HTU080@@2L0`1:09`70440U080BP2D2@1109@30340U080odBD0P3o
D9`70?mUW0<0ojZD0`3oZY`40?n^W0<0ok:L1`3oZY`30?n^W0P0oiVL103oOI`70<DDW0P0_A2D3035
49@80;d@U0<0ogfD2`3oLI@60?m]U0<00000103oKI@00`3oJI@0oooo0?ooo`0l0?ooo`00A@3oool2
07/0U0<0mP0H00@0o`0H06X0U01Z09@0JP2D1P1R09@00`1B09@0FP2D05X0U00405X0U00304X0R`3o
?9@0ocbD00@0ocbD2@3o@9@50?m4U0H0ocRD1`3o=9`20?l`W080mRBD0`1109`204X0W0P0@@2D00<0
BP2D0440U01109@01`1109@40340U0030?m4U03oII`0ofFL00L0ofFL0`3oZY@30?nZW0@0ojjL0`3o
/Y`60?nZW0@0ojjL203oVI`40?mmW0L0aABL202m49@<0<D@U0P0_A2D0P3oOI@;0?maU0L0offD0`00
00030?m]U080ofVD?P3oool004D0oooo0P1k09@30?H06080o`0H0P1Z09@60680U0030580U01J09@0
FP2D00<0FP2D0P1:08/50?llU0X0od2D1@3oA9@00`3oA9`0ocRD0?lhU0020?lhU0L0ocBL0`3o<9`2
0?HTU0@0@@2L0P1:09`A0440U0@0<@2D00<0odBD0?mUU03oII`01P3oII`30?nZU0<0ojZL103o[Y`3
0?nbW0H0ojZL1@3o[Y`80?nIW0@0ogfL1`3559`80;d@U0/0aA2D2P2m49@00`3oOI@0og6D0?maU009
0?maU0H0offD0`0000040?m]U080ofVD?P3oool004D0oooo0P1k09@30?H060<0o`0H00<0JP2D0680
U01R09@0101R09@00`1B09@0FP2D05X0U00305X0U00304X0R`3o?9@0ocbD00@0ocbD2@3o@9@60?m4
U0030?m4W03o>9@0ocRD0080ocRD1P3o=9`50?l`W0030?HTU01109`0@@2L00<0@@2L00<0BP2L0440
U01109@0401109@40340U0030?mUU03oII`0ofFL00D0ofFL0`3oZY@30?nZW0@0ojjL0`3o/Y`50?nZ
W0D0ojjL2@3oVI`40?mmW0H0aABL2P2m49@:0<D@U0X0_A2D303oLI@60?m]U0<00000103oKI@20?mY
U3h0oooo00150?ooo`80N`2D0`3f01P30?l0600306X0U01R09@0HP2D00<0HP2D0`1B09@405X0U003
04X0R`3o?9@0ocbD00@0ocbD2@3o@9@50?m4U080odBL0`3o>9@70?ldW0D0oc2L0P3f99@50440W180
@@2D00D0>@2D0340U00a09@0<@2D0?mUU0060?mUW0<0ojZD0`3oZY`40?n^W0<0ok:L00<0okJL0?nZ
W03oZY`00P3oZY`60?n^W0P0oiVL1@3oNI`00`2m59`0aABL0<DDW0030<DDW0030;@<U02m49@0_A2D
00L0_A2D2@3549@;0;d@U0/0og6D1P3oKI@4000000<0offD0`3oJI@n0?ooo`00A@3oool307/0U0<0
mP0H0P3o01P60680U0<0DP2D0`1J09@00`1:08/0ocbD0?llU0040?llU0X0od2D1@3oA9@30?m4W080
ocRD1P3o=9`60?l`W0030?HTU03V79@0iQbD00@0@@2L4P1109@00`0i09@0<@2D0340U0020340U0H0
ofFL0P3oZY@30?nZW0@0ojjL103o/Y`00`3o]Y`0ojZL0?nZW0020?nZW0D0ojjL00<0ok:L0?nIW03o
VI`01P3oVI`50?miW080_ABL103559`00`2d39@0_A2D0;d@U0080;d@U0P0aA2D302m49@:0?maU0H0
offD0`0000040?m]U0<0ofVD?P3oool004@0oooo101k09@00`3o0200mP0H0?H060030?l060D0HP2D
0`1B09@305X0U00304X0R`3oA9@0ocbD00@0ocbD2@3o@9@60?m4U0<0odBL00<0ocRD0?ldW03o=9`0
1@3o=9`60?l`W0<0iQbD00<0<@2L0440W01109`00P1109`A0440U080>@2D0`0a09@50?mUW0<0ojZD
0`3oZY`40?n^W0<0ok:L0P3o]Y`30?nZW0D0ojjL0P3o/Y`80?nIW0@0ogVL0`2m59`40<DDW080]0bD
2@2m49@70<D@U0d0_A2D2@3oLI@70?m]U0<000000`3oKI@40?mYU3h0oooo00140?ooo`@0N`2D00<0
o`0P0?H0603f01P00`3o01P50680U0@0DP2D0P1J09@00`1:08/0odBD0?m4U0040?llU0T0od2D1@3o
A9@40?m4W0L0ocBL203o<9`20>HLU080<@2L0`1109`00`0i09@0@@2D0440U00>0440U080>@2D100a
09@30?mUW0040?mmW03oZY@0ojZD0?nZU080ojZL103o[Y`30?nbW0<0okJL0P3oZY`50?n^W080ok:L
2@3oVI`40?miW0@0_ABL0P3559`30;@<U0X0_A2D1P3549@=0;d@U0T0og6D1`3oKI@3000000<0offD
103oJI@n0?ooo`00A03oool407/0U080o`0P00D0mP0H0?l0603o01P0o`0H0?l080030680U0D0DP2D
00<0FP2D04X0R`1:08/00`3oA9@20?llU0X0od2D1@3oA9@40?m4W0030?m8W03o=9`0ocBL00<0ocBL
2@3o<9`30>HLU080<@2L0P1109`203T0U0l0@@2D0`0i09@30340U080ofFL00<0ogfL0?nZU03oZY@0
0P3oZY@20?nZW0<0ojjL103o/Y`30?nfW0030?nZW03o[Y`0ojjL00<0ojjL0`3o/Y`80?nIW0D0ogVL
102m59`20<DDW0<0]0bD2P2m49@50<D@U0l0_A2D1`3oLI@70?m]U0<000000`3oKI@60?mYU3d0oooo
00140?ooo`D0N`2D0P3o02030?l060040?l0801R09@0HP2D0680U0D0DP2D00<0FP2D04X0R`3oA9@0
103oA9@00`3o?9@0od2D0?m0U0070?m0U0D0odBD1@3oA9`00`3oB9`0ocBL0?ldW0030?ldW0T0oc2L
0`3V79@30340W080@@2L00<0>@2D0440U01109@03P1109@203T0U0@0<@2D0P3oOI`40?nZU0030?nZ
W03o[Y`0ojjL0080ojjL0`3o/Y`40?nfW0D0ojjL103o/Y`80?nIW0D0ogVL1@2m59`00`3559`0]0bD
0;@<U0020;@<U0T0_A2D1@3549@?0;d@U0L0og6D1`3oKI@3000000<0offD1P3oJI@m0?ooo`00A03o
ool507/0U080o`0P0`3o01P20?l08080HP2D1@1B09@204X0R`D0odBD2P3o@9@50?m4U0@0odBL0`3o
B9`30?ldW0X0oc2L0`3V79@40340W0030440W00i09@0>@2D00l0@@2D0`0i09@30340U0030?mmW03o
ZY@0ojZD00<0ojZD103o[Y`30?nbW0D0okJL103o[Y`40?nbW0T0oiVL1@3oNI`50;dDW0D0]0bD2P2m
49@30<D@U100_A2D1P3oLI@70?m]U0@000000P3oKI@70?mYU3d0oooo00140?ooo`D0N`2D0`3o0203
0?l060030?l0801R09@0HP2D00D0DP2D00<0@@2D04X0R`3oA9@0103oA9@00`3oB9@0od2D0?m0U007
0?m0U0D0odBD103oA9`30?m8W0<0ocBL2`3o<9`00`3V79@0<@2L0340W0040340W0<0>@2D3P1109@0
100i09`0>@2D03T0U00i09@20340U0030?mmW03oZY@0ojZD00<0ojZD103o[Y`30?nbW0@0okJL00@0
okZL0?n^W03o[Y`0ojjL1@3o/Y`90?nIW0D0ogVL1@2m59`00`2/29@0]0bD0;@<U0030;@<U0T0_A2D
0`3549@A0;d@U0D0og6D1`3oKI@400000080offD1`3oJI@m0?ooo`00A03oool407/0U00307<0U03o
0200o`0P0080o`0P0P3o01P20?l080H0DP2D00<0@@2D04X0R`3oA9@0103oA9@20?m8U0L0od2D1@3o
A9@50?m4W0@0odRL00<0ocBL0?l`W03o<9`02P3o<9`20>HLU0D0<@2L0`0i09@>0440U00403T0W00i
09@0>@2D03T0U0<0<@2D103oZY@0103oTJ@0ojjL0?n^W03o[Y`30?nbW0@0okJL0P3o^Y`20?n^W0D0
ok:L00<0okJT0?nIW03oVI`01P3oVI`60?maW0040;@DW02m59`0_ABL0;dDW080[0RD1@2d39@:0;d@
U0030<D@U02m49@0_A2D0100_A2D1@3oLI@60?m]U0@000000P3oKI@80?mYU3d0oooo00140?ooo`@0
N`2D00<0L`2D0?l0803o02000P3o02020?l060<0o`0P1@1B09@00`1109@0odBD0?m4U0040?m4U080
odRD1`3o@9@50?m4U0@0odBL1@3oB9`=0?l`W0030>HLU03=59@0cABD00D0<@2L0`0i09@40440U003
04X0U01109@0@@2D00H0@@2D0P0i09`303T0U0<0<@2D0`3oZY@00`3o[Y@0ojjL0?n^W0040?nbW0@0
okJL0P3o^Y`00`3o[Y`0ok:L0?nbW0030?nbW080okJT1`3oVI`00`3oUJ@0og6L0?maW0040?maW004
0;@DW02m59`0_ABL0;dDW0<0[0RD102d39@:0;d@U0030<D@U02m49@0_A2D0100_A2D103oLI@70?m]
U0@0000000<0offD0?mYU03oJI@01`3oJI@m0?ooo`00A03oool407/0U080L`2D103o02000`3o01P0
o`0P0?l080020?l080@0DP2D00<0@@2D0?m4U03oA9@00`3oA9@40?m8U0H0od2D1@3oA9@40?m4W0H0
odRL303o<9`30<dDU00301P0W00a09`0<@2L0080<@2L00@0<@2D03T0U00i09@0>@2D0`1109@00`1:
09@0@@2D0440U0060440U080>@2L0`0i09@00`3oZY@0<@2D0340U0020?nZU0040?nAY03o[Y@0ojjL
0?n^W0<0ok:L103o]Y`30?njW0D0ok:L0`3o]Z@50?nIW0<0oiFT1P3oLI`20;@DW0030;dDW02/29@0
[0RD0080[0RD1@2d39@M0;d@U0<0og6D1P3oKI@500000080offD203oJI@m0?ooo`00A03oool407/0
U080L`2D2@3o02030580U080@@2D1@3oA9@40?m8U0D0od2D1@3oA9@50?m4W0H0odRL303o<9`01@3^
:9`0cABD0<dDU03=59@0602L00<0<@2L00<0<@2D03T0U00i09@00P0i09@20440U080BP2D1`1109@3
03T0W080>@2D00D0ojZD0340U00a09@0<@2D0?nZU0020?n^U0040?n^W03o/Y`0ok:L0?nbW0@0okJL
0`3o^Y`50?nbW0@0okJT0`3oVI`50?nEY0H0og6L0P2d59`50:`8U0D0]0bD2@2m49@00`2m39@0_A2D
0;d@U00A0;d@U0<0og6D1@3oKI@600000080offD203oJI@m0?ooo`00A03oool407/0U080L`2D2P3o
02020580U080@@2D1@3oA9@40?m8U0030?m<U03o@9@0od2D0080od2D1@3oA9@40?m4W0P0odRL2P3o
<9`20>hXW0<0cABD0P0H09`20340W080<@2D0`0i09@20440U0<0BP2D1P1109@303T0W00303T0U03o
ZY@0ojZD00<0<@2D00<0oi6T0?n^U03o[Y@0103o/Y`40?nfW0<0okZL1@3o/Y`40?nfY0030?nIW03o
UJ@0oiFT00@0oiFT1`3oLI`20;@DW00309@4W02/29@0[0RD00<0[0RD1@2d39@80;d@U0030;d<U02m
49@0_A2D0140_A2D0P3oLI@60?m]U0D000000`3oKI@80?mYU3d0oooo00140?ooo`@0N`2D0P1c09@:
0?l08080DP2D00<0@@2D0?m4U03oA9@00`3oA9@50?m8U080odbD0`3o@9@40?m4U0D0odBL203oB9`9
0?l`W0<0kRRL0`3=59@301P0W0030340W00a09@0<@2D00@0>@2D00@0@@2D04X0U01:09@0BP2D1P11
09@403T0W080ojZD00@0>@2D0340U00a09@0<@2D0P3o[Y@30?nbW0@0okJL0`3o^Y`00`3o_Y`0ok:L
0?nbW0020?nbW0@0okJT203oUJ@70?maW080]1BL00<0U0BL0:`8U02/29@00`2/29@50;@<U0L0_A2D
0P2m39@D0;d@U0030?maU03oKI@0offD00<0offD1P0000030?m]U0T0ofVD?03oool004<0oooo1@1k
09@207<0U0H0o`0P00<0o`0Y0?l0803o02000P3o02000`1B09@0@@2D0?m4U0040?m4U0D0odRD0P3o
C9@20?m0U0D0odBD103oA9`:0?m8W0P0oc2L103^:9`40<dDU080602L0`0a09@403T0U0@0BP2D1@11
09@303T0W0<0ojZD0P0i09@20340U0040?n^U03oZZ`0ok:L0?nbW0@0okJL0`3o^Y`20?nnW0<0ok:L
103o]Z@00`3o_Z@0oiFT0?nEY0060?nEY0L0og6L00@0]1BL09@4W02D19`0U0BL1@2/29@40;@<U0L0
_A2D0`2m39@C0;d@U0H0offD1P0000030?m]U0T0ofVD?03oool004<0oooo00<0R`2D07/0U01k09@0
0P1k09@307<0U0D0o`0P00<0o`0Y0?l0803o02000P3o02020440U0D0odBD103oB9@40?m<U0030?m0
U03oA9@0odBD00<0odBD103oA9`:0?m8W0L0oc2L1@3^:9`30<dDU00301P0W02/39@0602L00@0<@2D
0`0i09@404X0U0D0@@2D0`0i09`30?nZU080>@2D0`0a09@00`3o[Y`0ok:L0?nbW0040?nfW0<0okZL
0P3o_Y`20?nbW0@0okJT0P3o_Z@80?nEY0L0og6L00@0]1BL09@4W02D19`0U0BL1@2/29@50;@<U0H0
_A2D0`2m39@C0;d@U0030?mYU03oKI@0offD0080offD1P0000040?m]U0T0ofVD?03oool004<0oooo
0P2;09@307/0U0<0L`2D1@3o02020?l0:@@0o`0P00<0@@2D0?m4U03oA9@00`3oA9@40?m8U0@0odbD
1@3oA9@50?m4W0X0odRL00<0odbL0?l`W03o<9`00`3o<9`60>hXW080cABD00<0BP2d0:`<U02/39@0
0P0H09`30340U0@0>@2D101:09@40440U080>@2L0`3oZY@0100i09@0ojZD03T0U00i09@20340U003
0?n^W03o/Y`0okJL00<0okJL0`3o^Y`30?nnW0030?nbW03o]Z@0okJT0080okJT0`3o_Z@70?nEY0P0
og6L1@2D19`40:`8U0D0]0bD1@2m49@40;d<U1@0_A2D103oKI@6000000@0offD2@3oJI@l0?ooo`00
@`3oool208/0U0<0N`2D0`1c09@50?l080<0o`0Y0`3o02050?m4U0D0odRD103oC9@00`3oD9@0odBD
0?m4U0020?m4U0@0odBL2`3oB9`00`3oC9`0oc2L0?l`W0020?l`W0L0kRRL1P2/39@00`0H09`0802;
0340U0020340U0<0>@2D1@1:09@30440U080>@2L0`3oZY@0100i09`0ojZD03T0U00i09@30340U0@0
okJL0`3o^Y`40?nnW0@0okJT103o_Z@70?nEY0P0offL00<0odBD09@4W02D19`00P2D19`50:`8U0D0
]0bD102m49@50;d<U1<0_A2D0`3oKI@7000000@0offD2@3oJI@l0?ooo`00@`3oool308/0U080N`2D
0`1c09@50?l080<0o`0Y0`3o02050?m4U0D0odRD103oC9@20?m@U0<0odBD103oA9`:0?m8W080odbL
103o<9`70>hXW0030=DTW02/39@0[0bD0080[0bD00<0002D01P0W00P08/00`0a09@303T0U0D0BP2D
0`1109@01P0i09`0ojZD0?nZU03oZY@0>@2L0?nZU0@0>@2D0P0a09@40?nfW0<0okZL103o_Y`30?nf
Y0D0okjT1`3oUJ@80?m]W0030?m4U02D19`0U0BL0080U0BL1@2/29@50;@<U0<0_A2D1P2m39@C0;d@
U0<0offD1`0000040?m]U0T0ofVD?03oool004<0oooo102;09@0101k09@0L`2D07<0U01c09@60?l0
80<0o`0Y0P3o02050?m4U0@0odRD1@3oC9@20?m@U080odBD1@3oA9`:0?m8W0<0odbL0P3o<9`70>hX
W080eBBL102/39@0100009@0[0bD01P0W00P08/30340U080>@2D1P1:09@30440U0D0ojZD0P0i09`2
03T0U080<@2D00<0802D0?nfW03o]Y`00`3o^Y`40?nnW0030?o6Y03o]Z@0okJT00H0okjT1`3oUJ@7
0?m]W080odBD00<0L`2L09@4W02D19`00P2D19`40:`8U0D0]0bD0`2m49@60;d<U1<0_A2D0P3oKI@7
000000D0offD2@3oJI@l0?ooo`00@`3oool408/0U0D0L`2D1@3o02030?l0:@80o`0P103oA9@50?m8
U0@0odbD103oD9@00`3oA9@0odBL0?m4W0020?m4W0X0odRL103oC9`00`3o<9`0kRRL0>hXW0050>hX
W0@0eBBL102/39@00`0009@0602L0200R`040340U00303T0U01:09@0BP2D00@0BP2D0P1109@30?nZ
U00303T0W03oZY@0ojjD0080>@2L0`0i09@00`0a09@0802D0?nfW0030?njW0@0okjL0P3oaZ@00`3o
]Z@0okjT0?nnY0040?nnY0P0oiFT1@3oKI`01@2D4:`0offL0?m4U03oA9@0L`2L00@0U0BL1@2/29@5
0;@<U0030;d@U02m39@0_@bD00H0_@bD4P2m49@00`2m39@0offD00000006000000D0offD2@3oJI@l
0?ooo`00@`3oool408/0U00308/4U01c09@0L`2D0080L`2D00<0o`0H0?l0803o02000P3o02030?l0
:@030?l0<@3oA9@0odBD00<0odBD1@3oB9@40?m<U0@0oe2D1@3oA9`:0?m8W0@0odbL1`3^:9`50=DT
W0D0[0bD00<0002D0200R`0P08/00`0a09@00`0i09@0BP2D04X0U00504X0U0040440U03oZY@0ojZD
03T0W080ojZD0P3o[Y@203T0W080>@2D00<0<@2D0200U00P09@00`3o^Y`40?nnW080olJT1P3o_Z@0
0`3o`Z`0oiFT0?nEY0060?nEY0<0offL00@0U1B/0?m]W03oKI`0offL0P3oA9@207<0W0@0U0BL102/
29@50;@<U0030;d@U02m39@0_@bD00H0_@bD4@2m49@20;d<U0P000001@3oKI@90?mYU3`0oooo0013
0?ooo`@0R`2D0P2;19@307<0U0030?l0603o0200o`0P0080o`0P0`3o02T00`3o0340odBD0?m4U003
0?m4U0D0odRD103oC9@40?m@U0030?mEU03oA9`0odBL0080odBL2@3oB9`50?m<W0030?m<Y03^:9`0
kRRL00@0kRRL1@3E99`60:`<U080802;100a09@704X0U0D0ojZD0`3o[Y@203T0W0<0>@2D0P0P09@2
0?njW0@0okjL0P3oaZ@60?nnY080ol:/203oUJ@00`3oKI`0U1B/0?m]W0040?m]W080odBD0P1c09`4
09@4W0D0[0RD102d39@90;d<U140_A2D0P2m39@7000000H0offD2@3oJI@l0?ooo`00@`3oool408/0
U080R`BD0`1c09@20?l060<0o`0P0`3o02T00`3o0340odBD0?m4U0030?m4U0@0odRD1@3oC9@40?m@
U080oeFD0P3oA9`:0?m8W0@0odbL0`3oC:@40>hXW0L0eBBL1@2/39@00`0009@0802;0200R`030340
U0L0BP2D0P3oZY@00`1109`0ojZD0?nZU0020?n^U0@0>@2L0P0i09@30200U0@0okjL0`3oaZ@50?nn
Y0<0ol:/1`3oUJ@80?m]W080odBD0P1c09`509@4W0@0[0RD102d39@:0;d<U0l0_A2D102m39@60000
00L0offD203oJI@00`3oII@0oooo0?ooo`0i0?ooo`00@`3oool408/0U0<0R`BD0`1c09@20?l06080
o`0P0`3o02T00`3o0340odBD0?m4U0020?m4U0D0odRD103oC9@50?m@U0<0oeFD00<0odBL0?m8W03o
B9`01`3oB9`50?m<W0<0odbT0`3^:9`80=DTW0D0[0bD00@000230200R`0P08/0802;0`0a09@504X0
U0D0ojZD0`3o[Y@20?n^W080>@2L0P0i09@00`0Y09@0802D0200U0030?nnW0<0olJT00<0oljT0?nn
Y03o_Z@00P3o_Z@40?o2[0D0oiFT0P3oVJ@40?m]Y0<0og6L0`3oA9@307<0W0@0U0BL102/29@30;@<
U0/0_@bD3P2m49@50;d<U0H000001`3oKI@70?mYU080ofFD>`3oool004<0oooo102;09@408/4U080
L`2D0P3o01P30?l08080o`0Y1@3oA9@50?m8U0@0odbD103oD9@40?mEU0X0odRL103oC9`50?m<Y003
0>hXW03E99`0eBBL00L0eBBL1P2L19`00`0008<0802;0200R`030340U0D0BP2D1@3oZY@30?n^U003
03T0W03o[Y`0>@2L0080>@2L00<0>@2D02T0U00Y09@00P0P09@20?nnW080olJT0P3ocZ@30?nnY0D0
ol:/0P3oUJ@50?nIY0L0offT0`3oA9@307<0W0@0U0BL1@2/29@20;@<U0/0_@bD3P2m49@50;d<U0D0
0000203oKI@70?mYU080ofFD>`3oool004<0oooo102;09@408/4U080L`2D0`3o01P20?l08080o`0Y
1@3oA9@50?m8U0@0odbD103oD9@40?mEU0030?mMW03oB9`0odRL00H0odRL1@3oC9`50?m<Y0T0eBBL
0P3=9:@609`4W0<0802;0P0a09@504X0U0@0ojZD0`3o[Y@0103o[Y`0>@2L03T0W03o[Y`203T0W003
03T0U00Y09@0:@2D0080802D00@0okjL0?o6Y03oaZ@0olJT0P3ocZ@20?nnY0D0ol:/203oVJ@70?m]
Y0040?m0W03oA9@0odBD0?m4U0<0L`2L102D19`40:`8U0030;@<U02m39@0_@bD00X0_@bD3@2m49@6
0;d<U0D00000203oKI@60?mYU0<0ofFD>`3oool004<0oooo102;09@408/4U00308/4W01c09@0o`0H
0080o`0H0P3o02020?l0:@@0odBD1@3oB9@40?m<U0D0oe2D103oEI@20?mMW0L0odRL103oC9`60?m<
Y0030?m8Y03E99`0eBBL00D0eBBL0`3=9:@609`4W00308/0000P08/0802;0080<@2D101:09@00`3o
YI@0ojZD0?nZU0020?nZU0<0ojjD00<0ojjL03T0W00i09`0100i09`302T0U080802D0P3oaZ@30?o>
Y0030?nnY03o`Z`0ol:/00<0ol:/00<0olZ/0?nIY03oVJ@01P3oVJ@70?m]Y080od2L0P3oA9@00`1c
09`0odBD07<0W00409@4W0@0[0RD3P2m39@<0;d@U0L0_@bD100000080?m]U0H0ofVD0`3oII@k0?oo
o`00@`3oool408/0U0@0R`BD0P2;19`01@1c09@0o`0H0?l0603o01P0o`0P0080o`0Y103oA9@50?m8
U0@0odbD103oD9@50?mEU0<0oefL1@3oB9`50?m<W0D0odbT0`3oB:@50=DTW0@0cBBT1`2L19`30200
R`030340U01:09@0BP2D0080BP2D00@0ojFD0?nZU03oZY@0ojZD0`3o[Y@20?n^W0<0>@2L00<0ojjL
03T0W00i09`00`0Y09@20200U0040?o6Y03ocZ@0oljT0?o>Y0H0ol:/0P3obZ`70?nIY0P0offT0`3o
@9`00`110:@0L`2L07<0W00207<0W0@0U0BL0`2/29@>0;d<U0/0_A2D202m39@3000000T0offD1@3o
JI@40?mUU3/0oooo00130?ooo`@0R`2D102;19@208/4W00607<0U03o01P0o`0H0?l0603o0200o`0Y
1@3oA9@50?m8U0@0odbD103oD9@40?mEU0@0oefL1@3oB9`40?m<W0H0odbT0`3oB:@40=DTW0D0cBBT
1`2L19`0100807/0802;0200R`0a09@304X0U0<0ojFD0P3oZY@30?n^U080ojjL1P0i09`0100Y09`0
:@2D02T0U00Y09@20200U0<0oljT103o`Z`40?o:[0<0oiVT103oUJ`40?mYY0@0offT0`3o@9`00`11
0:@0FP2L07<0W00207<0W0@0U0BL0`2/29@>0;d<U0X0_A2D2@2m39@3000000T0offD103oJI@50?mU
U3/0oooo00130?ooo`@0R`2D102;19@308/4W0@0o`0H00<0o`0Y0?m4U03oA9@00`3oA9@40?m8U0D0
odbD103oD9@40?mEU0@0oefL00@0offL0?m8W03oB9`0odRL1@3oC9`50?m<Y0D0odRT0P3E99`60<dT
Y0L0W0BL00@0DP1c0200R`0P08/0802;0`1:09@30?nUU0040?nZU03o[Y@0ojjD0?n^U0<0ojjL00<0
@@2L0?n^W00i09`00`0i09`202T0W080:@2D0P0P09@20?o>Y0040?oJ[03o`Z`0ol:/0?o2[0@0olZ/
203oUJ`70?mYY0D0od2L00@0FP2L07<0W01c09`0L`2L1@2D19`00`2/29@0_@bD0;d<U00>0;d<U0T0
_A2D2@2m39@3000000T0offD103oJI@50?mUU3/0oooo00130?ooo`@0R`2D102;19@308/4W0@0o`0H
00<0o`0Y0?m4U03oA9@00P3oA9@50?m8U0@0odbD1@3oD9@40?mEU0@0oefL0P3oKI`20?m8W0@0odbL
1@3oC:@60?m8Y0L0cBBT0P2m8:`608<4Y0040580L`0P08/0802;0200R`80BP2D103oYI@0103oZY@0
ojjD0?n^U03o[Y@30?n^W080@@2L100i09`202T0W0<0:@2D0P0P09@20?oJ[080ol:/103obZ`00`3o
b[@0oiF/0?nE[0050?nE[0P0ofVT00<0od2T0?m0W00P0:`00P3o@9`00`110:@0FP2L07<0W00207<0
W0@0U0BL00<0[0RD0;d<U02m39@03P2m39@80;d@U0/0_@bD00<000000?m]U03oKI@0203oKI@30?mY
U0H0ofFD>`3oool004<0oooo102;09@408/4U0@0R`BL103o01P40?m4U0D0odRD103oC9@40?m@U0D0
oeFD103oGI`30?m]W0D0odbL1@3oC:@60?m8Y0030?I8[03=9:@0cBBT0080cBBT102m8:`708<4Y005
00P0N`0P08/0802;0200R`1:09@0103oYI@40?n^U0<0ojjL0P1109`0103o[Y`0>@2L03T0W00i09`3
02T0W080:@2D0P0P09@20?oJ[0@0olZ/0`3ob[@70?nE[0P0ofVT0P3o@:@30?m0W0030440Y01J09`0
L`2L0080L`2L102D19`A0;d<U0P0_A2D2`2m39@00`000000offD0?m]U0080?m]U080ofVD1`3oII@k
0?ooo`00@`3oool408/0U0@0R`BD102;19`30?l060D0odBD1@3oB9@40?m<U0@0oe2D103oEI@40?mM
W0@0offL0P3oOJ@20?m<W0D0odbT1P3oB:@30?I8[080cBBT1@2m8:`00`2LKMh0P`BT08<4Y00408<4
Y0040580L`0P08/0802;0200R`D0ojFD00<0ojZD0?n^U03o[Y@0103o[Y`30440W0<0>@2L0`0Y09`3
02T0U080802D00@0omZ/0?o:[03obZ`0olZ/103ob[@70?nE[0L0ofVT103o@:@30?m0W0030440Y01c
09`0L`2L0080L`2L0P2D19`20;d8Ra40_@bD1P2m49@<0;d<U0030000003oKI@0offD00P0offD0P3o
JI@70?mUU3/0oooo00130?ooo`@0R`2D102;19@408/4W0<0o`0H103oA9@50?m8U0@0odbD1@3oD9@4
0?mEU0@0oefL103oKI`30?mmY0D0odbT1P3oB:@40?I8[0P0_B2/1P231:@0101B07<0201k0200R`0P
08/50?nUU0030?nZU03o[Y@0ojjD00@0ojjL0`1109`0103oZY`0>@2L03T0W00a09`302T0W080:@2D
0P0P09@00`3oi[@0olZ/0?o:]0050?o:]0H0oiF/203oJJ@40?m0Y0<0od2L00<0@@2T05X0W01c09`0
0P1c09`0102D19`0_@R;0;d8R`2m28/A0;d<U0D0_A2D3@2m39@;0?m]U0030?mYU03oII@0ofFD00H0
ofFD>`3oool004<0oooo102;09@408/4U0@0R`BL0`3o01P40?m4U0D0odRD103oC9@40?m@U0D0oeFD
103oGI`40?m]W0<0ogfT00<0ohV/0?m<Y03oC:@00P3oC:@50?m8Y0D0mTR/00<0gTRd0;dP[02m8:`0
1@2m8:`608<4Y00307/0N`0807/0802;00D0ojFD0P3oZY@00`3o[Y@0ojjL0?n^W0030?n^W080BP2L
0P1109`203T0W080<@2L0P0Y09`302T0U080802D1P3ob[@70?nI[080off/1@3oJJ@60?m0Y0<0od2L
00@0@@2T07<0W01c09`0L`2L102m28/A0;d<U0D0_A2D2@2m39@00`000000_@bD0;d<U0020;d<U0X0
offD2@3oII@k0?ooo`00@`3oool408/0U0@0R`BD1@2;19`20?l060@0odBD1@3oB9@40?m<U0@0oe2D
103oEI@40?mMW0@0offL103oOJ@20?n9[080odbT1P3oB:@40?I8[080gTRd1`2m8:`608<4Y00307/0
N`1B07<0201k00D0ojFD0P3oZY@00`3o[Y@0ojjL0?n^W0030?n^W080BP2L0`1109`00`0i09`0<@2L
0340W00302T0W080:@2D0P0P09@60?o:]0L0oiV/103oKJ`30?mYY0L0od2T0P3o@9`00`110:@0e@R3
0=D8P`020=D8P`@0_@R;4@2m39@30;d@U0d0_@bD00<000000;d<U03oKI@02@3oKI@00`3oJI@0ofFD
0?mUU0060?mUU3/0oooo00130?ooo`@0R`2D102;19@508/4W0030?l0603oA9@0odBD00<0odBD1@3o
B9@40?m<U0@0oe2D103oEI@40?mMW0@0offL0`3oOJ@40?n9[0H0odRT103fB:`40=i8]0@0_B2/0`2/
:;@307<<]080P`BT00<0]01c0580L`0807/0103oYI@30?nZU0H0ojjL0`1:09`20440W00403T0W00a
09`0<@2L0340W080:@2L0`0Y09@20200U0D0olZd1P3oVJ`70?m][0T0od2T00<0od2L0?l/JP3o;6X0
0`3E28<40;d8Ra40_@bD0P2m49@=0;d<U0030000002m39@0_@bD00T0offD0P3oJI@80?mUU3/0oooo
00130?ooo`@0R`2D102;19@508/4W0030?l0603oA9@0odBD0080odBD1@3oB9@40?m<U0D0oe2D103o
EI@40?mMW0@0offL0`3oOJ@40?n9[080ohfd0`3oB:@40?I8[0D0gTRd0P2m8:`50:`X]0H0L`bd00<0
DP1c0?nUU03oYI@00`3oYI@30?nZU0H0ojjL0`1:09`30440W0<0<@2L0`0Y09`302T0U0030200U03o
b[@0olZd00<0olZd1P3oVJ`70?m][0030?I4[03o@:@0od2T00H0od2T0P3o85X0103o;6X0e@R30=D8
P`3E28<40;d8Ra40_@bD00<0_A2D0;d<U02m39@0302m39@00`000000_@bD0;d<U0080?m]U0<0ofVD
203oII@k0?ooo`00@`3oool408/0U0@0R`BD1@2;19`00`3o01P0odBD0?m4U0020?m4U0D0odRD103o
C9@40?m@U0D0oeFD103oGI`30?m]W0<0ogfT1@3oRJ`40?n=]0@0mTR/1P3NB;@80:`X]0D0L`bd00<0
DP1c0?nUU03oYI@00P3oYI@40?nZU0H0ojjL101:09`20440W0@0<@2L0P0Y09`302T0U080802D103o
b[@60?nI[0L0off/0P3fA:`70?m0Y0030=D0003o85X0obaZ00<0e@R3102m28/A0;d<U0030?mYW02m
39@0_@bD00/0_@bD0P0000030;d<U0L0offD0`3oJI@80?mUU3/0oooo00130?ooo`@0R`2D102;19@5
08/4W0D0odBD1@3oB9@40?m<U0@0oe2D103oEI@40?mMW0@0offL0`3oOJ@40?n9[0D0ohfd00<0ohFm
0?I8[03fB:`01P3NB;@20<e8]0L0[2Rd1@1c3;@50?nUU0<0ojZD00<0ojFD0?n^W03o[Y`0103o[Y`0
101B09`0BP2L04X0W01:09`20440W0@0<@2L0`0Y09`302T0U0040200U03ob[@0olZd0?o:]0H0oiV/
1`3oKJ`40?I4[0D0od2T00@0HRCN00P0W03o85X0obaZ103E28<40;d8Rad0_@bD0P0000040;d<U0H0
offD103oJI@80?mUU3/0oooo00130?ooo`@0R`2D102;19@508/4W0@0odBD1P3oB9@30?m<U0D0oe2D
103oEI@40?mMW0@0offL0`3oOJ@40?n9[0@0ohfd0`3oQKd60=i8]0@0cDRd1P2/:;@507<<]0@0ojFD
103oZY@00`3oYI@0ojjL0?n^W0030?n^W0030?nZW01B09`0ojZL00<0BP2L00<0@@2L0340W00a09`0
0`0a09`202T0W0<0:@2D0P0P09@20?o6_@H0oiVd0`3oMK@40?m][0D0mTB/103o@:@200P0W0030?lP
FP3o;6X0e@R300<0e@R3102m28/L0;d<U0<00000102m39@50?m]U0D0ofVD203oII@k0?ooo`00@`3o
ool408/0U0@0R`BD1@2;19`20?m4U0030?l0603oA9@0odRD00@0odRD103oC9@50?m@U0@0oeFD103o
GI`30?m]W0<0ogfT103oRJ`40?n=]0050?n9]03oQKd0ohFm0?n5_@3fOKd0103NB;@60<e8]0<0[2Rd
0`2T=;d207<Pc@0307<<]03oYI@0ojFD00<0ojFD0`3oZY@30?nUU0@0ojjL00<0ojZL0580W01B09`0
0`1:09`00`1109`0<@2L0340W0030340W0<0:@2L0`0Y09@00`0P09@0olJm0?o6_@060?nI]0H0ogFd
1`3fA:`20?m0Y00507<hgP0809`0202L0?lPFP3o;6X0103E28<40;d8R`h0_@bD00<0ofVL0;d<U02m
39@02P2m39@3000000D0_@bD1P3oKI@40?mYU0P0ofFD>`3oool004<0oooo102;09@408/4U0D0R`BL
0P3oA9@20?l060D0odRD103oC9@40?m@U0@0oeFD103oGI`40?m]W0<0ogfT103oRJ`30?n=]0040?n9
]03oQKd0ohFm0?n5_@<0mWfm0P3NB;@70<e8]0L0Y3Bm0P1c8<d40?nUU0@0ojZD0`3oYI@30?n^W080
ojZL0P1B09`0102/PMD0BP2L04X0W01:09`60340W0<0:@2L0P0Y09@20200U0030?o6_@3oVK@0oiVd
00@0oiVd1P3oMK@00`3VD;@0mTB/0?I4[0050?I4[0070?m0Y00809`0202L00P0W03o85X0obaZ0?l/
N`030=D8P`@0_@R;3@2m39@00`3oJI`0_@bD0;d<U00:0;d<U0@000001P2m39@50?m]U0@0ofVD203o
II@k0?ooo`00A03oool308/0U0@0R`BD102;19`40?m4U0030?l0603oB9@0odRD00<0odRD103oC9@4
0?m@U0@0oeFD103oGI`40?m]W080ogfT103oRJ`40?n=]0<0ohFm1@3fOKd70<e8]080aDbm1`2T=;d5
0?nUU0<0ojZD103oYI@30?n^W080ojZL0`1B09`304X0W0H0<@2L0`0Y09`302T0U0030200U03oVK@0
oiVd00@0oiVd1`3oMK@20>I@]0H0mTB/100809`00`3o85X0obaZ0?lPFP040=D8P`@0_@R;302m39@0
0`2m49@0_@bD0;d<U00:0;d<U0<0000000<000080;d<U02m39@0102m39@50?m]U0@0ofVD203oII@k
0?ooo`00A03oool00`2L19@0R`2D08/0U00408/4U0@0R`BL103oA9@20?l060<0odRD103oC9@50?m@
U0@0oeFD103oGI`40?m]W080ogfT103oRJ`30?n=]0030?n9]03oQKd0ohFm00D0mWfm0`3NLLD30<e8
]0D0aDbm1P2T=;d40?nUU0@0ojZD103oYI@20?n^W0<0ojZL101B09`204X0W00303T0W00a09`0<@2L
00@0<@2L0`0Y09`202T0U080802D1@3oVKd20?mm]0@0ogFd103VD;@50?I4[00306X8]00809`0202L
0080202L00<0ob1J0?l/JP3E28<00`3E28<40;d8R`/0_@bD0P2m49@<0;d<U0<000001`2m39@50?m]
U0@0ofVD203oII@k0?ooo`00A03oool209`4U00308/0U02;19@0R`BD0080R`BD102;19`40?m4U0<0
o`0H0P3oB9@40?m<U0D0oe2D103oEI@40?mMW0<0offL0`3oOJ@30?n9[0<0ohfd00<0ohVd0?n5_@3o
QKd01@3fOKd50=iaa@P0aDbm102TA<D50?nUU0<0ojZD1@3oYI@20?n^W0<0ojZL00@0FP2L0580W01B
09`0DP2L0P1:09`203T0W0D0<@2L0`0Y09`302T0U0030200U03oVKd0oiVm0080oiVm1@3oOK@20?me
]0D0iU2d0`3fA:`206X8]0@0202L00<0ob1J0?l/JP3E28<00`3E28<40;d8R`/0_@bD0P2m49@;0;d<
U0<0000000<000080;d<U02m39@01@2m39@50?m]U0@0ofVD203oII@k0?ooo`00A03oool309`4U0@0
R`BD102;19`50?m4U0040?l0603f0100odRD0?m8U0@0odbD103oD9@40?mEU0@0oefL103oKI`20?mm
Y0@0ohV/0P3oSK@00`3oRK@0ohFm0?n5_@050?Im_@D0gW750P3=JLD60<E<_@80_EG50`2TA<D40?nU
U0@0ojZD103oYI@00`3oXI@0ojjL0?nZW0020?nZW0030?nMW01J09`0FP2L00<0DP2L00<0BP2L03T0
W00i09`01P0a09`302T0W080:@2D0P0P09@30?nI_@H0ogfd1`3VD;@20?I4[0<0JPRd0`0809`00`3o
85X0obaZ0=D8P`030=D8P`D0_@R;2@2m39@40;d@U0T0_@bD0`000002000020P0_@bD103oKI@40?mY
U0P0ofFD>`3oool004@0oooo0`2L19@408/4U0@0R`BL1@3oA9@0103o01P0mP0@0?l0603oB9@30?m<
U0D0oe2D103oEI@40?mMW0@0offL0P3oOJ@30?n9[080aHGN00<0cK[N0=k6gP3Na]h00`3N/]D20?Im
_@D0gW75103=JLD30<E<_@@0_EG50`2TA<D40?nUU0<0ojZD1@3oYI@0103oXI@0ojZL0?nZW03oZY`2
0?nMW080FP2L0`1B09`0101:09`0>@2L03T0W00i09`50340W0<0:@2L0`0Y09@00`0P09@0oiVm0?nI
_@070?mm]0030>IM_@3VD;@0iU2d00D0iU2d101Z2;@300P0W0030?lPFP3o;6X0e@R300@0e@R3102m
28/80;d<U0D0_A2D202m39@4000000030000202m39@0_@bD00L0_@bD103oKI@40?mYU0P0ofFD>`3o
ool004@0oooo102L19@308/4U0<0R`BL1@3oA9@0103oB9@0o`0H0?l0603f01040?m<U0D0oe2D103o
EI@40?mMW0<0offL0P3oOJ@30:@4_@80aHGN00<0cK[N0=k6gP3Na]h01@3N/]D50=iaa@H0cFW51`2m
ELD00`2TA<D0ojFD0?nUU0030?nUU0<0ojZD103oYI@20?nQU0040?nAU03oZY`0ojZL0?nMW0@0FP2L
0`1B09`303T0W0H0<@2L0`0Y09`202T0U0030200U00809@0oiFm0080ogfm103oOK@30>IM_@H0iU2d
00<0W2Rm06X8]01Z2;@00P1Z2;@200P0W0030?lPFP3o;6X0obak00@0e@R3102m28/80;d<U0030<D@
U02m49@0_A2D0080_A2D202m39@4000000030000202m39@0_@bD00L0_@bD103oKI@40?mYU0P0ofFD
>`3oool004@0oooo1@2L19@208/4U0<0R`BL1@3oA9@00`3oB9@0o`0H0?l060020?H040<0odbD1@3o
D9@30?mEU0@0oefL103oKI`0103oOJ@0aABd0:@4_@2T1;d20<F5gP030<fjgP3Na]h0g/KN00H0g[;E
103ESLd60<eYa@80aFG51P2mELD00`2/ELd0ojFD0?nUU0020?nUU0<0ojZD1@3oYI@20?nQU0040?nA
U03oZY`0oifL0?nMW0@0FP2L0`1B09`403T0W0D0<@2L0`0Y09`302T0U00300P0U03oOKd0ogfm00<0
ogfm0P3oOK@40>IM_@@0iU2d0`2L:;d306X8]080202L00<0ob1J0?l/JP3o;7/0103E28<40;d8R`L0
_@bD0P3549@40;d@U0030;d<U0350680_@bD00D0_@bD0`000002000020T0_@bD103oKI@40?mYU0P0
ofFD>`3oool004@0oooo1P2L19@0102;19@0R`BL08/4W02;19`50?m4U080odRD00@0o`0H0?H0403f
0100o`0H0P3oC9@40?m@U0@0oeFD103oGI`40?m]W0030<DD]02T1;d0Y0Bm0080aHGN00<0cK[N0=k6
gP3Na]h01P3N/]D40=F=c@<0cGW=0`3=JLD40<EUa@<0_EG50P2dGLD50?nUU0<0ojZD103oYI@20?nQ
U080oi6D0`3oWI`00`1Z09`0FP2L05X0W00205X0W080DP2L00@0@@2T03T0W00i09`0>@2L1P0a09`3
02T0W080:@2D0P0809@50?mm_@H0iUfm0P3VD;@409`X_@@0JPRd0P0809`00`3o;6X0obak0=D8P`03
0=D8P`D0_@R;1P2m39@20<D@U0D0_A2D1P2m39@4000000030000202m39@0_@bD00T0_@bD0`3oKI@4
0?mYU0P0ofFD>`3oool004@0oooo1`2L19@308/4W0D0odBD0P3oB9@20?l06080mP0@0P3oC9@40?m@
U0<0oeFD1@3oGI`30?m]W0040<DD]02T1;d0FPS506XHc@@0LbcV0`2TPMh30=jbe@@0eHg=1@3=NLd7
0<EUa@@0]5g5103oYI@30?nZU0D0ojFD0P3oXI@20?nAU0030?maR`3oWI`0ohVL0080JP2L101J09`0
0`1B09`0@@2T0440Y00303T0W0D0<@2L0`0Y09`202T0U0030100U00809@0ogfm00@0ogfm0P3NJKd5
0>IM_@H0W2Rm0`1Z2;@200P0W0030?l/JP3o85X0e@R300<0e@R31@2m28/50;d<U0@0aA2D102m49@0
0`2m39@000000;d<U0020;d<U0D0000000<000080;d<U02m39@02@2m39@30?m]U0@0ofVD203oII@k
0?ooo`00A03oool809`4U080R`BL103oA9@30?m8U080o`0H0P3f01000`3o01P0odbD0?m@U0030?m@
U0<0oeFD00@0oef;0?mMW03oGI`0oefL103oGH/010355;@0FPS506XHc@1Z6<d207/Xc@L0Y87N103E
SLd60<eic@80aG7=1035ILD20;eUa@80]5g51@3oYI@30?nZU0@0ojFD0P3oXI@30?nAU0030?maR`3o
WI`0ohVL0080JP2L101J09`00`1B09`0@@2T0440Y00403T0W0D0<@2L0`0Y09`0100Y09@0402D00P0
U00809@30?mm_@@0gVVm103VGKd00`2d@;d0W2Rm09`X_@0309`X_@@0JPRd00<0202L0?lPFP3o85X0
1@3E28<40;d8R`@0_@bD1@3549@40;d@U0@0_@bD1@000002000020/0_@bD0`3oKI@40?mYU0P0ofFD
>`3oool004@0oooo202L19@00`2L29`0odBD0?m4U0030?m4U0@0odRD00@0o`0H0?H0403f0100kP08
1@3oD9@30?mEU0P0oef;0P1J2<D0101Z6<d0NbS=07/Xc@1k:<d209A0c@@0Y87N102mOMD60<eic@@0
aG7=0P35ILD40;eUa@030;AMa@3oYI@0ojFD0080ojFD0`3oZY@50?nUU080oj6D0P3oTI@20?maR`03
0?n9W01Z09`0JP2L0080JP2L101J09`30440Y0<0>@2L1@0a09`302T0W0<0402D00<0202D0>j1a@3^
PLD01P3NJKd20>IM_@<0]42m1@2L:;d306X8]00300P0W03o85X0obaZ00D0e@R3102m28/40;d<U003
0<d@U03549@0aA2D0080aA2D1@2m49@00`2m39@0odb;0;d<U005000000030000202m39@0_@bD00X0
_@bD0`3oKI@40?mYU0P0ofFD>`3oool004@0oooo202L19@00`2L29`0odBD0?m4U0030?m4U0@0odRD
0P3o01P20?H040040?l0603f01P0oe2D0?m@U0@0oeFD203oGH/00`234;@0JQS=07/Xc@0307/Xc@<0
U43=0P2TPMh50;eme@80aGG=0`3=NLd60<Eac@D0_FG51@3oYI@30?nZU0@0ojFD0P3oXI@30?nAU080
og6;00<0ohVL0?m]W01Z09`00`1Z09`305X0W0@0@@2T0`0i09`50340W080:@2L0`0@09@200P0U003
0>j1a@3NLLD0gW7500D0gVVm1@2d@;d409`X_@@0JPRd0P3o;6X00`3o;7/0e@R30=D8P`020=D8P`D0
_@R;0P2m39@20<d@U0@0aA2D1@2m49@00`2m39@0000000000004000000800008302m39@30?m]U0@0
ofVD1`3oII@00`3oGI@0oooo0?ooo`0i0?ooo`00A03oool809`4U00309`8W03oA9@0odBD00<0odBD
103oB9@20?l06080mP0@00@0kP080?H0603oD9@0oe2D103oEI@80?mMR`0308<@]02;6;@0U1bd0080
NbS=1@2D@<d50;eme@D0aGG=1P35LLd30<E]c@<0_FG5103oYI@30?nZU0D0ojFD0P3oXI@20?nAU0<0
og6;1P1Z09`305X0W00404X0Y0110:@0@@2T0440Y0<0>@2L1@0a09`202T0W0@0402D00<0202D0=ia
a@3NLLD00P3NLLD30=iY_@80_EG51@2d@;d409`X_@<0JPRd00<0ob1J0?l/JP3o;7/0103E28<50;d8
R`80_@bD0P3=49@50<D@U0@0_A2D00<0_@bD000000000000100000000`0000P0_@bD0;d<U00:0;d<
U080]0bD0P3oKI@40?mYU0H0ofFD0P3oGI@k0?ooo`00A03oool809`4U00309`8W03oA9@0odBD00<0
odBD103oB9@20?l06080mP0@00@0kP080?H0603f01P0oe2D103oEI@30?mMR`0300P0BP3oGH/0oef;
0080oef;00D0Pa2d08/H]02D7;@0U1bd07/Xc@0509A0c@80[5G50`2mOMD50<Eec@D0aG7=1@35KLd0
0`2mJLd0ojFD0?nUU0030?nUU0<0ojZD103oYI@20?nQU0<0oi6D0P3oLH/0103o<7/0iP1J06X0W02m
OMD406X0W080FP2L0P1:0:@30440Y0<0>@2L1@0a09`00`0Y09`0402D0100U0020100U080202D103N
LLD50;eEa@D0]42m0`2L:;d306X8]0030?lPFP3o;6X0obak00D0e@R3102m28/01@2m39@0cA2D0<d@
U03=49@0kP0P00@0aA2D102m49@7000000030000202m39@0_@bD00T0_@bD0`2d39@20?m]U0@0ofVD
1@3oII@30?mMU3/0oooo00140?ooo`P0W0BD00<0W0RL0?m4U03oA9@00P3oA9@50?m8U0040?m<U03o
01P0mP0@0?H04080kP0800<0mP0H0?m@U03oEI@00P3oEI@40?mMR`0300P0BP3oGH/0oef;0080oef;
00@0Pa2d08/H]02D7;@0U1bd1@2D@<d50:aEa@D0aGG=1@35LLd70<E]c@040?nQU03oYI@0ojFD0?nU
U0<0ojZD1@3oYI@20?nQU0<0oi6D0P3oLH/00`3o<7/0iP1J08<4Y00206X0W0050;f1e@1Z09`0JP2L
06X0W01J09`00P1:0:@30440Y0<0>@2L1@0a09`60100U00400P0U03NLLD0gW750=iaa@80aF751@2m
ELD40;A0_@@0RbS50`1Z4<D00`3o;6X0obak0=D8P`040=D8P`@0_@R;1@3=49@40<D@U0@0_A2D1P00
0002000020X0_@bD102d39@20?m]U0@0ofVD103oII@40?mMU3/0oooo00140?ooo`P0W0BD1@3oA9@4
0?m8U080odbD0P3o01P20?H040030>h0203f01P0oeFD00<0oeFD203oGH/208<@]00308/H]02D7;@0
U1bd0080Y2bm0`2D@<d50:aEa@80_F750`35MLd50<Eac@L0aFg=00@0oj6D0?nUU03oYI@0ojFD0`3o
ZY@50?nUU0040?nQU03oTI@0oi6D0?nAU080og6;00<0oc1k0>H0FP1R09@00P231:@506X0W00405X0
W01:0:@0BP2T04X0Y0<0@@2T0`0i09`40340W0030100W00@09@0402D00<0402D0P0809@00`3NLLD0
aF750<EQa@020<EQa@D0_EG5102T?<D408/Xa@80JQ3500<0ob1J0?l/N`3E28<0103E28<40;d8R`03
0=hDU03=49@0cA2D0080cA2D1@3549@20;d@U003000020000000000000@0000000<000080;d<U02m
39@0202m39@50;@<U080offD103oJI@40?mUU0@0oefD>`3oool004@0oooo202L19@50?m4U0@0odRD
0P3oC9@20?l06080mP0@0P3^00P0103f01P0oeFD0?mEU03oEI@80?mMR`80Pa2d00<0RaRd09@L]02D
7;@0102T;;d50:aEa@D0_F751@35LLd70<E]c@80oj6D0P3oYI@30?nZU0D0ojFD0P3oXI@30?nAU080
og6;00<0oc1k0>H0FP1R09@00`231:@506X0W0@0BP2T0`110:@303T0W0<0<@2L00<0402L0100U00@
09@0100@09@00`0809@0aF750<EQa@040<EQa@<0_EG50P2/C<D40:@la@<0RbS50P1Z4<D20?lPFPD0
e@R3102m28/00`3N59@0cA2D0<d@U0020<d@U0D0aA2D00<0_A2D0000200000001P0000000`0000P0
_@bD0;d<U0070;d<U0L0]0bD00<0offD0?mYU03oJI@00P3oJI@30?mUU0D0oefD>`3oool004D0oooo
1`2L19@50?m4U0@0odRD0`3oC9@00`3o01P0mP0@0?H040020>h020040?H0603f0100oeFD0?mEU0<0
oef;00<0obb30?mMR`3oGH/00P3oGH/208<@]00308/H]02D7;@0U1bd00@0Y2bm0P2d@;d30:aEa@D0
_F751035ILD60<E]c@80aG7=0P3oXI@20?nUU0<0ojZD1@3oYI@20?nQU080oi6D0`3oLH/00`3o<7/0
iP1J0680U00408<4Y0@0JP2L101:0:@30440Y0<0>@2L0`0a09`20100W0D0402D0P0809@00`35JLD0
aF750<EQa@030<EQa@D0[4c5102T?<D308/Xa@0406X@a@3o85X0obaZ0?l/N`D0e@R30P2m28/20=hD
U0@0cA2D00<000000<D@U03549@00P3549@00`2m49@00008000000050000008000081`2m39@90;@<
U0030?m]U03oJI@0ofVD0080ofVD0P3oII@60?mMU3/0oooo00150?ooo`L0W0BD103oA9@50?m8U0<0
odbD0P3o01P20?H040030>h0203N0000mP0@0080oeFD0`3oGH/00`3o;8<0oef;0?mMR`020?mMR`80
Pa2d00<0RaRd09@L]02D7;@0102T;;d40;A0_@D0_F751@35ILD20<E]a@<0aFg=0P35LLd20?nQU080
ojFD0`3oZY@50?nUU080oj6D0`3oTI@20?maR`040?l`N`3V05X0HP2D0680U0@0P`BT101Z09`00`1J
0:@0BP2T04X0Y00204X0Y0<0@@2T0`0i09`20340W00301P0W00@09`0402D00D0402D00<0202D0<EY
a@35JLD00`35HLD20;AIa@@0[4c51@2T?<D308/Xa@030?lPFP3o;6X0obak00D0e@R30P2m28/20=hD
U0030?n^W03=49@0cA2D0080cA2D103549@2000020H0000000<000080;d<U02m39@01P2m39@90;@<
U0030?m]U03oJI@0ofVD0080ofVD00<0ofFD0?mMU03oGI@01@3oGI@k0?ooo`00A@3oool709`4U0@0
odBD1@3oB9@30?m<U080o`0H0P3f01020>h02080mP0@00D0oeFD0?mMR`3oGH/0oef;0?l/P`040?mM
R`030:`L[02;6;@0U1bd0080U1bd102T;;d40;A0_@80_E2m0`2mHLD40<EUa@D0aFg50`35LLd20?nQ
U0<0ojFD0P3oZY@50?nUU080oj6D0P3oTI@30?maR`040?l`N`3V05X0HP2;0680U0D0P`BT0`1Z09`2
05X0Y0@0BP2T0P110:@303T0W080<@2L00<0602L0100W00@09`01@0@09@200P0U080aFW51@2dFLD4
0:a<a@@0Y3c50`2;:<D00`1Z4<D0obaZ0?l/N`050=D8P`030;d8R`3N59@0gQBD0080gQBD103=49@3
0<D@U0030000600000P0000000D000000P0000P70;d<U0X0]0bD00<0offD0?mYU03oJI@00P3oJI@8
0?mMU3/0oooo00150?ooo`H0W0BD1@3oA9@40?m8U0@0odbD0P3o01P20?H04080kP0800<0gP000?H0
403oGH/0203oGH/00`2/7:`0]22/0;@T[00209@L]0@0Y2bm102d@;d40;e@_@D0aFG51@35KLD20<ea
a@80oj6D2P3oYI@20?nQU0<0oi6D0P3oLH/01@3o<7/0iP1J0>H0FP3oA9@0aGW=00H0P`BT0P1Z09`2
05X0Y0@0BP2T0`110:@303T0W0040340W00H09`0602L0100W0H0402D00@0202D0;eQa@2mHLD0_F75
1@2dFLD30:a<a@D0[4S50`2dD<D00`3o;6X0obak0=D8P`040=D8P`030;d8R`3N59@0gQBD0080gQBD
103=49@01@0P02T0aA2D0000600001P0000800H000000P0000P60;d<U0`0]0bD0`3oJI@00`3oHI@0
oefD0?mMU0060?mMU3/0oooo00150?ooo`H0W0BD1@3oA9@40?m8U0@0odbD00@0oe2D0?l0603o01P0
mP0@0P3^00P00`3N0000e@000?H040020?mMR`030?l/P`3oGH/0oef;00<0oef;00@0[1b/0;@P[02d
9:`0]2B/1@2T;;d40;A0_@@0_E2m103=HLD50<E]a@<0cG750P3oXI@:0?nUU080oj6D0`3oTI@20?ma
R`030?l`N`3V05X0iP1J0080odBD1`231:@0101Z09`0FP2T05X0Y01J0:@404X0Y0<0@@2T0P0i09`3
01P0W080402L1@0@09@00`0809@0_F750;eQa@020;eQa@@0]5W5102/C<D50:a8a@80]53500<0ob1J
0?l/N`3E28<0103E28<50=hDU0@0cA2D00<0800Y0<D@U00001P00P0000P6000000030000202m39@0
_@bD00@0_@bD3@2d39@20?mYU080of6D203oGI@k0?ooo`00A@3oool609`4U0D0odBD103oB9@40?m<
U0030?m@U03o0200o`0H0080mP0@0P3^00P01@3N0000mP0@0?mMR`3oGH/0obb300@0oef;0P2/7:`0
0`2d8:`0]2B/0;@T[0020;dd]0<0Y2bm102d@;d40;e@_@@0cF750P3=JLD30<E]a@<0cG750P3oXI@9
0?nUU080oj6D0`3oTI@20?maR`80oc1k00D0iP1J0;@0:@3oA9@0odBD08<8Y00708<4Y0@0FP2T101:
0:@20440Y080>@2L100H09`00`0@09`0402D0100U0030100U080202D0`2mHLD50:a@a@@0[4c5102/
B<D20;A@a@030?lPFP3o;7/0e@R300@0e@R31@3N59@0201B04X0cA2D0<d@U03=49@0800Y0<D@U000
01P000081P000002000020D0_@bD3P2d39@0103oJI@0of6D0?mQU03oHI@80?mMU3/0oooo00150?oo
o`H0W0BD103oA9@50?m8U0@0odbD0P3oD9@00`3o0200mP0@0?H040020>h020050=h0003E0000oef;
0?mMR`0804X0103oGH/20:`L[0030;@P[02d9:`0]2B/00@0_CBd1@2d@;d40;e@_@@0cF75103=JLD3
0<eaa@80oj6D2P3oYI@20?nQU0<0oi6D0P3oLH/00`3o<7/0iP1J0>H0FP030?m4U0030:@DY0232:@0
P`BT00D0P`BT101J0:@404X0Y0<0@@2T00<0>@2L01P0W00H09`00P0H09`20100W0D0402D00<0202D
0;AMc@2dGLd00P2dGLd40:a@a@@0[4c51@2/B<D0102dD<D0ob1J0?l/N`3o;7/40=D8P`030?l/U03N
59@0gQBD00<0gQBD00@0cA2D0580BP3=49@0cA2D0P0001P00`0000P0000000000004000000030000
202m39@0_@bD00<0_@bD3`2d39@40?mQU0P0oefD>`3oool004D0oooo1P2L19@40?m4U0D0odRD103o
C9@20?m@U0030?l0803f0100mP0@00<0kP0800@0gP000?H0403oGH/0201:103oGH/20:`L[0030;@P
[02d9:`0]2B/00D0_CBd0`3=A;@50;e@_@@0cF75103=JLD30<eaa@80oj6D1`3oYI@0103oZY@0ojFD
0?nQU03oXI@30?nAU0<0og6;00<0oc1k0>H0FP3V05X00`3oA9@20:@DY00308<8Y0231:@0P`BT00<0
P`BT00<0HP2/05X0Y01J0:@00P1J0:@404X0Y080@@2T1P0H09`00`0@09`0402D0100U0030100U080
202D102dGLd40:a@a@@0[4c5102/B<D0102dD<D0ob1J0?l/JP3o;7/40=D8P`030?l/U03N59@0gQBD
00<0gQBD0`3=49@00`0P02T0000H00002007000000040000202m39@0_@bD0;d<U180]0bD0`3oHI@8
0?mMU3/0oooo00150?ooo`D0W0BD1@3oA9@40?m8U0D0odbD0P3oD9@20?l08080mP0@0P3^00P00`3N
0000e@000>H020050?mMR`80[1b/00<0]22/0;@T[02d9:`01@2m=;@40<e4]0<0eEFm1@3=HLD40<eY
a@80cG750P3oXI@80?nUU0040?nZU03oYI@0oj6D0?nQU0<0oi6D0P3oLH/20?l`N`030>H0FP2d02T0
odBD0080odBD0`2T5:@00`232:@0P`BT08<4Y00208<4Y080HP2/101J0:@404X0Y0030440Y00P0:@0
602L00@0602L0P0@09`50100U00300P0U02dILd0]5g=00<0]5g=0`2/D<D40:a<a@D0Y4C500<0]4c5
0?l/JP3o;7/0103E28<20?l/U0@0gQBD0P3=49@0100P02T0000H0000600000P60000008000080P2m
39@C0;@<U0<0of6D203oGI@k0?ooo`00A@3oool509`4U0D0odBD103oB9@40?m<U0@0oe2D00<0o`0P
0?l0603f01000P3^00P00`3N0000e@000>H020050?mMR`80[1b/00<0]22/0;@T[02d9:`01@2m=;@4
0<e4]0@0eEFm103EIKd40<eYa@80cG750P3oXI@70?nUU080ojZD0P3oXI@40?nAU080og6;00@0oc1k
0>H0FP3V05X0]00Y0`3oA9@40:@DY00408<8Y0231:@0P`BT08<4Y0<0HP2/0`1J0:@404X0Y0030440
Y00P0:@0802T00D0602L00<0402L0100U00@09@00`0@09@200P0U0@0]5g=102TC<d409a4a@@0Y4C5
00<0]4c50?l/JP3o;7/00`3E28<30?l/U0@0gQBD00<0DP1:0200:@0P02T00P0001P7000000030000
202m49@0_@bD01@0]0bD0`3oHI@80?mMU3/0oooo00150?ooo`D0W0BD103oA9@50?m8U0@0odbD103o
D9@20?l080060?l0603^00P0kP080>h0203N0000e@001@3oGH/20:`L[0030;@P[02d9:`0]2B/00D0
_CBd103=A;@40=EE_@@0eFFm103ELLD00`3=LLD0oj6D0?nQU0080?nUU080ojZD00<0ojFD0?nQU03o
TI@00P3oTI@20?maR`80oc1k0P3V05X40?m4U0D0Y1BT00<0P`RT08<4Y0231:@0101R0:`305X0Y0@0
BP2T0P0P0:@501P0W080402L1@0@09@00`0809@0[67=0:aIc@030:aIc@<0Y4c=102LA<D50:A4a@03
0?lPFP3o;7/0e@R30080e@R30`3o;9@20=hDU0030580BP3N59@0800Y0080800Y00<0000H00000000
00001@000002000020030;d@U02d39@0]0bD01<0]0bD0`3oHI@80?mMU3/0oooo00150?ooo`D0W0BD
103oA9@50?m8U0@0odbD103oD9@20?l080070?l0603^00P0kP080>h0203N0000e@000>H020030?mM
R`<0[1b/00<0]22/0;@T[02d9:`01@2m=;@40<e4]0@0eEFm103EIKd40=Eaa@030=Eia@3oXI@0oj6D
00L0ojFD0`3oZY@00`3oYI@0oi6D0?nAU0020?nAU080og6;00@0oc1k0>H0FP3V05X0]00Y103oA9@6
0:@DY00308<8Y0231:@0HP2/00<0HP2/101J0:@304X0Y0<0802T1@0H09`00`0@09`0402D0100U003
0100U080202D102/FLd40:A<c@@0W4C5102TA<D00`3o85X0obak0=D8P`020=D8P`<0obbD103N59@2
0200:@80000H1P000002000020030;d@U02d39@0]0bD01D0]0bD0P3oHI@80?mMU3/0oooo00150?oo
o`D0W0BD103oA9@50?m8U0@0odbD103oD9@0103oEI@0o`0P0?l0603o01P20>h02080gP0000@0e@00
0?mMR`3oGH/0oef;0`2/7:`00`2d8:`0]2B/0;@T[0050;dd]0@0cDBd103EEKd40=EU_@@0eG7500<0
eGW50?nQU03oXI@01`3oYI@20?nZU0<0ojFD0P3oTI@30?maR`040?l`N`3V05X0iP1J0;@0:@@0odBD
1`2T5:@00`232:@0HP2/0680[0030680[0<0FP2T0`1:0:@00`0Y0:@0802T0200Y00501P0W080402L
1@0@09@00`0809@0[5W=0:aIc@020:aIc@@0Y4c=102LA<D40:A4a@030?lPFP3o;7/0obak0080e@R3
103o;9@30=hDU080800Y00<0000H00002000000010000003000021P0]0bD0P3oHI@80?mMU3/0oooo
00150?ooo`@0W0BD1@3oA9@40?m8U0D0odbD103oD9@01@3oEI@0o`0P0?l0803o01P0mP0@0080kP08
00<0gP000=D0003oGH/00P3oGH/30=DXY0030;@P[02d9:`0]2B/00D0_CBd103=A;@40=EE_@@0eFFm
103ELLD20?nQU0L0ojFD0`3oZY@40?nUU0030?nAU03oLH/0og6;0080oc1k0P3V05X50?m4U0P0Y1BT
1P1R0:`305X0Y080BP2T0P0Y0:@20200Y0D0602L00<0402L0100U00@09@00`0@09@200P0U0@0Y5G=
102LB<d408/hc@@0PbS50P3o;7/20=D8P`@0obbD0P3N59@0101B04X0800Y0200:@0000P5000000@0
0008602d39@20?mQU0P0oefD>`3oool004D0oooo102L19@50?m4U0@0odRD103oC9@50?m@U0030?mE
U03o0200o`0P0080o`0H00<0mP0@0>h0203N00000P3E00020?mMR`@0eBRT00<0gRbT0=hdY02m=;@0
102m=;@40<e4]0@0eEFm103EIKd40=Eaa@80oj6D1`3oYI@20?nZU0D0ojFD0`3oLH/0103o<7/0iP1J
0>H0FP2d02T50?m4U0030?mEU03N=:@0Y1BT00D0Y1BT00<0L`R/0680[01R0:`0101R0:`305X0Y003
04X0Y00Y0:@0:@2T00<0802T100H09`20100W0D0402D00<0202D0:AEc@2TELd00P2TELd409a8c@@0
RcS=1023:<D20?l/N`030=D8P`3o;9@0obbD00<0obbD00@0gQBD0580BP1B04X0800Y0P0000P50000
00<000086@2d39@20?mQU0P0oefD>`3oool004D0oooo102L19@40?m4U0D0odRD103oC9@50?m@U080
oeFD0P3o02000`3o01P0mP0@0?H040020=h000030=D0003oGH/0oef;00@0eBRT00<0gRbT0=hdY03N
=:@01@3VA:`40>iM]0@0mW6m103^OLD20>j5a@80oj6D203oYI@20?nZU0D0ojFD00@0oifD0?maR`3o
<7/0oc1k0P3V05X00`2d02T0odBD0?m4U0020?m4U080oeFD0`3N=:@40:@DY080L`R/1@1R0:`305X0
Y0@0:@2T0P0P0:@501P0W0030100W00@09@0402D00<0402D0P0809@30:AEc@D0W4S=102;><d308<X
a@030?l/JP3o;7/0e@R300D0obbD0P1B04X20200:@8000081@000003000021T0]0bD0P3oHI@80?mM
U3/0oooo00150?ooo`@0W0BD103oA9@50?m8U0@0odbD103oD9@30?mEU080o`0P0P3o01P20?H04004
0=h0003E0000e@000?mMR`@0eBRT00<0gRbT0=hdY03N=:@01@3VA:`40>iM]0@0mW6m103^OLD20>j5
a@80oj6D1`3oYI@30?nZU0D0ojFD00@0oifD0?maR`3o<7/0oc1k0P3V05X01@2d02T0odBD0?m4U03o
A9@0aGg=0080oeFD103N=:@30:@DY0<0L`R/1@1R0:`205X0Y0040340[00Y0:@0:@2T02T0Y0<0802T
100H09`20100W0D0402D00<0202D09aIc@2LFLd00P2LFLd409A8c@@0RcS=0`23:<D00`3o;6X0obak
0=D8P`050?l/U080DP1:00<0800Y0000400000P01@000003000020030;@@U02d39@0]0bD01P0]0bD
00<0of6D0?mMU03oGI@01P3oGI@k0?ooo`00AP3oool00`2T29@0W0BD0?m4U0040?m4U0D0odRD103o
C9@40?m@U0@0oeFD00<0o`0P0?l0603o01P00P3f0100103^00P0gP000=D0003oGH/40=DXY0030=h/
Y03N=:@0gSBT00D0iTB/103^GK@40?Ia_@@0kWg500<0kXG50?nQU03oXI@0203oYI@20?nZU0D0ojFD
0P3oWI@20?l`N`80iP1J00D0]00Y0?m4U03oA9@0odBD0<Emc@030?mEU0H0gSBT00<0Y1BT07<8[01c
2:`00P1c2:`50680[00305X0Y00a0:`0<@2/00<0:@2T0P0P0:@501P0W0030100W00@09@0402D00<0
402D0P0809@309aIc@@0U4S=1023=<d206XLc@0408<Xa@3o85X0obak0=D8P`@0obbD0`1B04X00`0P
02T0000800002005000000<0000800<0]12D0;@<U02d39@0602d39@00`3oHI@0oefD0?mMU0060?mM
U3/0oooo00160?ooo`80Y0RD1@3oA9@40?m8U0D0odbD103oD9@40?mEU080o`0P00D0o`0H0?H0403f
0100mP0@0>h020020=D000@0eBRT00<0gRbT0=hdY03N=:@01@3VA:`40>iM]0@0mW6m103^OLD00`3^
QLD0oj6D0?nQU0070?nUU0<0ojZD1@3oYI@20?nMU0050?nER`3o<7/0iP1J0>H0FP2d02T00`3oA9@4
0?mEU0L0gSBT1@1c2:`50680[080<@2/100Y0:@20200Y0@0602L0P0@09`50100U00400P0U02TIMD0
Y6GE0:AUe@@0U4S=1023=<d306XLc@030?lPFP3o;7/0obbD00@0obbD0`1B04X00`00010000080000
0004000000@0000800<0]12D0;@<U02d39@0602d39@00`3oHI@0oefD0?mMU0060?mMU3/0oooo0016
0?ooo`80Y0RD103oA9@50?m8U0@0odbD1@3oD9@40?mEU080o`0P0P3o01P20?H040030>h0203E0000
e@0000@0eBRT00<0gRbT0=hdY03N=:@01@3VA:`40>iM]0@0mW6m103^OLD00`3oYLd0oj6D0?nQU007
0?nUU080ojZD1@3oYI@30?nMU0050?nER`3V05X0iP1J0>H0FP2d02T00P3oA9@00`35OLd0oeFD0?mE
U0020?mEU0L0gSBT0P2;6;@407<8[0@0HP2/0`0a0:`302T0Y0<0802T100H09`00`0@09`0402D0100
U0030100U00400P0U02TIMD0Y6GE0:AUe@@0U5GE1023=<d406XLc@030?l/N`3obZ@0obbD0080obbD
00<0N`1J0580BP1B04X00P0001000`0000P0000000000003000000<000080`2d49@I0;@<U0030?mQ
U03oGI@0oefD00H0oefD>`3oool004H0oooo0P2T29@40?m4U080od2D0`3oB9@40?m<U0D0oe2D103o
EI@0103oGH/0o`0P0?l0803o01P30?H040030>h0203E0000eBRT00<0eBRT00<0gRbT0=hdY03N=:@0
1@3VA:`40>iM]0@0mW6m103o[/D20?nQU0L0ojFD0`3oZY@50?nUU080oifD0P3oUH/00`3oQH/0iP1J
0;@0:@020?m4U0030<Emc@3oEI@0oeFD00<0oeFD1`3N=:@308/H]0@0L`R/0`1R0:`0100i0;@0<@2/
0340[00a0:`302T0Y080802T100H09`20100W0@0402D0P0008/20:Aae@@0U5GE101k@=D406XLc@03
0?l/N`3obZ@0obbD0080obbD00@0N`1J0580BP1B04X0000@0P0000P5000000<000080`2d49@J0;@<
U0P0oefD>`3oool004H0oooo0P2T29@40?m4U0<0od2D0P3oB9@40?m<U0D0oe2D103oEI@00`3oGH/0
o`0P0?l080020?l06080mP0@00<0kP080=h0003E0000103E::@30=hdY0@0iTB/103^GK@20?Ia_@<0
ojZm0`3o[/D20?nQU0L0ojFD0P3oZY@50?nUU0<0oifD0P3oUH/0103oQH/0iP1J0;@0:@3oA9@20<F1
c@D0oeFD1`3N=:@408/H]0@0L`R/0P1R0:`203T0]080<@2/0`0Y0:@30200Y0@0602L00<0402L0100
U00@09@00P0@09@20000R`80Y77E102LJMh407]0e@<0JRCN00H0JQc=0?l/N`3obZ@0olZT0?l/U01k
05X20580BP03000080000100000800D000000`0000P40;@@U1X0]0bD203oGI@k0?ooo`00AP3oool2
0:@8U0@0odBD103o@9@50?m<U0@0oe2D1@3oEI@00`3oGH/0o`0P0?l080020?l06080mP0@0P3^00P0
0`2d0000eBRT0=DXY0020=DXY0<0gSBT103VA:`40>iM]0D0ojZm0P3o[/D20?nQU0P0ojFD0P3oZY@5
0?nUU080oifD0P3oUH/20?n5R`040>H0FP2d02T0aH7=0<F1c@H0oeFD1`3N=:@508/H]0@0L`R/00@0
HP2/03T0]00i0;@0>@2d0P0a0:`302T0Y080802T100H09`20100W080402D100008/00`2TLMD0W6WN
09aYgP0209aYgP80PeGN0P1k@=D406XTgP070?l/N`3obZ@0olZT0?l/U01k05X0DP1:000080020000
4003000020000000000000<000000`0000P0102m49`0]12D0;@@U02d49@J0;@<U0L0oefD?03oool0
04H0oooo0P2T29@40?m4U0H0od2D0`3oC9@40?m@U0@0oeFD0`3oGH/20?l08080o`0H0P3f01000`3^
00P0gP000;@000030=DXY0<0gSBT103VA:`20>iM]0<0oiVd1@3oZ[d00`3o[/D0oj6D0?nQU0070?nU
U0<0ojZD103oYI@30?nMU080oiF;0P3oQH/20;@0:@030<F1c@3oEI@0oeFD00D0oeFD1`3N=:@608/H
]0<0L`R/100i0;@30340[0<0:@2T0P0P0:@401P0W0030100W00008/0002;00@0002;00<0]8GE0:B5
gP2TQMh00P2TQMh408=EgP@0JRCN00<0ob1J0?o:Y03obZ@00P1k05X2000080030000400000P00000
00@00000100000P00`2m49`0]12D0;@@U0020;@@U1T0]0bD1@3oGI@30;@0DS/0oooo00160?ooo`03
0:@8U03oA9@0odBD00<0odBD203o@9@50?m@U0@0oeFD0`3oGH/20?l08080o`0H0P3f01020>h02004
0;@0003E::@0eBRT0=DXY0<0gSBT103VA:`50?nI]0D0ojZm0P3oXI@80?nUU080ojZD1@3oYI@30?nM
U080oiF;0P3oQH/00`3oIH/0]00Y0;eme@070?mEU0L0oe2/1`2;6;@207<8[0030440]00i0;@0>@2d
0080>@2d0P0a0:`302T0Y0<0802T0`0H09`20000U0H0002;0`2TQMh509AaiP@0JRcV00@0ob1J0?o:
Y03obZ@0N`1J0`0002000`000100000800000004000000<000080P2m49`40;@@U1X0]0bD0P3oGI@5
0;@0DS/0oooo00160?ooo`030:@8U03oA9@0odBD00<0odBD2P3o@9@30?m@U0@0oeFD0`3oGH/30?l0
80070?l0603f0100mP0@0?H0403^00P0gP000;@000020=DXY0<0gSBT0P3VA:`30?ma[0@0oiVd1@3o
Z[d20?nQU0L0ojFD0`3oZY@40?nUU0<0oifD0P3oUH/30?n5R`030?mUR`2mOMD0oeFD00H0oeFD00<0
ofFL0?m@[03oD:`01@3oD:`20:@d_@H0RaRd00<0L`R/0440]0110;@0100i0;@20340[0<0:@2T0P0P
0:@301P0W080002D1P0008/20:B5gPD0U77V1@1k=>H0100i0=h0olZT0?o:Y01k05X2000080030000
400000P0000800@00000100000P20;d@W0@0]12D6P2d39@30;@0BP@0]01B>`3oool004H0oooo00<0
Y0RD0?m4U03oA9@00P3oA9@<0?m0U080oe2D103oEI@40?mMR`80o`0P0P3o01P20?H04080kP0800<0
gP000=DXY03E::@00`3N=:@50?ma[0D0oiVd0`3oZ[d00`3om/D0oj6D0?nQU0070?nUU080ojZD1@3o
YI@30?nMU080oiF;0`3oQH/00`3oIH/0oeFD0?mEU0050?mEU080ofFL1`3oD:`40:@d_@D0RaRd0`11
0;@303T0]0<0<@2/0P0Y0:@30200Y00301P0W00009@0002D0080002D1P0008/50;BMiP@0NcCV0`1:
0=D00`3obZ@0P`1R07/0FP02000080030000400000P0000000@000000`0000P30;d@W0@0]12D6P2d
39@30;@0BP@0]01B>`3oool004H0oooo00<0Y0RD0?m4U03oA9@00P3oA9@=0?m0U0D0oeFD103oGH/2
0?l08080o`0H0`3f0100103^00P0gP000<d0003E::@40?m<Y0@0og6/1@3oVK@20?nZ_@030?ofa@3o
XI@0oj6D00L0ojFD0`3oZY@50?nUU080oifD0`3oUH/20?n5R`80ofF;00<0]7WE0?mEU03oEI@0103o
EI@20?mUW0L0oe2/1@2T=;d408/H]0040584_@110;@0@@2d0440]0<0>@2d0P0a0:`302T0Y080802T
1@0009@60000R`@0]9gV102LINH207/0e@80U02/0P3obZ@01@0001P0000P000080000100000800D0
00000`0000P40;d@W0<0]12D6P2d39@30;@0BP@0]01B>`3oool004H0oooo00<0Y0RD0?m4U03oA9@0
0P3oA9@=0?m0U080ocbD0`3oEI@40?mMR`<0o`0P0P3o01P20?H04080kP0800<0gP000?ldW03o=9`0
0`3oC:@40?ma[0D0oiVd0`3om/D20?nQU0L0ojFD0P3oZY@50?nUU0<0oifD0P3oUH/30?n5R`030:aa
e@3oIH/0[77E00D0oeFD0`3oII`70?m@[0L0Y3Bm0P2;6;@20584_@80@@2d100i0;@20340[080:@2T
200009@60000R`80g/;N102LINH20;eYe@0509@0[02T0680oaaZ0?o:Y01k05X00P0002000`000100
000800000004000000@00008102m49`40;@@U1X0]0bD0P2d04X50;@0DSX0oooo00160?ooo`030<d0
BP3oA9@0odBD0080odBD3@3o@9@40?llU0H0oef;00@0o`0Y0?l0803o01P0o`0H0P3f01020>h02003
0=h0003=0000ocBL00<0odbT1@3oLJ`30?nI]0<0ooZm0P3oXI@80?nUU080ojZD1@3oYI@20?nMU0<0
oiF;0`3oQH/20?mUR`030:aae@3oEI@0oeFD0080oeFD103oII`70?m@[0P0Y3Bm101B1;d20440]0<0
>@2d0`0a0:`00`0Y0:@0002L0000U0060000U0H0002;00<0g/;N0=k:gP3Nb]h00P3Nb]h20;eYe@06
09@0[03oa[d0oaaZ0?lLJP3obZ@0000H0P0002000`000100000800000004000000<000081@2m49`4
0;@@U1X0]0bD0P2d04X50;@0DSX0oooo00160?ooo`D0odBD3@3o@9@40?llU080ocR;103oGH/20?l0
:@<0o`0H0P3f01020>h020030=h0003=0000odbT0080odbT1@3oLJ`20?nI]0@0ooZm0P3oXI@70?nU
U0<0ojZD103oYI@30?nMU0<0oiF;0P3oQH/30?mUR`040:aae@3oEI@0oeFD0?mEU0D0ofFL1`3oD:`8
0:@d_@03068@a@1B1;d0DPBm0080DPBm0P110;@303T0]080<@2/0`0009`70000U0D0002;103Nb]h2
0;eYe@80olJm0`3o76X00`3obZ@0000H00008002000040D00000100000P50;d@W0@0]12D6P2d39@3
0;@0BP@0]01B>P3oool004H0oooo1@3oA9@=0?m0U0@0ocbD0`3o>8/40?mMR`<0o`0Y00<0o`0H0?H0
403f01000P3^00P00`3N0000c@000;d000020?m<Y0D0og6/00<0oiVd0?oj_@3on[d00P3on[d20?nQ
U0P0ojFD0P3oZY@50?nUU0<0oifD0P3oUH/30?n5R`<0ofF;00@0W6WE0?mEU03oEI@0oeFD103oII`2
0?n5[0H0offd0`2mD<D50:@d_@80HQ35101B1;d20440]0<0>@2d00@0<@2/0000W00009`0002L1`00
09@60000R`80g/[N0`3om/d20?o6_@80oaaZ00H0od1k0?o:Y0000200000P0000400000P5000000<0
00080P2m69`40;d@W0@0]12D6P2d39@30;@0BP@0]01B>P3oool004D0oooo00<0c@1:0?m4U03oA9@0
0`3oA9@=0?m0U0@0ocbD103o>8/30?mMR`@0o`0Y0`3f01020>h020040=h0003=0000_@000?m<Y0D0
og6/1@3on[d20?nMU080oj6D1@3oYI@30?nZU0@0ojFD0`3oWI@30?nER`<0ohF;0P3oIH/0102LJMD0
olJT0?mEU03oEI@40?mUW0<0ohF/1P3oKK@50;e@a@<0Y3Bm0`1R4<D40584_@80@@2d0P0i0;@50000
W0L0002D1@0008/20?o>c@80ooK=0P3oa[d0202T08<0oaaZ0?lLJP3o@7/0000H0000803obZ@0000@
1P00000300002080_ARL1@2m49`40;@@U1T0]0bD0`2d04X40;@0DSX0oooo00150?ooo`030<d0BP3o
A9@0odBD0080odBD3P3o@9@40?llU0@0ocR;00@0gQ2;0?mMR`3oGH/0R`BL103o02T0103o0200mP0@
0>h0203^00P20=h000030<d0003oC:@0odbT00@0og6/0P3ogZ`20?oj_@030?Ii_@3oWI@0oifD0080
oj6D1@3oYI@20?nZU0D0ojFD0`3oWI@30?nER`<0ohF;00D0ReGN0?mUR`3oaZ@0olJT0?mEU0040?mU
W0@0ohF/1P3oKK@70;e@a@D0HQ35101B1;d010110;@0>@2d0000Y0000:@40000W0L0002D1P0008/2
0?ofc@<0olJm00L0Y0230?lLJP3o76X0od1k000060000200000@00H000000`0000P30;dHW0D0_A2L
102d49@E0;@<U0D0[0RD0P2d04X40;@0DSX0oooo00150?ooo`030<d0BP3oA9@0odBD0080odBD3@3o
@9@50?llU0@0ocR;00@0gQ2;0=DHW03oGH/0R`BL103o02T20?l080<0kP0800@0gP000<d0002m0000
odbT0`3oLJ`40?oN[0030>H8P`3oWI@0oifD00<0oj6D0P3oYI@20?nZW0<0ojZD103oYI@30?nMU0<0
oiF;0`3oQH/30?mUR`030?o6Y02/08<0ofFL00<0ofFL1@3oQJ`60?m]]0L0_E350P1c;<d4068@a@@0
DPBm0P000:`20000Y0@0002L1`0009@50000R`80ooK=0P3oa[d20:@0P`80oaaZ00@0oeF300006000
0200000@1P000002000020040000402m69`0_ARL0;dHW0D0_A2L102d49@C0;@<U0L0[0RD0P2d04X5
0;@0DST0oooo00140?ooo`80c@1:103oA9@=0?m0U0D0ocbD103o>8/0103N48/0eARL0?mMR`2;19`5
0?l0:@<0o`0P00D0kP080=h0003N0000c@0000P0]0020?ma[0060?m8L`3ogZ`0omj/0?lLJP3ogZ`0
iPR30P3oWI@20?nQU0<0ojFD0P3oZY`20?nbW0D0ojFD0`3oWI@30?nER`<0ohF;0`3oIH/00`3oaZ@0
[0230?oR]0020?mUW0H0ohF/1P3oKK@70;e@a@<0Lbc=101R4<D30584_@<0002/0P000:@30000W0L0
002D1P0008/20?o6_@<0Y02300<0oaaZ0?m0N`0001P00P00020600000004000020000100000@0000
40@0_ARL102m49`40;@@U140]0bD2@2/29@30;@0BP@0]01B>@3oool004@0oooo00<0]01:0?m4U03o
A9@00`3oA9@=0?m0U0@0ocbD1@3o>8/20=h@R`030=DHW03oGH/0eARL00@0o`0Y103o02020=h00006
0<d0002m0000202d0?ma[03ogZ`0odQc0P3ogZ`0103V28<000230?nMU03oWI@20?nQU080ojFD0`3o
ZY`20?nbW080okJL0P3oYI@40?nMU0<0oiF;0`3oQH/20?mUR`050?o6Y02;07<0[0230?oR]03oII`0
1P3oQJ`20?nQ_@D0ohFm1035KLD30;e@a@D0Lbc=0`1R4<D30000_@<0002/00<0002T0000W00009`0
0P0009`70000U0D0002;0P3o@9`30:@0P`050?lLJP3o@7/0000H0000600001001P000000100000P0
000@0000403=<:`40;dHW0@0_A2L1@2d49@<0;@<U0d0[0RD0`2d04X40;@0DST0oooo00140?ooo`03
0;@0BP3oA9@0odBD00<0odBD3@3o@9@40?llU0D0ocR;0P3N48/30=DHW0D0o`0Y103o0200103f0200
gP000<d0002m00050?oN[0030000P`3oWI@0oifD0080oj6D0`3oYI@20?nZW0<0ok:L0P3o]Y`00`3o
^Y`0ojFD0?nMU0020?nMU0<0oiF;0`3oQH/01`3oIH/0NcSE0?mUR`3oaZ@0R`1c0?l0>@3oh[@01@3o
QJ`40?nQ_@D0ohFm1`35KLD607</c@80HQ350P0H0<d20000_@80002/0P000:@30000W0L0002D1P00
08/0203o@9`0Y0230:@0P`2T08<0oaaZ0?lTP`0001P0000P1P00000200002080000@00<0cC2/0;dH
W02m69`00P2m69`50;d@W0@0]12D202d39@A0:`8U0<0]01:102d058i0?ooo`00A03oool00`2d04X0
odBD0?m4U0030?m4U0d0od2D103o?9@50?lhR`80gQ2;0P3E69`20;d@W0@0o`0Y103o02020?H08080
c@0000H0_@000?oN[03ogZ`0omj/0>H8P`3oool20?nMU080oj6D0P3oYI@30?nZW080ok:L0`3o]Y`0
0`3o^Y`0oifD0?nMU0020?nMU0<0oiF;0`3oQH/00`3oIH/0NcSE0?mUR`0208/0L`030=D0003oh[@0
on[500<0ohF/1@3oXKd50?n5_@L0aFg50P2;B=D507</c@@0603=0P000;d20000[080002T0`0009`7
0000U0D0002;00P0N`230:@0P`2T08<0Y0230?lLJP3o98<0000P0=D0N`H0000000<0000800004000
01000P3=<:`40;dHW0D0_A2L102d49@40;@<U1D0[0RD0`2d04X40;@0DST0oooo00140?ooo`030;@0
BP3oA9@0odBD00<0odBD3@3o@9@40?llU0@0ocR;0`3N48/20=DHW080_A2L1@3o02T40?l08080mP0P
00<0c@000;d0002300000P3ogZ`00`3o76X0oifD0?nMU0030?nQU080ojFD0P3oZY`30?nbW080okJL
0P3o^Y`00`3o]Y`0oifD0?nMU0040?nER`<0ohF;0`3oIH/208/0L`040=D0003oj/D0on[50?oZa@L0
oj6m1@3oQKd70<E]a@@0RdSE0`1c;<d203T4e@<0603=0P000;d20000[0030000Y00009`0002L0080
002L1P0009@60000R`<0Y02300<0od1k0000600001P01`0000000`0000P0000@000040020<d`[0D0
_ARL102m49`40;@@U080]0bD602/29@20;@0BP@0]01B>@3oool004<0oooo0P2d04X40?m4U0d0od2D
1@3o?9@40?lhR`@0gQ2;102m49`40?l0:@@0o`0P0`3f02001@3=0000_@0008<0003o76X0oooo0080
oifD0P3oXI@20?nUU0<0ojZL0P3o/Y`30?nfW080okZL0P3o]Y`0103oWI@0oiF;0?nER`3oUH/40?n5
R`80ofF;0`2;07<00`3E0000on[50?oZa@020?oRc@@0oj6m0P3o//D50?JIa@H0cH7=1`2;B=D403T4
e@<0603=0P000;d20000[0040000Y00009`0002L0000W0L0002D1@0008/20:@0P`0302T0HP3o98<0
000H00L0000000<00008000040000100103=<:`40;dHW0@0_A2L102d49@J0:`8U080]01:1@2m058h
0?ooo`00@`3oool20;@0BP@0odBD3@3o@9@50?llU0@0ocR;103N48/0103E69`0_A2L0;d@W02m49`4
0?l0:@D0o`0P0P3f02001@3^01P0_@000;d0002T0000oooo0080oifD0P3oXI@20?nUU0030100U03o
ZY`0ok:L0080ok:L0P3o]Y`20?njW0<0okJL103oUH/30?n5R`<0ofF;0`2;07<00`3E0000on[50?oR
c@020?oRc@80oj6m103o//D50?JIa@H0cH7=0`2LIMD408]8e@80FQSN100i1=D201P0c@80002m00<0
002/0000Y0000:@00`0009`60000U0D0002;0P2T08<00`3o76X0obB3000060070000000300002000
0100000@00@0cC2/102m69`40;d@W0D0Y0RL6@2/29@30<D0DP@0_@1B>03oool004<0oooo00<0]01:
0?m4U03oA9@00`3oA9@=0?m0U0D0ocbD103o>8/40=h@R`040=DHW02m49`0_A2L0;d@W0D0o`0Y103o
02030?H080030>h0603V01P0_@000080oifD0P3oXI@30?nUU080ojZL0P3o/Y`30?nfW080okZL0`3o
]Y`0103oYI`0oiF;0?nER`3oUH/30?n5R`030?mUR`1Z5<d0ofF;00<0R`1c00<0e@000?oRc@3oh/d0
0P3oh/d60?nba@D0mYW51P3=PLd609aUe@@0FQSN100i1=D201P0c@80002m00<0002/0000Y00009`0
0P0009`70000U0D0002;00<0Y0230>H0JP3o98<01`000000100000P0000@0000403==:`40<d`[0@0
_ARL1@2D19`40:@8W1T0[0RD0`3505840;d0DSP0oooo00130?ooo`030;@0BP3oA9@0odBD00<0odBD
3@3o@9@40?llU0D0ocR;103N48/20=DHW0<0_A2L103o02T50?l08080mP0P0P3^01P00`3V01P0oifD
0?nMU0020?nQU080ojFD0P3oZY`00`0@09@0ok:L0?nbW0020?nfW080okZL103o]Y`00`3oYI`0oiF;
0?nER`040?n5R`030?mUR`3oaZ@0R`1c00<0R`1c00<0e@000?l0>@3oh/d00`3od/d50?nba@D0iZG=
1P35TMD609aUe@80LcSN101J6=h303T4e@80603=0P000;d00`000:`0002T0000W0020000W0H0002D
1@0008/00`2T08<0obB30000600700000005000020000100000@0=EM_@3==:`00`3=<:`507<0W0@0
U0BL102T29`I0:`8U0<0a@1B102m058h0?ooo`00@`3oool00`2d04X0odBD0?m4U0030?m4U0d0od2D
103o?9@50?lhR`@0gQ2;0P3E69`30;d@W0D0o`0Y103o02030?H080030>h0603oWI@0oifD0080oj6D
0`3oYI@0100809@0ojZL0?nbW03o/Y`30?nfW080okZL0`3o]Y`30?nUW0040?nER`3oQH/0ohF;0?n5
R`<0ofF;102;07<00`3E0000o`a10?oBc@030?oBc@H0m[K=103VYLd60<FAe@D0Y7WN1@1c>=h305XH
gP@0002m00<0002;08/000000:`00P000:@20000W0L0002D1@0008/00`3o98<00000000000050000
0003000020000100000@0080eEfm00<0cCB/0<d`[03=<:`00P110:@407<0W0@0U0BL102T29`I0:`8
U0<0a@1B102m058h0?ooo`00@P3oool20;@0BPD0odBD3@3o@9@40?llU0D0ocR;103N48/00`3N03T0
eARL0=DHW0030;d@W0@0o`0Y1@3o02020?H080030>h0603oWI@0oifD0080oj6D0P3oYI@30?nZW080
ok:L0`3o]Y`20?njW0<0okJL0`3oYI`40?n5R`<0ofF;102;07<00`3E0000o`a10?oBc@020?oBc@80
k/KE1@3f]/d40>JUc@D0aI7E1P2TNMh308=IiP<0LcSN100Y0=h30000_@040000R`2;0000W00009`0
00<0002L1P0009@50000R`030?lTP`000000000000D0000000<000080000400001000P3EGKd00`3=
=:`0@@2T0440Y0020440Y0@0L`2L102D19`40:@8W1T0[0RD0`3505840;d0DSP0oooo00120?ooo`80
]01:1@3oA9@=0?m0U0@0ocbD103o>8/50=h@R`<0gP0i0`2m49`50?l0:@@0o`0P0`3f02020?nMU080
oj6D0P3oYI@20?nZW080ok:L0`3o]Y`20?njW0<0okJL103oYI`01`3oNI`0ohF;0?n5R`3oQH/0ofF;
0?o6Y03oIH/0102;07<00`3E0000o`a10?oBc@040>k6e@<0m[K=0P3N/]D40=FZe@D0aIWE1@2/RMh6
08=IiP@0FQSV0`0Y0=h20000_@040>i0[02;0000W00009`00080001R1`0009@50000R`H0000000@0
0008000040000100000@0`080:`0100a0:@0@@2T0440Y0110:@407<0W0D0U0BL102T29`I0:`8U080
a@1B102m058h0?ooo`00@P3oool20;@0BP@0odBD3@3o@9@50?llU0@0ocR;1@3N48/01@0@06X0ocbL
0=h0803N0200_A2L0080_ART103o02T50?l080030?H0803oWI@0oifD0080oj6D0P3oYI@30?nZW080
ok:L0`3o]Y`20?njW0<0okJL0`3oYI`20?miW0<0ohF;00<0ofF;08/0L`2;07<0102;07<20=D000D0
k/KE1@3N/]D40=FZe@D0aIWE102/RMh309AeiP<0PeWV0`1k@>H505XHiP80:@3N00<0002m0>i0[02;
00000P2L00020000HP030000N`0009@0002D00<0002D1@0008/600000003000020000100000@0080
002m0P080:`0100a0:@0@@2T0440Y0110:@407<0W0D0U0BL102T29`I0:`8U080a@1B102m058h0?oo
o`00@P3oool00`2d04X0odBD0?m4U0030?m4U0d0od2D1@3o?9@40?lhR`D0gQ2;00D0401Z0?llW03o
?9`0gP0P0;d@W0020;dHY0@0o`0Y1@3o02000`3f0200oifD0?nMU0020?nQU080ojFD0P3oZY`30?nb
W080okJL0P3o^Y`30?nfW0@0ojFL0`3oNI`00`3oQH/0ofF;0?mUR`0608/0L`80e@0000<0eL;N0=jj
e@3N^]D00`3N^]D40=jbe@@0eJ[E1035VMD40:b9gPH0U7GV1P1k@>H505X@iP<0:@3E00D0R`0009`0
00000680001R0000L`020000N`@0002D1@0008/40000008000080P0001020000_@<0202/10110:@4
07<0W0@0U0BL102T29`I0:`8U080a@1B102m058h0?ooo`00@P3oool00`2d04X0odBD0?m4U0030?m4
U0d0od2D103o?9@50?lhR`D0gQ2;00@0401Z0?llW03o?9`0ocbL0`2m6:@50?l0:@@0o`0P0P3oWI@2
0?nQU080ojFD00<0ojZL0>H0603oZY`00P3o/Y`30?nfW080okZL0`3o]Y`30?nUW0@0ogVL00@0ohF;
0?mUR`3oIH/0ofF;1@2;07<20=D000030?l0>@3=]]h0g[[E00<0g[[E1@3E[]h30<fZgP@0_IgN102d
TMh40:B5gPH0RfGV1`1k?>H205X@iP80:@3E00@0R`0009`000000680001R0`0007/00`0008<0002D
0000U0050000R`@0000000<0000800004000010010000;d200P0[0040340Y0110:@0@@2T0440Y0@0
L`2L102D19`40:@8W1T0[0RD0P3505840;d0DSP0oooo00110?ooo`80]01:1@3oA9@=0?m0U0@0ocbD
1@3o>8/50=h@R`040100JP3o?9`0ocbL0?llW080ogV/0P2m6:@40?l0:@@0o`0P0P3oWI@20?nQU080
ojFD0P3oZY`00`3V01P0ok:L0?nbW0020?nfW080okZL0`3o]Y`40?nUW0@0ogVL00<0ohF;0?mUR`3o
IH/01P2;07<20=D000030?l<@@3=]]h0cKKN00@0cK;N103E[]h30<fZgP@0_IgN0`2dTMh50:B5gP@0
W7gV1P2;HNH608=<iP80RdSV00@0R`0009`000000680001c0P0007/30000P`H0002;0P0000020000
2080000@00@0>@3N0000_@000;d0002m0P080:`0100a0:@0@@2T0440Y0110:@407<0W0@0U0BL102T
29`I0:`8U080a@1B102m058h0?ooo`00@@3oool20;@0BPD0odBD3@3o@9@40?llU0D0ocR;103N48/0
0`3o?9`0401Z0?llW0020?llW0@0ogV/1@3o02T30?l08080oifD00@0oj6D0?nUU03oYI@0ojFD0P3o
ZY`20?nbW0<0okJL0P3o^Y`30?nfW0<0ojFL1@3oNI`30?mUR`H0R`1c0P3E0000103o3440aJkN0<F^
gP35[]h40<fbgP@0aJ[N0P35YMh40;fQgP<0]9WN102/TMh809amiPH0U6gV1P2DINH00`2L0000001R
0000HP030000N`@00023100008/200000003000020000100000@0080olJm0P3oh[d20000_@80202/
0`110:@407<0W0D0U0BL102T29`H0:`8U0<0a@1B102m058g0?ooo`00@@3oool20;@0BPD0odBD3@3o
@9@40?llU0D0ocR;103N48/20100JP<0ocbL103oNJ`00`3oXKd0o`0Y0?l0:@020?l0:@80o`0P0P3o
WI@20?nQU080ojFD00<0ojZL0>h0603V01P00P3o/Y`30?nfW080okZL0P3o]Y`40?nUW0@0ogVL00<0
of6L0?mUR`3oIH/01`2;07<20=D000040?l<@@35[]h0aJkN0<F^gPP0aJ[N0P35YMh30;fQgP<0]9WN
102/TMh40:B=iP80W7gV1P2LPNH609amiP@0Y7WV00<0W0000000HP0007<00P0007/60000P`80002;
00<000000000200000P00P0001040?oR_@040?o>]0000;d0202/00P0[0@0@@2T0`1c09`509@4W0@0
Y0RL6@2/29@20<D0DP@0_@1B=`3oool00440oooo0P2d04X50?m4U0`0od2D1@3o?9@40?lhR`D0gQ2;
0P0@06X30?llW0@0ogV/00<0oj6m0?l0:@3o02T00`3o02T00`3o0200oifD0?nMU0020?nQU080ojFD
0P3oZY`20?nbW0<0okJL0P3o^Y`30?nfW0<0ojFL1@3oNI`00`3oC9`0ofF;0?mUR`0708/0L`80e@00
00<0o`a10<FZgP35Z]h01P35Z]h30<FUgP80_JGN0`2mXMh30;BMgP<0]9WN1P2TSNH40:bAiPD0Y8gV
1P2/SNH30:bAiP0309`000000680001c0080001k200008<0100000P0000@0000403oj/D40?oR_@80
oljd0P080:`0100a0:@0@@2T0440Y0110:@407<0W0@0U0BL102T29`I0:`8U080a@1B102m058g0?oo
o`00@@3oool00`2d04X0odBD0?m4U0030?m4U0d0od2D1@3o?9@40?lhR`D0gQ2;00@0000H0?l8JP3o
?9`0ocbL103oNJ`20?nQ_@D0o`0Y0P3oWI@20?nQU080ojFD0`3oZY`20?nbW0<0okJL0P3o^Y`20?nf
W0@0ojFL103oNI`01@3oHI`0odbL08/0L`2;07<0[02300H0R`1c0P3E00000`3o3440_JGN0;fUgP03
0<FZgP@0_JGN0P35YMh20;fUgP<0_J7N0P2dWMh50;BIgP@0[9WN102/TNH30:bIiPD0]9WV1P2dXNH2
0<F^gP040000HP0007<0001k0000N`P0002300@00008000040000100on[5103oh[d40?o>]00400P0
[0110:@0@@2T0440Y0@0L`2L102D19`40:@8W1T0[0RD0P3505840;d0DSL0oooo00100?ooo`80]01:
1@3oA9@=0?m0U0D0ocbD103o>8/50=h@R`040000603o26X0ocbL0?llW0@0ogV/0`3oXKd40?l0<@80
oifD0P3oXI@20?nUU0040?nZW03f0200ok:L0?nbW0<0okJL0P3o^Y`30?nfW0<0ojFL103oNI`00`3o
HI`0R`1108/0@@0908/0L`80e@0000<0o`a10?l0>@2mYMh02P2mYMh60;fQgP80]9gN0P2dVMh40:bI
gP<0]9WN0P2/VNH50;BQiPD0_JGV1@35/]h20=k:gP040000HP0007<0001k0000N`P0002300<0000@
0?oZa@3oj/D0103oh[d30?o>]0030?n9[03oOJ`0@@2T0080@@2T101c09`409@4W0@0Y0RL6@2/29@2
0<D0DP@0_@1B=`3oool00400oooo0P2T04X50?m4U0d0od2D103o?9@50?lhR`D0gQ2;00@0000H0?l8
JP3o?9`0ocbL103oNJ`30?nQ_@040?nZ_@3o0340o`0a0?l0<@80oifD00<0oj6D0?nUU03oYI@00`3o
ZY`20?nbW0<0okJL0P3o^Y`20?nfW0@0ojFL0P3oNI`50;@0@@<0R`1c00<0[02308/0L`2;07<00`2;
07<30=D000030?l<@@2mYMh0_JGN00T0_JGN1@2mXMh70;BMgP80]9WN0`2dWMh30;fQgPD0_J[N1@35
/]h50=G6gP030=k:gP2L0000001c0080001k200008<00`000100on[50?oZa@040?oR_@80oljd0P3o
RJ`00`3oOJ`0@@2T0440Y0020440Y0<0L`2L1@2D19`30:@8W1T0[0RD0P3505840;d0DSL0oooo0010
0?ooo`80Y01:1@3oA9@=0?m0U0@0ocbD1@3o>8/50=h@R`040100JP3o26X0ocbL0?llW0<0ogV/103o
XKd00`3oZ[d0o`0a0?l0<@020?nMU080oj6D0P3oYI@0103oZY`0o`0a0?nbW03o/Y`30?nfW080okZL
0`3o]Y`00`3f03T0gP0i0=h0>@020=h0>@H0]01100<0o`1B08/0L`2;07<01P2;07<30=D000030?l<
@@2mYMh0_JGN00T0_JGN1P2mXMh70;BMgPD0_J7N0`2mZ]h50<F^gPD0cKkN103Ea]h20?KJgP@00000
00D000230000000000000000000020020000P`0308<0P`3oj/D0on[500@0on:m103oRJ`20?mm[0<0
@@2T0`1c09`509@4W0@0Y0RL602/29@20<D0DP@0_@1B=`3oool00400oooo0P2T04X50?m4U0d0od2D
103o?9@50?lhR`@0gQ2;0P0@06X00`3o26X0401Z0?llW0030?mi[0<0oj6m00@0ojZm0?nfc@3o]/d0
o`0a0P3oWI@00`3oXI@0ojFD0?nUU00;0?l0<@@0mP0i103N03T50;@0@@80o`1B1`2;07<30=D00003
0?l<@@2mYMh0_JGN00T0_JGN302mXMh40;fUgP030;fZgP35[]h0aJkN00<0aJkN103=]]h50<fngP@0
i/kN00<0m][N0000000000000P000000100007/0000000000000000200002080000@00<0002304X0
U03oj/D0103oUK@40?n9[080ogf/00<040230440Y0110:@0101c09`409@4W0@0Y0RL602/29@20<D0
DP@0_@1B=`3oool00400oooo0P2T04X50?m4U0d0od2D103o?9@50?lhR`@0gQ2;00@0000H0100JP3o
26X0401Z103oNJ`30?nQ_@030?nZ_@3o]/d0Y5GN0080oifD403o03440?H0>@@0gP0i0`2d04430?l0
DP030:`0P`2;07<0R`1c00@0R`1c0`3E0000103o3440_J7N0;fQgP2mXMh>0;fUgP80_J7N1@2mYMh5
0;fZgP@0aJkN103=]]h50=FngP@0i/kN00<0omKE0000000000001P0000000`0000P0000@00004002
0000P`030680P`3oYKd0oiFd00<0oiFd103oRJ`20?mm[080402300<0@@2T07<0W01c09`00P1c09`4
09@4W0@0Y0RL6@2/29@00`350580_@1B0;d0DP020;d0DSL0oooo00100?ooo`030:@0BP3oA9@0odBD
00@0odBD303o@9@50?llU0@0ocR;1@3N48/0100001P0401Z0?l8JP0@06X30?mi[0<0oj6m00<0ojZm
0:`/e@2/;=D00P3oWI@B0?l0<@@0mP0i103N03T20;@0@@@0o`1B1P2;07<30=D000030?l<@@2mXMh0
_JGN01L0_JGN1035Z]h40<F^gPD0cKKN103E_]h40>K:e@@0000000@0gP0000000000000000000P00
00P2000040<0002300<0ojFm0?nE]03oUK@00P3oUK@30?n9[080ogf/00@0ogFT0100P`0@08<04023
101c09`409@4W0@0Y0RL6@2/29@00`350580_@1B0;d0DP020;d0DSL0oooo00100?ooo`030:@0BP3o
A9@0odBD00<0odBD3@3o@9@50?llU0@0ocR;1@3N48/0100001P0401Z0?l8JP0@06X30?mi[080oj6m
00@0Y02/0:`<a@2/;=D0Y5GN0P3oWI@B0?l0<@@0mP0i1@3N03T60?l0DP0308/0L`2/08<0R`1c0080
R`1c0`3E00000`3o3440_J7N0;fUgP0C0;fUgP@0_J[N1035Z]h40<F^gPD0cKKN103E_]h30>K:e@P0
00000P0000P2000040@0002300<0ojFm0?nE]03oUK@00P3oUK@30?n9[080ogf/00<0ogFT0?l4>@0@
08<00P0@08<00`2D09@0L`2L07<0W00509@4W0<0Y0RL6@2/29@00`3=0580_@1B0;d0DP020;d0DSL0
oooo00100?ooo`030:@0BP3oA9@0odBD00<0odBD3@3o@9@50?llU0@0ocR;1@3N48/0100001P0oaQZ
0?l8JP2T05830?mi[0040?nQ_@2T0:`0[0c50:`/e@80mQR;0P3oWI@00`3oXI@0o`0a0?l0<@0@0?l0
<@@0mP0i103N03T00`3o0440o`1B0?l0DP030?l0DP030:`0P`2;07<0R`1c0080R`1c0`3E00020?l<
@@<0_J7N4@2mYMh40;fZgP@0aJ[N1035[]h40<ffgP@0eKkN103Vb]D60000008000080P0801020100
60D000230`3oUK@40?n9[080ogf/00<0ogFT0100P`0@08<00P0@08<209@0U00307<0W02D19`0U0BL
00<0U0BL102T29`H0:`8U0D0c@1B=`3oool003l0oooo0P2T04X50?m4U0@0od2D0P3o?9@70?m0U0@0
ocbD1@3o>8/40=h@R`80000H00<0oaQZ0?l8JP2T05800P3oNJ`20:@0[0040:`<a@3V58/0iQB;0?HH
R`<0oifD00<0oj6D0?l0<@3o03404@3o03440?H0>@80gP0i0P3o04460?l0DP040:`0P`2;07<0R`1c
08/0L`<0e@000P3o34430;fQgQ00_JGN102mZ]h50<FZgP@0aJkN103=/]h40=FfgP<0i[[E1@000003
00002080200@0P0@01P60000P`<0oiFd103oRJ`20?mm[080ogFT0`0@08<309@0U0D0U0BL102T29`H
0:`8U0D0c@1B=`3oool003l0oooo0P2T04X50?m4U0@0od2D103o?9@50?m0U0@0ocbD1@3o>8/40=h@
R`050000600@06X0oaQZ0?l8JP0@06X00P3oNJ`00`3E59@0iQB;0>HDR`020>HDR`030?HHR`3oWI@0
oifD0080ohfD00<0oiFL0?l0<@3o03404@3o03440?H0>@040=h0>@3o0440o`110?l0@@D0o`1B00@0
mP1R08/0L`2;07<0R`1c0`3E00020?l<@@<0_J7N502mYMh40<FZgP@0aJkN103=/]h50=FfgP80i[[E
00<0a@1k0000000000000P00000400002080200@0P0@01P60000P`<0oiFd103oRJ`20?mm[0030?me
Y00@08<0402300804023102D09@20:@4U080U0BL102T29`H0:`8U0D0c@1B=`3oool003l0oooo0P2T
04X50?m4U0@0od2D103o?9@20?lhU0<0od2D103o?9@50?lhR`@0gQ2;00H0000H0100JP3o66X0o`QZ
0100JP3oNJ`20=DDU0@0iQB;00<0mQR;0?nMU03oRI@00P3oSI@00`3oUI`0o`0a0?l0<@0A0?l0<@@0
mP0i103o04460?l0DP030<d4N`2;07<0R`1c00<0e@000P3o344F0;fUgPP0aJ[N1@3=[]h40=F^e@80
i[[E00<0mS2L0000000000000`00000300002080200@0P0@01P00`0007/000230000P`050000P`80
oiFd103oRJ`20?mm[080ogFT00<0kP1R0100P`0@08<0102D09@40:@4U0@0Y0RL6@2/29@40<d0DSL0
oooo000o0?ooo`80Y01:1@3oA9@40?m0U0@0ocbD103o>9@50?llU0D0ocR;103N48/01@0001P0401Z
0?lHJP3o26X0401Z00<0eABD103V58/30?n9U0040?n=U03oUI`0oiFL0?nEW1<0o`0a0`3f03T00`3o
03T0o`110?l0@@020?l0@@H0o`1B0P2;07<40=D000030?l<@@2mYMh0aJGN00@0aJGN3`2mYMh=0<FZ
gPD0eJkE0P3NZ]D5000000@000080P080102010060030000N`0008<0002300D0002300<0oiFd0?n9
[03oRJ`00P3oRJ`20?mm[080ogFT00@0oaQR0100P`0@08<04023102D09@50:@4U0030:@8U02T29`0
Y0RL01T0[0RD103=058g0?ooo`00?`3oool20:@0BPD0odBD103o@9@40?llU0@0ocRD0P3o<9@30?ll
U0@0ocR;1@3N48/01@0001P0401Z0?lHJP3o26X0401Z00<0eABD103V58/20?n9U080ohfD0P3oUI`0
0`3oXI`0o`0a0?l0<@0B0?l0<@040?H0>@3o03T0o`0i0?l0>@<0o`110P3o05801P3^<:@0o`1B0?l0
DP3o0580mP1R08/0L`@0e@0000<0o`a10<FZgP35Z]h00`35YMh70<FZgPT0_JGN2035YMh40<FZgPD0
cJGE0P3NZ]D00`3oC:@0000000000003000000<000080P080102010060030?m]W00005X0001k00L0
0023103oEJ`20?m@Y0030?m<Y03oD:@0oaQR00@040230`2D09@50:@4U0<0Y0RD6@2/29@40<d0DSL0
oooo000o0?ooo`80Y01:1@3oA9@40?m0U0@0ocbD103o>9@30?l`U080ocbD103o>8/50=h@R`050000
600@06X0oaQZ0?l8JP0@06X0103E59@30>HDR`80ohVD00@0ohfD0?nEW03oUI`0oiFL0P3oXI`C0?l0
<@@0o`0i103o04460?l0DPD0e@000P3o344;0<FZgPl0_JGN1@35YMh50<fUe@80cIgE00<0odbT0000
000000000`00000400002080200@0P0@01P00`3oKI`0001J0000FP070000P`@0oeF/0P3oD:@0103o
C:@0oe2T0?lHHP3^06830100P`<0U02D1@2T19@40:@8U1P0[0RD103=058g0?ooo`00?`3oool20:@0
BP@0odBD1@3o@9@40?llU0@0ocRD103o<9@50?lhR`D0gQ2;00@0000H0?lHJP3o66X0o`QZ0P0@06X3
0=DDU080iQB;0P3oRI@20?n=U080oiFL0P3oXI`00`3o[Y`0o`0a0?l0<@0A0?l0<@D0o`0i0`3o0446
0?l0DP030<d0003E0000e@000080e@000P3o344;0<FZgP80_J[N2`2mYMh50;fQgPH0aJ7N0P3=WMD0
0`2L08<0000000000004000000<000080P080102010060<0offL00<0001J0000JP0008<01@0008<4
0?mE[080oe2T00<0odbT0?m@Y03o66800P3^06820100P`@0U02D102T19@40:@8U1P0[0RD103=058g
0?ooo`00?P3oool20:@0BPD0odBD1@3o@9@40?llU0@0ocRD103o<9@00`3f99@0ocR;0?lhR`020?lh
R`@0gQ2;0P0001P20?lHJP80o`QZ00@0401Z0=DDU03E59@0eABD0P3V58/20?n9U080ohfD0P3oUI`2
0?nQW0030?n^W03o0340o`0a0100o`0a1P3o03T40?l0@@D0o`1B00<0iP080=D0003E00000P3E0002
0?l<@@80cJkN2@35Z]h20;fZgPT0_JGN1@2mXMh50;fMgP@0_IGE00<0W02300000000000010000004
00002080200@0P0@01P30?m]W080001J1`0008<20?mE[0<0oe2T00<0odbT0?m@Y03o66800P3^0682
0100P`@0U02D00@0e@1J0:@4U02T19@0Y0BD102T29@H0:`8U0@0c@1B=`3oool003h0oooo0P2T04X5
0?m4U0@0od2D1@3o?9@40?lhU0@0oc2D0P3f99@30?lhR`@0gQ2;0P0001P20?lHJP80o`QZ00@0401Z
0=DDU03E59@0eABD0P3V58/20?n9U0030?n=U03oUI`0oiFL0080oj6L0`3o[Y`@0?l0<@P0o`0i0`3o
04450?l0DP030>H0203o3440e@000080e@000P3o34440<f^gPD0aJkN0P35Z]h80;fUgPD0_J7N1@2d
VMh20;fMgP<0]97N00<0_IGE0:`0U00000001P00000300002080200@0P0@01P40?m]W00306X4[000
05X0001Z00H000230P3oEJ`20?m@Y0050?m<Y03oD:@0oe2T0?lHHP3^06800`0@08<409@0U0@0Y0BD
102T29@00`3E0580[0RD0:`8U00E0:`8U0@0c@1B=`3oool003h0oooo0P2T04X50?m4U0@0od2D1@3o
?9@40?lhU0@0oc2D0`3f99@20?lhR`@0gQ2;00@0000H0100JP3o66X0oaQZ0P3o26X01@2T0580eABD
0=DDU03E59@0iQB;0080ohVD0P3oSI@20?nEW080oj6L0P3o[Y`00`3o_Z@0o`0a0?l0<@0?0?l0<@L0
o`0i103o04440?l0DP030>H0203o3440e@000080e@000P3o34430<f^gPD0aJkN0`35Z]h30;fUgP@0
_J7N0`2dXMh40:bIiPD0]9WN1@2dTMh7000000@000080P080102010060<0offL0P1Z1:`20000FP03
0000L`0008<0002300@0002300@0oeF/0?m@Y03oD:@0odbT0P3oD:@00`3o6680kP1R0>h0HP020100
P`@0U02D102T19@40:@8U1T0[0RD0`3=058g0?ooo`00?P3oool20:@0BPD0odBD103o@9@50?llU0@0
ocRD103o<9@40?HTU0D0gQ2;00@0000H0100JP3o66X0oaQZ0P3o26X01@2T0580eABD0=DDU03E59@0
iQB;0080ohVD00@0ohfD0?nEW03oUI`0oiFL0P3oXI`20?n^W080okjT4@3o03420?l0>@030?ma]03o
03T0o`0i0080o`0i0`3o04430?l0DP80iP0800@0c@000=D0003E0000e@000P3o34460<fbgP80aJkN
0`35Z]h40;fUgP<0_J7N102dVNH40:bIiPH0Y8WV00<0Y87N0;d0Y00000001P00000400002080200@
0P0@01P20?n5[080offL0P1Z1:`0103o;7<0001J0000JP0007<50000P`070?mE[03oD:@0oe2T0?m<
Y03oD:@0oaaJ0?lHHP020>h0HP804023102D09@0102T19@0e@1J0:@4U02T19@40:@8U1T0[0RD0`3=
058g0?ooo`00?P3oool20:@0BPD0odBD103o@9@40?llU0@0ocRD1@3o<9@40?HTU0030<dHU03N48/0
gQ2;0080gQ2;00@0000H0100JP3o66X0oaQZ0P3o26X0102T0580eABD0=DDU03E59@20?n9U080ohfD
0P3oUI`20?nQW080ojjL0P3o_Z@00`3obZ@0o`0a0?l0<@0?0?l0<@P0o`0i0`3o04420?l0DP<0iP08
00<0o`a10=D0003E00000`3o34440<fbgP<0aJkN0`35Z]h40;fUgP@0]:7N102dVNH60:B9iP<0U6gV
00<0_@2T0000000000001P000003000020<0200@0P0@01P30?n5[0<0JPB/00@0obac0000FP0005X0
001c1P0008<20?m@Y0040?m<Y03oD:@0oaaJ0?lHHP@0kP1R00@0e@1J09@0U02D09@0U02D102T19@4
0:@8U1T0[0RD0`3=058g0?ooo`00?P3oool20:@0BPD0odBD103o@9@40?llU0@0ocRD1@3o<9@40?HT
U080cARD0`3N48/00`0001P0401Z0?lHJP030?l8JP040:@0DP3E59@0eABD0=DDU080ohVD0P3oSI@2
0?nEW080oj6L0P3o[Y`20?nnY080olZT4@3o03470?l0>@<0o`110P3o05830>H020<0e@000`3o3444
0<ffgP<0aK;N1035[]h30;fUgP@0]:7N1P2/SNH509AUiP0309A]iP2m0:@0000000L00000100000P2
00P04080400H103oQJ`00`2m?;d0JPB/0?m4L`020?l/L`030000FP0006X0001c00D000230P3oD:@0
103oC:@0oe2T0?lLFP3o66840>h0HP80e@1J0P2D09@40:@4U0@0Y0RD00<0[0RD0=D0DP2/29@05P2/
29@30<d0DSL0oooo000n0?ooo`030:@0BP2D04X0odBD00<0odBD1@3o@9@40?llU0@0ocRD1@3o<9@4
0?HTU0<0cARD0P3N48/00`0001P0oaQZ0?lHJP030?l8JP040:@0DP3E59@0eABD0=DDU080ohVD00<0
ohfD0?nEW03oUI`00P3oXI`30?n^W080okjT0P3obZ@A0?l0<@P0o`0i0`3o04400`3o0580iP080>H0
20020>H020<0e@000P3o34430<ffgP@0aK;N1035[]h40;fUgPD0]9gV1@2LONH409AUiP030;d0Y000
0000000000L000000`0000P300P04080400H0`3oQJ`20;dl_@0406X4[03oA7<0obac0?l/L`80001J
0P0007<40000P`060?m@Y03oC:@0oe2T0?m@Y03o75X0mP0i103^06850=D0FP<0Y0BD102T29@00`2/
29@0e@1B0:`8U00F0:`8U0<0c@1B=`3oool003d0oooo0`2D04X40?m4U0D0od2D103o?9@40?lhU0@0
oc2D1@3f99@30<dHU0030000603N48/0000H0080oaQZ0`3o26X00`0@06X0eABD0=DDU0020?n9U080
ohfD0P3oUI`20?nQW080ojjL0P3o_Z@20?o:Y080omJT4@3o03470?l0>@<0o`111@3V00P00`3o3440
e@000=D000020?l<@@<0eK[N1035/]h40<F^gP@0_JGN1P2dVNH609A]iP80NbcV2@00000400002080
200@0P0@01P30?n5[0@0_Cbm00L0odAc0?l/L`3o;7<0]0000000FP0006X0001c00D0002300D0odbT
0?m@Y03oD:@0oaaJ0?H0>@040>h0HPH0e@1J0P2T19@40:@8U1T0[0RD0`3=058g0?ooo`00?@3oool3
09@0BP@0odBD1@3o@9@40?llU0@0ocRD103o<9@50?HTU080cARD00@0000@0000603N48/0000H0P3o
66X30?l8JP030100JP3E59@0eABD0080ohVD00<0ohfD0?nEW03oUI`00`3oXI`20?n^W080okjT0P3o
bZ@20?oFY140o`0a0P3o03T00`3oKK@0o`0i0?l0>@030?l0>@80o`1100<0o`0P0>H0203V00P00P3V
00P30=D00080o`a100<0]0000=FjgP35/]h00`35/]h50<F^gPD0_J[N1P2dWNH309A]iP80U5WV00<0
W02300000000000020000003000020<0200@0P0@01P20?n5[0D0_Cbm00H0odAc0?l/L`3o;7<0o`Qc
0000FP0006X20000L`@0002300D0odbT0?m@Y03oD:@0oaaJ0?H0>@040>h0HPP0e@1J102T29@20:`8
U0030=D0DP2/29@0[0RD01@0[0RD0`3=058g0?ooo`00?@3oool309@0BP@0odBD103o@9@50?llU0@0
ocRD103o<9@50?HTU080000@0`0001P00`0@06X0oaQZ0?lHJP030?l8JP040100JP3E59@0eABD0?n9
U080ohfD0P3oUI`20?nQW080ojjL0P3o_Z@20?o:Y0<0okZd00<0onZm0?l0<@3o03403`3o03470?l0
>@80o`1100<0o`0P0>H0203V00P00P3V00P00`3=0000e@000=D000020?l<@@030?l0>@3E_]h0aK;N
00<0aK;N2`35[]h50;BMiP0509AIiP2LGNH0W5gV09aMiP2m0:@02P00000400002080200@0P0@01P2
0?nI]00309@T_@2m?;d0_Cbm00<0_Cbm00H0odAc0?l/L`3o;7<0o`Qc0;@0000005X20000L`030000
N`0008<000230080002300@0oe2T0?lLFP3o75X0mP0i103^06880=D0FP80e@1B0P2T29@20:`8U003
0=D0DP2/29@0[0RD01@0[0RD0`3=058g0?ooo`00?@3oool209@0BPD0odBD103o@9@50?llU0@0ocRD
103o<9@50?HTU080000@0`0001P00`0@06X0oaQZ0?lHJP030?l8JP040100JP3E59@0ohVD0?n9U080
ohfD00@0oiFL0?nQW03oXI`0oj6L0P3o[Y`20?nnY0040?o:Y03oSJ`0okZd0?nj]080onZm4@3o0348
0?l0>@030?l0@@3o0200o`0P00@0iP0800<0o`a10=D0003o34400P3o34400`3o03T0aK;N0<FbgP02
0<FbgP/0aJkN1035/]h30>K>gP030680W0000000000000@0000000<020000000000000000`000003
000020<0200@0P0@01P20?nI]0030?Ia_@2m?;d0_Cbm00<0_Cbm0`3o;7<0103o27<0]22T0000FP00
06X20000L`050000N`0008<0odbT0000P`3oD:@00P3o75X00`3f03T0kP1R0>h0HP020>h0HPP0e@1J
103E05800`2T29@0[0RD0=D0DP0G0:`8U080c@1B=`3oool003d0oooo0P2D04X50?m4U0@0od2D1@3o
?9@30?lhU0D0oc2D103f99@00`0i02T0000@00006003000060030:`<W03o66X0oaQZ00<0o`QZ00D0
401Z0=DDU03oRI@0ohVD0?n=U0020?nEW080oj6L0P3o[Y`20?nnY080ohf/0P3o^[@30?oZ_@<0o`0i
3`3o03400`3o03T0offd0?l0>@040?l0>@<0o`0P103V00P20=D000<0o`a100<0o`0i0<F^gP35[]h0
1`35[]h60<fngP80aK;N0`3Vc]h00`1R09`000000000000500000080200000@04008000000000000
0000100000P200P04080400H0P3oVK@30?Ia_@<0_Cbm00@0odAc0?l/L`3o;7<0obac0P3o27<0102d
0000001J0000L`0007<20000N`80002300@0mS2L0?lLFP3o75X0mP0i103^06830=D0FP0309@0U03E
05X0e@1J0080e@1J1`3E058G0:`8U080c@1B=`3oool003d0oooo0P2D04X50?m4U0@0od2D1@3o?9@3
0?lhU0D0oc2D0`3f99@203T0:@030000400001P0000H0080000H00<0[0bL0?lHJP3o66X00`3o26X0
0`0@06X0ohVD0?n9U0020?n=U080oiFL0P3oXI`20?n^W0040?nnY03oMJ@0ohf/0?n=[080okZd0P3o
j[d20?ooa@<0o`0i3`3o03460?l0>@040?l0:@3o0200o`0P0?l080<0iP080P3E00030?l<@@040?l0
>@2/00P0[00808/000H0aJkN1P3=_]h30>K>gP80HP2L1`00000200P0008040080P0H0104000020<0
200@0P0@01P00`3oVK@0mW6m0?Ia_@030?Ia_@80_Cbm00<0odAc0?l/L`3o;7<00`3o27<00`0008/0
001J0000JP020000L`80001k0P0008<20?lLFP030?H0>@3^0680kP1R0080kP1R0`3E05X00`2D09@0
e@1J0=D0FP020=D0FPT0e@1B5@2/29@20<d0DSL0oooo000m0?ooo`80U01:1@3oA9@40?m0U0@0ocbD
103o>9@50?l`U080mRBD0`0i02T5000060<0oaQZ0`3o26X0101B0;@0ohVD0?n9U03oSI@20?nEW0<0
oj6L00<0ojjL0?meY03oMJ@00P3oSJ`20?nj]080onZm0`3oolD00`3ok/D0o`0i0?l0>@0?0?l0<@H0
o`0i0P3o02T20?l080<0iP0800<0c@000?l<@@3o34400P3o34400`3o03T0[0080:`020020:`02003
08/00035[]h0aJkN0080aJkN1P3Vb]h30680W0P000000P080002010020<0600@00@0800H00002000
00P000080P080102010060030?nU_@3fLKd0mW6m00@0mW6m0P2m?;d00`3oA7<0obac0?l/L`030?l8
L`030000R`0005X0001J0080001c0`0007/0100008<0oaaJ0?lLFP3f03T30>h0HPT0e@1J2`3E058C
0:`8U080c@1B=`3oool003d0oooo0P2D04X40?m4U0D0od2D103o?9@40?lhU0D0oc2D0P3f99@303T0
:@0306X0DP0001P0000H0080000H0`3o66X30?l8JP040580]03oRI@0ohfD0?n=U080oiFL0P3oXI`0
103o[Y`0ofFL0?meY03oMJ@20?n=[0040?nj]03oj[d0onZm0?oZ_@80ooo50P3ok/D30?l0>@l0o`0a
1@3o03T20?l0:@<0o`0P0`3V00P01@3E0000o`a10?l<@@3o3440o`0i00H0[00800<0R`0000P00008
00000P08000503T000T000000`080000100@00P0600@01P0400H010302006004000020080100200@
00P04080400H00<0ojFm0?n9_@3fLKd01@3fLKd0102m?;d0odAc0?l/L`3o;7<30?l8L`040;@PY000
08/0001Z0000JP80001c0`0007/00`0008<0oaaJ0>h0HP020>h0HP0300P0002;0340R`0a0080R`0a
0P2d04430=D0FP`0e@1B4P2/29@20<d0DSL0oooo000m0?ooo`80U01:103oA9@50?m0U0@0ocbD103o
>9@40?l`U080>@0Y00<0mRBD03T0:@0i02T00P1Z0584000060<0oaQZ0`3o26X20?n9U080ohfD00@0
oiFL0?nQW03oXI`0oj6L0P3oII`00`3oMJ@0ohf/0?n=[0020?nj]080onZm0P3oolD30?o^a@030?oF
a@3o03T0o`0i00l0o`0a103o03T40?l0:@80o`0P0`3V00P01@3E0000o`a10?l<@@3o3440o`0i00L0
[0081P0i0003044000P000000`08000201002080600@100P01P300P04080400H00@0ojFm0?n9_@3o
RKd0ohVm1P3fLKd00`3oA7<0obac0?l/L`030?l8L`040;@PY00008/0001J0000FP80001c100007/0
0`3o75X0kP1R00P0000200P000@0R`0a102d044>0=D0DQ40[0RD00<0e@1B0<d0DP3oool0=P3oool0
03d0oooo0P2D04X40?m4U0D0od2D103o?9@40?lhU0<0oc2D0P1J03T403T0:@80JP1B100001P30?lH
JP<0o`QZ0P3oRI@00`3oSI@0oiFL0?nEW0020?nQW080ofFL0P3oMJ@00`3oSJ`0okZd0?nj]0020?oZ
_@80ooo50`3ok/D20?oFa@<0o`0i3`3o03430?l0>@@0o`0Y0`3o02020>H020040=D0003o3440o`a1
0?l<@@P0[0080`0i000504400080BP001`00000200P0008040080`0H010402006003020080080100
200@0080400H1@3oRKd50?Ia_@030?m4L`3o;7<0obac00<0o`Qc00@0]22T0000R`2d0000001Z0`00
07<30000N`040?lLFP080000200000P000D0R`0a102d04420<D0BPl0e@1B3P2/29@20=D0DSL0oooo
000m0?ooo`80U01:103oA9@40?m0U0D0ocbD103o>9@20?l`U0<0FP0i0`0i02T306X0DP@0000H0`3o
66X20?l8JP80ohVD0P3oSI@0103oUI`0oj6L0?nQW03oHI@20?mUW0040?meY03oSJ`0ohf/0?nj]080
onZm0P2/5<D30=j^gP@0onKE0P3o03T?0?l0<@80o`0i1P3o02T20?l080<0iP080`3o34480:@080H0
@@00101:00060000008020000P0@00P301P040@0800H0`0P0202010060L0ohVm0P3fLKd20?Im_@03
0?m4L`3o;7<0obac00@0o`Qc0`0008/00`0006X0001c0000L`040000N`<02000102;03450;@0@@@0
a@1:3`3E058<0:`8U080e@1B=`3oool003d0oooo0P2D04X40?m4U0@0od2D1@3o?9@30?lhU0H0FP0i
0P0i02T506X0DP80000H00@0[0bL0?lHJP3o66X0oaQZ0P3o26X20?n9U0040?n=U03oUI`0oiFL0?nQ
W080of6D00@0ofFL0?meY03oMJ@0ohf/0P3o^[@00`3oj[d0[1C50:`Da@030=j^gP@0onKE00@0om;=
0?l0>@3o03T0o`0i3`3o03400`3o03T0o`0Y0?l0:@040?l0:@<0o`0P0P3V00P30?l<@@P0Y00P1011
000504X00080BP081000000300P0008040080P0H0105020060<0800P00<0:@0P0100603oUKd01P3o
RKd40?Im_@030?m4L`3o;7<0obac00@0o`Qc0P0008/00`0005X0001Z0000L`020000L`<0001k0`08
000408/0<@D0]0111@3504X@0=D0DP/0[0RD00<0e@1B0?ooo`3oool0=@3oool003d0oooo0P2D04X4
0?m4U0@0od2D1@3o?9@30?lhU00307<0@@1J03T0FP0i00<0FP0i0P0i02T506X0DP80000H00@0[0bL
0?lHJP3o66X0oaQZ0P3o26X0103oRI@0ohfD0?n=U03oUI`30?mQU080ofFL00D0ogFT0?n=[03oSJ`0
okZd0?oZ_@020:`Da@<0gZkN103oi]D30?oBc@<0o`0i3P3o03480?l0:@80o`0P0P3V00P30?l<@@P0
Y00P0P11000604X000<0BP080`00000300P0008040080`0H0104020060<0800P0P0Y02030?nE_@@0
ohVm0P3oQKd30?Im_@030?m4L`3o;7<0obac00@0o`Qc0P0008/00`1109@0001Z0000JP020000L`@0
001k00<0200008/0<@2;03400`2;03440;@0@@H0a@1:0P3=04X?0=D0DPX0[0RD00<0e@1B0?ooo`3o
ool0=@3oool003d0oooo00<0U01:0?m4U03oA9@00`3oA9@40?m0U0D0ocbD0P3o>9@207<0@@D0FP0i
00<0>@0Y06X0DP1Z0580101Z0582000060@0oaQZ00<0o`QZ0?n9U03oRI@00P3oSI@01@3oUI`0of6D
0?mQU03oHI@0ofFL0080ogFT00<0ohf/0?nj]01c08/00P2/5<D30=j^gP@0onKE103od/d30?l0>@l0
o`0a1`3o02T30?l080030>H0203o3440o`a100T0Y00P1P1:000404X02003044040000000000000<0
20000P0@00P301P040D0800H0`0P020202T080@0oiFm0P3oRKd40?n5_@80mWfm00<0odAc0?l/L`3o
27<0103o27<30000R`040000FP0006X0001c0000L`@0001k00<0200008/0<@2;03400`2;03440;@0
@@H0a@1:0`3=04X?0=D0DPT0[0RD00<0e@1B0?ooo`3oool0=@3oool003d0oooo00<0U01:0?m4U03o
A9@00P3oA9@50?m0U0D0ocbD00@0ocRD07<0@@1c0440L`111@1J03T706X0DP80000H103o66X01P3o
26X0ohVD0?n9U03oSI@0oiFL0?mMU080of6D0P3oII`0103oMJ@0ohf/0?n=[01c08/20:`Da@80gZkN
103oi]D50?oBc@80ok[=0`3o03T?0?l0<@L0o`0Y0P3o02020>H020030:`0BP2D02T0U00Y00L0U00Y
1@1:000404X02080@@0@00@0000000P00008000020000`0@00P201P040D0800H0`0P020202T080H0
oiFm1@3oQKd0103fOKd0odAc0?m4L`3o;7<50?l8L`040;@PY00008/0002;0000FP80001Z0P0007<4
0000N`@0R`0a1@2d04460<D0BP@0c@1:4@3E05860:`8U0030=D0DP3oool0oooo03D0oooo000m0?oo
o`0309@0BP3oA9@0odBD0080odBD1@3o@9@40?llU0D0L`111@1J03T00`230580JP1B06X0DP0406X0
DP80000H103o66X01@3o26X0ohVD0?n=U03oSI@0oefD00<0of6D00D0ofFL0?meY03oMJ@0ohf/0:aI
c@0308/`iPD0cK[N1@3^_]D30?njc@<0o`0i3`3o03470?l0:@<0o`0P00<0iP080:@0BP2D02T0202D
02T304X000D0BP080`11010400P0008040080`0H0104020060<0800P0`0Y0200103oWLD0oiFm0?nE
_@3oUKd30?n9_@D0ohFm0P3oA7<00`3o;7<0o`Qc0?l8L`030?l8L`060;@PY00008/0002;07/0P`00
08/0001Z0P0007<40000N`040:`0402;0340R`0a08/0<@D0]0111@3504X50<d0BP80e@1:4@3E0584
0:`8U0030=D0DP3oool0oooo03D0oooo000m0?ooo`0309@0BP3oA9@0odBD0080odBD1@3o@9@20?ll
U0<0N`1:101c044405X0>@80P`1B1`1Z05800`0001P0oaQZ0?lHJP020?lHJP80ohVD00<0ohfD0?mM
U03oGI@00P3oHI@20?mUW0030?meY03oSJ`0[5W=0080[5W=1P3=^]h60>jne@80ok;=0P3o^/d30?l0
>@l0o`0a1`3o02T20?l080030>H0202T04X0U00Y00P0U00Y0P1:000504X020<0@@0@0P1101P200P0
008040080`0H0105020060<0800P0P0Y02030?nMa@H0ohVm103oQKd20?m4L`030?l/L`3o27<0o`Qc
00@0o`Qc0P0008/00`1k08<0001J0000JP030000L`<0001k0P2/010208/0<@@0]0111P3504X50<d0
BP<0e@1:4P3E05820:`8U0030=D0DP3oool0oooo03D0oooo000m0?ooo`0309@0BP3oA9@0odBD0080
odBD1@3o@9@00`3o?9@0N`1:07/0BP0207/0BPD0L`110`1J03T208<0DPL0JP1B00L0000H0?lHJP3o
66X0oaQZ0?l8JP3oRI@0ohfD0080oefD0`3oHI@20?mUW0030?meY03oSJ`0[5W=0080[5W=0P3=NLd3
0<fjgPH0k[kE103o//d0103oYLD0o`0i0?l0>@3o03T@0?l0<@H0o`0Y0`3o02000`2T04X0U00Y09@0
:@0709@0:@D0BP08101101030440600400P0000@00P0400801002080600@1@0P01P3020080<0:@0P
0P3oWLD20?nAa@H0ohVm0`3oQKd20?m4L`030?l/L`3o27<0o`Qc00@0o`Qc0P0008/0101k08<0001J
0000R`0006X20000L`@0001k0P2/01050;@0@@H0a@1:1@3=04X40=D0BQ40e@1B0P2/29@00`3E0580
oooo0?ooo`0e0?ooo`00?@3oool00`2D04X0odBD0?m4U0020?m4U0@0od2D1P1k04X507<0@@80FP0i
0`23058706X0DP040000603o66X0oaQZ0?lHJP80ohVD0`3oGI@20?mQU080ofFL00<0ogFT0?n=[02/
FLd00P2/FLd50<eic@H0k[kE1@3o//d20?nUc@<0o`0i3`3o03470?l0:@80o`0P00<0iP0809@0:@2D
02T01@2D02T207<0<@@0BP0810110104044060<040080`0H010502006080800P0`0Y02020?nMa@@0
oi751@3oRKd30?n5_@80odAc00<0obac0?l8L`3o27<0103o27<30000R`030440U03oYJ@0001Z00<0
001c0`0007/20:`04080c@0i0`2d04450<D0BPD0c@1:1`3E04XA0=D0DSP0oooo000m0?ooo`0309@0
BP3oA9@0odBD0080odBD0P3o@9@308<0BPD0N`1:1@1c044205X0>@@0P`1B1P1Z05801@0001P0oaQZ
0?lHJP3o66X0ohVD00@0oefD0P3oHI@20?mUW0030?meY02/FLd0[5W=0080[5W=1@3=NLd20>J=a@<0
k[kE1@3o//d30?nUc@<0o`0i403o03460?l0:@<0o`0P1@2D02T407<0<@<0BP081011010404406080
@@0P00@0400801P0400H0100600@1@0P01P302008080:@0P00<0oig50?nAa@3oTLD01@3oTLD20?n9
_@<0oh6m0P3oQKd00`3oA7<0obac0?l/L`060?l8L`<0002;00@0@@2D00P0R`0006X0001Z0P0007<4
0000N`@0c@0i0P2d04450<D0BPD0c@1:2@3E04X?0=D0DP030:`8U03oool0oooo03D0oooo000m0?oo
o`0309@0BP3oA9@0odBD0080odBD00<0od2D08<0BP2304X00P2304X507/0BPD0L`1100<0FP0i08<0
DP2305800`23058606X0DP@0oaQZ00@0ohVD0?mMU03oGI@0oefD0P3oHI@20?mUW0030?meY03=?;@0
cCbd0080[5W=1@3=NLd50>J=a@D0ok;=1@3oYLd30?l0>A00o`0a1P3o02T20?l080<0U00Y1P1c0342
04X020@0@@0@101101P3044080<0600@1@0P01P3020080<0:@0P0P3oULD60?nAa@D0oh6m0P3oQKd0
0`3oA7<0obac0?l8L`060?l8L`80002;0P3o04400`1109@0o`110000JP030000L`<0001k1@3=03T6
0<D0BPD0c@1:2P3E04X>0=D0DP030:`8U03oool0oooo03D0oooo000m0?ooo`0409@0BP3oA9@0odBD
0?m4U0H0P`1:1@1k04X507<0@@H0P`1B1P1Z05801@3o1680oaQZ0?lHJP3oRI@0oeV;00<0oefD0P3o
HI@20?mUW0040;@P[03=?;@0cCbd0<dl]0H0cGW=1@3VSLD40?JEa@D0ojG=00<0oj750?l0>@3o03T0
0P3o03T?0?l0<@H0o`0Y0P3o020907<0<@D0@@0@101101P4044080<0600@1@0P01P302008080:@0P
103oULD30?nAa@<0mXG51@3oPKd00`3oQKd0odAc0?l/L`070?l8L`D0o`1100<0202;0000JP0006X0
0P0007<40000N`@0c@0i00<0e@110<D0BP3504X00P3504X60<d0BPX0e@1:3P3E05800`2/29@0oooo
0?ooo`0e0?ooo`00?@3oool00`2;04X0odBD08/0BP0208/0BPD0P`1:1@1k04X507<0@@0308/0DP23
0580P`1B00<0P`1B1P1Z0580103o1680oaQZ0?lHJP3oFH/30?mMU0<0of6D00<0ofFL0?meY02d8:`0
0`3=?;@20=iE_@<0cGW=1@3VSLD50?JEa@@0mYg50`3oXLD30?l0>@D0o`0a00<0o`0i0?l0<@3o0340
203o03460?l0:@0307<0@@3N0000L`0a00H0L`0a00<0JP0a0440401101000P110104044060@0@@0P
00<0>@0P01P0400H01001@0P01P3020080<0:@0P1@3oULD50?J5a@D0oh6m00<0ohFm0?m4L`3o;7<0
1`3o27<00`3V0680o`110?l0@@020?l0@@0300P0R`3o0440001Z00<0001c0`0007/30<d0>@<0e@11
0`3504X50<d0BP/0e@1:3P3E05800`2/29@0oooo0?ooo`0e0?ooo`00?@3oool508/0BPD0P`1:1@1k
04X407<0@@80R`1B1P23058406X0DP80o`AR00<0oaQZ0?mIR`3oFH/00`3oGI@20?mQU080ofFL0P2d
8:`30<dl]0@0gUFm1P3VSLD40?JEa@L0mYg500<0oj750?l0>@3o03T00P3o03T40?l0<@80o`0i2P3o
03450?l0:@80gP001P1c034206X0<@<0@@0@101101P404408080>@0P00<0600@0200600P01P0100P
01P2020080<0:@0P0P3fULD20?nEa@<0kXW51@3fQLD40?n1_@030?Ia_@3oA7<0obac00L0o`Qc00<0
iP1R0?l0@@3o04400P3o04400`1109@0202;0000JP030000L`<0001k0`3=03T40=D0@@80a@1:1@3=
04X;0=D0BPh0e@1B00<0[0RD0?ooo`3oool0=@3oool003d0oooo00<0odBD08/0BP2;04X00P2;04X5
08<0BPD0N`1:0`1c044308/0DPH0P`1B101Z05820?l4HP030?lHJP3oFH/0oeV;00<0oefD0P3oHI@0
0`3oII`0ogFT0;@P[0040<dl]0@0gUFm0P3^MKd30>J=a@D0mYG52@3fWLD30?l0>@@0o`0a0P3o03T:
0?l0<@D0o`0Y00<0mP0H0=h0001c03400`1c034406X0<@80@@0@101101P4044080<0>@0P1P0P01P3
020080<0:@0P0P3fULD50>j9a@D0mXG51@3^LKd00`3oA7<0obac0?l8L`050?l8L`<0iP1R103o0440
0`0808/0001Z0000JP030000L`<0001k00<0c@0i0=D0@@3E0440103E04460<d0BP/0e@1:3P3E0580
0`2/29@0oooo0?ooo`0e0?ooo`00?@3oool00`3oA9@0R`1:08/0BP0208/0BPD0P`1:1@1k04X207<0
@@@0R`1B1P23058306X0DP@0o`AR00@0oeV;0?mMU03oGI@0oefD0P3oHI@20?mUW080]22/103=?;@4
0=iE_@@0kWFm1@3fULD:0?JMa@@0o`0i0P3o03440?l0>@X0o`0a103o02T00`3f01P0L`0a07<0<@02
07<0<@D0JP0a00<0@@0@0440601101P00P1101P4044080D0>@0P100P01P3020080<0:@0P00@0mYG5
0>j=a@3^SLD0kXg51@3^RLD20?J5a@<0iWW50`3^LKd20?m4L`030?l/L`3o27<0o`Qc00@0o`Qc0`3V
06840?l0@@030440U00808/0001Z00<0001c0`0007/00`3=03T0e@110=D0@@040=D0@@030=D0BP3=
04X0c@1:00<0c@1:2P3E04X?0=D0DP030:`8U03oool0oooo03D0oooo000l0?ooo`80odbD102;04X6
08<0BP@0N`1:00<0L`1108/0DP2;05800`2;058608<0DP<0JP1B0`3o16820?mIR`<0oefD0P3oHI@0
103oII`0]22/0;@P[02d8:`30<dl]0D0gUFm103^MKd40?J9a@X0mYg50P3fXLd30?l0>@80o`0a1@3o
03T:0?l0<@80o`0Y0`3f01P00`1c0340JP0a06X0<@0506X0<@@0@@0H1011020603T080@0800H0P0P
020302T080H0kXg5103^RLD50>Iia@<0kW6m0P3oA7<00`3o;7<0o`Qc0?l8L`040?l8L`<0iP1R103o
0440101109@0202;0000P`0006X20000L`@0001k1P3E04420=D0BP<0c@1:2`3E04X?0=D0DP030:`8
U03oool0oooo03D0oooo000l0?ooo`80odbD102;04X608<0BP@0N`1:1`2;058608<0DP80JP1B0`3o
16820?mIR`80oefD0P3oHI@20?mUW0<0]22/0`3=?;@40=iE_@D0kWFm103fRLD50?nIa@D0mYg50P3f
XLd40?l0>@030?l0<@3o03T0o`0i00<0o`0i2P3o03420?l0:@040?l0803f01P0mP0H06X0<@80gP00
00D0c@0006X0<@1Z0340JP0a05X0<@03044060@0@@0P1`0i0203020060<0800P0`0Y02000`3^TLd0
kXg50>j=a@030>j=a@D0iX75103VNLD30>ia_@80odAc00<0obac0?l8L`3o27<00`3o27<50>H0HP@0
o`1100<0202;0>h0BP0006X00`0007<30000N`D0e@11103E04X20<d0BP/0e@1:3`3E05820:`8U3H0
oooo000l0?ooo`80odbD102;04X608<0BP@0N`1:00<0U01B08/0DP2;0580102;058608<0DP0306X0
DP3o1680o`AR0080o`AR00@0oeV;0?mMU03oGI@0oefD0P3oHI@00`3oII`0]22/0;@P[0020;@P[0<0
cCbd103NEKd50>ie_@@0mXW51@3oVLD40?nQa@@0mZ7=2P3o03T:0?l0<@030?l0:@3o0200o`0P0080
mP0H1@1Z034205X0<@80@@0H1@11020703T0800303T0:@0P01P0800H0080800P0`0Y02030>jAc@D0
iXW5103VPLD40>Iia@<0kW6m0P3oA7<60?l8L`D0iP1R103o04400`3^04X0202;0000P`040000L`<0
001k103E04450=D0BP030<d0BP3E04X0e@1:00T0e@1:3`3E05820:`8U3H0oooo000l0?ooo`80odbD
102;04X608<0BP<0N`1:0P2D058608/0DPH0P`1B00@0JP1B0?l4HP3o1680o`AR0P3oFH/30?mMU003
0?mQU03oII`0e@1k00<0oe2/103=?;@40=iE_@D0kWFm103fRLD40?nIa@D0oj75103fYLd;0?l0>@X0
o`0a0P3o02020?H060@0JP0a0`1J03400`1101P0@@0P04408003044080L0>@0P0P0i02T0100P01P0
800P0200800P020302T080@0iXg=103VRLD40>J1a@@0iWW50`3=FKd20?m4L`H0o`Qc1P3V06820?l0
@@050440U03^04X0202;0000P`0006X00`0007<30000N`<0e@114@3E04X@0=D0DP80[0RD=P3oool0
03`0oooo0P3oC9@408/0BPH0P`1:0P1k04X309@0DPH0R`1B1P2305840?l4HP040?mIR`3oGI@0oefD
0?mMU080of6D00<0e@1k0?lHJP3oD:`00P3oD:`30?mQ[0@0gUFm1P3^MKd40?J9a@@0oiW5103oXLD6
0?JUc@X0o`0i2P3o03430?l080040?H0601Z0340JP0a06X0<@@0FP0a1@11020703T080<0>@0Y0`0P
020302T080D0iXg=103VRLD50=Eea@@0eFW50P3=FKd20?m4L`D0o`Qc1`3V06800`3o0440kP1:0>h0
BP030>h0BP030000P`0007<0001c0080001c0P0007/30=D0@@H0e@1:0P3N04X90=D0BQ00e@1B0P2/
29@f0?ooo`00?03oool20?m<U0D0R`1:1@2304X207/0BP<0U01B1P2;058608<0DP030=D0FP3o1680
o`AR0080oeV;0`3oGI@0103oHI@0e@1k0=D0N`3o66X30?m@[0<0of6/103oLK@50?n5_@@0mXW5103o
VLD50?nQa@H0mZG=2`3o03T90?l0<@040?l0:@3o0200o`0P0?l08080JP0a1@1J0344044080L0>@0P
100i02T2020080@0:@0P1@3VSLd40=j1a@D0eGG5103EJLD0103=FKd0oi6;0?m4L`3oA7<50?l8L`L0
iP1R1P3^04X00`0008<0001Z0000L`020000L`<0001k0P3E04460=D0BP<0gP1:203E04X?0=D0DP<0
[0RD=P3oool003`0oooo0P3oC9@508/0BPD0P`1:00<0N`1:09@0DP2D05800`2D058508/0DPD0P`1B
0P3E05X20?l4HP80oeV;0P3oGI@20?mQU0030=D0N`3o66X0oaQZ00<0oe2/0`3oHJ`40?ma]0D0ohFm
103oVLD40?nUa@@0ojk=203fYLd;0?l0>@P0o`0a0P3o02T20?l080L0FP0a0`11020803T080@0>@0Y
0P0P020302T08080iY7=103NRLd40=j1a@D0eGG5103EJLD0103=FKd0oi6;0?m4L`3oA7<50?l8L`L0
iP1R00<0iP1J0>h0BP3^04X00`3^04X00`0808/000230000L`030000L`80001k00<0e@110=D0BP3E
04X0103E04X50=h0BPL0e@1:3`3E05800`2T29@0[0RD0:`8U00f0?ooo`00?03oool20?m<U0D0R`1:
1@2304X609@0DPH0R`1B102305820=D0FP80o`AR00L0oeV;0?mMU03oGI@0oefD0?mQU03V17/0e@1k
0080oaQZ0`3oD:`30?mQ[0@0og6d1@3oQKd40?nIa@@0ojG52@3o[/d40?J^c@X0o`0i203o03430?l0
:@030?l0801J0340FP0a00D0FP0a0P11020803T080D0>@0Y00@0800P02T0800Y0200:@0P0`3VTLd4
0=j9c@@0gX751@3EMLD40=EYa@80oi6;0P3oA7<40?l8L`L0iP1R0P3V05X60>h0BP030000P`0007<0
001c00<0001c0P0007/60=D0BPH0gP1:1P3E04X?0=D0DP80Y0RD00<0[0RD0?ooo`3oool0=03oool0
03`0oooo0P3oC9@508/0BPD0P`1:1P2D058608/0DP<0P`1B0`3E05X00`3o1680oeV;0?mIR`030?mM
U0030>H4N`3E07/0oaQZ0080oaQZ0`3oD:`30?mQ[0@0og6d1@3oQKd40?nIa@@0ojG52@3o[/d40?J^
c@/0o`0i1P3o03440?l0:@80o`0P1P1J03400`110200>@0P03T0800603T080H0>@0Y100Y02030=jA
c@@0gXW=103EOLd50<eaa@@0aF750P3oTH/20?m4L`@0o`Qc1`3V06830>H0FPD0kP1:00<000230000
N`0007<00`0007<20000N`H0e@1:1`3N04X40=D0BQ00e@1B0`2T29@f0?ooo`00?03oool20?m<U0D0
R`1:102304X709@0DPH0R`1B0P2305840=D0FP030?l4HP3oFH/0oeV;0080oefD00<0of6D0>H4N`3E
07/00`3o66X30?m@[0<0of6/103oLK@50?n5_@@0oiW5103oYLD80?n^c@@0mZk=0P3^Z/d;0?l0>@H0
o`0a103o02T00`3o0200FP0a05X0<@0405X0<@P0>@0P200i02T202T080@0gY7=103NRLd40=Emc@D0
cG750`35HLD20?nAR`80odAc1@3o27<60>H0HP@0iP1J1@3^04X00`3V04X000230000L`040000L`80
001k103E04X90=h0BP<0e@1:403E05840:@8U3D0oooo000l0?ooo`80odbD1@2;04X308<0BPP0U01B
1P2;058208<0DP@0e@1J00<0o`AR0?mIR`3oGI@00P3oGI@00`3V17/0e@1k0?lHJP030?lHJP<0oe2/
0`3oHJ`40?ma]0D0ohFm103oVLD30?nUa@D0ojk=103o^/d40?Jbc@80kZk=2`3o03T70?l0<@@0o`0Y
1P1J034703T080T0>@0Y0P0Y02040=jAc@@0gXW=103EOLd50<eaa@80aF7500<0om:/0?nAR`000000
0P1B0200102D0440o`Qc0?l8L`3o27<70>H0HP@0iP1J103^04X30>H0BP030000N`0007<0001c0080
001c0P0007/40=D0BPX0gP1:0P3E04X@0=D0DP@0Y0RD=@3oool003`0oooo0P3oC9@508/0BP80P`1:
2P2D058508/0DP0308<0DP3E05X0e@1J00<0e@1J0P3oFH/20?mMU080iPAk00<0e@1k0?lHJP3o66X0
0P3o66X30?m@[0<0of6/103oLK@50?n5_@<0oiW51@3oa/d40?o2c@@0ok[=103f//d30>j^c@/0o`0i
1`3o03430?l0:@D0FP0a00<0DP0a03T0800i02001@0i020903T0:@0302T0803NTLd0gY7=00<0gY7=
103NRLd40=F1c@D0aGG=00@0aF750?oB[000000000000P1B020309@0@@80o`Qc1P3V06860>H0FP80
kP1:103V04X00`0007/0001c0000L`030000L`040000N`3E04X0e@1:0=D0BP`0gP1:00<0e@1:0=D0
DP3E05803@3E05850:@8U3D0oooo000l0?ooo`80odbD1@2;04X00`2304X0U01B09@0DP0909@0DPD0
R`1B1P3E05X20?mIR`80oefD0P3V17/00`3o1680oaQZ0?lHJP020?lHJP<0oe2/0`3oHJ`40?ma]0@0
ohFm103o`/D50?o6c@@0ol;=103o^/d40?Jbc@<0kZk=00<000000?l0>@3o03T02@3o03T60?l0<@<0
o`0Y00@0FP0a0?l0801J0340FP0a0P1B034603T080X0>@0Y00<0iYG=0=jAc@3NTLd00`3NTLd40=j9
c@@0eH7=1@35MLd00`3odZ`00000000000020580800307<0<@2D0440U0110080U01100<0o`Qc0>H0
HP3V0680103V06860>H0FP030>h0BP3V04X0iP1:00@0iP1:1P0007<00`0007/0e@1:0=D0BP0<0=h0
BQ00e@1B1@2T29@e0?ooo`00?03oool20?m<U0D0R`1:302D058508/0DP030;d0DP3E05X0e@1J0080
e@1J0P3oFH/20?mMU0040?H@P`3V17/0e@1k0?l4HP@0oaQZ0`3oD:`30?mQ[0<0og6d1@3o^[d40?o2
a@D0olK=103o`/d50?o6e@@0m[K=00<0kZk=0000000a04X02`3o03T70?l0<@80o`0Y0`1J03430580
<@D0>@0P2`0i02T00`3VULd0gY7=0=jAc@030=jAc@@0gXg=103ERLd40<Eec@0309`0[00000000000
00<0DP0P1@2D04460>H0HPL0iP1J1`3V04X00`0007/0001c0000L`030000L`030000N`3E04X0e@1:
00d0gP1:3`3E05850:@8U3D0oooo000l0?ooo`80odbD102;04X=09@0DP@0R`1B0P2m05840=D0FP80
oeV;00@0oefD0?H@P`3V17/0iPAk0P3o16840?lHJP<0oe2/0P3oHJ`50?nZ_@@0okZm103o`/D50?o6
c@80ol;=0`3oe]D40?o6e@@0m[K=00@0Y01R000000110440@@112`3o03T70?l0<@030?l0:@1J0340
FP0a00@0DP0a100i020;03T0:@030>JIc@3NULd0gYG=00<0gYG=1@3NSLd40=F9c@<0aH7=00@0W02/
00000000000000000P1B020609@0@@030;d0BP3V0680iP1R00<0iP1R1`3V05X00`3V0580iP1:0>H0
BP040>H0BP030000N`0007<0001c00@0001c00<0001k0=h0BP3N04X03@3N04X>0=D0DPD0Y0RD=@3o
ool003`0oooo0P3oC9@308/0BPh0U01B102;05820;d0DP@0e@1J00D0oeV;0?mMU03oGI@0mQ230>H4
N`030?l4HP@0oaQZ0P3oD:`30?nE]0D0ojZm103o^[d40?o2a@D0olK=1@3oe]D40?o6e@<0k[KE00<0
Y01R0000001104400P11044<0?l0>@L0o`0a00<0FP0a0580<@1B03400`1B034403T080X0>@0Y1P3V
VLd50=jEc@D0eHW=00<0aH7=09`0[02L0:`00`0000020580800307<0<@2D0440U01100<0U0110`2m
04X30>H0HPL0iP1J0`3V05850>H0BP030000N`3V04X0001c00D0001c403N04X=0=D0DPD0Y0RD=@3o
ool003`0oooo0P3oC9@208/0BQ00U01B0P2;05830;d0DP<0e@1J0P3oFH/0103oGI@0mQ230?H@P`3V
17/20?l4HP030340JP3o66X0oaQZ0080oaQZ0P3oRJ`30?nE]0D0ojZm103o^[d40?o2a@H0onK=103o
e]D50>k2e@80k[KE00<000000?o6]01104400P1104400`1:03T0o`0i0?l0>@090?l0>@L0o`0a1P1B
034303T080/0>@0Y1@3VVLd30=jIc@<0gYG=103EULd00`2mA<d0W02/09`0[003000000<0DP0P1@2D
04440;d0BP<0iP1R1`3V05X30>H0DPH0iP1:00<0001k0000L`0007<0100007<A0=h0BP/0e@1B1P2T
29@e0?ooo`00?03oool20?m<U00308/0BP2D0580U01B00l0U01B0P2;05840;d0DP80e@1J0P3oFH/2
0?H@P`030>H4N`3E07/0o`AR0080o`AR103o66X00`2d0000ohV/0?nE]0020?nE]0D0ojZm103o^[d2
0?o2a@<0oo;=1@3oi/d20?oFe@<0m]KE103^`]D0103^]]D000000?o6]00H01P20440@@80BP0i303o
03T60?l0<@H0DP0a0P0i020;03T0:@D0iYW=1P3NVLd30=FEc@040;e4c@2L0:`0W02/09`0[0<00000
0`1B020509@0@@H0_@1:00<0iP1R0>H0FP3V05X01@3V05X50>H0DPH0iP1:00<0001k0000L`0007<0
100007<@0=h0BP/0e@1B1P2T29@e0?ooo`00?03oool20?m<U180U01B00<0R`1B0;d0DP2m05800`2m
05820=D0FP050?mIR`3oGI@0mQ230?H@P`3V17/01@3o16830?lHJP80]0000`3oUK@50?nZ_@@0okZm
1@3ol/d50?oVc@D0m]KE103^`]D20:@0HP0301P060110440@@1100@0BP0i303o03T50?l0<@H0DP0a
00<0>@0P03T0:@0i02T02@0i02T00`2/0000U00005X000030>JIc@80iYg=0P3NVLd30440_@<04000
1@1J00030580800307<0<@2D0440U0110080U0111`2m04X70>H0FPH0iP1B1P3V04X00`0007/0001c
0000L`040000La00gP1:00<0gP1B0=D0DP3E0580203E05860:@8U3D0oooo000l0?ooo`<0odbD4@2D
05800`2;0580_@1B0;d0DP030;d0DP040=D0FP3oFH/0oeV;0?lLP`80mQ2300<0iPAk0?l4HP3o1680
0`3o16830?lHJP80]0000`3oUK@50?nZ_@<0okZm0P3on/D40?obc@<0onK=0`3oi]D40?KFe@D0eK;E
0P0H01P00`110440BP0i04X0>@0304X0>@030580>@3o03T0o`0i00T0o`0i1@3o03460580<@`0>@0Y
0P2/000209@000P0DP001`1J000408<0400307<0<@2D0440U01100<0U0111`2m04X00`3=0580iP1J
0>H0FP040>H0FPL0iP1B1P3V04X00`0007/0001c0000L`040000L`l0gP1:0P3N05890=D0DPL0Y0RD
=03oool003/0oooo103oC9@A09@0DPH0_@1B00<0e@1J0?mIR`3oFH/00P3f48<00`3V17/0kP0i0?l4
HP030?l4HP040340JP3o66X0oaQZ0?lHJP<0]0000P3oUK@50?nZ_@80okZm0`3on/D40?obc@H0onKE
1P3=]]h00`3E/]D0Y01R01P0600201P060D0BP0i0P1B03T<0?l0>@@0o`0a1P1B034;03T0:@80_@00
00@0NcSV0:`0002/0000U0002023000305X000D0P`0@0P2;020509@0@@L0_@1:0P3=05850>H0FPP0
iP1B1`3V04X60000L`l0gP1:0`3N05880=D0DPL0Y0RD=03oool003/0oooo103oC9@A09@0DP030:`0
DP2m0580_@1B00<0_@1B0P3oFH/01@3o78<0mQ230?H@P`3V17/0e@1J00D0o`AR0`3o66X30;@00080
oiFd1@3oZ[d50?oja@80oo;=103of]D60<F^iP@0cKKN00@0Y01R01P0600H01P0600H1@1:03T30580
>@030680>@3o03T0o`0i00X0o`0i0`3o03460580<@X0>@0Y00<0e@080=D0402m00000P2m00000`2d
XNH0[00008<0000708<000H0P`0@0P2;020309`0:@<0U0111`2m04X40<d0DP<0iP1J2P3V05860>H0
BPH0001c00<0iP1:0=h0BP3N04X02`3N04X50=h0DPL0e@1B1`2T29@d0?ooo`00>`3oool40?m<U100
U01B0P2/05850;d0DP80oeV;00D0oab30?H@P`3V17/0c@1J0=D0FP050?l4HP<0oaQZ102d00000`3o
UK@0ojZm0?nZ_@020?nZ_@80oo:m103on/D30?oJe@0308/0Y02/FMh0[5WN00<0[5WN1035[^H20:Am
gP050000000H01P0600H01P0600i02T0101:03T40580>@030680>@3o03T0o`0i00X0o`0i0`3o0346
0580<@X0>@0Y00@0e@080=D0403E0100e@0@0`2m00000`2dXNH0W00009`0000609`000<0P`0@00<0
R`0P09`0:@2L02T01@2L02T00`2D0440_@1:0;d0BP050;d0BPD0c@1B0`3V05X;0>H0DPH0iP1:1P00
07<=0=h0BPH0gP1B1@3E05880:@8U3@0oooo000k0?ooo`@0odbD3`2D05830:`0DPD0_@1B00D0oeV;
0?lLP`3f48<0mQ230>H4N`020=D0FPD0o`AR0P3o66X20;d0@@<0[00Y00<0oiFd0?nZ_@3oZ[d0103o
l[d30?oja@<0oiW50`2;0:@00`0008/000230?ooo`020000]00503T0gP1kD>H0Ne3V07]@iP000000
0`0H01P203T0:@<0BP0i1@1B03T20680>@`0o`0i0P3o03460580<@T0>@0Y0P3^01P40=D040<0_@00
1@3Vc]h30?oRe@030?oZe@2L02T0W00Y00P0W00Y1`2m04X70<d0DP030>H0FP3V0580iP1B00X0iP1B
1P3V04X60000L`030>H0BP3N04X0gP1:00X0gP1:1`3N05840=D0DPP0Y0RD=03oool003/0oooo1@3o
C9@>09@0DP<0[01B102m05820?mIR`030?lLP`3f48<0mQ2300@0e@1J103o16850;d0@@<0[00Y00<0
N`000?ob_@3ol[d00`3ol[d20?oja@<0oiW50P2;0:@202T0W080002;00@000230000]0000;@0002d
0P0a0=D010000000600H01P0600H01P303T0:@80BP0i1P1B03T20680>@d0o`0i00<0o`0a0580<@1B
0340101B034803T0:@<0kP0H0P3N02040=D04080_@002@2/01P709`0:@<0]00i1@2m04X80<d0DPh0
iP1B1P3V04X50000L`80iP1:2P3N04X90=h0DP<0e@1B202T29@d0?ooo`00>`3oool50?m<U0d0U01B
1@2/05830;d0DP050?mIR`3o98<0mQ230?H@P`3V17/0103E05X30?l4HP80_@1:102m04440:`0:@80
N`000`3ol[d01P3on/D0oiW50?nIa@3oVLD0R`2T06X0W0<0:@2L00@0002D0000R`0008<000230P00
0;@2000000<0600H0`0i02T204X0>@L0DP0i00<0HP0i05X0>@1J03T0303o03T00`3o0340DP0a0580
<@040580<@P0>@0Y00<0mP0P0>h0603^01P00`3N02050=D040030;d0002/01P0[00H00H0[00H1@2L
02T60;@0>@<0_@1:203=05820=D0BPd0iP1B1P3V04X60000L`80iP1:2@3N04X:0=h0DP80e@1B202T
29@d0?ooo`00>`3oool50?m<U0`0U01B1P2/05830;d0DP050?lTP`3o78<0mQ230?H@P`3V17/0103E
05X20?l4HP<0_@1:1@2m04440:`0:@<0N`0000D0oo:m0?nIa@3oVLD0od1Z08/4W00206X0W0@0:@2L
0P0008/00`0008<0oooo0000000202T00080600H100i02T00`1:03T0DP0i0580>@050580>@D0FP0i
303o03T60580<@L0>@0Y0`3f02000`3^01P0gP0P0=h080030=h080@0e@0@2@2/01P209`0:@T0]00i
00<0_@1:0<d0DP3=05801P3=05830=D0BPh0iP1B1P3V04X50000L`<0iP1:203N04X;0=h0DP030=D0
DP2T29@0Y0RD00H0Y0RD=03oool003/0oooo1@3oC9@;09@0DPL0[01B0P2m05800`3oFH/0obB30?lL
P`020?H@P`D0e@1J1P2m04X50;d0@@<0[00Y101k00020?IU]0030?m0JP2;19`0JP2L0080JP2L0`0Y
09`3000000@0:@0000<0600H03T0:@0i02T00`0i02T70580>@H0FP0i303o03T60580<@H0>@0Y00<0
o`0Y0?H0803f02000P3f02060=h080@0e@0@2035020;0;@0>@P0c@1B1@3E04X=0>H0DPL0iP1:1@00
07<30>H0BPL0gP1:2`3N05800`2/29@0Y0RD0:@8U0060:@8U3@0oooo000k0?ooo`D0odbD2`2D0580
0`2T0580[01B0:`0DP040:`0DP80_@1B0P3o98<20?H@P`030>H4N`3E05X0e@1J00<0e@1J00<0]01:
0;d0BP2m04X00`2m04X50;d0@@@0[00Y1@1k0000103o@6X0R`BL08/4W01Z09`5020000D0:@0000<0
600H03T0:@0i02T00`0i02T70580>@P0FP0i2`3o03T60580<@H0>@0Y0P3o02T40?H080030>h0:@3N
0200gP0P00@0gP0P0P3E01090<D080P0]00i0`3504460<d0DPH0e@1:3P3V05860>H0BPD0001c0`3V
04X60=h0BP`0gP1B00<0[0RD0:@8U02T29@01P2T29@d0?ooo`00>`3oool50?m<U0X0U01B0P2T0587
0:`0DP80obB300@0oab30?H@P`3f48<0_@1B103E05X20;@0BPH0_@1:1@2m04440:`0:@D0N`001P0P
000702T000D0>@0Y00<0BP0a0580>@1B03T0101B03T905X0>@/0o`0i1P1B034503T0:@@0o`0Y0`3f
02030>h0:@D0gP0P00<0e@0@0<D0803502001`3502060;@0>@D0a@111@3=05880=D0BPh0iP1B1P3V
04X40000L`@0iP1:1@3N04X<0=h0DP030:`8U02T29@0Y0RD00L0Y0RD<`3oool003/0oooo1P3oC9@9
09@0DP80Y01B1`2/05820?lTP`040?lLP`3f48<0mQ230;d0DP<0e@1J102d04X50;d0BPH0_@11102/
02T207/000P0DP001P0Y000503T0:@80BP0a1@1B03T;05X0>@X0o`0i1P1B034403T0:@80o`0a103o
02T20?H080@0kP0Y1@3N020:0<D080<0]00i1`3504440<d0DPT0e@1:3P3V05870>H0BP@0001c103V
04X40=h0BP`0gP1B00<0[0RD0:@8U02T29@01`2T29@c0?ooo`00>`3oool60?m<U0P0U01B102T0586
0:`0DP040?lTP`3o78<0mQ230?H@P`80_@1B0P3E05X50;@0BPH0_@1:1@2m04440:`0:@T0DP00100Y
000304X060<0>@0Y101:03430580>@d0FP0i2P3o03T60580<@@0>@0Y0`3o03440?l0:@030?H0803^
02T0kP0Y00@0kP0Y103N02090=D0<@/0a@110P3=058:0=D0BPl0iP1B1P3V04X40000L`@0iP1:0`3N
04X<0=h0DP80[0RD2@2T29@c0?ooo`00>`3oool60?m<U0P0U01B102T05850:`0DP80obB300<0oab3
0?H@P`3f48<00P2m05800`3E05X0]01:0;@0BP050;@0BPD0_@1:1P2m04420:`0:@D0JP0P101B0002
02T000D0BP0H0`0i02T404X0<@<0DP0i3`1J03T90?l0>@H0DP0a0`0i02T50?l0<@@0o`0Y1`3^02T3
0=h080X0e@0a2P3504400`3=0580e@1:0=D0BP080=D0BP80gP1:3P3V05870>H0BP<0001c1@3V04X2
0=h0BP`0gP1B0P2/29@90:@8U3<0oooo000k0?ooo`H0odbD1`2D05850:@0DPD0[01B0P3o98<20?H@
P`<0_@1B202d04X60;d0BPD0_@112P1Z020804X0600303T0:@1:0340BP0a00@0BP0a0P1B03TA05X0
>@P0o`0i1P1B034203T0:@L0o`0a103o02T00`3f0340kP0Y0>h0:@050>h0:@030=h0803E0340e@0a
00P0e@0a2P35044:0=D0BP@0gP1:3P3V05860>H0BP@0001c1@3V04X00`3N04X0gP1B0=h0DP0:0=h0
DP80[0RD2@2T29@c0?ooo`00>`3oool60?m<U0H0U01B1`2T05840:`0DP040?lTP`3o78<0mQ230?H@
P`<0_@1B00<0[01:0;@0BP2d04X01@2d04X60;d0BP@0_@110`1k034806X080L0BP0H00<0>@0Y04X0
<@1:03401@1:03400`1B03T0FP0i05X0>@0A05X0>@L0o`0i1P1B034203T0:@P0o`0a0`3o02T30?H0
<@H0kP0Y2`3E03460<D0@@@0e@11203E04X50=h0BPh0iP1B1`3V04X30000L`D0iP1:303N05830:`8
U0T0Y0RD<`3oool003/0oooo1P3oC9@00`3oFI`0U01B09@0DP0309@0DP0309`0DP2T0580Y01B00@0
Y01B0`2/05820?lTP`030?lLP`3f48<0_@1B0080_@1B0`2/04X70;@0BPH0_@1:0P2m044607/0<@D0
JP0P1`1:01P804X0<A@0FP0i0P1B03460?l0>@H0DP0a00<0>@0Y0?l0<@3o0340203o03420?l0:@D0
mP0a1@3^02T50=h0<@D0e@0a0`3504470=D0@@L0e@1:1`3N04X=0>H0DPL0iP1:0`0007<50>H0BP03
0>H0DP3N0580gP1B00T0gP1B0`2/29@90:@8U3<0oooo000k0?ooo`D0odbD0P3oFI`409@0DP80W01B
1P2T05830:`0DP040?lTP`3o78<0mQ230?H@P`80_@1B102/04X70;@0BPH0_@1:00<0_@1107/0<@1k
03401`1k034206X080@0BP0H101J02T704X0<@030580<@1J03T0FP0i0180FP0i0P1B03460?l0>@H0
DP0a00<0o`0i0?l0<@3o03402@3o03400`3o02T0mP0a0?H0<@040?H0<@@0kP0Y2P3N034;0=D0@@D0
e@1:203N04X<0>H0DPT0iP1:0`0007<30>H0BP<0iP1B2P3N05800`2T29@0[0RD0:`8U0090:@8U3<0
oooo000k0?ooo`<0odbD103oFI`309@0DP<0W01B1P2T05830:`0DP040?lTP`3o78<0mQ230:`0DP80
_@1B1@2/04X70;@0BPD0_@1:2`1k034805X0:@H0BP0a0`1B034D05X0>@<0DP0a1@3o03T60580<@80
o`0i2`3o03480?H0<@<0kP0Y2P3N034:0=D0@@@0e@1:2P3N04X:0>H0DPX0iP1:0`0007<30>H0BP<0
iP1B2@3N05830:@8U0030:`8U02T29@0Y0RD00L0Y0RD<`3oool003/0oooo0P3oC9@00`3oFI@0oeVL
0?mIW0020?mIW080U01B1@2L05860:@0DP070:`0DP3o98<0obB30?lLP`3^17<0[01B0;d0DP060:`0
BPL0]01:102m04X308<0>@T0N`0a201J02T404X0<@D0DP0a501J03T40580<@@0o`0i1@1B03440?l0
>@/0o`0a00<0o`0i0?H0<@3f03401P3f03400`3^02T0gP0a0=h0<@080=h0<@/0e@110P3E04X;0=h0
BPT0iP1B2`3V04X40000L`030>H0BP3V0580iP1B00<0iP1B203N058=0:@8U3<0oooo000k0?ooo`03
0?m<U03oFI@0oeVD00@0oeVL00<0U01B09`0DP2L0580102L05860:@0DP040:`0DP3o98<0oab30?H@
P`80[01B202/04X70;@0BP80_@1:1P2303T607/0<@P0FP0Y0`1:03460580<AD0FP0i1@1B03430?l0
>@@0DP0a1P3o03T:0?l0<@80o`0i203f034:0=h0<@/0e@11303N04X20>H0BPL0iP1B3@3V04X30000
L`030>H0BP3V0580iP1B00@0iP1B1`3N058>0:@8U380oooo000j0?ooo`@0oeVD103oFI`709`0DPH0
Y01B00@0[01B0?lTP`3o78<0kPAc0P2/05800`2T04X0[01:0:`0BP050:`0BPL0]01:00<0_@1:08<0
>@2303T01P2303T507/0<@P0FP0Y00<0BP0a0580<@1B03401P1B034E05X0>@D0DP0a0`3o03T30580
<@P0o`0i2@3o03440?l0>@L0mP0a0`3V03T70=h0<@L0e@11103N044:0=h0BP<0iP1:1`3V058>0>H0
BP80001c1`3V05870=h0DPh0Y0RD<P3oool003X0oooo103oFI@50?mIW0L0W01B1@2T05820?lTP`80
kPAc00@0[01B0:@0BP2T04X0Y01:1`2/04X60;@0BP/0P`0i0P1k034805X0:@X0DP0a5@1J03T60580
<@80o`0i0`1B03490?l0>@P0o`0a1@3o03T60?H0<@L0iP0i0`3N03440=D0@@L0gP11203N04X60>H0
BPD0iP1B403V04X20000L`L0iP1B1@3N05800`2/29@0Y0RD0:@8U00<0:@8U380oooo000j0?ooo`@0
oeVD1@3oFI`709`0DPD0Y01B00D0obB30?lLP`3^17<0[01B0>H0JP030:@0BPP0[01:1@2d04X208/0
@@X0P`0i2@1R03490580<AH0FP0i1`1B03400`3o03T0DP0a0580<@0;0?l0>@L0o`0a1`3o03T40?H0
<@X0iP0i303N04460=h0BPL0iP1:103V058A0>H0BP80001c203V05840=h0DP030:`8U02T29@0Y0RD
00`0Y0RD<P3oool003X0oooo103oFI@50?mIW0L0W01B1@2T0580103o98<0mPak0:`0DP2/05850:@0
BPL0[01:102d04X408/0@@T0P`0i2@1R03480580<AL0FP0i2@1B034=0?l0>@H0o`0a203o03T30?H0
<@/0iP0i2`3N04440=h0BPX0iP1:0P3V058B0>H0BP030>H0DP0007<0iP1B00L0iP1B103N05800`2/
29@0Y0RD0:@8U00<0:@8U380oooo000j0?ooo`@0oeVD1P3oFI`609`0DP@0Y01B00D0obB30?lLP`2/
0580[01B0>H0JP050:@0BPP0[01:0`2d04X508/0@@L0P`0i2P1R03460580<AT0FP0i201B034?0?l0
>@D0o`0a2P3o03T00`3f0340iP0i0>H0>@090>H0>@`0gP110P3N04X;0>H0BP030>H0DP3V04X0iP1:
0100iP1:0P3V05800`0007<0001Z0>H0DP070>H0DP80gP1B0P2/29@>0:@8U380oooo000j0?ooo`@0
oeVD1P3oFI`709`0DP<0Y01B00@0obB30?H<N`2T0580[01B1`2T04X70:`0BP80]01:202;044508<0
>@T0HP0a1@1B034K05X0>@80DP0a00<0i[kE0580<@1B03400`1B03400`3V`]D0o`0i0?l0>@0=0?l0
>@@0o`0a2`3o03T;0>H0>@`0gP11803V04X20>H0DP80001c203V05820=h0DP80[0RD2P2T29@0102L
29@0Y0RD0:@8U02T29@b0?ooo`00>P3oool40?mIU0H0oeVL1`2L05830:@0DP030?lTP`2T0580Y01B
00P0Y01:202/04X00`2d04X0R`1108/0@@0708/0@@<0P`0i2P1R03430580<Ad0FP0i1`1B03420>Jn
e@030>K2e@3o03T0o`0i00d0o`0i0`3o034<0?l0>@<0kP0i203V03T80=h0@@@0iP117P3V04X40>H0
DP030000L`3V0580iP1B00L0iP1B00<0gP1B0:`8U02/29@02P2T29@209`8U080Y0RD<P3oool003X0
oooo103oFI@70?mIW0H0W01B0P2T05801@3o98<0mPak0:@0DP3^17<0W01:00P0Y01:1`2/04X;08/0
@@80P`0i2P1R03400`1B0340FP0i05X0>@0M05X0>@H0DP0a103V_]D@0?l0>@80o`0a303o03T70>h0
>@@0iP0i103N04480>H0@Ah0iP1:1@3V05800`0007<0iP1B0>H0DP060>H0DP<0[0RD2P2T29@309`8
U0030:@8U03oool0oooo0300oooo000j0?ooo`@0oeVD1`3oFI`709`0DP040:@0DP3o98<0Y01B0>h4
L`<0W01:202T04X60:`0BP`0R`112P1R034Q05X0>@D0DP0a1P3V_]D@0?l0>@030?l0<@3o03T0o`0i
00X0o`0i2`3^03T=0>H0@A`0iP1:3`3V05830:`8U0X0Y0RD102L29@b0?ooo`00>P3oool40?mIU0L0
oeVL1`2L0580102T0580mPak0?H<N`2T058309`0BPP0Y01:1@2/04X=08/0@@X0JP0i4`1J03T00`1R
03T0FP0i05X0>@0:05X0>@D0DP0a103V_]D20>jne@80k/;E7@3o03T;0>h0>@`0iP116`3V04X80>H0
DP030000JP3V0580iP1B00@0iP1B102/29@:0:@8U0D0W0RD<@3oool003X0oooo103oFI@80?mIW0H0
W01B00<0obB30:@0DP2T05801@2L04X80:@0BP<0[01:3@2;044;06X0>A40FP0i0`1R03T<05X0>@@0
DP0a103V_]D40>jne@030>k2e@3o03T0o`0i01/0o`0i2`3^03T<0>H0@A`0iP1:3P3V05840:`8U0X0
Y0RD1@2L29@a0?ooo`00>P3oool40?mIU0P0oeVL1P2L05800`3o98<0Y01B0:@0DP0509`0BPP0Y01:
0`2/04X<08/0@@/0JP0i201J03T20680>@L0FP0i101R03T<05X0>@@0DP0a0`3V_]D40>jne@<0k/;E
703o03T;0>h0>@d0iP11703V04X<0>H0DP030:`<U02/29@0[0RD0080[0RD2P2T29@509`8U340oooo
000j0?ooo`@0oeVD203oFI`709`0DP030:@0DP2L04X0W01:00D0W01:202T04X00`2/04X0R`1108/0
@@0;08/0@@/0JP0i1P1J03T40680>@D0FP0i1@1R03T=05X0>@<0DP0a0`3V_]D50>jne@@0k/;E6`3o
03T<0>h0>@`0iP11703V04X70>H0DP030000JP3V0580iP1B0080iP1B00<0[0bD0:`8U02/29@00P2/
29@:0:@8U0D0W0RD<@3oool003X0oooo103oFI@90?mIW0@0W01B00<0obB309`0DP2L04X01`2L04X8
0:@0BPd0R`112`1Z03T405X0>@H0HP0i1@1J03T60680>@d0FP0i0P1B03430>Jne@H0k[kE103^`]DL
0?l0>@<0mP11203^03T<0>H0@Ad0iP1:2P3V05820:`<U0@0[0RD2P2T29@509`8U340oooo000j0?oo
o`@0oeVD2@3oFI`609`0DP0309@0BP2L04X0W01:00H0W01:1`2T04X<08/0@@`0JP0i0P1J03T80680
>@<0FP0i201R03T=05X0>@030580<@3^^]D0k[[E0080k[[E1@3^_]D30>k2e@<0m/;E6`3o03T70?H0
@@@0kP0i1P3V04470>h0@@/0iP1:0P3^04X?0>H0BPL0iP1B00<0001Z0>H0DP3V05800P2/39@40:`8
U0X0Y0RD1@2L29@a0?ooo`00>P3oool40?mIU0T0oeVL1@2L058309@0BPP0W01:1@2T04X=08/0@@/0
L`0i2P1R03T305X0>@T0HP0i3@1J03T40>jje@<0k[kE2@3f`]D00`3^a]D0o`0i0?l0>@0H0?l0>@/0
mP113@3^04490>H0BPD0kP1:3`3V04X80>H0DP<0[0bD102/29@:0:@8U0D0W0RD<@3oool003X0oooo
103oFI@90?mIW0040?mMW02L0580W01B09`0DP@0U01:202L04X50:@0BPd0R`112`1c03T:0680>@03
05X0>@1R03T0HP0i00P0HP0i3@1J03T40>jje@<0k[kE2P3f`]D20?K6eAT0o`0i303f044<0>h0@@P0
iP1:1P3^04X?0>H0BPL0iP1B00@0Y0RL0:`<U02/39@0[0bD102/29@:0:@8U0D0W0RD<@3oool003X0
oooo103oFI@90?mIW0040?mMW02L0580W01B09`0DPD0U01:202L04X30:@0BPd0R`11301c03TE0680
>@`0FP0i1@3^^]D30?Jne@L0m/;E1P3fa]D<0?l0>@030?l0@@3o03T0o`0i00T0o`0i303f044=0>h0
@@D0iP1:2@3^04X>0>H0BP030>h0BP3V0580iP1B00@0iP1B00@0001Z0:@8W02/39@0[0bD102/29@:
0:@8U0D0W0RD<@3oool003X0oooo103oFI@90?mIW0030?mMW02L0580W01B00H0U01:202L04X30:@0
BPd0R`112`1c03T80680>@80JP0i301R03T;05X0>@80m[K=0`3^^]D30?Jne@P0m/;E103fa]D30?o:
e@/0o`0i0P3o044:0?l0>@`0mP113@3^04440>H0BPX0kP1:3@3V04X30>h0BPD0iP1B00@0001c0:@8
W02T29`0[0bD102/29@:0:@8U0D0W0RD<@3oool003X0oooo103oFI@90?mIW0030?m]W02L0580U01:
00L0U01:202L04X00`2T04X0R`1108/0@@0;08/0@@`0L`0i1P1R03T406X0>@`0HP0i2P1J03T50?Jf
c@<0m[kE2@3f`]D80?o:e@X0o`0i103o04480?l0>@d0mP11303^04420>H0BPd0kP1:2`3V04X40>h0
BP@0iP1B00<0001Z0000L`0006X00P2T29`40:`8U0X0Y0RD1@2L29@a0?ooo`00>P3oool40?mIU0T0
oeVL00<0ofVL09@0BP2D04X01`2D04X809`0BPh0R`112`1c03T40680>@L0JP0i301R03T905X0>@D0
m[K=103o_/d40?o2c@D0olK=203ob]D00`3od]D0o`0i0?l0>@070?l0>@D0o`11203o03T<0?H0@@`0
kP113`3^04X:0>H0BPH0kP1:0`3V05830000JP80Y0RL102/29@:0:@8U0D0W0RD<@3oool003X0oooo
103oFI@80?mIW080ofVL00<0mQ1k09@0BP2D04X01`2D04X709`0BP80R`1:2`2;044<07<0>@80HP0i
201Z03T=0680>@P0FP0i103o//d60?nnc@@0ol;=1@3oa/d40?o:e@D0olkE00<0om;E0?l0>@3o03T0
1P3o03T70?l0@@H0o`0i303f04460>h0@AH0kP1:203V04X70>h0BP80iP1B00@0001R0000JP0006X0
001c0P2T29`0102L29`0[0RD0:`8U02/29@:0:@8U0D0W0RD<@3oool003X0oooo103oFI@70?mIW0<0
ofVL00<0mQ1k0?H<N`2D04X01`2D04X609`0BP@0R`1:2P2;044;07<0@@/0JP0i3@1R03T705X0>@D0
ok;=1@3o^/d40?o2c@D0olK=1@3ob]D50?o>e@80om;=1`3o03T80?l0@@D0o`0i303f044L0>h0BPL0
iP1:2@3^04X00`3V0580001J0000HP030000JP030:@8W02L29`0W0RL0080[0RD2P2T29@509`8U340
oooo000j0?ooo`@0oeVD1`3oFI`20?mYW080mQ1k00<0mPak09@0BP2D04X01`2D04X509`0BPD0R`1:
2@2;044;07<0@@/0JP0i3@1R03T605X0>@80ojk50`3o//d60?njc@@0ol;=1@3oa/d50?o:e@<0olkE
0`3oc/d20?oBc@H0o`0i2P3o04440?l0>@`0mP11703^04X60>H0BPT0kP1:00<0001R0000BP000680
0`0006X01@2T29`0W0RL09`8W02L29`0[0RD00X0Y0RD1@2L29@a0?ooo`00>P3oool40?mIU0H0oeVL
0`3oJI`20?H@N`030?H<N`3o97/0U01:00L0U01:102L04X708/0BPL0R`11301c044;06X0>@`0HP0i
1P1J03T50?n^a@H0ok[=1@3o`/d50?o6c@D0ol[E1P3oc/d30?oBc@H0o`0i2P3o04430?l0>@`0mP11
703^04X50>H0BPX0kP1:0`0006830000JP030:@8W02L29`0W0RL0080W0RL2P2T29@509`8U340oooo
000j0?ooo`@0oeVD1@3oFI`40?mYW0040?H@N`3f37/0mPak0?lTN`T0U01:0`2L04X908/0BPD0R`11
2`1c044;06X0>@`0HP0i00<0HP1105X0>@1J03T00`1J03T60?n^a@D0okk=1@3o`/d60?o:c@D0ol[E
1P3oc/d40?oBc@D0o`0i303o04400`3o03T0mP110?H0@@0;0?H0@A/0kP1:103V04X:0>h0BP050000
JP0007<0001R0000DP0006800`0006X409`8W0X0Y0RD1@2L29@a0?ooo`00>P3oool40?mIU0D0oeVL
0`3oJI`20?H@N`040?H<N`3o77/0obAk0?lTN`P0U01:0P2L04X;08/0BP<0R`11301c044906X0>@80
JP112P1R03T30680@@@0FP0i0`3oZ/D30?n^a@H0okk=1@3oa/d60?o:c@D0ol[E1`3oc/d20?oBc@80
olK5103o03T=0?l0@@d0mP11703^04X20>H0BPX0kP1:00<0Y0bL0000JP0006X0100006820000JP@0
W0RL00<0W0RD0:@8U02T29@01`2T29@509`8U340oooo000j0?ooo`@0oeVD103oFI`40?mYW080mQ1k
00@0mPak0?lLN`3o97/0obAk2@2D04X00`2L04X0R`1:08/0BP0:08/0BP80R`11301c044606X0>@D0
JP112@1R03T40680@@<0FP0i1P3oZ/D70?nnc@D0olK=1@3ob/d60?o:e@L0olk=1@3oa/D30?l0>A40
o`112@3f044L0>h0BP030>H0BP3^04X0kP1:00T0kP1:0P2T39`00`0006X0001c0000HP020000HP<0
001Z0`2L29`209`8U0P0Y0RD1@2L29@a0?ooo`00>P3oool40?mIU0<0oeVL1@3oJI`00`3f47/0mPak
0?lLN`020?lTN`80obak202D04X>08/0BP`0L`111@1Z03T706X0@@L0HP0i1@1R044305X0>@L0oj[5
1P3o_/D50?o6c@H0olkE1P3ob]D40?o>c@<0olK=1@3oa/D00`3o[[d0o`0i0?l0>@0D0?l0@@L0mP11
9P3^04X30:@<W080001Z100006820000JP<0W0RL0`2L29@70:@8U0D0W0RD<@3oool003X0oooo103o
FI@20?mIW0D0ofVL0P3f47/0103f37/0oaak0?lTN`3o97/20?l/N`030?mIR`2D04X0U01:00D0U01:
0P2304X<08/0BP`0L`110P1Z03T:06X0@@H0HP0i1P1R044205X0>@040?n1_@3oYKd0ojFm0?nU_@<0
oj[51`3o_/D50?o>c@H0olkE1P3ob]D70?o6c@<0olK5103o[[d00`3o03T0o`110?l0@@0F0?l0@@<0
mP111P3^04X70?H0BQP0kP1:00L0[0bL0:@<W02T39`0Y0bL0?ooo`0006X0001c00<0001R0P0006X3
09`8W0@0W0RD1P2T29@509`8U340oooo000j0?ooo`@0oeVD00<0oeVL0?mYW03oJI`0103oJI`20?H@
N`80oaak0P3o97/00`3o;7/0oeV;0?mIR`0609@0BP@0P`1:2P2;04X<07<0@@`0JP111@1R03T80680
@@0305X0>@3oPKd0ojFm00D0ojFm1`3o_/D50?o>c@L0olkE1P3^a]D70?o6c@P0ojjm6`3o044=0?H0
BQL0kP1:0P2/39`30:@<W0030?ooo`0006X0001Z00@0001R0P0006X209`8W0D0W0RD1@2T29@509`8
U340oooo000j0?ooo`@0oeVD1`3oJI`0103f47/0mPak0?lLN`3o77/20?lTN`040?l/N`3oFH/0ogV;
0?miR`D0U01:1@2304X908/0BP`0L`11301Z04440680>@T0HP1100<0oh6m0?nU_@3oYKd01@3oYKd6
0?o2a@H0omK=1`3od]D60>k6e@@0olK=103f]/d60?n^_@80oi6d00<0oif/0?l0@@3o0440603o044=
0?H0BQH0kP1:00<0U0RL0:`<W02T39`00P2T39`0103oool0Y0RL0000FP0006X30000HP80001Z0P2L
29`509`8U0D0Y0RD1@2L29@a0?ooo`00>P3oool40?mIU0030?mUU03oJI`0ofVL00<0ofVL0P3f47/2
0?lLN`80obAk00<0obak0?mIR`3oFH/00P3oNH/409@0BPL0P`1:1`2;04X=07<0@@`0JP110P1R03T:
0680@@030?me]03oYKd0ojFm00D0ojFm1`3o`/D60?oFc@L0om;E1P3^a]D80?Jfc@@0ojjm103oTK@2
0?nM[1T0o`113@3f04XE0>h0BP80U0RL102T39`0103oool0Y0RL0:@8W00005X40000HP030000JP2L
29`0W0RL00D0W0RD00<0W0BD0:@8U02T29@00P2T29@509`8U340oooo000j0?ooo`<0oeVD0P3oII@5
0?mYW080mQ1k0P3o77/20?lTN`030?l/N`3oFH/0oeV;00<0ogV;0`2D04X908<0BPD0R`1:301c044=
06X0@@030680>@1R0440HP1100P0HP110P3oMK@30?nQ]0@0ojFm1`3o`/D60?oFc@L0k];N1`35/]h7
0?Jfc@80ojjm1`3oTK@00`3oWJ`0ohF/0?l0@@0G0?l0@@d0mP1:503^04X409@8W0@0Y0bL0P2T29`2
0000FP<0001R0P0006X00`2L29`0W0RD09`8U00309`8U080W0BD0`2T29@509`8U340oooo000j0?oo
o`80oeVD0`3oII@50?mYW0040?H@N`3o77/0oaak0?lLN`80obAk0`3oFH/30?miR`80U01:2`2304X3
08/0BPd0L`11301Z044:0680@@@0ogFd1P3oXK@70?o2a@L0onK=1P3^d]h80<FbgPL0m[K=2@3oTK@4
0?n5[1H0o`113P3f04XC0>h0BPD0U0RL0`2T39`30:@8W0030000FP000680001R0080001R00<0001Z
09`8W02L29@0102L29@309`4U080Y0RD1@2L29@a0?ooo`00>P3oool00`3oFI@0ofFD0?mUU0020?mU
U0@0ofVL0P3f47/20?lLN`<0obAk0P3oFH/40?miR`030?meW02D04X0P`1:00/0P`1:0P2;04X=07<0
@@`0JP112@1R0440103oKJ`0ogFd0?me]03oMK@70?nQ]0L0olZm1P3oi/d70<F^iPP0ReWV203VVLd6
0?nA]0<0ogFd0`3oQJ`00`3oJJ@0o`110?l0@@0D0?l0@@d0mP1:4P3^04X709@8W080Y0bL0`2T29`2
0000FP<0001R0P0006X509`8U0<0W0BD0P2T29@509`8U340oooo000j0?ooo`D0ofFD103oJI`0103f
47/0oaQk0?lLN`3o77/20?lTN`<0oeV;0`3oNH/20?meW0h0P`1:3@1c044=06X0@@L0HP11103oKJ`2
0?me]0H0oj6d1`3ob[d30?oVc@@0ooK51`35[^H808]IiPP0iYW=103oTK@50?me]080ohF/0`3oJJ@E
0?l0@@d0mP1:4@3^04X909@8W0030:@<W02T29`0Y0RL0080Y0RL00<0001J0000HP0006800P000680
0`0006X0W0RD09`8U00309`8U0@0W0BD00<0Y0RD09`8U02L29@00`2L29@a0?ooo`00>@3oool60?mU
U0@0ofVL00@0mQ1k0?lHN`3o77/0oaak0P3o97/30?mIR`<0ogV;103oMI`<08<0BPH0N`111`1c044=
06X0@@H0HP111P3oKJ`70?nQ]0H0olZm1`3om/D409A4iP<0o`QJ0`2d08<00`000:@0803E0200e@03
0200e@P0iYW=0P3oTK@70?me]0030?n5[03oJJ@0ofVT00@0ofVT4`3o044>0?H0BPl0kP1:2`2D29`5
0:@8W0050000FP000680001R0000HP0006X01@2L29@509`4U0D0W0RD<@3oool003X0oooo1@3oII@3
0?mYW0030?H@N`3o67/0oaak0080oaak00<0obAk0?llP`3oFH/00P3oFH/20?miR`030?m@U03oMI`0
ogFL0080ogFL00<0e@B;08<0BP2304X02@2304X<07/0@@d0JP111@1R04400`3oKJ@0off/0?m][005
0?m][0H0oj6d1`3oc[d50?ofa@030?ooa@1J0;d0FP2m00H0o`QJ102d08<209@000030000Y00P0=D0
803E00P0aG7=2@3oMK@70?mYY0030?mEY03o0440o`110100o`113P3f04X>0>h0BP0309`<W02D29`0
U0RL00T0U0RL1@2T29`00`0005X0001R0000FP020000HP030000JP2L29@0W0RD0080W0RD1@2L19@5
09`8U340oooo000j0?ooo`D0ofFD0`3oJI`0103f47/0oaQk0?lLN`3o77/20?lTN`040?llP`3oFH/0
oeV;0?mIR`80ogV;00<0oe2D0?meW03oMI`00P3oMI`00`3E08<0e@B;08<0BP0808<0BPd0N`113@1Z
04440680@@<0offT1@3oKJ`70?nQ]0L0oljm0`3om/D20?ooa@T0o`QJ1@2d08<409@000P0aG7=1P3o
MK@40?mI[0D0ofVT0`3oEJ@B0?l0@@d0mP1:303^04X00`1k19`0W0bL09`<W00;09@8W00309@4W02T
29`0Y0RL0080Y0RL00<0W0RL0000FP0005X00P0006800`0006X0W0RD09`8U00209`8U0D0W0BD00<0
U0BD09`8U02L29@00P2L29@a0?ooo`00>P3oool50?mUU0<0ofVL0P3o67/20?lLN`030?lTN`3o?8<0
ocb30080oeV;0P3oNH/20?m@U0<0ogFL0P3E08<00`3oOI`0ohFL08<0BP0708<0BPd0N`113@1Z0442
0680@@H0offT103oKJ`70?nQ]0L0oljm00D0ooK50?ooa@3oolD0ooZm0?oF]0090?l8FPH0]0230`2D
00040:a<a@@0aG7=0`3oMK@70?mI[0@0ofVT1P3oEJ@@0?l0@@h0mP1:2P3^04X307/4W00309`<W02D
29`0U0RL00T0U0RL0P2D19`30:@8W00409`8W0000580001J0000FP80001R00@0001Z09`8U02L29@0
W0RD1@2L19@209@4U0<0W0RD<@3oool003X0oooo1@3oII@20?mYW0030?H@N`3o67/0oaQk0080oaak
00<0obAk0?llP`3oFH/00P3oFH/0103oNH/0oe2D0?m@U03oD9@20?meW0<0e@2300@0ogfL0?n5W03o
QI`0ohFL1P2304X<07/0@@h0JP1100<0HP110?m]Y03oKJ@01P3oKJ@20?m][0L0oj6d1`3oc[d30?oo
a@030?oj_@3oe[@0o`QJ00T0o`QJ1P2d08<00`3o0440U00009@000080:a<a@X0oeV/0`3oJJ@70?mE
Y0030?mEW03o0440o`1100d0o`113P3f04X80>h0BPD0N`BL302D29`309@4W080Y0RL0P2L29`01@00
0580001J0000HP000680001Z00<0W0RD1@2L19@309@4U080W0RD<@3oool003X0oooo1@3oII@20?mY
W080oaQk0`3o77/20?llP`<0oeV;00@0ogV;0?m@U03oD9@0oe2D0P3oMI`20=D0P`80ogfL103oQI`4
08<0BPd0N`113@1Z04420?m0W0T0offT203oXK@30?o>_@@0omZd00@0ooo50?oj_@3on[d0omJd2`3o
25X70;@0P`030?l0@@2D0000[4c500P0[4c52@3oFJ`20?mYY0P0oeFT00<0odRL0?mEW03o04403@3o
044>0?H0BPH0kP1:201k19`;09@8W0<0U0BL0P2T29`209`8W0030000DP0005X0001J0080001R0`2L
29@509`4U0@0U0BD00<0W0RD0?ooo`3oool0;`3oool003X0oooo1@3oII@20?mYW080oaQk0P3o77/0
0`3o97/0ocb30?llP`030?mIR`@0oe2D00<0ogFL0=D0P`3E08<0103oOI`20?n5W080ogfD0`2304X=
07/0@@X0JP1100@0odbD0?m0W03o@9`0od2L2P3oKJ@70?nQ[0L0omZd0`3on[d00`3oe[@0oeVL0?l8
FP0:0?l8FPL0]0230P3o04490:a<a@T0oeV/00<0ofVT0?mEY03oEJ@01P3oEJ@20?m8W080oeFL0`23
19`;0?l0@@h0mP1:103^04X00`1k1:@0N`BL07/4W00707/4W0X0U0RL102D19`01P2T29`0W0RL09`8
W02L29`0001B0000FP80001R00<0001Z09`8U02L29@01@2L19@509@4U340oooo000j0?ooo`D0ofFD
00@0ofVL0?lHN`3o67/0oaQk0P3o77/30?llP`80oeV;1@3oD9@30=D0P`@0ogfL0P3oQI`30?mmU080
P`1:301k044806X0@@@0odbD0`3o@9`90?m]Y0P0oj6/1@3of[@01@3oe[@0ooZm0?oj_@3on[d0omJd
0080oeVL2`3o25X80;@0P`040?l0@@2T9;@0Y2Bd0:@T]0H0[4c52@3oFJ`80?mEY0<0odRL0P3oEI`7
08<4W0L0o`113P3f04X20>h0BP80FP2T2P1k19`:09@8W0D0U0BL102L29`20000FP80001R0P2L29@5
09`4U0D0U0BD<@3oool003X0oooo1@3oII@00`3oJI`0oaQk0?lHN`030?lLN`80ocb30`3oFH/40?m@
U0<0e@231@3oOI`20?n5W0@0ogfD3@1k044506X0@@P0odbD00<0od2L0?m]Y03oKJ@01`3oKJ@90?nQ
[080omZd00@0omjd0?oF]03oe[@0omJd0P3on[d0103oe[@0ohVL0?mIW03oFI`:0?l8FPT0]02300<0
o`110:@T]02T9;@00`2T9;@40:a<a@H0oeV/103o@:@60?mEY0D0odRL00<0oeFL08<4W02319`01P23
19`307<0W0<0o`113P3f04X305X0Y080HP2L2P1k19`809@8W0H0U0BL102L29`20000FP80001R00<0
001Z09`8U02L19@0102L19@509@4U340oooo000j0?ooo`D0ofFD00<0ofVL0?lHN`3o67/00P3o77/3
0?llP`80oeV;00<0ocB;0?m@U03oD9@00P3oD9@00`3E07/0e@230?mmW0050?mmW0030?n5W03oOI@0
ogfD00@0ogfD103oPI@00`3oII@0N`1107/0@@0507/0@@80JP110`3oFI@80?m<U0030?m0W03oKJ@0
offT00L0offT203oYJ`20?oN]0D0omJd00@0ooZm0?mIW03oYJ@0ohVL0P3oFI`70?l8FP<0od2D00<0
a@R;0;@0P`2d08<01`2d08<70:@T]080[4c50`3oFJ`70?m0Y0D0oeFT1P3oB9`00`3oEI`0odRL07<0
W00608<4W0L0L`2L1@1B09@00`1108/0>@2D03T0U00403T0U0<0FP2T0`1R09`;07/4W0L0U0RL1`2D
19`309`8W0030000DP0005X0001J0080001R00<0W0RD09`4U02L19@00`2L19@509@4U340oooo000j
0?ooo`H0ofFD0P3o67/20?lLN`<0ocb30P3oFH/0103o=8/0oe2D0?m@U03oD9@20=D0N`030?miW03o
OI`0ogfL00@0ogfL00<0ohFL0?mmU03oOI@01@3oOI@30?n1U0D0ofFD203oFI@80?m<U0X0offT1`3o
WJ`90?oF]0030?nUY03oRI`0oeVL0080oeVL0`3o25X70?m0U080a@R;202d08<90:@T]0X0od2T103o
EJ@70?m8W0030?mEW03oB9`0L`2L0080L`2L102319`707<0W0H0DP2D1P0i09@205X0Y0D0HP2L2P1k
19`709@8W0P0U0BL0`2L29`20000FP80001R00<0W0RD09`4U02L19@00`2L19@509@4U340oooo000j
0?ooo`D0ofFD0`3o67/00`3o77/0obR30?llP`020?llP`030?mIR`3o=8/0ocB;00<0oe2D0P3E07/0
0`3oNI`0ogfL0?mmW0040?mmW0P0ogfD0`3oPI@60?mUU0P0oeVD1`3oC9@20?maW0L0offT203oWJ`6
0?oF]0030?oB[03oe[@0ojFT0080ohVL0P3oA9`;0?m0U080a@R;202d08<20:`DY0P0Y2Bd2@3o@:@3
0?mEY0X0odRL101c09`308<4W0L0L`2L1`1B09@50580W0L0HP2L2`1k19`609@8W0P0U0BL0`2L29`0
1@000580001J0000FP000680001J00D0W0BD1@2D19@a0?ooo`00>P3oool50?mUU080oaQk0P3o77/0
0`3o:8<0ocb30?llP`020?mIR`80ocB;0P3oD9@20=D0N`80ogVL1P3oOI`00`3oNI@0ogfD0?mmU005
0?mmU080oh6D1`3oII@90?mIU0H0odbD0`3oLI`60?m]Y0P0oif/103oe[@20?oB[0040?oF]03oYJ@0
ojFT0?n9W0<0odBL2`3o@9@30<D8R`L0]023102/5:@60:@T]0T0od2T0P3oEJ@90?m8W0030?llW03o
B9`0odRL00D0L`2L00<0P`BL07<0W01c09`01P1c09`60580U0H0DP2L1`1R09`:07/4W0H0U0RL2@2D
19`209`8W00309`8U00005X0001J0080001R1@2L19@00`2D19@0oooo09@4U00209@4U340oooo000j
0?ooo`D0ofFD0P3o67/00`3o77/0obR30?lXP`020?llP`050?mIR`3o=8/0ocB;0?ldR`3oD9@00`3E
07/20?miW0D0ogfL0P3oNI@80?mmU0030?n1U03oII@0ofFD00H0ofFD203oFI@50?m<U0H0og6L0`3o
KJ@80?nM[0<0omJd103odZ`20?nUY080ohVL0`3oA9`;0?m0U0<0a@R;1`2d08<50:`DY0D0Y2Bd2@3o
@:@00`3oEJ@0odRL0?m8W0070?m8W080ocbL0P3oB9`>07<0W0H0DP2D1P1B09`70680W0X0N`BL00<0
P`2L09@8W02D29`00`2D29`909@4W080W0RL00H0W0RD0000FP0005X0001J0000HP0005X409`4U0D0
U0BD<@3oool003X0oooo1@3oII@20?lHN`030?lLN`3o:8<0ocb30080ocb300D0oeV;0?ldR`3o=8/0
ocB;0?m@U0020=D0N`<0ogVL1@3oOI`20?miU0P0ogfD00<0oh6D0?mUU03oII@01P3oII@90?mIU0@0
odbD1`3oLI`20?m]Y0P0oif/00<0omJd0?oB[03odZ`00`3odZ`30?nUY0030?n9W03oA9`0odBL0080
odBL2`3o@9@40<D8R`H0]0231`2/5:@30:@T]0T0od2T2@3oB9`30?llW080odRL1`1c09`00`1Z09`0
L`2L07<0W00407<0W0L0DP2D1P1B09`70680W0T0N`BL00<0P`2L09@8W02D29`00P2D29`;09@4W007
09`8W02L29@0W0RD0000DP0005X0001R0000FP0409`4U0D0U0BD<@3oool003X0oooo103oII@30?lH
N`80obR30`3o?8<40?ldR`<0e@1k103oNI`30?mmW0@0ogVD1`3oOI@:0?mUU0T0oeVD0`3oC9@80?ma
W0P0oif/1P3odZ`00`3ocZ@0ojFT0?nUY0020?n9W0@0odBL2`3o@9@50<D8R`D0]0232@2/5:@00`2T
9;@0od2T0?m0Y0030?m0Y0D0mS2L1`3oB9`40?llW080odRL1`1c09`306X0W0@0L`2L1`1B09@60580
W0L0HP2L201k19`308<0W0<0U0RL2`2D19`409`8U080001J00<0001R09`4U02L19@00P2L19@509@4
U340oooo000j0?ooo`@0ofFD0P3o67/00`3o77/0obR30?lXP`020?llP`@0ocB;0`3E07/50?miW0<0
ogfL103oNI@70?mmU0030?m]U03oII@0ofFD00L0ofFD2@3oFI@20?m<U0T0og6L203oXJ@50?oB[080
oljT00<0ojFT0?n9W03oRI`01@3oA9`;0?m0U0D0a@R;1@2d08<:0:`DY0X0mS2L1P3oB9`60?llW003
0?m8W01c09`0L`2L00D0L`2L1@1Z09`207<0W0L0DP2D1`1B09`50680W080JP2L1`1k19`308<0W0<0
U0RL2`2D19`0202;19`0W0RD09`8U02L29@0001B0000FP000680001J0`2L19@509@4U340oooo000k
0?ooo`<0ofFD0P3o67/30?lXP`80ocb3103o=8/00`3E07<0e@1k0?miW0050?miW080ogfL1@3oNI@7
0?mmU0030?m]U03oII@0ofFD00L0ofFD2P3oFI@00`3oC9@0og6L0?maW0070?maW0P0oj6T103odZ`3
0?o>Y0030?nUY03oRI`0odBL00D0odBL2`3o@9@60<D8R`@0]0232`2/5:@90?H`W0D0odRL1`3o?9`0
0`3oB9`0L`2L07<0W00507<0W0L0JP2L201B09@60580W0@0HP2L0`1Z09`607/4W0D0P`2L0P2D29`;
09@4W080R`BL0`2L29@30000FP<0W0BD1@2D19@a0?ooo`00>`3oool20?mUU0<0oaQk0P3o:8<20?ll
P`040?lLP`3o=8/0ocB;0?ldR`80e@1c00<0ogFL0?miW03oNI`0103oNI`20?mmW0H0ogVD1@3oOI@3
0?m]U0T0ofFD2@3oFI@:0?maW0L0oj6T0`3odZ`50?o>Y080ohVL00<0ohfD0?m4W03oA9`00`3oA9`;
0?m0U0H0a@R;1@2d08<00`2m49`0[1BT0:`DY0070:`DY0X0mS2L0`3oB9`80?llW0030?m8W03o@9@0
JP2L00D0L`2L201Z09`205X0U0D0DP2D1`1B09`20680W0D0JP2L1@1k19`508<0W080U0RL2`2D19`2
08/4W0<0W0RD00@0001B0000FP000680001J0P2L19@509@4U340oooo000k0?ooo`80ofFD0P3o67/3
0?lXP`80ocb300@0oab30?ldR`3o=8/0ocB;0P3E07<00`3oMI`0ogVL0?miW0040?miW0030?mmW03o
NI@0ogVD00D0ogVD1@3oOI@30?m]U0X0ofFD203oFI@20?meW0L0og6L203oXJ@20?oB[0D0oljT00<0
ohVL0?n=U03oSI@01P3oA9`;0?m0U0L0a@R;102d08<30;d@W0L0[1BT2P3f<9`20?m8W0T0ocbL0P3o
@9@206X0W0D0L`2L1`1Z09`505X0U080DP2D1`1B09`00`1R09`0JP2L06X0W00406X0W0D0N`BL1P23
09`00`2D29`0U0BL09@4W00909@4W0<0R`BL0P2L29@0102L19@0001J0000FP0005X209`4U0D0U0BD
<@3oool003/0oooo0P3oII@20?lHN`<0obR300<0ocb30?lLP`3o78<00P3o=8/30=D0L`030?meW03o
NI`0ogVL00@0ogVL203oNI@50?mmU0@0offD2P3oII@70?mIU0@0ogFL1@3oLI`80?nQY0030?oB[03o
cZ@0oljT00<0oljT00@0olJT0?n9W03oSI@0ohfD1P3oA9`;0?m0U0L0a@R;102d08<40;d@W0H0[1BT
2P3f<9`00`3oB9`0ocbL0?llW0080?llW0030?lhW03o@9@0JP2L0080JP2L101c09`806X0W0H0FP2D
1`1B09`806X0W0<0N`BL1`2309`<09@4W0@0R`BL00<0W0RD09`4U00005800P0005X209`4U0D0U0BD
<@3oool003/0oooo0P3oII@00`3o67/0oaak0?lXP`020?lXP`030?llP`3o78<0oab30080ocB;0P3E
07<30?meW0D0ogVL2@3oNI@30?mmU0D0offD2P3oII@60?mIU0H0ogFL103oLI`70?nQY0H0oljT0P3o
aZ@00`3oRI`0ohfD0?m4W0060?m4W0/0od2D203528/30;@0P`H0_A2L102/5:@:0?H`W0X0ocbL0P3o
>9`20?m0U0@0JP2L0P1c09`806X0W0L0FP2D1`1J09`706X0W0<0N`BL202309`;09@4W0@0R`BL00<0
W0RD09`4U02L19@00`0005X00`2L19@0U0BD09@4U00309@4U340oooo000k0?ooo`040?mUU03o67/0
oaQk0?lLN`80obR300D0ocb30?lLP`3o78<0oab30?ldR`020=D0L`@0ogFL1@3oNI`90?miU0<0ogfD
1P3oKI@:0?mUU0D0oeVD203oMI`20?maW0L0oj6T1@3ocZ@20?o6Y0030?n9W03oSI@0ohfD0080ocRL
1@3oA9`;0?m0U0T0a@R;0P2d08<70;d@W0<0[1BT1`3f<9`40?HXW0P0ocbL0`3o>9`20?m0U0D0JP2L
00<0L`2L06X0W01Z09`01P1Z09`705X0U0L0FP2L201Z09`00`1k19`0P`2L08<0W00808<0W0X0U0BL
1@2;19`209`4U080001B00<0001J09`4U02D19@0102D19@a0?ooo`00>`3oool0103oII@0oaQk0?lL
N`3o77/20?lXP`050?llP`3o78<0oab30?lLP`3o=8/00P3E07<40?meW0@0ogVL2P3oNI@30?mmU0H0
offD2`3oII@40?mIU0T0ogFL203oXJ@40?o>Y0<0olJT0P3oSI@00`3oVI@0ocRL0?lhW0020?lhW0<0
odBL2`3o@9@90<D8R`80]0232@2m49`00`2/5:@0mS2L0?H`W0020?H`W0L0mRRL1`3o?9`40?lhW080
od2D3`1Z09`705X0U0L0FP2L1`1Z09`00`1k19`0P`2L08<0W00808<0W0T0U0BL1P2;19`309`4U003
0000DP0005X0W0BD0080U0BD00<0oooo09@4U02D19@0<@3oool003/0oooo00<0ofFD0?lHN`3o77/0
0`3o:8<40?lLP`80e@1c1@3oMI`40?miW0/0ogVD00<0ogfD0?m]U03oKI@01P3oKI@:0?mUU0<0oeVD
2P3oMI`80?nQY0<0oljT0`3oaZ@30?n=U0030?nIU03o>9`0ocRL00@0ocRL303o@9@:0<D8R`030;@0
P`2m49`0_A2L00P0_A2L2`3f:9`60?llW0H0ocRL00<0od2D06X0W01Z09`03@1Z09`705X0U0L0FP2L
1`1Z09`<08<0W0P0U0BL1`2;19`209`4U0030000BP000580001J00D0U0BD<@3oool003/0oooo00<0
ofFD0?lLN`3o77/00`3o:8<30?lLP`80e@1c00<000000?meW03oMI`00`3oMI`30?miW0`0ogVD00<0
ogfD0?m]U03oKI@01P3oKI@;0?mUU080oeVD2P3oMI`70?nQY0<0oljT103oaZ@20?n=U080oiVD1P3o
>9`30?l/U0T0od2D2P3528/00`2d08<0_A2L0;d@W0080;d@W0/0mRRL1@3o?9`70?lhW0030?m0U01Z
09`0JP2L00d0JP2L1`1J09@705X0W0P0JP2L302309`709@4W0P0R`BL0P2L19@20000DPD0U0BD<@3o
ool003/0oooo00<0oaQk0?lLN`3o77/00P3o:8<40?lLP`030=D0L`000000og6L00H0ogFL0P3oNI`<
0?miU0X0offD2`3oII@00`3oFI@0ogFL0?meW0070?meW0P0oj6T0P3ocZ@40?o6Y0040?nnW03oSI@0
ohfD0?nIU0L0ocRL1P3o;9@60?m0U0/0a@R;2P2m49`;0?HXW0@0ocbL203o>9`00`3o@9@0ocbD0680
W00>06X0W0L0FP2D1`1J09`806X0W0/0P`2L1`2D19`808/4W080W0BD00<0001:0000DP0005X0102D
19@a0?ooo`00>`3oool30?lLN`80obR30`3o78<20=D0L`030000003oLI`0ogFL00D0ogFL0P3oNI`<
0?miU0030?maU03oKI@0offD00L0offD2`3oII@:0?meW0P0oj6T00<0oljT0?o6Y03oaZ@00P3oaZ@2
0?nnW0030?n=U03oVI@0oiVD00L0ocRL2@3o;9@30?m0U0/0a@R;2P2m49`;0?HXW0<0ocbL2@3o>9`0
103o@9@0ocbD0680W01R09`=06X0W0L0FP2D1`1J09`806X0W0`0P`2L1P2D19`908/4W080W0BD0P00
058409@4U340oooo000k0?ooo`80oaak0P3o:8<0103f47/0oab30?lLP`3o78<20=D0L`80og6L1P3o
MI`00`3oNI`0ogVD0?miU00;0?miU0030?maU03oKI@0offD00L0offD2`3oII@20?mmW0P0ogFL1`3o
XJ@50?o6Y0<0okjL00<0ohfD0?nIU03oVI@01`3o>9`<0?l/U0/0a@R;0P3549@80;d@W0/0mRRL0P3o
?9`:0?lhW080ocbD0`1R09`<06X0W0L0FP2D201J09`806X0W0/0P`2L1P2D19`:08/4W00309`4U000
04X0001B00@0U0BD<@3oool003X0oooo0`3o77/20?lXP`030?H@N`3o78<0oab30080e@1c0`3oLI`6
0?meW0030?miW03oNI@0ogVD00X0ogVD0`3oLI@90?m]U0X0ofFD103oOI`50?meW0P0oj6T103oaZ@4
0?nnW080oiVD203o>9`<0?l/U0030=D@R`3528/0a@R;00P0a@R;103549@60;d@W0/0mRRL00<0ocbL
0?lhW03o>9`0203o>9`20?ldW0030?llU01R09`0HP2L0080HP2L301Z09`20680U0D0FP2D1`1J09`8
06X0W0`0P`2L1@2D19`:08/4W00409`4U02D19@0001B0000DP<0U0BD<@3oool003X0oooo0`3o77/0
0`3o:8<0mQ1k0?H@N`020?lLP`80e@1c0`3oLI`60?meW0d0ogVD0`3oLI@:0?m]U0T0ofFD1P3oOI`3
0?meW0P0oj6T0`3oaZ@50?nnW080oiVD203o>9`<0?l/U080eA2;2@3528/50<D@U0D0_A2L2`3f:9`:
0?lhW0<0ocBL0P3o?9@40680W0/0JP2L1@1R09@205X0U0L0FP2L2@1Z09`;08<0W0@0U0BL302;19`0
0`2D19@0001:0000DP0309@4U340oooo000j0?ooo`<0oaak00@0obR30?H@N`3f47/0oab30P3E07<4
0?maW0H0ogFL00<0ogFD0?miU03oNI@02P3oNI@40?maU0X0offD1`3oII@90?mmW0T0oj6T0P3oaZ@5
0?nnW0<0oiVD203o>9`<0?l/U0<0eA2;203528/70<D@U0<0_A2L203f:9`40>hTW0P0ocRL103o=9`2
0?llU0D0HP2L2P1Z09`70680U0P0HP2L201Z09`<08<0W0<0U0BL302;19`209@4U0040000DP2D19@0
U0BD09@4U340oooo000j0?ooo`80oaak00L0obR30?H@N`3f47/0mQ1k0?lLP`3E07<0Y01:00@0og6L
1@3oMI`20?meU0/0ogVD1@3oLI@;0?m]U0H0ofFD2@3oOI`80?nQY080olJT1P3o_Y`20?nIU080oc2D
1`3o>9`<0?l/U0@0eA2;1`3528/90<D@U0030;d@W03f:9`0mRRL0080mRRL203^99`70?lhW0D0ocBL
0P3o?9@60680W0X0JP2L1`1R09@70680W0T0JP2L2`2309`309@4W0`0R`BL00@0R`BD09@4U00004X0
001B0P2D19@a0?ooo`00>P3oool20?lLN`040?lXP`3f47/0mQ1k0?H@N`80e@1c1P3oLI`40?meW080
ogFD2`3oNI@60?maU0/0offD1@3oII@90?mmW0P0oj6T00<0olJT0?nnW03o_Y`0103o_Y`00`3o]Y`0
oiVD0?nIU0030?l`U0H0ocRL303o;9@50=D@R`H0a@R;2P3549@<0>hTW0H0ocRL1`3o=9`00`3o?9@0
HP2L0680W0050680W0T0JP2L1`1R09@80680W0P0JP2L302309`209@4W0`0R`BL00@0R`BD09@4U02D
19@0001B0P2D19@a0?ooo`00>@3oool30?lLN`<0mQ1k0P3E07<00`2T04X0og6L0?maW0040?maW0<0
ogFL103oMI@:0?miU0H0og6D303oKI@30?mUU0T0ogfL2@3oXJ@60?nnW080okJL00<0oiVD0?nUU03o
<9@00`3o<9@50?lhW0`0obbD1P3E48/50<D8R`/0aA2D2`3^99`50?lhW0P0ocBL00<0ocbD0680W01R
09`01`1R09`706X0W0L0HP2D201R09`806X0W00307<0W02309`0P`2L00T0P`2L0P2D19`<08/4W080
R`BD00@0U0BD0000DP000580U0BD<@3oool003T0oooo0`3o77/30?H@N`030=D0JP2T04X0offD00H0
og6L0`3oMI`40?meU0T0ogVD203oLI@<0?m]U080ofFD2@3oOI`80?nQY0H0okjL0P3o]Y`00`3oVI@0
ojFD0?l`U0060?l`U0<0ocRL303o;9@70=D@R`@0a@R;2`3549@;0>hTW0@0ocRL2@3o=9`00`3o?9@0
ocRD0680W0090680W0D0JP2L201R09@70680W0L0JP2L0P1c09`<08<0W00309@4W02;19`0R`BL00X0
R`BL0P2;19@209@4U0030000DP3oool0oooo0300oooo000i0?ooo`80oaak0`3f47/20=D0JP030:@0
BP3oKI@0og6L00D0og6L0P3oMI`50?meU0T0ogVD203oLI@=0?m]U0030?mUU03oOI`0ogfL00L0ogfL
1P3oXJ@20?nQW0D0okjL0`3o]Y`00`3oVI@0ojFD0?l`U0070?l`U080ocRL303o;9@80=D@R`<0a@R;
2`3549@;0>hTW0<0ocRL2P3o=9`00`3o?9@0ocRD05X0W00:0680W0D0JP2L1`1R09@80680W0D0JP2L
101c09`;08<0W00309@4W02;19`0R`BL00X0R`BL0`2;19@00`2D19@0001B0000DP0a0?ooo`00>@3o
ool20?lLN`<0mQ1k00@0e@1Z0:@0BP3oKI@0offD1P3oLI`20?meW0D0ogFD203oNI@:0?maU0`0offD
2@3oOI`40?nQY0D0oj6L103o_Y`40?nfW080ojFD2@3o<9@=0?l/U0T0eA2;0P3528/;0<D@U0/0kRBL
0P3o>9`;0?ldW080ocRD0P1J09`;0680W0<0JP2L1`1R09@80680W0@0JP2L1@1c09`;08<0W0`0R`BL
102;19@209@4U0030000DP3oool0oooo02l0oooo000h0?ooo`80oaak00@0kPQk0?H@N`3f47/0e@1Z
103oKI@60?maW0030?meW03oMI@0ogFD00D0ogFD1`3oNI@00`3oMI@0og6D0?maU0070?maU0`0offD
103oPI`50?mmW080oj6T1`3oXI`30?nnW0@0okJL0P3oYI@:0?l`U080obBD2`3o;9@:0=D@R`030<D8
R`3549@0aA2D00T0aA2D2`3^99`00`3o>9`0ocBL0?ldW00:0?ldW0030?l`U03o>9@0FP2L0080FP2L
301R09`00`1Z09`0HP2D0680U0050680U0T0HP2L0P1Z09`707<0W0/0P`2L2`2;19`508/4U00309@4
U0000580001B0300oooo000h0?ooo`80oaak00D0kPQk0?H@N`3f47/0e@1Z0:@0BP040?m]U0D0og6L
00<0ogFL0?meU03oMI@01@3oMI@70?miU080ogFD203oLI@<0?m]U0P0oh6L2@3oXI`30?nnW0D0okJL
0P3oYI@:0?l`U0@0obBD2@3o;9@;0=D@R`/0aA2D2`3^99`<0?ldW080oc2D0P3o>9@305X0W0`0HP2L
201R09@80680W00306X0W01c09`0L`2L00H0L`2L302309`:08/4W0D0R`BD0P3oool00`000580oooo
0?ooo`0^0?ooo`00>03oool0103o77/0kPQk0>h8N`3f47/20=D0JPD0offD1@3oLI`80?meU0H0ogVD
0`3oMI@80?maU0030?meU03oKI@0offD00P0offD2@3oPI`90?nQW080okjL1@3o]Y`00`3o/Y`0ojFD
0?nUU00:0?l`U0H0obBD1`3o;9@;0=D@R`<0eABD203549@90>hTW0<0mRBD2P3o=9`30?l`U080ocRD
101J09`>0680W0D0HP2D201R09`:07<0W0/0P`2L2P2;19`508/4U080oooo00<0001B0?ooo`3oool0
;P3oool003P0oooo00H0oaak0>h8N`3^27/0mQ1k0?ooo`2T04X50?m]U0D0og6L2@3oMI@50?miU0@0
ogFD1`3oLI@20?meU0T0offD2@3oPI`90?nQW0030?nnW03o]Y`0okJL00<0okJL0P3o/Y`20?nUU0X0
oc2D203o99@50?l/U0/0eA2;1@3E59@60<D@U0L0kRBL1@3f99@90?ldW0@0oc2D0P3o>9@505X0W100
HP2L0P1R09@90680W0T0L`2L302309`908/4W0D0R`BD0`3oool00`000580oooo0?ooo`0]0?ooo`00
=`3oool0103o77/0kPQk0>h8N`3^27/20=D0JPH0offD1@3oLI`90?meU0@0ogVD1@3oMI@70?maU0<0
ogFD1`3oKI@:0?n1W0T0oj6L1@3o]Y`30?nbW080ojFD00<0obRD0?l`U03o<9@01`3o<9@:0?lTU0<0
obbD2`3E48/70=DDU0@0aA2D1@3^99`70?HTU0P0ocBL1P3o<9@00`3o>9@0FP2L05X0W00405X0W1X0
HP2L2@1c09`<08<0W0T0R`BL1@2;19@30?ooo`030000DP3oool0oooo02d0oooo000g0?ooo`070?lL
N`3^27/0kPQk0>h8N`3E06X0Y01:0?ooo`050?m]U0@0og6L2P3oMI@40?miU0H0ogFD1@3oLI@50?me
U0H0offD2P3oPI`80?nQW0H0okJL0`3o/Y`20?nUU080obRD203o<9@<0?lTU0`0eA2;2@3E59@20<D@
U0<0kRBL2@3f99@70?ldW0L0oc2D00<0ocRD05X0W01J09`01@1J09`J0680W0T0L`2L302309`708/4
W0H0R`BD<`3oool003L0oooo0`3^27/20=D0JP80oooo1@3oKI@40?maW0X0ogFD0`3oNI@70?meU0D0
og6D1P3oMI@50?m]U0T0oh6L203oXI`00`3oWI`0okJL0?nfW0030?nfW0@0ok:L0P3oYI@30?lXU0L0
oc2D303o99@20>HHU0X0eA2;2`3E59@<0?HTU0H0ocBL203o<9@00`3o>9@0FP2L05X0W00505X0W1X0
HP2L2@1c09`<08<0W0L0R`BL1P2;19@c0?ooo`00=`3oool30>h8N`040<d0JP2T04X0oooo0?ooo`H0
offD0P3oLI`<0?meU080ogVD203oMI@40?maU0L0ogFD0`3oKI@:0?n1W0H0oj6L0`3oWI`40?nfW0D0
ok:L00<0ojFD0?lXU03o:9@00`3o:9@60?l`U0`0obBD0`3V69@90=D@R``0eABD303f99@40?ldW0T0
oc2D00<0ocRD0?ldU01J09`01P1J09`I0680W0X0L`2L302309`608/4W0H0R`BD<`3oool003H0oooo
0`3^27/20<d0JP<0oooo1P3oKI@20?maW0`0ogFD00<0ogVD0?meU03oMI@01`3oMI@40?maU0P0ogFD
0P3oKI@:0?n1W0@0oj6L1@3oWI`30?nfW0H0ok:L00<0ojFD0?lXU03o:9@0103o:9@50?l`U0`0obBD
103V69@80=D@R``0eABD303f99@30?ldW0X0oc2D0P3o=9@705X0W1X0HP2L2@1c09`<08<0W0H0R`BL
1P2;19@c0?ooo`00=P3oool30>h8N`030<d0JP2T04X0oooo0080oooo1P3oKI@20?maW0`0ogFD00<0
ogVD0?meU03oMI@0203oMI@20?maU0X0ogFD2`3oPI`30?nQW0H0oifL0P3o]Y`60?nbW080ojFD1`3o
:9@40?l`U0`0obBD1P3V69@60=D@R``0eABD303f99@20?ldW0/0oc2D00<0obbD0?ldU01J09`01P1J
09`J0680W0T0L`2L3@2309`508/4W0H0R`BD<`3oool003H0oooo0P3^27/20<d0JP@0oooo1P3oKI@0
0`3oLI`0ogFD0?meU00F0?meU080og6D2P3oMI@50?n5W0H0oh6L00<0oj6L0?nMW03oWI`01@3oWI`3
0?nfW0H0ok:L0P3oYI@80?lXU0<0oc2D303o99@70>HHU0D0eA2;303E59@<0?HTU0030?ldW03o<9@0
oc2D00T0oc2D0P3o;9@20?ldU0L0FP2L6@1R09`:07<0W0`0P`2L1@2;19`508/4U3@0oooo000f0?oo
o`80kPQk00<0c@1Z0:@0BP3oool00`3oool60?m]U0030?maW03oMI@0ogFD01L0ogFD00<0og6D0?me
U03oMI@0203oMI@:0?n5W0T0oifL0P3o]Y`60?nbW0030?nZW03oYI@0ojFD00T0obRD0P3o<9@<0?lT
U0P0iQRD103E48/<0=DDU0`0mRBD2`3o<9@30?l/U080ocBD1`1J09`J0680W0T0L`2L3@2309`308/4
W0H0R`BD=03oool003H0oooo00<0kPQk0<d0JP3=06X01@3oool60?m]U2D0ogFD2P3oQI`90?nMW003
0?nfW03o/Y`0ok:L00@0ok:L0P3oZY`00`3oYI@0obRD0?lXU0090?lXU0d0obBD2P3V69@20=D@R``0
eABD3@3f99@90?l`U0@0obbD0P3o=9@705X0W1X0HP2L2P1c09`<08<0W0<0R`BL1P2;19@d0?ooo`00
=P3oool00`3^27/0c@1Z0:@0BP050?ooo`H0offD6P3oMI@20?miU0P0ogFD2`3oQI`90?nMW0H0ok:L
0P3oZY`20?nUU0/0obRD3@3o99@;0>HHU0030=D@R`3E59@0eABD00X0eABD3@3f99@80?l`U0D0obbD
0P3o=9@805X0W1T0HP2L2P1c09`=08<0W080R`BL1P2;19@d0?ooo`00=P3oool20<d0JPL0oooo103o
KI@K0?meU0<0ogVD1`3oMI@:0?n5W0T0oifL1P3o/Y`30?nZW0030?nUU03o99@0obRD00X0obRD3@3o
99@<0>HHU0`0eABD3@3f99@70?l`U0L0obbD00<0ocBD05X0W01J09`01P1J09`E0680W0D0JP2L2@1c
09`=08<0W080R`BL1P2;19@d0?ooo`00=P3oool00`3=06X0oooo0?ooo`060?ooo`@0offD6P3oMI@5
0?miU0H0ogFD2P3oQI`90?nMW0D0ok:L103oZY`00`3oYI@0obBD0?lTU00:0?lXU0d0obBD303V69@4
0=hHU0P0eABD3@3f99@60?l`U0P0obbD00<0ocBD05X0W01J09`01P1J09`A0680W0T0JP2L2P1c09`=
08<0W00308/4W02;19@0R`BD00@0R`BD=03oool003D0oooo00<0c@1Z0?ooo`3oool01`3oool30?m]
U1/0ogFD1P3oNI@40?meU0/0ohFL2@3oWI`40?nbW0D0ojZL00@0ojFD0?lTU03o99@0obBD2@3o:9@=
0?lTU0`0iQRD203N69@40=DDU0d0mRBD1P3o<9@80?l/U0030?ldU01J09`0FP2L00H0FP2L4P1R09`8
06X0W0X0L`2L3@2309`00`2;19`0R`BD08/4U00408/4U3@0oooo000o0?ooo`<0offD6`3oMI@70?mi
U0<0ogFD2P3oQI`90?nMW0@0ok:L1@3oZY`20?nUU0@0obBD203o:9@=0?lTU0`0iQRD303N69@=0?HT
U0D0oc2D2@3o;9@20?ldU0P0FP2L4@1R09`906X0W0X0L`2L302309`708/4U3@0oooo000o0?ooo`80
offD6`3oMI@90?miU080ogFD2P3oQI`90?nMW0<0ok:L1P3oZY`00`3oYI@0obBD0?lTU0040?lTU0L0
obRD3@3o99@<0>HHU0d0gQRD303f99@40?l`U0X0obbD0P3o=9@805X0W140HP2L2@1Z09`:07<0W0`0
P`2L00<0P`2D08/4U02;19@0102;19@d0?ooo`00?`3oool20?m]U1/0ogFD2P3oNI@;0?n5W0T0oifL
0P3o/Y`60?nZW0030?nUW03oYI@0obBD00H0obBD1P3o:9@=0?lTU0`0iQRD3@3N69@<0?HTU0<0oc2D
303o;9@00`3o=9@0FP2L05X0W00605X0W180HP2L201Z09`;07<0W0/0P`2L00<0P`2D08/4U02;19@0
0`2;19@e0?ooo`00?`3oool00`3oKI@0ogFD0?meU00J0?meU0X0ogVD2P3oQI`90?nMW080ok:L1P3o
ZY`20?nUW0030?nUU03o99@0obBD00H0obBD1@3o:9@=0?lTU0`0iQRD3@3N69@<0?HTU080oc2D3@3o
;9@20?ldU0L0FP2L4P1R09`906X0W0X0L`2L2`2309`208<0U0@0R`BD=@3oool003l0oooo00<0offD
0?meU03oMI@06@3oMI@;0?miU0X0ohFL2@3oWI`00`3o/Y`0ojZL0?nZW0040?nZW0<0ojFL00<0ojFD
0?lTU03o99@01`3o99@40?lXU0d0obBD0P3^69@:0>HHU0d0gQRD303f99@00`3o<9@0obbD0?l/U00<
0?l/U080ocBD1`1J09`B0680W0T0JP2L2`1c09`908<0W0<0P`2D102;19@e0?ooo`00?`3oool?0?me
U0030?miU03oMI@0ogFD00X0ogFD2`3oNI@:0?n5W0T0oifL1P3oZY`30?nUW0030?nUU03o99@0obBD
00T0obBD0`3o:9@=0?lTU0@0kQRD203V69@=0=hHU0`0mRBD3`3o;9@20?ldU0P0FP2L4@1R09`906X0
W0/0L`2L2@2309`408<0U0<0R`BD=@3oool00400oooo3P3oMI@20?miU0X0ogFD2`3oNI@;0?n5W0P0
oifL1`3oZY`30?nUW0030?nUU03o99@0obBD00X0obBD0P3o:9@=0?lTU0H0kQRD1P3V69@=0=hHU0d0
mRBD3P3o;9@20?ldU0P0FP2L4P1R09`806X0W0`0L`2L202309`408<0U0<0R`BD=@3oool00400oooo
3@3oMI@30?miU0X0ogFD2`3oNI@:0?n5W0P0oifL00<0oiVL0?nZW03oZY`0103oZY`40?nUW0030?nU
U03o99@0obBD01T0obBD1`3^69@50>HHU0d0gQRD3@3f99@>0?l/U080ocBD201J09`B0680W0T0JP2L
2`1c09`808<0W0D0P`2D0P2;19@e0?ooo`00@03oool=0?meU0@0ogVD2@3oMI@;0?miU0X0ohFL1P3o
WI`30?nIW0D0ojZL1@3oYI`00`3oYI@0mRBD0?lTU00;0?lTU080ob2D303o99@90>hHU0<0iQRD3@3N
69@=0?HTU0h0obbD00<0ocBD05X0W01J09`01`1J09`B0680W0T0JP2L2`1c09`708<0W0H0P`2D0P2;
19@e0?ooo`00@@3oool<0?meU0D0ogVD1`3oMI@<0?miU0X0ohFL1@3oWI`40?nIW0@0ojZL1@3oYI`2
0?nUU080mRBD2`3o99@30?lPU0/0obBD2`3^69@00`3V69@0gQRD0=hHU00;0=hHU0d0mRBD3P3o;9@2
0?ldU0030?l`U01J09`0FP2L00D0FP2L4P1R09`:06X0W0/0L`2L1P2309`708<0U00308/4U03oool0
oooo03<0oooo00110?ooo`/0ogFD1P3oNI@70?meU0/0ogVD2P3oQI`40?nMW0H0oiVL0`3oZY`60?nU
W080ojFD0`3f99@:0?lTU0@0ob2D2P3o99@<0>hHU0d0gQRD3@3f99@>0?l/U0030?ldU03o<9@0oc2D
00P0FP2L4P1R09`906X0W0/0L`2L1P2309`708<0U3H0oooo00110?ooo`/0ogFD1`3oNI@60?meU0/0
ogVD2P3oQI`30?nMW0H0oiVL103oZY`50?nUW0030?nQW03oYI@0ojFD00@0mRBD2@3o99@60?lPU0P0
obBD303^69@=0>HLU0d0mRBD3P3o;9@30?l`U0P0FP2L4P1R09`906X0W0`0L`2L102309`808<0U3H0
oooo00120?ooo`X0ogFD1`3oNI@50?meU0`0ogVD2P3oQI`00`3oWI`0oiVL0?nIW0060?nIW0<0ojZL
1@3oYI`20?nQW0030?nUU03f99@0mRBD00@0mRBD203o99@70?lPU0L0obBD303^69@>0>HLU0`0mRBD
3`3o;9@20?l`U0P0FP2L4P1R09`:06X0W0/0L`2L102309`808<0U3H0oooo00120?ooo`T0ogFD2@3o
NI@40?meU0/0ogVD2P3oQI`:0?nIW080ojZL1@3oYI`30?nQW0030?nUU03f99@0mRBD00D0mRBD1`3o
99@80?lPU0H0obBD303^69@>0>HLU0`0mRBD3`3o;9@30?l`U0P0FP2L4P1R09`906X0W0/0L`2L1023
09`808<0U3H0oooo00120?ooo`T0ogFD2P3oNI@30?meU0/0ogVD2P3oRI`:0?nIW0030?nZW03oYI`0
ojFL00@0ojFL0`3oXI`90?HTU0H0obBD2P3o89@40?lTU0`0kQRD3P3V79@<0?HTU0l0obbD0`3o<9@8
05X0W180HP2L2@1Z09`<07<0W0<0P`2L1`2309@g0?ooo`00@`3oool70?meU0/0ogVD0P3oMI@<0?mi
U0X0ohVL2P3oVI`60?nUW0@0oj6L00<0ojFD0?HTU03f99@01`3f99@50?lTU0/0ob2D0`3o99@<0>hH
U0h0iQbD303f99@?0?l/U0<0oc2D201J09`B0680W0X0JP2L2`1c09`208<0W0P0P`2D=`3oool004<0
oooo1`3oMI@<0?miU0030?meU03oNI@0ogVD00T0ogVD2`3oRI`90?nIW0H0ojFL1@3oXI`;0?HTU0@0
obBD303o89@20?lTU0`0kQRD3P3V79@<0?HTU0l0obbD0`3o<9@805X0W1<0HP2L2@1Z09`<07<0W003
08<0W02309@0P`2D00H0P`2D=`3oool004<0oooo1`3oMI@H0?miU0X0ohVL2P3oVI`50?nUW0H0oj6L
303f99@30?lTU0d0ob2D3@3^69@>0>HLU0/0mRBD0P3o99@?0?l/U0<0oc2D201J09`B0680W0T0JP2L
301c09`00`2309`0P`2D08<0U00508<0U3P0oooo00140?ooo`D0ogFD3@3oNI@20?mmU0X0ogVD2P3o
RI`:0?nIW0D0ojFL1@3oXI`20?ooo``0mRBD0P3o99@=0?lPU0<0kQbD2P3^69@>0>HLU0T0mRBD103o
99@?0?l/U0<0oc2D00<0oooo05X0W01J09`01@1J09`B0680W0X0JP2L2`1c09`808<0U3P0oooo0014
0?ooo`D0ogFD3@3oNI@30?mmU0P0ogVD2`3oRI`:0?nIW0@0ojFL1P3oXI`30?ooo``0mRBD00<0obBD
0?lPU03o89@02`3o89@50>hLU0P0kQRD3P3V79@70?HTU0H0obBD3`3o;9@30?l`U080oooo1P1J09`C
0680W0T0JP2L301c09`708<0U3P0oooo00140?ooo`D0ogFD303oNI@50?mmU0L0ogVD2`3oRI`:0?nI
W0<0ojFL1P3oXI`50?ooo`/0mRBD3P3o89@70>hLU0H0kQRD3P3V79@60?HTU0L0obBD3`3o;9@20?l`
U0<0oooo1P1J09`C0680W0T0JP2L301c09`608<0U3T0oooo00150?ooo`<0ogFD3@3oNI@70?mmU0D0
ogVD2P3oRI`:0?nIW0<0ojFL1P3oXI`70?ooo`X0mRBD0P3f89@<0?lPU0T0kQbD103^69@>0>HLU0@0
mRBD2@3o99@?0?l/U0030?l`U03oool0oooo00<0oooo1P1J09`B0680W0X0JP2L301c09`508<0U3T0
oooo00150?ooo`<0ogFD3@3oNI@80?mmU0<0ogVD2`3oRI`:0?nIW0<0ojFL1@3oXI`90?ooo`T0mRBD
0`3f89@;0?lPU0/0kQbD0P3^69@>0>HLU080mRBD303o99@>0?l/U0L0oooo1@1J09`C0680W0T0JP2L
301c09`508<0U3T0oooo00150?ooo`<0ogFD303oNI@:0?mmU080ogVD2`3oRI`:0?nIW080ojFL1P3o
XI`90?ooo`T0mRBD1@3f89@90?lPU0d0kQbD3P3V79@>0?lTU0h0obbD203oool405X0W1<0HP2L2@1Z
09`<07<0W0@0P`2D>P3oool004H0oooo00<0ogFD0?miU03oNI@02`3oNI@;0?mmU0/0ohVL2`3oVI`0
0`3oYI`0oj6L0?nQW0040?nQW0/0oooo203f99@60?HPU0P0ob2D6`3^79@>0?lTU0d0obbD2@3oool4
05X0W1<0HP2L2P1Z09`<07<0W0<0P`2D>P3oool004H0oooo00<0ogFD0?miU03oNI@02`3oNI@;0?mm
U0/0ohVL2`3oVI`60?nQW0d0oooo1`3f99@70?HPU0L0ob2D6`3^79@>0?lTU0`0obbD2`3oool305X0
W1@0HP2L2@1Z09`<07<0W0<0P`2D>P3oool004H0oooo3@3oNI@<0?mmU0/0ohVL2P3oVI`60?nQW0l0
oooo1P3f99@90?HPU0D0ob2D6`3^79@>0?lTU0/0obbD3@3oool305X0W1<0HP2L2@1Z09`<07<0W080
P`2D>`3oool004L0oooo303oNI@<0?mmU0/0ohVL2@3oVI`00`3oUI`0oj6L0?nQW0030?nQW140oooo
1@3f99@:0?HPU0@0ob2D6`3^79@>0?lTU0/0obbD3P3oool205X0W1<0HP2L2P1Z09`<07<0W00308<0
U03oool0oooo03T0oooo00180?ooo`/0ogVD2`3oOI@;0?n9W0T0oiVL0P3oUI`50?nQW140oooo1@3f
99@<0?HPU080ob2D6`3^79@?0?lTU0T0obbD3`3oool205X0W1<0HP2L2P1Z09`<07<0W00308<0U03o
ool0oooo03T0oooo00180?ooo`X0ogVD303oOI@;0?n9W0L0oiVL103oUI`40?nQW1<0oooo103f99@=
0?HPU0030?lPU03^79@0kQbD01T0kQbD3`3o99@80?l/U140oooo00<0FP2L0680W01R09`04P1R09`9
06X0W0`0L`2L?03oool004T0oooo2@3oNI@<0?mmU0/0ohVL1P3oVI`50?nEW0<0oj6L5@3oool30?HT
U0h0mR2D6`3^79@?0?lTU0L0obbD4`3oool;0680W0<0HP2D1P1R09`606X0W0@0JP2D2`1c09`l0?oo
o`00B@3oool90?miU0`0ogfD2`3oRI`40?nIW0H0oiFL0`3oXI`G0?ooo`80mRBD3P3f89@30?HLU1P0
kQbD3`3o99@70?l/U1<0oooo2`1R09`60680U0<0HP2L0`1Z09`706X0U0X0L`2L?@3oool004X0oooo
1`3oNI@<0?mmU0/0ohVL103oVI`70?nEW0<0oj6L603oool00`3f99@0mR2D0?HPU00<0?HPU0D0mQbD
5P3^79@?0?lTU0H0obbD5P3oool90680W0T0HP2D2`1Z09@907<0W3d0oooo001:0?ooo`L0ogVD303o
OI@;0?n9W080oiVL2@3oUI`20?nQW1T0oooo3`3f89@70?HLU1@0kQbD3`3o99@50?l/U1P0oooo201R
09`:0680U0X0JP2D201c09`n0?ooo`00B`3oool60?miU0`0ogfD2`3oRI`00`3oVI`0oiFL0?nEW008
0?nEW0030?nQW03oool0oooo01X0oooo3@3f89@:0?HLU140kQbD3`3o99@40?l/U1X0oooo201R09`9
0680U0/0JP2D1P1c09`o0?ooo`00C03oool40?miU0d0ogfD2P3oRI`<0?nEW1h0oooo303f89@<0?HL
U0l0kQbD3`3o99@40?l/U1`0oooo1P1R09`90680U0/0JP2D1P1c09`o0?ooo`00C03oool40?miU0`0
ogfD2`3oRI`;0?nEW200oooo2`3f89@>0?HLU0h0mR2D3P3o99@30?l/U1h0oooo1@1R09`:0680U0/0
JP2D101c09a00?ooo`00C@3oool30?miU0`0ogfD2`3oRI`:0?nEW2<0oooo2@3f89@>0?HLU0h0mR2D
3P3o99@20?l/U200oooo101R09`:0680U0/0JP2D0`1c09a10?ooo`00C@3oool20?miU0d0ogfD2`3o
RI`90?nEW2D0oooo203f89@>0?HLU0h0mR2D3P3o99@00`3o;9@0oooo0?ooo`0Q0?ooo`<0HP2L2@1R
09@<06X0U080L`2L@@3oool004h0oooo00<0ogVD0?mmU03oOI@02`3oOI@;0?n9W0P0oiFL9`3oool7
0?HPU0h0mQbD3P3f89@>0?lTU2D0oooo0P1R09`:0680U0/0JP2D00<0L`2L0?ooo`3oool0@03oool0
04h0oooo3@3oOI@<0?n9W0H0oiFL:P3oool60?HPU0h0mQbD3P3f89@=0?lTU2L0oooo00<0HP2L0680
U01R09@0201R09@;06X0U4<0oooo001@0?ooo`/0ogfD2`3oRI`60?nEW2d0oooo103f89@>0?HLU0h0
mR2D2`3o99@Z0?ooo`X0HP2D2@1Z09A50?ooo`00DP3oool90?mmU0/0ohVL1@3oUI`_0?ooo`<0mR2D
3P3f79@>0?HPU0X0obBD;`3oool70680U0D0JP2DB03oool005<0oooo203oOI@;0?n9W0<0oiFL<P3o
ool20?HPU0h0mQbD3P3f89@80?lTU3D0oooo0`1R09@306X0U4X0oooo001E0?ooo`D0ogfD303oRI`2
0?nEW3@0oooo3`3f79@>0?HPU0L0obBDQP3oool005H0oooo103oOI@<0?n9W0030?nEW03oool0oooo
03H0oooo303f79@>0?HPU0D0obBDR03oool005P0oooo0P3oOI@;0?n9W3d0oooo2@3f79@>0?HPU0@0
obBDR@3oool00:D0oooo1P3f79@>0?HPU080obBDR`3oool00:P0oooo0`3f79@>0?HPU8d0oooo003o
0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o
0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o
0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o
0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o
0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o
0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o
0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o
0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o
0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo003o0?ooodL0oooo0000
\
\>"],
  ImageRangeCache->{{{0, 325.25}, {528.938, 0}} -> {0.186172, 0.00597699, \
0.00188028, 0.00188028}}]
}, Open  ]],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`function\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`w(
          z) = \(ln(z + 1)\)\/\(\(-z\) - 1\) + \(ln(\(-z\) - 1)\)\/\(z + \
1\)\)]],
  "has the two branch points ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(\[PlusMinus]1\)\)]],
  ". At these points we have an additional pole. This is a visualization of \
the graph on the Riemann sphere."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.05112 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.032076 1.10198 -1.40946e-17 1.10198 [
[ 0 0 0 0 ]
[ 1 1.05112 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.05112 L
0 1.05112 L
closepath
clip
newpath
.46598 .48821 m .41958 .47996 L .41921 .48657 L 1 .731 0 r
F
.46598 .48821 m .46605 .4816 L .41958 .47996 L F
.46591 .49482 m .46598 .48821 L .41921 .48657 L 1 .725 0 r
F
.51289 .48767 m .46605 .4816 L .46598 .48821 L 1 .683 0 r
F
.5131 .49428 m .46598 .48821 L .46591 .49482 L 1 .677 0 r
F
.5131 .49428 m .51289 .48767 L .46598 .48821 L F
.46605 .4816 m .41996 .47336 L .41958 .47996 L 1 .737 0 r
F
.46605 .4816 m .46612 .47498 L .41996 .47336 L F
.51267 .48105 m .46612 .47498 L .46605 .4816 L 1 .69 0 r
F
.51289 .48767 m .51267 .48105 L .46605 .4816 L 1 .683 0 r
F
.46591 .49482 m .41921 .48657 L .41886 .49317 L 1 .725 0 r
F
.46584 .50142 m .46591 .49482 L .41886 .49317 L 1 .718 0 r
F
.51329 .50089 m .46591 .49482 L .46584 .50142 L 1 .67 0 r
F
.51329 .50089 m .5131 .49428 L .46591 .49482 L F
.46612 .47498 m .42036 .46675 L .41996 .47336 L 1 .744 0 r
F
.46612 .47498 m .4662 .46837 L .42036 .46675 L F
.51243 .47443 m .4662 .46837 L .46612 .47498 L 1 .697 0 r
F
.51267 .48105 m .51243 .47443 L .46612 .47498 L 1 .69 0 r
F
.46584 .50142 m .41886 .49317 L .41852 .49976 L 1 .718 0 r
F
.46577 .50802 m .46584 .50142 L .41852 .49976 L 1 .712 0 r
F
.51348 .50749 m .46584 .50142 L .46577 .50802 L 1 .663 0 r
F
.51348 .50749 m .51329 .50089 L .46584 .50142 L F
.4662 .46837 m .42077 .46014 L .42036 .46675 L 1 .75 0 r
F
.4662 .46837 m .46628 .46175 L .42077 .46014 L F
.51219 .46781 m .46628 .46175 L .4662 .46837 L 1 .703 0 r
F
.51243 .47443 m .51219 .46781 L .4662 .46837 L 1 .697 0 r
F
.46577 .50802 m .41852 .49976 L .41819 .50636 L 1 .712 0 r
F
.4657 .51461 m .46577 .50802 L .41819 .50636 L 1 .705 0 r
F
.51366 .51409 m .46577 .50802 L .4657 .51461 L 1 .656 0 r
F
.51366 .51409 m .51348 .50749 L .46577 .50802 L F
.46628 .46175 m .42119 .45354 L .42077 .46014 L 1 .756 0 r
F
.46628 .46175 m .46636 .45514 L .42119 .45354 L F
.51194 .46118 m .46636 .45514 L .46628 .46175 L 1 .71 0 r
F
.51219 .46781 m .51194 .46118 L .46628 .46175 L 1 .703 0 r
F
.4657 .51461 m .41819 .50636 L .41788 .51294 L 1 .705 0 r
F
.46564 .52119 m .4657 .51461 L .41788 .51294 L 1 .698 0 r
F
.51382 .52068 m .4657 .51461 L .46564 .52119 L 1 .649 0 r
F
.51382 .52068 m .51366 .51409 L .4657 .51461 L F
.55947 .48494 m .55895 .47831 L .5364 .47964 L .958 .643 0 r
F
.55947 .48494 m .5364 .47964 L .53638 .47974 L F
.53555 .48295 m .5364 .47964 L .51267 .48105 L .951 .635 0 r
F
.55947 .48494 m .53604 .47966 L .53555 .48295 L .958 .643 0 r
F
.55947 .48494 m .53875 .48322 L .53513 .48636 L F
.53875 .48322 m .53555 .48295 L .53513 .48636 L F
.53182 .48923 m .53505 .48643 L .51289 .48767 L .95 .628 0 r
F
.53505 .48643 m .53513 .48636 L .53507 .48636 L F
.53505 .48643 m .53507 .48636 L .51289 .48767 L F
.53808 .48975 m .53762 .48971 L .54068 .49268 L .957 .636 0 r
F
.53762 .48971 m .53658 .49061 L .54068 .49268 L F
.53427 .48944 m .51289 .48767 L .5337 .49308 L .95 .628 0 r
F
.53427 .48944 m .53375 .49143 L .53395 .49146 L .957 .636 0 r
F
.53427 .48944 m .53395 .49146 L .54068 .49268 L F
.53367 .49308 m .51289 .48767 L .5131 .49428 L .95 .628 0 r
F
.53062 .49572 m .53366 .49312 L .5131 .49428 L .95 .621 0 r
F
.53366 .49312 m .5337 .49308 L .53367 .49308 L F
.53366 .49312 m .53367 .49308 L .5131 .49428 L F
.5321 .4998 m .5131 .49428 L .51329 .50089 L F
.53033 .50653 m .51329 .50089 L .51348 .50749 L .949 .613 0 r
F
.53703 .50615 m .5321 .50505 L .53033 .50653 L .957 .623 0 r
F
.5321 .50505 m .53073 .50475 L .53033 .50653 L F
.56089 .50481 m .53428 .50261 L .53703 .50615 L F
.53127 .50236 m .51329 .50089 L .53033 .50653 L .949 .613 0 r
F
.53428 .50261 m .53127 .50236 L .53703 .50615 L .957 .623 0 r
F
.53127 .50236 m .5321 .4998 L .51329 .50089 L .949 .613 0 r
F
.53127 .50236 m .51326 .50088 L .53051 .5047 L .957 .623 0 r
F
.53127 .50236 m .53051 .5047 L .53703 .50615 L F
.53894 .49941 m .53378 .49839 L .53211 .4998 L .957 .63 0 r
F
.53378 .49839 m .53243 .49812 L .53211 .4998 L F
.56044 .49819 m .53625 .49619 L .53894 .49941 L F
.53284 .49591 m .5131 .49428 L .53211 .4998 L .95 .621 0 r
F
.53625 .49619 m .51306 .49427 L .53894 .49941 L .957 .63 0 r
F
.56044 .49819 m .55997 .49156 L .5337 .49308 L F
.53284 .49591 m .5337 .49308 L .53062 .49572 L .95 .621 0 r
F
.53284 .49591 m .5337 .49308 L .51306 .49427 L .957 .63 0 r
F
.56044 .49819 m .5337 .49308 L .53284 .49591 L F
.56034 .49817 m .5337 .49308 L .53284 .49591 L .95 .621 0 r
F
.53211 .4998 m .53211 .4998 L .5321 .4998 L .949 .613 0 r
F
.56089 .50481 m .56044 .49819 L .53211 .4998 L .957 .623 0 r
F
.53127 .50236 m .53211 .4998 L .51326 .50088 L F
.56089 .50481 m .53211 .4998 L .53127 .50236 L F
.56078 .50478 m .53211 .4998 L .53211 .4998 L .949 .613 0 r
F
.56078 .50478 m .56034 .49817 L .53211 .4998 L F
.56078 .50478 m .5321 .4998 L .53127 .50236 L F
.52777 .50866 m .53033 .50653 L .51348 .50749 L .948 .606 0 r
F
.56132 .51142 m .56089 .50481 L .53703 .50615 L .956 .616 0 r
F
.56132 .51142 m .53703 .50615 L .53556 .50735 L F
.56132 .51142 m .53033 .50653 L .52953 .5088 L F
.52953 .5088 m .53033 .50653 L .52777 .50866 L .948 .606 0 r
F
.52835 .51325 m .51348 .50749 L .51366 .51409 L F
.52953 .5088 m .51348 .50749 L .52835 .51325 L F
.52835 .51325 m .51345 .50748 L .51363 .51407 L .956 .616 0 r
F
.56132 .51142 m .52953 .5088 L .52835 .51325 L F
.52953 .5088 m .51345 .50748 L .52835 .51325 L F
.5612 .51138 m .52953 .5088 L .52835 .51325 L .948 .606 0 r
F
.56172 .51803 m .56132 .51142 L .535 .51288 L .955 .609 0 r
F
.56172 .51803 m .535 .51288 L .53361 .514 L F
.56172 .51803 m .52835 .51325 L .5276 .51522 L F
.52614 .5151 m .52833 .5133 L .51366 .51409 L .948 .599 0 r
F
.52833 .5133 m .52835 .51325 L .51366 .51409 L F
.52614 .51998 m .51366 .51409 L .51382 .52068 L F
.56172 .51803 m .5276 .51522 L .52614 .51998 L .955 .609 0 r
F
.56159 .51797 m .5276 .51522 L .52614 .51998 L .948 .599 0 r
F
.5276 .51522 m .51366 .51409 L .52614 .51998 L F
.52614 .51998 m .5276 .51522 L .52568 .52 L .955 .609 0 r
F
.52568 .52 m .51363 .51407 L .5138 .52066 L F
.5276 .51522 m .51363 .51407 L .52568 .52 L F
.5276 .51522 m .52839 .51325 L .52614 .5151 L .948 .599 0 r
F
.53361 .514 m .535 .51288 L .52835 .51325 L .955 .609 0 r
F
.56159 .51797 m .52839 .51325 L .5276 .51522 L .948 .599 0 r
F
.52839 .51325 m .52839 .51325 L .5276 .51522 L F
.56211 .52463 m .56172 .51803 L .53275 .51962 L .955 .602 0 r
F
.56211 .52463 m .53275 .51962 L .53144 .52066 L F
.56211 .52463 m .52614 .51998 L .52548 .52162 L F
.52434 .52152 m .52609 .5201 L .51382 .52068 L .947 .592 0 r
F
.52609 .5201 m .52614 .51998 L .51382 .52068 L F
.51398 .52725 m .51382 .52068 L .46564 .52119 L .999 .642 0 r
F
.52369 .52671 m .51382 .52068 L .51398 .52725 L .947 .592 0 r
F
.56211 .52463 m .52548 .52162 L .52369 .52671 L .955 .602 0 r
F
.56196 .52456 m .52548 .52162 L .52369 .52671 L .947 .592 0 r
F
.52548 .52162 m .51382 .52068 L .52369 .52671 L F
.52369 .52671 m .52548 .52162 L .5232 .52673 L .955 .602 0 r
F
.5232 .52673 m .5138 .52066 L .51396 .52724 L F
.52548 .52162 m .5138 .52066 L .5232 .52673 L F
.53144 .52066 m .53275 .51962 L .52614 .51998 L F
.56196 .52456 m .52625 .51997 L .52618 .52003 L .947 .592 0 r
F
.52548 .52162 m .52618 .52003 L .52434 .52152 L F
.56196 .52456 m .52618 .52003 L .52548 .52162 L F
.56247 .53122 m .56211 .52463 L .53028 .52635 L .954 .595 0 r
F
.56247 .53122 m .53028 .52635 L .52903 .52733 L F
.56247 .53122 m .52369 .52671 L .52313 .52799 L F
.52235 .52793 m .52359 .52693 L .51398 .52725 L .946 .584 0 r
F
.52359 .52693 m .52369 .52671 L .51398 .52725 L F
.51398 .52725 m .46564 .52119 L .46557 .52777 L .999 .642 0 r
F
.51412 .53382 m .51398 .52725 L .46557 .52777 L .999 .635 0 r
F
.52096 .53344 m .51398 .52725 L .51412 .53382 L .946 .584 0 r
F
.56247 .53122 m .52313 .52799 L .52096 .53344 L .954 .595 0 r
F
.56231 .53113 m .52313 .52799 L .52096 .53344 L .946 .584 0 r
F
.52313 .52799 m .51398 .52725 L .52096 .53344 L F
.52096 .53344 m .52313 .52799 L .52044 .53347 L .954 .595 0 r
F
.52044 .53347 m .51396 .52724 L .51411 .53381 L F
.52313 .52799 m .51396 .52724 L .52044 .53347 L F
.52903 .52733 m .53028 .52635 L .52369 .52671 L F
.56231 .53113 m .52389 .5267 L .52369 .52686 L .946 .584 0 r
F
.52313 .52799 m .52369 .52686 L .52235 .52793 L F
.56231 .53113 m .52369 .52686 L .52313 .52799 L F
.5628 .5378 m .56247 .53122 L .52755 .53309 L .953 .588 0 r
F
.5628 .5378 m .52755 .53309 L .52636 .534 L F
.5628 .5378 m .52096 .53344 L .52054 .53433 L F
.52015 .5343 m .52079 .5338 L .51412 .53382 L .945 .577 0 r
F
.52079 .5338 m .52096 .53344 L .51412 .53382 L F
.51412 .53382 m .46557 .52777 L .46551 .53433 L .999 .635 0 r
F
.51426 .54038 m .51412 .53382 L .46551 .53433 L .998 .628 0 r
F
.51791 .54017 m .51412 .53382 L .51426 .54038 L .945 .577 0 r
F
.5628 .5378 m .52054 .53433 L .51791 .54017 L .953 .588 0 r
F
.56263 .53769 m .52054 .53433 L .51791 .54017 L .945 .577 0 r
F
.52054 .53433 m .51412 .53382 L .51791 .54017 L F
.51791 .54017 m .52054 .53433 L .51736 .5402 L .953 .588 0 r
F
.51736 .5402 m .51411 .53381 L .51425 .54037 L F
.52054 .53433 m .51411 .53381 L .51736 .5402 L F
.52636 .534 m .52755 .53309 L .52096 .53344 L F
.56263 .53769 m .52127 .53342 L .52086 .53374 L .945 .577 0 r
F
.52054 .53433 m .52086 .53374 L .52015 .5343 L F
.56263 .53769 m .52086 .53374 L .52054 .53433 L F
.56312 .54438 m .5628 .5378 L .52453 .53982 L .953 .581 0 r
F
.56312 .54438 m .52453 .53982 L .52338 .54068 L F
.56312 .54438 m .51791 .54017 L .51768 .54065 L F
.51426 .54038 m .46551 .53433 L .46545 .54088 L .998 .628 0 r
F
.51438 .54692 m .51426 .54038 L .46545 .54088 L .998 .621 0 r
F
.51452 .54691 m .51426 .54038 L .51438 .54692 L .944 .569 0 r
F
.51452 .54691 m .51425 .54037 L .51438 .54692 L .953 .581 0 r
F
.56312 .54438 m .51768 .54065 L .51452 .54691 L F
.51768 .54065 m .51426 .54038 L .51452 .54691 L .944 .569 0 r
F
.51768 .54065 m .51425 .54037 L .51452 .54691 L .953 .581 0 r
F
.56293 .54424 m .51768 .54065 L .51452 .54691 L .944 .569 0 r
F
.56341 .55094 m .56312 .54438 L .51452 .54691 L .952 .573 0 r
F
.51451 .54693 m .51452 .54691 L .51438 .54692 L .944 .561 0 r
F
.51451 .54693 m .51452 .54691 L .51438 .54692 L .952 .573 0 r
F
.56341 .55094 m .51452 .54691 L .51451 .54693 L F
.51501 .54697 m .51514 .54687 L .51452 .54691 L .944 .561 0 r
F
.51501 .54697 m .51452 .54691 L .51451 .54693 L F
.56321 .55078 m .56293 .54424 L .51514 .54687 L F
.56321 .55078 m .51514 .54687 L .51501 .54697 L F
.52338 .54068 m .52453 .53982 L .51791 .54017 L .953 .581 0 r
F
.51768 .54065 m .51791 .54017 L .51426 .54038 L .944 .569 0 r
F
.51768 .54065 m .51791 .54017 L .51425 .54037 L .953 .581 0 r
F
.51771 .54065 m .51836 .54015 L .51791 .54017 L .944 .569 0 r
F
.51771 .54065 m .51791 .54017 L .51768 .54065 L F
.56293 .54424 m .56263 .53769 L .51836 .54015 L F
.56293 .54424 m .51836 .54015 L .51771 .54065 L F
.52054 .53433 m .52096 .53344 L .51411 .53381 L .953 .588 0 r
F
.52079 .5338 m .52127 .53342 L .52096 .53344 L .945 .577 0 r
F
.56263 .53769 m .56231 .53113 L .52127 .53342 L F
.52313 .52799 m .52369 .52671 L .51396 .52724 L .954 .595 0 r
F
.52359 .52693 m .52389 .5267 L .52369 .52671 L .946 .584 0 r
F
.56231 .53113 m .56196 .52456 L .52389 .5267 L F
.52548 .52162 m .52614 .51998 L .5138 .52066 L .955 .602 0 r
F
.52609 .5201 m .52625 .51997 L .52614 .51998 L .947 .592 0 r
F
.56196 .52456 m .56159 .51797 L .52625 .51997 L F
.5276 .51522 m .52835 .51325 L .51363 .51407 L .955 .609 0 r
F
.52833 .5133 m .52839 .51325 L .52835 .51325 L .948 .599 0 r
F
.56159 .51797 m .5612 .51138 L .52839 .51325 L F
.53556 .50735 m .53703 .50615 L .53033 .50653 L .956 .616 0 r
F
.52953 .5088 m .53033 .50653 L .51345 .50748 L F
.5612 .51138 m .53033 .50653 L .52953 .5088 L .948 .606 0 r
F
.5612 .51138 m .56078 .50478 L .53033 .50653 L F
.56078 .50478 m .53127 .50236 L .53033 .50653 L .949 .613 0 r
F
.53033 .50653 m .51326 .50088 L .51345 .50748 L .957 .623 0 r
F
.53073 .50475 m .51326 .50088 L .53033 .50653 L F
.53211 .4998 m .5321 .4998 L .5321 .4998 L .95 .621 0 r
F
.5321 .4998 m .5131 .49428 L .5321 .4998 L F
.56034 .49817 m .53284 .49591 L .53211 .4998 L F
.53211 .4998 m .53221 .49808 L .5317 .49982 L .957 .63 0 r
F
.53243 .49812 m .53221 .49808 L .53211 .4998 L F
.5317 .49982 m .51306 .49427 L .51326 .50088 L F
.53221 .49808 m .51306 .49427 L .5317 .49982 L F
.5337 .49308 m .53366 .49307 L .53367 .49308 L .95 .628 0 r
F
.53366 .49307 m .51289 .48767 L .53367 .49308 L F
.53762 .48971 m .53427 .48944 L .53658 .49061 L .957 .636 0 r
F
.53427 .48944 m .53513 .48636 L .53182 .48923 L .95 .628 0 r
F
.55997 .49156 m .53513 .48636 L .53511 .48644 L .957 .636 0 r
F
.55997 .49156 m .5348 .48638 L .53427 .48944 L F
.55987 .49155 m .53513 .48636 L .53427 .48944 L .95 .628 0 r
F
.55997 .49156 m .55947 .48494 L .53513 .48636 L .957 .636 0 r
F
.53511 .48644 m .53513 .48636 L .5348 .48638 L F
.53504 .48636 m .51267 .48105 L .51289 .48767 L .951 .635 0 r
F
.53427 .48944 m .5348 .48638 L .51285 .48766 L .957 .636 0 r
F
.54068 .49268 m .51285 .48766 L .51306 .49427 L F
.55997 .49156 m .53808 .48975 L .54068 .49268 L F
.55987 .49155 m .53427 .48944 L .5337 .49308 L .95 .628 0 r
F
.56034 .49817 m .55987 .49155 L .5337 .49308 L .95 .621 0 r
F
.53427 .48944 m .51285 .48766 L .53375 .49143 L .957 .636 0 r
F
.55987 .49155 m .55939 .48493 L .53513 .48636 L .95 .628 0 r
F
.52987 .48003 m .51243 .47443 L .51267 .48105 L .951 .642 0 r
F
.5364 .47964 m .53139 .47855 L .52987 .48003 L F
.53139 .47855 m .51243 .47443 L .52987 .48003 L F
.5367 .47646 m .51243 .47443 L .53631 .47962 L F
.5367 .47646 m .53631 .47962 L .5364 .47964 L F
.53087 .47333 m .51219 .46781 L .51243 .47443 L .952 .649 0 r
F
.53235 .47188 m .51219 .46781 L .53087 .47333 L F
.53437 .46967 m .51219 .46781 L .53744 .47291 L F
.53744 .47283 m .53744 .47291 L .53754 .47293 L F
.53437 .46967 m .53744 .47291 L .53744 .47283 L F
.53172 .46663 m .51194 .46118 L .51219 .46781 L .952 .655 0 r
F
.53317 .4652 m .51194 .46118 L .53172 .46663 L F
.53541 .46317 m .51194 .46118 L .53844 .4662 L F
.53844 .46613 m .53844 .4662 L .53854 .46622 L F
.53541 .46317 m .53844 .4662 L .53844 .46613 L F
.53243 .45994 m .51168 .45456 L .51194 .46118 L .953 .662 0 r
F
.53387 .45852 m .51168 .45456 L .53243 .45994 L F
.53633 .45666 m .51168 .45456 L .53932 .4595 L F
.53932 .45943 m .53932 .4595 L .53942 .45952 L F
.53633 .45666 m .53932 .4595 L .53932 .45943 L F
.53301 .45326 m .5114 .44794 L .51168 .45456 L .953 .669 0 r
F
.53445 .45185 m .5114 .44794 L .53301 .45326 L F
.53714 .45014 m .5114 .44794 L .54009 .4528 L F
.54009 .45274 m .54009 .4528 L .54018 .45282 L F
.53714 .45014 m .54009 .4528 L .54009 .45274 L F
.53347 .44658 m .51112 .44132 L .5114 .44794 L .953 .676 0 r
F
.53492 .44517 m .51112 .44132 L .53347 .44658 L F
.53784 .44363 m .51112 .44132 L .54076 .44611 L F
.54076 .44606 m .54076 .44611 L .54084 .44612 L F
.53784 .44363 m .54076 .44611 L .54076 .44606 L F
.53381 .43991 m .51082 .43471 L .51112 .44132 L .953 .682 0 r
F
.53529 .4385 m .51082 .43471 L .53381 .43991 L F
.53845 .43711 m .51082 .43471 L .54132 .43943 L F
.54132 .43938 m .54132 .43943 L .5414 .43944 L F
.53845 .43711 m .54132 .43943 L .54132 .43938 L F
.53405 .43325 m .51052 .4281 L .51082 .43471 L .954 .689 0 r
F
.53555 .43183 m .51052 .4281 L .53405 .43325 L F
.53896 .43059 m .51052 .4281 L .5418 .43276 L F
.54179 .43272 m .5418 .43276 L .54185 .43276 L F
.53896 .43059 m .5418 .43276 L .54179 .43272 L F
.53417 .42661 m .5102 .4215 L .51052 .4281 L .954 .696 0 r
F
.53571 .42516 m .5102 .4215 L .53417 .42661 L F
.53938 .42407 m .5102 .4215 L .54217 .42609 L F
.54217 .42607 m .54217 .42609 L .54222 .4261 L F
.53938 .42407 m .54217 .42609 L .54217 .42607 L F
.53419 .41997 m .50988 .41491 L .5102 .4215 L .954 .702 0 r
F
.53578 .41851 m .50988 .41491 L .53419 .41997 L F
.53972 .41755 m .50988 .41491 L .54247 .41944 L F
.54246 .41942 m .54247 .41944 L .5425 .41944 L F
.53972 .41755 m .54247 .41944 L .54246 .41942 L F
.53412 .41335 m .50954 .40832 L .50988 .41491 L .954 .709 0 r
F
.53575 .41186 m .50954 .40832 L .53412 .41335 L F
.53999 .41104 m .50954 .40832 L .54267 .4128 L F
.54267 .41279 m .54267 .4128 L .54269 .4128 L F
.53999 .41104 m .54267 .4128 L .54267 .41279 L F
.53395 .40674 m .50919 .40175 L .50954 .40832 L .954 .715 0 r
F
.53564 .40523 m .50919 .40175 L .53395 .40674 L F
.54017 .40454 m .50919 .40175 L .5428 .40617 L F
.5428 .40616 m .5428 .40617 L .54281 .40617 L F
.54017 .40454 m .5428 .40617 L .5428 .40616 L F
.53369 .40015 m .50884 .39519 L .50919 .40175 L .954 .722 0 r
F
.53545 .3986 m .50884 .39519 L .53369 .40015 L F
.54028 .39804 m .50884 .39519 L .54284 .39955 L F
.50919 .40175 m .50884 .39519 L .46712 .39583 L 1 .766 0 r
F
.50884 .39519 m .46721 .38929 L .46712 .39583 L 1 .772 0 r
F
.50884 .39519 m .50847 .38864 L .46721 .38929 L F
.53334 .39357 m .50847 .38864 L .50884 .39519 L .954 .728 0 r
F
.53518 .39199 m .50847 .38864 L .53334 .39357 L F
.5426 .39176 m .50847 .38864 L .5428 .39294 L F
.50847 .38864 m .46731 .38276 L .46721 .38929 L .999 .778 0 r
F
.50847 .38864 m .50809 .3821 L .46731 .38276 L F
.5329 .38701 m .50809 .3821 L .50847 .38864 L .954 .735 0 r
F
.53483 .38539 m .50809 .3821 L .5329 .38701 L F
.5425 .38527 m .50809 .3821 L .54269 .38636 L F
.50809 .3821 m .4674 .37624 L .46731 .38276 L .999 .784 0 r
F
.50809 .3821 m .50771 .37558 L .4674 .37624 L F
.53239 .38047 m .50771 .37558 L .50809 .3821 L .954 .741 0 r
F
.5344 .37881 m .50771 .37558 L .53239 .38047 L F
.54232 .3788 m .50771 .37558 L .5425 .37978 L F
.50771 .37558 m .4675 .36974 L .4674 .37624 L .998 .79 0 r
F
.50771 .37558 m .50731 .36907 L .4675 .36974 L F
.53179 .37394 m .50731 .36907 L .50771 .37558 L .954 .747 0 r
F
.53391 .37224 m .50731 .36907 L .53179 .37394 L F
.54207 .37234 m .50731 .36907 L .54225 .37323 L F
.50731 .36907 m .46759 .36326 L .4675 .36974 L .998 .796 0 r
F
.50731 .36907 m .5069 .36258 L .46759 .36326 L F
.53111 .36744 m .5069 .36258 L .50731 .36907 L .954 .754 0 r
F
.53334 .36569 m .5069 .36258 L .53111 .36744 L F
.54176 .36589 m .5069 .36258 L .54193 .3667 L F
.5069 .36258 m .46769 .3568 L .46759 .36326 L .997 .802 0 r
F
.5069 .36258 m .50648 .35611 L .46769 .3568 L F
.53037 .36096 m .50648 .35611 L .5069 .36258 L .953 .76 0 r
F
.53271 .35916 m .50648 .35611 L .53037 .36096 L F
.54139 .35945 m .50648 .35611 L .54155 .36018 L F
.50648 .35611 m .46779 .35035 L .46769 .3568 L .996 .808 0 r
F
.50648 .35611 m .50606 .34965 L .46779 .35035 L F
.52955 .3545 m .50606 .34965 L .50648 .35611 L .953 .766 0 r
F
.53202 .35264 m .50606 .34965 L .52955 .3545 L F
.54096 .35304 m .50606 .34965 L .54111 .35369 L F
.50606 .34965 m .46789 .34393 L .46779 .35035 L .996 .814 0 r
F
.50606 .34965 m .50562 .34322 L .46789 .34393 L F
.52866 .34806 m .50562 .34322 L .50606 .34965 L .953 .772 0 r
F
.53127 .34615 m .50562 .34322 L .52866 .34806 L F
.54047 .34663 m .50562 .34322 L .54061 .34722 L F
.50562 .34322 m .46799 .33753 L .46789 .34393 L .995 .82 0 r
F
.50562 .34322 m .50517 .33681 L .46799 .33753 L F
.5277 .34165 m .50517 .33681 L .50562 .34322 L .952 .779 0 r
F
.53046 .33968 m .50517 .33681 L .5277 .34165 L F
.53992 .34025 m .50517 .33681 L .54004 .34077 L F
.50517 .33681 m .46809 .33115 L .46799 .33753 L .994 .825 0 r
F
.50517 .33681 m .50472 .33042 L .46809 .33115 L F
.52669 .33526 m .50472 .33042 L .50517 .33681 L .952 .785 0 r
F
.5296 .33324 m .50472 .33042 L .52669 .33526 L F
.53931 .33389 m .50472 .33042 L .53942 .33435 L F
.50472 .33042 m .46819 .3248 L .46809 .33115 L .993 .831 0 r
F
.50472 .33042 m .50425 .32406 L .46819 .3248 L F
.52561 .32891 m .50425 .32406 L .50472 .33042 L .951 .791 0 r
F
.52868 .32681 m .50425 .32406 L .52561 .32891 L F
.53865 .32754 m .50425 .32406 L .53875 .32795 L F
.50425 .32406 m .4683 .31847 L .46819 .3248 L .993 .837 0 r
F
.50425 .32406 m .50377 .31772 L .4683 .31847 L F
.52448 .32257 m .50377 .31772 L .50425 .32406 L .951 .797 0 r
F
.52772 .32042 m .50377 .31772 L .52448 .32257 L F
.53793 .32122 m .50377 .31772 L .53803 .32158 L F
.50377 .31772 m .4684 .31216 L .4683 .31847 L .992 .843 0 r
F
.50377 .31772 m .50329 .31141 L .4684 .31216 L F
.52329 .31627 m .50329 .31141 L .50377 .31772 L .95 .803 0 r
F
.52672 .31405 m .50329 .31141 L .52329 .31627 L F
.53716 .31493 m .50329 .31141 L .53725 .31524 L F
.50329 .31141 m .46851 .30589 L .4684 .31216 L .991 .848 0 r
F
.50329 .31141 m .50279 .30512 L .46851 .30589 L F
.52206 .31 m .50279 .30512 L .50329 .31141 L .95 .809 0 r
F
.52567 .30771 m .50279 .30512 L .52206 .31 L F
.53635 .30865 m .50279 .30512 L .53642 .30892 L F
.50279 .30512 m .46862 .29964 L .46851 .30589 L .99 .854 0 r
F
.50279 .30512 m .50229 .29886 L .46862 .29964 L F
.52077 .30376 m .50229 .29886 L .50279 .30512 L .949 .815 0 r
F
.52458 .30139 m .50229 .29886 L .52077 .30376 L F
.53549 .30241 m .50229 .29886 L .53555 .30264 L F
.50229 .29886 m .46873 .29342 L .46862 .29964 L .989 .86 0 r
F
.50229 .29886 m .50177 .29263 L .46873 .29342 L F
.51945 .29755 m .50177 .29263 L .50229 .29886 L .949 .822 0 r
F
.52346 .29511 m .50177 .29263 L .51945 .29755 L F
.53458 .29619 m .50177 .29263 L .53463 .29638 L F
.50177 .29263 m .46884 .28723 L .46873 .29342 L .987 .866 0 r
F
.50177 .29263 m .50125 .28643 L .46884 .28723 L F
.51808 .29137 m .50125 .28643 L .50177 .29263 L .948 .828 0 r
F
.52231 .28886 m .50125 .28643 L .51808 .29137 L F
.53362 .29 m .50125 .28643 L .53367 .29016 L F
.50125 .28643 m .46895 .28108 L .46884 .28723 L .986 .871 0 r
F
.50125 .28643 m .50072 .28027 L .46895 .28108 L F
.51668 .28523 m .50072 .28027 L .50125 .28643 L .947 .834 0 r
F
.52112 .28264 m .50072 .28027 L .51668 .28523 L F
.53263 .28383 m .50072 .28027 L .53267 .28397 L F
.50072 .28027 m .46906 .27495 L .46895 .28108 L .985 .877 0 r
F
.50072 .28027 m .50018 .27414 L .46906 .27495 L F
.51524 .27912 m .50018 .27414 L .50072 .28027 L .946 .84 0 r
F
.51991 .27645 m .50018 .27414 L .51524 .27912 L F
.53159 .2777 m .50018 .27414 L .53163 .27782 L F
.50018 .27414 m .46917 .26886 L .46906 .27495 L .984 .882 0 r
F
.50018 .27414 m .49963 .26804 L .46917 .26886 L F
.51377 .27305 m .49963 .26804 L .50018 .27414 L .945 .846 0 r
F
.51868 .27029 m .49963 .26804 L .51377 .27305 L F
.53052 .2716 m .49963 .26804 L .53055 .2717 L F
.49963 .26804 m .46928 .26281 L .46917 .26886 L .982 .888 0 r
F
.49963 .26804 m .49907 .26197 L .46928 .26281 L F
.51228 .26701 m .49907 .26197 L .49963 .26804 L .944 .852 0 r
F
.51742 .26418 m .49907 .26197 L .51228 .26701 L F
.52941 .26554 m .49907 .26197 L .52943 .26562 L F
.49907 .26197 m .4694 .25679 L .46928 .26281 L .981 .894 0 r
F
.49907 .26197 m .4985 .25594 L .4694 .25679 L F
.51076 .26101 m .4985 .25594 L .49907 .26197 L .943 .858 0 r
F
.51614 .25809 m .4985 .25594 L .51076 .26101 L F
.52826 .25951 m .4985 .25594 L .52828 .25957 L F
.4985 .25594 m .46951 .25081 L .4694 .25679 L .979 .899 0 r
F
.4985 .25594 m .49792 .24995 L .46951 .25081 L F
.5271 .25356 m .49792 .24995 L .4985 .25594 L .942 .863 0 r
F
.52734 .25354 m .52708 .25351 L .5271 .25356 L .945 .866 0 r
F
.52734 .25354 m .52708 .25351 L .5271 .25356 L .942 .863 0 r
F
.52708 .25351 m .49792 .24995 L .5271 .25356 L F
.52859 .25955 m .52734 .25354 L .5271 .25356 L .947 .86 0 r
F
.52826 .25947 m .5271 .25356 L .50845 .25512 L .943 .858 0 r
F
.52758 .25943 m .50845 .25512 L .4985 .25594 L F
.52859 .25955 m .5271 .25356 L .52826 .25951 L .947 .86 0 r
F
.52859 .25955 m .50845 .25512 L .52758 .25943 L .943 .858 0 r
F
.52828 .25957 m .51614 .25809 L .51076 .26101 L F
.52826 .25951 m .5271 .25356 L .49849 .25604 L .947 .86 0 r
F
.52859 .25955 m .52734 .25354 L .5271 .25356 L .943 .858 0 r
F
.52859 .25955 m .5271 .25356 L .52826 .25947 L F
.52981 .26558 m .52861 .25966 L .5283 .25968 L .948 .854 0 r
F
.52861 .25966 m .52859 .25955 L .52824 .25957 L F
.52941 .26554 m .52828 .25957 L .49907 .26197 L .944 .852 0 r
F
.52861 .25966 m .52824 .25957 L .49905 .26207 L .948 .854 0 r
F
.52981 .26559 m .52859 .25955 L .52828 .25957 L .944 .852 0 r
F
.52981 .26558 m .5283 .25968 L .52941 .26554 L .948 .854 0 r
F
.52981 .26559 m .52828 .25957 L .52941 .26554 L .944 .852 0 r
F
.52941 .26554 m .5283 .25968 L .49905 .26207 L .948 .854 0 r
F
.5271 .25356 m .52504 .25327 L .52401 .25383 L .945 .866 0 r
F
.52708 .25351 m .52504 .25327 L .5271 .25356 L F
.52401 .25383 m .49791 .25005 L .49849 .25604 L F
.52504 .25327 m .49791 .25005 L .52401 .25383 L F
.52859 .25955 m .52826 .25951 L .52828 .25957 L .947 .86 0 r
F
.52859 .25955 m .52826 .25951 L .52828 .25957 L .943 .858 0 r
F
.52828 .25957 m .5263 .25928 L .52531 .25983 L .947 .86 0 r
F
.52826 .25951 m .5263 .25928 L .52828 .25957 L F
.52531 .25983 m .49849 .25604 L .49905 .26207 L F
.5263 .25928 m .49849 .25604 L .52531 .25983 L F
.52943 .26562 m .51742 .26418 L .51228 .26701 L .944 .852 0 r
F
.52981 .26558 m .52941 .26554 L .52943 .26562 L .948 .854 0 r
F
.52981 .26559 m .52941 .26554 L .52943 .26562 L .944 .852 0 r
F
.53102 .27166 m .52981 .26558 L .52943 .26562 L .949 .848 0 r
F
.5305 .27154 m .52943 .26562 L .51191 .26704 L .945 .846 0 r
F
.52972 .27151 m .51191 .26704 L .49963 .26804 L F
.53102 .27166 m .52943 .26562 L .53052 .2716 L .949 .848 0 r
F
.53102 .27166 m .51191 .26704 L .52972 .27151 L .945 .846 0 r
F
.53052 .2716 m .52943 .26562 L .49961 .26814 L .949 .848 0 r
F
.53102 .27166 m .52981 .26559 L .52943 .26562 L .945 .846 0 r
F
.53102 .27166 m .52943 .26562 L .5305 .27154 L F
.53221 .27777 m .53106 .27185 L .53058 .27189 L .95 .842 0 r
F
.53106 .27185 m .53102 .27166 L .53049 .27171 L F
.53159 .2777 m .53055 .2717 L .50018 .27414 L .946 .84 0 r
F
.53106 .27185 m .53049 .27171 L .50016 .27424 L .95 .842 0 r
F
.53221 .27777 m .53102 .27166 L .53055 .2717 L .946 .84 0 r
F
.53221 .27777 m .53058 .27189 L .53159 .2777 L .95 .842 0 r
F
.53221 .27777 m .53055 .2717 L .53159 .2777 L .946 .84 0 r
F
.53159 .2777 m .53058 .27189 L .50016 .27424 L .95 .842 0 r
F
.52943 .26562 m .52753 .26532 L .52658 .26586 L .948 .854 0 r
F
.52941 .26554 m .52753 .26532 L .52943 .26562 L F
.52658 .26586 m .49905 .26207 L .49961 .26814 L F
.52753 .26532 m .49905 .26207 L .52658 .26586 L F
.53055 .2717 m .51868 .27029 L .51377 .27305 L .945 .846 0 r
F
.53102 .27166 m .53052 .2716 L .53055 .2717 L .949 .848 0 r
F
.53102 .27166 m .53052 .2716 L .53055 .2717 L .945 .846 0 r
F
.53055 .2717 m .52874 .2714 L .52782 .27193 L .949 .848 0 r
F
.53052 .2716 m .52874 .2714 L .53055 .2717 L F
.52782 .27193 m .49961 .26814 L .50016 .27424 L F
.52874 .2714 m .49961 .26814 L .52782 .27193 L F
.53163 .27782 m .51991 .27645 L .51524 .27912 L .946 .84 0 r
F
.53221 .27777 m .53159 .2777 L .53163 .27782 L .95 .842 0 r
F
.53221 .27777 m .53159 .2777 L .53163 .27782 L .946 .84 0 r
F
.53338 .28392 m .53221 .27777 L .53163 .27782 L .95 .837 0 r
F
.53261 .28371 m .53163 .27782 L .51515 .27913 L .947 .834 0 r
F
.5317 .28373 m .51515 .27913 L .50072 .28027 L F
.53338 .28392 m .53163 .27782 L .53263 .28383 L .95 .837 0 r
F
.53338 .28392 m .51515 .27913 L .5317 .28373 L .947 .834 0 r
F
.53263 .28383 m .53163 .27782 L .5007 .28037 L .95 .837 0 r
F
.53338 .28392 m .53221 .27777 L .53163 .27782 L .947 .834 0 r
F
.53338 .28392 m .53163 .27782 L .53261 .28371 L F
.53454 .29009 m .53344 .28421 L .53271 .28427 L .951 .831 0 r
F
.53344 .28421 m .53338 .28392 L .5326 .28398 L F
.53362 .29 m .53267 .28397 L .50125 .28643 L .948 .828 0 r
F
.53344 .28421 m .5326 .28398 L .50123 .28654 L .951 .831 0 r
F
.53567 .2963 m .53454 .29009 L .53367 .29016 L .952 .825 0 r
F
.53458 .29619 m .53367 .29016 L .50177 .29263 L .949 .822 0 r
F
.53458 .29619 m .53367 .29016 L .50176 .29274 L .952 .825 0 r
F
.53567 .2963 m .53367 .29016 L .53458 .29619 L F
.53678 .30254 m .53567 .2963 L .53463 .29638 L .953 .819 0 r
F
.53549 .30241 m .53463 .29638 L .50229 .29886 L .949 .815 0 r
F
.53549 .30241 m .53463 .29638 L .50227 .29897 L .953 .819 0 r
F
.53678 .30254 m .53463 .29638 L .53549 .30241 L F
.53787 .30881 m .53678 .30254 L .53555 .30264 L .953 .813 0 r
F
.53635 .30865 m .53555 .30264 L .50279 .30512 L .95 .809 0 r
F
.53635 .30865 m .53555 .30264 L .50277 .30523 L .953 .813 0 r
F
.53787 .30881 m .53555 .30264 L .53635 .30865 L F
.53895 .31511 m .53787 .30881 L .53642 .30892 L .954 .807 0 r
F
.53716 .31493 m .53642 .30892 L .50329 .31141 L .95 .803 0 r
F
.53716 .31493 m .53642 .30892 L .50327 .31151 L .954 .807 0 r
F
.53895 .31511 m .53642 .30892 L .53716 .31493 L F
.54 .32143 m .53895 .31511 L .53725 .31524 L .955 .8 0 r
F
.53793 .32122 m .53725 .31524 L .50377 .31772 L .951 .797 0 r
F
.53793 .32122 m .53725 .31524 L .50375 .31783 L .955 .8 0 r
F
.54 .32143 m .53725 .31524 L .53793 .32122 L F
.54103 .32778 m .54 .32143 L .53803 .32158 L .955 .794 0 r
F
.53865 .32754 m .53803 .32158 L .50425 .32406 L .951 .791 0 r
F
.53865 .32754 m .53803 .32158 L .50423 .32416 L .955 .794 0 r
F
.54103 .32778 m .53803 .32158 L .53865 .32754 L F
.54204 .33415 m .54103 .32778 L .53875 .32795 L .956 .788 0 r
F
.53931 .33389 m .53875 .32795 L .50472 .33042 L .952 .785 0 r
F
.53931 .33389 m .53875 .32795 L .50469 .33053 L .956 .788 0 r
F
.54204 .33415 m .53875 .32795 L .53931 .33389 L F
.54303 .34055 m .54204 .33415 L .53942 .33435 L .956 .782 0 r
F
.53992 .34025 m .53942 .33435 L .50517 .33681 L .952 .779 0 r
F
.53992 .34025 m .53942 .33435 L .50515 .33692 L .956 .782 0 r
F
.54303 .34055 m .53942 .33435 L .53992 .34025 L F
.544 .34697 m .54303 .34055 L .54004 .34077 L .957 .776 0 r
F
.54047 .34663 m .54004 .34077 L .50562 .34322 L .953 .772 0 r
F
.54047 .34663 m .54004 .34077 L .50559 .34332 L .957 .776 0 r
F
.544 .34697 m .54004 .34077 L .54047 .34663 L F
.54495 .35341 m .544 .34697 L .54061 .34722 L .957 .77 0 r
F
.54096 .35304 m .54061 .34722 L .50606 .34965 L .953 .766 0 r
F
.54096 .35304 m .54061 .34722 L .50603 .34976 L .957 .77 0 r
F
.54495 .35341 m .54061 .34722 L .54096 .35304 L F
.54588 .35987 m .54495 .35341 L .54111 .35369 L .958 .764 0 r
F
.54139 .35945 m .54111 .35369 L .50648 .35611 L .953 .76 0 r
F
.54139 .35945 m .54111 .35369 L .50646 .35621 L .958 .764 0 r
F
.54588 .35987 m .54111 .35369 L .54139 .35945 L F
.54588 .35987 m .54139 .35945 L .54155 .36018 L F
.54679 .36635 m .54588 .35987 L .54155 .36018 L .958 .758 0 r
F
.54176 .36589 m .54155 .36018 L .5069 .36258 L .954 .754 0 r
F
.54176 .36589 m .54155 .36018 L .50687 .36268 L .958 .758 0 r
F
.54679 .36635 m .54155 .36018 L .54176 .36589 L F
.54679 .36635 m .5418 .36589 L .54177 .36591 L F
.54679 .36635 m .54177 .36591 L .54193 .3667 L F
.54768 .37285 m .54679 .36635 L .54193 .3667 L .958 .752 0 r
F
.54207 .37234 m .54193 .3667 L .50731 .36907 L .954 .747 0 r
F
.54207 .37234 m .54193 .3667 L .50728 .36916 L .958 .752 0 r
F
.54768 .37285 m .54193 .3667 L .54207 .37234 L F
.54768 .37285 m .54224 .37235 L .5421 .37247 L F
.54768 .37285 m .5421 .37247 L .54225 .37323 L F
.54855 .37936 m .54768 .37285 L .54225 .37323 L .958 .745 0 r
F
.54232 .3788 m .54225 .37323 L .50771 .37558 L .954 .741 0 r
F
.54232 .3788 m .54225 .37323 L .50767 .37567 L .958 .745 0 r
F
.54855 .37936 m .54225 .37323 L .54232 .3788 L F
.54855 .37936 m .54263 .37883 L .54236 .37905 L F
.54855 .37936 m .54236 .37905 L .5425 .37978 L F
.54939 .38589 m .54855 .37936 L .5425 .37978 L .959 .739 0 r
F
.5425 .38527 m .5425 .37978 L .50809 .3821 L .954 .735 0 r
F
.5425 .38527 m .5425 .37978 L .50806 .38219 L .959 .739 0 r
F
.54939 .38589 m .5425 .37978 L .5425 .38527 L F
.54939 .38589 m .54294 .38532 L .54256 .38564 L F
.54939 .38589 m .54256 .38564 L .54269 .38636 L F
.55022 .39244 m .54939 .38589 L .54269 .38636 L .959 .733 0 r
F
.5426 .39176 m .54269 .38636 L .50847 .38864 L .954 .728 0 r
F
.5426 .39176 m .54269 .38636 L .50844 .38872 L .959 .733 0 r
F
.55022 .39244 m .54269 .38636 L .5426 .39176 L F
.55022 .39244 m .54319 .39181 L .54269 .39226 L F
.55022 .39244 m .54269 .39226 L .5428 .39294 L F
.55102 .39899 m .55022 .39244 L .5428 .39294 L .959 .727 0 r
F
.55102 .39899 m .5428 .39294 L .54278 .39363 L F
.54264 .39826 m .5428 .39294 L .50884 .39519 L .954 .722 0 r
F
.55102 .39899 m .54182 .39301 L .54264 .39826 L .959 .727 0 r
F
.5517 .40476 m .55102 .39899 L .54284 .39955 L .959 .721 0 r
F
.54264 .39826 m .54028 .39804 L .54284 .39954 L .954 .722 0 r
F
.55102 .39899 m .54262 .39899 L .5426 .39956 L .959 .727 0 r
F
.54264 .39826 m .54284 .39954 L .54285 .39955 L .954 .722 0 r
F
.55102 .39899 m .54337 .39832 L .54274 .39888 L .959 .727 0 r
F
.54276 .39899 m .54274 .39888 L .54262 .39899 L F
.55102 .39899 m .54274 .39888 L .54276 .39899 L F
.54284 .39955 m .53545 .3986 L .53369 .40015 L .954 .722 0 r
F
.5518 .40556 m .5517 .40476 L .54282 .40008 L .959 .721 0 r
F
.5518 .40556 m .54282 .40008 L .54281 .40014 L F
.54261 .40476 m .54284 .39955 L .50919 .40175 L .954 .715 0 r
F
.5517 .40476 m .54284 .39955 L .54193 .39961 L .959 .721 0 r
F
.5518 .40556 m .54193 .39961 L .54261 .40476 L F
.55256 .41214 m .5518 .40556 L .54281 .40617 L .959 .714 0 r
F
.54281 .40617 m .53564 .40523 L .53395 .40674 L .954 .715 0 r
F
.5518 .40556 m .54348 .40483 L .54272 .40553 L .959 .721 0 r
F
.54261 .40476 m .54017 .40454 L .54281 .40617 L .954 .715 0 r
F
.55256 .41214 m .54281 .40617 L .55187 .41176 L .959 .714 0 r
F
.54251 .41127 m .54281 .40617 L .50954 .40832 L .954 .709 0 r
F
.55256 .41214 m .54195 .40622 L .54251 .41127 L .959 .714 0 r
F
.5533 .41874 m .55256 .41214 L .54269 .4128 L .959 .708 0 r
F
.54269 .4128 m .53575 .41186 L .53412 .41335 L .954 .709 0 r
F
.55256 .41214 m .54351 .41136 L .54262 .41218 L .959 .714 0 r
F
.5533 .41874 m .54269 .4128 L .54622 .41508 L .959 .708 0 r
F
.54232 .41779 m .54269 .4128 L .50988 .41491 L .954 .702 0 r
F
.5533 .41874 m .54189 .41285 L .54232 .41779 L .959 .708 0 r
F
.55401 .42533 m .5533 .41874 L .5425 .41944 L .959 .702 0 r
F
.5425 .41944 m .53578 .41851 L .53419 .41997 L .954 .702 0 r
F
.5533 .41874 m .54346 .41788 L .54244 .41885 L .959 .708 0 r
F
.5425 .41944 m .54244 .41885 L .54175 .41949 L F
.5533 .41874 m .54244 .41885 L .5425 .41944 L F
.54232 .41779 m .53972 .41755 L .5425 .41944 L .954 .702 0 r
F
.5102 .4215 m .50988 .41491 L .46685 .41553 L 1 .748 0 r
F
.55401 .42533 m .5425 .41944 L .54448 .42079 L .959 .702 0 r
F
.54206 .42431 m .5425 .41944 L .5102 .4215 L .954 .696 0 r
F
.55401 .42533 m .54175 .41949 L .54206 .42431 L .959 .702 0 r
F
.55471 .43194 m .55401 .42533 L .54222 .4261 L .959 .695 0 r
F
.54222 .4261 m .53571 .42516 L .53417 .42661 L .954 .696 0 r
F
.55401 .42533 m .54334 .42442 L .54217 .42553 L .959 .702 0 r
F
.54222 .4261 m .54217 .42553 L .54152 .42614 L F
.55401 .42533 m .54217 .42553 L .54222 .4261 L F
.54206 .42431 m .53938 .42407 L .54222 .4261 L .954 .696 0 r
F
.51052 .4281 m .5102 .4215 L .46677 .42211 L 1 .741 0 r
F
.55471 .43194 m .54222 .4261 L .54349 .42701 L .959 .695 0 r
F
.54172 .43083 m .54222 .4261 L .51052 .4281 L .954 .689 0 r
F
.55471 .43194 m .54152 .42614 L .54172 .43083 L .959 .695 0 r
F
.55538 .43855 m .55471 .43194 L .54185 .43276 L .959 .689 0 r
F
.54185 .43276 m .53555 .43183 L .53405 .43325 L .954 .689 0 r
F
.55471 .43194 m .54314 .43095 L .54182 .43222 L .959 .695 0 r
F
.54185 .43276 m .54182 .43222 L .54121 .43281 L F
.55471 .43194 m .54182 .43222 L .54185 .43276 L F
.54172 .43083 m .53896 .43059 L .54185 .43276 L .954 .689 0 r
F
.51082 .43471 m .51052 .4281 L .46668 .42871 L 1 .735 0 r
F
.55538 .43855 m .54185 .43276 L .54273 .43342 L .959 .689 0 r
F
.54129 .43735 m .54185 .43276 L .51082 .43471 L .953 .682 0 r
F
.55538 .43855 m .54121 .43281 L .54129 .43735 L .959 .689 0 r
F
.55603 .44517 m .55538 .43855 L .5414 .43944 L .959 .682 0 r
F
.5414 .43944 m .53529 .4385 L .53381 .43991 L .953 .682 0 r
F
.55538 .43855 m .54285 .43749 L .54137 .43892 L .959 .689 0 r
F
.5414 .43944 m .54137 .43892 L .54079 .43948 L F
.55538 .43855 m .54137 .43892 L .5414 .43944 L F
.54129 .43735 m .53845 .43711 L .5414 .43944 L .953 .682 0 r
F
.51112 .44132 m .51082 .43471 L .4666 .43531 L 1 .729 0 r
F
.55603 .44517 m .5414 .43944 L .54202 .43994 L .959 .682 0 r
F
.54077 .44388 m .5414 .43944 L .51112 .44132 L .953 .676 0 r
F
.55603 .44517 m .54079 .43948 L .54077 .44388 L .959 .682 0 r
F
.55666 .4518 m .55603 .44517 L .54084 .44612 L .959 .676 0 r
F
.54084 .44612 m .53492 .44517 L .53347 .44658 L .953 .676 0 r
F
.55603 .44517 m .54247 .44402 L .54083 .44563 L .959 .682 0 r
F
.54084 .44612 m .54083 .44563 L .54028 .44616 L F
.55603 .44517 m .54083 .44563 L .54084 .44612 L F
.54077 .44388 m .53784 .44363 L .54084 .44612 L .953 .676 0 r
F
.5114 .44794 m .51112 .44132 L .46652 .44191 L 1 .722 0 r
F
.55666 .4518 m .54084 .44612 L .5413 .44651 L .959 .676 0 r
F
.54016 .4504 m .54084 .44612 L .5114 .44794 L .953 .669 0 r
F
.55666 .4518 m .54028 .44616 L .54016 .4504 L .959 .676 0 r
F
.55727 .45842 m .55666 .4518 L .54018 .45282 L .959 .67 0 r
F
.54018 .45282 m .53445 .45185 L .53301 .45326 L .953 .669 0 r
F
.55666 .4518 m .54201 .45056 L .54018 .45235 L .959 .676 0 r
F
.54018 .45282 m .54018 .45235 L .53967 .45285 L F
.55666 .4518 m .54018 .45235 L .54018 .45282 L F
.54016 .4504 m .53714 .45014 L .54018 .45282 L .953 .669 0 r
F
.51168 .45456 m .5114 .44794 L .46644 .44852 L 1 .716 0 r
F
.55727 .45842 m .54018 .45282 L .54053 .45312 L .959 .67 0 r
F
.53946 .45692 m .54018 .45282 L .51168 .45456 L .953 .662 0 r
F
.55727 .45842 m .53967 .45285 L .53946 .45692 L .959 .67 0 r
F
.55785 .46505 m .55727 .45842 L .53942 .45952 L .959 .663 0 r
F
.53942 .45952 m .53387 .45852 L .53243 .45994 L .953 .662 0 r
F
.55727 .45842 m .54145 .45709 L .53942 .45907 L .959 .67 0 r
F
.53942 .45952 m .53942 .45907 L .53894 .45954 L F
.55727 .45842 m .53942 .45907 L .53942 .45952 L F
.53946 .45692 m .53633 .45666 L .53942 .45952 L .953 .662 0 r
F
.51194 .46118 m .51168 .45456 L .46636 .45514 L 1 .71 0 r
F
.55785 .46505 m .53942 .45952 L .53968 .45976 L .959 .663 0 r
F
.53865 .46344 m .53942 .45952 L .51194 .46118 L .952 .655 0 r
F
.55785 .46505 m .53894 .45954 L .53865 .46344 L .959 .663 0 r
F
.55841 .47168 m .55785 .46505 L .53854 .46622 L .958 .656 0 r
F
.53854 .46622 m .53317 .4652 L .53172 .46663 L .952 .655 0 r
F
.55785 .46505 m .54079 .46362 L .53856 .4658 L .959 .663 0 r
F
.53854 .46622 m .53856 .4658 L .5381 .46625 L F
.55785 .46505 m .53856 .4658 L .53854 .46622 L F
.53865 .46344 m .53541 .46317 L .53854 .46622 L .952 .655 0 r
F
.55841 .47168 m .53854 .46622 L .53874 .46642 L .958 .656 0 r
F
.53773 .46995 m .53854 .46622 L .51219 .46781 L .952 .649 0 r
F
.55841 .47168 m .5381 .46625 L .53773 .46995 L .958 .656 0 r
F
.55895 .47831 m .55841 .47168 L .53754 .47293 L .958 .65 0 r
F
.53754 .47293 m .53235 .47188 L .53087 .47333 L .952 .649 0 r
F
.55841 .47168 m .54002 .47014 L .53756 .47254 L .958 .656 0 r
F
.53754 .47293 m .53756 .47254 L .53714 .47295 L F
.55841 .47168 m .53756 .47254 L .53754 .47293 L F
.53773 .46995 m .53437 .46967 L .53754 .47293 L .952 .649 0 r
F
.54002 .47014 m .51215 .46782 L .53714 .47295 L .958 .656 0 r
F
.55835 .47169 m .53773 .46995 L .53754 .47293 L .952 .649 0 r
F
.55835 .47169 m .55779 .46506 L .53854 .46622 L F
.53874 .46642 m .53854 .46622 L .53851 .46635 L .958 .656 0 r
F
.55835 .47169 m .53854 .46622 L .53773 .46995 L .952 .649 0 r
F
.53851 .46635 m .53854 .46622 L .5381 .46625 L .958 .656 0 r
F
.54079 .46362 m .5119 .4612 L .5381 .46625 L .959 .663 0 r
F
.55779 .46506 m .53865 .46344 L .53854 .46622 L .952 .655 0 r
F
.55779 .46506 m .55721 .45844 L .53942 .45952 L F
.53968 .45976 m .53942 .45952 L .53939 .45967 L .959 .663 0 r
F
.55779 .46506 m .53942 .45952 L .53865 .46344 L .952 .655 0 r
F
.53939 .45967 m .53942 .45952 L .53894 .45954 L .959 .663 0 r
F
.54145 .45709 m .51164 .45459 L .53894 .45954 L .959 .67 0 r
F
.55721 .45844 m .53946 .45692 L .53942 .45952 L .953 .662 0 r
F
.55721 .45844 m .55661 .45181 L .54018 .45282 L F
.54053 .45312 m .54018 .45282 L .54015 .453 L .959 .67 0 r
F
.55721 .45844 m .54018 .45282 L .53946 .45692 L .953 .662 0 r
F
.54015 .453 m .54018 .45282 L .53967 .45285 L .959 .67 0 r
F
.54201 .45056 m .51136 .44797 L .53967 .45285 L .959 .676 0 r
F
.55661 .45181 m .54016 .4504 L .54018 .45282 L .953 .669 0 r
F
.55661 .45181 m .55599 .44519 L .54084 .44612 L F
.5413 .44651 m .54084 .44612 L .54081 .44634 L .959 .676 0 r
F
.55661 .45181 m .54084 .44612 L .54016 .4504 L .953 .669 0 r
F
.54081 .44634 m .54084 .44612 L .54028 .44616 L .959 .676 0 r
F
.54247 .44402 m .51108 .44136 L .54028 .44616 L .959 .682 0 r
F
.55599 .44519 m .54077 .44388 L .54084 .44612 L .953 .676 0 r
F
.55599 .44519 m .55534 .43857 L .5414 .43944 L F
.54202 .43994 m .5414 .43944 L .54136 .43969 L .959 .682 0 r
F
.55599 .44519 m .5414 .43944 L .54077 .44388 L .953 .676 0 r
F
.54136 .43969 m .5414 .43944 L .54079 .43948 L .959 .682 0 r
F
.54285 .43749 m .51079 .43476 L .54079 .43948 L .959 .689 0 r
F
.55534 .43857 m .54129 .43735 L .5414 .43944 L .953 .682 0 r
F
.55534 .43857 m .55467 .43196 L .54185 .43276 L F
.54273 .43342 m .54185 .43276 L .54182 .43305 L .959 .689 0 r
F
.55534 .43857 m .54185 .43276 L .54129 .43735 L .953 .682 0 r
F
.54182 .43305 m .54185 .43276 L .54121 .43281 L .959 .689 0 r
F
.54314 .43095 m .51048 .42816 L .54121 .43281 L .959 .695 0 r
F
.55467 .43196 m .54172 .43083 L .54185 .43276 L .954 .689 0 r
F
.55467 .43196 m .55398 .42535 L .54222 .4261 L F
.54349 .42701 m .54222 .4261 L .54218 .42643 L .959 .695 0 r
F
.55467 .43196 m .54222 .4261 L .54172 .43083 L .954 .689 0 r
F
.54218 .42643 m .54222 .4261 L .54152 .42614 L .959 .695 0 r
F
.54334 .42442 m .51017 .42156 L .54152 .42614 L .959 .702 0 r
F
.55398 .42535 m .54206 .42431 L .54222 .4261 L .954 .696 0 r
F
.55398 .42535 m .55327 .41876 L .5425 .41944 L F
.54448 .42079 m .5425 .41944 L .54246 .41983 L .959 .702 0 r
F
.55398 .42535 m .5425 .41944 L .54206 .42431 L .954 .696 0 r
F
.54246 .41983 m .5425 .41944 L .54175 .41949 L .959 .702 0 r
F
.54346 .41788 m .50984 .41497 L .54175 .41949 L .959 .708 0 r
F
.55327 .41876 m .54232 .41779 L .5425 .41944 L .954 .702 0 r
F
.55327 .41876 m .55253 .41216 L .54269 .4128 L F
.54622 .41508 m .54269 .4128 L .54266 .41325 L .959 .708 0 r
F
.55327 .41876 m .54269 .4128 L .54232 .41779 L .954 .702 0 r
F
.54266 .41325 m .54269 .4128 L .54189 .41285 L .959 .708 0 r
F
.54269 .4128 m .54262 .41218 L .54189 .41285 L .959 .714 0 r
F
.55256 .41214 m .54262 .41218 L .54269 .4128 L F
.54251 .41127 m .53999 .41104 L .54269 .4128 L .954 .709 0 r
F
.50988 .41491 m .50954 .40832 L .46694 .40895 L 1 .754 0 r
F
.54351 .41136 m .5095 .40839 L .54189 .41285 L .959 .714 0 r
F
.55253 .41216 m .54251 .41127 L .54269 .4128 L .954 .709 0 r
F
.55253 .41216 m .55178 .40558 L .54281 .40617 L F
.55187 .41176 m .54281 .40617 L .54277 .40668 L .959 .714 0 r
F
.55253 .41216 m .54281 .40617 L .54251 .41127 L .954 .709 0 r
F
.54277 .40668 m .54281 .40617 L .54195 .40622 L .959 .714 0 r
F
.54281 .40617 m .54272 .40553 L .54195 .40622 L .959 .721 0 r
F
.5518 .40556 m .54272 .40553 L .54281 .40617 L F
.55178 .40558 m .54261 .40476 L .54281 .40617 L .954 .715 0 r
F
.55178 .40558 m .551 .39901 L .54284 .39955 L F
.55178 .40558 m .54284 .39955 L .54261 .40476 L F
.54281 .40014 m .54282 .40008 L .54193 .39961 L .959 .721 0 r
F
.5426 .39956 m .54262 .39899 L .54193 .39961 L .959 .727 0 r
F
.551 .39901 m .54283 .39296 L .54264 .39826 L .954 .722 0 r
F
.54283 .39296 m .5428 .39294 L .54264 .39826 L F
.551 .39901 m .5502 .39246 L .5428 .39294 L F
.54278 .39363 m .5428 .39294 L .54182 .39301 L .959 .727 0 r
F
.54285 .39955 m .54284 .39954 L .54284 .39955 L .954 .722 0 r
F
.54284 .39954 m .54028 .39804 L .54284 .39955 L F
.54274 .39888 m .5088 .39527 L .54193 .39961 L .959 .727 0 r
F
.54337 .39832 m .54264 .39826 L .54274 .39888 L F
.54264 .39826 m .5088 .39527 L .54274 .39888 L F
.54264 .39826 m .54182 .39301 L .5088 .39527 L F
.551 .39901 m .54264 .39826 L .54285 .39955 L .954 .722 0 r
F
.5502 .39246 m .54938 .38591 L .54269 .38636 L .954 .728 0 r
F
.5502 .39246 m .54269 .38636 L .5426 .39176 L F
.54938 .38591 m .54853 .37938 L .5425 .37978 L .954 .735 0 r
F
.54938 .38591 m .5425 .37978 L .5425 .38527 L F
.54853 .37938 m .54767 .37286 L .54225 .37323 L .954 .741 0 r
F
.54853 .37938 m .54225 .37323 L .54232 .3788 L F
.54767 .37286 m .54678 .36637 L .54193 .3667 L .954 .747 0 r
F
.54767 .37286 m .54193 .3667 L .54207 .37234 L F
.54678 .36637 m .54588 .35988 L .54155 .36018 L .954 .754 0 r
F
.54678 .36637 m .54155 .36018 L .54176 .36589 L F
.54588 .35988 m .54495 .35342 L .54111 .35369 L .953 .76 0 r
F
.54588 .35988 m .54111 .35369 L .54139 .35945 L F
.54495 .35342 m .544 .34698 L .54061 .34722 L .953 .766 0 r
F
.54495 .35342 m .54061 .34722 L .54096 .35304 L F
.544 .34698 m .54303 .34056 L .54004 .34077 L .953 .772 0 r
F
.544 .34698 m .54004 .34077 L .54047 .34663 L F
.54303 .34056 m .54204 .33416 L .53942 .33435 L .952 .779 0 r
F
.54303 .34056 m .53942 .33435 L .53992 .34025 L F
.54204 .33416 m .54103 .32779 L .53875 .32795 L .952 .785 0 r
F
.54204 .33416 m .53875 .32795 L .53931 .33389 L F
.54103 .32779 m .53999 .32144 L .53803 .32158 L .951 .791 0 r
F
.54103 .32779 m .53803 .32158 L .53865 .32754 L F
.53999 .32144 m .53894 .31511 L .53725 .31524 L .951 .797 0 r
F
.53999 .32144 m .53725 .31524 L .53793 .32122 L F
.53894 .31511 m .53787 .30881 L .53642 .30892 L .95 .803 0 r
F
.53894 .31511 m .53642 .30892 L .53716 .31493 L F
.53787 .30881 m .53678 .30254 L .53555 .30264 L .95 .809 0 r
F
.53787 .30881 m .53555 .30264 L .53635 .30865 L F
.53678 .30254 m .53567 .29631 L .53463 .29638 L .949 .815 0 r
F
.53678 .30254 m .53463 .29638 L .53549 .30241 L F
.53567 .29631 m .53454 .2901 L .53367 .29016 L .949 .822 0 r
F
.53567 .29631 m .53367 .29016 L .53458 .29619 L F
.53454 .2901 m .53338 .28392 L .53267 .28397 L .948 .828 0 r
F
.53454 .29009 m .53271 .28427 L .53362 .29 L .951 .831 0 r
F
.53454 .2901 m .53267 .28397 L .53362 .29 L .948 .828 0 r
F
.53362 .29 m .53271 .28427 L .50123 .28654 L .951 .831 0 r
F
.53163 .27782 m .52991 .27752 L .52902 .27804 L .95 .842 0 r
F
.53159 .2777 m .52991 .27752 L .53163 .27782 L F
.52902 .27804 m .50016 .27424 L .5007 .28037 L F
.52991 .27752 m .50016 .27424 L .52902 .27804 L F
.53267 .28397 m .52112 .28264 L .51668 .28523 L .947 .834 0 r
F
.53338 .28392 m .53263 .28383 L .53267 .28397 L .95 .837 0 r
F
.53338 .28392 m .53263 .28383 L .53267 .28397 L .947 .834 0 r
F
.53267 .28397 m .53104 .28366 L .53017 .28418 L .95 .837 0 r
F
.53263 .28383 m .53104 .28366 L .53267 .28397 L F
.53017 .28418 m .5007 .28037 L .50123 .28654 L F
.53104 .28366 m .5007 .28037 L .53017 .28418 L F
.53367 .29016 m .52231 .28886 L .51808 .29137 L .948 .828 0 r
F
.53454 .29009 m .53362 .29 L .53367 .29016 L .951 .831 0 r
F
.53454 .2901 m .53362 .29 L .53367 .29016 L .948 .828 0 r
F
.53367 .29016 m .53214 .28984 L .53129 .29035 L .951 .831 0 r
F
.53362 .29 m .53214 .28984 L .53367 .29016 L F
.53129 .29035 m .50123 .28654 L .50176 .29274 L F
.53214 .28984 m .50123 .28654 L .53129 .29035 L F
.53463 .29638 m .52346 .29511 L .51945 .29755 L .949 .822 0 r
F
.53567 .2963 m .53458 .29619 L .53463 .29638 L .952 .825 0 r
F
.53567 .29631 m .53458 .29619 L .53463 .29638 L .949 .822 0 r
F
.53463 .29638 m .5332 .29604 L .53236 .29657 L .952 .825 0 r
F
.53458 .29619 m .5332 .29604 L .53463 .29638 L F
.53236 .29657 m .50176 .29274 L .50227 .29897 L F
.5332 .29604 m .50176 .29274 L .53236 .29657 L F
.53555 .30264 m .52458 .30139 L .52077 .30376 L .949 .815 0 r
F
.53678 .30254 m .53549 .30241 L .53555 .30264 L .953 .819 0 r
F
.53678 .30254 m .53549 .30241 L .53555 .30264 L .949 .815 0 r
F
.53555 .30264 m .53423 .30228 L .53339 .30281 L .953 .819 0 r
F
.53549 .30241 m .53423 .30228 L .53555 .30264 L F
.53339 .30281 m .50227 .29897 L .50277 .30523 L F
.53423 .30228 m .50227 .29897 L .53339 .30281 L F
.53642 .30892 m .52567 .30771 L .52206 .31 L .95 .809 0 r
F
.53787 .30881 m .53635 .30865 L .53642 .30892 L .953 .813 0 r
F
.53787 .30881 m .53635 .30865 L .53642 .30892 L .95 .809 0 r
F
.53642 .30892 m .53521 .30854 L .53437 .30908 L .953 .813 0 r
F
.53635 .30865 m .53521 .30854 L .53642 .30892 L F
.53437 .30908 m .50277 .30523 L .50327 .31151 L F
.53521 .30854 m .50277 .30523 L .53437 .30908 L F
.53725 .31524 m .52672 .31405 L .52329 .31627 L .95 .803 0 r
F
.53895 .31511 m .53716 .31493 L .53725 .31524 L .954 .807 0 r
F
.53894 .31511 m .53716 .31493 L .53725 .31524 L .95 .803 0 r
F
.53725 .31524 m .53614 .31482 L .53529 .31539 L .954 .807 0 r
F
.53716 .31493 m .53614 .31482 L .53725 .31524 L F
.53529 .31539 m .50327 .31151 L .50375 .31783 L F
.53614 .31482 m .50327 .31151 L .53529 .31539 L F
.53803 .32158 m .52772 .32042 L .52448 .32257 L .951 .797 0 r
F
.54 .32143 m .53793 .32122 L .53803 .32158 L .955 .8 0 r
F
.53999 .32144 m .53793 .32122 L .53803 .32158 L .951 .797 0 r
F
.53803 .32158 m .53703 .32113 L .53617 .32172 L .955 .8 0 r
F
.53793 .32122 m .53703 .32113 L .53803 .32158 L F
.53617 .32172 m .50375 .31783 L .50423 .32416 L F
.53703 .32113 m .50375 .31783 L .53617 .32172 L F
.53875 .32795 m .52868 .32681 L .52561 .32891 L .951 .791 0 r
F
.54103 .32778 m .53865 .32754 L .53875 .32795 L .955 .794 0 r
F
.54103 .32779 m .53865 .32754 L .53875 .32795 L .951 .791 0 r
F
.53875 .32795 m .53787 .32747 L .53699 .32808 L .955 .794 0 r
F
.53865 .32754 m .53787 .32747 L .53875 .32795 L F
.53699 .32808 m .50423 .32416 L .50469 .33053 L F
.53787 .32747 m .50423 .32416 L .53699 .32808 L F
.53942 .33435 m .5296 .33324 L .52669 .33526 L .952 .785 0 r
F
.54204 .33415 m .53931 .33389 L .53942 .33435 L .956 .788 0 r
F
.54204 .33416 m .53931 .33389 L .53942 .33435 L .952 .785 0 r
F
.53942 .33435 m .53867 .33382 L .53776 .33447 L .956 .788 0 r
F
.53931 .33389 m .53867 .33382 L .53942 .33435 L F
.53776 .33447 m .50469 .33053 L .50515 .33692 L F
.53867 .33382 m .50469 .33053 L .53776 .33447 L F
.54004 .34077 m .53046 .33968 L .5277 .34165 L .952 .779 0 r
F
.54303 .34055 m .53992 .34025 L .54004 .34077 L .956 .782 0 r
F
.54303 .34056 m .53992 .34025 L .54004 .34077 L .952 .779 0 r
F
.54004 .34077 m .53941 .3402 L .53847 .34089 L .956 .782 0 r
F
.53992 .34025 m .53941 .3402 L .54004 .34077 L F
.53847 .34089 m .50515 .33692 L .50559 .34332 L F
.53941 .3402 m .50515 .33692 L .53847 .34089 L F
.54061 .34722 m .53127 .34615 L .52866 .34806 L .953 .772 0 r
F
.544 .34697 m .54047 .34663 L .54061 .34722 L .957 .776 0 r
F
.544 .34698 m .54047 .34663 L .54061 .34722 L .953 .772 0 r
F
.54061 .34722 m .54009 .3466 L .53911 .34733 L .957 .776 0 r
F
.54047 .34663 m .54009 .3466 L .54061 .34722 L F
.53911 .34733 m .50559 .34332 L .50603 .34976 L F
.54009 .3466 m .50559 .34332 L .53911 .34733 L F
.54111 .35369 m .53202 .35264 L .52955 .3545 L .953 .766 0 r
F
.54495 .35341 m .54096 .35304 L .54111 .35369 L .957 .77 0 r
F
.54495 .35342 m .54096 .35304 L .54111 .35369 L .953 .766 0 r
F
.54111 .35369 m .54072 .35301 L .5397 .35379 L .957 .77 0 r
F
.54096 .35304 m .54072 .35301 L .54111 .35369 L F
.5397 .35379 m .50603 .34976 L .50646 .35621 L F
.54072 .35301 m .50603 .34976 L .5397 .35379 L F
.54155 .36018 m .53271 .35916 L .53037 .36096 L .953 .76 0 r
F
.54588 .35988 m .54139 .35945 L .54155 .36018 L F
.54155 .36018 m .54129 .35944 L .54023 .36028 L .958 .764 0 r
F
.54139 .35945 m .54129 .35944 L .54155 .36018 L F
.54023 .36028 m .50646 .35621 L .50687 .36268 L F
.54129 .35944 m .50646 .35621 L .54023 .36028 L F
.54193 .3667 m .53334 .36569 L .53111 .36744 L .954 .754 0 r
F
.54678 .36637 m .54176 .36589 L .54193 .3667 L F
.54193 .3667 m .54177 .36591 L .54068 .36679 L .958 .758 0 r
F
.54068 .36679 m .50687 .36268 L .50728 .36916 L F
.5418 .36589 m .50687 .36268 L .54068 .36679 L F
.54225 .37323 m .53391 .37224 L .53179 .37394 L .954 .747 0 r
F
.54767 .37286 m .54207 .37234 L .54225 .37323 L F
.54225 .37323 m .5421 .37247 L .54108 .37331 L .958 .752 0 r
F
.54108 .37331 m .50728 .36916 L .50767 .37567 L F
.54224 .37235 m .50728 .36916 L .54108 .37331 L F
.5425 .37978 m .5344 .37881 L .53239 .38047 L .954 .741 0 r
F
.54853 .37938 m .54232 .3788 L .5425 .37978 L F
.5425 .37978 m .54236 .37905 L .5414 .37986 L .958 .745 0 r
F
.5414 .37986 m .50767 .37567 L .50806 .38219 L F
.54263 .37883 m .50767 .37567 L .5414 .37986 L F
.54269 .38636 m .53483 .38539 L .5329 .38701 L .954 .735 0 r
F
.54938 .38591 m .5425 .38527 L .54269 .38636 L F
.54269 .38636 m .54256 .38564 L .54165 .38643 L .959 .739 0 r
F
.54165 .38643 m .50806 .38219 L .50844 .38872 L F
.54294 .38532 m .50806 .38219 L .54165 .38643 L F
.5428 .39294 m .53518 .39199 L .53334 .39357 L .954 .728 0 r
F
.5502 .39246 m .5426 .39176 L .5428 .39294 L F
.5428 .39294 m .54269 .39226 L .54182 .39301 L .959 .733 0 r
F
.54182 .39301 m .50844 .38872 L .5088 .39527 L F
.54319 .39181 m .50844 .38872 L .54182 .39301 L F
.50954 .40832 m .50919 .40175 L .46703 .40238 L 1 .76 0 r
F
.54261 .40476 m .54193 .39961 L .50916 .40183 L .959 .721 0 r
F
.50919 .40175 m .46712 .39583 L .46703 .40238 L 1 .766 0 r
F
.54193 .39961 m .5088 .39527 L .50916 .40183 L .959 .727 0 r
F
.54251 .41127 m .54195 .40622 L .5095 .40839 L .959 .714 0 r
F
.50954 .40832 m .46703 .40238 L .46694 .40895 L 1 .76 0 r
F
.54195 .40622 m .50916 .40183 L .5095 .40839 L .959 .721 0 r
F
.54348 .40483 m .50916 .40183 L .54195 .40622 L F
.54232 .41779 m .54189 .41285 L .50984 .41497 L .959 .708 0 r
F
.50988 .41491 m .46694 .40895 L .46685 .41553 L 1 .754 0 r
F
.54189 .41285 m .5095 .40839 L .50984 .41497 L .959 .714 0 r
F
.54206 .42431 m .54175 .41949 L .51017 .42156 L .959 .702 0 r
F
.5102 .4215 m .46685 .41553 L .46677 .42211 L 1 .748 0 r
F
.54175 .41949 m .50984 .41497 L .51017 .42156 L .959 .708 0 r
F
.54172 .43083 m .54152 .42614 L .51048 .42816 L .959 .695 0 r
F
.51052 .4281 m .46677 .42211 L .46668 .42871 L 1 .741 0 r
F
.54152 .42614 m .51017 .42156 L .51048 .42816 L .959 .702 0 r
F
.54129 .43735 m .54121 .43281 L .51079 .43476 L .959 .689 0 r
F
.51082 .43471 m .46668 .42871 L .4666 .43531 L 1 .735 0 r
F
.54121 .43281 m .51048 .42816 L .51079 .43476 L .959 .695 0 r
F
.54077 .44388 m .54079 .43948 L .51108 .44136 L .959 .682 0 r
F
.51112 .44132 m .4666 .43531 L .46652 .44191 L 1 .729 0 r
F
.54079 .43948 m .51079 .43476 L .51108 .44136 L .959 .689 0 r
F
.54016 .4504 m .54028 .44616 L .51136 .44797 L .959 .676 0 r
F
.5114 .44794 m .46652 .44191 L .46644 .44852 L 1 .722 0 r
F
.54028 .44616 m .51108 .44136 L .51136 .44797 L .959 .682 0 r
F
.53946 .45692 m .53967 .45285 L .51164 .45459 L .959 .67 0 r
F
.51168 .45456 m .46644 .44852 L .46636 .45514 L 1 .716 0 r
F
.53967 .45285 m .51136 .44797 L .51164 .45459 L .959 .676 0 r
F
.53865 .46344 m .53894 .45954 L .5119 .4612 L .959 .663 0 r
F
.53894 .45954 m .51164 .45459 L .5119 .4612 L .959 .67 0 r
F
.53773 .46995 m .5381 .46625 L .51215 .46782 L .958 .656 0 r
F
.5381 .46625 m .5119 .4612 L .51215 .46782 L .959 .663 0 r
F
.55895 .47831 m .53754 .47293 L .53769 .47309 L .958 .65 0 r
F
.5367 .47646 m .53754 .47293 L .51243 .47443 L .951 .642 0 r
F
.55895 .47831 m .53714 .47295 L .5367 .47646 L .958 .65 0 r
F
.55895 .47831 m .5367 .47646 L .5364 .47964 L F
.55888 .47831 m .55835 .47169 L .53754 .47293 L .951 .642 0 r
F
.53769 .47309 m .53754 .47293 L .53751 .47304 L .958 .65 0 r
F
.55888 .47831 m .53754 .47293 L .5367 .47646 L .951 .642 0 r
F
.53751 .47304 m .53754 .47293 L .53714 .47295 L .958 .65 0 r
F
.5367 .47646 m .53714 .47295 L .5124 .47443 L F
.53714 .47295 m .51215 .46782 L .5124 .47443 L .958 .656 0 r
F
.5364 .47964 m .5124 .47443 L .51263 .48105 L .958 .65 0 r
F
.5367 .47646 m .5124 .47443 L .5364 .47964 L F
.55888 .47831 m .5367 .47646 L .5364 .47964 L .951 .642 0 r
F
.55939 .48493 m .55888 .47831 L .5364 .47964 L .951 .635 0 r
F
.55939 .48493 m .5364 .47964 L .53555 .48295 L F
.53638 .47974 m .5364 .47964 L .53604 .47966 L .958 .643 0 r
F
.53504 .48636 m .51267 .48105 L .53504 .48636 L .951 .635 0 r
F
.53505 .48634 m .51267 .48105 L .53507 .48636 L F
.53555 .48295 m .51267 .48105 L .53513 .48636 L F
.53555 .48295 m .53604 .47966 L .51263 .48105 L .958 .643 0 r
F
.53507 .48636 m .53504 .48636 L .53504 .48636 L .951 .635 0 r
F
.53513 .48636 m .53505 .48634 L .53507 .48636 L F
.53513 .48636 m .51263 .48105 L .51285 .48766 L .958 .643 0 r
F
.53555 .48295 m .51263 .48105 L .53513 .48636 L F
.55939 .48493 m .53555 .48295 L .53513 .48636 L .951 .635 0 r
F
.46636 .45514 m .42162 .44694 L .42119 .45354 L 1 .762 0 r
F
.46636 .45514 m .46644 .44852 L .42162 .44694 L F
.51285 .48766 m .46607 .4816 L .466 .48818 L 1 .693 0 r
F
.51285 .48766 m .51263 .48105 L .46607 .4816 L F
.51306 .49427 m .51285 .48766 L .466 .48818 L 1 .687 0 r
F
.51263 .48105 m .46614 .475 L .46607 .4816 L 1 .7 0 r
F
.51263 .48105 m .5124 .47443 L .46614 .475 L F
.51306 .49427 m .466 .48818 L .46593 .49477 L 1 .687 0 r
F
.51326 .50088 m .51306 .49427 L .46593 .49477 L 1 .681 0 r
F
.46607 .4816 m .42032 .47341 L .41996 .47997 L 1 .748 0 r
F
.46607 .4816 m .46614 .475 L .42032 .47341 L F
.466 .48818 m .46607 .4816 L .41996 .47997 L 1 .742 0 r
F
.466 .48818 m .41996 .47997 L .41961 .48652 L F
.46593 .49477 m .466 .48818 L .41961 .48652 L 1 .737 0 r
F
.46564 .52119 m .41788 .51294 L .41758 .51952 L 1 .698 0 r
F
.46557 .52777 m .46564 .52119 L .41758 .51952 L 1 .691 0 r
F
.5124 .47443 m .46622 .46841 L .46614 .475 L 1 .706 0 r
F
.5124 .47443 m .51215 .46782 L .46622 .46841 L F
.46614 .475 m .4207 .46684 L .42032 .47341 L 1 .753 0 r
F
.46614 .475 m .46622 .46841 L .4207 .46684 L F
.46593 .49477 m .41961 .48652 L .41927 .49307 L 1 .737 0 r
F
.46586 .50135 m .46593 .49477 L .41927 .49307 L 1 .731 0 r
F
.51326 .50088 m .46593 .49477 L .46586 .50135 L 1 .681 0 r
F
.51345 .50748 m .51326 .50088 L .46586 .50135 L 1 .675 0 r
F
.51215 .46782 m .46629 .46181 L .46622 .46841 L 1 .712 0 r
F
.51215 .46782 m .5119 .4612 L .46629 .46181 L F
.46644 .44852 m .42207 .44034 L .42162 .44694 L 1 .769 0 r
F
.46644 .44852 m .46652 .44191 L .42207 .44034 L F
.46622 .46841 m .42109 .46027 L .4207 .46684 L 1 .759 0 r
F
.46622 .46841 m .46629 .46181 L .42109 .46027 L F
.46586 .50135 m .41927 .49307 L .41895 .49961 L 1 .731 0 r
F
.46579 .50792 m .46586 .50135 L .41895 .49961 L 1 .726 0 r
F
.51345 .50748 m .46586 .50135 L .46579 .50792 L 1 .675 0 r
F
.51363 .51407 m .51345 .50748 L .46579 .50792 L 1 .669 0 r
F
.5119 .4612 m .46637 .45522 L .46629 .46181 L 1 .718 0 r
F
.5119 .4612 m .51164 .45459 L .46637 .45522 L F
.46579 .50792 m .41895 .49961 L .41864 .50614 L 1 .726 0 r
F
.46572 .51448 m .46579 .50792 L .41864 .50614 L 1 .72 0 r
F
.51363 .51407 m .46579 .50792 L .46572 .51448 L 1 .669 0 r
F
.46557 .52777 m .41758 .51952 L .4173 .52609 L 1 .691 0 r
F
.46551 .53433 m .46557 .52777 L .4173 .52609 L 1 .684 0 r
F
.46629 .46181 m .4215 .45371 L .42109 .46027 L 1 .765 0 r
F
.46629 .46181 m .46637 .45522 L .4215 .45371 L F
.5138 .52066 m .51363 .51407 L .46572 .51448 L 1 .662 0 r
F
.46652 .44191 m .42253 .43375 L .42207 .44034 L 1 .775 0 r
F
.46652 .44191 m .4666 .43531 L .42253 .43375 L F
.51164 .45459 m .46645 .44862 L .46637 .45522 L 1 .724 0 r
F
.51164 .45459 m .51136 .44797 L .46645 .44862 L F
.46572 .51448 m .41864 .50614 L .41835 .51266 L 1 .72 0 r
F
.46566 .52104 m .46572 .51448 L .41835 .51266 L 1 .715 0 r
F
.5138 .52066 m .46572 .51448 L .46566 .52104 L 1 .662 0 r
F
.46637 .45522 m .42192 .44714 L .4215 .45371 L 1 .77 0 r
F
.46637 .45522 m .46645 .44862 L .42192 .44714 L F
.51396 .52724 m .5138 .52066 L .46566 .52104 L 1 .656 0 r
F
.46551 .53433 m .4173 .52609 L .41702 .53265 L 1 .684 0 r
F
.46545 .54088 m .46551 .53433 L .41702 .53265 L 1 .678 0 r
F
.46566 .52104 m .41835 .51266 L .41807 .51917 L 1 .715 0 r
F
.46559 .52759 m .46566 .52104 L .41807 .51917 L 1 .71 0 r
F
.51396 .52724 m .46566 .52104 L .46559 .52759 L 1 .656 0 r
F
.46645 .44862 m .42235 .44057 L .42192 .44714 L 1 .776 0 r
F
.46645 .44862 m .46653 .44203 L .42235 .44057 L F
.51136 .44797 m .46653 .44203 L .46645 .44862 L 1 .73 0 r
F
.51136 .44797 m .51108 .44136 L .46653 .44203 L F
.4666 .43531 m .42301 .42717 L .42253 .43375 L 1 .781 0 r
F
.4666 .43531 m .46668 .42871 L .42301 .42717 L F
.51411 .53381 m .51396 .52724 L .46559 .52759 L 1 .649 0 r
F
.46559 .52759 m .41807 .51917 L .41781 .52566 L 1 .71 0 r
F
.46553 .53413 m .46559 .52759 L .41781 .52566 L 1 .704 0 r
F
.51411 .53381 m .46559 .52759 L .46553 .53413 L 1 .649 0 r
F
.46545 .54088 m .41702 .53265 L .41677 .5392 L 1 .678 0 r
F
.46539 .54741 m .46545 .54088 L .41677 .5392 L 1 .67 0 r
F
.51438 .54692 m .46545 .54088 L .46539 .54741 L .998 .621 0 r
F
.46653 .44203 m .4228 .43401 L .42235 .44057 L 1 .782 0 r
F
.46653 .44203 m .46661 .43544 L .4228 .43401 L F
.51108 .44136 m .46661 .43544 L .46653 .44203 L 1 .736 0 r
F
.51108 .44136 m .51079 .43476 L .46661 .43544 L F
.51425 .54037 m .51411 .53381 L .46553 .53413 L 1 .643 0 r
F
.46668 .42871 m .4235 .42059 L .42301 .42717 L 1 .787 0 r
F
.46668 .42871 m .46677 .42211 L .4235 .42059 L F
.46553 .53413 m .41781 .52566 L .41756 .53214 L 1 .704 0 r
F
.46547 .54066 m .46553 .53413 L .41756 .53214 L 1 .699 0 r
F
.51425 .54037 m .46553 .53413 L .46547 .54066 L 1 .643 0 r
F
.46661 .43544 m .42326 .42744 L .4228 .43401 L 1 .787 0 r
F
.46661 .43544 m .4667 .42885 L .42326 .42744 L F
.51079 .43476 m .4667 .42885 L .46661 .43544 L 1 .742 0 r
F
.51079 .43476 m .51048 .42816 L .4667 .42885 L F
.41921 .48657 m .37381 .47615 L .37315 .48275 L 1 .778 0 r
F
.41921 .48657 m .41958 .47996 L .37381 .47615 L F
.41886 .49317 m .41921 .48657 L .37315 .48275 L 1 .772 0 r
F
.41958 .47996 m .3745 .46956 L .37381 .47615 L 1 .785 0 r
F
.41958 .47996 m .41996 .47336 L .3745 .46956 L F
.46539 .54741 m .41677 .5392 L .41652 .54574 L 1 .67 0 r
F
.46533 .55394 m .46539 .54741 L .41652 .54574 L 1 .663 0 r
F
.51237 .55318 m .51438 .54692 L .46539 .54741 L .997 .613 0 r
F
.51425 .54966 m .51438 .54715 L .51414 .54787 L 1 .63 0 r
F
.51449 .55345 m .51438 .54715 L .51425 .54966 L F
.51438 .54715 m .51438 .54692 L .51237 .55318 L .997 .613 0 r
F
.51449 .55345 m .51408 .54692 L .51237 .55318 L 1 .63 0 r
F
.56341 .55094 m .51451 .54693 L .51449 .55345 L .952 .573 0 r
F
.51451 .54693 m .51439 .54692 L .5144 .54712 L .944 .561 0 r
F
.51439 .54692 m .51438 .54692 L .51438 .54715 L F
.51451 .54693 m .51438 .54692 L .51438 .54715 L .952 .573 0 r
F
.51451 .54693 m .51438 .54715 L .51449 .55345 L F
.56321 .55078 m .51451 .54693 L .51449 .55344 L .944 .561 0 r
F
.51451 .54693 m .5144 .54712 L .51449 .55344 L F
.51439 .54692 m .51438 .54715 L .51449 .55344 L F
.51449 .55344 m .51438 .54715 L .51237 .55318 L .997 .613 0 r
F
.51414 .54787 m .51438 .54692 L .51408 .54692 L 1 .63 0 r
F
.51438 .54715 m .51438 .54692 L .51414 .54787 L F
.51237 .55318 m .51408 .54692 L .46541 .54718 L F
.5123 .55347 m .46539 .54741 L .46533 .55394 L .997 .613 0 r
F
.51237 .55318 m .46539 .54741 L .5123 .55347 L F
.5123 .55347 m .46541 .54718 L .46535 .55369 L 1 .63 0 r
F
.51449 .55345 m .51237 .55318 L .5123 .55347 L F
.5123 .55347 m .51237 .55318 L .5123 .55347 L .997 .613 0 r
F
.51237 .55318 m .46541 .54718 L .5123 .55347 L 1 .63 0 r
F
.51449 .55344 m .51237 .55318 L .5123 .55347 L .997 .613 0 r
F
.41886 .49317 m .37315 .48275 L .37251 .48934 L 1 .772 0 r
F
.41852 .49976 m .41886 .49317 L .37251 .48934 L 1 .766 0 r
F
.41996 .47336 m .37522 .46297 L .3745 .46956 L 1 .791 0 r
F
.41996 .47336 m .42036 .46675 L .37522 .46297 L F
.41852 .49976 m .37251 .48934 L .3719 .49593 L 1 .766 0 r
F
.41819 .50636 m .41852 .49976 L .3719 .49593 L 1 .759 0 r
F
.51438 .54692 m .51425 .54037 L .46547 .54066 L 1 .636 0 r
F
.42036 .46675 m .37596 .45638 L .37522 .46297 L 1 .797 0 r
F
.42036 .46675 m .42077 .46014 L .37596 .45638 L F
.46677 .42211 m .424 .41402 L .4235 .42059 L 1 .793 0 r
F
.46677 .42211 m .46685 .41553 L .424 .41402 L F
.46547 .54066 m .41756 .53214 L .41732 .53861 L 1 .699 0 r
F
.46541 .54718 m .46547 .54066 L .41732 .53861 L 1 .694 0 r
F
.51438 .54692 m .46547 .54066 L .46541 .54718 L 1 .636 0 r
F
.41819 .50636 m .3719 .49593 L .37131 .50252 L 1 .759 0 r
F
.41788 .51294 m .41819 .50636 L .37131 .50252 L 1 .753 0 r
F
.42077 .46014 m .37672 .44979 L .37596 .45638 L 1 .803 0 r
F
.42077 .46014 m .42119 .45354 L .37672 .44979 L F
.4667 .42885 m .42374 .42089 L .42326 .42744 L 1 .793 0 r
F
.4667 .42885 m .46678 .42227 L .42374 .42089 L F
.51048 .42816 m .46678 .42227 L .4667 .42885 L 1 .748 0 r
F
.51048 .42816 m .51017 .42156 L .46678 .42227 L F
.41788 .51294 m .37131 .50252 L .37075 .5091 L 1 .753 0 r
F
.41758 .51952 m .41788 .51294 L .37075 .5091 L 1 .746 0 r
F
.46533 .55394 m .41652 .54574 L .4163 .55226 L 1 .663 0 r
F
.46527 .56044 m .46533 .55394 L .4163 .55226 L 1 .656 0 r
F
.5146 .55998 m .51449 .55345 L .5123 .55347 L 1 .623 0 r
F
.51459 .55995 m .51449 .55344 L .5123 .55347 L .996 .606 0 r
F
.51012 .55941 m .5123 .55347 L .46533 .55394 L F
.5146 .55998 m .5123 .55347 L .51213 .55392 L 1 .623 0 r
F
.51044 .55945 m .51195 .55347 L .51012 .55941 L F
.5146 .55998 m .51316 .55645 L .51044 .55945 L F
.51316 .55645 m .51195 .55347 L .51044 .55945 L F
.50992 .56 m .46533 .55394 L .46527 .56044 L .996 .606 0 r
F
.5146 .55998 m .51044 .55945 L .50992 .56 L 1 .623 0 r
F
.50994 .56 m .50992 .56 L .50992 .56 L .996 .606 0 r
F
.50992 .56 m .46533 .55394 L .50992 .56 L F
.51044 .55945 m .51012 .55941 L .50992 .56 L 1 .623 0 r
F
.51012 .55941 m .46533 .55394 L .50994 .56 L .996 .606 0 r
F
.51012 .55941 m .46535 .55369 L .50992 .56 L 1 .623 0 r
F
.50992 .56 m .46535 .55369 L .46529 .56018 L F
.5147 .56649 m .51352 .55999 L .51149 .56214 L 1 .616 0 r
F
.5147 .56649 m .50992 .56 L .50766 .5656 L F
.50493 .56526 m .50992 .56 L .46527 .56044 L .996 .598 0 r
F
.5147 .56649 m .50816 .56566 L .50727 .56652 L 1 .616 0 r
F
.50727 .56652 m .46527 .56044 L .46522 .56693 L .996 .598 0 r
F
.50816 .56566 m .50766 .5656 L .50727 .56652 L 1 .616 0 r
F
.51468 .56645 m .50766 .5656 L .50727 .56652 L .996 .598 0 r
F
.50766 .5656 m .46527 .56044 L .50727 .56652 L F
.50513 .56529 m .5099 .56004 L .50992 .56 L F
.50513 .56529 m .50992 .56 L .50493 .56526 L F
.50766 .5656 m .50994 .56 L .50513 .56529 L F
.51149 .56214 m .51352 .55999 L .50992 .56 L 1 .616 0 r
F
.51468 .56645 m .5102 .56036 L .50766 .5656 L .996 .598 0 r
F
.5102 .56036 m .50994 .56 L .50766 .5656 L F
.50766 .5656 m .46529 .56018 L .50722 .56651 L 1 .616 0 r
F
.50766 .5656 m .50722 .56651 L .50727 .56652 L F
.50727 .56652 m .46529 .56018 L .46524 .56667 L F
.51479 .57299 m .5147 .56649 L .5109 .56651 L 1 .609 0 r
F
.51479 .57299 m .5109 .56651 L .50923 .56821 L F
.51479 .57299 m .50727 .56652 L .50497 .57174 L F
.50223 .57141 m .50727 .56652 L .46522 .56693 L .995 .591 0 r
F
.51479 .57299 m .50566 .57183 L .5043 .57303 L 1 .609 0 r
F
.5043 .57303 m .46522 .56693 L .46517 .57341 L .995 .591 0 r
F
.50566 .57183 m .50497 .57174 L .5043 .57303 L 1 .609 0 r
F
.51475 .57292 m .50497 .57174 L .5043 .57303 L .995 .591 0 r
F
.50497 .57174 m .46522 .56693 L .5043 .57303 L F
.50268 .57146 m .50721 .56667 L .50727 .56652 L F
.50268 .57146 m .50727 .56652 L .50223 .57141 L F
.50923 .56821 m .5109 .56651 L .50727 .56652 L 1 .609 0 r
F
.50497 .57174 m .50735 .56652 L .50268 .57146 L .995 .591 0 r
F
.51475 .57292 m .50777 .56689 L .50497 .57174 L F
.50777 .56689 m .50735 .56652 L .50497 .57174 L F
.50497 .57174 m .46524 .56667 L .50423 .57301 L 1 .609 0 r
F
.50497 .57174 m .50423 .57301 L .5043 .57303 L F
.5043 .57303 m .46524 .56667 L .46518 .57315 L F
.51486 .57948 m .51479 .57299 L .50799 .57302 L 1 .602 0 r
F
.51486 .57948 m .50799 .57302 L .50656 .5744 L F
.51486 .57948 m .5043 .57303 L .50198 .57784 L F
.49924 .57751 m .5043 .57303 L .46517 .57341 L .994 .583 0 r
F
.51486 .57948 m .50288 .57795 L .50094 .57952 L 1 .602 0 r
F
.50094 .57952 m .46517 .57341 L .46512 .57986 L .994 .583 0 r
F
.50288 .57795 m .50198 .57784 L .50094 .57952 L 1 .602 0 r
F
.51482 .57938 m .50198 .57784 L .50094 .57952 L .994 .583 0 r
F
.50198 .57784 m .46517 .57341 L .50094 .57952 L F
.49997 .57759 m .50414 .57337 L .5043 .57303 L F
.49997 .57759 m .5043 .57303 L .49924 .57751 L F
.50656 .5744 m .50799 .57302 L .5043 .57303 L 1 .602 0 r
F
.50198 .57784 m .50448 .57302 L .49997 .57759 L .994 .583 0 r
F
.51482 .57938 m .50502 .57336 L .50198 .57784 L F
.50502 .57336 m .50448 .57302 L .50198 .57784 L F
.50198 .57784 m .46518 .57315 L .50085 .5795 L 1 .602 0 r
F
.50198 .57784 m .50085 .5795 L .50094 .57952 L F
.50094 .57952 m .46518 .57315 L .46513 .57961 L F
.51493 .58595 m .51486 .57948 L .50471 .57951 L 1 .594 0 r
F
.51493 .58595 m .50471 .57951 L .50344 .58067 L F
.51493 .58595 m .50094 .57952 L .49863 .58387 L F
.49593 .58355 m .50094 .57952 L .46512 .57986 L .993 .575 0 r
F
.51493 .58595 m .49978 .58402 L .49708 .58599 L 1 .594 0 r
F
.49708 .58599 m .46512 .57986 L .46507 .58629 L .993 .575 0 r
F
.49978 .58402 m .49863 .58387 L .49708 .58599 L 1 .594 0 r
F
.51487 .58582 m .49863 .58387 L .49708 .58599 L .993 .575 0 r
F
.49863 .58387 m .46512 .57986 L .49708 .58599 L F
.49696 .58367 m .5006 .58016 L .50094 .57952 L F
.49696 .58367 m .50094 .57952 L .49593 .58355 L F
.50344 .58067 m .50471 .57951 L .50094 .57952 L 1 .594 0 r
F
.49863 .58387 m .50126 .57951 L .49696 .58367 L .993 .575 0 r
F
.51487 .58582 m .50187 .57979 L .49863 .58387 L F
.50187 .57979 m .50126 .57951 L .49863 .58387 L F
.49863 .58387 m .46513 .57961 L .49696 .58597 L 1 .594 0 r
F
.49863 .58387 m .49696 .58597 L .49708 .58599 L F
.49708 .58599 m .46513 .57961 L .46508 .58606 L F
.51498 .5924 m .51493 .58595 L .50098 .58598 L 1 .587 0 r
F
.51498 .5924 m .50098 .58598 L .49982 .58697 L F
.51498 .5924 m .49708 .58599 L .49483 .58984 L F
.49222 .58953 m .49708 .58599 L .46507 .58629 L .992 .567 0 r
F
.51498 .5924 m .49628 .59002 L .4926 .59244 L 1 .587 0 r
F
.4926 .59244 m .46507 .58629 L .46502 .5927 L .992 .567 0 r
F
.49628 .59002 m .49483 .58984 L .4926 .59244 L 1 .587 0 r
F
.51492 .59223 m .49483 .58984 L .4926 .59244 L .992 .567 0 r
F
.49483 .58984 m .46507 .58629 L .4926 .59244 L F
.49358 .58969 m .49645 .58706 L .49708 .58599 L F
.49358 .58969 m .49708 .58599 L .49222 .58953 L F
.49982 .58697 m .50098 .58598 L .49708 .58599 L 1 .587 0 r
F
.49483 .58984 m .49763 .58598 L .49358 .58969 L .992 .567 0 r
F
.51492 .59223 m .49821 .58619 L .49483 .58984 L F
.49821 .58619 m .49763 .58598 L .49483 .58984 L F
.49483 .58984 m .46508 .58606 L .49246 .59241 L 1 .587 0 r
F
.49483 .58984 m .49246 .59241 L .4926 .59244 L F
.4926 .59244 m .46508 .58606 L .46503 .5925 L F
.51503 .59884 m .51498 .5924 L .49666 .59244 L 1 .579 0 r
F
.51503 .59884 m .49666 .59244 L .49559 .5933 L F
.51503 .59884 m .4926 .59244 L .4905 .59573 L F
.48805 .59544 m .4926 .59244 L .46502 .5927 L .991 .559 0 r
F
.51503 .59884 m .4923 .59595 L .48735 .59888 L 1 .579 0 r
F
.48735 .59888 m .46502 .5927 L .46497 .59909 L .991 .559 0 r
F
.4923 .59595 m .4905 .59573 L .48735 .59888 L 1 .579 0 r
F
.51495 .59863 m .4905 .59573 L .48735 .59888 L .991 .559 0 r
F
.4905 .59573 m .46502 .5927 L .48735 .59888 L F
.48976 .59564 m .49153 .59412 L .4926 .59244 L F
.48976 .59564 m .4926 .59244 L .48805 .59544 L F
.49559 .5933 m .49666 .59244 L .4926 .59244 L 1 .579 0 r
F
.4905 .59573 m .49348 .59244 L .48976 .59564 L .991 .559 0 r
F
.51495 .59863 m .49389 .59255 L .4905 .59573 L F
.49389 .59255 m .49348 .59244 L .4905 .59573 L F
.4905 .59573 m .46503 .5925 L .48718 .59884 L 1 .579 0 r
F
.4905 .59573 m .48718 .59884 L .48735 .59888 L F
.48735 .59888 m .46503 .5925 L .46498 .59892 L F
.51506 .60525 m .51503 .59884 L .49162 .59888 L 1 .571 0 r
F
.51506 .60525 m .49162 .59888 L .49061 .59963 L F
.51506 .60525 m .48735 .59888 L .48549 .60152 L F
.48333 .60126 m .48735 .59888 L .46497 .59909 L .99 .551 0 r
F
.51506 .60525 m .48773 .6018 L .48111 .60531 L 1 .571 0 r
F
.48111 .60531 m .46497 .59909 L .46493 .60546 L .99 .551 0 r
F
.48773 .6018 m .48549 .60152 L .48111 .60531 L 1 .571 0 r
F
.51497 .60499 m .48549 .60152 L .48111 .60531 L .99 .551 0 r
F
.48549 .60152 m .46497 .59909 L .48111 .60531 L F
.48541 .60151 m .48735 .59888 L .48333 .60126 L F
.48549 .60152 m .46498 .59892 L .48111 .60531 L 1 .571 0 r
F
.48111 .60531 m .46498 .59892 L .46493 .60534 L F
.47795 .60699 m .48111 .60531 L .46493 .60546 L .989 .543 0 r
F
.51508 .61165 m .51506 .60525 L .48566 .6053 L 1 .563 0 r
F
.51508 .61165 m .48566 .6053 L .48469 .60598 L F
.51508 .61165 m .48111 .60531 L .47964 .60719 L F
.51508 .61165 m .48243 .60754 L .47364 .61172 L F
.47364 .61172 m .46493 .60546 L .46488 .6118 L .989 .543 0 r
F
.48243 .60754 m .47964 .60719 L .47364 .61172 L 1 .563 0 r
F
.51498 .61134 m .47964 .60719 L .47364 .61172 L .989 .543 0 r
F
.47964 .60719 m .46493 .60546 L .47364 .61172 L F
.47964 .60719 m .48111 .60531 L .47795 .60699 L F
.47964 .60719 m .46493 .60534 L .47364 .61172 L 1 .563 0 r
F
.47364 .61172 m .46493 .60534 L .46489 .61173 L F
.47178 .61261 m .47364 .61172 L .46488 .6118 L .988 .535 0 r
F
.51509 .61802 m .51508 .61165 L .47854 .61171 L .999 .554 0 r
F
.51509 .61802 m .47854 .61171 L .47759 .61232 L F
.51509 .61802 m .47364 .61172 L .47277 .61272 L F
.47277 .61272 m .47364 .61172 L .47178 .61261 L .988 .535 0 r
F
.51509 .61802 m .47277 .61272 L .46484 .61812 L .999 .554 0 r
F
.47277 .61272 m .46488 .6118 L .46484 .61796 L .988 .535 0 r
F
.47277 .61272 m .46489 .61173 L .46484 .61796 L .999 .554 0 r
F
.47277 .61272 m .46484 .61796 L .46484 .61812 L F
.51498 .61765 m .47277 .61272 L .46484 .61811 L .988 .535 0 r
F
.47277 .61272 m .46484 .61796 L .46484 .61811 L F
.51509 .62438 m .51509 .61802 L .46484 .61812 L .997 .546 0 r
F
.51496 .62394 m .51498 .61765 L .46852 .61808 L .986 .526 0 r
F
.4679 .61847 m .46852 .61808 L .46484 .61811 L F
.51496 .62394 m .46852 .61808 L .4679 .61847 L F
.47759 .61232 m .47854 .61171 L .47364 .61172 L .999 .554 0 r
F
.47277 .61272 m .47364 .61172 L .46489 .61173 L F
.47464 .61294 m .47364 .61172 L .47277 .61272 L .988 .535 0 r
F
.47464 .61294 m .47644 .61169 L .47364 .61172 L F
.51498 .61765 m .51498 .61134 L .47644 .61169 L F
.51498 .61765 m .47644 .61169 L .47464 .61294 L F
.48469 .60598 m .48566 .6053 L .48111 .60531 L 1 .563 0 r
F
.47964 .60719 m .48111 .60531 L .46493 .60534 L F
.48042 .60728 m .48111 .60531 L .47964 .60719 L .989 .543 0 r
F
.48042 .60728 m .48307 .60529 L .48111 .60531 L F
.51498 .61134 m .51497 .60499 L .48307 .60529 L F
.51498 .61134 m .48307 .60529 L .48042 .60728 L F
.49061 .59963 m .49162 .59888 L .48735 .59888 L 1 .571 0 r
F
.48541 .60151 m .4856 .60136 L .48735 .59888 L .99 .551 0 r
F
.48549 .60152 m .48735 .59888 L .46498 .59892 L 1 .571 0 r
F
.4856 .60136 m .48868 .59887 L .48735 .59888 L .99 .551 0 r
F
.51497 .60499 m .51495 .59863 L .48868 .59887 L F
.51497 .60499 m .48868 .59887 L .48541 .60151 L F
.4905 .59573 m .4926 .59244 L .46503 .5925 L 1 .579 0 r
F
.49153 .59412 m .49348 .59244 L .4926 .59244 L .991 .559 0 r
F
.51495 .59863 m .51492 .59223 L .49348 .59244 L F
.49483 .58984 m .49708 .58599 L .46508 .58606 L 1 .587 0 r
F
.49645 .58706 m .49763 .58598 L .49708 .58599 L .992 .567 0 r
F
.51492 .59223 m .51487 .58582 L .49763 .58598 L F
.49863 .58387 m .50094 .57952 L .46513 .57961 L 1 .594 0 r
F
.5006 .58016 m .50126 .57951 L .50094 .57952 L .993 .575 0 r
F
.51487 .58582 m .51482 .57938 L .50126 .57951 L F
.50198 .57784 m .5043 .57303 L .46518 .57315 L 1 .602 0 r
F
.50414 .57337 m .50448 .57302 L .5043 .57303 L .994 .583 0 r
F
.51482 .57938 m .51475 .57292 L .50448 .57302 L F
.50497 .57174 m .50727 .56652 L .46524 .56667 L 1 .609 0 r
F
.50721 .56667 m .50735 .56652 L .50727 .56652 L .995 .591 0 r
F
.51475 .57292 m .51468 .56645 L .50735 .56652 L F
.5147 .56649 m .5146 .55998 L .51352 .55999 L 1 .616 0 r
F
.50766 .5656 m .50992 .56 L .46529 .56018 L F
.5099 .56004 m .50994 .56 L .50992 .56 L .996 .598 0 r
F
.51468 .56645 m .51459 .55995 L .50994 .56 L F
.51459 .55995 m .5123 .55347 L .51012 .55941 L .996 .606 0 r
F
.51213 .55392 m .5123 .55347 L .51195 .55347 L 1 .623 0 r
F
.51012 .55941 m .51195 .55347 L .46535 .55369 L F
.51459 .55995 m .51012 .55941 L .50994 .56 L .996 .606 0 r
F
.42119 .45354 m .37751 .44321 L .37672 .44979 L 1 .809 0 r
F
.42119 .45354 m .42162 .44694 L .37751 .44321 L F
.46541 .54718 m .41732 .53861 L .41709 .54506 L 1 .694 0 r
F
.46535 .55369 m .46541 .54718 L .41709 .54506 L 1 .689 0 r
F
.41758 .51952 m .37075 .5091 L .37022 .51568 L 1 .746 0 r
F
.4173 .52609 m .41758 .51952 L .37022 .51568 L 1 .74 0 r
F
.46685 .41553 m .42451 .40746 L .424 .41402 L 1 .799 0 r
F
.46685 .41553 m .46694 .40895 L .42451 .40746 L F
.46678 .42227 m .42422 .41434 L .42374 .42089 L F
.46678 .42227 m .46687 .4157 L .42422 .41434 L F
.51017 .42156 m .46687 .4157 L .46678 .42227 L 1 .754 0 r
F
.42162 .44694 m .37833 .43663 L .37751 .44321 L 1 .815 0 r
F
.42162 .44694 m .42207 .44034 L .37833 .43663 L F
.51017 .42156 m .50984 .41497 L .46687 .4157 L 1 .754 0 r
F
.4173 .52609 m .37022 .51568 L .36971 .52225 L 1 .74 0 r
F
.41702 .53265 m .4173 .52609 L .36971 .52225 L 1 .733 0 r
F
.56368 .55749 m .51449 .55345 L .5146 .55998 L .951 .566 0 r
F
.56368 .55749 m .56341 .55094 L .51449 .55345 L F
.46527 .56044 m .4163 .55226 L .41608 .55877 L 1 .656 0 r
F
.46522 .56693 m .46527 .56044 L .41608 .55877 L 1 .649 0 r
F
.56346 .5573 m .51449 .55344 L .51459 .55995 L .943 .554 0 r
F
.56346 .5573 m .56321 .55078 L .51449 .55344 L F
.42207 .44034 m .37917 .43007 L .37833 .43663 L 1 .821 0 r
F
.42207 .44034 m .42253 .43375 L .37917 .43007 L F
.46535 .55369 m .41709 .54506 L .41688 .5515 L 1 .689 0 r
F
.46529 .56018 m .46535 .55369 L .41688 .5515 L 1 .684 0 r
F
.60441 .47338 m .55841 .47168 L .55895 .47831 L .903 .599 0 r
F
.60522 .48002 m .55895 .47831 L .55947 .48494 L .902 .592 0 r
F
.60522 .48002 m .60441 .47338 L .55895 .47831 L F
.606 .48665 m .55947 .48494 L .55997 .49156 L .901 .584 0 r
F
.606 .48665 m .60522 .48002 L .55947 .48494 L F
.60357 .46674 m .55785 .46505 L .55841 .47168 L .904 .606 0 r
F
.60441 .47338 m .60357 .46674 L .55841 .47168 L .903 .599 0 r
F
.60674 .49329 m .55997 .49156 L .56044 .49819 L .901 .577 0 r
F
.60674 .49329 m .606 .48665 L .55997 .49156 L F
.46687 .4157 m .42473 .4078 L .42422 .41434 L 1 .804 0 r
F
.46687 .4157 m .46695 .40913 L .42473 .4078 L F
.50984 .41497 m .46695 .40913 L .46687 .4157 L 1 .76 0 r
F
.50984 .41497 m .5095 .40839 L .46695 .40913 L F
.46694 .40895 m .42504 .40092 L .42451 .40746 L 1 .804 0 r
F
.46694 .40895 m .46703 .40238 L .42504 .40092 L F
.60269 .4601 m .55727 .45842 L .55785 .46505 L .904 .613 0 r
F
.60357 .46674 m .60269 .4601 L .55785 .46505 L .904 .606 0 r
F
.41702 .53265 m .36971 .52225 L .36923 .52881 L 1 .733 0 r
F
.41677 .5392 m .41702 .53265 L .36923 .52881 L 1 .726 0 r
F
.60745 .49992 m .56044 .49819 L .56089 .50481 L .9 .57 0 r
F
.60745 .49992 m .60674 .49329 L .56044 .49819 L F
.60413 .47339 m .55835 .47169 L .55888 .47831 L .898 .591 0 r
F
.60493 .48002 m .55888 .47831 L .55939 .48493 L .897 .584 0 r
F
.60493 .48002 m .60413 .47339 L .55888 .47831 L F
.60569 .48664 m .55939 .48493 L .55987 .49155 L .896 .576 0 r
F
.60569 .48664 m .60493 .48002 L .55939 .48493 L F
.41996 .47997 m .3756 .46968 L .37498 .47621 L 1 .793 0 r
F
.41996 .47997 m .42032 .47341 L .3756 .46968 L F
.41961 .48652 m .41996 .47997 L .37498 .47621 L 1 .787 0 r
F
.42032 .47341 m .37625 .46316 L .3756 .46968 L 1 .798 0 r
F
.42032 .47341 m .4207 .46684 L .37625 .46316 L F
.60331 .46677 m .55779 .46506 L .55835 .47169 L .898 .599 0 r
F
.60413 .47339 m .60331 .46677 L .55835 .47169 L .898 .591 0 r
F
.42253 .43375 m .38004 .42351 L .37917 .43007 L 1 .826 0 r
F
.42253 .43375 m .42301 .42717 L .38004 .42351 L F
.41961 .48652 m .37498 .47621 L .37439 .48272 L 1 .787 0 r
F
.41927 .49307 m .41961 .48652 L .37439 .48272 L 1 .782 0 r
F
.4207 .46684 m .37693 .45662 L .37625 .46316 L 1 .804 0 r
F
.4207 .46684 m .42109 .46027 L .37693 .45662 L F
.60641 .49326 m .55987 .49155 L .56034 .49817 L .895 .569 0 r
F
.60641 .49326 m .60569 .48664 L .55987 .49155 L F
.60244 .46014 m .55721 .45844 L .55779 .46506 L .899 .606 0 r
F
.60331 .46677 m .60244 .46014 L .55779 .46506 L .898 .599 0 r
F
.60178 .45347 m .55666 .4518 L .55727 .45842 L .905 .62 0 r
F
.60269 .4601 m .60178 .45347 L .55727 .45842 L .904 .613 0 r
F
.60812 .50655 m .56089 .50481 L .56132 .51142 L .899 .562 0 r
F
.60812 .50655 m .60745 .49992 L .56089 .50481 L F
.56393 .56402 m .5146 .55998 L .5147 .56649 L .95 .558 0 r
F
.56393 .56402 m .56368 .55749 L .5146 .55998 L F
.41927 .49307 m .37439 .48272 L .37383 .48922 L 1 .782 0 r
F
.41895 .49961 m .41927 .49307 L .37383 .48922 L 1 .776 0 r
F
.42109 .46027 m .37764 .45009 L .37693 .45662 L 1 .809 0 r
F
.42109 .46027 m .4215 .45371 L .37764 .45009 L F
.6071 .49987 m .56034 .49817 L .56078 .50478 L .894 .561 0 r
F
.6071 .49987 m .60641 .49326 L .56034 .49817 L F
.60154 .45352 m .55661 .45181 L .55721 .45844 L .9 .613 0 r
F
.60244 .46014 m .60154 .45352 L .55721 .45844 L .899 .606 0 r
F
.56369 .56381 m .51459 .55995 L .51468 .56645 L .941 .546 0 r
F
.56369 .56381 m .56346 .5573 L .51459 .55995 L F
.46522 .56693 m .41608 .55877 L .41588 .56526 L 1 .649 0 r
F
.46517 .57341 m .46522 .56693 L .41588 .56526 L 1 .641 0 r
F
.46529 .56018 m .41688 .5515 L .41668 .55793 L 1 .684 0 r
F
.46524 .56667 m .46529 .56018 L .41668 .55793 L 1 .679 0 r
F
.60083 .44684 m .55603 .44517 L .55666 .4518 L .906 .627 0 r
F
.60178 .45347 m .60083 .44684 L .55666 .4518 L .905 .62 0 r
F
.41895 .49961 m .37383 .48922 L .3733 .49572 L 1 .776 0 r
F
.41864 .50614 m .41895 .49961 L .3733 .49572 L 1 .771 0 r
F
.4215 .45371 m .37838 .44355 L .37764 .45009 L 1 .815 0 r
F
.4215 .45371 m .42192 .44714 L .37838 .44355 L F
.60876 .51318 m .56132 .51142 L .56172 .51803 L .898 .555 0 r
F
.60876 .51318 m .60812 .50655 L .56132 .51142 L F
.41677 .5392 m .36923 .52881 L .36877 .53536 L 1 .726 0 r
F
.41652 .54574 m .41677 .5392 L .36877 .53536 L 1 .719 0 r
F
.60776 .50648 m .56078 .50478 L .5612 .51138 L .893 .554 0 r
F
.60776 .50648 m .6071 .49987 L .56078 .50478 L F
.60061 .4469 m .55599 .44519 L .55661 .45181 L .901 .62 0 r
F
.60154 .45352 m .60061 .4469 L .55661 .45181 L .9 .613 0 r
F
.46695 .40913 m .42524 .40127 L .42473 .4078 L 1 .81 0 r
F
.46695 .40913 m .46704 .40258 L .42524 .40127 L F
.5095 .40839 m .46704 .40258 L .46695 .40913 L 1 .765 0 r
F
.42301 .42717 m .38093 .41696 L .38004 .42351 L 1 .832 0 r
F
.42301 .42717 m .4235 .42059 L .38093 .41696 L F
.5095 .40839 m .50916 .40183 L .46704 .40258 L 1 .765 0 r
F
.41864 .50614 m .3733 .49572 L .37281 .50219 L 1 .771 0 r
F
.41835 .51266 m .41864 .50614 L .37281 .50219 L 1 .766 0 r
F
.42192 .44714 m .37915 .43702 L .37838 .44355 L 1 .821 0 r
F
.42192 .44714 m .42235 .44057 L .37915 .43702 L F
.59985 .44022 m .55538 .43855 L .55603 .44517 L .906 .634 0 r
F
.60083 .44684 m .59985 .44022 L .55603 .44517 L .906 .627 0 r
F
.46703 .40238 m .42558 .39438 L .42504 .40092 L 1 .81 0 r
F
.46703 .40238 m .46712 .39583 L .42558 .39438 L F
.60937 .5198 m .56172 .51803 L .56211 .52463 L .897 .547 0 r
F
.60937 .5198 m .60876 .51318 L .56172 .51803 L F
.60837 .51309 m .5612 .51138 L .56159 .51797 L .892 .546 0 r
F
.60837 .51309 m .60776 .50648 L .5612 .51138 L F
.59964 .44028 m .55534 .43857 L .55599 .44519 L .901 .628 0 r
F
.60061 .4469 m .59964 .44028 L .55599 .44519 L .901 .62 0 r
F
.56415 .57054 m .5147 .56649 L .51479 .57299 L .949 .551 0 r
F
.56415 .57054 m .56393 .56402 L .5147 .56649 L F
.41835 .51266 m .37281 .50219 L .37236 .50865 L 1 .766 0 r
F
.41807 .51917 m .41835 .51266 L .37236 .50865 L 1 .761 0 r
F
.42235 .44057 m .37994 .43049 L .37915 .43702 L 1 .826 0 r
F
.42235 .44057 m .4228 .43401 L .37994 .43049 L F
.41652 .54574 m .36877 .53536 L .36834 .5419 L 1 .719 0 r
F
.4163 .55226 m .41652 .54574 L .36834 .5419 L 1 .712 0 r
F
.59883 .4336 m .55471 .43194 L .55538 .43855 L .907 .641 0 r
F
.59985 .44022 m .59883 .4336 L .55538 .43855 L .906 .634 0 r
F
.56389 .57029 m .51468 .56645 L .51475 .57292 L .94 .538 0 r
F
.56389 .57029 m .56369 .56381 L .51468 .56645 L F
.46524 .56667 m .41668 .55793 L .41649 .56434 L 1 .679 0 r
F
.46518 .57315 m .46524 .56667 L .41649 .56434 L 1 .674 0 r
F
.60896 .51968 m .56159 .51797 L .56196 .52456 L .891 .538 0 r
F
.60896 .51968 m .60837 .51309 L .56159 .51797 L F
.60993 .52641 m .56211 .52463 L .56247 .53122 L .896 .54 0 r
F
.60993 .52641 m .60937 .5198 L .56211 .52463 L F
.46517 .57341 m .41588 .56526 L .4157 .57174 L 1 .641 0 r
F
.46512 .57986 m .46517 .57341 L .4157 .57174 L 1 .634 0 r
F
.59864 .43367 m .55467 .43196 L .55534 .43857 L .902 .635 0 r
F
.59964 .44028 m .59864 .43367 L .55534 .43857 L .901 .628 0 r
F
.4235 .42059 m .38184 .41042 L .38093 .41696 L 1 .838 0 r
F
.4235 .42059 m .424 .41402 L .38184 .41042 L F
.46704 .40258 m .42577 .39475 L .42524 .40127 L 1 .815 0 r
F
.46704 .40258 m .46713 .39603 L .42577 .39475 L F
.50916 .40183 m .46713 .39603 L .46704 .40258 L 1 .771 0 r
F
.41807 .51917 m .37236 .50865 L .37194 .51508 L 1 .761 0 r
F
.41781 .52566 m .41807 .51917 L .37194 .51508 L 1 .757 0 r
F
.50916 .40183 m .5088 .39527 L .46713 .39603 L 1 .771 0 r
F
.4228 .43401 m .38076 .42396 L .37994 .43049 L 1 .832 0 r
F
.4228 .43401 m .42326 .42744 L .38076 .42396 L F
.59779 .42699 m .55401 .42533 L .55471 .43194 L .907 .648 0 r
F
.59883 .4336 m .59779 .42699 L .55471 .43194 L .907 .641 0 r
F
.6095 .52627 m .56196 .52456 L .56231 .53113 L .89 .53 0 r
F
.6095 .52627 m .60896 .51968 L .56196 .52456 L F
.61047 .53302 m .56247 .53122 L .5628 .5378 L .895 .532 0 r
F
.61047 .53302 m .60993 .52641 L .56247 .53122 L F
.5976 .42707 m .55398 .42535 L .55467 .43196 L .902 .642 0 r
F
.59864 .43367 m .5976 .42707 L .55467 .43196 L .902 .635 0 r
F
.46712 .39583 m .42613 .38786 L .42558 .39438 L 1 .816 0 r
F
.46712 .39583 m .46721 .38929 L .42613 .38786 L F
.4163 .55226 m .36834 .5419 L .36794 .54843 L 1 .712 0 r
F
.41608 .55877 m .4163 .55226 L .36794 .54843 L 1 .705 0 r
F
.56435 .57705 m .51479 .57299 L .51486 .57948 L .948 .543 0 r
F
.56435 .57705 m .56415 .57054 L .51479 .57299 L F
.424 .41402 m .38278 .40389 L .38184 .41042 L 1 .844 0 r
F
.424 .41402 m .42451 .40746 L .38278 .40389 L F
.46518 .57315 m .41649 .56434 L .41631 .57074 L 1 .674 0 r
F
.46513 .57961 m .46518 .57315 L .41631 .57074 L 1 .668 0 r
F
.41781 .52566 m .37194 .51508 L .37156 .52149 L 1 .757 0 r
F
.41756 .53214 m .41781 .52566 L .37156 .52149 L 1 .753 0 r
F
.42326 .42744 m .38161 .41744 L .38076 .42396 L 1 .837 0 r
F
.42326 .42744 m .42374 .42089 L .38161 .41744 L F
.56407 .57676 m .51475 .57292 L .51482 .57938 L .939 .53 0 r
F
.56407 .57676 m .56389 .57029 L .51475 .57292 L F
.59671 .42039 m .5533 .41874 L .55401 .42533 L .908 .655 0 r
F
.59779 .42699 m .59671 .42039 L .55401 .42533 L .907 .648 0 r
F
.61001 .53284 m .56231 .53113 L .56263 .53769 L .888 .522 0 r
F
.61001 .53284 m .6095 .52627 L .56231 .53113 L F
.46512 .57986 m .4157 .57174 L .41552 .5782 L 1 .634 0 r
F
.46507 .58629 m .46512 .57986 L .41552 .5782 L 1 .626 0 r
F
.59653 .42047 m .55327 .41876 L .55398 .42535 L .903 .649 0 r
F
.5976 .42707 m .59653 .42047 L .55398 .42535 L .902 .642 0 r
F
.61096 .53961 m .5628 .5378 L .56312 .54438 L .893 .524 0 r
F
.61096 .53961 m .61047 .53302 L .5628 .5378 L F
.46713 .39603 m .42631 .38824 L .42577 .39475 L 1 .821 0 r
F
.46713 .39603 m .46722 .3895 L .42631 .38824 L F
.5088 .39527 m .46722 .3895 L .46713 .39603 L 1 .777 0 r
F
.5088 .39527 m .50844 .38872 L .46722 .3895 L F
.41756 .53214 m .37156 .52149 L .37123 .52787 L 1 .753 0 r
F
.41732 .53861 m .41756 .53214 L .37123 .52787 L 1 .749 0 r
F
.41608 .55877 m .36794 .54843 L .36757 .55495 L 1 .705 0 r
F
.41588 .56526 m .41608 .55877 L .36757 .55495 L 1 .698 0 r
F
.42374 .42089 m .38249 .41093 L .38161 .41744 L 1 .843 0 r
F
.42374 .42089 m .42422 .41434 L .38249 .41093 L F
.46721 .38929 m .42669 .38136 L .42613 .38786 L 1 .822 0 r
F
.46721 .38929 m .46731 .38276 L .42669 .38136 L F
.61049 .53941 m .56263 .53769 L .56293 .54424 L .887 .514 0 r
F
.61049 .53941 m .61001 .53284 L .56263 .53769 L F
.59559 .41379 m .55256 .41214 L .5533 .41874 L .908 .661 0 r
F
.59671 .42039 m .59559 .41379 L .5533 .41874 L .908 .655 0 r
F
.42451 .40746 m .38374 .39738 L .38278 .40389 L 1 .849 0 r
F
.42451 .40746 m .42504 .40092 L .38374 .39738 L F
.56452 .58354 m .51486 .57948 L .51493 .58595 L .946 .535 0 r
F
.56452 .58354 m .56435 .57705 L .51486 .57948 L F
.59543 .41388 m .55253 .41216 L .55327 .41876 L .904 .656 0 r
F
.59653 .42047 m .59543 .41388 L .55327 .41876 L .903 .649 0 r
F
.61143 .54619 m .56312 .54438 L .56341 .55094 L .892 .516 0 r
F
.61143 .54619 m .61096 .53961 L .56312 .54438 L F
.46513 .57961 m .41631 .57074 L .41613 .57714 L 1 .668 0 r
F
.46508 .58606 m .46513 .57961 L .41613 .57714 L 1 .662 0 r
F
.56423 .58321 m .51482 .57938 L .51487 .58582 L .938 .522 0 r
F
.56423 .58321 m .56407 .57676 L .51482 .57938 L F
.41732 .53861 m .37123 .52787 L .37093 .53421 L 1 .749 0 r
F
.41709 .54506 m .41732 .53861 L .37093 .53421 L 1 .747 0 r
F
.42422 .41434 m .38339 .40442 L .38249 .41093 L 1 .848 0 r
F
.42422 .41434 m .42473 .4078 L .38339 .40442 L F
.46507 .58629 m .41552 .5782 L .41537 .58464 L 1 .626 0 r
F
.46502 .5927 m .46507 .58629 L .41537 .58464 L 1 .619 0 r
F
.46722 .3895 m .42687 .38174 L .42631 .38824 L 1 .827 0 r
F
.46722 .3895 m .46732 .38297 L .42687 .38174 L F
.50844 .38872 m .46732 .38297 L .46722 .3895 L 1 .783 0 r
F
.61092 .54596 m .56293 .54424 L .56321 .55078 L .886 .506 0 r
F
.61092 .54596 m .61049 .53941 L .56293 .54424 L F
.50844 .38872 m .50806 .38219 L .46732 .38297 L 1 .783 0 r
F
.41588 .56526 m .36757 .55495 L .36722 .56145 L 1 .698 0 r
F
.4157 .57174 m .41588 .56526 L .36722 .56145 L 1 .691 0 r
F
.59444 .40721 m .5518 .40556 L .55256 .41214 L .908 .668 0 r
F
.59559 .41379 m .59444 .40721 L .55256 .41214 L .908 .661 0 r
F
.59429 .4073 m .55178 .40558 L .55253 .41216 L .904 .663 0 r
F
.59543 .41388 m .59429 .4073 L .55253 .41216 L .904 .656 0 r
F
.61185 .55277 m .56341 .55094 L .56368 .55749 L .891 .509 0 r
F
.61185 .55277 m .61143 .54619 L .56341 .55094 L F
.42504 .40092 m .38473 .39088 L .38374 .39738 L 1 .855 0 r
F
.42504 .40092 m .42558 .39438 L .38473 .39088 L F
.56468 .59001 m .51493 .58595 L .51498 .5924 L .945 .527 0 r
F
.56468 .59001 m .56452 .58354 L .51493 .58595 L F
.46731 .38276 m .42727 .37487 L .42669 .38136 L 1 .827 0 r
F
.46731 .38276 m .4674 .37624 L .42727 .37487 L F
.46508 .58606 m .41613 .57714 L .41596 .58353 L 1 .662 0 r
F
.46503 .5925 m .46508 .58606 L .41596 .58353 L 1 .656 0 r
F
.41709 .54506 m .37093 .53421 L .37069 .54051 L 1 .747 0 r
F
.41688 .5515 m .41709 .54506 L .37069 .54051 L 1 .745 0 r
F
.42473 .4078 m .38432 .39793 L .38339 .40442 L 1 .854 0 r
F
.42473 .4078 m .42524 .40127 L .38432 .39793 L F
.56436 .58964 m .51487 .58582 L .51492 .59223 L .937 .514 0 r
F
.56436 .58964 m .56423 .58321 L .51487 .58582 L F
.61133 .5525 m .56321 .55078 L .56346 .5573 L .884 .498 0 r
F
.61133 .5525 m .61092 .54596 L .56321 .55078 L F
.59326 .40064 m .55102 .39899 L .5518 .40556 L .909 .675 0 r
F
.59444 .40721 m .59326 .40064 L .5518 .40556 L .908 .668 0 r
F
.59312 .40074 m .551 .39901 L .55178 .40558 L .904 .67 0 r
F
.59429 .4073 m .59312 .40074 L .55178 .40558 L .904 .663 0 r
F
.61224 .55933 m .56368 .55749 L .56393 .56402 L .889 .5 0 r
F
.61224 .55933 m .61185 .55277 L .56368 .55749 L F
.4157 .57174 m .36722 .56145 L .3669 .56794 L 1 .691 0 r
F
.41552 .5782 m .4157 .57174 L .3669 .56794 L 1 .683 0 r
F
.46502 .5927 m .41537 .58464 L .41523 .59105 L 1 .619 0 r
F
.46497 .59909 m .46502 .5927 L .41523 .59105 L 1 .611 0 r
F
.46732 .38297 m .42743 .37526 L .42687 .38174 L 1 .832 0 r
F
.46732 .38297 m .46741 .37647 L .42743 .37526 L F
.50806 .38219 m .46741 .37647 L .46732 .38297 L 1 .789 0 r
F
.50806 .38219 m .50767 .37567 L .46741 .37647 L F
.42558 .39438 m .38574 .3844 L .38473 .39088 L 1 .86 0 r
F
.42558 .39438 m .42613 .38786 L .38574 .3844 L F
.37381 .47615 m .33029 .46363 L .32929 .47021 L 1 .832 0 r
F
.37381 .47615 m .3745 .46956 L .33029 .46363 L F
.37315 .48275 m .37381 .47615 L .32929 .47021 L 1 .826 0 r
F
.41688 .5515 m .37069 .54051 L .37051 .54675 L 1 .745 0 r
F
.41668 .55793 m .41688 .5515 L .37051 .54675 L F
.37315 .48275 m .32929 .47021 L .32833 .47679 L 1 .826 0 r
F
.37251 .48934 m .37315 .48275 L .32833 .47679 L 1 .82 0 r
F
.3745 .46956 m .33133 .45706 L .33029 .46363 L 1 .838 0 r
F
.3745 .46956 m .37522 .46297 L .33133 .45706 L F
.37251 .48934 m .32833 .47679 L .32741 .48337 L 1 .82 0 r
F
.3719 .49593 m .37251 .48934 L .32741 .48337 L 1 .813 0 r
F
.42524 .40127 m .38528 .39145 L .38432 .39793 L 1 .859 0 r
F
.42524 .40127 m .42577 .39475 L .38528 .39145 L F
.37522 .46297 m .3324 .45049 L .33133 .45706 L 1 .844 0 r
F
.37522 .46297 m .37596 .45638 L .3324 .45049 L F
.5648 .59646 m .51498 .5924 L .51503 .59884 L .944 .519 0 r
F
.5648 .59646 m .56468 .59001 L .51498 .5924 L F
.46503 .5925 m .41596 .58353 L .41579 .58994 L 1 .656 0 r
F
.46498 .59892 m .46503 .5925 L .41579 .58994 L 1 .649 0 r
F
.3719 .49593 m .32741 .48337 L .32653 .48996 L 1 .813 0 r
F
.37131 .50252 m .3719 .49593 L .32653 .48996 L 1 .807 0 r
F
.61169 .55902 m .56346 .5573 L .56369 .56381 L .883 .49 0 r
F
.61169 .55902 m .61133 .5525 L .56346 .5573 L F
.4674 .37624 m .42786 .3684 L .42727 .37487 L 1 .833 0 r
F
.4674 .37624 m .4675 .36974 L .42786 .3684 L F
.59205 .39409 m .55022 .39244 L .55102 .39899 L .909 .682 0 r
F
.59326 .40064 m .59205 .39409 L .55102 .39899 L .909 .675 0 r
F
.37596 .45638 m .33351 .44393 L .3324 .45049 L 1 .85 0 r
F
.37596 .45638 m .37672 .44979 L .33351 .44393 L F
.59192 .39418 m .5502 .39246 L .551 .39901 L .905 .677 0 r
F
.59312 .40074 m .59192 .39418 L .551 .39901 L .904 .67 0 r
F
.6126 .56587 m .56393 .56402 L .56415 .57054 L .888 .492 0 r
F
.6126 .56587 m .61224 .55933 L .56393 .56402 L F
.37131 .50252 m .32653 .48996 L .32568 .49654 L 1 .807 0 r
F
.37075 .5091 m .37131 .50252 L .32568 .49654 L 1 .801 0 r
F
.56447 .59604 m .51492 .59223 L .51495 .59863 L .935 .505 0 r
F
.56447 .59604 m .56436 .58964 L .51492 .59223 L F
.37672 .44979 m .33465 .43737 L .33351 .44393 L 1 .856 0 r
F
.37672 .44979 m .37751 .44321 L .33465 .43737 L F
.41552 .5782 m .3669 .56794 L .36661 .57441 L 1 .683 0 r
F
.41537 .58464 m .41552 .5782 L .36661 .57441 L 1 .676 0 r
F
.37075 .5091 m .32568 .49654 L .32487 .50312 L 1 .801 0 r
F
.37022 .51568 m .37075 .5091 L .32487 .50312 L 1 .794 0 r
F
.41668 .55793 m .37051 .54675 L .37039 .55293 L 1 .745 0 r
F
.41649 .56434 m .41668 .55793 L .37039 .55293 L 1 .746 0 r
F
.46741 .37647 m .42801 .3688 L .42743 .37526 L 1 .838 0 r
F
.46741 .37647 m .4675 .36997 L .42801 .3688 L F
.50767 .37567 m .4675 .36997 L .46741 .37647 L 1 .795 0 r
F
.42613 .38786 m .38677 .37793 L .38574 .3844 L 1 .866 0 r
F
.42613 .38786 m .42669 .38136 L .38677 .37793 L F
.37751 .44321 m .33584 .43082 L .33465 .43737 L 1 .861 0 r
F
.37751 .44321 m .37833 .43663 L .33584 .43082 L F
.46497 .59909 m .41523 .59105 L .4151 .59745 L 1 .611 0 r
F
.46493 .60546 m .46497 .59909 L .4151 .59745 L 1 .603 0 r
F
.50767 .37567 m .50728 .36916 L .4675 .36997 L 1 .795 0 r
F
.42577 .39475 m .38626 .38498 L .38528 .39145 L 1 .865 0 r
F
.42577 .39475 m .42631 .38824 L .38626 .38498 L F
.61202 .56552 m .56369 .56381 L .56389 .57029 L .882 .482 0 r
F
.61202 .56552 m .61169 .55902 L .56369 .56381 L F
.37022 .51568 m .32487 .50312 L .3241 .50969 L 1 .794 0 r
F
.36971 .52225 m .37022 .51568 L .3241 .50969 L 1 .788 0 r
F
.59081 .38754 m .54939 .38589 L .55022 .39244 L .909 .688 0 r
F
.59205 .39409 m .59081 .38754 L .55022 .39244 L .909 .682 0 r
F
.59068 .38764 m .54938 .38591 L .5502 .39246 L .905 .683 0 r
F
.59192 .39418 m .59068 .38764 L .5502 .39246 L .905 .677 0 r
F
.46498 .59892 m .41579 .58994 L .41563 .59635 L 1 .649 0 r
F
.46493 .60534 m .46498 .59892 L .41563 .59635 L 1 .642 0 r
F
.56491 .60289 m .51503 .59884 L .51506 .60525 L .942 .511 0 r
F
.56491 .60289 m .5648 .59646 L .51503 .59884 L F
.37833 .43663 m .33705 .42429 L .33584 .43082 L 1 .867 0 r
F
.37833 .43663 m .37917 .43007 L .33705 .42429 L F
.61292 .5724 m .56415 .57054 L .56435 .57705 L .887 .484 0 r
F
.61292 .5724 m .6126 .56587 L .56415 .57054 L F
.4675 .36974 m .42846 .36194 L .42786 .3684 L 1 .839 0 r
F
.4675 .36974 m .46759 .36326 L .42846 .36194 L F
.36971 .52225 m .3241 .50969 L .32337 .51627 L 1 .788 0 r
F
.36923 .52881 m .36971 .52225 L .32337 .51627 L 1 .781 0 r
F
.41649 .56434 m .37039 .55293 L .37035 .55903 L 1 .746 0 r
F
.41631 .57074 m .41649 .56434 L .37035 .55903 L 1 .75 0 r
F
.41537 .58464 m .36661 .57441 L .36634 .58086 L 1 .676 0 r
F
.41523 .59105 m .41537 .58464 L .36634 .58086 L 1 .668 0 r
F
.56455 .60242 m .51495 .59863 L .51497 .60499 L .934 .497 0 r
F
.56455 .60242 m .56447 .59604 L .51495 .59863 L F
.37917 .43007 m .33831 .41776 L .33705 .42429 L 1 .873 0 r
F
.37917 .43007 m .38004 .42351 L .33831 .41776 L F
.42669 .38136 m .38783 .37148 L .38677 .37793 L 1 .871 0 r
F
.42669 .38136 m .42727 .37487 L .38783 .37148 L F
.42631 .38824 m .38726 .37853 L .38626 .38498 L 1 .87 0 r
F
.42631 .38824 m .42687 .38174 L .38726 .37853 L F
.4675 .36997 m .42861 .36235 L .42801 .3688 L 1 .843 0 r
F
.4675 .36997 m .4676 .3635 L .42861 .36235 L F
.50728 .36916 m .4676 .3635 L .4675 .36997 L 1 .8 0 r
F
.61231 .57201 m .56389 .57029 L .56407 .57676 L .88 .473 0 r
F
.61231 .57201 m .61202 .56552 L .56389 .57029 L F
.36923 .52881 m .32337 .51627 L .32268 .52283 L 1 .781 0 r
F
.36877 .53536 m .36923 .52881 L .32268 .52283 L 1 .774 0 r
F
.50728 .36916 m .50687 .36268 L .4676 .3635 L 1 .8 0 r
F
.46493 .60546 m .4151 .59745 L .41498 .60382 L 1 .603 0 r
F
.46488 .6118 m .46493 .60546 L .41498 .60382 L 1 .595 0 r
F
.58953 .38102 m .54855 .37936 L .54939 .38589 L .91 .695 0 r
F
.59081 .38754 m .58953 .38102 L .54939 .38589 L .909 .688 0 r
F
.58941 .38112 m .54853 .37938 L .54938 .38591 L .906 .69 0 r
F
.59068 .38764 m .58941 .38112 L .54938 .38591 L .905 .683 0 r
F
.38004 .42351 m .3396 .41125 L .33831 .41776 L 1 .878 0 r
F
.38004 .42351 m .38093 .41696 L .3396 .41125 L F
.6132 .57892 m .56435 .57705 L .56452 .58354 L .885 .476 0 r
F
.6132 .57892 m .61292 .5724 L .56435 .57705 L F
.46493 .60534 m .41563 .59635 L .41546 .60277 L 1 .642 0 r
F
.46489 .61173 m .46493 .60534 L .41546 .60277 L 1 .634 0 r
F
.56499 .6093 m .51506 .60525 L .51508 .61165 L .941 .502 0 r
F
.56499 .6093 m .56491 .60289 L .51506 .60525 L F
.41631 .57074 m .37035 .55903 L .3704 .56501 L 1 .75 0 r
F
.41613 .57714 m .41631 .57074 L .3704 .56501 L 1 .756 0 r
F
.64841 .46628 m .60357 .46674 L .60441 .47338 L .844 .545 0 r
F
.64951 .47292 m .60441 .47338 L .60522 .48002 L .842 .538 0 r
F
.64951 .47292 m .64841 .46628 L .60441 .47338 L F
.36877 .53536 m .32268 .52283 L .32202 .52939 L 1 .774 0 r
F
.36834 .5419 m .36877 .53536 L .32202 .52939 L 1 .767 0 r
F
.64727 .45964 m .60269 .4601 L .60357 .46674 L .845 .553 0 r
F
.64841 .46628 m .64727 .45964 L .60357 .46674 L .844 .545 0 r
F
.65056 .47957 m .60522 .48002 L .606 .48665 L .841 .53 0 r
F
.65056 .47957 m .64951 .47292 L .60522 .48002 L F
.64608 .453 m .60178 .45347 L .60269 .4601 L .846 .561 0 r
F
.64727 .45964 m .64608 .453 L .60269 .4601 L .845 .553 0 r
F
.41523 .59105 m .36634 .58086 L .3661 .58729 L 1 .668 0 r
F
.4151 .59745 m .41523 .59105 L .3661 .58729 L 1 .66 0 r
F
.46759 .36326 m .42907 .35551 L .42846 .36194 L 1 .844 0 r
F
.46759 .36326 m .46769 .3568 L .42907 .35551 L F
.65157 .48622 m .606 .48665 L .60674 .49329 L .84 .522 0 r
F
.65157 .48622 m .65056 .47957 L .606 .48665 L F
.38093 .41696 m .34092 .40475 L .3396 .41125 L 1 .884 0 r
F
.38093 .41696 m .38184 .41042 L .34092 .40475 L F
.64484 .44637 m .60083 .44684 L .60178 .45347 L .847 .568 0 r
F
.64608 .453 m .64484 .44637 L .60178 .45347 L .846 .561 0 r
F
.42687 .38174 m .3883 .37209 L .38726 .37853 L 1 .876 0 r
F
.42687 .38174 m .42743 .37526 L .3883 .37209 L F
.37625 .46316 m .33431 .4509 L .33336 .4574 L 1 .844 0 r
F
.37625 .46316 m .37693 .45662 L .33431 .4509 L F
.3756 .46968 m .37625 .46316 L .33336 .4574 L 1 .838 0 r
F
.3756 .46968 m .33336 .4574 L .33246 .46389 L F
.37498 .47621 m .3756 .46968 L .33246 .46389 L 1 .831 0 r
F
.37693 .45662 m .3353 .4444 L .33431 .4509 L 1 .851 0 r
F
.37693 .45662 m .37764 .45009 L .3353 .4444 L F
.56461 .60878 m .51497 .60499 L .51498 .61134 L .933 .488 0 r
F
.56461 .60878 m .56455 .60242 L .51497 .60499 L F
.65253 .49286 m .60674 .49329 L .60745 .49992 L .839 .514 0 r
F
.65253 .49286 m .65157 .48622 L .60674 .49329 L F
.42727 .37487 m .38891 .36505 L .38783 .37148 L 1 .877 0 r
F
.42727 .37487 m .42786 .3684 L .38891 .36505 L F
.61257 .57848 m .56407 .57676 L .56423 .58321 L .878 .465 0 r
F
.61257 .57848 m .61231 .57201 L .56407 .57676 L F
.64356 .43975 m .59985 .44022 L .60083 .44684 L .848 .576 0 r
F
.64484 .44637 m .64356 .43975 L .60083 .44684 L .847 .568 0 r
F
.37498 .47621 m .33246 .46389 L .3316 .47038 L 1 .831 0 r
F
.37439 .48272 m .37498 .47621 L .3316 .47038 L 1 .825 0 r
F
.37764 .45009 m .33634 .4379 L .3353 .4444 L 1 .857 0 r
F
.37764 .45009 m .37838 .44355 L .33634 .4379 L F
.58822 .37451 m .54768 .37285 L .54855 .37936 L .91 .702 0 r
F
.58953 .38102 m .58822 .37451 L .54855 .37936 L .91 .695 0 r
F
.64676 .4597 m .60244 .46014 L .60331 .46677 L .84 .546 0 r
F
.64788 .46632 m .60331 .46677 L .60413 .47339 L .839 .538 0 r
F
.64788 .46632 m .64676 .4597 L .60331 .46677 L F
.64895 .47295 m .60413 .47339 L .60493 .48002 L .838 .53 0 r
F
.64895 .47295 m .64788 .46632 L .60413 .47339 L F
.58811 .37461 m .54767 .37286 L .54853 .37938 L .906 .697 0 r
F
.58941 .38112 m .58811 .37461 L .54853 .37938 L .906 .69 0 r
F
.64559 .45308 m .60154 .45352 L .60244 .46014 L .841 .554 0 r
F
.64676 .4597 m .64559 .45308 L .60244 .46014 L .84 .546 0 r
F
.65344 .49951 m .60745 .49992 L .60812 .50655 L .837 .506 0 r
F
.65344 .49951 m .65253 .49286 L .60745 .49992 L F
.64997 .47957 m .60493 .48002 L .60569 .48664 L .836 .522 0 r
F
.64997 .47957 m .64895 .47295 L .60493 .48002 L F
.36834 .5419 m .32202 .52939 L .32141 .53594 L 1 .767 0 r
F
.36794 .54843 m .36834 .5419 L .32141 .53594 L 1 .76 0 r
F
.4676 .3635 m .42921 .35592 L .42861 .36235 L 1 .849 0 r
F
.4676 .3635 m .4677 .35704 L .42921 .35592 L F
.50687 .36268 m .4677 .35704 L .4676 .3635 L 1 .806 0 r
F
.61345 .58542 m .56452 .58354 L .56468 .59001 L .883 .467 0 r
F
.61345 .58542 m .6132 .57892 L .56452 .58354 L F
.37838 .44355 m .33743 .43141 L .33634 .4379 L 1 .863 0 r
F
.37838 .44355 m .37915 .43702 L .33743 .43141 L F
.37439 .48272 m .3316 .47038 L .3308 .47686 L 1 .825 0 r
F
.37383 .48922 m .37439 .48272 L .3308 .47686 L 1 .818 0 r
F
.64438 .44646 m .60061 .4469 L .60154 .45352 L .843 .562 0 r
F
.64559 .45308 m .64438 .44646 L .60154 .45352 L .841 .554 0 r
F
.64223 .43313 m .59883 .4336 L .59985 .44022 L .849 .583 0 r
F
.64356 .43975 m .64223 .43313 L .59985 .44022 L .848 .576 0 r
F
.50687 .36268 m .50646 .35621 L .4677 .35704 L 1 .806 0 r
F
.65095 .4862 m .60569 .48664 L .60641 .49326 L .835 .514 0 r
F
.65095 .4862 m .64997 .47957 L .60569 .48664 L F
.41613 .57714 m .3704 .56501 L .37059 .57084 L 1 .756 0 r
F
.41596 .58353 m .41613 .57714 L .37059 .57084 L 1 .767 0 r
F
.46488 .6118 m .41498 .60382 L .41489 .61017 L 1 .595 0 r
F
.46476 .6181 m .46488 .6118 L .41489 .61017 L 1 .587 0 r
F
.46476 .6181 m .46489 .61173 L .4153 .60922 L 1 .625 0 r
F
.46484 .61812 m .46484 .61796 L .46476 .6181 L F
.46484 .61796 m .46488 .6118 L .46476 .6181 L 1 .587 0 r
F
.46484 .61796 m .46489 .61173 L .46476 .6181 L 1 .625 0 r
F
.46484 .61811 m .46484 .61796 L .46476 .6181 L 1 .587 0 r
F
.64312 .43985 m .59964 .44028 L .60061 .4469 L .844 .569 0 r
F
.64438 .44646 m .64312 .43985 L .60061 .4469 L .843 .562 0 r
F
.38184 .41042 m .34228 .39827 L .34092 .40475 L 1 .889 0 r
F
.38184 .41042 m .38278 .40389 L .34228 .39827 L F
.37915 .43702 m .33855 .42492 L .33743 .43141 L 1 .869 0 r
F
.37915 .43702 m .37994 .43049 L .33855 .42492 L F
.37383 .48922 m .3308 .47686 L .33005 .48332 L 1 .818 0 r
F
.3733 .49572 m .37383 .48922 L .33005 .48332 L 1 .811 0 r
F
.65431 .50615 m .60812 .50655 L .60876 .51318 L .836 .498 0 r
F
.65431 .50615 m .65344 .49951 L .60812 .50655 L F
.46489 .61173 m .41546 .60277 L .4153 .60922 L 1 .634 0 r
F
.65189 .49282 m .60641 .49326 L .6071 .49987 L .833 .506 0 r
F
.65189 .49282 m .65095 .4862 L .60641 .49326 L F
.64086 .42652 m .59779 .42699 L .59883 .4336 L .85 .591 0 r
F
.64223 .43313 m .64086 .42652 L .59883 .4336 L .849 .583 0 r
F
.56505 .61569 m .51508 .61165 L .51509 .61802 L .939 .494 0 r
F
.56505 .61569 m .56499 .6093 L .51508 .61165 L F
.64181 .43325 m .59864 .43367 L .59964 .44028 L .845 .577 0 r
F
.64312 .43985 m .64181 .43325 L .59964 .44028 L .844 .569 0 r
F
.37994 .43049 m .33972 .41843 L .33855 .42492 L 1 .875 0 r
F
.37994 .43049 m .38076 .42396 L .33972 .41843 L F
.65277 .49944 m .6071 .49987 L .60776 .50648 L .832 .498 0 r
F
.65277 .49944 m .65189 .49282 L .6071 .49987 L F
.4151 .59745 m .3661 .58729 L .36589 .5937 L 1 .66 0 r
F
.41498 .60382 m .4151 .59745 L .36589 .5937 L 1 .652 0 r
F
.3733 .49572 m .33005 .48332 L .32935 .48977 L 1 .811 0 r
F
.37281 .50219 m .3733 .49572 L .32935 .48977 L 1 .803 0 r
F
.65513 .51279 m .60876 .51318 L .60937 .5198 L .834 .49 0 r
F
.65513 .51279 m .65431 .50615 L .60876 .51318 L F
.36794 .54843 m .32141 .53594 L .32083 .54248 L 1 .76 0 r
F
.36757 .55495 m .36794 .54843 L .32083 .54248 L 1 .753 0 r
F
.42743 .37526 m .38935 .36567 L .3883 .37209 L 1 .881 0 r
F
.42743 .37526 m .42801 .3688 L .38935 .36567 L F
.64046 .42665 m .5976 .42707 L .59864 .43367 L .846 .585 0 r
F
.64181 .43325 m .64046 .42665 L .59864 .43367 L .845 .577 0 r
F
.63945 .41992 m .59671 .42039 L .59779 .42699 L .851 .598 0 r
F
.64086 .42652 m .63945 .41992 L .59779 .42699 L .85 .591 0 r
F
.61278 .58493 m .56423 .58321 L .56436 .58964 L .877 .456 0 r
F
.61278 .58493 m .61257 .57848 L .56423 .58321 L F
.46769 .3568 m .4297 .34909 L .42907 .35551 L 1 .85 0 r
F
.46769 .3568 m .46779 .35035 L .4297 .34909 L F
.42786 .3684 m .39002 .35864 L .38891 .36505 L 1 .882 0 r
F
.42786 .3684 m .42846 .36194 L .39002 .35864 L F
.58688 .36801 m .54679 .36635 L .54768 .37285 L .91 .708 0 r
F
.58822 .37451 m .58688 .36801 L .54768 .37285 L .91 .702 0 r
F
.38278 .40389 m .34368 .39181 L .34228 .39827 L 1 .895 0 r
F
.38278 .40389 m .38374 .39738 L .34368 .39181 L F
.58677 .36812 m .54678 .36637 L .54767 .37286 L .906 .704 0 r
F
.58811 .37461 m .58677 .36812 L .54767 .37286 L .906 .697 0 r
F
.65361 .50605 m .60776 .50648 L .60837 .51309 L .831 .489 0 r
F
.65361 .50605 m .65277 .49944 L .60776 .50648 L F
.56465 .61511 m .51498 .61134 L .51498 .61765 L .931 .48 0 r
F
.56465 .61511 m .56461 .60878 L .51498 .61134 L F
.38076 .42396 m .34094 .41196 L .33972 .41843 L 1 .881 0 r
F
.38076 .42396 m .38161 .41744 L .34094 .41196 L F
.61366 .5919 m .56468 .59001 L .5648 .59646 L .882 .459 0 r
F
.61366 .5919 m .61345 .58542 L .56468 .59001 L F
.37281 .50219 m .32935 .48977 L .32871 .49621 L 1 .803 0 r
F
.37236 .50865 m .37281 .50219 L .32871 .49621 L 1 .796 0 r
F
.41596 .58353 m .37059 .57084 L .37096 .57645 L 1 .767 0 r
F
.41579 .58994 m .41596 .58353 L .37096 .57645 L 1 .783 0 r
F
.6559 .51942 m .60937 .5198 L .60993 .52641 L .833 .482 0 r
F
.6559 .51942 m .65513 .51279 L .60937 .5198 L F
.63907 .42006 m .59653 .42047 L .5976 .42707 L .847 .592 0 r
F
.64046 .42665 m .63907 .42006 L .5976 .42707 L .846 .585 0 r
F
.63799 .41333 m .59559 .41379 L .59671 .42039 L .852 .606 0 r
F
.63945 .41992 m .63799 .41333 L .59671 .42039 L .851 .598 0 r
F
.4677 .35704 m .42983 .34951 L .42921 .35592 L 1 .854 0 r
F
.4677 .35704 m .46779 .3506 L .42983 .34951 L F
.50646 .35621 m .46779 .3506 L .4677 .35704 L 1 .812 0 r
F
.50646 .35621 m .50603 .34976 L .46779 .3506 L F
.65439 .51266 m .60837 .51309 L .60896 .51968 L .829 .481 0 r
F
.65439 .51266 m .65361 .50605 L .60837 .51309 L F
.36757 .55495 m .32083 .54248 L .3203 .54901 L 1 .753 0 r
F
.36722 .56145 m .36757 .55495 L .3203 .54901 L 1 .746 0 r
F
.38161 .41744 m .34219 .40549 L .34094 .41196 L 1 .886 0 r
F
.38161 .41744 m .38249 .41093 L .34219 .40549 L F
.46474 .61811 m .41489 .61017 L .4148 .61649 L 1 .587 0 r
F
.46484 .61812 m .46476 .6181 L .46474 .61811 L 1 .625 0 r
F
.46484 .61811 m .46476 .6181 L .46474 .61811 L 1 .587 0 r
F
.46476 .6181 m .41489 .61017 L .46474 .61811 L F
.46474 .61811 m .4153 .60922 L .41514 .61567 L 1 .625 0 r
F
.46476 .6181 m .4153 .60922 L .46474 .61811 L F
.4648 .62448 m .46484 .61812 L .46474 .61811 L 1 .615 0 r
F
.4648 .6244 m .46484 .61811 L .46474 .61811 L 1 .578 0 r
F
.46065 .62374 m .46474 .61811 L .4148 .61649 L F
.46083 .62378 m .46474 .61811 L .46065 .62374 L 1 .615 0 r
F
.4648 .62448 m .46476 .62017 L .46083 .62378 L F
.46476 .62017 m .46474 .61811 L .46083 .62378 L F
.51509 .62438 m .46484 .61812 L .4648 .62448 L .997 .546 0 r
F
.4648 .62448 m .46083 .62378 L .45949 .62423 L 1 .615 0 r
F
.45949 .62423 m .4148 .61649 L .41473 .62279 L 1 .578 0 r
F
.46083 .62378 m .46065 .62374 L .45949 .62423 L 1 .615 0 r
F
.4648 .6244 m .46065 .62374 L .45949 .62423 L 1 .578 0 r
F
.46065 .62374 m .4148 .61649 L .45949 .62423 L F
.46065 .62374 m .41514 .61567 L .45949 .62423 L 1 .615 0 r
F
.45949 .62423 m .41514 .61567 L .41499 .62213 L F
.46475 .63082 m .4648 .62448 L .45949 .62423 L 1 .604 0 r
F
.455 .62912 m .45578 .62841 L .45949 .62423 L 1 .57 0 r
F
.44821 .62806 m .45949 .62423 L .41473 .62279 L F
.455 .62912 m .45949 .62423 L .44821 .62806 L F
.45559 .62922 m .45949 .62423 L .45513 .62914 L 1 .604 0 r
F
.46475 .63082 m .46051 .62551 L .45559 .62922 L F
.46051 .62551 m .45949 .62423 L .45559 .62922 L F
.51508 .6307 m .4648 .62448 L .46475 .63082 L .995 .537 0 r
F
.46475 .63082 m .45559 .62922 L .45177 .63024 L 1 .604 0 r
F
.45177 .63024 m .41473 .62279 L .41468 .62906 L 1 .57 0 r
F
.45559 .62922 m .45513 .62914 L .45177 .63024 L 1 .604 0 r
F
.46476 .63066 m .45513 .62914 L .45177 .63024 L 1 .57 0 r
F
.45513 .62914 m .41473 .62279 L .45177 .63024 L F
.45513 .62914 m .4603 .62426 L .455 .62912 L F
.46476 .63066 m .46215 .62691 L .45513 .62914 L F
.46215 .62691 m .4603 .62426 L .45513 .62914 L F
.45513 .62914 m .41499 .62213 L .45171 .63023 L 1 .604 0 r
F
.45513 .62914 m .45171 .63023 L .45177 .63024 L F
.45177 .63024 m .41499 .62213 L .41486 .62859 L F
.44085 .63315 m .45177 .63024 L .41468 .62906 L 1 .561 0 r
F
.46471 .63715 m .46475 .63082 L .45177 .63024 L 1 .593 0 r
F
.44739 .63418 m .45177 .63024 L .44085 .63315 L 1 .561 0 r
F
.44739 .63418 m .45177 .63024 L .41486 .62859 L 1 .593 0 r
F
.46471 .63715 m .45356 .6312 L .44837 .63434 L F
.51506 .63701 m .46475 .63082 L .46471 .63715 L .993 .528 0 r
F
.46471 .63715 m .44837 .63434 L .43995 .6361 L 1 .593 0 r
F
.43995 .6361 m .41468 .62906 L .41464 .6353 L 1 .561 0 r
F
.44837 .63434 m .44739 .63418 L .43995 .6361 L 1 .593 0 r
F
.44837 .63434 m .45177 .63024 L .44739 .63418 L F
.45356 .6312 m .45177 .63024 L .44837 .63434 L F
.46473 .63689 m .44739 .63418 L .43995 .6361 L 1 .561 0 r
F
.44739 .63418 m .41468 .62906 L .43995 .6361 L F
.44739 .63418 m .41486 .62859 L .43995 .6361 L 1 .593 0 r
F
.43995 .6361 m .41486 .62859 L .41474 .63503 L F
.43134 .63789 m .43995 .6361 L .41464 .6353 L 1 .553 0 r
F
.46468 .64345 m .46471 .63715 L .43995 .6361 L 1 .582 0 r
F
.43628 .63866 m .43995 .6361 L .43134 .63789 L 1 .553 0 r
F
.43628 .63866 m .43995 .6361 L .41474 .63503 L 1 .582 0 r
F
.46468 .64345 m .44265 .6369 L .43821 .63899 L F
.51503 .64329 m .46471 .63715 L .46468 .64345 L .991 .519 0 r
F
.46468 .64345 m .43821 .63899 L .42121 .64171 L 1 .582 0 r
F
.42121 .64171 m .41464 .6353 L .41461 .6415 L 1 .553 0 r
F
.43821 .63899 m .43628 .63866 L .42121 .64171 L 1 .582 0 r
F
.43821 .63899 m .43995 .6361 L .43628 .63866 L F
.44265 .6369 m .43995 .6361 L .43821 .63899 L F
.46469 .64308 m .43628 .63866 L .42121 .64171 L 1 .553 0 r
F
.43628 .63866 m .41464 .6353 L .42121 .64171 L F
.43628 .63866 m .41474 .63503 L .42121 .64171 L 1 .582 0 r
F
.42121 .64171 m .41474 .63503 L .41463 .64145 L F
.41863 .64213 m .42121 .64171 L .41461 .6415 L 1 .544 0 r
F
.46464 .64972 m .46468 .64345 L .42121 .64171 L 1 .571 0 r
F
.42002 .64234 m .42121 .64171 L .41863 .64213 L 1 .544 0 r
F
.42002 .64234 m .42121 .64171 L .41463 .64145 L 1 .571 0 r
F
.46464 .64972 m .42121 .64171 L .42002 .64234 L F
.42833 .64363 m .42121 .64171 L .42002 .64234 L 1 .544 0 r
F
.42833 .64363 m .4317 .64204 L .42121 .64171 L F
.51498 .64954 m .46468 .64345 L .46464 .64972 L .989 .509 0 r
F
.51498 .64954 m .51503 .64329 L .46468 .64345 L F
.46466 .64925 m .46469 .64308 L .4317 .64204 L 1 .544 0 r
F
.46466 .64925 m .4317 .64204 L .42833 .64363 L F
.44022 .63928 m .43995 .6361 L .43628 .63866 L 1 .553 0 r
F
.44022 .63928 m .44519 .63627 L .43995 .6361 L F
.51503 .64329 m .51506 .63701 L .46471 .63715 L .991 .519 0 r
F
.46469 .64308 m .46473 .63689 L .44519 .63627 L 1 .553 0 r
F
.46469 .64308 m .44519 .63627 L .44022 .63928 L F
.44876 .63439 m .45177 .63024 L .44739 .63418 L 1 .561 0 r
F
.44876 .63439 m .45414 .63032 L .45177 .63024 L F
.51506 .63701 m .51508 .6307 L .46475 .63082 L .993 .528 0 r
F
.46473 .63689 m .46476 .63066 L .45414 .63032 L 1 .561 0 r
F
.46473 .63689 m .45414 .63032 L .44876 .63439 L F
.45513 .62914 m .45949 .62423 L .41499 .62213 L 1 .604 0 r
F
.45578 .62841 m .4603 .62426 L .45949 .62423 L 1 .57 0 r
F
.51508 .6307 m .51509 .62438 L .4648 .62448 L .995 .537 0 r
F
.46476 .63066 m .4648 .6244 L .4603 .62426 L 1 .57 0 r
F
.4648 .6244 m .46474 .61811 L .46065 .62374 L 1 .578 0 r
F
.46065 .62374 m .46474 .61811 L .41514 .61567 L 1 .615 0 r
F
.51496 .62394 m .46484 .61811 L .4648 .6244 L .986 .526 0 r
F
.63762 .41348 m .59543 .41388 L .59653 .42047 L .848 .6 0 r
F
.63907 .42006 m .63762 .41348 L .59653 .42047 L .847 .592 0 r
F
.37236 .50865 m .32871 .49621 L .32813 .50262 L 1 .796 0 r
F
.37194 .51508 m .37236 .50865 L .32813 .50262 L 1 .787 0 r
F
.65662 .52605 m .60993 .52641 L .61047 .53302 L .831 .473 0 r
F
.65662 .52605 m .6559 .51942 L .60993 .52641 L F
.56508 .62206 m .51509 .61802 L .51509 .62438 L .937 .485 0 r
F
.56508 .62206 m .56505 .61569 L .51509 .61802 L F
.38374 .39738 m .34511 .38536 L .34368 .39181 L 1 .9 0 r
F
.38374 .39738 m .38473 .39088 L .34511 .38536 L F
.63648 .40676 m .59444 .40721 L .59559 .41379 L .853 .613 0 r
F
.63799 .41333 m .63648 .40676 L .59559 .41379 L .852 .606 0 r
F
.42801 .3688 m .39043 .35927 L .38935 .36567 L 1 .887 0 r
F
.42801 .3688 m .42861 .36235 L .39043 .35927 L F
.41498 .60382 m .36589 .5937 L .3657 .60009 L 1 .652 0 r
F
.41489 .61017 m .41498 .60382 L .3657 .60009 L 1 .644 0 r
F
.65513 .51926 m .60896 .51968 L .6095 .52627 L .827 .473 0 r
F
.65513 .51926 m .65439 .51266 L .60896 .51968 L F
.61297 .59136 m .56436 .58964 L .56447 .59604 L .875 .447 0 r
F
.61297 .59136 m .61278 .58493 L .56436 .58964 L F
.41579 .58994 m .37096 .57645 L .37164 .58168 L 1 .783 0 r
F
.40052 .59131 m .41579 .58994 L .37164 .58168 L 1 .806 0 r
F
.41556 .59633 m .37164 .58168 L .37289 .5862 L F
.41563 .59635 m .41556 .59632 L .41556 .59633 L F
.41556 .59632 m .37164 .58168 L .41556 .59633 L F
.41489 .61017 m .3657 .60009 L .36555 .60646 L 1 .644 0 r
F
.4148 .61649 m .41489 .61017 L .36555 .60646 L 1 .636 0 r
F
.4153 .60922 m .41546 .60277 L .37554 .58897 L 1 .89 0 r
F
.41546 .60277 m .41563 .59635 L .37289 .5862 L 1 .84 0 r
F
.32684 .58284 m .31827 .58016 L .31564 .58313 L 1 .419 0 r
F
.32915 .58278 m .31845 .5802 L .32684 .58284 L F
.31845 .5802 m .31827 .58016 L .32684 .58284 L F
.31564 .58313 m .31827 .58015 L .26875 .56872 L .726 .923 0 r
F
.31827 .58015 m .31854 .57499 L .28278 .56882 L 1 .764 0 r
F
.36661 .57441 m .31934 .56203 L .31892 .56852 L 1 .731 0 r
F
.36634 .58086 m .36661 .57441 L .31892 .56852 L 1 .724 0 r
F
.36634 .58086 m .31892 .56852 L .31854 .57499 L F
.3661 .58729 m .36634 .58086 L .33995 .57762 L 1 .716 0 r
F
.3661 .58729 m .33995 .57762 L .33733 .57888 L F
.3661 .58729 m .32801 .57615 L .32787 .5774 L F
.32915 .58278 m .31854 .57499 L .31827 .58015 L F
.34447 .58465 m .33601 .57951 L .32915 .58278 L F
.3661 .58729 m .3504 .58323 L .34447 .58465 L F
.3504 .58323 m .33601 .57951 L .34447 .58465 L F
.36589 .5937 m .36596 .59163 L .33921 .58593 L 1 .708 0 r
F
.32716 .58375 m .32807 .58331 L .32915 .58278 L .762 .062 0 r
F
.32713 .58375 m .32915 .58278 L .31564 .58313 L F
.32716 .58375 m .32915 .58278 L .32713 .58375 L F
.33921 .58593 m .32915 .58278 L .32773 .58348 L 1 .708 0 r
F
.34071 .58556 m .32915 .58278 L .33921 .58593 L F
.36596 .59163 m .3661 .58729 L .32915 .58278 L F
.37289 .5862 m .32918 .58278 L .32807 .58331 L .762 .062 0 r
F
.32717 .58375 m .32807 .58331 L .32716 .58375 L F
.33737 .58637 m .33921 .58593 L .32773 .58348 L 1 .708 0 r
F
.33737 .58637 m .32773 .58348 L .32717 .58375 L F
.37289 .5862 m .32807 .58331 L .32717 .58375 L .762 .062 0 r
F
.32773 .58348 m .32915 .58278 L .31821 .58144 L 1 .708 0 r
F
.36596 .59163 m .34071 .58556 L .33921 .58593 L F
.32435 .58953 m .32652 .58896 L .32416 .58953 L .393 0 0 r
F
.36589 .5937 m .33921 .58593 L .33737 .58637 L 1 .708 0 r
F
.32657 .58896 m .31564 .58313 L .31542 .58962 L .762 .062 0 r
F
.32671 .58895 m .32716 .58375 L .32685 .58642 L F
.32671 .58895 m .32685 .58642 L .32657 .58896 L F
.34605 .59447 m .36589 .5937 L .32671 .58895 L 1 .701 0 r
F
.3657 .60009 m .32671 .58895 L .32665 .59011 L F
.36589 .5937 m .32717 .58375 L .32671 .58895 L 1 .708 0 r
F
.32416 .58953 m .32652 .58896 L .31542 .58962 L .393 0 0 r
F
.32395 .59506 m .31542 .58962 L .31524 .59608 L F
.34393 .59453 m .32435 .58953 L .32395 .59506 L 1 .701 0 r
F
.32665 .59011 m .32671 .58895 L .32536 .58928 L F
.32435 .58953 m .32481 .58941 L .32435 .58953 L .393 0 0 r
F
.32665 .59011 m .32536 .58928 L .32435 .58953 L 1 .701 0 r
F
.32481 .58941 m .32652 .58896 L .32435 .58953 L .393 0 0 r
F
.32536 .58928 m .32441 .58867 L .32435 .58953 L 1 .701 0 r
F
.32668 .58896 m .32667 .58896 L .32481 .58941 L .393 0 0 r
F
.32667 .58896 m .32652 .58896 L .32481 .58941 L F
.37554 .58897 m .32668 .58896 L .32481 .58941 L F
.37554 .58897 m .32481 .58941 L .32435 .58953 L F
.32668 .58896 m .32673 .58895 L .32652 .58896 L F
.32536 .58928 m .32671 .58895 L .32441 .58867 L 1 .701 0 r
F
.32435 .58953 m .32441 .58867 L .31791 .58788 L F
.32397 .59505 m .32435 .58953 L .32395 .59506 L .393 0 0 r
F
.37554 .58897 m .32435 .58953 L .32397 .59505 L F
.32435 .58953 m .31542 .58962 L .32395 .59506 L F
.32055 .6011 m .31524 .59608 L .3151 .60252 L .299 .188 0 r
F
.32435 .58953 m .32136 .58876 L .32395 .59506 L 1 .701 0 r
F
.32136 .58876 m .32117 .59175 L .32395 .59506 L F
.32395 .59506 m .31791 .58788 L .31765 .5943 L F
.3657 .60009 m .34393 .59453 L .32395 .59506 L F
.32094 .59514 m .32395 .59506 L .31524 .59608 L .299 .188 0 r
F
.32095 .59513 m .32395 .59506 L .32094 .59514 L F
.35927 .60487 m .32097 .5947 L .32095 .59513 L 1 .692 0 r
F
.36555 .60646 m .35965 .6049 L .35927 .60487 L F
.35965 .6049 m .32097 .5947 L .35927 .60487 L F
.36555 .60646 m .3657 .60009 L .32395 .59506 L F
.36555 .60646 m .32395 .59506 L .32248 .59509 L F
.32095 .59513 m .32395 .59506 L .32095 .59513 L .299 .188 0 r
F
.32248 .59509 m .32395 .59506 L .32097 .5947 L 1 .692 0 r
F
.32095 .59513 m .32397 .59505 L .32395 .59506 L .299 .188 0 r
F
.34533 .59108 m .35723 .59113 L .32397 .59505 L F
.34533 .59108 m .32397 .59505 L .32095 .59513 L F
.3657 .60009 m .36588 .59395 L .34605 .59447 L 1 .701 0 r
F
.36588 .59395 m .36589 .5937 L .34605 .59447 L F
.37554 .58897 m .37289 .5862 L .32673 .58895 L .393 0 0 r
F
.37554 .58897 m .32673 .58895 L .32668 .58896 L F
.37031 .58796 m .37554 .58897 L .35723 .59113 L .299 .188 0 r
F
.38442 .59068 m .37289 .5862 L .37554 .58897 L 1 .84 0 r
F
.41544 .60276 m .37289 .5862 L .41543 .60276 L F
.38387 .58468 m .37554 .58897 L .37031 .58796 L .299 .188 0 r
F
.38387 .58468 m .35723 .59113 L .34533 .59108 L F
.36542 .6128 m .36555 .60646 L .32065 .60108 L 1 .684 0 r
F
.32094 .59514 m .31524 .59608 L .32055 .6011 L .299 .188 0 r
F
.31789 .60081 m .32065 .60108 L .3151 .60252 L .526 .778 0 r
F
.31789 .60081 m .32065 .60108 L .31789 .60081 L F
.31789 .60081 m .32065 .60108 L .31789 .60075 L 1 .684 0 r
F
.31789 .60081 m .31789 .60075 L .31744 .60069 L F
.3177 .60712 m .3151 .60252 L .31499 .60892 L .526 .778 0 r
F
.3177 .6071 m .3151 .60252 L .3177 .60712 L F
.31789 .60081 m .3151 .60252 L .3177 .60711 L F
.3177 .60712 m .31744 .60069 L .31726 .60706 L 1 .684 0 r
F
.36542 .6128 m .31789 .60081 L .3177 .60712 L F
.31789 .60081 m .31744 .60069 L .3177 .60712 L F
.3177 .60711 m .3177 .6071 L .3177 .60712 L .526 .778 0 r
F
.31789 .6008 m .32065 .60108 L .31789 .60081 L F
.32063 .6015 m .32065 .60108 L .31789 .60081 L 1 .684 0 r
F
.36542 .6128 m .32065 .60108 L .32063 .6015 L F
.32065 .60108 m .32094 .59514 L .32075 .59805 L .299 .188 0 r
F
.32065 .60108 m .32075 .59805 L .32055 .6011 L F
.35927 .60487 m .32095 .59513 L .32065 .60108 L 1 .692 0 r
F
.32066 .60107 m .32083 .59753 L .32065 .60108 L .299 .188 0 r
F
.32083 .59753 m .32094 .59514 L .32065 .60108 L F
.32095 .59513 m .31765 .5943 L .32065 .60108 L 1 .692 0 r
F
.32065 .60108 m .31765 .5943 L .31744 .60069 L F
.36555 .60646 m .35927 .60487 L .32065 .60108 L F
.31789 .6008 m .32066 .60107 L .32065 .60108 L .526 .778 0 r
F
.38387 .58468 m .32095 .59513 L .32066 .60107 L .299 .188 0 r
F
.37289 .5862 m .32717 .58375 L .32671 .58895 L .762 .062 0 r
F
.33601 .57951 m .31854 .57499 L .32915 .58278 L 1 .716 0 r
F
.33733 .57888 m .33995 .57762 L .32801 .57615 L F
.32787 .5774 m .32801 .57615 L .31854 .57499 L F
.37164 .58168 m .32796 .56917 L .31827 .58015 L 1 .419 0 r
F
.37164 .58168 m .31827 .58015 L .31833 .58016 L F
.37289 .5862 m .37164 .58168 L .32918 .58278 L .762 .062 0 r
F
.37164 .58168 m .31827 .58016 L .32915 .58278 L 1 .419 0 r
F
.36661 .57441 m .3669 .56794 L .31934 .56203 L 1 .731 0 r
F
.3669 .56794 m .36722 .56145 L .3198 .55552 L 1 .739 0 r
F
.3669 .56794 m .3198 .55552 L .31934 .56203 L F
.37059 .57084 m .3704 .56501 L .32874 .55839 L 1 .626 0 r
F
.32876 .55866 m .32874 .55839 L .32673 .55807 L F
.37059 .57084 m .32874 .55839 L .32876 .55866 L F
.32258 .59986 m .3306 .59849 L .32066 .60107 L .526 .778 0 r
F
.37059 .57084 m .32673 .55807 L .32724 .56372 L 1 .626 0 r
F
.37096 .57645 m .37059 .57084 L .32724 .56372 L 1 .555 0 r
F
.37096 .57645 m .32724 .56372 L .32796 .56917 L F
.37164 .58168 m .37096 .57645 L .32796 .56917 L 1 .419 0 r
F
.32716 .58375 m .31564 .58313 L .32657 .58896 L .762 .062 0 r
F
.32671 .58895 m .31821 .58144 L .31791 .58788 L 1 .708 0 r
F
.32717 .58375 m .32716 .58375 L .32671 .58895 L .762 .062 0 r
F
.32717 .58375 m .31821 .58144 L .32671 .58895 L 1 .708 0 r
F
.31542 .58962 m .31564 .58313 L .26835 .5753 L 1 .735 0 r
F
.31542 .58962 m .26835 .5753 L .26801 .58187 L F
.31524 .59608 m .31542 .58962 L .26801 .58187 L 1 .725 0 r
F
.31564 .58313 m .26875 .56872 L .26835 .5753 L .726 .923 0 r
F
.31791 .58788 m .31821 .58144 L .27212 .57355 L 1 .756 0 r
F
.31791 .58788 m .27212 .57355 L .27173 .58002 L F
.31765 .5943 m .31791 .58788 L .27173 .58002 L 1 .748 0 r
F
.31524 .59608 m .26801 .58187 L .26772 .58842 L 1 .725 0 r
F
.31765 .5943 m .27173 .58002 L .2714 .58647 L 1 .748 0 r
F
.29585 .58723 m .33358 .5881 L .28383 .58578 L .827 .06 0 r
F
.34026 .5887 m .3306 .59849 L .32258 .59986 L .526 .778 0 r
F
.42753 .53277 m .41795 .52845 L .41786 .5317 L 1 .68 0 r
F
.44244 .53441 m .42757 .53079 L .42753 .53277 L F
.42757 .53079 m .41795 .52845 L .42753 .53277 L F
.41499 .62213 m .41514 .61567 L .42675 .55152 L 0 0 0 r
F
.41499 .62213 m .42675 .55152 L .42673 .55182 L F
.42698 .55147 m .42718 .54912 L .42716 .55043 L F
.41499 .62213 m .42708 .54975 L .42698 .55147 L F
.42708 .54975 m .42718 .54912 L .42698 .55147 L F
.41543 .60276 m .38442 .59068 L .37554 .58897 L 1 .84 0 r
F
.4153 .60922 m .37554 .58897 L .38387 .58468 L 1 .89 0 r
F
.41514 .61567 m .4153 .60922 L .40703 .60276 L 1 .842 0 r
F
.41514 .61567 m .40703 .60276 L .40424 .60486 L F
.4148 .61649 m .36555 .60646 L .36542 .6128 L 1 .636 0 r
F
.41473 .62279 m .4148 .61649 L .36542 .6128 L 1 .628 0 r
F
.41473 .62279 m .36542 .6128 L .36532 .61912 L F
.41468 .62906 m .41473 .62279 L .36532 .61912 L 1 .62 0 r
F
.41546 .60277 m .41544 .60276 L .41543 .60276 L 1 .84 0 r
F
.40424 .60486 m .40703 .60276 L .40465 .6009 L 1 .842 0 r
F
.39931 .59998 m .40465 .6009 L .38387 .58468 L F
.40424 .60486 m .40465 .6009 L .39931 .59998 L F
.41563 .59635 m .41576 .59137 L .40052 .59131 L 1 .806 0 r
F
.41576 .59137 m .41579 .58994 L .40052 .59131 L F
.44241 .53765 m .44244 .53441 L .42477 .53246 L 1 .671 0 r
F
.42383 .53315 m .42477 .53246 L .41786 .5317 L F
.44241 .53765 m .42477 .53246 L .42383 .53315 L F
.44241 .53765 m .41786 .5317 L .41778 .53494 L F
.44238 .54087 m .44241 .53765 L .41778 .53494 L 1 .661 0 r
F
.4274 .53922 m .41778 .53494 L .41772 .53815 L F
.44238 .54087 m .42744 .53727 L .4274 .53922 L F
.42744 .53727 m .41778 .53494 L .4274 .53922 L F
.42716 .55043 m .42718 .54912 L .42722 .54892 L 0 0 0 r
F
.44236 .54407 m .44238 .54087 L .41772 .53815 L 1 .651 0 r
F
.42735 .54242 m .41772 .53815 L .41767 .54136 L F
.44236 .54407 m .42738 .54047 L .42735 .54242 L F
.42738 .54047 m .41772 .53815 L .42735 .54242 L F
.4272 .5502 m .42722 .54892 L .42723 .54885 L 0 0 0 r
F
.44235 .54725 m .44236 .54407 L .42735 .54242 L 1 .641 0 r
F
.42733 .54366 m .42735 .54242 L .41767 .54136 L F
.44235 .54725 m .42735 .54242 L .42733 .54366 L F
.41514 .61567 m .38387 .58468 L .41763 .5463 L 1 .842 0 r
F
.42725 .54876 m .42268 .54675 L .41763 .5463 L 1 .631 0 r
F
.42268 .54675 m .41764 .54454 L .41763 .5463 L F
.40978 .5456 m .38387 .58468 L .3306 .59849 L .526 .778 0 r
F
.42728 .54683 m .41764 .54454 L .42725 .54876 L 1 .631 0 r
F
.44235 .54725 m .41767 .54136 L .41764 .54454 L 1 .641 0 r
F
.44235 .55041 m .44235 .54725 L .4273 .5456 L 1 .631 0 r
F
.42728 .54683 m .4273 .5456 L .41764 .54454 L F
.44235 .55041 m .4273 .5456 L .42728 .54683 L F
.44235 .55041 m .42728 .54683 L .42725 .54876 L F
.41514 .61567 m .41762 .54633 L .41808 .54644 L 1 .842 0 r
F
.42716 .54925 m .41808 .54644 L .42725 .54876 L F
.41514 .61567 m .41808 .54644 L .42716 .54925 L F
.41025 .54529 m .41763 .5463 L .40978 .5456 L .526 .778 0 r
F
.40735 .54511 m .40954 .54352 L .33358 .5881 L 0 0 0 r
F
.38469 .56067 m .34502 .58886 L .34026 .5887 L .526 .778 0 r
F
.40878 .54509 m .41763 .5463 L .40878 .54421 L 1 .698 0 r
F
.40786 .54481 m .40954 .54352 L .40735 .54511 L 0 0 0 r
F
.40987 .54333 m .40954 .54352 L .40786 .54481 L F
.41763 .5463 m .41764 .54454 L .40992 .5433 L 1 .698 0 r
F
.40987 .54333 m .40992 .5433 L .40954 .54352 L 0 0 0 r
F
.36722 .56145 m .3203 .54901 L .3198 .55552 L 1 .746 0 r
F
.3704 .56501 m .37035 .55903 L .32641 .55226 L 1 .668 0 r
F
.3704 .56501 m .32641 .55226 L .32673 .55807 L F
.41763 .5463 m .38387 .58468 L .40978 .5456 L .526 .778 0 r
F
.42673 .55182 m .42675 .55152 L .42718 .54912 L 0 0 0 r
F
.41499 .62213 m .42714 .55051 L .36651 .61756 L F
.44235 .55355 m .44235 .55258 L .43161 .55046 L 1 .621 0 r
F
.42721 .55011 m .42723 .54885 L .42725 .54876 L 0 0 0 r
F
.42721 .55011 m .42725 .54876 L .42724 .54904 L F
.42721 .55011 m .42725 .549 L .42723 .54998 L F
.42724 .54904 m .42725 .54876 L .42725 .549 L F
.42724 .5496 m .42725 .54876 L .41762 .54771 L 1 .621 0 r
F
.44235 .55258 m .42725 .54876 L .42724 .5496 L F
.42725 .549 m .42725 .54876 L .42725 .54873 L 0 0 0 r
F
.42723 .54998 m .42725 .54873 L .42724 .54996 L F
.42725 .549 m .42725 .54873 L .42723 .54998 L F
.42723 .54998 m .43161 .55046 L .42724 .5496 L 1 .621 0 r
F
.4272 .5502 m .42723 .54885 L .42721 .55011 L 0 0 0 r
F
.42716 .55043 m .42722 .54892 L .4272 .5502 L F
.42723 .54998 m .42724 .5496 L .41762 .54771 L 1 .621 0 r
F
.44235 .55355 m .43161 .55046 L .42723 .54998 L F
.42714 .55051 m .42723 .54998 L .41761 .54893 L 0 0 0 r
F
.44235 .55258 m .44235 .55041 L .42725 .54876 L 1 .621 0 r
F
.41762 .54633 m .41763 .5463 L .42725 .54876 L 1 .842 0 r
F
.46794 .55195 m .44235 .54725 L .44235 .55041 L 1 .559 0 r
F
.46805 .54564 m .44238 .54087 L .44236 .54407 L 1 .578 0 r
F
.46804 .54881 m .46805 .54564 L .44236 .54407 L 1 .569 0 r
F
.49578 .55718 m .49564 .55322 L .47168 .54885 L 1 .876 0 r
F
.47168 .54885 m .46805 .54564 L .46804 .54881 L 1 .489 0 r
F
.47173 .5488 m .46805 .54564 L .47168 .54885 L F
.49564 .55322 m .47428 .54646 L .47168 .54885 L 1 .874 0 r
F
.47327 .54763 m .46805 .54564 L .4718 .54885 L 1 .489 0 r
F
.47428 .54646 m .47499 .54572 L .46805 .54564 L F
.47499 .54572 m .46807 .54244 L .46805 .54564 L 1 .498 0 r
F
.49564 .55322 m .4955 .54933 L .47493 .54571 L 1 .874 0 r
F
.4955 .54933 m .49538 .54549 L .47819 .54261 L 1 .871 0 r
F
.47676 .54361 m .46807 .54244 L .47499 .54572 L 1 .498 0 r
F
.47795 .54257 m .46809 .53922 L .46807 .54244 L 1 .508 0 r
F
.48061 .53938 m .46811 .53598 L .46809 .53922 L 1 .517 0 r
F
.48305 .53617 m .46813 .53272 L .46811 .53598 L 1 .526 0 r
F
.48529 .53294 m .46815 .52943 L .46813 .53272 L 1 .535 0 r
F
.48738 .52968 m .46817 .52612 L .46815 .52943 L 1 .544 0 r
F
.48932 .52639 m .46819 .52279 L .46817 .52612 L 1 .553 0 r
F
.4878 .52884 m .46817 .52612 L .48737 .52967 L 1 .544 0 r
F
.4878 .52884 m .48737 .52967 L .48738 .52968 L F
.49494 .53066 m .49485 .52705 L .48934 .52639 L 1 .849 0 r
F
.49485 .52705 m .49476 .52346 L .49132 .52308 L 1 .844 0 r
F
.48961 .52577 m .46819 .52279 L .48932 .52638 L 1 .553 0 r
F
.48961 .52577 m .48932 .52638 L .48934 .52639 L F
.48932 .52638 m .46819 .52279 L .48932 .52639 L F
.4912 .52307 m .46821 .51944 L .46819 .52279 L 1 .562 0 r
F
.49285 .51972 m .46824 .51606 L .46821 .51944 L 1 .57 0 r
F
.49135 .52266 m .46821 .51944 L .49118 .52307 L 1 .562 0 r
F
.49135 .52266 m .49118 .52307 L .4912 .52307 L F
.49476 .52346 m .49468 .51989 L .49297 .51972 L 1 .84 0 r
F
.4946 .51634 m .49461 .51292 L .46826 .51267 L 1 .579 0 r
F
.49452 .51634 m .46826 .51267 L .46824 .51606 L F
.4946 .51634 m .49452 .51633 L .49452 .51634 L F
.49452 .51633 m .46826 .51267 L .49452 .51634 L F
.49286 .5197 m .46824 .51606 L .49285 .51972 L 1 .57 0 r
F
.49303 .51952 m .46824 .51606 L .49297 .51972 L F
.49348 .51962 m .49303 .51952 L .49343 .51977 L 1 .835 0 r
F
.49303 .51952 m .49452 .51634 L .46824 .51606 L 1 .57 0 r
F
.49303 .51952 m .46842 .51401 L .49297 .51966 L 1 .835 0 r
F
.49303 .51952 m .49297 .51966 L .49343 .51977 L F
.49468 .51989 m .4946 .51661 L .49439 .51701 L F
.4934 .5196 m .49439 .51701 L .49306 .51953 L F
.49468 .51989 m .49439 .51701 L .4934 .5196 L F
.52499 .52153 m .5248 .5177 L .49466 .51634 L 1 .784 0 r
F
.49461 .51292 m .49462 .50947 L .46828 .50925 L 1 .587 0 r
F
.5248 .5177 m .52463 .51388 L .49623 .51286 L 1 .782 0 r
F
.52463 .51388 m .52445 .51006 L .49813 .50936 L 1 .781 0 r
F
.49623 .51286 m .49462 .50947 L .49461 .51292 L .978 .494 0 r
F
.49462 .50947 m .49462 .506 L .46831 .50581 L 1 .595 0 r
F
.49462 .50947 m .46831 .50581 L .46828 .50925 L F
.49623 .51286 m .49445 .50926 L .49452 .5128 L 1 .781 0 r
F
.52463 .51388 m .49751 .50973 L .49623 .51286 L F
.49694 .51112 m .49731 .50971 L .49623 .51286 L .978 .494 0 r
F
.49731 .50971 m .49462 .50947 L .49623 .51286 L F
.49769 .50935 m .49462 .506 L .49462 .50947 L .983 .502 0 r
F
.49462 .506 m .49462 .50249 L .46834 .50235 L 1 .603 0 r
F
.49462 .506 m .46834 .50235 L .46831 .50581 L F
.49769 .50935 m .49438 .50573 L .49445 .50926 L 1 .779 0 r
F
.52445 .51006 m .49923 .50643 L .49769 .50935 L F
.52445 .51006 m .52429 .50624 L .49906 .50581 L F
.52429 .50624 m .52413 .50242 L .50078 .50225 L 1 .777 0 r
F
.49906 .50581 m .49462 .50249 L .49462 .506 L .987 .509 0 r
F
.49987 .50296 m .49462 .50249 L .49906 .50581 L F
.49462 .50249 m .49461 .49896 L .46836 .49887 L 1 .611 0 r
F
.50035 .50225 m .49461 .49896 L .49462 .50249 L .992 .516 0 r
F
.50156 .49865 m .4946 .4954 L .49461 .49896 L .997 .523 0 r
F
.5027 .49502 m .49459 .4918 L .4946 .4954 L 1 .53 0 r
F
.50379 .49136 m .49458 .48818 L .49459 .4918 L 1 .537 0 r
F
.50481 .48766 m .49456 .48452 L .49458 .48818 L 1 .543 0 r
F
.50579 .48391 m .49454 .48084 L .49456 .48452 L 1 .55 0 r
F
.49454 .48084 m .46854 .47751 L .46851 .48113 L 1 .656 0 r
F
.49456 .48452 m .49454 .48084 L .46851 .48113 L 1 .649 0 r
F
.50579 .48391 m .49395 .48083 L .494 .48443 L 1 .768 0 r
F
.52341 .48314 m .50663 .48183 L .50579 .48391 L F
.52355 .48704 m .52341 .48314 L .50579 .48391 L 1 .77 0 r
F
.52355 .48704 m .50579 .48391 L .50578 .48397 L F
.50518 .48542 m .50579 .48391 L .49456 .48452 L 1 .543 0 r
F
.52355 .48704 m .50616 .48404 L .50572 .48546 L 1 .77 0 r
F
.52368 .49091 m .52355 .48704 L .50481 .48766 L 1 .771 0 r
F
.49456 .48452 m .46851 .48113 L .46848 .48472 L 1 .649 0 r
F
.49458 .48818 m .49456 .48452 L .46848 .48472 L 1 .641 0 r
F
.50481 .48766 m .494 .48443 L .49406 .48801 L 1 .77 0 r
F
.52355 .48704 m .50572 .48546 L .50481 .48766 L F
.50505 .48764 m .50509 .48644 L .50481 .48766 L 1 .543 0 r
F
.50509 .48644 m .50513 .48541 L .50481 .48766 L F
.50572 .48546 m .50532 .48543 L .50481 .48766 L 1 .77 0 r
F
.50513 .48541 m .49456 .48452 L .50481 .48766 L 1 .543 0 r
F
.50532 .48543 m .494 .48443 L .50481 .48766 L 1 .77 0 r
F
.52368 .49091 m .50481 .48766 L .50481 .4877 L 1 .771 0 r
F
.50425 .48901 m .50481 .48766 L .49458 .48818 L 1 .537 0 r
F
.52368 .49091 m .5048 .4877 L .50437 .48902 L 1 .771 0 r
F
.50437 .48902 m .50481 .48766 L .50425 .48901 L 1 .537 0 r
F
.5048 .4877 m .50457 .48766 L .50437 .48902 L 1 .771 0 r
F
.50462 .48904 m .50481 .48766 L .50437 .48902 L 1 .537 0 r
F
.50462 .48904 m .50505 .48764 L .50481 .48766 L F
.52159 .49049 m .5216 .48679 L .50505 .48764 L F
.52159 .49049 m .50505 .48764 L .50462 .48904 L F
.50572 .48546 m .50577 .48397 L .50532 .48543 L 1 .77 0 r
F
.50616 .48404 m .50577 .48397 L .50572 .48546 L F
.50532 .48543 m .50579 .48391 L .50518 .48542 L 1 .543 0 r
F
.50577 .48397 m .50551 .48393 L .50532 .48543 L 1 .77 0 r
F
.5216 .48679 m .50579 .48391 L .50532 .48543 L 1 .543 0 r
F
.5216 .48679 m .52161 .48305 L .50579 .48391 L F
.50663 .48183 m .50623 .48179 L .50579 .48391 L 1 .768 0 r
F
.50623 .48179 m .50603 .48178 L .50579 .48391 L 1 .55 0 r
F
.50603 .48178 m .49454 .48084 L .50579 .48391 L F
.50623 .48179 m .49395 .48083 L .50579 .48391 L 1 .768 0 r
F
.52161 .48305 m .50623 .48179 L .50579 .48391 L 1 .55 0 r
F
.50578 .48397 m .50579 .48391 L .50551 .48393 L 1 .77 0 r
F
.50532 .48543 m .50551 .48393 L .494 .48443 L F
.5216 .48679 m .50532 .48543 L .50505 .48764 L 1 .543 0 r
F
.50532 .48543 m .50513 .48541 L .50505 .48764 L F
.50481 .4877 m .50481 .48766 L .50457 .48766 L 1 .771 0 r
F
.50437 .48902 m .50457 .48766 L .49406 .48801 L F
.49458 .48818 m .46848 .48472 L .46845 .48829 L 1 .641 0 r
F
.49459 .4918 m .49458 .48818 L .46845 .48829 L 1 .634 0 r
F
.50379 .49136 m .49406 .48801 L .49412 .49158 L 1 .771 0 r
F
.52368 .49091 m .50477 .48906 L .50379 .49136 L F
.52383 .49476 m .52368 .49091 L .50379 .49136 L 1 .773 0 r
F
.52158 .49415 m .52159 .49049 L .50379 .49136 L 1 .53 0 r
F
.50328 .49256 m .50379 .49136 L .49459 .4918 L F
.52383 .49476 m .50379 .49136 L .50378 .49139 L 1 .773 0 r
F
.52383 .49476 m .50377 .49139 L .50337 .49257 L F
.50337 .49257 m .50379 .49136 L .50328 .49256 L 1 .53 0 r
F
.50377 .49139 m .50359 .49136 L .50337 .49257 L 1 .773 0 r
F
.52158 .49415 m .50379 .49136 L .50337 .49257 L 1 .53 0 r
F
.50477 .48906 m .50437 .48902 L .50379 .49136 L 1 .771 0 r
F
.50411 .49008 m .50418 .489 L .50379 .49136 L 1 .537 0 r
F
.50418 .489 m .49458 .48818 L .50379 .49136 L F
.50437 .48902 m .49406 .48801 L .50379 .49136 L 1 .771 0 r
F
.50401 .49135 m .50411 .49008 L .50379 .49136 L 1 .537 0 r
F
.52159 .49049 m .50437 .48902 L .50401 .49135 L F
.50437 .48902 m .50418 .489 L .50401 .49135 L F
.50378 .49139 m .50379 .49136 L .50359 .49136 L 1 .773 0 r
F
.50337 .49257 m .50359 .49136 L .49412 .49158 L F
.50319 .49255 m .49459 .4918 L .5027 .49502 L 1 .53 0 r
F
.49459 .4918 m .46845 .48829 L .46842 .49184 L 1 .634 0 r
F
.4946 .4954 m .49459 .4918 L .46842 .49184 L 1 .626 0 r
F
.5027 .49502 m .49412 .49158 L .49419 .49513 L 1 .773 0 r
F
.52383 .49476 m .50377 .49261 L .5027 .49502 L F
.52397 .4986 m .52383 .49476 L .5027 .49502 L 1 .774 0 r
F
.52156 .49777 m .52158 .49415 L .5027 .49502 L .997 .523 0 r
F
.50224 .49607 m .5027 .49502 L .4946 .4954 L F
.52397 .4986 m .5027 .49502 L .5027 .49505 L 1 .774 0 r
F
.52397 .4986 m .50269 .49505 L .50232 .49607 L F
.50232 .49607 m .5027 .49502 L .50224 .49607 L .997 .523 0 r
F
.50269 .49505 m .50254 .49502 L .50232 .49607 L 1 .774 0 r
F
.52156 .49777 m .5027 .49502 L .50232 .49607 L .997 .523 0 r
F
.50377 .49261 m .50337 .49257 L .5027 .49502 L 1 .773 0 r
F
.50307 .49367 m .50319 .49255 L .5027 .49502 L 1 .53 0 r
F
.50337 .49257 m .49412 .49158 L .5027 .49502 L 1 .773 0 r
F
.50293 .49501 m .50307 .49367 L .5027 .49502 L 1 .53 0 r
F
.52158 .49415 m .50337 .49257 L .50293 .49501 L F
.50337 .49257 m .50319 .49255 L .50293 .49501 L F
.5027 .49505 m .5027 .49502 L .50254 .49502 L 1 .774 0 r
F
.50232 .49607 m .50254 .49502 L .49419 .49513 L F
.50214 .49606 m .4946 .4954 L .50156 .49865 L .997 .523 0 r
F
.4946 .4954 m .46842 .49184 L .46839 .49537 L 1 .626 0 r
F
.49461 .49896 m .4946 .4954 L .46839 .49537 L 1 .619 0 r
F
.50156 .49865 m .49419 .49513 L .49425 .49867 L 1 .774 0 r
F
.52397 .4986 m .50272 .49612 L .50156 .49865 L F
.52413 .50242 m .52397 .4986 L .50156 .49865 L 1 .776 0 r
F
.52154 .50135 m .52156 .49777 L .50156 .49865 L .992 .516 0 r
F
.50115 .49954 m .50156 .49865 L .49461 .49896 L F
.52413 .50242 m .50156 .49865 L .50156 .49867 L 1 .776 0 r
F
.52413 .50242 m .50155 .49867 L .50121 .49954 L F
.50121 .49954 m .50156 .49865 L .50115 .49954 L .992 .516 0 r
F
.50155 .49867 m .50143 .49865 L .50121 .49954 L 1 .776 0 r
F
.52154 .50135 m .50156 .49865 L .50121 .49954 L .992 .516 0 r
F
.50272 .49612 m .50232 .49607 L .50156 .49865 L 1 .774 0 r
F
.50198 .49723 m .50214 .49606 L .50156 .49865 L .997 .523 0 r
F
.50232 .49607 m .49419 .49513 L .50156 .49865 L 1 .774 0 r
F
.50178 .49864 m .50198 .49723 L .50156 .49865 L .997 .523 0 r
F
.52156 .49777 m .50232 .49607 L .50178 .49864 L F
.50232 .49607 m .50214 .49606 L .50178 .49864 L F
.50156 .49867 m .50156 .49865 L .50143 .49865 L 1 .776 0 r
F
.50121 .49954 m .50143 .49865 L .49425 .49867 L F
.50104 .49953 m .49461 .49896 L .50035 .50225 L .992 .516 0 r
F
.49461 .49896 m .46839 .49537 L .46836 .49887 L 1 .619 0 r
F
.50035 .50225 m .49425 .49867 L .49431 .5022 L 1 .776 0 r
F
.52413 .50242 m .50162 .49959 L .50035 .50225 L F
.50045 .50303 m .50078 .50225 L .50035 .50225 L 1 .777 0 r
F
.52429 .50624 m .50078 .50225 L .50045 .50303 L F
.52151 .50489 m .52154 .50135 L .50035 .50225 L .987 .509 0 r
F
.5 .50297 m .50035 .50225 L .49462 .50249 L F
.50045 .50303 m .50035 .50225 L .5003 .50245 L 1 .777 0 r
F
.50045 .50303 m .50028 .5024 L .50005 .50298 L F
.50005 .50298 m .50035 .50225 L .5 .50297 L .987 .509 0 r
F
.50028 .5024 m .50024 .50225 L .50005 .50298 L 1 .777 0 r
F
.52151 .50489 m .50035 .50225 L .50005 .50298 L .987 .509 0 r
F
.50162 .49959 m .50121 .49954 L .50035 .50225 L 1 .776 0 r
F
.50083 .50075 m .50104 .49953 L .50035 .50225 L .992 .516 0 r
F
.50121 .49954 m .49425 .49867 L .50035 .50225 L 1 .776 0 r
F
.50057 .50224 m .50083 .50075 L .50035 .50225 L .992 .516 0 r
F
.52154 .50135 m .50121 .49954 L .50057 .50224 L F
.50121 .49954 m .50104 .49953 L .50057 .50224 L F
.5003 .50245 m .50035 .50225 L .50024 .50225 L 1 .777 0 r
F
.49462 .50249 m .46836 .49887 L .46834 .50235 L 1 .611 0 r
F
.49906 .50581 m .49431 .5022 L .49438 .50573 L 1 .777 0 r
F
.52429 .50624 m .50005 .50298 L .49906 .50581 L F
.49961 .50424 m .49987 .50296 L .49906 .50581 L .987 .509 0 r
F
.50005 .50298 m .49431 .5022 L .49906 .50581 L 1 .777 0 r
F
.49929 .5058 m .49961 .50424 L .49906 .50581 L .987 .509 0 r
F
.52151 .50489 m .50005 .50298 L .49929 .5058 L F
.50005 .50298 m .49987 .50296 L .49929 .5058 L F
.50005 .50298 m .50024 .50225 L .49431 .5022 L 1 .777 0 r
F
.52148 .5084 m .52151 .50489 L .49929 .5058 L .983 .502 0 r
F
.49928 .50584 m .49929 .5058 L .49906 .50581 L F
.52148 .5084 m .49929 .5058 L .49928 .50584 L F
.49882 .50637 m .49906 .50581 L .49462 .506 L F
.49906 .50582 m .49906 .50581 L .49906 .50582 L 1 .779 0 r
F
.52445 .51006 m .49906 .50581 L .49906 .50582 L F
.52445 .51006 m .49898 .50581 L .49882 .50637 L F
.52148 .5084 m .49906 .50581 L .49882 .50637 L .983 .502 0 r
F
.49906 .50582 m .49906 .50581 L .49898 .50581 L 1 .779 0 r
F
.49793 .5098 m .49813 .50936 L .49769 .50935 L 1 .781 0 r
F
.49749 .50973 m .49769 .50935 L .49462 .50947 L .978 .494 0 r
F
.49767 .50939 m .49769 .50935 L .49764 .50935 L 1 .781 0 r
F
.49793 .5098 m .49769 .50935 L .49767 .50939 L F
.49751 .50973 m .49769 .50935 L .49749 .50973 L .978 .494 0 r
F
.49793 .5098 m .49764 .50935 L .49751 .50973 L 1 .781 0 r
F
.52463 .51388 m .49813 .50936 L .49793 .5098 L F
.52144 .51188 m .49769 .50935 L .49751 .50973 L .978 .494 0 r
F
.52144 .51188 m .52148 .5084 L .49769 .50935 L F
.49923 .50643 m .49882 .50637 L .49769 .50935 L 1 .779 0 r
F
.49776 .50917 m .49462 .506 L .49769 .50935 L .983 .502 0 r
F
.49882 .50637 m .49462 .506 L .49793 .50934 L F
.49882 .50637 m .49438 .50573 L .49769 .50935 L 1 .779 0 r
F
.49793 .50934 m .49776 .50917 L .49769 .50935 L .983 .502 0 r
F
.52148 .5084 m .49882 .50637 L .49793 .50934 L F
.49882 .50637 m .49898 .50581 L .49438 .50573 L 1 .779 0 r
F
.49751 .50973 m .49445 .50926 L .49623 .51286 L 1 .781 0 r
F
.49649 .51285 m .49694 .51112 L .49623 .51286 L .978 .494 0 r
F
.52144 .51188 m .49751 .50973 L .49649 .51285 L F
.49751 .50973 m .49731 .50971 L .49649 .51285 L F
.49751 .50973 m .49764 .50935 L .49445 .50926 L 1 .781 0 r
F
.5214 .51533 m .52144 .51188 L .49649 .51285 L .974 .487 0 r
F
.49647 .51288 m .49649 .51285 L .49623 .51286 L F
.5214 .51533 m .49649 .51285 L .49647 .51288 L F
.49613 .51306 m .49623 .51286 L .49461 .51292 L F
.49616 .51306 m .49623 .51286 L .49613 .51306 L 1 .782 0 r
F
.5248 .5177 m .49623 .51286 L .49616 .51306 L F
.5214 .51533 m .49623 .51286 L .49613 .51306 L .974 .487 0 r
F
.49613 .51306 m .49623 .51286 L .49452 .5128 L 1 .782 0 r
F
.49461 .51292 m .46828 .50925 L .46826 .51267 L 1 .587 0 r
F
.49466 .51634 m .49452 .5128 L .4946 .51634 L 1 .782 0 r
F
.5248 .5177 m .49613 .51306 L .49466 .51634 L F
.49466 .51634 m .49461 .51292 L .4946 .51634 L .974 .487 0 r
F
.49613 .51306 m .49461 .51292 L .49466 .51634 L F
.49613 .51306 m .49452 .5128 L .49466 .51634 L 1 .782 0 r
F
.5214 .51533 m .49613 .51306 L .49466 .51634 L .974 .487 0 r
F
.52134 .51874 m .5214 .51533 L .49466 .51634 L .97 .479 0 r
F
.49466 .51635 m .49466 .51634 L .4946 .51634 L F
.52499 .52153 m .49466 .51634 L .49466 .51635 L 1 .784 0 r
F
.52134 .51874 m .49466 .51634 L .49466 .51635 L .97 .479 0 r
F
.49466 .51635 m .49466 .51634 L .4946 .51634 L 1 .784 0 r
F
.52499 .52153 m .49466 .51635 L .49468 .51989 L F
.49466 .51635 m .49465 .51635 L .49465 .51637 L .97 .479 0 r
F
.49465 .51635 m .4946 .51634 L .4946 .51646 L F
.49466 .51635 m .4946 .51634 L .4946 .51646 L 1 .784 0 r
F
.49466 .51635 m .4946 .51646 L .49468 .51989 L F
.49466 .51635 m .49465 .51637 L .49465 .51638 L .97 .479 0 r
F
.52134 .51874 m .49466 .51635 L .49459 .51974 L F
.49466 .51635 m .49465 .51638 L .49459 .51974 L F
.49465 .51635 m .4946 .51646 L .49459 .51974 L F
.49459 .51974 m .4946 .51634 L .49452 .51634 L 1 .57 0 r
F
.4946 .51661 m .4946 .51646 L .49306 .51953 L 1 .835 0 r
F
.49453 .51661 m .49452 .51634 L .49303 .51952 L 1 .57 0 r
F
.4946 .51646 m .4946 .51634 L .49352 .51857 L 1 .835 0 r
F
.4946 .51646 m .49352 .51857 L .49306 .51953 L F
.49459 .51974 m .49453 .51661 L .49303 .51952 L 1 .57 0 r
F
.49305 .51952 m .49303 .51952 L .49297 .51972 L F
.49297 .51972 m .46842 .51401 L .46839 .51728 L 1 .835 0 r
F
.49343 .51977 m .49299 .51966 L .49297 .51972 L F
.49299 .51966 m .46842 .51401 L .49297 .51972 L F
.49468 .51989 m .49348 .51962 L .49343 .51977 L F
.49306 .51953 m .4946 .51634 L .46842 .51401 L F
.49457 .52311 m .49459 .51974 L .49296 .51972 L 1 .562 0 r
F
.49291 .51982 m .49296 .51972 L .49285 .51972 L F
.49476 .52346 m .49297 .51972 L .49283 .52006 L 1 .84 0 r
F
.49457 .52311 m .49296 .51972 L .49291 .51982 L 1 .562 0 r
F
.49135 .52266 m .49285 .51972 L .46821 .51944 L F
.49297 .51972 m .49286 .5197 L .49285 .51972 L 1 .57 0 r
F
.4928 .52001 m .49297 .51972 L .49262 .51969 L 1 .84 0 r
F
.49283 .52006 m .49297 .51972 L .4928 .52001 L F
.49291 .51983 m .49285 .51972 L .49135 .52266 L 1 .562 0 r
F
.4914 .52267 m .49262 .51969 L .49135 .52266 L 1 .84 0 r
F
.49476 .52346 m .49286 .52011 L .4914 .52267 L F
.49286 .52011 m .49262 .51969 L .4914 .52267 L F
.49476 .52346 m .49175 .52275 L .49161 .52311 L F
.49175 .52275 m .4914 .52267 L .49161 .52311 L F
.4914 .52267 m .46839 .51728 L .49122 .52302 L F
.4914 .52267 m .49122 .52302 L .49161 .52311 L F
.49485 .52705 m .49132 .52308 L .48969 .52578 L 1 .844 0 r
F
.49455 .52645 m .49457 .52311 L .4912 .52307 L 1 .553 0 r
F
.49119 .52308 m .4912 .52307 L .49118 .52307 L F
.48961 .52577 m .49113 .52307 L .46819 .52279 L F
.48927 .52638 m .46836 .52056 L .46833 .52386 L 1 .844 0 r
F
.48934 .52639 m .48928 .52637 L .48927 .52638 L F
.48928 .52637 m .46836 .52056 L .48927 .52638 L F
.48961 .52577 m .49118 .52307 L .49113 .52307 L 1 .553 0 r
F
.48969 .52578 m .49084 .52367 L .48994 .52522 L 1 .844 0 r
F
.48965 .52577 m .49077 .52379 L .48961 .52577 L 1 .553 0 r
F
.49077 .52379 m .49118 .52307 L .48961 .52577 L F
.48969 .52578 m .49082 .5239 L .49084 .52367 L 1 .844 0 r
F
.48994 .52522 m .49084 .52367 L .49089 .52303 L F
.49084 .52367 m .4912 .52307 L .49089 .52303 L F
.49082 .5239 m .4912 .52307 L .49084 .52367 L F
.49119 .52308 m .4912 .52307 L .49119 .52308 L 1 .553 0 r
F
.49455 .52645 m .4912 .52307 L .49119 .52308 L F
.49082 .5239 m .49132 .52308 L .4912 .52307 L 1 .844 0 r
F
.49455 .52645 m .49118 .52307 L .48965 .52577 L 1 .553 0 r
F
.49457 .52311 m .49291 .51983 L .49135 .52266 L 1 .562 0 r
F
.49115 .52306 m .46839 .51728 L .46836 .52056 L 1 .84 0 r
F
.49161 .52311 m .49118 .523 L .49115 .52306 L F
.49118 .523 m .46839 .51728 L .49115 .52306 L F
.49459 .51974 m .49305 .51952 L .49297 .51972 L 1 .57 0 r
F
.49135 .52266 m .49262 .51969 L .46839 .51728 L 1 .84 0 r
F
.49138 .52266 m .49135 .52266 L .4912 .52307 L 1 .562 0 r
F
.49457 .52311 m .49138 .52266 L .4912 .52307 L F
.49485 .52705 m .48969 .52578 L .48934 .52639 L 1 .844 0 r
F
.48969 .52578 m .46836 .52056 L .48934 .52639 L F
.49452 .52977 m .49455 .52645 L .48934 .52639 L 1 .544 0 r
F
.48933 .52639 m .48934 .52639 L .48932 .52639 L F
.48932 .52639 m .48932 .52639 L .48932 .52639 L F
.4878 .52884 m .48932 .52639 L .46817 .52612 L F
.48934 .52639 m .48932 .52638 L .48932 .52639 L 1 .553 0 r
F
.48927 .5265 m .48934 .52639 L .48908 .52635 L 1 .849 0 r
F
.48928 .5265 m .48934 .52639 L .48927 .5265 L F
.48933 .52639 m .48934 .52639 L .48933 .52639 L 1 .544 0 r
F
.49452 .52977 m .48934 .52639 L .48933 .52639 L F
.48964 .52577 m .48961 .52577 L .48934 .52639 L 1 .553 0 r
F
.48961 .52577 m .49089 .52303 L .46836 .52056 L 1 .844 0 r
F
.48969 .52578 m .49089 .52303 L .48961 .52577 L F
.49452 .52977 m .48932 .52639 L .48932 .52639 L 1 .544 0 r
F
.49494 .53066 m .48934 .52639 L .48928 .5265 L 1 .849 0 r
F
.49494 .53066 m .48937 .52657 L .4879 .52886 L F
.49494 .53066 m .4881 .52891 L .48771 .52972 L F
.4881 .52891 m .4879 .52886 L .48771 .52972 L F
.4879 .52886 m .46833 .52386 L .48741 .52963 L F
.4879 .52886 m .48741 .52963 L .48771 .52972 L F
.49504 .53431 m .49494 .53066 L .48738 .52968 L 1 .854 0 r
F
.49449 .53306 m .49452 .52977 L .48738 .52968 L 1 .535 0 r
F
.48738 .52968 m .48738 .52968 L .48737 .52968 L F
.4859 .53188 m .48737 .52968 L .46815 .52943 L F
.48602 .53191 m .48733 .52975 L .4859 .53188 L 1 .854 0 r
F
.49504 .53431 m .48745 .52982 L .48602 .53191 L F
.48745 .52982 m .48733 .52975 L .48602 .53191 L F
.49504 .53431 m .48738 .52968 L .48733 .52975 L F
.49515 .53799 m .49504 .53431 L .48529 .53294 L 1 .859 0 r
F
.48602 .53191 m .4859 .53188 L .48529 .53294 L 1 .854 0 r
F
.48592 .53188 m .4859 .53188 L .48529 .53294 L 1 .535 0 r
F
.4859 .53188 m .46815 .52943 L .48529 .53294 L F
.4859 .53188 m .4683 .52719 L .48529 .53294 L 1 .854 0 r
F
.48529 .53294 m .4683 .52719 L .46827 .53055 L F
.49504 .53431 m .48602 .53191 L .48529 .53294 L F
.49515 .53799 m .4854 .53306 L .48403 .53491 L 1 .859 0 r
F
.49515 .53799 m .48529 .53294 L .48526 .53299 L F
.49526 .54172 m .49515 .53799 L .48305 .53617 L 1 .864 0 r
F
.4839 .53488 m .48529 .53294 L .46813 .53272 L 1 .526 0 r
F
.48388 .53487 m .46813 .53272 L .48305 .53617 L F
.48305 .53617 m .46827 .53055 L .46823 .53395 L 1 .859 0 r
F
.49515 .53799 m .48403 .53491 L .48305 .53617 L F
.48403 .53491 m .4839 .53488 L .48305 .53617 L F
.4831 .53618 m .48373 .53513 L .48305 .53617 L 1 .526 0 r
F
.48373 .53513 m .48388 .53487 L .48305 .53617 L F
.4839 .53488 m .46827 .53055 L .48305 .53617 L 1 .859 0 r
F
.49526 .54172 m .48305 .53617 L .48302 .53621 L 1 .864 0 r
F
.48175 .53784 m .48305 .53617 L .46811 .53598 L 1 .517 0 r
F
.49526 .54172 m .48318 .53628 L .48192 .53788 L 1 .864 0 r
F
.49538 .54549 m .49526 .54172 L .48061 .53938 L 1 .868 0 r
F
.48171 .53783 m .46811 .53598 L .48061 .53938 L 1 .517 0 r
F
.48061 .53938 m .46823 .53395 L .46819 .5374 L 1 .864 0 r
F
.49526 .54172 m .48192 .53788 L .48061 .53938 L F
.48192 .53788 m .48176 .53784 L .48061 .53938 L F
.48073 .53939 m .48136 .53837 L .48061 .53938 L 1 .517 0 r
F
.48136 .53837 m .48171 .53783 L .48061 .53938 L F
.48176 .53784 m .46823 .53395 L .48061 .53938 L 1 .864 0 r
F
.49538 .54549 m .48061 .53938 L .4806 .53941 L 1 .868 0 r
F
.47942 .54075 m .48061 .53938 L .46809 .53922 L 1 .508 0 r
F
.49538 .54549 m .48059 .53941 L .47947 .54076 L 1 .868 0 r
F
.47947 .54076 m .48061 .53938 L .47942 .54075 L 1 .508 0 r
F
.48059 .53941 m .48049 .53936 L .47947 .54076 L 1 .868 0 r
F
.47963 .54078 m .48061 .53938 L .47947 .54076 L 1 .508 0 r
F
.47963 .54078 m .48073 .53939 L .48061 .53938 L F
.49438 .54278 m .49442 .53956 L .48073 .53939 L F
.49438 .54278 m .48073 .53939 L .47963 .54078 L F
.48192 .53788 m .48302 .53621 L .48176 .53784 L 1 .864 0 r
F
.48318 .53628 m .48302 .53621 L .48192 .53788 L F
.48176 .53784 m .48305 .53617 L .48175 .53784 L 1 .517 0 r
F
.48302 .53621 m .48289 .53615 L .48176 .53784 L 1 .864 0 r
F
.48186 .53785 m .48305 .53617 L .48176 .53784 L 1 .517 0 r
F
.48186 .53785 m .4831 .53618 L .48305 .53617 L F
.49442 .53956 m .49446 .53632 L .4831 .53618 L F
.49442 .53956 m .4831 .53618 L .48186 .53785 L F
.48403 .53491 m .48525 .53299 L .4839 .53488 L 1 .859 0 r
F
.4854 .53306 m .48525 .53299 L .48403 .53491 L F
.48525 .53299 m .4851 .53291 L .4839 .53488 L F
.48392 .53488 m .48529 .53294 L .4839 .53488 L 1 .526 0 r
F
.48396 .53489 m .4853 .53294 L .48529 .53294 L F
.48396 .53489 m .48529 .53294 L .48392 .53488 L F
.49446 .53632 m .49449 .53306 L .4853 .53294 L F
.49446 .53632 m .4853 .53294 L .48396 .53489 L F
.48595 .53188 m .48719 .52995 L .4859 .53188 L 1 .535 0 r
F
.48719 .52995 m .48737 .52968 L .4859 .53188 L F
.48733 .52975 m .48715 .52965 L .4859 .53188 L 1 .854 0 r
F
.48733 .52975 m .48738 .52968 L .48715 .52965 L F
.48733 .52975 m .48738 .52968 L .48733 .52975 L F
.49449 .53306 m .48738 .52968 L .48738 .52968 L 1 .535 0 r
F
.49449 .53306 m .48737 .52968 L .48595 .53188 L F
.4879 .52886 m .48927 .5265 L .4878 .52884 L 1 .849 0 r
F
.48937 .52657 m .48927 .5265 L .4879 .52886 L F
.48933 .5264 m .48932 .52639 L .4878 .52884 L 1 .544 0 r
F
.48927 .5265 m .48908 .52635 L .4878 .52884 L 1 .849 0 r
F
.49452 .52977 m .48933 .5264 L .4878 .52884 L 1 .544 0 r
F
.48729 .52966 m .46833 .52386 L .4683 .52719 L 1 .849 0 r
F
.48771 .52972 m .48733 .5296 L .48729 .52966 L F
.48733 .5296 m .46833 .52386 L .48729 .52966 L F
.49455 .52645 m .48964 .52577 L .48934 .52639 L 1 .553 0 r
F
.4878 .52884 m .48908 .52635 L .46833 .52386 L 1 .849 0 r
F
.48783 .52884 m .4878 .52884 L .48738 .52968 L 1 .544 0 r
F
.49452 .52977 m .48783 .52884 L .48738 .52968 L F
.4859 .53188 m .48715 .52965 L .4683 .52719 L 1 .854 0 r
F
.49449 .53306 m .48592 .53188 L .48559 .53243 L 1 .535 0 r
F
.4853 .53294 m .48559 .53243 L .48529 .53294 L F
.49449 .53306 m .48559 .53243 L .4853 .53294 L F
.48526 .53299 m .48529 .53294 L .4851 .53291 L 1 .859 0 r
F
.4839 .53488 m .4851 .53291 L .46827 .53055 L F
.49446 .53632 m .4839 .53488 L .4831 .53618 L 1 .526 0 r
F
.4839 .53488 m .48388 .53487 L .4831 .53618 L F
.48302 .53621 m .48305 .53617 L .48289 .53615 L 1 .864 0 r
F
.48176 .53784 m .48289 .53615 L .46823 .53395 L F
.49442 .53956 m .48176 .53784 L .48073 .53939 L 1 .517 0 r
F
.48176 .53784 m .48171 .53783 L .48073 .53939 L F
.4806 .53941 m .48061 .53938 L .48049 .53936 L 1 .868 0 r
F
.47947 .54076 m .48049 .53936 L .46819 .5374 L F
.47935 .54074 m .46809 .53922 L .47795 .54257 L 1 .508 0 r
F
.47795 .54257 m .46819 .5374 L .46815 .54092 L 1 .868 0 r
F
.49538 .54549 m .47965 .54081 L .47795 .54257 L F
.47719 .5437 m .47819 .54261 L .47795 .54257 L 1 .871 0 r
F
.4955 .54933 m .47819 .54261 L .47719 .5437 L F
.49433 .54596 m .49438 .54278 L .47795 .54257 L 1 .498 0 r
F
.47692 .54363 m .47795 .54257 L .46807 .54244 L F
.47765 .5429 m .47795 .54257 L .47785 .54255 L 1 .871 0 r
F
.47753 .54311 m .47795 .54257 L .47765 .5429 L F
.47699 .54364 m .47795 .54257 L .47692 .54363 L 1 .498 0 r
F
.47719 .5437 m .47795 .54257 L .47753 .54311 L 1 .871 0 r
F
.47719 .5437 m .47785 .54255 L .47699 .54364 L F
.49433 .54596 m .47795 .54257 L .47699 .54364 L 1 .498 0 r
F
.47965 .54081 m .47947 .54076 L .47795 .54257 L 1 .868 0 r
F
.47887 .54147 m .47935 .54074 L .47795 .54257 L 1 .508 0 r
F
.47947 .54076 m .46819 .5374 L .47795 .54257 L 1 .868 0 r
F
.47816 .54257 m .47887 .54147 L .47795 .54257 L 1 .508 0 r
F
.49438 .54278 m .47947 .54076 L .47816 .54257 L F
.47947 .54076 m .47935 .54074 L .47816 .54257 L F
.47499 .54572 m .46815 .54092 L .46811 .54451 L 1 .871 0 r
F
.4955 .54933 m .47699 .54364 L .47499 .54572 L F
.47616 .5445 m .47676 .54361 L .47499 .54572 L 1 .498 0 r
F
.47699 .54364 m .46815 .54092 L .47499 .54572 L 1 .871 0 r
F
.47534 .54573 m .47616 .5445 L .47499 .54572 L 1 .498 0 r
F
.49433 .54596 m .47699 .54364 L .47534 .54573 L F
.47699 .54364 m .47676 .54361 L .47534 .54573 L F
.47699 .54364 m .47785 .54255 L .46815 .54092 L 1 .871 0 r
F
.49427 .54912 m .49433 .54596 L .47534 .54573 L 1 .489 0 r
F
.4753 .54578 m .47534 .54573 L .47499 .54572 L F
.49427 .54912 m .47534 .54573 L .4753 .54578 L F
.47435 .54649 m .47467 .54605 L .47428 .54646 L 1 .874 0 r
F
.49564 .55322 m .47499 .54573 L .47435 .54649 L F
.47499 .54573 m .47493 .54571 L .47435 .54649 L F
.49427 .54912 m .47499 .54572 L .47428 .54646 L 1 .489 0 r
F
.47467 .54605 m .47493 .54571 L .47428 .54646 L 1 .874 0 r
F
.47463 .54651 m .47428 .54646 L .47327 .54763 L 1 .489 0 r
F
.47428 .54646 m .46805 .54564 L .47327 .54763 L F
.47428 .54646 m .47493 .54571 L .46811 .54451 L 1 .874 0 r
F
.47168 .54885 m .46811 .54451 L .46807 .54819 L F
.47174 .5488 m .47173 .5488 L .47168 .54885 L 1 .489 0 r
F
.47428 .54646 m .46811 .54451 L .47168 .54885 L 1 .874 0 r
F
.4718 .54885 m .47174 .5488 L .47168 .54885 L 1 .489 0 r
F
.49422 .55226 m .49427 .54912 L .47168 .54885 L 1 .479 0 r
F
.47128 .54923 m .47168 .54885 L .46804 .54881 L F
.47132 .54925 m .47168 .54885 L .47128 .54923 L 1 .876 0 r
F
.49578 .55718 m .47168 .54885 L .47132 .54925 L F
.49422 .55226 m .47168 .54885 L .47128 .54923 L 1 .479 0 r
F
.47128 .54923 m .47168 .54885 L .46807 .54819 L 1 .876 0 r
F
.49427 .54912 m .47463 .54651 L .4718 .54885 L 1 .489 0 r
F
.49578 .55718 m .47132 .54925 L .46802 .55197 L 1 .876 0 r
F
.47132 .54925 m .47128 .54923 L .46802 .55197 L F
.47128 .54923 m .46802 .55188 L .46802 .55197 L F
.47132 .54925 m .46802 .55197 L .46802 .55197 L F
.49422 .55226 m .47128 .54923 L .46802 .55195 L 1 .479 0 r
F
.47128 .54923 m .46804 .54881 L .46802 .55188 L F
.47128 .54923 m .46802 .55188 L .46802 .55195 L F
.47128 .54923 m .46807 .54819 L .46802 .55188 L 1 .876 0 r
F
.46804 .54881 m .44236 .54407 L .44235 .54725 L 1 .569 0 r
F
.46797 .55586 m .46802 .55197 L .46794 .55195 L 1 .97 0 r
F
.46801 .55508 m .46802 .55195 L .46794 .55195 L 1 .549 0 r
F
.46786 .56404 m .46792 .55988 L .45978 .55774 L 1 .972 0 r
F
.46411 .55485 m .44235 .55041 L .44235 .55355 L 1 .549 0 r
F
.46792 .55988 m .46797 .55586 L .46419 .55485 L 1 .973 0 r
F
.46415 .55488 m .46419 .55485 L .46411 .55485 L 1 .539 0 r
F
.46418 .55486 m .46419 .55485 L .46416 .55484 L 1 .973 0 r
F
.46418 .55486 m .46419 .55485 L .46418 .55486 L F
.46797 .55586 m .46794 .55204 L .46503 .55459 L 1 .97 0 r
F
.46794 .55204 m .46794 .55195 L .46714 .55268 L F
.46794 .55204 m .46714 .55268 L .46503 .55459 L F
.49609 .56533 m .46797 .55586 L .46792 .55988 L 1 .877 0 r
F
.49609 .56533 m .49593 .56122 L .46797 .55586 L F
.49593 .56122 m .46802 .55197 L .46797 .55586 L F
.46468 .55447 m .44235 .55041 L .46419 .55485 L 1 .549 0 r
F
.46468 .55447 m .46794 .55195 L .44235 .55041 L F
.46795 .55194 m .46804 .54881 L .44235 .54725 L 1 .559 0 r
F
.46795 .55194 m .44235 .54725 L .46794 .55195 L F
.46419 .55485 m .44434 .54563 L .44399 .54943 L 1 .97 0 r
F
.46797 .55586 m .46482 .5545 L .46419 .55485 L F
.46482 .5545 m .46468 .55447 L .46419 .55485 L 1 .549 0 r
F
.46482 .5545 m .46608 .55347 L .46468 .55447 L F
.46608 .55347 m .46794 .55195 L .46468 .55447 L F
.46482 .5545 m .44434 .54563 L .46419 .55485 L 1 .97 0 r
F
.46503 .55459 m .46794 .55195 L .46793 .55196 L F
.46503 .55459 m .46794 .55195 L .46486 .55452 L F
.46801 .55508 m .46482 .5545 L .46419 .55485 L 1 .549 0 r
F
.468 .55818 m .46801 .55508 L .46441 .55486 L 1 .539 0 r
F
.4643 .55495 m .46441 .55486 L .46419 .55485 L F
.468 .55818 m .46441 .55486 L .4643 .55495 L F
.46792 .55988 m .46419 .55485 L .46418 .55486 L 1 .973 0 r
F
.468 .55818 m .46419 .55485 L .46415 .55488 L 1 .539 0 r
F
.46077 .55687 m .46411 .55485 L .44235 .55355 L F
.46121 .55695 m .46411 .55485 L .46077 .55687 L F
.46415 .55488 m .46411 .55485 L .46121 .55695 L F
.46419 .55485 m .46412 .55484 L .46411 .55485 L 1 .549 0 r
F
.46412 .55484 m .44235 .55041 L .46411 .55485 L F
.46121 .55695 m .46416 .55484 L .44399 .54943 L 1 .973 0 r
F
.46122 .55696 m .46193 .55644 L .46121 .55695 L F
.46193 .55644 m .46416 .55484 L .46121 .55695 L F
.46127 .55698 m .46416 .55484 L .46122 .55696 L F
.46792 .55988 m .46423 .55493 L .46127 .55698 L F
.46423 .55493 m .46416 .55484 L .46127 .55698 L F
.49626 .56954 m .46792 .55988 L .46786 .56404 L 1 .876 0 r
F
.49626 .56954 m .49609 .56533 L .46792 .55988 L F
.46792 .55988 m .46127 .55698 L .45954 .55768 L 1 .973 0 r
F
.45954 .55768 m .44235 .55355 L .44236 .55666 L 1 .539 0 r
F
.46127 .55698 m .46121 .55695 L .45954 .55768 L 1 .973 0 r
F
.468 .55818 m .46121 .55695 L .45954 .55768 L 1 .539 0 r
F
.46121 .55695 m .44235 .55355 L .45954 .55768 L F
.46121 .55695 m .44399 .54943 L .45954 .55768 L 1 .973 0 r
F
.45954 .55768 m .44399 .54943 L .44358 .55348 L F
.46786 .56404 m .45978 .55774 L .45725 .55942 L 1 .972 0 r
F
.45774 .55942 m .4602 .55772 L .45954 .55768 L 1 .528 0 r
F
.456 .5591 m .45954 .55768 L .44236 .55666 L F
.45725 .55942 m .45978 .55774 L .45954 .55768 L 1 .972 0 r
F
.45688 .55926 m .45954 .55768 L .456 .5591 L 1 .528 0 r
F
.45917 .55789 m .45954 .55768 L .45947 .55766 L 1 .972 0 r
F
.45725 .55942 m .45954 .55768 L .45917 .55789 L F
.45725 .55942 m .45947 .55766 L .45781 .55867 L F
.45688 .55926 m .45781 .55867 L .45685 .55925 L F
.45725 .55942 m .45781 .55867 L .45688 .55926 L F
.4678 .56834 m .46786 .56404 L .45368 .56046 L 1 .967 0 r
F
.4678 .56834 m .45368 .56046 L .45361 .56049 L F
.4678 .56834 m .45346 .5604 L .45158 .56141 L F
.49643 .57383 m .46786 .56404 L .4678 .56834 L 1 .873 0 r
F
.45346 .5604 m .44236 .55666 L .44238 .55976 L 1 .528 0 r
F
.49643 .57383 m .49626 .56954 L .46786 .56404 L 1 .873 0 r
F
.4539 .56017 m .44236 .55666 L .45346 .5604 L 1 .528 0 r
F
.46786 .56404 m .45698 .55931 L .45346 .5604 L 1 .972 0 r
F
.45688 .55926 m .44236 .55666 L .45404 .56021 L 1 .528 0 r
F
.45698 .55931 m .45688 .55926 L .45346 .5604 L 1 .972 0 r
F
.45688 .55926 m .45404 .56021 L .45497 .56049 L 1 .528 0 r
F
.45688 .55926 m .44358 .55348 L .45346 .5604 L 1 .972 0 r
F
.45346 .5604 m .44358 .55348 L .4431 .55779 L F
.45361 .56049 m .45368 .56046 L .45346 .5604 L 1 .967 0 r
F
.45149 .56137 m .45517 .5605 L .45346 .5604 L 1 .518 0 r
F
.45075 .56124 m .45346 .5604 L .44238 .55976 L F
.45149 .56137 m .45346 .5604 L .45075 .56124 L F
.46797 .5643 m .46798 .56125 L .45517 .5605 L F
.45158 .56141 m .45346 .5604 L .45337 .56038 L 1 .967 0 r
F
.45149 .56137 m .45337 .56038 L .4431 .55779 L F
.45158 .56141 m .45337 .56038 L .45149 .56137 L F
.45165 .56144 m .45149 .56137 L .44512 .56298 L F
.4678 .56834 m .45165 .56144 L .44512 .56298 L F
.46774 .5728 m .44458 .56322 L .44197 .56726 L 1 .959 0 r
F
.44434 .56317 m .44512 .56298 L .4424 .56283 L 1 .507 0 r
F
.44437 .56355 m .44241 .56362 L .44197 .56726 L 1 .959 0 r
F
.44458 .56322 m .4425 .5636 L .44437 .56355 L F
.4425 .5636 m .44241 .56362 L .44437 .56355 L F
.42714 .55051 m .41761 .54893 L .36651 .61756 L 0 0 0 r
F
.43981 .56255 m .41735 .55751 L .41504 .56409 L 1 .88 0 r
F
.44512 .56298 m .44238 .55976 L .4424 .56283 L 1 .518 0 r
F
.44566 .56302 m .44547 .56283 L .44512 .56298 L F
.44547 .56283 m .44238 .55976 L .44512 .56298 L F
.46774 .5728 m .4678 .56834 L .44512 .56298 L 1 .959 0 r
F
.44458 .56322 m .44512 .56298 L .44256 .56238 L F
.46774 .5728 m .44512 .56298 L .44458 .56322 L F
.44197 .56726 m .44241 .56362 L .41504 .56409 L .956 .835 0 r
F
.4424 .56283 m .44238 .55976 L .42991 .55842 L 1 .59 0 r
F
.4424 .56283 m .42991 .55842 L .43778 .56169 L F
.4424 .56283 m .42661 .55895 L .42988 .55993 L F
.42988 .55993 m .42194 .55756 L .41735 .55751 L 1 .88 0 r
F
.44235 .55355 m .41762 .54771 L .41761 .54893 L 1 .621 0 r
F
.43269 .5525 m .41761 .54893 L .41761 .55086 L F
.44235 .55355 m .41761 .54893 L .43269 .5525 L F
.36532 .61912 m .36542 .6128 L .34469 .61033 L 1 .676 0 r
F
.34431 .61295 m .34469 .61033 L .32908 .60847 L F
.36532 .61912 m .34469 .61033 L .34431 .61295 L F
.34375 .61657 m .31499 .60892 L .31493 .6153 L .57 .814 0 r
F
.34376 .61656 m .31499 .60892 L .34375 .61657 L F
.36532 .61912 m .34418 .61382 L .34375 .61657 L 1 .676 0 r
F
.34418 .61382 m .31499 .60892 L .34378 .61657 L .57 .814 0 r
F
.34418 .61382 m .31797 .60718 L .31499 .60892 L F
.33415 .61126 m .32908 .60847 L .3177 .60712 L 1 .676 0 r
F
.36532 .61912 m .3177 .60712 L .34418 .61382 L F
.41761 .54893 m .40815 .54669 L .31499 .60892 L .57 .814 0 r
F
.34375 .61657 m .31726 .60706 L .31712 .61341 L 1 .676 0 r
F
.34418 .61382 m .31726 .60706 L .34375 .61657 L F
.34378 .61657 m .34376 .61656 L .34375 .61657 L .57 .814 0 r
F
.36532 .61912 m .32908 .60847 L .33415 .61126 L 1 .676 0 r
F
.36651 .61756 m .34418 .61382 L .34378 .61657 L .57 .814 0 r
F
.41468 .62906 m .36532 .61912 L .36525 .62541 L 1 .62 0 r
F
.35586 .6243 m .31493 .6153 L .31489 .62166 L 1 .784 0 r
F
.35586 .6243 m .31493 .6153 L .35586 .6243 L F
.35608 .62312 m .31493 .6153 L .35588 .62431 L F
.35549 .62301 m .34453 .61698 L .31493 .6153 L F
.34453 .61698 m .34375 .61657 L .31493 .6153 L F
.35586 .6243 m .31712 .61341 L .31703 .61974 L 1 .667 0 r
F
.36525 .62541 m .35608 .62312 L .35586 .6243 L F
.36525 .62541 m .36532 .61912 L .35695 .61813 L F
.35632 .62174 m .35695 .61813 L .34375 .61657 L F
.36525 .62541 m .35695 .61813 L .35632 .62174 L F
.36525 .62541 m .34842 .61848 L .35608 .62312 L F
.34842 .61848 m .34375 .61657 L .35068 .62025 L F
.34842 .61848 m .35068 .62025 L .35608 .62312 L F
.36516 .63172 m .36518 .63156 L .31489 .62166 L 1 .711 0 r
F
.41464 .6353 m .41468 .62906 L .36525 .62541 L 1 .611 0 r
F
.41464 .6353 m .36525 .62541 L .36522 .62967 L F
.41464 .6353 m .36522 .62967 L .37135 .63161 L F
.37349 .63228 m .36521 .63108 L .3652 .63113 L 1 .656 0 r
F
.37349 .63228 m .3652 .63113 L .36516 .63172 L F
.3826 .63515 m .37349 .63228 L .36516 .63172 L 1 .639 0 r
F
.39004 .63661 m .37349 .63228 L .3826 .63515 L F
.41461 .6415 m .41463 .63799 L .39693 .63572 L 1 .602 0 r
F
.4052 .63942 m .39693 .63572 L .37685 .63316 L F
.41461 .6415 m .39693 .63572 L .4052 .63942 L F
.41455 .64783 m .41461 .64363 L .36491 .63831 L 1 .625 0 r
F
.41461 .6415 m .37685 .63316 L .39004 .63661 L 1 .602 0 r
F
.46464 .64972 m .42002 .64234 L .41455 .64783 L 1 .571 0 r
F
.42002 .64234 m .41587 .6417 L .41559 .64302 L 1 .544 0 r
F
.41587 .6417 m .41461 .6415 L .41461 .64317 L F
.41652 .64585 m .41461 .64317 L .41455 .64783 L 1 .571 0 r
F
.42002 .64234 m .41461 .64317 L .41652 .64585 L F
.41461 .64317 m .41461 .6415 L .41336 .64141 L 1 .594 0 r
F
.41461 .64317 m .41336 .64141 L .40887 .64109 L F
.41461 .6415 m .40603 .6398 L .40887 .64109 L 1 .602 0 r
F
.40887 .64109 m .36516 .63172 L .36491 .63831 L 1 .639 0 r
F
.40603 .6398 m .39004 .63661 L .40887 .64109 L 1 .602 0 r
F
.41463 .64145 m .39004 .63661 L .40887 .64109 L 1 .639 0 r
F
.39004 .63661 m .36516 .63172 L .40887 .64109 L F
.39004 .63661 m .3652 .63167 L .40887 .64109 L 1 .602 0 r
F
.40887 .64109 m .3652 .63167 L .36518 .6379 L F
.41461 .64363 m .40892 .64109 L .40887 .64109 L 1 .625 0 r
F
.41443 .64361 m .40887 .64109 L .36491 .63831 L F
.41461 .64363 m .40887 .64109 L .41443 .64361 L F
.40912 .64118 m .41463 .64145 L .40892 .64109 L F
.41433 .64351 m .41439 .64309 L .40912 .64118 L F
.41439 .64309 m .41463 .64145 L .40912 .64118 L F
.41461 .64317 m .41463 .64145 L .41433 .64351 L F
.41461 .64317 m .40887 .64109 L .36518 .6379 L 1 .594 0 r
F
.41461 .64363 m .41461 .64317 L .41433 .64351 L 1 .625 0 r
F
.41461 .64768 m .41461 .64317 L .36518 .6379 L 1 .594 0 r
F
.41587 .6417 m .41461 .64317 L .41461 .64768 L 1 .544 0 r
F
.42002 .64234 m .41463 .64145 L .41461 .64317 L 1 .571 0 r
F
.46466 .64925 m .42002 .64234 L .41461 .64768 L 1 .544 0 r
F
.42002 .64234 m .41559 .64302 L .41461 .64768 L F
.41463 .63799 m .37349 .63228 L .3652 .63167 L 1 .602 0 r
F
.41463 .64145 m .37349 .63228 L .39004 .63661 L 1 .639 0 r
F
.39004 .63661 m .37685 .63316 L .3652 .63167 L 1 .602 0 r
F
.41463 .63799 m .41464 .6353 L .37349 .63228 L F
.37349 .63228 m .36521 .63108 L .3652 .63167 L 1 .611 0 r
F
.37646 .6325 m .36521 .63108 L .37349 .63228 L F
.37135 .63161 m .36522 .62967 L .36521 .63108 L F
.41474 .63503 m .3656 .62493 L .36521 .63108 L 1 .656 0 r
F
.41464 .6353 m .36521 .63108 L .37646 .6325 L 1 .611 0 r
F
.41474 .63503 m .36521 .63108 L .37349 .63228 L 1 .656 0 r
F
.41463 .64145 m .41474 .63503 L .37349 .63228 L 1 .639 0 r
F
.36443 .63098 m .36451 .63058 L .35608 .62447 L 1 .711 0 r
F
.36518 .63156 m .36521 .63108 L .36443 .63098 L F
.36521 .63108 m .36525 .62541 L .35586 .6243 L 1 .659 0 r
F
.36521 .63108 m .3656 .62493 L .36443 .63098 L 1 .711 0 r
F
.36518 .63156 m .35588 .62431 L .31489 .62166 L F
.3652 .63167 m .36521 .63108 L .31703 .61974 L 1 .659 0 r
F
.36521 .63108 m .35586 .6243 L .31703 .61974 L F
.35608 .62447 m .3656 .62493 L .35588 .62431 L 1 .711 0 r
F
.36451 .63058 m .3656 .62493 L .35608 .62447 L F
.3656 .62493 m .34378 .61657 L .35549 .62301 L 1 .784 0 r
F
.35608 .62312 m .31712 .61341 L .35586 .6243 L 1 .667 0 r
F
.35588 .62431 m .35586 .6243 L .35586 .6243 L 1 .784 0 r
F
.3656 .62493 m .35608 .62312 L .35588 .62431 L F
.35608 .62312 m .34375 .61657 L .31712 .61341 L 1 .667 0 r
F
.34453 .61698 m .34378 .61657 L .34375 .61657 L 1 .784 0 r
F
.3656 .62493 m .36651 .61756 L .34378 .61657 L F
.34418 .61382 m .3177 .60712 L .31726 .60706 L 1 .676 0 r
F
.36651 .61756 m .41761 .54893 L .31797 .60718 L .57 .814 0 r
F
.36651 .61756 m .31797 .60718 L .34418 .61382 L F
.41763 .5463 m .41008 .54396 L .41003 .54451 L 1 .698 0 r
F
.41763 .5463 m .40992 .5433 L .40933 .54373 L F
.37035 .55903 m .37039 .55293 L .32625 .54631 L 1 .697 0 r
F
.37035 .55903 m .32625 .54631 L .32641 .55226 L F
.41764 .54454 m .41767 .54136 L .41054 .54021 L 1 .708 0 r
F
.41077 .53706 m .32894 .57438 L .3302 .57929 L .211 .02 0 r
F
.41077 .53706 m .32894 .57438 L .41077 .53706 L F
.41088 .53611 m .32894 .57438 L .41081 .53704 L F
.41041 .54019 m .41045 .53925 L .41037 .54021 L .201 .015 0 r
F
.41045 .53925 m .3302 .57929 L .41037 .54021 L F
.37051 .54675 m .37069 .54051 L .32632 .53413 L 1 .734 0 r
F
.37051 .54675 m .32632 .53413 L .32623 .54026 L F
.37039 .55293 m .37051 .54675 L .32623 .54026 L 1 .718 0 r
F
.37039 .55293 m .32623 .54026 L .32625 .54631 L F
.44253 .52787 m .41817 .52191 L .41806 .52519 L 1 .699 0 r
F
.44248 .53115 m .44253 .52787 L .41806 .52519 L 1 .689 0 r
F
.44248 .53115 m .41806 .52519 L .41795 .52845 L F
.44244 .53441 m .44248 .53115 L .41795 .52845 L 1 .68 0 r
F
.41806 .52519 m .41817 .52191 L .39525 .51823 L 1 .766 0 r
F
.41806 .52519 m .39525 .51823 L .39504 .52149 L F
.41795 .52845 m .41806 .52519 L .39504 .52149 L 1 .757 0 r
F
.41795 .52845 m .39504 .52149 L .39486 .52473 L F
.41786 .5317 m .41795 .52845 L .41196 .52749 L 1 .747 0 r
F
.41167 .52983 m .41196 .52749 L .39486 .52473 L F
.41786 .5317 m .41196 .52749 L .41167 .52983 L F
.41786 .5317 m .39486 .52473 L .3947 .52796 L F
.41778 .53494 m .41786 .5317 L .41174 .53071 L 1 .738 0 r
F
.41778 .53494 m .41174 .53071 L .41173 .53081 L F
.41778 .53494 m .41155 .53068 L .41127 .53297 L F
.41115 .53387 m .3947 .52796 L .39466 .52885 L F
.41127 .53297 m .3947 .52796 L .41115 .53387 L F
.41127 .53297 m .41155 .53068 L .3947 .52796 L F
.42612 .52649 m .40614 .5209 L .39466 .52885 L 1 .517 0 r
F
.41004 .53442 m .39461 .52888 L .32894 .57438 L F
.41115 .53387 m .39538 .52912 L .41004 .53442 L F
.39538 .52912 m .39461 .52888 L .41004 .53442 L F
.41115 .53387 m .39466 .52885 L .39461 .52888 L F
.31854 .57499 m .31892 .56852 L .28442 .56253 L 1 .771 0 r
F
.28442 .56253 m .26971 .55549 L .2692 .56211 L .962 .392 0 r
F
.28278 .56882 m .2692 .56211 L .26875 .56872 L .933 .324 0 r
F
.28277 .569 m .28278 .56882 L .2815 .5686 L 1 .764 0 r
F
.31827 .58015 m .28278 .56882 L .26875 .56872 L .726 .923 0 r
F
.31827 .58015 m .28278 .56882 L .28277 .569 L 1 .764 0 r
F
.28278 .56881 m .2692 .56211 L .28278 .56882 L .933 .324 0 r
F
.31854 .57499 m .28326 .5638 L .28278 .56882 L 1 .771 0 r
F
.28326 .5638 m .2692 .56211 L .28281 .56882 L .933 .324 0 r
F
.31892 .56852 m .31934 .56203 L .28982 .55688 L 1 .779 0 r
F
.28475 .55764 m .26971 .55549 L .28442 .56253 L .962 .392 0 r
F
.28611 .55623 m .27027 .54885 L .26971 .55549 L .985 .447 0 r
F
.28783 .54991 m .27089 .5422 L .27027 .54885 L 1 .491 0 r
F
.28957 .54359 m .27156 .53553 L .27089 .5422 L 1 .529 0 r
F
.32141 .53594 m .27709 .52132 L .27629 .52788 L 1 .815 0 r
F
.32083 .54248 m .32141 .53594 L .29523 .53127 L 1 .808 0 r
F
.29372 .5336 m .29523 .53127 L .27629 .52788 L F
.32083 .54248 m .29523 .53127 L .29372 .5336 L F
.32046 .54694 m .32083 .54248 L .29133 .53724 L 1 .801 0 r
F
.29133 .53724 m .29045 .5367 L .27581 .53205 L 1 .808 0 r
F
.29045 .5367 m .27629 .52788 L .27581 .53205 L F
.27156 .53553 m .27581 .53205 L .22826 .51862 L .739 .934 0 r
F
.29372 .5336 m .27629 .52788 L .29133 .53724 L 1 .808 0 r
F
.27629 .52788 m .27709 .52132 L .25171 .51529 L 1 .863 0 r
F
.25171 .51529 m .23026 .50519 L .22922 .51191 L 1 .662 0 r
F
.32202 .52939 m .27794 .51475 L .27709 .52132 L 1 .822 0 r
F
.32141 .53594 m .32202 .52939 L .27709 .52132 L 1 .815 0 r
F
.27709 .52132 m .27794 .51475 L .25452 .50916 L 1 .87 0 r
F
.25223 .51135 m .23026 .50519 L .25171 .51529 L 1 .662 0 r
F
.25342 .5089 m .23135 .49846 L .23026 .50519 L 1 .676 0 r
F
.32268 .52283 m .27885 .50818 L .27794 .51475 L 1 .829 0 r
F
.25518 .5025 m .23251 .49174 L .23135 .49846 L 1 .69 0 r
F
.32337 .51627 m .2798 .50161 L .27885 .50818 L 1 .836 0 r
F
.25697 .49609 m .23374 .48501 L .23251 .49174 L 1 .702 0 r
F
.3241 .50969 m .28081 .49503 L .2798 .50161 L 1 .842 0 r
F
.32487 .50312 m .28186 .48846 L .28081 .49503 L 1 .849 0 r
F
.28186 .48846 m .2418 .47177 L .24043 .47834 L 1 .904 0 r
F
.28081 .49503 m .28186 .48846 L .2615 .48349 L 1 .897 0 r
F
.26021 .48651 m .2615 .48349 L .24043 .47834 L F
.28081 .49503 m .2615 .48349 L .26021 .48651 L F
.2798 .50161 m .28025 .49866 L .25961 .4901 L 1 .891 0 r
F
.2798 .50161 m .25961 .4901 L .25956 .4902 L F
.2798 .50161 m .25878 .48976 L .25876 .48982 L F
.25763 .49252 m .25853 .49042 L .23374 .48501 L 1 .702 0 r
F
.25853 .49042 m .25881 .48969 L .23374 .48501 L F
.2798 .50161 m .25876 .48982 L .25773 .49254 L 1 .891 0 r
F
.25773 .49254 m .25853 .49042 L .25763 .49252 L 1 .702 0 r
F
.25321 .48864 m .23973 .48171 L .23374 .48501 L 1 .861 0 r
F
.25881 .48969 m .24017 .48189 L .25321 .48864 L F
.24017 .48189 m .23973 .48171 L .25321 .48864 L F
.28081 .49503 m .24043 .47834 L .23977 .48168 L 1 .897 0 r
F
.28552 .49468 m .24574 .47839 L .23977 .48168 L 1 .861 0 r
F
.24002 .48179 m .23977 .48168 L .23973 .48171 L F
.28081 .49503 m .23977 .48168 L .25881 .48969 L 1 .897 0 r
F
.28552 .49468 m .23977 .48168 L .24002 .48179 L 1 .861 0 r
F
.28552 .49468 m .23973 .48171 L .25881 .48969 L F
.25881 .48969 m .23977 .48168 L .23913 .48491 L 1 .897 0 r
F
.23977 .48168 m .24043 .47834 L .22236 .47267 L 1 .946 0 r
F
.23374 .48501 m .23977 .48168 L .19509 .4659 L .699 .909 0 r
F
.23977 .48168 m .22236 .47267 L .22173 .47247 L 1 .946 0 r
F
.24043 .47834 m .2418 .47177 L .22374 .46608 L 1 .952 0 r
F
.22374 .46608 m .19837 .45246 L .19669 .45918 L 1 .784 0 r
F
.28297 .48188 m .24322 .46521 L .2418 .47177 L 1 .91 0 r
F
.28186 .48846 m .28297 .48188 L .2418 .47177 L 1 .904 0 r
F
.2418 .47177 m .24322 .46521 L .2263 .45985 L 1 .959 0 r
F
.22445 .46295 m .19837 .45246 L .22374 .46608 L 1 .784 0 r
F
.22581 .45969 m .20012 .44575 L .19837 .45246 L 1 .792 0 r
F
.28413 .47531 m .24471 .45866 L .24322 .46521 L 1 .916 0 r
F
.22793 .45331 m .20194 .43906 L .20012 .44575 L 1 .8 0 r
F
.28533 .46874 m .24625 .45212 L .24471 .45866 L 1 .922 0 r
F
.2301 .44694 m .20384 .43238 L .20194 .43906 L 1 .807 0 r
F
.28659 .46218 m .24786 .44559 L .24625 .45212 L 1 .929 0 r
F
.23233 .44058 m .20581 .42571 L .20384 .43238 L 1 .814 0 r
F
.28789 .45562 m .24953 .43906 L .24786 .44559 L 1 .935 0 r
F
.2346 .43423 m .20785 .41906 L .20581 .42571 L 1 .821 0 r
F
.28924 .44907 m .25125 .43256 L .24953 .43906 L 1 .94 0 r
F
.29064 .44252 m .25304 .42606 L .25125 .43256 L 1 .946 0 r
F
.25304 .42606 m .21165 .40567 L .21689 .41423 L 1 .893 0 r
F
.25125 .43256 m .25304 .42606 L .23965 .42168 L 1 .995 0 r
F
.238 .42549 m .23965 .42168 L .21689 .41423 L F
.25125 .43256 m .23965 .42168 L .238 .42549 L F
.24953 .43906 m .25054 .43524 L .23726 .42811 L 1 .99 0 r
F
.24953 .43906 m .23726 .42811 L .23722 .42819 L F
.24953 .43906 m .23691 .42792 L .2369 .42796 L F
.23537 .43158 m .23661 .42872 L .20785 .41906 L 1 .821 0 r
F
.23661 .42872 m .23692 .42789 L .20785 .41906 L F
.24953 .43906 m .2369 .42796 L .2355 .43164 L 1 .99 0 r
F
.23692 .42789 m .21604 .41662 L .20785 .41906 L 1 .977 0 r
F
.2369 .42796 m .23676 .42784 L .2355 .43164 L 1 .99 0 r
F
.23722 .42819 m .23726 .42811 L .23691 .42792 L F
.25054 .43524 m .25125 .43256 L .23692 .42789 L F
.25054 .43524 m .23692 .42789 L .23676 .42784 L F
.25125 .43256 m .21689 .41423 L .21611 .4166 L 1 .995 0 r
F
.21656 .41685 m .21611 .4166 L .21604 .41662 L 1 .977 0 r
F
.25125 .43256 m .21611 .4166 L .23692 .42789 L 1 .995 0 r
F
.25493 .43336 m .21604 .41662 L .23692 .42789 L 1 .977 0 r
F
.23692 .42789 m .21611 .4166 L .21478 .42067 L 1 .995 0 r
F
.25493 .43336 m .22073 .41523 L .21611 .4166 L 1 .977 0 r
F
.25493 .43336 m .21611 .4166 L .21656 .41685 L F
.2534 .43979 m .23696 .4279 L .23661 .42872 L 1 .821 0 r
F
.2355 .43164 m .23661 .42872 L .23537 .43158 L F
.2534 .43979 m .23661 .42872 L .2355 .43164 L F
.24786 .44559 m .24953 .43906 L .235 .43436 L 1 .984 0 r
F
.23494 .43451 m .235 .43436 L .2346 .43423 L F
.24786 .44559 m .235 .43436 L .23494 .43451 L F
.24786 .44559 m .2346 .43423 L .23458 .43431 L F
.24786 .44559 m .23457 .4343 L .23322 .4379 L F
.2331 .43784 m .2343 .43504 L .20581 .42571 L 1 .814 0 r
F
.2343 .43504 m .2346 .43423 L .20581 .42571 L F
.23457 .4343 m .23441 .43417 L .23322 .4379 L 1 .984 0 r
F
.2343 .43504 m .23464 .43424 L .2346 .43423 L 1 .814 0 r
F
.24625 .45212 m .24786 .44559 L .23275 .44071 L 1 .978 0 r
F
.23268 .44087 m .23275 .44071 L .23233 .44058 L F
.24625 .45212 m .23275 .44071 L .23268 .44087 L F
.24625 .45212 m .23233 .44058 L .23231 .44066 L F
.24625 .45212 m .2323 .44066 L .231 .44417 L F
.23087 .44412 m .23203 .44138 L .20384 .43238 L 1 .807 0 r
F
.23203 .44138 m .23233 .44058 L .20384 .43238 L F
.2323 .44066 m .23212 .44051 L .231 .44417 L 1 .978 0 r
F
.23307 .43783 m .20581 .42571 L .23233 .44058 L 1 .814 0 r
F
.23219 .44053 m .21273 .42714 L .21076 .43362 L 1 .984 0 r
F
.24786 .44559 m .23322 .4379 L .23233 .44058 L F
.23237 .44059 m .2325 .44007 L .23233 .44058 L 1 .814 0 r
F
.2325 .44007 m .23307 .43783 L .23233 .44058 L F
.23322 .4379 m .23307 .43783 L .23237 .44059 L F
.23233 .44058 m .23322 .4379 L .23219 .44053 L 1 .984 0 r
F
.23535 .43157 m .20785 .41906 L .2346 .43423 L 1 .821 0 r
F
.2346 .43423 m .21478 .42067 L .21273 .42714 L 1 .99 0 r
F
.24953 .43906 m .2355 .43164 L .2346 .43423 L F
.23478 .43373 m .23535 .43157 L .2346 .43423 L 1 .821 0 r
F
.2355 .43164 m .23535 .43157 L .23464 .43424 L F
.2355 .43164 m .21478 .42067 L .2346 .43423 L 1 .99 0 r
F
.23464 .43424 m .23478 .43373 L .2346 .43423 L 1 .821 0 r
F
.23322 .4379 m .23464 .43424 L .2331 .43784 L 1 .814 0 r
F
.23322 .4379 m .21273 .42714 L .23219 .44053 L 1 .984 0 r
F
.25194 .44622 m .23465 .43425 L .23322 .4379 L 1 .814 0 r
F
.23465 .43425 m .23464 .43424 L .23322 .4379 L F
.23203 .44138 m .23237 .44059 L .23233 .44058 L 1 .807 0 r
F
.24471 .45866 m .24625 .45212 L .23055 .44708 L 1 .971 0 r
F
.23048 .44724 m .23055 .44708 L .2301 .44694 L F
.24471 .45866 m .23055 .44708 L .23048 .44724 L F
.24471 .45866 m .2301 .44694 L .23008 .44703 L F
.24471 .45866 m .23007 .44702 L .22882 .45044 L F
.2287 .45039 m .22981 .44773 L .20194 .43906 L 1 .8 0 r
F
.22981 .44773 m .2301 .44694 L .20194 .43906 L F
.23007 .44702 m .22987 .44686 L .22882 .45044 L 1 .971 0 r
F
.23084 .4441 m .20384 .43238 L .2301 .44694 L 1 .807 0 r
F
.22994 .44689 m .21076 .43362 L .20885 .44012 L 1 .978 0 r
F
.24625 .45212 m .231 .44417 L .2301 .44694 L F
.23014 .44695 m .23027 .44643 L .2301 .44694 L 1 .807 0 r
F
.23027 .44643 m .23084 .4441 L .2301 .44694 L F
.231 .44417 m .23084 .4441 L .23014 .44695 L F
.2301 .44694 m .231 .44417 L .22994 .44689 L 1 .978 0 r
F
.231 .44417 m .23237 .44059 L .23087 .44412 L 1 .807 0 r
F
.231 .44417 m .21076 .43362 L .22994 .44689 L 1 .978 0 r
F
.25056 .45266 m .23238 .44059 L .231 .44417 L 1 .807 0 r
F
.23238 .44059 m .23237 .44059 L .231 .44417 L F
.22981 .44773 m .23014 .44695 L .2301 .44694 L 1 .8 0 r
F
.24322 .46521 m .24471 .45866 L .2284 .45346 L 1 .965 0 r
F
.22833 .45362 m .2284 .45346 L .22793 .45331 L F
.24322 .46521 m .2284 .45346 L .22833 .45362 L F
.24322 .46521 m .22793 .45331 L .22791 .4534 L F
.24322 .46521 m .2279 .4534 L .22669 .45673 L F
.22657 .45668 m .22765 .45409 L .20012 .44575 L 1 .792 0 r
F
.22765 .45409 m .22793 .45331 L .20012 .44575 L F
.2279 .4534 m .22768 .45323 L .22669 .45673 L 1 .965 0 r
F
.22866 .45038 m .20194 .43906 L .22793 .45331 L 1 .8 0 r
F
.22774 .45325 m .20885 .44012 L .20702 .44664 L 1 .971 0 r
F
.24471 .45866 m .22882 .45044 L .22793 .45331 L F
.22797 .45332 m .22809 .4528 L .22793 .45331 L 1 .8 0 r
F
.22809 .4528 m .22866 .45038 L .22793 .45331 L F
.22882 .45044 m .22866 .45038 L .22797 .45332 L F
.22793 .45331 m .22882 .45044 L .22774 .45325 L 1 .971 0 r
F
.22882 .45044 m .23014 .44695 L .2287 .45039 L 1 .8 0 r
F
.22882 .45044 m .20885 .44012 L .22774 .45325 L 1 .971 0 r
F
.24924 .4591 m .23015 .44695 L .22882 .45044 L 1 .8 0 r
F
.23015 .44695 m .23014 .44695 L .22882 .45044 L F
.22765 .45409 m .22797 .45332 L .22793 .45331 L 1 .792 0 r
F
.22502 .46301 m .2263 .45985 L .22581 .45969 L 1 .959 0 r
F
.2418 .47177 m .2263 .45985 L .22495 .46319 L F
.28297 .48188 m .28413 .47531 L .24322 .46521 L 1 .91 0 r
F
.22653 .45666 m .20012 .44575 L .22581 .45969 L 1 .792 0 r
F
.22581 .45969 m .20702 .44664 L .20526 .45317 L 1 .965 0 r
F
.24322 .46521 m .22699 .45689 L .22581 .45969 L F
.22669 .45673 m .22797 .45332 L .22657 .45668 L 1 .792 0 r
F
.248 .46553 m .22797 .45332 L .22669 .45673 L F
.22797 .45332 m .22797 .45332 L .22669 .45673 L F
.22699 .45689 m .22669 .45673 L .22581 .45969 L 1 .965 0 r
F
.22669 .45673 m .20702 .44664 L .22562 .45956 L F
.22584 .4597 m .22653 .45666 L .22581 .45969 L 1 .792 0 r
F
.22669 .45673 m .22653 .45666 L .22584 .4597 L F
.22669 .45673 m .22562 .45956 L .22581 .45969 L 1 .965 0 r
F
.22495 .46319 m .22502 .46301 L .22532 .46104 L 1 .959 0 r
F
.22443 .46295 m .22581 .45969 L .19837 .45246 L 1 .784 0 r
F
.22529 .46114 m .22532 .46104 L .22554 .4596 L 1 .959 0 r
F
.22495 .46319 m .22532 .46104 L .22529 .46114 L F
.2245 .46298 m .22553 .46046 L .22581 .45969 L 1 .784 0 r
F
.2245 .46298 m .22581 .45969 L .22443 .46295 L F
.22532 .46104 m .22581 .45969 L .22554 .4596 L 1 .959 0 r
F
.22502 .46301 m .22581 .45969 L .22532 .46104 L F
.24683 .47197 m .22584 .4597 L .22553 .46046 L 1 .784 0 r
F
.22461 .46302 m .22553 .46046 L .2245 .46298 L F
.22495 .46319 m .22554 .4596 L .22461 .46302 L 1 .959 0 r
F
.24683 .47197 m .22553 .46046 L .22461 .46302 L 1 .784 0 r
F
.22553 .46046 m .22584 .4597 L .22581 .45969 L F
.24683 .47197 m .248 .46553 L .22584 .4597 L F
.28413 .47531 m .28533 .46874 L .24471 .45866 L 1 .916 0 r
F
.248 .46553 m .24924 .4591 L .22797 .45332 L 1 .792 0 r
F
.28533 .46874 m .28659 .46218 L .24625 .45212 L 1 .922 0 r
F
.24924 .4591 m .25056 .45266 L .23014 .44695 L 1 .8 0 r
F
.28659 .46218 m .28789 .45562 L .24786 .44559 L 1 .929 0 r
F
.25056 .45266 m .25194 .44622 L .23237 .44059 L 1 .807 0 r
F
.28789 .45562 m .28924 .44907 L .24953 .43906 L 1 .935 0 r
F
.25194 .44622 m .2534 .43979 L .23464 .43424 L 1 .814 0 r
F
.2369 .42796 m .23691 .42792 L .23676 .42784 L 1 .99 0 r
F
.23661 .42872 m .23696 .4279 L .23692 .42789 L 1 .821 0 r
F
.28924 .44907 m .29064 .44252 L .25125 .43256 L 1 .94 0 r
F
.2534 .43979 m .25493 .43336 L .23696 .4279 L 1 .821 0 r
F
.2355 .43164 m .23676 .42784 L .21478 .42067 L 1 .99 0 r
F
.2534 .43979 m .2355 .43164 L .23464 .43424 L 1 .821 0 r
F
.23458 .43431 m .2346 .43423 L .23441 .43417 L 1 .984 0 r
F
.23322 .4379 m .23441 .43417 L .21273 .42714 L F
.25194 .44622 m .23322 .4379 L .23237 .44059 L 1 .814 0 r
F
.23231 .44066 m .23233 .44058 L .23212 .44051 L 1 .978 0 r
F
.231 .44417 m .23212 .44051 L .21076 .43362 L F
.25056 .45266 m .231 .44417 L .23014 .44695 L 1 .807 0 r
F
.23008 .44703 m .2301 .44694 L .22987 .44686 L 1 .971 0 r
F
.22882 .45044 m .22987 .44686 L .20885 .44012 L F
.24924 .4591 m .22882 .45044 L .22797 .45332 L 1 .8 0 r
F
.22791 .4534 m .22793 .45331 L .22768 .45323 L 1 .965 0 r
F
.22669 .45673 m .22768 .45323 L .20702 .44664 L F
.248 .46553 m .22669 .45673 L .22584 .4597 L 1 .792 0 r
F
.22374 .46608 m .20526 .45317 L .20357 .45971 L 1 .959 0 r
F
.2418 .47177 m .22461 .46302 L .22374 .46608 L F
.22389 .46556 m .22445 .46295 L .22374 .46608 L 1 .784 0 r
F
.22461 .46302 m .22445 .46295 L .22377 .46608 L F
.22461 .46302 m .20526 .45317 L .22374 .46608 L 1 .959 0 r
F
.22377 .46608 m .22389 .46556 L .22374 .46608 L 1 .784 0 r
F
.24683 .47197 m .22461 .46302 L .22377 .46608 L F
.22461 .46302 m .22554 .4596 L .20526 .45317 L 1 .959 0 r
F
.24574 .47839 m .24683 .47197 L .22377 .46608 L 1 .775 0 r
F
.22377 .46609 m .22377 .46608 L .22374 .46608 L F
.24574 .47839 m .22377 .46608 L .22377 .46609 L F
.22258 .46932 m .22374 .46608 L .19669 .45918 L F
.22296 .46951 m .22374 .46608 L .22258 .46932 L 1 .952 0 r
F
.24043 .47834 m .22374 .46608 L .22296 .46951 L F
.24574 .47839 m .22374 .46608 L .22258 .46932 L 1 .775 0 r
F
.22258 .46932 m .22374 .46608 L .20357 .45971 L 1 .952 0 r
F
.22173 .47247 m .19669 .45918 L .19509 .4659 L 1 .775 0 r
F
.22258 .46932 m .19669 .45918 L .22173 .47247 L F
.22173 .47247 m .20357 .45971 L .20196 .46627 L 1 .952 0 r
F
.24043 .47834 m .22258 .46932 L .22173 .47247 L F
.22258 .46932 m .20357 .45971 L .22173 .47247 L F
.24574 .47839 m .22258 .46932 L .22173 .47247 L 1 .775 0 r
F
.23977 .48168 m .24574 .47839 L .22173 .47247 L .699 .909 0 r
F
.23977 .48168 m .22173 .47247 L .19509 .4659 L F
.23977 .48168 m .22173 .47247 L .20196 .46627 L 1 .946 0 r
F
.23913 .48491 m .23977 .48168 L .20196 .46627 L F
.25876 .48982 m .25833 .48957 L .25773 .49254 L 1 .891 0 r
F
.25956 .4902 m .25961 .4901 L .25878 .48976 L F
.28025 .49866 m .28081 .49503 L .25881 .48969 L F
.28025 .49866 m .25881 .48969 L .25833 .48957 L F
.28482 .50106 m .25884 .4897 L .25853 .49042 L 1 .702 0 r
F
.28482 .50106 m .25853 .49042 L .25773 .49254 L F
.27885 .50818 m .2798 .50161 L .25792 .49632 L 1 .884 0 r
F
.25782 .49656 m .25792 .49632 L .25697 .49609 L F
.27885 .50818 m .25792 .49632 L .25782 .49656 L F
.27885 .50818 m .25697 .49609 L .25695 .49624 L F
.27885 .50818 m .25692 .49622 L .25592 .49883 L F
.25583 .49881 m .25669 .49682 L .23251 .49174 L 1 .69 0 r
F
.25669 .49682 m .25697 .49609 L .23251 .49174 L F
.25692 .49622 m .25647 .49597 L .25592 .49883 L 1 .884 0 r
F
.25754 .49249 m .23374 .48501 L .25697 .49609 L 1 .702 0 r
F
.25697 .49609 m .23913 .48491 L .23789 .49149 L 1 .891 0 r
F
.2798 .50161 m .25773 .49254 L .25697 .49609 L F
.25708 .49557 m .25754 .49249 L .25697 .49609 L 1 .702 0 r
F
.25773 .49254 m .25754 .49249 L .257 .4961 L F
.25773 .49254 m .23913 .48491 L .25697 .49609 L 1 .891 0 r
F
.257 .4961 m .25708 .49557 L .25697 .49609 L 1 .702 0 r
F
.25669 .49682 m .257 .4961 L .25697 .49609 L 1 .69 0 r
F
.27794 .51475 m .27885 .50818 L .2562 .50274 L 1 .877 0 r
F
.25609 .50299 m .2562 .50274 L .25518 .5025 L F
.27794 .51475 m .2562 .50274 L .25609 .50299 L F
.27794 .51475 m .25518 .5025 L .25515 .50264 L F
.27794 .51475 m .25513 .50262 L .25415 .50512 L F
.25407 .5051 m .25489 .50321 L .23135 .49846 L 1 .676 0 r
F
.25489 .50321 m .25518 .5025 L .23135 .49846 L F
.25513 .50262 m .25465 .50237 L .25415 .50512 L 1 .877 0 r
F
.25573 .49878 m .23251 .49174 L .25518 .5025 L 1 .69 0 r
F
.25453 .50234 m .23789 .49149 L .23671 .49806 L 1 .884 0 r
F
.27885 .50818 m .25592 .49883 L .25518 .5025 L F
.25521 .5025 m .25528 .50197 L .25518 .5025 L 1 .69 0 r
F
.25528 .50197 m .25573 .49878 L .25518 .5025 L F
.25592 .49883 m .25573 .49878 L .25521 .5025 L F
.25518 .5025 m .25592 .49883 L .25453 .50234 L 1 .884 0 r
F
.25592 .49883 m .25693 .49628 L .25583 .49881 L 1 .69 0 r
F
.25592 .49883 m .23789 .49149 L .25453 .50234 L 1 .884 0 r
F
.2842 .50741 m .257 .4961 L .25693 .49628 L 1 .69 0 r
F
.2842 .50741 m .25693 .49628 L .25592 .49883 L F
.25489 .50321 m .25521 .5025 L .25518 .5025 L 1 .676 0 r
F
.25334 .51177 m .25452 .50916 L .25342 .5089 L 1 .87 0 r
F
.27709 .52132 m .25452 .50916 L .25334 .51177 L F
.32202 .52939 m .32268 .52283 L .27794 .51475 L 1 .822 0 r
F
.25396 .50507 m .23135 .49846 L .25342 .5089 L 1 .676 0 r
F
.25342 .5089 m .23671 .49806 L .2356 .50464 L 1 .877 0 r
F
.27794 .51475 m .25499 .50546 L .25342 .5089 L F
.28366 .51374 m .25521 .5025 L .25511 .50273 L 1 .676 0 r
F
.25415 .50512 m .25511 .50273 L .25407 .5051 L F
.28366 .51374 m .25511 .50273 L .25415 .50512 L F
.25499 .50546 m .25415 .50512 L .25342 .5089 L 1 .877 0 r
F
.25345 .5089 m .25396 .50507 L .25342 .5089 L 1 .676 0 r
F
.25415 .50512 m .25396 .50507 L .25345 .5089 L F
.25415 .50512 m .23671 .49806 L .25279 .50849 L 1 .877 0 r
F
.25415 .50512 m .25279 .50849 L .25342 .5089 L F
.25229 .51137 m .25342 .5089 L .23026 .50519 L 1 .662 0 r
F
.25304 .50984 m .25342 .5089 L .25288 .50877 L 1 .87 0 r
F
.25317 .51067 m .25342 .5089 L .25304 .50984 L F
.25235 .51138 m .25314 .50961 L .25342 .5089 L 1 .662 0 r
F
.25314 .50961 m .25345 .5089 L .25342 .5089 L F
.25235 .51138 m .25342 .5089 L .25229 .51137 L F
.2832 .52004 m .28366 .51374 L .25345 .5089 L F
.25334 .51177 m .25342 .5089 L .25317 .51067 L 1 .87 0 r
F
.25334 .51177 m .25304 .50984 L .25242 .5114 L F
.25242 .5114 m .25333 .50917 L .25314 .50961 L 1 .662 0 r
F
.25242 .5114 m .25314 .50961 L .25235 .51138 L F
.25304 .50984 m .25288 .50877 L .25242 .5114 L 1 .87 0 r
F
.25181 .51476 m .25223 .51135 L .25171 .51529 L 1 .662 0 r
F
.25242 .5114 m .25223 .51135 L .25174 .5153 L F
.25242 .5114 m .2356 .50464 L .25102 .51484 L 1 .87 0 r
F
.25242 .5114 m .25102 .51484 L .25171 .51529 L F
.2832 .52004 m .25345 .5089 L .25333 .50917 L 1 .662 0 r
F
.2832 .52004 m .25333 .50917 L .25242 .5114 L F
.32268 .52283 m .32337 .51627 L .27885 .50818 L 1 .829 0 r
F
.28366 .51374 m .2842 .50741 L .25521 .5025 L 1 .676 0 r
F
.32337 .51627 m .3241 .50969 L .2798 .50161 L 1 .836 0 r
F
.2842 .50741 m .28482 .50106 L .257 .4961 L 1 .69 0 r
F
.25876 .48982 m .25878 .48976 L .25833 .48957 L 1 .891 0 r
F
.25853 .49042 m .25884 .4897 L .25881 .48969 L 1 .702 0 r
F
.3241 .50969 m .32487 .50312 L .28081 .49503 L 1 .842 0 r
F
.28482 .50106 m .28552 .49468 L .25884 .4897 L 1 .702 0 r
F
.25773 .49254 m .25833 .48957 L .23913 .48491 L 1 .891 0 r
F
.28482 .50106 m .25773 .49254 L .257 .4961 L 1 .702 0 r
F
.25695 .49624 m .25697 .49609 L .25647 .49597 L 1 .884 0 r
F
.25592 .49883 m .25647 .49597 L .23789 .49149 L F
.2842 .50741 m .25592 .49883 L .25521 .5025 L 1 .69 0 r
F
.25515 .50264 m .25518 .5025 L .25465 .50237 L 1 .877 0 r
F
.25415 .50512 m .25465 .50237 L .23671 .49806 L F
.28366 .51374 m .25415 .50512 L .25345 .5089 L 1 .676 0 r
F
.25171 .51529 m .2356 .50464 L .23454 .51122 L 1 .87 0 r
F
.27709 .52132 m .25242 .5114 L .25171 .51529 L F
.25174 .5153 m .25181 .51476 L .25171 .51529 L 1 .662 0 r
F
.2832 .52004 m .25242 .5114 L .25174 .5153 L F
.25242 .5114 m .25288 .50877 L .2356 .50464 L 1 .87 0 r
F
.28282 .5263 m .2832 .52004 L .25174 .5153 L 1 .646 0 r
F
.25174 .5153 m .25174 .5153 L .25171 .51529 L F
.28282 .5263 m .25174 .5153 L .25174 .5153 L F
.25074 .51768 m .25171 .51529 L .22922 .51191 L F
.25136 .51793 m .25171 .51529 L .25074 .51768 L 1 .863 0 r
F
.27629 .52788 m .25171 .51529 L .25136 .51793 L F
.28282 .5263 m .25171 .51529 L .25074 .51768 L 1 .646 0 r
F
.25074 .51768 m .25171 .51529 L .23454 .51122 L 1 .863 0 r
F
.25005 .52169 m .22922 .51191 L .22826 .51862 L 1 .646 0 r
F
.27629 .52788 m .25074 .51768 L .25033 .52009 L 1 .863 0 r
F
.25074 .51768 m .22922 .51191 L .25005 .52169 L 1 .646 0 r
F
.27629 .52788 m .23395 .51518 L .25005 .52169 L 1 .863 0 r
F
.28282 .5263 m .25074 .51768 L .25005 .52169 L 1 .646 0 r
F
.25033 .52009 m .23454 .51122 L .23395 .51518 L 1 .863 0 r
F
.25074 .51768 m .23454 .51122 L .25033 .52009 L F
.25005 .52169 m .23395 .51518 L .23355 .51779 L F
.27521 .53186 m .25005 .52169 L .23772 .51995 L .739 .934 0 r
F
.27581 .53205 m .25005 .52169 L .27521 .53186 L F
.27581 .53205 m .23772 .51995 L .22826 .51862 L F
.28733 .5369 m .27578 .53207 L .27156 .53553 L 1 .718 0 r
F
.32083 .54248 m .29372 .5336 L .29133 .53724 L 1 .808 0 r
F
.32623 .54026 m .27578 .53207 L .29133 .53724 L 1 .718 0 r
F
.27553 .53444 m .27581 .53205 L .23355 .51779 L 1 .856 0 r
F
.27581 .53205 m .27629 .52788 L .25265 .5223 L F
.27581 .53205 m .25265 .5223 L .23355 .51779 L F
.29133 .53724 m .27612 .53218 L .28733 .5369 L 1 .718 0 r
F
.27612 .53218 m .27578 .53207 L .28733 .5369 L F
.27581 .53205 m .28282 .5263 L .25005 .52169 L .739 .934 0 r
F
.32623 .54026 m .28282 .5263 L .27581 .53205 L 1 .718 0 r
F
.27594 .53209 m .27581 .53205 L .27578 .53207 L F
.32623 .54026 m .27581 .53205 L .27594 .53209 L F
.29133 .53724 m .27581 .53205 L .27553 .53444 L 1 .808 0 r
F
.3203 .54901 m .32046 .54694 L .29126 .53736 L 1 .801 0 r
F
.29006 .53918 m .29133 .53724 L .27156 .53553 L 1 .529 0 r
F
.29123 .5374 m .29126 .53736 L .29042 .53708 L 1 .801 0 r
F
.3203 .54901 m .29126 .53736 L .29123 .5374 L F
.2901 .53918 m .29094 .53789 L .29133 .53724 L 1 .529 0 r
F
.2901 .53918 m .29133 .53724 L .29006 .53918 L F
.29126 .53736 m .29133 .53724 L .29042 .53708 L 1 .801 0 r
F
.32046 .54694 m .29133 .53724 L .29126 .53736 L F
.29015 .53919 m .29094 .53789 L .2901 .53918 L 1 .529 0 r
F
.3203 .54901 m .29042 .53708 L .29015 .53919 L 1 .801 0 r
F
.32625 .54631 m .29136 .53724 L .29094 .53789 L 1 .529 0 r
F
.32625 .54631 m .29094 .53789 L .29015 .53919 L F
.29094 .53789 m .29136 .53724 L .29133 .53724 L F
.32625 .54631 m .32623 .54026 L .29136 .53724 L F
.29015 .53919 m .29042 .53708 L .27553 .53444 L 1 .801 0 r
F
.28996 .53916 m .27156 .53553 L .28957 .54359 L 1 .529 0 r
F
.28957 .54359 m .27553 .53444 L .27483 .54098 L 1 .801 0 r
F
.3203 .54901 m .29223 .53987 L .28957 .54359 L F
.3198 .55552 m .3203 .54901 L .28957 .54359 L 1 .794 0 r
F
.32641 .55226 m .32625 .54631 L .28957 .54359 L 1 .491 0 r
F
.28831 .54535 m .28957 .54359 L .27089 .5422 L F
.3198 .55552 m .28957 .54359 L .28956 .54378 L 1 .794 0 r
F
.3198 .55552 m .28947 .54375 L .28839 .54537 L F
.28839 .54537 m .28957 .54359 L .28831 .54535 L 1 .491 0 r
F
.28947 .54375 m .28862 .54342 L .28839 .54537 L 1 .794 0 r
F
.32641 .55226 m .28957 .54359 L .28839 .54537 L 1 .491 0 r
F
.29223 .53987 m .29015 .53919 L .28957 .54359 L 1 .801 0 r
F
.28964 .54305 m .28996 .53916 L .28957 .54359 L 1 .529 0 r
F
.29015 .53919 m .28996 .53916 L .2896 .54359 L F
.29015 .53919 m .27553 .53444 L .28957 .54359 L 1 .801 0 r
F
.2896 .54359 m .28964 .54305 L .28957 .54359 L 1 .529 0 r
F
.32625 .54631 m .29015 .53919 L .2896 .54359 L F
.28956 .54378 m .28957 .54359 L .28862 .54342 L 1 .794 0 r
F
.28839 .54537 m .28862 .54342 L .27483 .54098 L F
.2882 .54533 m .27089 .5422 L .28783 .54991 L 1 .491 0 r
F
.28783 .54991 m .27483 .54098 L .27419 .54752 L 1 .794 0 r
F
.3198 .55552 m .29079 .54614 L .28783 .54991 L F
.31934 .56203 m .3198 .55552 L .28783 .54991 L 1 .786 0 r
F
.32673 .55807 m .32641 .55226 L .28783 .54991 L .985 .447 0 r
F
.28658 .55151 m .28783 .54991 L .27027 .54885 L F
.31934 .56203 m .28783 .54991 L .28781 .55011 L 1 .786 0 r
F
.31934 .56203 m .28771 .55007 L .28664 .55152 L F
.28664 .55152 m .28783 .54991 L .28658 .55151 L .985 .447 0 r
F
.28771 .55007 m .28684 .54974 L .28664 .55152 L 1 .786 0 r
F
.32673 .55807 m .28783 .54991 L .28664 .55152 L .985 .447 0 r
F
.29079 .54614 m .28839 .54537 L .28783 .54991 L 1 .794 0 r
F
.2879 .54938 m .2882 .54533 L .28783 .54991 L 1 .491 0 r
F
.28839 .54537 m .2882 .54533 L .28785 .54992 L F
.28839 .54537 m .27483 .54098 L .28783 .54991 L 1 .794 0 r
F
.28785 .54992 m .2879 .54938 L .28783 .54991 L 1 .491 0 r
F
.32641 .55226 m .28839 .54537 L .28785 .54992 L F
.28781 .55011 m .28783 .54991 L .28684 .54974 L 1 .786 0 r
F
.28664 .55152 m .28684 .54974 L .27419 .54752 L F
.28646 .55149 m .27027 .54885 L .28611 .55623 L .985 .447 0 r
F
.28611 .55623 m .27419 .54752 L .27359 .55405 L 1 .786 0 r
F
.31934 .56203 m .28941 .55241 L .28611 .55623 L F
.28811 .55868 m .28982 .55688 L .28611 .55623 L 1 .779 0 r
F
.31892 .56852 m .28982 .55688 L .28811 .55868 L F
.32724 .56372 m .32673 .55807 L .28611 .55623 L .962 .392 0 r
F
.28487 .55766 m .28611 .55623 L .26971 .55549 L F
.28811 .55868 m .28611 .55623 L .28606 .5569 L 1 .779 0 r
F
.28493 .55767 m .28611 .55623 L .28487 .55766 L .962 .392 0 r
F
.28448 .56198 m .28475 .55764 L .28442 .56253 L F
.28493 .55767 m .28475 .55764 L .28444 .56253 L F
.28493 .55767 m .27359 .55405 L .28229 .56086 L 1 .779 0 r
F
.28493 .55767 m .28229 .56086 L .28442 .56253 L F
.28811 .55868 m .28509 .55605 L .28493 .55767 L F
.32724 .56372 m .28612 .55623 L .28493 .55767 L .962 .392 0 r
F
.28612 .55623 m .28611 .55623 L .28493 .55767 L F
.28941 .55241 m .28664 .55152 L .28611 .55623 L 1 .786 0 r
F
.28617 .55568 m .28646 .55149 L .28611 .55623 L .985 .447 0 r
F
.28664 .55152 m .28646 .55149 L .28613 .55623 L F
.28664 .55152 m .27419 .54752 L .28611 .55623 L 1 .786 0 r
F
.28613 .55623 m .28617 .55568 L .28611 .55623 L .985 .447 0 r
F
.32673 .55807 m .28664 .55152 L .28613 .55623 L F
.28606 .5569 m .28611 .55623 L .28509 .55605 L 1 .779 0 r
F
.28442 .56253 m .27359 .55405 L .27305 .56056 L F
.31892 .56852 m .28493 .55767 L .28442 .56253 L F
.28444 .56253 m .28448 .56198 L .28442 .56253 L .962 .392 0 r
F
.32724 .56372 m .28493 .55767 L .28444 .56253 L F
.28493 .55767 m .28509 .55605 L .27359 .55405 L 1 .779 0 r
F
.32796 .56917 m .32724 .56372 L .28444 .56253 L .933 .324 0 r
F
.28444 .56254 m .28444 .56253 L .28443 .56253 L F
.32796 .56917 m .28444 .56253 L .28444 .56254 L F
.28326 .5638 m .28442 .56253 L .2692 .56211 L F
.28382 .56319 m .28442 .56253 L .28339 .56236 L 1 .771 0 r
F
.28431 .56413 m .28442 .56253 L .28382 .56319 L F
.28431 .56413 m .28339 .56236 L .28326 .5638 L F
.28326 .5638 m .28443 .56253 L .28442 .56253 L .933 .324 0 r
F
.31854 .57499 m .28442 .56253 L .28431 .56413 L 1 .771 0 r
F
.32796 .56917 m .28443 .56253 L .28326 .5638 L .933 .324 0 r
F
.27921 .56821 m .27305 .56056 L .27256 .56706 L 1 .771 0 r
F
.28278 .56882 m .28046 .56685 L .27921 .56821 L F
.28046 .56685 m .27305 .56056 L .27921 .56821 L F
.28278 .56881 m .28278 .56881 L .28278 .56882 L .933 .324 0 r
F
.28326 .5638 m .27305 .56056 L .28278 .56882 L 1 .771 0 r
F
.28281 .56882 m .28278 .56881 L .28278 .56882 L .933 .324 0 r
F
.32796 .56917 m .28326 .5638 L .28281 .56882 L F
.28326 .5638 m .28339 .56236 L .27305 .56056 L 1 .771 0 r
F
.31827 .58015 m .32796 .56917 L .28278 .56882 L .726 .923 0 r
F
.37069 .54051 m .37093 .53421 L .32652 .52792 L 1 .748 0 r
F
.37069 .54051 m .32652 .52792 L .32632 .53413 L F
.32894 .57438 m .39466 .52885 L .28239 .56279 L .465 .718 0 r
F
.39466 .52885 m .3947 .52796 L .38895 .52672 L 1 .8 0 r
F
.39486 .52473 m .39504 .52149 L .38968 .52032 L 1 .819 0 r
F
.37156 .52149 m .37194 .51508 L .32762 .509 L 1 .779 0 r
F
.37156 .52149 m .32762 .509 L .32717 .51535 L F
.37123 .52787 m .37156 .52149 L .32717 .51535 L 1 .769 0 r
F
.37123 .52787 m .32717 .51535 L .3268 .52166 L F
.37093 .53421 m .37123 .52787 L .3268 .52166 L 1 .759 0 r
F
.37093 .53421 m .3268 .52166 L .32652 .52792 L F
.32652 .52792 m .3268 .52166 L .28366 .51374 L 1 .762 0 r
F
.32652 .52792 m .28366 .51374 L .2832 .52004 L F
.32632 .53413 m .32652 .52792 L .2832 .52004 L 1 .742 0 r
F
.32632 .53413 m .2832 .52004 L .28282 .5263 L F
.32623 .54026 m .32632 .53413 L .28282 .5263 L 1 .718 0 r
F
.39018 .51388 m .28253 .53251 L .28232 .53868 L .344 .052 0 r
F
.3947 .52796 m .39486 .52473 L .38936 .52354 L 1 .809 0 r
F
.38982 .51711 m .28232 .53868 L .2822 .5448 L .343 .051 0 r
F
.38982 .51711 m .28232 .53868 L .38982 .51711 L F
.38996 .51629 m .28232 .53868 L .38989 .51709 L F
.39466 .52885 m .38895 .52672 L .28239 .56279 L .465 .718 0 r
F
.39455 .53119 m .39466 .52885 L .38902 .52739 L 1 .8 0 r
F
.38947 .52034 m .2822 .5448 L .28217 .55086 L .342 .051 0 r
F
.38947 .52033 m .2822 .5448 L .38947 .52034 L F
.3896 .5195 m .38952 .51952 L .38954 .52031 L F
.38952 .51952 m .2822 .5448 L .38947 .52033 L F
.38952 .51952 m .38947 .52033 L .38954 .52031 L F
.41845 .51532 m .39598 .50842 L .39572 .5117 L 1 .794 0 r
F
.41831 .51862 m .41845 .51532 L .39572 .5117 L 1 .785 0 r
F
.41831 .51862 m .39572 .5117 L .39547 .51497 L F
.41817 .52191 m .41831 .51862 L .39547 .51497 L 1 .775 0 r
F
.41817 .52191 m .39547 .51497 L .39525 .51823 L F
.39525 .51823 m .39547 .51497 L .39033 .51386 L 1 .837 0 r
F
.39025 .51309 m .28253 .53251 L .39018 .51388 L .344 .052 0 r
F
.37194 .51508 m .32813 .50262 L .32762 .509 L 1 .787 0 r
F
.3268 .52166 m .32717 .51535 L .2842 .50741 L 1 .78 0 r
F
.3268 .52166 m .2842 .50741 L .28366 .51374 L F
.41879 .50867 m .39657 .50184 L .39627 .50513 L 1 .812 0 r
F
.41861 .512 m .41879 .50867 L .39627 .50513 L 1 .803 0 r
F
.41861 .512 m .39627 .50513 L .39598 .50842 L F
.41845 .51532 m .41861 .512 L .39598 .50842 L 1 .794 0 r
F
.39627 .50513 m .39657 .50184 L .37594 .49744 L 1 .874 0 r
F
.39627 .50513 m .37594 .49744 L .3755 .50068 L F
.39598 .50842 m .39627 .50513 L .3755 .50068 L 1 .865 0 r
F
.39598 .50842 m .3755 .50068 L .37509 .50393 L F
.39572 .5117 m .39598 .50842 L .39112 .50737 L 1 .856 0 r
F
.3908 .50985 m .39112 .50737 L .37509 .50393 L F
.39572 .5117 m .39112 .50737 L .3908 .50985 L F
.39069 .51061 m .37509 .50393 L .37501 .50462 L F
.3908 .50985 m .37509 .50393 L .39069 .51061 L F
.40579 .50756 m .38647 .50117 L .37501 .50462 L 1 .708 0 r
F
.3894 .51087 m .37495 .50464 L .28253 .53251 L F
.39069 .51061 m .37577 .50495 L .3894 .51087 L F
.37577 .50495 m .37495 .50464 L .3894 .51087 L F
.39069 .51061 m .37501 .50462 L .37495 .50464 L F
.32487 .50312 m .32568 .49654 L .28186 .48846 L 1 .849 0 r
F
.32762 .509 m .32813 .50262 L .28552 .49468 L 1 .808 0 r
F
.32762 .509 m .28552 .49468 L .28482 .50106 L F
.32717 .51535 m .32762 .509 L .28482 .50106 L 1 .795 0 r
F
.32717 .51535 m .28482 .50106 L .2842 .50741 L F
.28253 .53251 m .37501 .50462 L .24078 .51666 L .373 .545 0 r
F
.37501 .50462 m .37509 .50393 L .37108 .5028 L 1 .913 0 r
F
.37501 .50462 m .37108 .5028 L .24078 .51666 L .373 .545 0 r
F
.37471 .50717 m .37501 .50462 L .37101 .50335 L 1 .913 0 r
F
.32568 .49654 m .32653 .48996 L .28297 .48188 L 1 .855 0 r
F
.32568 .49654 m .28297 .48188 L .28186 .48846 L F
.32813 .50262 m .32871 .49621 L .28629 .48827 L 1 .82 0 r
F
.32813 .50262 m .28629 .48827 L .28552 .49468 L F
.37155 .4996 m .24212 .50397 L .24141 .51033 L .467 .07 0 r
F
.37155 .4996 m .24212 .50397 L .37155 .4996 L F
.3717 .49894 m .37165 .49894 L .3716 .49959 L F
.37165 .49894 m .24212 .50397 L .37155 .4996 L F
.37165 .49894 m .37155 .4996 L .3716 .49959 L F
.3969 .49854 m .37689 .49095 L .3764 .49419 L 1 .892 0 r
F
.39657 .50184 m .3969 .49854 L .3764 .49419 L 1 .883 0 r
F
.39657 .50184 m .3764 .49419 L .37594 .49744 L F
.37594 .49744 m .3764 .49419 L .37272 .49317 L 1 .94 0 r
F
.39725 .49523 m .3774 .4877 L .37689 .49095 L 1 .901 0 r
F
.3969 .49854 m .39725 .49523 L .37689 .49095 L 1 .892 0 r
F
.37227 .49574 m .37272 .49317 L .37271 .49317 L 1 .94 0 r
F
.32653 .48996 m .32741 .48337 L .28413 .47531 L 1 .861 0 r
F
.32653 .48996 m .28413 .47531 L .28297 .48188 L F
.32871 .49621 m .32935 .48977 L .28713 .48185 L 1 .831 0 r
F
.32871 .49621 m .28713 .48185 L .28629 .48827 L F
.28552 .49468 m .28629 .48827 L .24574 .47839 L 1 .861 0 r
F
.37266 .49317 m .24378 .49121 L .24291 .4976 L .467 .071 0 r
F
.37271 .49317 m .37266 .49317 L .37266 .49317 L F
.37266 .49317 m .24378 .49121 L .37266 .49317 L F
.3717 .49894 m .37196 .49747 L .24212 .50397 L .467 .07 0 r
F
.37196 .49747 m .37214 .49638 L .24212 .50397 L F
.37172 .49894 m .37196 .49747 L .3717 .49894 L F
.37172 .49894 m .37214 .49638 L .37172 .49893 L 1 .931 0 r
F
.37271 .49317 m .24378 .49121 L .37271 .49317 L .467 .071 0 r
F
.37284 .49254 m .24378 .49121 L .37271 .49317 L F
.3764 .49419 m .37284 .49254 L .37271 .49317 L 1 .949 0 r
F
.37284 .49254 m .37271 .49317 L .37272 .49317 L .467 .071 0 r
F
.32741 .48337 m .32833 .47679 L .28533 .46874 L 1 .868 0 r
F
.32741 .48337 m .28533 .46874 L .28413 .47531 L F
.32833 .47679 m .32929 .47021 L .28659 .46218 L 1 .874 0 r
F
.32833 .47679 m .28659 .46218 L .28533 .46874 L F
.33005 .48332 m .3308 .47686 L .28901 .46897 L 1 .851 0 r
F
.33005 .48332 m .28901 .46897 L .28804 .47542 L F
.32935 .48977 m .33005 .48332 L .28804 .47542 L 1 .841 0 r
F
.32935 .48977 m .28804 .47542 L .28713 .48185 L F
.28629 .48827 m .28713 .48185 L .24683 .47197 L 1 .871 0 r
F
.28629 .48827 m .24683 .47197 L .24574 .47839 L F
.398 .48861 m .37851 .48121 L .37794 .48446 L 1 .919 0 r
F
.39762 .49192 m .398 .48861 L .37794 .48446 L 1 .91 0 r
F
.39762 .49192 m .37794 .48446 L .3774 .4877 L F
.37794 .48446 m .37851 .48121 L .3605 .47632 L 1 .974 0 r
F
.37794 .48446 m .3605 .47632 L .35978 .47949 L F
.3774 .4877 m .37794 .48446 L .37458 .48354 L 1 .966 0 r
F
.37406 .48614 m .37458 .48354 L .35978 .47949 L F
.3774 .4877 m .37458 .48354 L .37406 .48614 L F
.39725 .49523 m .39762 .49192 L .3774 .4877 L 1 .901 0 r
F
.37393 .48675 m .35978 .47949 L .35966 .48001 L 1 .966 0 r
F
.37406 .48614 m .35978 .47949 L .37393 .48675 L F
.38734 .48695 m .3698 .47958 L .35966 .48001 L 1 .847 0 r
F
.37393 .48675 m .35959 .48001 L .24472 .48481 L F
.37342 .48934 m .37372 .48785 L .37393 .48675 L .467 .071 0 r
F
.37336 .48934 m .37393 .48675 L .24472 .48481 L F
.37342 .48934 m .37393 .48675 L .37336 .48934 L F
.37383 .48725 m .37393 .48675 L .35909 .48267 L 1 .957 0 r
F
.3773 .48833 m .37393 .48675 L .37383 .48725 L F
.37689 .49095 m .3773 .48833 L .37385 .48726 L F
.37385 .48727 m .37385 .48726 L .37383 .48725 L F
.37689 .49095 m .37385 .48726 L .37385 .48727 L F
.37689 .49095 m .37383 .48725 L .37344 .48934 L F
.37331 .48996 m .24472 .48481 L .37331 .48996 L .467 .071 0 r
F
.37344 .48934 m .24472 .48481 L .37332 .48996 L F
.37331 .48996 m .35909 .48267 L .35843 .48585 L 1 .957 0 r
F
.37689 .49095 m .37344 .48934 L .37331 .48996 L F
.37344 .48934 m .35909 .48267 L .37331 .48996 L F
.37332 .48996 m .37331 .48996 L .37331 .48996 L .467 .071 0 r
F
.38691 .49269 m .38711 .48982 L .37331 .48996 L F
.37284 .49254 m .37331 .48996 L .24378 .49121 L F
.37292 .49209 m .37331 .48996 L .37331 .48996 L 1 .949 0 r
F
.3764 .49419 m .37689 .49095 L .37332 .48996 L F
.37332 .48997 m .37332 .48996 L .37331 .48996 L F
.3764 .49419 m .37332 .48996 L .37332 .48997 L F
.3764 .49419 m .37331 .48996 L .37284 .49254 L F
.38691 .49269 m .37331 .48996 L .37284 .49254 L .467 .071 0 r
F
.37284 .49254 m .37292 .49209 L .37331 .48996 L 1 .949 0 r
F
.37331 .48996 m .24472 .48481 L .24378 .49121 L .467 .071 0 r
F
.37283 .49254 m .37331 .48996 L .35843 .48585 L 1 .949 0 r
F
.37284 .49254 m .37331 .48996 L .37283 .49254 L F
.38711 .48982 m .37344 .48934 L .37332 .48996 L .467 .071 0 r
F
.3773 .48833 m .3774 .4877 L .37393 .48675 L 1 .957 0 r
F
.3774 .4877 m .37406 .48614 L .37393 .48675 L 1 .966 0 r
F
.38711 .48982 m .37394 .48675 L .37372 .48785 L .467 .071 0 r
F
.37344 .48934 m .37372 .48785 L .37342 .48934 L F
.38711 .48982 m .37372 .48785 L .37344 .48934 L F
.37372 .48785 m .37394 .48675 L .37393 .48675 L F
.37344 .48934 m .37383 .48725 L .35909 .48267 L 1 .957 0 r
F
.28804 .47542 m .28901 .46897 L .24924 .4591 L 1 .891 0 r
F
.28804 .47542 m .24924 .4591 L .248 .46553 L F
.28713 .48185 m .28804 .47542 L .248 .46553 L 1 .881 0 r
F
.28713 .48185 m .248 .46553 L .24683 .47197 L F
.24472 .48481 m .35966 .48001 L .20758 .46656 L .267 .354 0 r
F
.35966 .48001 m .35978 .47949 L .35718 .47857 L 1 1 0 r
F
.32929 .47021 m .33029 .46363 L .28789 .45562 L 1 .88 0 r
F
.32929 .47021 m .28789 .45562 L .28659 .46218 L F
.3308 .47686 m .3316 .47038 L .29005 .46252 L 1 .859 0 r
F
.3308 .47686 m .29005 .46252 L .28901 .46897 L F
.35713 .47857 m .20894 .46013 L .20758 .46656 L .591 .163 0 r
F
.35718 .47857 m .35713 .47857 L .35713 .47857 L F
.35713 .47857 m .20894 .46013 L .35713 .47857 L F
.35843 .48585 m .35909 .48267 L .35637 .48171 L 1 1 0 r
F
.35966 .48001 m .35718 .47857 L .20758 .46656 L .267 .354 0 r
F
.35574 .48431 m .35637 .48171 L .34278 .47689 L 1 1 0 r
F
.35843 .48585 m .35637 .48171 L .35574 .48431 L F
.35718 .47857 m .20894 .46013 L .35718 .47857 L .591 .163 0 r
F
.35731 .47807 m .20894 .46013 L .35718 .47857 L F
.28901 .46897 m .29005 .46252 L .25056 .45266 L 1 .9 0 r
F
.28901 .46897 m .25056 .45266 L .24924 .4591 L F
.35794 .47543 m .21039 .4537 L .20894 .46013 L .59 .165 0 r
F
.35799 .47543 m .35794 .47543 L .35794 .47543 L F
.35794 .47543 m .21039 .4537 L .35794 .47543 L F
.35978 .47949 m .3605 .47632 L .35803 .47545 L 1 1 0 r
F
.35802 .47549 m .35803 .47545 L .35799 .47543 L F
.35978 .47949 m .35803 .47545 L .35802 .47549 L F
.37851 .48121 m .3791 .47797 L .36125 .47315 L 1 .983 0 r
F
.37851 .48121 m .36125 .47315 L .3605 .47632 L F
.3605 .47632 m .36125 .47315 L .35883 .4723 L 1 1 0 r
F
.33029 .46363 m .28924 .44907 L .28789 .45562 L 1 .886 0 r
F
.33029 .46363 m .33133 .45706 L .28924 .44907 L F
.3316 .47038 m .33246 .46389 L .29115 .45606 L 1 .868 0 r
F
.3316 .47038 m .29115 .45606 L .29005 .46252 L F
.29005 .46252 m .29115 .45606 L .25194 .44622 L 1 .909 0 r
F
.29005 .46252 m .25194 .44622 L .25056 .45266 L F
.35883 .4723 m .21191 .44727 L .21039 .4537 L .589 .166 0 r
F
.3791 .47797 m .37972 .47474 L .36204 .46999 L 1 .991 0 r
F
.3791 .47797 m .36204 .46999 L .36125 .47315 L F
.36125 .47315 m .36204 .46999 L .35975 .46919 L 1 1 0 r
F
.33133 .45706 m .29064 .44252 L .28924 .44907 L 1 .892 0 r
F
.33246 .46389 m .29232 .4496 L .29115 .45606 L 1 .875 0 r
F
.29115 .45606 m .29232 .4496 L .2534 .43979 L 1 .917 0 r
F
.29115 .45606 m .2534 .43979 L .25194 .44622 L F
.3597 .46918 m .21352 .44084 L .21191 .44727 L .588 .167 0 r
F
.37972 .47474 m .36285 .46685 L .36204 .46999 L 1 1 0 r
F
.36204 .46999 m .36285 .46685 L .36065 .46608 L F
.33133 .45706 m .3324 .45049 L .29064 .44252 L 1 .892 0 r
F
.33246 .46389 m .33336 .4574 L .29232 .4496 L 1 .875 0 r
F
.3606 .46606 m .2152 .43442 L .21352 .44084 L .587 .167 0 r
F
.38036 .4715 m .3637 .46371 L .36285 .46685 L 1 1 0 r
F
.36285 .46685 m .3637 .46371 L .36159 .46298 L F
.33336 .4574 m .33431 .4509 L .29355 .44314 L 1 .883 0 r
F
.33336 .4574 m .29355 .44314 L .29232 .4496 L F
.3324 .45049 m .29209 .43599 L .29064 .44252 L 1 .898 0 r
F
.29064 .44252 m .29209 .43599 L .25304 .42606 L 1 .946 0 r
F
.29232 .4496 m .29355 .44314 L .25493 .43336 L 1 .925 0 r
F
.29232 .4496 m .25493 .43336 L .2534 .43979 L F
.36153 .46296 m .21697 .42801 L .2152 .43442 L .586 .168 0 r
F
.38103 .46827 m .36458 .46058 L .3637 .46371 L 1 1 0 r
F
.36167 .46253 m .21697 .42801 L .36153 .46296 L .586 .168 0 r
F
.3324 .45049 m .33351 .44393 L .29209 .43599 L 1 .898 0 r
F
.33431 .4509 m .29483 .43667 L .29355 .44314 L 1 .89 0 r
F
.33351 .44393 m .29359 .42947 L .29209 .43599 L 1 .903 0 r
F
.29209 .43599 m .25488 .41959 L .25304 .42606 L 1 .952 0 r
F
.29209 .43599 m .29359 .42947 L .25488 .41959 L F
.29355 .44314 m .29483 .43667 L .25653 .42694 L 1 .932 0 r
F
.29355 .44314 m .25653 .42694 L .25493 .43336 L F
.25304 .42606 m .25488 .41959 L .21165 .40567 L 1 .893 0 r
F
.25493 .43336 m .25653 .42694 L .22073 .41523 L 1 .977 0 r
F
.3637 .46371 m .36458 .46058 L .36249 .45986 L 1 1 0 r
F
.36249 .45986 m .21881 .42161 L .21697 .42801 L .585 .169 0 r
F
.36249 .45986 m .21881 .42161 L .36249 .45986 L F
.36458 .46058 m .36264 .45945 L .36249 .45986 L 1 1 0 r
F
.36269 .45946 m .36264 .45945 L .36255 .45987 L .585 .169 0 r
F
.36264 .45945 m .21881 .42161 L .36249 .45986 L F
.36264 .45945 m .36249 .45986 L .36255 .45987 L F
.33431 .4509 m .3353 .4444 L .29483 .43667 L 1 .89 0 r
F
.33351 .44393 m .33465 .43737 L .29359 .42947 L 1 .903 0 r
F
.3353 .4444 m .29618 .43022 L .29483 .43667 L 1 .897 0 r
F
.3353 .4444 m .33634 .4379 L .29618 .43022 L F
.29359 .42947 m .25678 .41313 L .25488 .41959 L 1 .958 0 r
F
.33465 .43737 m .29514 .42297 L .29359 .42947 L 1 .909 0 r
F
.29359 .42947 m .29514 .42297 L .25678 .41313 L 1 .958 0 r
F
.29618 .43022 m .25993 .41412 L .2582 .42052 L 1 .947 0 r
F
.29483 .43667 m .29618 .43022 L .2582 .42052 L 1 .94 0 r
F
.25488 .41959 m .21393 .39907 L .21165 .40567 L 1 .896 0 r
F
.25488 .41959 m .25678 .41313 L .21393 .39907 L F
.29514 .42297 m .25875 .40669 L .25678 .41313 L 1 .963 0 r
F
.25678 .41313 m .21628 .39249 L .21393 .39907 L 1 .9 0 r
F
.25678 .41313 m .25875 .40669 L .21628 .39249 L F
.22321 .40902 m .22133 .40141 L .21907 .40781 L .584 .188 0 r
F
.22324 .40894 m .22133 .40141 L .22321 .40902 L F
.2582 .42052 m .22525 .40274 L .22321 .40902 L 1 .991 0 r
F
.22525 .40274 m .22133 .40141 L .22326 .40903 L .584 .188 0 r
F
.2582 .42052 m .25993 .41412 L .22527 .40266 L 1 .991 0 r
F
.22527 .40266 m .22527 .40266 L .22527 .40266 L F
.2582 .42052 m .22527 .40266 L .22527 .40266 L F
.33465 .43737 m .33584 .43082 L .29514 .42297 L 1 .909 0 r
F
.33634 .4379 m .29758 .42376 L .29618 .43022 L 1 .904 0 r
F
.29618 .43022 m .29758 .42376 L .25993 .41412 L 1 .947 0 r
F
.33584 .43082 m .29673 .41647 L .29514 .42297 L 1 .915 0 r
F
.29514 .42297 m .29673 .41647 L .25875 .40669 L 1 .963 0 r
F
.29758 .42376 m .26174 .40773 L .25993 .41412 L 1 .953 0 r
F
.22527 .40266 m .22365 .39503 L .22133 .40141 L .581 .187 0 r
F
.22725 .39635 m .22365 .39503 L .22527 .40266 L F
.33634 .4379 m .33743 .43141 L .29758 .42376 L 1 .904 0 r
F
.33584 .43082 m .33705 .42429 L .29673 .41647 L 1 .915 0 r
F
.33743 .43141 m .29904 .41732 L .29758 .42376 L 1 .911 0 r
F
.29758 .42376 m .29904 .41732 L .26174 .40773 L 1 .953 0 r
F
.25993 .41412 m .26174 .40773 L .2274 .39632 L 1 .998 0 r
F
.2274 .39632 m .2274 .39632 L .2274 .39632 L F
.25993 .41412 m .2274 .39632 L .2274 .39632 L F
.25993 .41412 m .22738 .3964 L .22527 .40266 L F
.22531 .40268 m .22738 .3964 L .22527 .40266 L .581 .187 0 r
F
.25993 .41412 m .2274 .39632 L .22738 .3964 L 1 .998 0 r
F
.36839 .44819 m .22738 .3964 L .22531 .40268 L .581 .187 0 r
F
.36839 .44819 m .36942 .44512 L .2274 .39632 L F
.22738 .3964 m .2274 .39632 L .22365 .39503 L F
.36839 .44819 m .2274 .39632 L .22738 .3964 L F
.22738 .3964 m .2274 .39632 L .22696 .39618 L 1 .998 0 r
F
.22527 .40266 m .22696 .39618 L .22481 .40251 L F
.22738 .3964 m .22725 .39635 L .22527 .40266 L .581 .187 0 r
F
.22738 .3964 m .22696 .39618 L .22527 .40266 L 1 .998 0 r
F
.36739 .45126 m .36839 .44819 L .22527 .40266 L .584 .188 0 r
F
.22525 .40274 m .22527 .40266 L .22133 .40141 L F
.2582 .42052 m .22527 .40266 L .22525 .40274 L 1 .991 0 r
F
.36739 .45126 m .22527 .40266 L .22525 .40274 L .584 .188 0 r
F
.22525 .40274 m .22527 .40266 L .22524 .40274 L 1 .991 0 r
F
.22321 .40902 m .22481 .40251 L .22273 .40886 L F
.22525 .40274 m .22481 .40251 L .22321 .40902 L F
.22326 .40903 m .22324 .40894 L .22321 .40902 L .584 .188 0 r
F
.36739 .45126 m .22525 .40274 L .22326 .40903 L F
.22524 .40274 m .22527 .40266 L .22481 .40251 L 1 .991 0 r
F
.22319 .40911 m .2582 .42052 L .22321 .40902 L 1 .984 0 r
F
.22319 .40911 m .22321 .40902 L .21907 .40781 L .587 .189 0 r
F
.22319 .40911 m .22321 .40902 L .22273 .40886 L 1 .984 0 r
F
.36642 .45436 m .36739 .45126 L .22321 .40902 L .587 .189 0 r
F
.36642 .45436 m .22321 .40902 L .22319 .40911 L F
.36642 .45436 m .22319 .40911 L .35153 .44931 L F
.25653 .42694 m .22319 .40911 L .22073 .41523 L 1 .984 0 r
F
.22319 .40911 m .22273 .40886 L .2227 .40894 L F
.22319 .40911 m .2227 .40894 L .22073 .41523 L F
.22319 .40911 m .21907 .40781 L .2227 .40894 L .587 .189 0 r
F
.22319 .40911 m .2227 .40894 L .22271 .40894 L F
.22319 .40911 m .22271 .40894 L .35153 .44931 L F
.25653 .42694 m .25812 .42081 L .22319 .40911 L 1 .984 0 r
F
.25812 .42081 m .2582 .42052 L .22319 .40911 L F
.38245 .46184 m .36642 .45436 L .36549 .45746 L 1 1 0 r
F
.36348 .45678 m .35293 .45056 L .21881 .42161 L 1 .982 0 r
F
.36536 .45789 m .36549 .45746 L .36348 .45678 L 1 1 0 r
F
.38173 .46505 m .36549 .45746 L .36458 .46058 L F
.38173 .46505 m .38245 .46184 L .36549 .45746 L F
.36549 .45746 m .35153 .44931 L .35141 .44963 L F
.35309 .45063 m .353 .45057 L .35293 .45056 L 1 .982 0 r
F
.36549 .45746 m .35141 .44963 L .36348 .45678 L 1 1 0 r
F
.36549 .45746 m .36642 .45436 L .3645 .4537 L F
.36362 .45637 m .3645 .4537 L .35153 .44931 L F
.36549 .45746 m .3645 .4537 L .36362 .45637 L F
.37272 .4621 m .37333 .45917 L .36349 .45678 L .585 .169 0 r
F
.36349 .45678 m .36349 .45678 L .36348 .45678 L F
.37272 .4621 m .36349 .45678 L .36349 .45678 L F
.37333 .45917 m .35293 .45056 L .36348 .45678 L 1 .982 0 r
F
.36045 .45218 m .3603 .4521 L .35085 .44951 L F
.3603 .4521 m .35852 .45114 L .35141 .44963 L F
.3603 .4521 m .35141 .44963 L .35085 .44951 L F
.29483 .43667 m .2582 .42052 L .25653 .42694 L 1 .94 0 r
F
.21689 .41423 m .21165 .40567 L .17763 .39149 L 1 .093 0 r
F
.17755 .39901 m .17763 .39149 L .1751 .39807 L F
.21689 .41423 m .17946 .39255 L .17755 .39901 L F
.17946 .39255 m .17763 .39149 L .17755 .39901 L F
.18072 .40086 m .21689 .41423 L .17755 .39901 L 1 .931 0 r
F
.17744 .3994 m .17755 .39901 L .1751 .39807 L F
.20785 .41906 m .21604 .41662 L .17744 .3994 L .595 .825 0 r
F
.21604 .41662 m .21611 .4166 L .17744 .3994 L F
.17566 .40582 m .17741 .39949 L .17555 .40578 L F
.17524 .40565 m .17744 .3994 L .17678 .40013 L 1 .931 0 r
F
.17524 .40565 m .17678 .40013 L .17266 .40467 L F
.20581 .42571 m .20759 .41991 L .17722 .40695 L 1 1 0 r
F
.17514 .40606 m .17524 .40565 L .17266 .40467 L 1 .927 0 r
F
.17514 .40606 m .17524 .40565 L .17513 .40606 L 1 1 0 r
F
.20581 .42571 m .17524 .40565 L .17514 .40606 L F
.17722 .40695 m .20785 .41906 L .17524 .40565 L F
.20759 .41991 m .20785 .41906 L .17722 .40695 L F
.17741 .39949 m .1774 .39953 L .17555 .40578 L .595 .825 0 r
F
.20785 .41906 m .17744 .3994 L .17566 .40582 L F
.17744 .3994 m .17744 .39939 L .17566 .40582 L F
.17744 .3994 m .1751 .39807 L .17501 .39831 L 1 .931 0 r
F
.17744 .3994 m .17501 .39831 L .17266 .40467 L F
.17555 .40578 m .17559 .3982 L .17317 .4048 L .595 .825 0 r
F
.17744 .39939 m .17559 .3982 L .17555 .40578 L F
.21273 .42714 m .21478 .42067 L .17524 .40565 L 1 .927 0 r
F
.21273 .42714 m .17524 .40565 L .17514 .40606 L F
.20581 .42571 m .18242 .41073 L .17083 .41142 L 1 1 0 r
F
.18242 .41073 m .17495 .40629 L .17083 .41142 L F
.17514 .40606 m .17304 .40516 L .17083 .41142 L F
.14353 .38964 m .17304 .40516 L .14197 .3886 L .884 .072 0 r
F
.17304 .40516 m .1688 .40265 L .14197 .3886 L F
.17266 .40467 m .1751 .39807 L .1447 .38205 L 1 1 0 r
F
.17266 .40467 m .1447 .38205 L .14197 .3886 L F
.14353 .38964 m .17317 .4048 L .14238 .38872 L F
.17083 .41142 m .17292 .40552 L .14353 .38964 L F
.17083 .41142 m .14725 .3926 L .13976 .3953 L F
.14725 .3926 m .14342 .3898 L .13976 .3953 L F
.14353 .38964 m .14228 .38896 L .13976 .3953 L F
.11656 .37147 m .14228 .38896 L .14226 .38895 L .723 .049 0 r
F
.11656 .37147 m .14226 .38895 L .11582 .37089 L F
.13976 .3953 m .11656 .37147 L .11644 .37168 L 1 1 0 r
F
.13976 .3953 m .11644 .37168 L .12756 .38713 L F
.11656 .37147 m .11606 .37096 L .116 .37109 L F
.11656 .37147 m .116 .37109 L .1132 .37751 L F
.14228 .38896 m .13964 .38703 L .11582 .37089 L .723 .049 0 r
F
.14197 .3886 m .1447 .38205 L .11881 .36438 L 1 1 0 r
F
.14197 .3886 m .11881 .36438 L .11582 .37089 L F
.11656 .37147 m .14238 .38872 L .11606 .37096 L F
.13976 .3953 m .14215 .38928 L .11656 .37147 L F
.14215 .38928 m .14228 .38896 L .11656 .37147 L F
.15011 .39797 m .11656 .37147 L .12535 .381 L .723 .049 0 r
F
.11656 .37147 m .11582 .37089 L .11601 .37109 L F
.11656 .37147 m .11601 .37109 L .12535 .381 L F
.14228 .38896 m .14197 .3886 L .13964 .38703 L F
.14228 .38896 m .14238 .38872 L .11656 .37147 L 1 1 0 r
F
.15011 .39797 m .14228 .38896 L .11656 .37147 L .723 .049 0 r
F
.1447 .38205 m .1219 .35792 L .11881 .36438 L 1 1 0 r
F
.14238 .38872 m .11902 .36445 L .11606 .37096 L F
.11881 .36438 m .1219 .35792 L .10132 .33887 L F
.11881 .36438 m .1077 .34818 L .11844 .36378 L F
.11881 .36438 m .10672 .34469 L .1187 .36416 L F
.11582 .37089 m .11881 .36438 L .1187 .36416 L 1 .761 0 r
F
.11575 .37052 m .11865 .36426 L .0988 .34599 L 1 1 0 r
F
.11018 .36259 m .0988 .34599 L .09801 .34526 L F
.11575 .37052 m .0988 .34599 L .11018 .36259 L F
.11582 .37089 m .11786 .36612 L .11575 .37052 L 1 .761 0 r
F
.116 .37108 m .11572 .37069 L .11569 .37062 L 0 .02 0 r
F
.11601 .37109 m .11582 .37089 L .11572 .37069 L F
.11569 .37062 m .09801 .34526 L .09483 .35172 L 1 1 0 r
F
.11582 .37089 m .11575 .37052 L .11569 .37062 L 1 .761 0 r
F
.1157 .37063 m .11569 .37062 L .11569 .37062 L 1 1 0 r
F
.116 .37108 m .11569 .37062 L .11569 .37062 L 0 .02 0 r
F
.11575 .37052 m .11575 .37052 L .11569 .37062 L 1 .761 0 r
F
.11575 .37052 m .11018 .36259 L .1157 .37063 L 1 1 0 r
F
.11018 .36259 m .09801 .34526 L .11555 .37042 L F
.11018 .36259 m .11555 .37042 L .1157 .37063 L F
.11573 .37054 m .11564 .37035 L .11569 .37062 L 1 .761 0 r
F
.11575 .37052 m .11564 .37035 L .11573 .37054 L F
.11575 .37052 m .11867 .36423 L .11575 .37052 L F
.11786 .36612 m .11867 .36423 L .11575 .37052 L F
.11867 .36423 m .1187 .36416 L .11575 .37052 L F
.11897 .36456 m .1187 .36416 L .09801 .34526 L 1 1 0 r
F
.11844 .36378 m .10132 .33887 L .10672 .34469 L F
.1077 .34818 m .10132 .33887 L .11844 .36378 L F
.1219 .35792 m .12508 .35149 L .10474 .33252 L F
.1219 .35792 m .10474 .33252 L .10132 .33887 L F
.11902 .36445 m .11508 .34413 L .10672 .34469 L 1 .783 0 r
F
.11902 .36445 m .10672 .34469 L .1187 .36416 L F
.1187 .36416 m .10672 .34469 L .11195 .35032 L 1 1 0 r
F
.1187 .36416 m .10672 .34469 L .09801 .34526 L 1 .783 0 r
F
.11575 .37052 m .11195 .35032 L .11564 .37035 L 1 .761 0 r
F
.11569 .37062 m .11195 .35032 L .10874 .35648 L F
.11601 .37109 m .116 .37108 L .10874 .35648 L 0 .02 0 r
F
.116 .37108 m .11569 .37062 L .10874 .35648 L F
.116 .37108 m .11569 .37062 L .116 .37108 L F
.11569 .37062 m .11555 .37042 L .11569 .37062 L 1 1 0 r
F
.11555 .37042 m .09801 .34526 L .11569 .37062 L F
.11272 .37683 m .1157 .37063 L .11569 .37062 L F
.11241 .3764 m .11569 .37062 L .09483 .35172 L F
.11272 .37683 m .11569 .37062 L .11241 .3764 L F
.1132 .37751 m .11606 .37096 L .1157 .37063 L F
.1132 .37751 m .1157 .37063 L .11272 .37683 L F
.11606 .37096 m .11575 .37052 L .1157 .37063 L F
.10618 .3632 m .10874 .35648 L .10563 .36269 L 0 .02 0 r
F
.11575 .37052 m .1187 .36416 L .11201 .35043 L 1 .761 0 r
F
.11575 .37052 m .11201 .35043 L .11198 .35049 L F
.11606 .37096 m .11897 .36456 L .11865 .36426 L 1 1 0 r
F
.11606 .37096 m .11865 .36426 L .11575 .37052 L F
.12535 .381 m .11601 .37109 L .10874 .35648 L 0 .02 0 r
F
.12756 .38713 m .11644 .37168 L .1132 .37751 L 1 1 0 r
F
.12535 .381 m .10904 .35693 L .10618 .3632 L 0 .02 0 r
F
.10904 .35693 m .10874 .35648 L .10618 .3632 L F
.11198 .35049 m .11201 .35043 L .11195 .35032 L 1 .761 0 r
F
.11897 .36456 m .11902 .36445 L .1187 .36416 L 1 1 0 r
F
.14725 .3926 m .14353 .38964 L .14342 .3898 L F
.14353 .38964 m .14197 .3886 L .14228 .38896 L .884 .072 0 r
F
.14353 .38964 m .14238 .38872 L .14228 .38896 L 1 1 0 r
F
.14353 .38964 m .14228 .38896 L .14228 .38896 L .884 .072 0 r
F
.17941 .4134 m .14353 .38964 L .15011 .39797 L F
.14353 .38964 m .14228 .38896 L .15011 .39797 L F
.17292 .40552 m .17304 .40516 L .14353 .38964 L 1 1 0 r
F
.17304 .40516 m .17266 .40467 L .1688 .40265 L .884 .072 0 r
F
.17304 .40516 m .17317 .4048 L .14353 .38964 L 1 1 0 r
F
.17941 .4134 m .17304 .40516 L .14353 .38964 L .884 .072 0 r
F
.18242 .41073 m .17514 .40606 L .17495 .40629 L 1 1 0 r
F
.17514 .40606 m .17266 .40467 L .17304 .40516 L 1 .927 0 r
F
.17514 .40606 m .17317 .4048 L .17304 .40516 L 1 1 0 r
F
.17514 .40606 m .17304 .40516 L .17304 .40517 L 1 .927 0 r
F
.21273 .42714 m .17514 .40606 L .17941 .4134 L F
.17514 .40606 m .17304 .40517 L .17941 .4134 L F
.17513 .40606 m .17524 .40565 L .17317 .4048 L 1 1 0 r
F
.17741 .39949 m .17744 .39939 L .1774 .39953 L .595 .825 0 r
F
.21478 .42067 m .17744 .3994 L .17524 .40565 L 1 .931 0 r
F
.21478 .42067 m .17755 .39901 L .17744 .3994 L F
.17744 .3994 m .22073 .41523 L .17559 .3982 L .595 .825 0 r
F
.21611 .4166 m .21689 .41423 L .18072 .40086 L 1 .931 0 r
F
.21611 .4166 m .22073 .41523 L .17744 .3994 L .595 .825 0 r
F
.21478 .42067 m .21611 .4166 L .18072 .40086 L 1 .931 0 r
F
.21165 .40567 m .21393 .39907 L .18024 .38494 L 1 1 0 r
F
.21165 .40567 m .18024 .38494 L .17763 .39149 L F
.21393 .39907 m .21628 .39249 L .18292 .37841 L F
.21393 .39907 m .18292 .37841 L .18024 .38494 L F
.21907 .40781 m .22133 .40141 L .21123 .39715 L F
.21907 .40781 m .21123 .39715 L .20928 .40126 L F
.21628 .39249 m .18569 .37192 L .18292 .37841 L F
.211 .39705 m .18334 .37856 L .18068 .38508 L 1 .888 0 r
F
.2118 .395 m .18334 .37856 L .211 .39705 L F
.25875 .40669 m .2187 .38594 L .21628 .39249 L 1 .265 0 r
F
.21628 .39249 m .2187 .38594 L .18569 .37192 L 1 1 0 r
F
.2187 .38594 m .18853 .36546 L .18569 .37192 L F
.21378 .39085 m .18608 .37207 L .18334 .37856 L 1 .892 0 r
F
.21458 .38887 m .18608 .37207 L .21378 .39085 L F
.25499 .39807 m .22119 .37941 L .2187 .38594 L 1 1 0 r
F
.25875 .40669 m .25499 .39807 L .2187 .38594 L 1 .265 0 r
F
.29673 .41647 m .25499 .39807 L .25875 .40669 L 1 .864 0 r
F
.29673 .41647 m .29837 .40999 L .25499 .39807 L F
.29837 .40999 m .2571 .39149 L .25499 .39807 L 1 .867 0 r
F
.25499 .39807 m .2571 .39149 L .22119 .37941 L 1 1 0 r
F
.26076 .40027 m .2285 .38236 L .22604 .38868 L F
.33705 .42429 m .29837 .40999 L .29673 .41647 L 1 .92 0 r
F
.33743 .43141 m .33855 .42492 L .29904 .41732 L 1 .911 0 r
F
.33855 .42492 m .30056 .41089 L .29904 .41732 L 1 .917 0 r
F
.22659 .3889 m .26076 .40027 L .22604 .38868 L .31 0 0 r
F
.29904 .41732 m .2644 .40171 L .26174 .40773 L 1 .96 0 r
F
.2644 .40171 m .26358 .40143 L .26174 .40773 L F
.29837 .40999 m .30005 .40353 L .2571 .39149 L 1 .867 0 r
F
.26409 .40148 m .26284 .39387 L .26076 .40027 L .455 .082 0 r
F
.26428 .40162 m .30056 .41089 L .26409 .40148 L 1 .96 0 r
F
.2644 .40171 m .26963 .40304 L .26428 .40162 L F
.26963 .40304 m .30056 .41089 L .26428 .40162 L F
.29904 .41732 m .29989 .41373 L .2644 .40171 L F
.29989 .41373 m .30056 .41089 L .2644 .40171 L F
.38558 .44906 m .26407 .40156 L .36942 .44512 L .459 .083 0 r
F
.2644 .40171 m .26407 .40156 L .26358 .40143 L 1 .96 0 r
F
.26407 .40156 m .26404 .40155 L .26358 .40143 L .459 .083 0 r
F
.26404 .40155 m .26076 .40027 L .26358 .40143 L F
.22661 .38891 m .26358 .40143 L .22659 .3889 L .31 0 0 r
F
.26174 .40773 m .26358 .40143 L .23863 .39505 L 1 1 0 r
F
.22958 .39008 m .26358 .40143 L .22661 .38891 L .31 0 0 r
F
.38558 .44906 m .38642 .44589 L .26409 .40148 L .459 .083 0 r
F
.26407 .40156 m .26409 .40148 L .26076 .40027 L F
.26588 .39515 m .26284 .39387 L .26409 .40148 L .455 .082 0 r
F
.33705 .42429 m .33831 .41776 L .29837 .40999 L 1 .92 0 r
F
.33831 .41776 m .30005 .40353 L .29837 .40999 L 1 .926 0 r
F
.33855 .42492 m .33972 .41843 L .30056 .41089 L 1 .917 0 r
F
.33972 .41843 m .30213 .40446 L .30056 .41089 L 1 .923 0 r
F
.30056 .41089 m .30213 .40446 L .26601 .39511 L 1 .967 0 r
F
.26599 .39519 m .26601 .39511 L .26601 .39511 L F
.26599 .39519 m .26601 .39511 L .26601 .39511 L .455 .082 0 r
F
.26599 .39519 m .26601 .39511 L .26284 .39387 L F
.30005 .40353 m .25927 .38492 L .2571 .39149 L 1 .87 0 r
F
.30005 .40353 m .30179 .39709 L .25927 .38492 L F
.26601 .39511 m .26497 .38749 L .26284 .39387 L .452 .08 0 r
F
.33831 .41776 m .3396 .41125 L .30005 .40353 L 1 .926 0 r
F
.3396 .41125 m .30179 .39709 L .30005 .40353 L 1 .931 0 r
F
.30213 .40446 m .26796 .38884 L .26601 .39511 L 1 .973 0 r
F
.30056 .41089 m .26601 .39511 L .26599 .39519 L 1 .967 0 r
F
.33972 .41843 m .34094 .41196 L .30213 .40446 L 1 .923 0 r
F
.34094 .41196 m .30375 .39805 L .30213 .40446 L 1 .929 0 r
F
.30213 .40446 m .30375 .39805 L .26838 .38887 L 1 .973 0 r
F
.3396 .41125 m .34092 .40475 L .30179 .39709 L 1 .931 0 r
F
.34092 .40475 m .30357 .39066 L .30179 .39709 L 1 .936 0 r
F
.34094 .41196 m .34219 .40549 L .30375 .39805 L 1 .929 0 r
F
.34219 .40549 m .30543 .39166 L .30375 .39805 L 1 .935 0 r
F
.30179 .39709 m .2615 .37839 L .25927 .38492 L 1 .874 0 r
F
.30179 .39709 m .30357 .39066 L .2615 .37839 L F
.26798 .38877 m .26717 .38114 L .26497 .38749 L .448 .078 0 r
F
.26838 .38887 m .26898 .38569 L .26798 .38877 L 1 .979 0 r
F
.30375 .39805 m .27001 .38252 L .26838 .38887 L F
.27001 .38252 m .26717 .38114 L .26798 .38877 L .448 .078 0 r
F
.27001 .38252 m .26961 .38233 L .26838 .38887 L 1 .979 0 r
F
.26837 .38894 m .26838 .38887 L .26799 .38877 L 1 .973 0 r
F
.30213 .40446 m .26838 .38887 L .26837 .38894 L F
.30213 .40446 m .26799 .38877 L .26796 .38884 L F
.38818 .43959 m .27001 .38252 L .26798 .38877 L .448 .078 0 r
F
.38729 .44274 m .38818 .43959 L .26798 .38877 L .452 .08 0 r
F
.26796 .38884 m .26798 .38877 L .26497 .38749 L F
.26796 .38884 m .26799 .38877 L .26798 .38877 L 1 .973 0 r
F
.38729 .44274 m .26798 .38877 L .26796 .38884 L .452 .08 0 r
F
.26796 .38884 m .26798 .38877 L .26754 .38865 L 1 .973 0 r
F
.26798 .38877 m .26961 .38233 L .26754 .38865 L 1 .979 0 r
F
.26898 .38569 m .26961 .38233 L .26798 .38877 L F
.30375 .39805 m .30543 .39166 L .27003 .38244 L F
.27001 .38252 m .26993 .3824 L .26991 .38247 L .448 .078 0 r
F
.27003 .38245 m .26993 .3824 L .27001 .38252 L F
.26991 .38247 m .26993 .3824 L .26717 .38114 L F
.27001 .38252 m .27003 .38244 L .26961 .38233 L 1 .979 0 r
F
.30375 .39805 m .27003 .38244 L .27001 .38252 L F
.38818 .43959 m .27003 .38245 L .27001 .38252 L .448 .078 0 r
F
.38818 .43959 m .3891 .43646 L .27003 .38244 L F
.27003 .38244 m .27003 .38244 L .26993 .3824 L F
.30357 .39066 m .26379 .37187 L .2615 .37839 L 1 .403 0 r
F
.27003 .38244 m .26941 .37482 L .26717 .38114 L .478 0 0 r
F
.30543 .39166 m .27212 .37621 L .27003 .38244 L 1 .985 0 r
F
.3891 .43646 m .27212 .37621 L .27003 .38244 L .478 0 0 r
F
.27212 .37621 m .26941 .37482 L .27003 .38244 L F
.27212 .37621 m .27175 .37604 L .27003 .38244 L 1 .985 0 r
F
.27003 .38244 m .27174 .37604 L .26961 .38233 L F
.27175 .37604 m .27174 .37604 L .27003 .38244 L F
.27003 .38245 m .27003 .38244 L .27003 .38244 L .448 .078 0 r
F
.38818 .43959 m .27003 .38244 L .27003 .38245 L F
.26604 .39512 m .26796 .38884 L .26601 .39511 L .452 .08 0 r
F
.38729 .44274 m .26796 .38884 L .26604 .39512 L F
.26796 .38884 m .26497 .38749 L .26601 .39511 L F
.26796 .38884 m .26761 .38868 L .26601 .39511 L 1 .973 0 r
F
.26601 .39511 m .26754 .38865 L .26554 .39499 L F
.26761 .38868 m .26754 .38865 L .26601 .39511 L F
.26599 .39519 m .26601 .39511 L .26599 .39519 L .455 .082 0 r
F
.26599 .39519 m .26601 .39511 L .26554 .39499 L 1 .967 0 r
F
.26447 .40157 m .26507 .39823 L .26409 .40148 L F
.26453 .40004 m .26588 .39515 L .26409 .40148 L .455 .082 0 r
F
.26507 .39823 m .26564 .39504 L .26409 .40148 L 1 .967 0 r
F
.26412 .40149 m .26453 .40004 L .26409 .40148 L .455 .082 0 r
F
.30056 .41089 m .26599 .39519 L .26447 .40157 L 1 .967 0 r
F
.26599 .39519 m .26588 .39515 L .26453 .40004 L .455 .082 0 r
F
.26599 .39519 m .26564 .39504 L .26507 .39823 L 1 .967 0 r
F
.26599 .39519 m .26507 .39823 L .26447 .40157 L F
.26599 .39519 m .26453 .40004 L .26412 .40149 L .455 .082 0 r
F
.38642 .44589 m .26599 .39519 L .26412 .40149 L F
.38642 .44589 m .38729 .44274 L .26601 .39511 L F
.38642 .44589 m .26601 .39511 L .26599 .39519 L F
.26409 .40148 m .26554 .39499 L .26361 .40135 L 1 .967 0 r
F
.26564 .39504 m .26554 .39499 L .26409 .40148 L F
.26407 .40156 m .26409 .40148 L .26407 .40156 L .459 .083 0 r
F
.2644 .40171 m .26409 .40148 L .26407 .40156 L 1 .96 0 r
F
.38558 .44906 m .26409 .40148 L .26407 .40156 L .459 .083 0 r
F
.26407 .40156 m .26409 .40148 L .26407 .40156 L 1 .96 0 r
F
.26358 .40143 m .26361 .40135 L .26252 .40108 L 1 1 0 r
F
.26358 .40143 m .26252 .40108 L .23863 .39505 L F
.26358 .40143 m .26358 .40143 L .22661 .38891 L .31 0 0 r
F
.26358 .40143 m .26358 .40143 L .26358 .40143 L F
.36942 .44512 m .26358 .40143 L .26358 .40143 L F
.23863 .39505 m .26252 .40108 L .22958 .39008 L 1 1 0 r
F
.36942 .44512 m .26358 .40143 L .22958 .39008 L .31 0 0 r
F
.26358 .40143 m .26076 .40027 L .22659 .3889 L F
.22958 .39008 m .26361 .40135 L .22919 .38987 L 1 1 0 r
F
.26252 .40108 m .26361 .40135 L .22958 .39008 L F
.26407 .40156 m .26361 .40135 L .26358 .40143 L 1 .96 0 r
F
.26407 .40156 m .26358 .40143 L .26358 .40143 L .459 .083 0 r
F
.26407 .40156 m .26358 .40143 L .36942 .44512 L F
.26407 .40156 m .26409 .40148 L .26361 .40135 L 1 .96 0 r
F
.2187 .38594 m .22119 .37941 L .18853 .36546 L 1 1 0 r
F
.22119 .37941 m .19145 .35903 L .18853 .36546 L F
.21661 .38467 m .1889 .36561 L .18608 .37207 L 1 .896 0 r
F
.21741 .38277 m .1889 .36561 L .21661 .38467 L F
.2571 .39149 m .22374 .37291 L .22119 .37941 L 1 1 0 r
F
.26076 .40027 m .26284 .39387 L .2285 .38236 L F
.2571 .39149 m .25927 .38492 L .22374 .37291 L F
.26284 .39387 m .23102 .37607 L .2285 .38236 L F
.22119 .37941 m .22374 .37291 L .19145 .35903 L F
.22604 .38868 m .2285 .38236 L .2197 .3786 L F
.22604 .38868 m .2197 .3786 L .21965 .37869 L F
.22604 .38868 m .21956 .37854 L .21954 .37858 L F
.22604 .38868 m .2195 .37852 L .21752 .38284 L F
.22604 .38868 m .21752 .38284 L .21661 .38467 L F
.22365 .39503 m .22604 .38868 L .21682 .38476 L F
.22365 .39503 m .21682 .38476 L .21677 .38487 L F
.22365 .39503 m .21664 .38469 L .21664 .38471 L F
.22365 .39503 m .21661 .38467 L .21479 .389 L F
.22365 .39503 m .21469 .38894 L .21378 .39085 L F
.22133 .40141 m .22365 .39503 L .214 .39095 L F
.22133 .40141 m .214 .39095 L .21394 .39107 L F
.22133 .40141 m .21379 .39086 L .21378 .39086 L F
.22133 .40141 m .21378 .39085 L .21203 .39514 L F
.22133 .40141 m .21192 .39507 L .211 .39705 L F
.20968 .40041 m .21123 .39715 L .211 .39705 L F
.22273 .40886 m .22481 .40251 L .21103 .39707 L 1 .883 0 r
F
.20928 .40126 m .20968 .40041 L .20958 .40035 L 1 1 0 r
F
.20907 .40113 m .21064 .39789 L .18068 .38508 L 1 .883 0 r
F
.21064 .39789 m .211 .39705 L .18068 .38508 L F
.20928 .40126 m .20958 .40035 L .2092 .40121 L 1 1 0 r
F
.20968 .40041 m .211 .39705 L .20958 .40035 L F
.22273 .40886 m .21103 .39707 L .21064 .39789 L 1 .883 0 r
F
.2092 .40121 m .21064 .39789 L .20907 .40113 L F
.22273 .40886 m .21064 .39789 L .2092 .40121 L F
.20958 .40035 m .211 .39705 L .1893 .38791 L 1 1 0 r
F
.2092 .40121 m .20958 .40035 L .1893 .38791 L F
.21064 .39789 m .21103 .39707 L .211 .39705 L 1 .883 0 r
F
.21394 .39107 m .214 .39095 L .21379 .39086 L 1 1 0 r
F
.21378 .39086 m .21379 .39086 L .21378 .39085 L F
.21103 .39707 m .21192 .39507 L .211 .39705 L 1 .888 0 r
F
.21178 .39499 m .2134 .3917 L .18334 .37856 L F
.2134 .3917 m .21378 .39085 L .18334 .37856 L F
.21203 .39514 m .21378 .39085 L .21192 .39507 L 1 1 0 r
F
.22481 .40251 m .21381 .39087 L .21178 .39499 L 1 .888 0 r
F
.21192 .39507 m .21378 .39085 L .19197 .38161 L 1 1 0 r
F
.2134 .3917 m .21381 .39087 L .21378 .39085 L 1 .888 0 r
F
.22481 .40251 m .21192 .39507 L .21103 .39707 L F
.2274 .39632 m .22604 .38868 L .22365 .39503 L .31 0 0 r
F
.26174 .40773 m .22958 .39008 L .2274 .39632 L 1 1 0 r
F
.36942 .44512 m .22958 .39008 L .2274 .39632 L .31 0 0 r
F
.22958 .39008 m .22604 .38868 L .2274 .39632 L F
.2274 .39632 m .22919 .38987 L .22696 .39618 L 1 1 0 r
F
.22958 .39008 m .22919 .38987 L .2274 .39632 L F
.22481 .40251 m .22696 .39618 L .21381 .39087 L 1 .888 0 r
F
.21677 .38487 m .21682 .38476 L .21664 .38469 L 1 1 0 r
F
.21664 .38471 m .21664 .38469 L .21661 .38467 L F
.21381 .39087 m .21469 .38894 L .21378 .39085 L 1 .892 0 r
F
.21456 .38886 m .21622 .38554 L .18608 .37207 L F
.21622 .38554 m .21661 .38467 L .18608 .37207 L F
.21479 .389 m .21661 .38467 L .21469 .38894 L 1 1 0 r
F
.22696 .39618 m .21665 .38469 L .21456 .38886 L 1 .892 0 r
F
.21469 .38894 m .21661 .38467 L .19471 .37535 L 1 1 0 r
F
.21622 .38554 m .21665 .38469 L .21661 .38467 L 1 .892 0 r
F
.22696 .39618 m .21469 .38894 L .21381 .39087 L F
.22696 .39618 m .22919 .38987 L .21665 .38469 L F
.21965 .37869 m .2197 .3786 L .21956 .37854 L 1 1 0 r
F
.21954 .37858 m .21956 .37854 L .2195 .37852 L F
.21665 .38469 m .21752 .38284 L .21661 .38467 L 1 .896 0 r
F
.22919 .38987 m .21752 .38284 L .21665 .38469 L F
.2195 .37852 m .1918 .35918 L .1889 .36561 L 1 .899 0 r
F
.2204 .37676 m .1918 .35918 L .2195 .37852 L F
.26284 .39387 m .26497 .38749 L .23102 .37607 L 1 1 0 r
F
.2285 .38236 m .23102 .37607 L .22263 .37247 L F
.2285 .38236 m .22263 .37247 L .22259 .37254 L F
.2285 .38236 m .22252 .37242 L .2225 .37248 L F
.2285 .38236 m .22244 .37239 L .2204 .37676 L F
.2285 .38236 m .2204 .37676 L .2195 .37852 L F
.22919 .38987 m .2315 .38358 L .21954 .37853 L 1 .896 0 r
F
.21953 .37855 m .21954 .37853 L .2195 .37852 L F
.22919 .38987 m .21954 .37853 L .21953 .37855 L F
.22259 .37254 m .22263 .37247 L .22252 .37242 L 1 1 0 r
F
.2225 .37248 m .22252 .37242 L .22244 .37239 L F
.21954 .37853 m .2204 .37676 L .2195 .37852 L 1 .899 0 r
F
.2315 .38358 m .2204 .37676 L .21954 .37853 L F
.2315 .38358 m .23388 .37732 L .22244 .37239 L F
.22013 .37659 m .22244 .37239 L .1918 .35918 L F
.22374 .37291 m .19445 .35264 L .19145 .35903 L 1 1 0 r
F
.22374 .37291 m .22636 .36644 L .19445 .35264 L F
.25927 .38492 m .22636 .36644 L .22374 .37291 L F
.23102 .37607 m .22336 .37071 L .22244 .37239 L F
.22244 .37239 m .19478 .35279 L .1918 .35918 L 1 .902 0 r
F
.22336 .37071 m .22334 .3707 L .22244 .37239 L 1 1 0 r
F
.25927 .38492 m .2615 .37839 L .22636 .36644 L F
.26497 .38749 m .23361 .36981 L .23102 .37607 L F
.23102 .37607 m .23361 .36981 L .22554 .36633 L F
.22334 .3707 m .22381 .36977 L .22543 .36628 L F
.22381 .36977 m .22554 .36633 L .22543 .36628 L F
.22636 .36644 m .19752 .34628 L .19445 .35264 L F
.22636 .36644 m .22906 .35999 L .19752 .34628 L F
.22543 .36628 m .19783 .34643 L .19478 .35279 L 1 .905 0 r
F
.2615 .37839 m .22906 .35999 L .22636 .36644 L 1 1 0 r
F
.26497 .38749 m .26717 .38114 L .23361 .36981 L F
.2615 .37839 m .26379 .37187 L .22906 .35999 L F
.26717 .38114 m .23627 .36358 L .23361 .36981 L F
.22622 .3646 m .19783 .34643 L .22543 .36628 L 1 .905 0 r
F
.22334 .3707 m .22543 .36628 L .19478 .35279 L 1 .902 0 r
F
.26717 .38114 m .26941 .37482 L .23627 .36358 L 1 1 0 r
F
.26379 .37187 m .23181 .35358 L .22906 .35999 L F
.30119 .38182 m .26613 .36539 L .26379 .37187 L 1 .984 0 r
F
.30357 .39066 m .30119 .38182 L .26379 .37187 L 1 .403 0 r
F
.26379 .37187 m .26613 .36539 L .23181 .35358 L 1 1 0 r
F
.26941 .37482 m .23899 .35739 L .23627 .36358 L F
.22906 .35999 m .20067 .33996 L .19752 .34628 L F
.22906 .35999 m .23181 .35358 L .20067 .33996 L F
.21768 .35035 m .2096 .3446 L .20894 .34589 L F
.23181 .35358 m .20389 .33368 L .20067 .33996 L F
.2179 .35042 m .21343 .34627 L .2096 .3446 L F
.26613 .36539 m .23464 .3472 L .23181 .35358 L F
.23181 .35358 m .23464 .3472 L .20389 .33368 L F
.23899 .35739 m .23243 .35267 L .21028 .34334 L F
.23899 .35739 m .21028 .34334 L .21343 .34627 L F
.2179 .35042 m .23899 .35739 L .21343 .34627 L F
.23762 .36052 m .23899 .35739 L .21768 .35035 L F
.26941 .37482 m .27171 .36852 L .23899 .35739 L F
.30119 .38182 m .3031 .37527 L .26613 .36539 L 1 .984 0 r
F
.3031 .37527 m .26853 .35893 L .26613 .36539 L 1 .988 0 r
F
.26613 .36539 m .26853 .35893 L .23464 .3472 L 1 1 0 r
F
.27171 .36852 m .24178 .35123 L .23899 .35739 L F
.23899 .35739 m .24178 .35123 L .2347 .34814 L F
.23213 .35247 m .2347 .34814 L .20417 .33383 L 1 .91 0 r
F
.23243 .35267 m .2347 .34814 L .23213 .35247 L F
.23464 .3472 m .20719 .32743 L .20389 .33368 L 1 1 0 r
F
.23464 .3472 m .23752 .34086 L .20719 .32743 L F
.2347 .34814 m .20745 .32758 L .20417 .33383 L 1 .911 0 r
F
.26853 .35893 m .23752 .34086 L .23464 .3472 L 1 1 0 r
F
.24178 .35123 m .23556 .34672 L .2347 .34814 L F
.27171 .36852 m .27407 .36225 L .24178 .35123 L F
.27407 .36225 m .24464 .34511 L .24178 .35123 L F
.24178 .35123 m .24464 .34511 L .2381 .34224 L F
.23556 .34672 m .2381 .34224 L .23788 .34215 L F
.24178 .35123 m .2381 .34224 L .23556 .34672 L F
.24416 .35257 m .24692 .34647 L .23788 .34215 L 1 .911 0 r
F
.23525 .34651 m .23788 .34215 L .20745 .32758 L F
.23752 .34086 m .21056 .32123 L .20719 .32743 L 1 1 0 r
F
.23752 .34086 m .24048 .33455 L .21056 .32123 L F
.23788 .34215 m .21081 .32138 L .20745 .32758 L 1 .913 0 r
F
.26853 .35893 m .27099 .3525 L .23752 .34086 L 1 1 0 r
F
.27099 .3525 m .24048 .33455 L .23752 .34086 L F
.24464 .34511 m .23873 .34078 L .23788 .34215 L F
.3031 .37527 m .30506 .36875 L .26853 .35893 L 1 .988 0 r
F
.30506 .36875 m .27099 .3525 L .26853 .35893 L 1 .993 0 r
F
.27407 .36225 m .27649 .35601 L .24464 .34511 L 1 1 0 r
F
.27649 .35601 m .24756 .33903 L .24464 .34511 L F
.24464 .34511 m .24756 .33903 L .24135 .3363 L F
.23873 .34078 m .24135 .3363 L .24111 .33619 L F
.24464 .34511 m .24135 .3363 L .23873 .34078 L F
.24692 .34647 m .24975 .34041 L .24111 .33619 L 1 .913 0 r
F
.23842 .34056 m .24111 .33619 L .21081 .32138 L F
.24048 .33455 m .214 .31508 L .21056 .32123 L 1 1 0 r
F
.24048 .33455 m .2435 .32828 L .214 .31508 L F
.2735 .3461 m .2435 .32828 L .24048 .33455 L F
.24195 .33488 m .24378 .32847 L .21424 .31523 L 1 .214 0 r
F
.27099 .3525 m .2735 .3461 L .24048 .33455 L 1 1 0 r
F
.30506 .36875 m .30706 .36225 L .27099 .3525 L 1 .993 0 r
F
.30706 .36225 m .2735 .3461 L .27099 .3525 L 1 .997 0 r
F
.27649 .35601 m .27895 .3498 L .27094 .34705 L 1 1 0 r
F
.2691 .35167 m .27094 .34705 L .24756 .33903 L F
.27649 .35601 m .27094 .34705 L .2691 .35167 L F
.30706 .36225 m .30911 .35577 L .2735 .3461 L 1 .997 0 r
F
.30911 .35577 m .27606 .33973 L .2735 .3461 L 1 1 0 r
F
.34658 .37893 m .30706 .36225 L .30506 .36875 L 1 .849 0 r
F
.31114 .36518 m .27895 .3498 L .27649 .35601 L 1 1 0 r
F
.34658 .37893 m .34808 .37252 L .30706 .36225 L 1 .849 0 r
F
.34808 .37252 m .30911 .35577 L .30706 .36225 L 1 .852 0 r
F
.31114 .36518 m .31314 .35887 L .27895 .3498 L 1 1 0 r
F
.31314 .35887 m .28147 .34363 L .27895 .3498 L F
.2735 .3461 m .27606 .33973 L .2435 .32828 L F
.30911 .35577 m .3112 .34932 L .27606 .33973 L F
.3112 .34932 m .27868 .33339 L .27606 .33973 L F
.34808 .37252 m .34961 .36613 L .30911 .35577 L 1 .852 0 r
F
.34961 .36613 m .3112 .34932 L .30911 .35577 L 1 .855 0 r
F
.31314 .35887 m .31519 .35259 L .28147 .34363 L 1 1 0 r
F
.31519 .35259 m .28405 .33749 L .28147 .34363 L F
.27606 .33973 m .27868 .33339 L .24658 .32205 L F
.3112 .34932 m .31334 .3429 L .27868 .33339 L F
.31334 .3429 m .28136 .32709 L .27868 .33339 L F
.34961 .36613 m .35118 .35976 L .3112 .34932 L 1 .855 0 r
F
.35118 .35976 m .31334 .3429 L .3112 .34932 L 1 .519 0 r
F
.31519 .35259 m .31729 .34634 L .28405 .33749 L 1 1 0 r
F
.31729 .34634 m .28668 .33139 L .28405 .33749 L F
.27868 .33339 m .28136 .32709 L .24972 .31585 L F
.31334 .3429 m .31552 .33651 L .28136 .32709 L F
.31552 .33651 m .28409 .32083 L .28136 .32709 L F
.35005 .35049 m .31552 .33651 L .31334 .3429 L 1 .966 0 r
F
.35118 .35976 m .35005 .35049 L .31334 .3429 L 1 .519 0 r
F
.31729 .34634 m .31942 .34012 L .28668 .33139 L 1 1 0 r
F
.31942 .34012 m .28936 .32532 L .28668 .33139 L F
.28136 .32709 m .28409 .32083 L .25293 .3097 L F
.31552 .33651 m .31775 .33015 L .28409 .32083 L F
.31775 .33015 m .28687 .3146 L .28409 .32083 L F
.35005 .35049 m .35172 .34403 L .31552 .33651 L 1 .966 0 r
F
.35172 .34403 m .31775 .33015 L .31552 .33651 L 1 .971 0 r
F
.31942 .34012 m .3216 .33392 L .28936 .32532 L 1 1 0 r
F
.3216 .33392 m .29209 .31929 L .28936 .32532 L F
.28409 .32083 m .28687 .3146 L .2562 .30359 L F
.28936 .32532 m .29209 .31929 L .28553 .31702 L F
.28542 .31721 m .28553 .31702 L .28523 .31688 L 1 .885 0 r
F
.28543 .31723 m .28553 .31702 L .28542 .31721 L F
.28409 .32083 m .2562 .30359 L .25293 .3097 L 1 1 0 r
F
.28323 .32157 m .28523 .31688 L .25645 .30379 L 1 .885 0 r
F
.28936 .32532 m .28553 .31702 L .28333 .32163 L 1 1 0 r
F
.28668 .33139 m .28936 .32532 L .28263 .32299 L F
.28333 .32163 m .28523 .31688 L .28323 .32157 L 1 .885 0 r
F
.28936 .32532 m .28333 .32163 L .28263 .32299 L 1 1 0 r
F
.29102 .32674 m .28554 .31741 L .28333 .32163 L 1 .885 0 r
F
.28554 .31741 m .28523 .31688 L .28333 .32163 L F
.28136 .32709 m .25293 .3097 L .24972 .31585 L 1 1 0 r
F
.28004 .32734 m .28223 .32282 L .25319 .3099 L 1 .885 0 r
F
.28027 .3275 m .28116 .32538 L .28004 .32734 L F
.28116 .32538 m .28223 .32282 L .28004 .32734 L F
.28668 .33139 m .28263 .32299 L .28259 .32307 L 1 1 0 r
F
.28668 .33139 m .28254 .32296 L .28038 .32756 L F
.28405 .33749 m .28668 .33139 L .27966 .32896 L F
.28038 .32756 m .28223 .32282 L .28027 .3275 L 1 .885 0 r
F
.28668 .33139 m .28038 .32756 L .27966 .32896 L 1 1 0 r
F
.2884 .33278 m .28255 .32333 L .28038 .32756 L 1 .885 0 r
F
.28255 .32333 m .28223 .32282 L .28038 .32756 L F
.27868 .33339 m .24972 .31585 L .24658 .32205 L 1 1 0 r
F
.27712 .33331 m .27926 .3288 L .24999 .31605 L 1 .884 0 r
F
.27734 .33345 m .27819 .3314 L .27712 .33331 L F
.27819 .3314 m .27926 .3288 L .27712 .33331 L F
.28405 .33749 m .27966 .32896 L .27963 .32903 L 1 1 0 r
F
.28405 .33749 m .27957 .32893 L .27745 .33352 L F
.28147 .34363 m .28405 .33749 L .27672 .33496 L F
.27745 .33352 m .27926 .3288 L .27734 .33345 L 1 .884 0 r
F
.28405 .33749 m .27745 .33352 L .27672 .33496 L 1 1 0 r
F
.28584 .33885 m .27958 .32929 L .27745 .33352 L 1 .884 0 r
F
.27958 .32929 m .27926 .3288 L .27745 .33352 L F
.27606 .33973 m .24658 .32205 L .2435 .32828 L 1 1 0 r
F
.27423 .3393 m .27633 .3348 L .24685 .32224 L 1 .882 0 r
F
.27445 .33943 m .27526 .33745 L .27423 .3393 L F
.27526 .33745 m .27633 .3348 L .27423 .3393 L F
.28147 .34363 m .27672 .33496 L .27669 .33503 L 1 1 0 r
F
.28147 .34363 m .27664 .33494 L .27456 .3395 L F
.27895 .3498 m .28147 .34363 L .27382 .34099 L F
.27456 .3395 m .27633 .3348 L .27445 .33943 L 1 .882 0 r
F
.28147 .34363 m .27456 .3395 L .27382 .34099 L 1 1 0 r
F
.28334 .34497 m .27665 .33527 L .27456 .3395 L 1 .882 0 r
F
.27665 .33527 m .27633 .3348 L .27456 .3395 L F
.27138 .34531 m .27343 .34084 L .24378 .32847 L 1 .881 0 r
F
.27159 .34544 m .27235 .34352 L .27138 .34531 L F
.27235 .34352 m .27343 .34084 L .27138 .34531 L F
.27895 .3498 m .27382 .34099 L .27379 .34105 L 1 1 0 r
F
.27895 .3498 m .27374 .34097 L .2717 .34551 L F
.2717 .34551 m .27343 .34084 L .27159 .34544 L 1 .881 0 r
F
.27895 .3498 m .2717 .34551 L .27094 .34705 L 1 1 0 r
F
.28089 .35112 m .27375 .34129 L .2717 .34551 L 1 .881 0 r
F
.27375 .34129 m .27343 .34084 L .2717 .34551 L F
.2483 .33752 m .24378 .32847 L .24208 .33443 L 1 .214 0 r
F
.2483 .33752 m .24208 .33443 L .24195 .33488 L F
.26617 .34213 m .24378 .32847 L .2483 .33752 L 1 .881 0 r
F
.24756 .33903 m .24195 .33488 L .24111 .33619 L 1 1 0 r
F
.24195 .33488 m .21424 .31523 L .24115 .33621 L 1 .214 0 r
F
.24195 .33488 m .24192 .33486 L .24111 .33619 L 1 1 0 r
F
.24111 .33619 m .21424 .31523 L .21081 .32138 L 1 .214 0 r
F
.24115 .33621 m .24111 .33618 L .24111 .33619 L F
.24111 .33618 m .21424 .31523 L .24111 .33619 L F
.24402 .33641 m .25054 .33299 L .24465 .33038 L 1 1 0 r
F
.24402 .33641 m .24465 .33038 L .24195 .33488 L F
.24756 .33903 m .2483 .33752 L .24402 .33641 L F
.2483 .33752 m .25054 .33299 L .24402 .33641 L F
.25987 .34325 m .2483 .33752 L .24756 .33903 L F
.24975 .34041 m .24195 .33488 L .24115 .33621 L 1 .214 0 r
F
.24195 .33488 m .24465 .33038 L .22288 .32078 L 1 1 0 r
F
.27094 .34705 m .26576 .34348 L .2483 .33752 L F
.2717 .34551 m .26617 .34213 L .25989 .34148 L 1 .881 0 r
F
.27094 .34705 m .2483 .33752 L .25987 .34325 L 1 1 0 r
F
.25989 .34148 m .2483 .33752 L .24975 .34041 L 1 .881 0 r
F
.26617 .34213 m .2483 .33752 L .25989 .34148 L F
.2717 .34551 m .25054 .33299 L .26576 .34348 L 1 1 0 r
F
.2717 .34551 m .26576 .34348 L .27094 .34705 L F
.26576 .34348 m .25054 .33299 L .2483 .33752 L F
.28089 .35112 m .2717 .34551 L .24975 .34041 L 1 .881 0 r
F
.2717 .34551 m .25989 .34148 L .24975 .34041 L F
.24831 .33753 m .2483 .33752 L .24195 .33488 L 1 .214 0 r
F
.27374 .34097 m .24685 .32224 L .24378 .32847 L 1 .882 0 r
F
.27382 .34099 m .27375 .34095 L .27374 .34097 L 1 1 0 r
F
.27456 .3395 m .24685 .32224 L .27374 .34097 L 1 .882 0 r
F
.27456 .3395 m .25359 .32699 L .27382 .34099 L 1 1 0 r
F
.28334 .34497 m .27456 .3395 L .27374 .34097 L 1 .882 0 r
F
.27375 .34095 m .27375 .34095 L .27374 .34097 L 1 1 0 r
F
.27374 .34097 m .25359 .32699 L .25054 .33299 L F
.27375 .34095 m .25359 .32699 L .27374 .34097 L F
.27664 .33494 m .24999 .31605 L .24685 .32224 L 1 .884 0 r
F
.27672 .33496 m .27665 .33492 L .27664 .33494 L 1 1 0 r
F
.27745 .33352 m .24999 .31605 L .27664 .33494 L 1 .884 0 r
F
.27745 .33352 m .2567 .32103 L .27672 .33496 L 1 1 0 r
F
.28584 .33885 m .27745 .33352 L .27664 .33494 L 1 .884 0 r
F
.27665 .33492 m .27665 .33492 L .27664 .33494 L 1 1 0 r
F
.27664 .33494 m .2567 .32103 L .25359 .32699 L F
.27665 .33492 m .2567 .32103 L .27664 .33494 L F
.27957 .32893 m .25319 .3099 L .24999 .31605 L 1 .885 0 r
F
.27966 .32896 m .27959 .32891 L .27957 .32893 L 1 1 0 r
F
.28038 .32756 m .25319 .3099 L .27957 .32893 L 1 .885 0 r
F
.28038 .32756 m .25987 .31512 L .27966 .32896 L 1 1 0 r
F
.2884 .33278 m .28038 .32756 L .27957 .32893 L 1 .885 0 r
F
.27959 .32891 m .27959 .32891 L .27957 .32893 L 1 1 0 r
F
.27957 .32893 m .25987 .31512 L .2567 .32103 L F
.27959 .32891 m .25987 .31512 L .27957 .32893 L F
.28254 .32296 m .25645 .30379 L .25319 .3099 L 1 .885 0 r
F
.28263 .32299 m .28255 .32294 L .28254 .32296 L 1 1 0 r
F
.28333 .32163 m .25645 .30379 L .28254 .32296 L 1 .885 0 r
F
.28333 .32163 m .2631 .30926 L .28263 .32299 L 1 1 0 r
F
.29102 .32674 m .28333 .32163 L .28254 .32296 L 1 .885 0 r
F
.28255 .32294 m .28255 .32294 L .28254 .32296 L 1 1 0 r
F
.28254 .32296 m .2631 .30926 L .25987 .31512 L F
.28255 .32294 m .2631 .30926 L .28254 .32296 L F
.28687 .3146 m .25953 .29752 L .2562 .30359 L F
.28508 .31682 m .25978 .29773 L .25645 .30379 L 1 .422 0 r
F
.28514 .31673 m .25978 .29773 L .28508 .31682 L F
.28632 .31574 m .25978 .29773 L .28553 .31702 L F
.32002 .32383 m .28971 .3084 L .28687 .3146 L 1 1 0 r
F
.28687 .3146 m .28971 .3084 L .25953 .29752 L F
.28971 .3084 m .26292 .2915 L .25953 .29752 L F
.28993 .30862 m .26316 .29172 L .25978 .29773 L F
.29209 .31929 m .28632 .31574 L .28553 .31702 L F
.31775 .33015 m .32002 .32383 L .28687 .3146 L F
.28393 .31411 m .28993 .30862 L .25978 .29773 L 1 .422 0 r
F
.35172 .34403 m .35343 .3376 L .31775 .33015 L 1 .971 0 r
F
.35343 .3376 m .32002 .32383 L .31775 .33015 L 1 .975 0 r
F
.3216 .33392 m .32294 .33021 L .29209 .31929 L 1 1 0 r
F
.32294 .33021 m .30453 .32261 L .29209 .31929 L F
.31691 .32554 m .31736 .32453 L .29279 .3178 L F
.32383 .32776 m .31736 .32453 L .31691 .32554 L F
.35343 .3376 m .35518 .33119 L .32002 .32383 L 1 .975 0 r
F
.35518 .33119 m .32234 .31753 L .32002 .32383 L 1 .979 0 r
F
.39114 .35226 m .35343 .3376 L .35172 .34403 L 1 .831 0 r
F
.35609 .34081 m .32383 .32776 L .3216 .33392 L 1 .987 0 r
F
.39114 .35226 m .39229 .34589 L .35343 .3376 L 1 .831 0 r
F
.39229 .34589 m .35518 .33119 L .35343 .3376 L 1 .834 0 r
F
.35609 .34081 m .35779 .33455 L .32383 .32776 L 1 .987 0 r
F
.35779 .33455 m .32609 .32164 L .32383 .32776 L 1 .992 0 r
F
.32002 .32383 m .32234 .31753 L .28971 .3084 L 1 1 0 r
F
.35518 .33119 m .35696 .32482 L .32234 .31753 L 1 .979 0 r
F
.35696 .32482 m .3247 .31127 L .32234 .31753 L 1 .983 0 r
F
.39229 .34589 m .39347 .33955 L .35518 .33119 L 1 .834 0 r
F
.39347 .33955 m .35696 .32482 L .35518 .33119 L 1 .837 0 r
F
.35779 .33455 m .35953 .32832 L .32609 .32164 L 1 .992 0 r
F
.35953 .32832 m .3284 .31555 L .32609 .32164 L 1 .997 0 r
F
.32234 .31753 m .3247 .31127 L .29259 .30225 L 1 1 0 r
F
.35696 .32482 m .35877 .31848 L .3247 .31127 L 1 .983 0 r
F
.35877 .31848 m .3271 .30505 L .3247 .31127 L 1 .987 0 r
F
.39347 .33955 m .39466 .33324 L .35696 .32482 L 1 .837 0 r
F
.39466 .33324 m .35877 .31848 L .35696 .32482 L 1 .839 0 r
F
.35953 .32832 m .36129 .32211 L .3284 .31555 L 1 .997 0 r
F
.36129 .32211 m .33075 .30949 L .3284 .31555 L 1 1 0 r
F
.3247 .31127 m .3271 .30505 L .29553 .29614 L F
.35877 .31848 m .36061 .31217 L .3271 .30505 L 1 .987 0 r
F
.36061 .31217 m .32954 .29887 L .3271 .30505 L 1 .991 0 r
F
.39466 .33324 m .39588 .32695 L .35877 .31848 L 1 .839 0 r
F
.39588 .32695 m .36061 .31217 L .35877 .31848 L 1 .842 0 r
F
.36129 .32211 m .36309 .31594 L .33075 .30949 L 1 1 0 r
F
.36309 .31594 m .33314 .30347 L .33075 .30949 L F
.3271 .30505 m .32954 .29887 L .29852 .29007 L F
.36061 .31217 m .36249 .30589 L .32954 .29887 L 1 .991 0 r
F
.36249 .30589 m .33203 .29272 L .32954 .29887 L 1 .995 0 r
F
.39588 .32695 m .39712 .32069 L .36061 .31217 L 1 .842 0 r
F
.39712 .32069 m .36249 .30589 L .36061 .31217 L 1 .844 0 r
F
.36309 .31594 m .36492 .3098 L .33314 .30347 L 1 1 0 r
F
.36492 .3098 m .33557 .2975 L .33314 .30347 L F
.32954 .29887 m .33203 .29272 L .30156 .28405 L F
.33314 .30347 m .33557 .2975 L .32974 .29595 L F
.32962 .29618 m .32974 .29595 L .32943 .29582 L 1 .865 0 r
F
.32963 .2962 m .32974 .29595 L .32962 .29618 L F
.32954 .29887 m .30156 .28405 L .29852 .29007 L 1 1 0 r
F
.32763 .30063 m .32943 .29582 L .30177 .28429 L 1 .865 0 r
F
.33314 .30347 m .32974 .29595 L .32772 .30069 L 1 1 0 r
F
.33075 .30949 m .33314 .30347 L .32716 .30188 L F
.32772 .30069 m .32943 .29582 L .32763 .30063 L 1 .865 0 r
F
.33314 .30347 m .32772 .30069 L .32716 .30188 L 1 1 0 r
F
.33412 .30473 m .32974 .29642 L .32772 .30069 L 1 .865 0 r
F
.32974 .29642 m .32943 .29582 L .32772 .30069 L F
.3271 .30505 m .29852 .29007 L .29553 .29614 L 1 1 0 r
F
.32473 .30638 m .32676 .30173 L .29873 .2903 L 1 .865 0 r
F
.325 .30654 m .32585 .30422 L .32473 .30638 L F
.32585 .30422 m .32676 .30173 L .32473 .30638 L F
.33075 .30949 m .32716 .30188 L .32713 .30196 L 1 1 0 r
F
.33075 .30949 m .32708 .30186 L .32509 .3066 L F
.3284 .31555 m .33075 .30949 L .32452 .30783 L F
.32509 .3066 m .32676 .30173 L .325 .30654 L 1 .865 0 r
F
.33075 .30949 m .32509 .3066 L .32452 .30783 L 1 1 0 r
F
.33177 .31073 m .32709 .30231 L .32509 .3066 L 1 .865 0 r
F
.32709 .30231 m .32676 .30173 L .32509 .3066 L F
.3247 .31127 m .29553 .29614 L .29259 .30225 L 1 1 0 r
F
.32213 .31233 m .32413 .30768 L .29575 .29637 L 1 .865 0 r
F
.32239 .31249 m .32322 .31021 L .32213 .31233 L F
.32322 .31021 m .32413 .30768 L .32213 .31233 L F
.3284 .31555 m .32452 .30783 L .3245 .30791 L 1 1 0 r
F
.3284 .31555 m .32445 .30781 L .32249 .31255 L F
.32609 .32164 m .3284 .31555 L .32191 .31382 L F
.32249 .31255 m .32413 .30768 L .32239 .31249 L 1 .865 0 r
F
.3284 .31555 m .32249 .31255 L .32191 .31382 L 1 1 0 r
F
.32946 .31677 m .32446 .30824 L .32249 .31255 L 1 .865 0 r
F
.32446 .30824 m .32413 .30768 L .32249 .31255 L F
.32234 .31753 m .29259 .30225 L .28971 .3084 L 1 1 0 r
F
.31955 .31831 m .32152 .31367 L .29281 .30247 L 1 .864 0 r
F
.31981 .31847 m .3206 .31624 L .31955 .31831 L F
.3206 .31624 m .32152 .31367 L .31955 .31831 L F
.32609 .32164 m .32191 .31382 L .32189 .31388 L 1 1 0 r
F
.32609 .32164 m .32184 .3138 L .31991 .31853 L F
.32383 .32776 m .32609 .32164 L .31933 .31983 L F
.31991 .31853 m .32152 .31367 L .31981 .31847 L 1 .864 0 r
F
.32609 .32164 m .31991 .31853 L .31933 .31983 L 1 1 0 r
F
.3272 .32284 m .32185 .31421 L .31991 .31853 L 1 .864 0 r
F
.32185 .31421 m .32152 .31367 L .31991 .31853 L F
.317 .32433 m .31926 .31981 L .28993 .30862 L 1 .863 0 r
F
.31736 .32453 m .31926 .31981 L .317 .32433 L F
.31736 .32453 m .3118 .32131 L .29279 .3178 L F
.3118 .32131 m .28993 .30862 L .29279 .3178 L F
.28415 .31426 m .29278 .31776 L .28393 .31411 L 1 .422 0 r
F
.28632 .31574 m .29279 .3178 L .28415 .31426 L F
.28834 .31698 m .28902 .3166 L .28632 .31574 L 1 1 0 r
F
.29209 .31929 m .29279 .3178 L .28834 .31698 L F
.29279 .3178 m .29278 .31776 L .28415 .31426 L 1 .422 0 r
F
.29278 .31776 m .28993 .30862 L .28393 .31411 L F
.29279 .3178 m .29488 .31331 L .28834 .31698 L 1 1 0 r
F
.30453 .32261 m .29279 .3178 L .29209 .31929 L F
.2937 .32074 m .29279 .3178 L .28632 .31574 L 1 .422 0 r
F
.28632 .31574 m .29488 .31331 L .26639 .30345 L 1 1 0 r
F
.28902 .3166 m .29488 .31331 L .28632 .31574 L F
.31926 .31981 m .29281 .30247 L .28993 .30862 L 1 .864 0 r
F
.31933 .31983 m .31927 .3198 L .31926 .31981 L 1 1 0 r
F
.31991 .31853 m .29281 .30247 L .31926 .31981 L 1 .864 0 r
F
.31991 .31853 m .29772 .30736 L .31933 .31983 L 1 1 0 r
F
.32383 .32776 m .31933 .31983 L .31931 .3199 L F
.3272 .32284 m .31991 .31853 L .31926 .31981 L 1 .864 0 r
F
.31927 .3198 m .31927 .3198 L .31926 .31981 L 1 1 0 r
F
.31926 .31981 m .29772 .30736 L .29488 .31331 L F
.31927 .3198 m .29772 .30736 L .31926 .31981 L F
.32184 .3138 m .29575 .29637 L .29281 .30247 L 1 .865 0 r
F
.32191 .31382 m .32185 .31378 L .32184 .3138 L 1 1 0 r
F
.32249 .31255 m .29575 .29637 L .32184 .3138 L 1 .865 0 r
F
.32249 .31255 m .3006 .30146 L .32191 .31382 L 1 1 0 r
F
.32946 .31677 m .32249 .31255 L .32184 .3138 L 1 .865 0 r
F
.32185 .31378 m .32185 .31378 L .32184 .3138 L 1 1 0 r
F
.32184 .3138 m .3006 .30146 L .29772 .30736 L F
.32185 .31378 m .3006 .30146 L .32184 .3138 L F
.32445 .30781 m .29873 .2903 L .29575 .29637 L 1 .865 0 r
F
.32452 .30783 m .32446 .30779 L .32445 .30781 L 1 1 0 r
F
.32509 .3066 m .29873 .2903 L .32445 .30781 L 1 .865 0 r
F
.32509 .3066 m .30354 .2956 L .32452 .30783 L 1 1 0 r
F
.33177 .31073 m .32509 .3066 L .32445 .30781 L 1 .865 0 r
F
.32446 .30779 m .32446 .30779 L .32445 .30781 L 1 1 0 r
F
.32445 .30781 m .30354 .2956 L .3006 .30146 L F
.32446 .30779 m .30354 .2956 L .32445 .30781 L F
.32708 .30186 m .30177 .28429 L .29873 .2903 L 1 .865 0 r
F
.32716 .30188 m .32709 .30184 L .32708 .30186 L 1 1 0 r
F
.32772 .30069 m .30177 .28429 L .32708 .30186 L 1 .865 0 r
F
.32772 .30069 m .30653 .28979 L .32716 .30188 L 1 1 0 r
F
.33412 .30473 m .32772 .30069 L .32708 .30186 L 1 .865 0 r
F
.32709 .30184 m .32709 .30184 L .32708 .30186 L 1 1 0 r
F
.32708 .30186 m .30653 .28979 L .30354 .2956 L F
.32709 .30184 m .30653 .28979 L .32708 .30186 L F
.33203 .29272 m .30466 .27807 L .30156 .28405 L F
.32926 .29575 m .30486 .27831 L .30177 .28429 L 1 .562 0 r
F
.32932 .29566 m .30486 .27831 L .32926 .29575 L F
.33038 .29481 m .30486 .27831 L .32974 .29595 L F
.33203 .29272 m .33455 .28662 L .30466 .27807 L 1 1 0 r
F
.33455 .28662 m .3078 .27214 L .30466 .27807 L F
.36439 .29965 m .33455 .28662 L .33203 .29272 L 1 .999 0 r
F
.3347 .28683 m .308 .27239 L .30486 .27831 L 1 1 0 r
F
.33557 .2975 m .33038 .29481 L .32974 .29595 L F
.36249 .30589 m .36439 .29965 L .33203 .29272 L 1 .995 0 r
F
.32836 .2935 m .3347 .28683 L .30486 .27831 L 1 .562 0 r
F
.39712 .32069 m .39838 .31446 L .36249 .30589 L 1 .844 0 r
F
.39838 .31446 m .36439 .29965 L .36249 .30589 L 1 .615 0 r
F
.36492 .3098 m .36601 .30624 L .33557 .2975 L 1 1 0 r
F
.36601 .30624 m .34669 .2997 L .33557 .2975 L F
.36132 .30235 m .36164 .30152 L .33612 .29617 L F
.36679 .30369 m .36164 .30152 L .36132 .30235 L F
.39821 .30476 m .36633 .29344 L .36439 .29965 L 1 .96 0 r
F
.39838 .31446 m .39821 .30476 L .36439 .29965 L 1 .615 0 r
F
.433 .31737 m .39821 .30476 L .39838 .31446 L .969 .818 0 r
F
.39966 .30825 m .36868 .29762 L .36679 .30369 L 1 .972 0 r
F
.42846 .36194 m .39114 .35226 L .39002 .35864 L 1 .888 0 r
F
.42846 .36194 m .42907 .35551 L .39114 .35226 L F
.42861 .36235 m .39154 .35289 L .39043 .35927 L 1 .892 0 r
F
.42861 .36235 m .42921 .35592 L .39154 .35289 L F
.42907 .35551 m .39229 .34589 L .39114 .35226 L 1 .893 0 r
F
.42907 .35551 m .4297 .34909 L .39229 .34589 L F
.42921 .35592 m .39267 .34653 L .39154 .35289 L 1 .897 0 r
F
.42921 .35592 m .42983 .34951 L .39267 .34653 L F
.4297 .34909 m .39347 .33955 L .39229 .34589 L 1 .898 0 r
F
.4297 .34909 m .43033 .3427 L .39347 .33955 L F
.42983 .34951 m .39382 .3402 L .39267 .34653 L 1 .903 0 r
F
.46779 .35035 m .43033 .3427 L .4297 .34909 L 1 .856 0 r
F
.42983 .34951 m .43046 .34312 L .39382 .3402 L 1 .903 0 r
F
.43033 .3427 m .39466 .33324 L .39347 .33955 L F
.43033 .3427 m .43098 .33633 L .39466 .33324 L F
.43046 .34312 m .395 .33388 L .39382 .3402 L 1 .908 0 r
F
.46779 .35035 m .46789 .34393 L .43033 .3427 L 1 .856 0 r
F
.46789 .34393 m .43098 .33633 L .43033 .3427 L 1 .861 0 r
F
.43046 .34312 m .4311 .33675 L .395 .33388 L 1 .908 0 r
F
.43098 .33633 m .39588 .32695 L .39466 .33324 L 1 .909 0 r
F
.43098 .33633 m .43165 .32998 L .39588 .32695 L F
.4311 .33675 m .3962 .3276 L .395 .33388 L 1 .913 0 r
F
.46789 .34393 m .46799 .33753 L .43098 .33633 L 1 .861 0 r
F
.46799 .33753 m .43165 .32998 L .43098 .33633 L 1 .867 0 r
F
.4311 .33675 m .43176 .33041 L .3962 .3276 L 1 .913 0 r
F
.43165 .32998 m .39712 .32069 L .39588 .32695 L 1 .914 0 r
F
.43165 .32998 m .43232 .32366 L .39712 .32069 L F
.43176 .33041 m .39742 .32134 L .3962 .3276 L 1 .918 0 r
F
.46799 .33753 m .46809 .33115 L .43165 .32998 L 1 .867 0 r
F
.46809 .33115 m .43232 .32366 L .43165 .32998 L 1 .872 0 r
F
.43176 .33041 m .43243 .32409 L .39742 .32134 L 1 .918 0 r
F
.43232 .32366 m .39838 .31446 L .39712 .32069 L 1 .919 0 r
F
.43232 .32366 m .433 .31737 L .39838 .31446 L F
.43243 .32409 m .39867 .31511 L .39742 .32134 L 1 .924 0 r
F
.46809 .33115 m .46819 .3248 L .43232 .32366 L 1 .872 0 r
F
.46819 .3248 m .433 .31737 L .43232 .32366 L 1 .878 0 r
F
.43243 .32409 m .4331 .31779 L .39867 .31511 L 1 .924 0 r
F
.39382 .3402 m .395 .33388 L .36044 .32926 L 1 .952 0 r
F
.39267 .34653 m .39382 .3402 L .35908 .33553 L 1 .946 0 r
F
.39267 .34653 m .35908 .33553 L .35907 .33559 L F
.39267 .34653 m .35875 .33549 L .35875 .33549 L F
.39267 .34653 m .35875 .33549 L .35874 .33553 L F
.35875 .33549 m .35874 .33549 L .35874 .33553 L F
.38783 .37148 m .38891 .36505 L .35118 .35976 L 1 .922 0 r
F
.38891 .36505 m .35005 .35049 L .35118 .35976 L 1 .824 0 r
F
.38891 .36505 m .39002 .35864 L .35005 .35049 L F
.38677 .37793 m .38783 .37148 L .34961 .36613 L 1 .916 0 r
F
.38783 .37148 m .35118 .35976 L .34961 .36613 L 1 .922 0 r
F
.3883 .37209 m .38935 .36567 L .35267 .36071 L 1 .925 0 r
F
.3883 .37209 m .35267 .36071 L .35266 .36077 L F
.3883 .37209 m .35235 .36067 L .35234 .36072 L F
.38574 .3844 m .38677 .37793 L .34808 .37252 L 1 .911 0 r
F
.38677 .37793 m .34961 .36613 L .34808 .37252 L 1 .916 0 r
F
.38473 .39088 m .38574 .3844 L .34658 .37893 L 1 .906 0 r
F
.38574 .3844 m .34808 .37252 L .34658 .37893 L 1 .911 0 r
F
.38626 .38498 m .38726 .37853 L .34904 .37336 L 1 .914 0 r
F
.38726 .37853 m .35052 .36698 L .34904 .37336 L 1 .92 0 r
F
.38726 .37853 m .3883 .37209 L .35052 .36698 L F
.3883 .37209 m .35204 .36063 L .35052 .36698 L 1 .925 0 r
F
.35267 .36071 m .3536 .35434 L .35204 .36063 L 1 .931 0 r
F
.3536 .35434 m .35359 .35434 L .35204 .36063 L F
.38935 .36567 m .3542 .35449 L .35301 .36076 L F
.39002 .35864 m .35172 .34403 L .35005 .35049 L 1 .828 0 r
F
.35383 .35434 m .35384 .35429 L .35278 .35342 L .221 .039 0 r
F
.38935 .36567 m .39043 .35927 L .35389 .35434 L 1 .931 0 r
F
.35388 .35439 m .35384 .35429 L .35383 .35434 L .221 .039 0 r
F
.35389 .35434 m .35384 .35429 L .35388 .35439 L F
.35301 .36076 m .35389 .35439 L .35267 .36071 L 1 .931 0 r
F
.3542 .35449 m .35389 .35439 L .35301 .36076 L F
.35389 .35439 m .35388 .35439 L .35386 .35451 L F
.35389 .35439 m .35386 .35451 L .35267 .36071 L F
.38473 .39088 m .34658 .37893 L .34511 .38536 L 1 .906 0 r
F
.38528 .39145 m .38626 .38498 L .34759 .37975 L 1 .909 0 r
F
.38626 .38498 m .34904 .37336 L .34759 .37975 L 1 .914 0 r
F
.4278 .41947 m .35388 .35439 L .41054 .41938 L .221 .039 0 r
F
.35388 .35439 m .35278 .35342 L .35359 .35434 L F
.3536 .35434 m .3536 .35434 L .35359 .35434 L 1 .931 0 r
F
.35388 .35439 m .3536 .3543 L .35267 .36071 L F
.35388 .35439 m .35359 .35434 L .41054 .41938 L .221 .039 0 r
F
.3536 .35434 m .3536 .3543 L .35359 .35434 L 1 .931 0 r
F
.35388 .35439 m .35389 .35434 L .3536 .3543 L F
.38935 .36567 m .35389 .35434 L .35388 .35439 L F
.4278 .41947 m .35389 .35434 L .35388 .35439 L .221 .039 0 r
F
.35389 .35434 m .35389 .35434 L .35384 .35429 L F
.35547 .34803 m .35547 .34803 L .35543 .34799 L .218 .038 0 r
F
.39002 .35864 m .39114 .35226 L .35172 .34403 L 1 .828 0 r
F
.35695 .34166 m .35609 .34081 L .35543 .34799 L .216 .038 0 r
F
.35547 .34803 m .35683 .34171 L .35654 .3428 L 1 .941 0 r
F
.35543 .34799 m .35609 .34081 L .35442 .3471 L .216 .038 0 r
F
.35547 .34803 m .35654 .3428 L .3552 .34799 L 1 .941 0 r
F
.35547 .34803 m .35654 .3428 L .35547 .34803 L F
.39154 .35289 m .3574 .34189 L .35615 .34812 L F
.35457 .35443 m .35546 .34808 L .35422 .35438 L 1 .936 0 r
F
.39043 .35927 m .35578 .34818 L .35457 .35443 L F
.35578 .34818 m .35546 .34808 L .35457 .35443 L F
.3574 .34189 m .35709 .34179 L .35615 .34812 L 1 .941 0 r
F
.35384 .3543 m .35531 .34794 L .35384 .35429 L .218 .038 0 r
F
.35422 .35287 m .35531 .34794 L .35384 .3543 L F
.35546 .34808 m .35531 .34794 L .35389 .35434 L F
.35542 .34803 m .35543 .34799 L .35442 .3471 L F
.39043 .35927 m .39154 .35289 L .35547 .34803 L 1 .936 0 r
F
.35546 .34808 m .35543 .34799 L .35542 .34803 L .218 .038 0 r
F
.35547 .34803 m .35543 .34799 L .35546 .34808 L F
.35546 .34808 m .35547 .34803 L .3552 .34799 L 1 .936 0 r
F
.39043 .35927 m .35547 .34803 L .35546 .34808 L F
.4283 .41596 m .35547 .34803 L .35546 .34808 L .218 .038 0 r
F
.39154 .35289 m .39267 .34653 L .35709 .34174 L 1 .941 0 r
F
.35615 .34812 m .35709 .34179 L .35703 .34203 L F
.3558 .34807 m .35703 .34203 L .35547 .34803 L F
.35615 .34812 m .35703 .34203 L .3558 .34807 L F
.35708 .34179 m .35705 .3417 L .35704 .34175 L .216 .038 0 r
F
.39154 .35289 m .35709 .34174 L .35708 .34179 L 1 .941 0 r
F
.35709 .34175 m .35709 .34174 L .35705 .3417 L .216 .038 0 r
F
.36037 .32924 m .35953 .32832 L .35881 .33507 L .21 .037 0 r
F
.35945 .33279 m .35881 .33507 L .35877 .33538 L F
.36037 .32924 m .35881 .33507 L .35945 .33279 L F
.36038 .3292 m .36129 .32211 L .35953 .32832 L .207 .036 0 r
F
.362 .32293 m .36129 .32211 L .36038 .3292 L F
.36044 .32926 m .36193 .32303 L .3602 .32923 L 1 .957 0 r
F
.36216 .32306 m .36309 .31594 L .36129 .32211 L .204 .036 0 r
F
.36387 .31688 m .36309 .31594 L .3622 .32272 L F
.36302 .31994 m .3622 .32272 L .36216 .32306 L F
.36387 .31688 m .3622 .32272 L .36302 .31994 L F
.36392 .31689 m .36492 .3098 L .36309 .31594 L .201 .035 0 r
F
.36392 .31689 m .36394 .31683 L .36392 .31689 L 1 .967 0 r
F
.39742 .32134 m .36572 .3108 L .36565 .31102 L F
.39742 .32134 m .36565 .31102 L .36466 .31522 L F
.39742 .32134 m .36443 .31518 L .36393 .31689 L F
.3625 .32311 m .36391 .31693 L .36216 .32306 L 1 .962 0 r
F
.3962 .3276 m .36391 .31693 L .3625 .32311 L F
.395 .33388 m .36216 .32311 L .3621 .32333 L 1 .957 0 r
F
.36115 .32761 m .3621 .32333 L .36091 .32756 L F
.395 .33388 m .3621 .32333 L .36115 .32761 L F
.395 .33388 m .36091 .32756 L .36044 .32926 L F
.39382 .3402 m .36044 .32931 L .36038 .32953 L 1 .952 0 r
F
.35908 .33553 m .36038 .32953 L .35875 .33549 L F
.39382 .3402 m .36038 .32953 L .35908 .33553 L F
.39267 .34653 m .35875 .33554 L .35869 .33577 L 1 .946 0 r
F
.35743 .34179 m .35869 .33577 L .35709 .34174 L F
.39267 .34653 m .35869 .33577 L .35743 .34179 L F
.42934 .40892 m .42987 .40538 L .35874 .33549 L .213 .037 0 r
F
.35875 .33549 m .3602 .32923 L .35976 .33083 L 1 .952 0 r
F
.35874 .33549 m .35874 .33549 L .3587 .33545 L .213 .037 0 r
F
.35875 .33549 m .35875 .33549 L .35874 .33549 L 1 .946 0 r
F
.35876 .3355 m .35953 .32832 L .35779 .33455 L .21 .037 0 r
F
.35874 .33549 m .35976 .33083 L .35849 .33545 L 1 .952 0 r
F
.35875 .33549 m .35976 .33083 L .35874 .33549 L F
.42934 .40892 m .35874 .33549 L .35874 .33549 L .213 .037 0 r
F
.39382 .3402 m .36044 .32926 L .36043 .3293 L 1 .952 0 r
F
.42987 .40538 m .43042 .40183 L .36043 .32926 L .21 .037 0 r
F
.36043 .32926 m .36043 .32926 L .36038 .3292 L F
.42987 .40538 m .36043 .32926 L .36043 .32926 L F
.395 .33388 m .3962 .3276 L .36216 .32306 L 1 .957 0 r
F
.36044 .32926 m .36091 .32756 L .36044 .32926 L F
.36043 .32926 m .362 .32293 L .36038 .3292 L .207 .036 0 r
F
.36216 .32311 m .36215 .3231 L .36044 .32926 L 1 .957 0 r
F
.36215 .3231 m .36045 .3292 L .36044 .32926 L F
.43042 .40183 m .36215 .3231 L .36043 .32926 L .207 .036 0 r
F
.36215 .3231 m .362 .32293 L .36043 .32926 L F
.36215 .3231 m .36193 .32303 L .36045 .3292 L 1 .957 0 r
F
.36215 .3231 m .36216 .32306 L .36193 .32303 L F
.395 .33388 m .36216 .32306 L .36215 .3231 L F
.36215 .3231 m .36216 .32306 L .36216 .32306 L .207 .036 0 r
F
.36215 .3231 m .36216 .32306 L .36129 .32211 L F
.43042 .40183 m .43097 .39827 L .36216 .32306 L F
.43042 .40183 m .36216 .32306 L .36215 .3231 L F
.3962 .3276 m .39742 .32134 L .36392 .31689 L 1 .962 0 r
F
.36391 .31693 m .36392 .31689 L .3637 .31686 L F
.3962 .3276 m .36392 .31689 L .36391 .31693 L F
.36391 .31693 m .36392 .31689 L .36392 .31689 L .204 .036 0 r
F
.36391 .31693 m .36392 .31689 L .36309 .31594 L F
.43097 .39827 m .43153 .39469 L .36392 .31689 L F
.43097 .39827 m .36392 .31689 L .36391 .31693 L F
.39742 .32134 m .39867 .31511 L .36572 .31076 L 1 .967 0 r
F
.36571 .3108 m .36571 .3108 L .36392 .31689 L .201 .035 0 r
F
.36571 .3108 m .36492 .3098 L .36397 .31655 L F
.36571 .3108 m .36397 .31655 L .36392 .31689 L F
.36572 .31076 m .36679 .30369 L .36492 .3098 L .867 .059 0 r
F
.36753 .30469 m .39966 .30825 L .36679 .30369 L F
.36755 .3047 m .36754 .30469 L .36572 .31076 L 1 .973 0 r
F
.39867 .31511 m .36755 .3047 L .36572 .31076 L F
.39742 .32134 m .36572 .31076 L .36571 .3108 L 1 .967 0 r
F
.433 .31737 m .4337 .3111 L .39821 .30476 L .969 .818 0 r
F
.4337 .3111 m .39955 .29848 L .39821 .30476 L .966 .821 0 r
F
.40012 .30892 m .40097 .30208 L .39966 .30825 L .098 .014 0 r
F
.40136 .30273 m .40097 .30208 L .40017 .30846 L F
.40074 .30581 m .40017 .30846 L .40012 .30892 L F
.40136 .30273 m .40017 .30846 L .40074 .30581 L F
.4337 .3111 m .43441 .30486 L .39955 .29848 L .966 .821 0 r
F
.43441 .30486 m .40091 .29224 L .39955 .29848 L .962 .824 0 r
F
.4014 .30275 m .40229 .29594 L .40097 .30208 L .1 .015 0 r
F
.4684 .31216 m .43441 .30486 L .4337 .3111 L 1 .888 0 r
F
.4345 .30528 m .40271 .29664 L .40208 .29957 L 1 .939 0 r
F
.40143 .30268 m .40208 .29957 L .40142 .30268 L F
.4345 .30528 m .40208 .29957 L .40143 .30268 L F
.43441 .30486 m .43513 .29865 L .40091 .29224 L .962 .824 0 r
F
.43513 .29865 m .40229 .28603 L .40091 .29224 L .958 .827 0 r
F
.40271 .29661 m .40364 .28984 L .40229 .29594 L .103 .015 0 r
F
.404 .29048 m .40364 .28984 L .40278 .29612 L F
.40336 .29353 m .40278 .29612 L .40271 .29661 L F
.404 .29048 m .40278 .29612 L .40336 .29353 L F
.43513 .29865 m .43586 .29247 L .40229 .28603 L .958 .827 0 r
F
.43586 .29247 m .40369 .27986 L .40229 .28603 L .954 .83 0 r
F
.40404 .2905 m .40501 .28377 L .40364 .28984 L .107 .016 0 r
F
.46862 .29964 m .43586 .29247 L .43513 .29865 L 1 .899 0 r
F
.43594 .29289 m .4054 .28446 L .40479 .28718 L 1 .95 0 r
F
.4041 .29027 m .40479 .28718 L .40409 .29027 L F
.43594 .29289 m .40479 .28718 L .4041 .29027 L F
.43586 .29247 m .4366 .28633 L .40369 .27986 L .954 .83 0 r
F
.4366 .28633 m .40512 .27373 L .40369 .27986 L .95 .832 0 r
F
.40539 .28443 m .4064 .27773 L .40501 .28377 L .113 .016 0 r
F
.40673 .27837 m .4064 .27773 L .40547 .28392 L F
.40606 .28138 m .40547 .28392 L .40539 .28443 L F
.40673 .27837 m .40547 .28392 L .40606 .28138 L F
.4366 .28633 m .43735 .28021 L .40512 .27373 L .95 .832 0 r
F
.43735 .28021 m .40656 .26763 L .40512 .27373 L .946 .834 0 r
F
.40677 .27839 m .40781 .27173 L .4064 .27773 L .119 .017 0 r
F
.46884 .28723 m .43735 .28021 L .4366 .28633 L 1 .91 0 r
F
.43742 .28063 m .40816 .27242 L .40759 .27488 L 1 .96 0 r
F
.40688 .27796 m .40759 .27488 L .40687 .27796 L F
.43742 .28063 m .40759 .27488 L .40688 .27796 L F
.43735 .28021 m .43812 .27413 L .40656 .26763 L .946 .834 0 r
F
.43812 .27413 m .40803 .26158 L .40656 .26763 L .942 .837 0 r
F
.40816 .27239 m .40924 .26577 L .40781 .27173 L .126 .018 0 r
F
.40954 .2664 m .40924 .26577 L .40825 .27186 L F
.40886 .26938 m .40825 .27186 L .40816 .27239 L F
.40954 .2664 m .40825 .27186 L .40886 .26938 L F
.43812 .27413 m .43889 .26809 L .40803 .26158 L .942 .837 0 r
F
.43889 .26809 m .40952 .25557 L .40803 .26158 L .937 .839 0 r
F
.40958 .26643 m .41069 .25984 L .40924 .26577 L .135 .02 0 r
F
.46906 .27495 m .43889 .26809 L .43812 .27413 L 1 .92 0 r
F
.43896 .2685 m .41102 .26053 L .41049 .26269 L 1 .97 0 r
F
.40976 .26575 m .41049 .26269 L .40974 .26575 L F
.43896 .2685 m .41049 .26269 L .40976 .26575 L F
.43889 .26809 m .43968 .26208 L .40952 .25557 L .937 .839 0 r
F
.43968 .26208 m .41102 .24961 L .40952 .25557 L .932 .841 0 r
F
.41102 .2605 m .41216 .25396 L .41069 .25984 L .145 .021 0 r
F
.41244 .25458 m .41216 .25396 L .41111 .25995 L F
.41173 .25752 m .41111 .25995 L .41102 .2605 L F
.41244 .25458 m .41111 .25995 L .41173 .25752 L F
.43968 .26208 m .44047 .25611 L .41102 .24961 L .932 .841 0 r
F
.44047 .25611 m .41255 .24369 L .41102 .24961 L 1 .703 0 r
F
.41248 .25462 m .41365 .24812 L .41216 .25396 L .972 .152 0 r
F
.46928 .26281 m .44047 .25611 L .43968 .26208 L 1 .931 0 r
F
.44053 .25651 m .41396 .2488 L .41272 .25364 L 1 .981 0 r
F
.44053 .25651 m .41272 .25364 L .41248 .25462 L F
.41395 .2488 m .41365 .24812 L .41248 .25462 L .972 .152 0 r
F
.46917 .26886 m .43968 .26208 L .43889 .26809 L 1 .926 0 r
F
.43974 .26249 m .41247 .25465 L .41102 .2605 L 1 .976 0 r
F
.43896 .2685 m .40974 .26575 L .40958 .26643 L 1 .97 0 r
F
.46895 .28108 m .43812 .27413 L .43735 .28021 L 1 .915 0 r
F
.43818 .27455 m .40957 .26646 L .40816 .27239 L 1 .965 0 r
F
.43742 .28063 m .40687 .27796 L .40677 .27839 L 1 .96 0 r
F
.46873 .29342 m .4366 .28633 L .43586 .29247 L 1 .904 0 r
F
.43668 .28675 m .40676 .27842 L .40539 .28443 L 1 .955 0 r
F
.43594 .29289 m .40409 .29027 L .40404 .2905 L 1 .95 0 r
F
.46851 .30589 m .43513 .29865 L .43441 .30486 L 1 .894 0 r
F
.43521 .29907 m .40403 .29053 L .40271 .29661 L 1 .945 0 r
F
.46789 .34417 m .4311 .33675 L .43046 .34312 L 1 .865 0 r
F
.46789 .34417 m .46799 .33777 L .4311 .33675 L F
.46799 .33777 m .43176 .33041 L .4311 .33675 L 1 .871 0 r
F
.46799 .33777 m .4681 .3314 L .43176 .33041 L F
.4681 .3314 m .43243 .32409 L .43176 .33041 L 1 .876 0 r
F
.4681 .3314 m .4682 .32504 L .43243 .32409 L F
.46819 .3248 m .4683 .31847 L .433 .31737 L 1 .878 0 r
F
.4682 .32504 m .4331 .31779 L .43243 .32409 L 1 .882 0 r
F
.4682 .32504 m .4683 .31871 L .4331 .31779 L F
.4683 .31847 m .4337 .3111 L .433 .31737 L 1 .883 0 r
F
.4683 .31847 m .4684 .31216 L .4337 .3111 L F
.4683 .31871 m .4338 .31152 L .4331 .31779 L 1 .887 0 r
F
.4683 .31871 m .46841 .31241 L .4338 .31152 L F
.4684 .31216 m .46851 .30589 L .43441 .30486 L 1 .888 0 r
F
.46841 .31241 m .4345 .30528 L .4338 .31152 L 1 .892 0 r
F
.46841 .31241 m .46851 .30613 L .4345 .30528 L F
.46851 .30613 m .43521 .29907 L .4345 .30528 L 1 .898 0 r
F
.4027 .29664 m .40229 .29594 L .4014 .30275 L .1 .015 0 r
F
.4345 .30528 m .43521 .29907 L .40271 .29661 L 1 .939 0 r
F
.4027 .29664 m .40271 .29661 L .40254 .2966 L F
.4345 .30528 m .40271 .29661 L .4027 .29664 L F
.4345 .30528 m .40142 .30268 L .4014 .30275 L F
.4338 .31152 m .40139 .30278 L .40012 .30892 L 1 .934 0 r
F
.4331 .31779 m .40023 .30899 L .39962 .3114 L 1 .929 0 r
F
.4331 .31779 m .39962 .3114 L .39887 .31512 L F
.46779 .3506 m .43046 .34312 L .42983 .34951 L 1 .86 0 r
F
.46779 .3506 m .46789 .34417 L .43046 .34312 L F
.40011 .30895 m .39966 .30825 L .39993 .30893 L .096 .014 0 r
F
.40011 .30897 m .40011 .30895 L .39993 .30893 L 1 .929 0 r
F
.40023 .30899 m .40011 .30895 L .40011 .30897 L F
.40011 .30895 m .4338 .31152 L .40012 .30892 L F
.40011 .30895 m .40012 .30892 L .39993 .30891 L F
.40011 .30895 m .40012 .30892 L .40012 .30892 L .096 .014 0 r
F
.40011 .30895 m .40012 .30892 L .39966 .30825 L F
.4331 .31779 m .43369 .31252 L .40011 .30895 L 1 .929 0 r
F
.43369 .31252 m .4338 .31152 L .40011 .30895 L F
.40023 .30899 m .39993 .30893 L .39867 .31511 L F
.44912 .38576 m .44937 .38143 L .40012 .30892 L .096 .014 0 r
F
.44912 .38576 m .40012 .30892 L .40011 .30895 L F
.40011 .30895 m .39993 .30893 L .39993 .30893 L F
.40011 .30895 m .39993 .30891 L .39993 .30893 L 1 .929 0 r
F
.44912 .38576 m .40011 .30895 L .43209 .39109 L .096 .014 0 r
F
.40011 .30895 m .39993 .30893 L .43209 .39109 L F
.4338 .31152 m .4014 .30275 L .40139 .30278 L 1 .934 0 r
F
.44937 .38143 m .44962 .377 L .4014 .30275 L .098 .014 0 r
F
.40139 .30278 m .4014 .30275 L .40097 .30208 L F
.44937 .38143 m .4014 .30275 L .40139 .30278 L F
.4338 .31152 m .4345 .30528 L .4014 .30275 L 1 .934 0 r
F
.40139 .30278 m .4014 .30275 L .40123 .30274 L F
.40013 .30894 m .40136 .30273 L .40012 .30892 L .098 .014 0 r
F
.44937 .38143 m .40139 .30278 L .40013 .30894 L F
.40139 .30278 m .40136 .30273 L .40013 .30894 L F
.44962 .377 m .44987 .37248 L .40271 .29661 L .1 .015 0 r
F
.4027 .29664 m .40271 .29661 L .40229 .29594 L F
.40271 .29664 m .4027 .29664 L .4014 .30275 L 1 .939 0 r
F
.4027 .29664 m .40254 .2966 L .40169 .30116 L F
.4027 .29664 m .40169 .30116 L .4014 .30275 L F
.44962 .377 m .40271 .29661 L .4027 .29664 L .1 .015 0 r
F
.40271 .29661 m .40271 .29661 L .4027 .29664 L F
.46851 .30589 m .46862 .29964 L .43513 .29865 L 1 .894 0 r
F
.43521 .29907 m .40404 .2905 L .40403 .29053 L 1 .945 0 r
F
.44665 .36672 m .44717 .36287 L .40404 .2905 L .103 .015 0 r
F
.45133 .34221 m .45157 .33645 L .45104 .33536 L .145 .021 0 r
F
.43521 .29907 m .43594 .29289 L .40404 .2905 L 1 .945 0 r
F
.40538 .28446 m .40501 .28377 L .40404 .2905 L .107 .016 0 r
F
.46862 .29964 m .46873 .29342 L .43586 .29247 L 1 .899 0 r
F
.43594 .29289 m .43668 .28675 L .40539 .28443 L 1 .95 0 r
F
.40538 .28446 m .40539 .28443 L .40523 .28442 L F
.43594 .29289 m .40539 .28443 L .40538 .28446 L F
.44683 .36169 m .44734 .35775 L .40539 .28443 L .107 .016 0 r
F
.46873 .29342 m .46884 .28723 L .4366 .28633 L 1 .904 0 r
F
.43668 .28675 m .40676 .27839 L .40676 .27842 L 1 .955 0 r
F
.44702 .35655 m .44753 .3525 L .40677 .27839 L .113 .016 0 r
F
.45035 .33999 m .45104 .33536 L .45002 .33322 L .145 .021 0 r
F
.43668 .28675 m .43742 .28063 L .40677 .27839 L 1 .955 0 r
F
.40815 .27242 m .40781 .27173 L .40677 .27839 L .119 .017 0 r
F
.46884 .28723 m .46895 .28108 L .43735 .28021 L 1 .91 0 r
F
.43742 .28063 m .43818 .27455 L .40816 .27239 L 1 .96 0 r
F
.40815 .27242 m .40816 .27239 L .40801 .27238 L F
.43742 .28063 m .40816 .27239 L .40815 .27242 L F
.44723 .35129 m .44773 .34712 L .40816 .27239 L .119 .017 0 r
F
.46895 .28108 m .46906 .27495 L .43812 .27413 L 1 .915 0 r
F
.43818 .27455 m .40958 .26643 L .40957 .26646 L 1 .965 0 r
F
.44748 .34593 m .44797 .3416 L .40958 .26643 L .126 .018 0 r
F
.44939 .33784 m .45002 .33322 L .44914 .33137 L .145 .021 0 r
F
.43818 .27455 m .43896 .2685 L .40958 .26643 L 1 .965 0 r
F
.41101 .26053 m .41069 .25984 L .40958 .26643 L .135 .02 0 r
F
.46906 .27495 m .46917 .26886 L .43889 .26809 L 1 .92 0 r
F
.43896 .2685 m .43974 .26249 L .41102 .2605 L 1 .97 0 r
F
.41101 .26053 m .41102 .2605 L .41087 .26049 L F
.43896 .2685 m .41102 .2605 L .41101 .26053 L F
.44777 .34047 m .44824 .33595 L .41102 .2605 L .135 .02 0 r
F
.43974 .26249 m .41248 .25462 L .41247 .25465 L 1 .976 0 r
F
.44811 .33494 m .44857 .33019 L .41248 .25462 L .145 .021 0 r
F
.46917 .26886 m .46928 .26281 L .43968 .26208 L 1 .926 0 r
F
.43974 .26249 m .44053 .25651 L .41248 .25462 L 1 .976 0 r
F
.41396 .2488 m .41395 .2488 L .41247 .25462 L 1 .981 0 r
F
.46851 .30613 m .46862 .29988 L .43521 .29907 L 1 .898 0 r
F
.46862 .29988 m .43594 .29289 L .43521 .29907 L 1 .903 0 r
F
.46862 .29988 m .46873 .29366 L .43594 .29289 L F
.46873 .29366 m .43668 .28675 L .43594 .29289 L 1 .908 0 r
F
.46873 .29366 m .46884 .28747 L .43668 .28675 L F
.46884 .28747 m .43742 .28063 L .43668 .28675 L 1 .914 0 r
F
.46884 .28747 m .46895 .28131 L .43742 .28063 L F
.46895 .28131 m .43818 .27455 L .43742 .28063 L 1 .919 0 r
F
.46895 .28131 m .46906 .27519 L .43818 .27455 L F
.46906 .27519 m .43896 .2685 L .43818 .27455 L 1 .924 0 r
F
.46906 .27519 m .46917 .2691 L .43896 .2685 L F
.46917 .2691 m .43974 .26249 L .43896 .2685 L 1 .93 0 r
F
.46917 .2691 m .46929 .26304 L .43974 .26249 L F
.46928 .26281 m .4694 .25679 L .44047 .25611 L 1 .931 0 r
F
.46929 .26304 m .44053 .25651 L .43974 .26249 L 1 .935 0 r
F
.46929 .26304 m .4694 .25702 L .44053 .25651 L F
.4694 .25679 m .44078 .24637 L .44047 .25611 L .902 .822 0 r
F
.4694 .25679 m .46951 .25081 L .44078 .24637 L F
.46951 .25081 m .44162 .24043 L .44078 .24637 L .898 .824 0 r
F
.44148 .25058 m .4421 .24429 L .44128 .25018 L .201 .031 0 r
F
.4694 .25702 m .4415 .25061 L .44139 .25124 L 1 .94 0 r
F
.4694 .25702 m .44139 .25124 L .44071 .25652 L F
.50327 .31151 m .46851 .30613 L .46841 .31241 L .995 .852 0 r
F
.50327 .31151 m .50277 .30523 L .46851 .30613 L F
.50277 .30523 m .46862 .29988 L .46851 .30613 L .994 .858 0 r
F
.44147 .25061 m .46952 .25103 L .44148 .25058 L 1 .94 0 r
F
.4694 .25702 m .46947 .25322 L .44147 .25061 L F
.46947 .25322 m .46952 .25103 L .44147 .25061 L F
.4415 .25061 m .44147 .25061 L .44053 .25651 L F
.44147 .25061 m .44133 .25059 L .44125 .25118 L F
.44147 .25061 m .44125 .25118 L .44053 .25651 L F
.50375 .31783 m .46841 .31241 L .4683 .31871 L .996 .846 0 r
F
.50375 .31783 m .50327 .31151 L .46841 .31241 L F
.46994 .31505 m .46999 .30745 L .44148 .25058 L .181 .026 0 r
F
.44147 .25061 m .44148 .25058 L .44128 .25018 L F
.44147 .25061 m .44128 .25018 L .44133 .25059 L F
.4415 .25061 m .44147 .25061 L .44133 .25059 L 1 .94 0 r
F
.44147 .25061 m .44133 .25059 L .44133 .25059 L .181 .026 0 r
F
.44147 .25061 m .44133 .25058 L .44133 .25059 L 1 .94 0 r
F
.44148 .25058 m .44215 .24468 L .44133 .25058 L 1 .945 0 r
F
.46951 .25081 m .46963 .24487 L .44162 .24043 L .898 .824 0 r
F
.46963 .24487 m .44247 .23453 L .44162 .24043 L .893 .827 0 r
F
.4423 .24468 m .44293 .23843 L .4421 .24429 L .22 .035 0 r
F
.46952 .25103 m .44364 .24502 L .44153 .25046 L 1 .945 0 r
F
.46952 .25103 m .44153 .25046 L .44151 .25058 L F
.44364 .24502 m .44229 .24471 L .44148 .25058 L F
.44229 .24471 m .44229 .24471 L .44148 .25057 L .201 .031 0 r
F
.44229 .24471 m .44226 .24464 L .44187 .2476 L F
.44229 .24471 m .44187 .2476 L .44148 .25057 L F
.50277 .30523 m .50227 .29897 L .46862 .29988 L .994 .858 0 r
F
.50227 .29897 m .46873 .29366 L .46862 .29988 L .993 .863 0 r
F
.49792 .24995 m .46963 .24487 L .46951 .25081 L .978 .905 0 r
F
.46952 .25103 m .46963 .24509 L .4423 .24468 L 1 .945 0 r
F
.44229 .24471 m .4423 .24468 L .44229 .24471 L .201 .031 0 r
F
.44226 .24464 m .4421 .24429 L .44148 .25058 L F
.44229 .24471 m .4423 .24468 L .44215 .24468 L 1 .945 0 r
F
.46952 .25103 m .4423 .24468 L .44229 .24471 L F
.46999 .30745 m .4423 .24468 L .44229 .24471 L .201 .031 0 r
F
.46999 .30745 m .47006 .29962 L .4423 .24468 L F
.44229 .24471 m .4423 .24468 L .4421 .24429 L F
.4423 .24468 m .44313 .23885 L .44258 .24263 L 1 .951 0 r
F
.46963 .24509 m .44454 .23919 L .44235 .24456 L F
.44233 .24468 m .44235 .24456 L .4423 .24468 L F
.46963 .24509 m .44235 .24456 L .44233 .24468 L F
.46963 .24487 m .46975 .23896 L .44247 .23453 L .893 .827 0 r
F
.46975 .23896 m .44332 .22868 L .44247 .23453 L .889 .83 0 r
F
.44312 .23882 m .44376 .23262 L .44293 .23843 L .238 .039 0 r
F
.44454 .23919 m .44313 .23885 L .4423 .24468 L 1 .951 0 r
F
.50176 .29274 m .46884 .28747 L .46873 .29366 L .992 .869 0 r
F
.44311 .23885 m .44311 .23885 L .4423 .24467 L .22 .035 0 r
F
.44311 .23885 m .44308 .23878 L .44269 .24172 L F
.44311 .23885 m .44269 .24172 L .4423 .24467 L F
.49792 .24995 m .49733 .244 L .46963 .24487 L .978 .905 0 r
F
.49733 .244 m .46975 .23896 L .46963 .24487 L .976 .91 0 r
F
.46963 .24509 m .46975 .23918 L .44312 .23882 L 1 .951 0 r
F
.44308 .23878 m .44293 .23843 L .4423 .24468 L .22 .035 0 r
F
.4423 .24467 m .4423 .24468 L .4423 .24468 L F
.44308 .23878 m .4423 .24468 L .4423 .24467 L F
.44258 .24263 m .44297 .23882 L .44229 .24468 L 1 .951 0 r
F
.44313 .23885 m .44311 .23885 L .44258 .24263 L F
.44311 .23885 m .44297 .23882 L .44258 .24263 L F
.44311 .23885 m .44312 .23882 L .44297 .23882 L F
.46963 .24509 m .44312 .23882 L .44311 .23885 L F
.50227 .29897 m .50176 .29274 L .46873 .29366 L .993 .863 0 r
F
.47006 .29962 m .47012 .29158 L .44312 .23882 L .22 .035 0 r
F
.44311 .23885 m .44312 .23882 L .44293 .23843 L F
.47006 .29962 m .44312 .23882 L .44311 .23885 L F
.44312 .23882 m .44396 .23304 L .44342 .23671 L 1 .956 0 r
F
.46975 .23918 m .44544 .23339 L .44318 .2387 L F
.44316 .23882 m .44318 .2387 L .44312 .23882 L F
.46975 .23918 m .44318 .2387 L .44316 .23882 L F
.46975 .23896 m .46987 .2331 L .44332 .22868 L .889 .83 0 r
F
.46987 .2331 m .44419 .22288 L .44332 .22868 L .884 .832 0 r
F
.44396 .233 m .44461 .22685 L .44376 .23262 L .256 .044 0 r
F
.44544 .23339 m .44396 .23304 L .44312 .23882 L 1 .956 0 r
F
.50123 .28654 m .46895 .28131 L .46884 .28747 L .99 .874 0 r
F
.50123 .28654 m .5007 .28037 L .46895 .28131 L F
.5007 .28037 m .46906 .27519 L .46895 .28131 L .989 .88 0 r
F
.44395 .23303 m .44395 .23303 L .44313 .23881 L .238 .039 0 r
F
.44395 .23303 m .44392 .23297 L .44352 .23588 L F
.44395 .23303 m .44352 .23588 L .44313 .23881 L F
.49733 .244 m .49674 .23809 L .46975 .23896 L .976 .91 0 r
F
.49674 .23809 m .46987 .2331 L .46975 .23896 L .975 .916 0 r
F
.46975 .23918 m .46987 .23331 L .44396 .233 L 1 .956 0 r
F
.44392 .23297 m .44376 .23262 L .44313 .23882 L .238 .039 0 r
F
.44313 .23881 m .44313 .23882 L .44312 .23882 L F
.44392 .23297 m .44313 .23882 L .44313 .23881 L F
.44342 .23671 m .44381 .233 L .44312 .23882 L 1 .956 0 r
F
.44396 .23304 m .44395 .23303 L .44342 .23671 L F
.44395 .23303 m .44381 .233 L .44342 .23671 L F
.44395 .23303 m .44396 .233 L .44381 .233 L F
.46975 .23918 m .44396 .233 L .44395 .23303 L F
.50176 .29274 m .50123 .28654 L .46884 .28747 L .992 .869 0 r
F
.47012 .29158 m .47019 .28339 L .44396 .233 L .238 .039 0 r
F
.44395 .23303 m .44396 .233 L .44376 .23262 L F
.47012 .29158 m .44396 .233 L .44395 .23303 L F
.44396 .233 m .44481 .22726 L .44427 .23085 L 1 .961 0 r
F
.46987 .23331 m .44634 .22763 L .44396 .233 L F
.44634 .22763 m .44481 .22726 L .44471 .22796 L F
.44402 .23288 m .44471 .22796 L .44396 .233 L F
.44634 .22763 m .44471 .22796 L .44402 .23288 L F
.46987 .2331 m .46998 .22728 L .44419 .22288 L .884 .832 0 r
F
.46998 .22728 m .44507 .21713 L .44419 .22288 L .879 .834 0 r
F
.44481 .22723 m .44547 .22112 L .44461 .22685 L .272 .048 0 r
F
.50016 .27424 m .46917 .2691 L .46906 .27519 L .988 .886 0 r
F
.4448 .22726 m .4448 .22726 L .44397 .23299 L .256 .044 0 r
F
.4448 .22726 m .44477 .22719 L .44437 .23008 L F
.4448 .22726 m .44437 .23008 L .44397 .23299 L F
.49674 .23809 m .49613 .23221 L .46987 .2331 L .975 .916 0 r
F
.49613 .23221 m .46998 .22728 L .46987 .2331 L .973 .921 0 r
F
.46987 .23331 m .46999 .22748 L .44481 .22723 L 1 .961 0 r
F
.44477 .22719 m .44461 .22685 L .44396 .233 L .256 .044 0 r
F
.44397 .23299 m .44396 .233 L .44396 .233 L F
.44477 .22719 m .44396 .233 L .44397 .23299 L F
.44427 .23085 m .44465 .22722 L .44395 .233 L 1 .961 0 r
F
.44481 .22726 m .4448 .22726 L .44427 .23085 L F
.4448 .22726 m .44465 .22722 L .44427 .23085 L F
.4448 .22726 m .44481 .22723 L .44465 .22722 L F
.46987 .23331 m .44481 .22723 L .4448 .22726 L F
.5007 .28037 m .50016 .27424 L .46906 .27519 L .989 .88 0 r
F
.47019 .28339 m .47026 .27506 L .44481 .22723 L .256 .044 0 r
F
.4448 .22726 m .44481 .22723 L .44461 .22685 L F
.47019 .28339 m .44481 .22723 L .4448 .22726 L F
.44481 .22723 m .44567 .22153 L .44513 .22506 L 1 .966 0 r
F
.46999 .22748 m .44724 .22191 L .44481 .22723 L F
.44724 .22191 m .44567 .22153 L .44557 .22219 L F
.44487 .2271 m .44557 .22219 L .44481 .22723 L F
.44724 .22191 m .44557 .22219 L .44487 .2271 L F
.46998 .22728 m .4701 .2215 L .44507 .21713 L .879 .834 0 r
F
.4701 .2215 m .44596 .21143 L .44507 .21713 L .874 .836 0 r
F
.44567 .22149 m .44634 .21544 L .44547 .22112 L .287 .052 0 r
F
.49961 .26814 m .46929 .26304 L .46917 .2691 L .986 .891 0 r
F
.44566 .22153 m .44565 .22153 L .44481 .22721 L .272 .048 0 r
F
.44565 .22153 m .44562 .22145 L .44522 .22432 L F
.44565 .22153 m .44522 .22432 L .44481 .22721 L F
.49613 .23221 m .49552 .22638 L .46998 .22728 L .973 .921 0 r
F
.49552 .22638 m .4701 .2215 L .46998 .22728 L .971 .927 0 r
F
.46999 .22748 m .47011 .2217 L .44567 .22149 L 1 .966 0 r
F
.44562 .22145 m .44547 .22112 L .44481 .22722 L .272 .048 0 r
F
.44481 .22721 m .44481 .22722 L .44481 .22723 L F
.44562 .22145 m .44481 .22722 L .44481 .22721 L F
.44513 .22506 m .44551 .22149 L .4448 .22723 L 1 .966 0 r
F
.44567 .22153 m .44566 .22153 L .44513 .22506 L F
.44566 .22153 m .44551 .22149 L .44513 .22506 L F
.44566 .22153 m .44567 .22149 L .44551 .22149 L F
.46999 .22748 m .44567 .22149 L .44566 .22153 L F
.50016 .27424 m .49961 .26814 L .46917 .2691 L .988 .886 0 r
F
.47026 .27506 m .47034 .26666 L .44567 .22149 L .272 .048 0 r
F
.44565 .22153 m .44567 .22149 L .44547 .22112 L F
.47026 .27506 m .44567 .22149 L .44565 .22153 L F
.44567 .22149 m .44654 .21584 L .446 .21932 L 1 .971 0 r
F
.47011 .2217 m .44813 .21624 L .44567 .22149 L F
.44813 .21624 m .44654 .21584 L .44644 .21648 L F
.44573 .22136 m .44644 .21648 L .44567 .22149 L F
.44813 .21624 m .44644 .21648 L .44573 .22136 L F
.4701 .2215 m .47022 .21576 L .44596 .21143 L .874 .836 0 r
F
.47022 .21576 m .44686 .20578 L .44596 .21143 L .869 .838 0 r
F
.44654 .2158 m .44722 .2098 L .44634 .21544 L .302 .057 0 r
F
.49905 .26207 m .4694 .25702 L .46929 .26304 L .985 .897 0 r
F
.49905 .26207 m .49849 .25604 L .4694 .25702 L F
.49849 .25604 m .46952 .25103 L .4694 .25702 L .983 .902 0 r
F
.44652 .21584 m .44652 .21584 L .44567 .22147 L .287 .052 0 r
F
.44652 .21584 m .44649 .21576 L .44608 .21861 L F
.44652 .21584 m .44608 .21861 L .44567 .22147 L F
.49552 .22638 m .4949 .22059 L .4701 .2215 L .971 .927 0 r
F
.4949 .22059 m .47022 .21576 L .4701 .2215 L .97 .932 0 r
F
.47011 .2217 m .47023 .21595 L .44654 .2158 L 1 .971 0 r
F
.44649 .21576 m .44634 .21544 L .44567 .22149 L .287 .052 0 r
F
.44567 .22147 m .44567 .22149 L .44567 .22149 L F
.44649 .21576 m .44567 .22149 L .44567 .22147 L F
.446 .21932 m .44637 .2158 L .44566 .22149 L 1 .971 0 r
F
.44654 .21584 m .44652 .21584 L .446 .21932 L F
.44652 .21584 m .44637 .2158 L .446 .21932 L F
.44652 .21584 m .44654 .2158 L .44637 .2158 L F
.47011 .2217 m .44654 .2158 L .44652 .21584 L F
.49961 .26814 m .49905 .26207 L .46929 .26304 L .986 .891 0 r
F
.47034 .26666 m .47042 .25821 L .44654 .2158 L .287 .052 0 r
F
.44652 .21584 m .44654 .2158 L .44634 .21544 L F
.47034 .26666 m .44654 .2158 L .44652 .21584 L F
.44654 .2158 m .44742 .2102 L .44687 .21365 L 1 .977 0 r
F
.47023 .21595 m .44902 .2106 L .44654 .2158 L F
.44902 .2106 m .44742 .2102 L .44732 .21084 L F
.44661 .21566 m .44732 .21084 L .44654 .2158 L F
.44902 .2106 m .44732 .21084 L .44661 .21566 L F
.47022 .21576 m .47035 .21007 L .44686 .20578 L .869 .838 0 r
F
.47035 .21007 m .44776 .20018 L .44686 .20578 L .863 .84 0 r
F
.44742 .21015 m .4481 .20421 L .44722 .2098 L .315 .061 0 r
F
.49849 .25604 m .49791 .25005 L .46952 .25103 L .983 .902 0 r
F
.49791 .25005 m .46963 .24509 L .46952 .25103 L .982 .908 0 r
F
.4474 .21019 m .44737 .21012 L .44654 .21578 L .302 .057 0 r
F
.44737 .21012 m .44722 .2098 L .44654 .2158 L F
.4949 .22059 m .49427 .21485 L .47022 .21576 L .97 .932 0 r
F
.49427 .21485 m .47035 .21007 L .47022 .21576 L .968 .937 0 r
F
.47023 .21595 m .47035 .21026 L .44725 .21015 L 1 .977 0 r
F
.47042 .25821 m .47051 .24978 L .44742 .21015 L .302 .057 0 r
F
.4474 .21019 m .44742 .21015 L .44722 .2098 L F
.44742 .2102 m .4474 .21019 L .44653 .2158 L 1 .977 0 r
F
.47042 .25821 m .44742 .21015 L .4474 .21019 L .302 .057 0 r
F
.4474 .21019 m .44725 .21015 L .44718 .21066 L 1 .977 0 r
F
.4474 .21019 m .44718 .21066 L .44653 .2158 L F
.44742 .21015 m .44813 .20455 L .44725 .21015 L 1 .982 0 r
F
.47035 .21007 m .47047 .20442 L .44776 .20018 L .863 .84 0 r
F
.47047 .20442 m .44868 .19464 L .44776 .20018 L .858 .842 0 r
F
.44831 .20455 m .449 .19867 L .4481 .20421 L .328 .065 0 r
F
.44831 .20455 m .449 .19867 L .44831 .20455 L F
.47035 .21026 m .4483 .2046 L .44747 .21015 L 1 .982 0 r
F
.4483 .2046 m .44829 .20459 L .44747 .21015 L F
.49791 .25005 m .49732 .24409 L .46963 .24509 L .982 .908 0 r
F
.49732 .24409 m .46975 .23918 L .46963 .24509 L .98 .913 0 r
F
.47035 .21026 m .44831 .20455 L .44829 .20459 L 1 .982 0 r
F
.47051 .24978 m .4706 .24139 L .44831 .20455 L .315 .061 0 r
F
.44829 .20459 m .44831 .20455 L .4481 .20421 L F
.47051 .24978 m .44831 .20455 L .44829 .20459 L F
.49427 .21485 m .49363 .20914 L .47035 .21007 L .968 .937 0 r
F
.49363 .20914 m .47047 .20442 L .47035 .21007 L .966 .943 0 r
F
.47035 .21026 m .47047 .2046 L .44831 .20455 L 1 .982 0 r
F
.44825 .20452 m .4481 .20421 L .44742 .21015 L .315 .061 0 r
F
.44829 .20459 m .44831 .20455 L .44813 .20455 L 1 .982 0 r
F
.44831 .20455 m .44903 .199 L .44813 .20455 L 1 .987 0 r
F
.47047 .20442 m .47059 .19881 L .44868 .19464 L .858 .842 0 r
F
.47059 .19881 m .44961 .18915 L .44868 .19464 L .852 .843 0 r
F
.49298 .20349 m .47059 .19881 L .47047 .20442 L .964 .948 0 r
F
.46533 .19654 m .44961 .18924 L .44907 .19823 L .85 .84 0 r
F
.44776 .20018 m .44868 .19464 L .42717 .19266 L .997 .997 0 r
F
.44868 .19464 m .42889 .18726 L .42717 .19266 L .992 1 0 r
F
.44868 .19464 m .44961 .18915 L .42889 .18726 L F
.44776 .20018 m .42717 .19266 L .42548 .19811 L .997 .997 0 r
F
.44686 .20578 m .44776 .20018 L .42548 .19811 L 1 .993 0 r
F
.4481 .20421 m .449 .19867 L .4476 .19859 L 1 1 0 r
F
.44686 .20578 m .42548 .19811 L .42379 .20363 L 1 .993 0 r
F
.44596 .21143 m .44686 .20578 L .42379 .20363 L 1 .99 0 r
F
.44725 .20104 m .4476 .19859 L .4467 .20375 L 1 1 0 r
F
.4481 .20421 m .4476 .19859 L .44685 .2038 L F
.44915 .19896 m .449 .19867 L .44831 .20455 L .328 .065 0 r
F
.44605 .20397 m .42719 .19279 L .4255 .19825 L .87 .842 0 r
F
.44661 .20413 m .4461 .20383 L .44605 .20397 L F
.4461 .20383 m .42719 .19279 L .44605 .20397 L F
.44751 .20014 m .44784 .19866 L .4476 .19859 L F
.44739 .19933 m .4476 .19859 L .44728 .1985 L F
.44751 .20014 m .4476 .19859 L .44739 .19933 L F
.44666 .20373 m .44728 .1985 L .42719 .19279 L F
.44722 .2098 m .4481 .20421 L .44662 .20413 L 1 1 0 r
F
.44685 .2038 m .44725 .20104 L .4467 .20375 L F
.44813 .20455 m .44728 .1985 L .44666 .20373 L .87 .842 0 r
F
.44661 .20412 m .42719 .19279 L .44661 .20413 L F
.4467 .20375 m .42719 .19279 L .44661 .20412 L F
.4467 .20375 m .44661 .20412 L .44662 .20413 L 1 1 0 r
F
.4467 .20375 m .44661 .20412 L .44662 .20413 L .87 .842 0 r
F
.4467 .20375 m .42792 .19753 L .44661 .20412 L 1 1 0 r
F
.44705 .19843 m .42891 .18739 L .42719 .19279 L 1 .796 0 r
F
.4476 .19859 m .4471 .19829 L .44705 .19843 L F
.4471 .19829 m .42891 .18739 L .44705 .19843 L F
.4476 .19859 m .42891 .18739 L .4476 .19859 L F
.44769 .19823 m .42891 .18739 L .4476 .19859 L F
.44761 .19855 m .44761 .19855 L .4476 .19859 L 1 1 0 r
F
.44784 .19828 m .44769 .19823 L .44774 .1986 L F
.44769 .19823 m .4296 .19215 L .44667 .19822 L F
.44769 .19823 m .44667 .19822 L .44774 .1986 L F
.44769 .19823 m .44961 .18924 L .42891 .18739 L 1 .796 0 r
F
.449 .19867 m .44784 .19828 L .44774 .1986 L 1 1 0 r
F
.449 .19867 m .44907 .19823 L .44802 .19834 L F
.44903 .199 m .44907 .19824 L .44769 .19823 L 1 .796 0 r
F
.44907 .19823 m .44961 .18924 L .44769 .19823 L F
.44803 .19823 m .44991 .19317 L .44873 .19311 L 1 1 0 r
F
.44802 .19834 m .44806 .19823 L .44803 .19823 L F
.44806 .19823 m .44991 .19317 L .44803 .19823 L F
.44907 .19823 m .44991 .19317 L .44802 .19834 L F
.44907 .19824 m .44907 .19823 L .44769 .19823 L 1 .796 0 r
F
.44769 .19823 m .4476 .19859 L .44762 .1986 L F
.44761 .19855 m .4296 .19215 L .4476 .19859 L 1 1 0 r
F
.44961 .18915 m .43062 .18192 L .42889 .18726 L .988 1 0 r
F
.44961 .18924 m .43064 .18205 L .42891 .18739 L .99 1 0 r
F
.44873 .19311 m .43129 .18681 L .4296 .19215 L 1 1 0 r
F
.44991 .19317 m .44883 .1928 L .44873 .19311 L F
.44883 .1928 m .43129 .18681 L .44873 .19311 L F
.4476 .19859 m .4296 .19215 L .42792 .19753 L F
.44774 .1986 m .44761 .19855 L .4476 .19859 L F
.44662 .20413 m .44661 .20412 L .44661 .20413 L F
.44662 .20413 m .44661 .20412 L .44661 .20413 L .87 .842 0 r
F
.44661 .20412 m .44661 .20412 L .44661 .20413 L F
.44596 .21143 m .42379 .20363 L .42213 .20919 L 1 .99 0 r
F
.44507 .21713 m .44596 .21143 L .42213 .20919 L 1 .986 0 r
F
.44634 .21544 m .44722 .2098 L .44563 .20971 L 1 1 0 r
F
.44623 .20671 m .44661 .20413 L .44571 .20931 L F
.44661 .20417 m .44662 .20413 L .44661 .20413 L F
.44722 .2098 m .44662 .20413 L .44661 .20417 L F
.44722 .2098 m .44661 .20413 L .44585 .20936 L F
.44562 .20971 m .4255 .19825 L .42382 .20376 L .876 .842 0 r
F
.44563 .20971 m .44562 .20971 L .44562 .20971 L 1 1 0 r
F
.44563 .20971 m .44562 .2097 L .44562 .20971 L .876 .842 0 r
F
.44562 .2097 m .44562 .2097 L .44562 .20971 L F
.44507 .21713 m .42213 .20919 L .42049 .21481 L 1 .986 0 r
F
.44419 .22288 m .44507 .21713 L .42049 .21481 L 1 .982 0 r
F
.44547 .22112 m .44634 .21544 L .44465 .21534 L 1 1 0 r
F
.44524 .2124 m .44562 .20971 L .44473 .21493 L F
.44562 .20976 m .44563 .20971 L .44562 .20971 L F
.44634 .21544 m .44563 .20971 L .44562 .20976 L F
.44634 .21544 m .44562 .20971 L .44487 .21497 L F
.44463 .21534 m .42382 .20376 L .42216 .20933 L .882 .841 0 r
F
.44465 .21534 m .44463 .21533 L .44463 .21534 L 1 1 0 r
F
.44465 .21534 m .44463 .21533 L .44463 .21534 L .882 .841 0 r
F
.44463 .21533 m .44463 .21533 L .44463 .21534 L F
.44419 .22288 m .42049 .21481 L .41886 .22049 L 1 .982 0 r
F
.44332 .22868 m .44419 .22288 L .41886 .22049 L 1 .978 0 r
F
.44461 .22685 m .44547 .22112 L .44367 .22101 L 1 1 0 r
F
.44425 .21812 m .44463 .21534 L .44376 .22058 L F
.44464 .21538 m .44465 .21534 L .44463 .21534 L F
.44547 .22112 m .44465 .21534 L .44464 .21538 L F
.44547 .22112 m .44463 .21534 L .4439 .22062 L F
.44366 .22101 m .42216 .20933 L .42051 .21495 L .888 .841 0 r
F
.44367 .22101 m .44366 .221 L .44366 .22101 L 1 1 0 r
F
.44368 .22101 m .44366 .221 L .44366 .22101 L .888 .841 0 r
F
.44366 .221 m .44366 .221 L .44366 .22101 L F
.44332 .22868 m .41886 .22049 L .41726 .22622 L 1 .978 0 r
F
.44247 .23453 m .44332 .22868 L .41726 .22622 L 1 .974 0 r
F
.44376 .23262 m .44461 .22685 L .4427 .22672 L 1 .995 0 r
F
.44327 .22386 m .44366 .22101 L .44279 .22628 L 1 1 0 r
F
.44367 .22106 m .44367 .22101 L .44366 .22101 L F
.44461 .22685 m .44367 .22101 L .44367 .22106 L F
.44461 .22685 m .44366 .22101 L .44293 .22632 L F
.44269 .22672 m .42051 .21495 L .41889 .22063 L .894 .84 0 r
F
.4427 .22672 m .44269 .22672 L .44269 .22672 L 1 1 0 r
F
.44271 .22673 m .44269 .22672 L .44269 .22672 L .894 .84 0 r
F
.44269 .22672 m .44269 .22672 L .44269 .22672 L F
.44247 .23453 m .41726 .22622 L .41567 .23199 L 1 .974 0 r
F
.44162 .24043 m .44247 .23453 L .41567 .23199 L 1 .97 0 r
F
.44293 .23843 m .44376 .23262 L .44174 .23248 L 1 .99 0 r
F
.4423 .22962 m .44269 .22672 L .44183 .23202 L 1 .995 0 r
F
.4427 .22677 m .4427 .22672 L .44269 .22672 L F
.44376 .23262 m .4427 .22672 L .4427 .22677 L F
.44376 .23262 m .44269 .22672 L .44197 .23206 L F
.44173 .23248 m .41889 .22063 L .41728 .22635 L .9 .839 0 r
F
.44174 .23248 m .44173 .23248 L .44173 .23248 L 1 .995 0 r
F
.44175 .23248 m .44173 .23247 L .44173 .23248 L .9 .839 0 r
F
.44173 .23247 m .44173 .23247 L .44173 .23248 L F
.44162 .24043 m .41567 .23199 L .4141 .23782 L 1 .97 0 r
F
.44078 .24637 m .4141 .23782 L .41255 .24369 L 1 .966 0 r
F
.44078 .24637 m .44162 .24043 L .4141 .23782 L F
.4421 .24429 m .41669 .23656 L .41516 .24232 L 1 .985 0 r
F
.4421 .24429 m .44293 .23843 L .44079 .23828 L F
.4141 .23782 m .41567 .23199 L .38971 .22796 L 1 1 0 r
F
.41567 .23199 m .39201 .2223 L .38971 .22796 L F
.41567 .23199 m .41726 .22622 L .39201 .2223 L F
.41326 .23507 m .41728 .22635 L .39207 .22249 L 1 .731 0 r
F
.44026 .24373 m .44057 .24054 L .41669 .23656 L 1 .985 0 r
F
.44057 .24054 m .42293 .23701 L .41669 .23656 L F
.44293 .23843 m .44088 .2378 L .4408 .23822 L 1 .99 0 r
F
.44079 .23828 m .41689 .23583 L .42293 .23701 L F
.44293 .23843 m .4408 .23822 L .44079 .23828 L F
.4408 .23822 m .41689 .23583 L .44079 .23828 L F
.44088 .2378 m .44136 .23239 L .44084 .23778 L .906 .838 0 r
F
.44102 .23785 m .44102 .23782 L .44088 .2378 L 1 .99 0 r
F
.44293 .23843 m .44173 .23248 L .44102 .23785 L F
.44297 .23882 m .44169 .23372 L .44088 .2378 L .906 .838 0 r
F
.44102 .23782 m .44173 .23248 L .44088 .2378 L 1 .99 0 r
F
.44169 .23372 m .44136 .23239 L .44088 .2378 L .906 .838 0 r
F
.44297 .23882 m .44381 .233 L .44193 .23253 L F
.44174 .23253 m .44174 .23248 L .44173 .23248 L 1 .99 0 r
F
.44169 .23372 m .44193 .23253 L .44136 .23239 L .906 .838 0 r
F
.44293 .23843 m .44174 .23248 L .44174 .23253 L 1 .99 0 r
F
.44297 .23882 m .44193 .23253 L .44169 .23372 L .906 .838 0 r
F
.43577 .23532 m .41728 .22635 L .41689 .23583 L F
.41338 .23514 m .41689 .2358 L .41326 .23507 L 1 .731 0 r
F
.41415 .2356 m .41689 .23583 L .41338 .23514 L F
.41489 .23588 m .41503 .23567 L .41415 .2356 L 1 1 0 r
F
.41669 .23656 m .41689 .23583 L .41489 .23588 L F
.41689 .23583 m .41689 .2358 L .41338 .23514 L 1 .731 0 r
F
.41689 .2358 m .41728 .22635 L .41326 .23507 L F
.41689 .23583 m .41824 .23085 L .41489 .23588 L 1 1 0 r
F
.42293 .23701 m .41689 .23583 L .41669 .23656 L 1 .99 0 r
F
.41255 .24369 m .4141 .23782 L .38744 .23368 L 1 .999 0 r
F
.4141 .23782 m .38971 .22796 L .38744 .23368 L 1 1 0 r
F
.41516 .24232 m .41669 .23656 L .41415 .23625 L F
.41255 .24369 m .38744 .23368 L .38519 .23945 L 1 .999 0 r
F
.4117 .24178 m .38977 .22816 L .3875 .23387 L .927 .845 0 r
F
.41176 .24166 m .38977 .22816 L .4117 .24178 L F
.41224 .24194 m .38977 .22816 L .41223 .24195 L F
.41248 .24131 m .38977 .22816 L .41224 .24194 L F
.41227 .24195 m .41248 .24131 L .41223 .24195 L 1 1 0 r
F
.41516 .24232 m .41248 .24131 L .41227 .24195 L F
.41516 .24232 m .41415 .23625 L .41253 .24115 L F
.41249 .24132 m .41253 .24115 L .41248 .24131 L F
.41516 .24232 m .41253 .24115 L .41249 .24132 L F
.41338 .23604 m .39207 .22249 L .38977 .22816 L 1 .731 0 r
F
.41344 .23592 m .39207 .22249 L .41338 .23604 L F
.41409 .23557 m .39207 .22249 L .41391 .23622 L F
.41726 .22622 m .39434 .21669 L .39201 .2223 L 1 1 0 r
F
.41728 .22635 m .3944 .21688 L .39207 .22249 L F
.41584 .23056 m .396 .22238 L .39373 .22789 L F
.41824 .23085 m .41608 .23002 L .41584 .23056 L F
.41608 .23002 m .396 .22238 L .41584 .23056 L F
.41391 .23622 m .41344 .23592 L .41338 .23604 L 1 .731 0 r
F
.41248 .24131 m .41415 .23625 L .41391 .23622 L 1 1 0 r
F
.41248 .24131 m .41414 .23629 L .41391 .23622 L .927 .845 0 r
F
.41248 .24131 m .41391 .23622 L .38977 .22816 L F
.41248 .24131 m .41391 .23622 L .39149 .23346 L 1 1 0 r
F
.41391 .23622 m .39373 .22789 L .39149 .23346 L F
.41415 .23625 m .41393 .23616 L .41391 .23622 L F
.41393 .23616 m .39373 .22789 L .41391 .23622 L F
.41669 .23656 m .41439 .23569 L .41415 .23625 L F
.41415 .2356 m .41409 .23557 L .41391 .23622 L 1 .731 0 r
F
.41439 .23569 m .39373 .22789 L .41415 .23625 L 1 1 0 r
F
.41684 .23719 m .41415 .2356 L .41391 .23622 L 1 .731 0 r
F
.44047 .25611 m .44078 .24637 L .41255 .24369 L 1 .703 0 r
F
.44128 .25018 m .41516 .24232 L .41365 .24812 L 1 .98 0 r
F
.44128 .25018 m .4421 .24429 L .41516 .24232 L F
.41531 .24296 m .41684 .23719 L .41414 .23629 L .927 .845 0 r
F
.41365 .24812 m .41516 .24232 L .41223 .24195 L 1 1 0 r
F
.41531 .24296 m .41414 .23629 L .41248 .24131 L .927 .845 0 r
F
.41248 .24131 m .41224 .24194 L .41226 .24196 L F
.41102 .24961 m .38519 .23945 L .38298 .24527 L 1 .996 0 r
F
.41102 .24961 m .41255 .24369 L .38519 .23945 L F
.41216 .25396 m .41365 .24812 L .4106 .24773 L 1 1 0 r
F
.4109 .24682 m .41223 .24195 L .41082 .24707 L F
.41365 .24812 m .41223 .24195 L .41083 .24707 L F
.41395 .2488 m .44128 .25018 L .41365 .24812 L .972 .152 0 r
F
.41057 .24773 m .3875 .23387 L .38526 .23964 L .933 .845 0 r
F
.4106 .24773 m .41058 .24772 L .41057 .24773 L 1 1 0 r
F
.4106 .24774 m .41058 .24772 L .41057 .24773 L .933 .845 0 r
F
.41058 .24772 m .41057 .24772 L .41057 .24773 L F
.40952 .25557 m .38298 .24527 L .38079 .25114 L 1 .992 0 r
F
.40952 .25557 m .41102 .24961 L .38298 .24527 L F
.40803 .26158 m .40952 .25557 L .38079 .25114 L 1 .988 0 r
F
.41069 .25984 m .41216 .25396 L .40896 .25355 L 1 1 0 r
F
.40929 .25251 m .41057 .24773 L .40918 .25286 L F
.41059 .24779 m .4106 .24773 L .41057 .24773 L F
.41216 .25396 m .4106 .24773 L .41059 .24779 L F
.41216 .25396 m .41057 .24773 L .40919 .25287 L F
.41247 .25465 m .41248 .25462 L .41216 .25396 L .145 .021 0 r
F
.40893 .25354 m .38526 .23964 L .38305 .24546 L .939 .844 0 r
F
.40896 .25355 m .40893 .25353 L .40893 .25354 L 1 1 0 r
F
.40896 .25355 m .40893 .25354 L .40893 .25354 L .939 .844 0 r
F
.40893 .25354 m .40893 .25354 L .40893 .25354 L F
.40803 .26158 m .38079 .25114 L .37863 .25705 L 1 .988 0 r
F
.40656 .26763 m .40803 .26158 L .37863 .25705 L 1 .984 0 r
F
.40924 .26577 m .41069 .25984 L .40733 .2594 L 1 1 0 r
F
.40769 .25823 m .40893 .25354 L .40755 .2587 L F
.40895 .25361 m .40896 .25355 L .40893 .25354 L F
.41069 .25984 m .40896 .25355 L .40895 .25361 L F
.41069 .25984 m .40893 .25354 L .40757 .2587 L F
.41101 .26053 m .41102 .2605 L .41069 .25984 L .135 .02 0 r
F
.40729 .2594 m .38305 .24546 L .38086 .25132 L .944 .844 0 r
F
.40733 .2594 m .4073 .25939 L .40729 .2594 L 1 1 0 r
F
.40732 .25941 m .4073 .25939 L .40729 .2594 L .944 .844 0 r
F
.4073 .25939 m .4073 .25939 L .40729 .2594 L F
.40656 .26763 m .37863 .25705 L .37651 .26301 L 1 .984 0 r
F
.40512 .27373 m .40656 .26763 L .37651 .26301 L 1 .98 0 r
F
.40781 .27173 m .40924 .26577 L .40571 .2653 L 1 1 0 r
F
.40612 .26398 m .40729 .2594 L .40593 .26457 L F
.40731 .25946 m .40733 .2594 L .40729 .2594 L F
.40924 .26577 m .40733 .2594 L .40731 .25946 L F
.40924 .26577 m .40729 .2594 L .40596 .26458 L F
.40957 .26646 m .40958 .26643 L .40924 .26577 L .126 .018 0 r
F
.40568 .26529 m .38086 .25132 L .37871 .25723 L .95 .843 0 r
F
.40571 .2653 m .40568 .26529 L .40568 .26529 L 1 1 0 r
F
.40571 .2653 m .40568 .26529 L .40568 .26529 L .95 .843 0 r
F
.40568 .26529 m .40568 .26529 L .40568 .26529 L F
.40512 .27373 m .37651 .26301 L .37441 .26901 L 1 .98 0 r
F
.40369 .27986 m .37441 .26901 L .37235 .27506 L 1 .976 0 r
F
.40369 .27986 m .40512 .27373 L .37441 .26901 L F
.4064 .27773 m .37861 .26782 L .37656 .2737 L 1 .996 0 r
F
.4064 .27773 m .40781 .27173 L .40411 .27123 L F
.37441 .26901 m .37651 .26301 L .3478 .25674 L 1 1 0 r
F
.37651 .26301 m .35056 .25091 L .3478 .25674 L F
.37651 .26301 m .37863 .25705 L .35056 .25091 L F
.37327 .26521 m .37871 .25723 L .35069 .25114 L 1 .663 0 r
F
.40304 .27653 m .40368 .27336 L .37861 .26782 L 1 .996 0 r
F
.40368 .27336 m .38738 .26899 L .37861 .26782 L F
.40815 .27242 m .40816 .27239 L .40781 .27173 L .119 .017 0 r
F
.40801 .27238 m .40943 .26642 L .40587 .26535 L .955 .842 0 r
F
.4057 .26536 m .40571 .2653 L .40568 .26529 L 1 1 0 r
F
.40781 .27173 m .40568 .26529 L .40437 .27049 L F
.40565 .26607 m .40587 .26535 L .40532 .26519 L .955 .842 0 r
F
.40781 .27173 m .40433 .27048 L .40415 .2711 L 1 1 0 r
F
.40411 .27123 m .37898 .26678 L .38738 .26899 L F
.40781 .27173 m .40415 .2711 L .40411 .27123 L F
.40415 .2711 m .37898 .26678 L .40411 .27123 L F
.40433 .27048 m .40532 .26519 L .40426 .27044 L .955 .842 0 r
F
.40437 .27049 m .40437 .27048 L .40433 .27048 L 1 1 0 r
F
.40801 .27238 m .40565 .26607 L .40433 .27048 L .955 .842 0 r
F
.40437 .27048 m .40568 .26529 L .40433 .27048 L 1 1 0 r
F
.40565 .26607 m .40532 .26519 L .40433 .27048 L .955 .842 0 r
F
.40781 .27173 m .40571 .2653 L .4057 .26536 L 1 1 0 r
F
.40801 .27238 m .40587 .26535 L .40565 .26607 L .955 .842 0 r
F
.39885 .26765 m .37871 .25723 L .37898 .26678 L F
.37344 .26531 m .37898 .26674 L .37327 .26521 L 1 .663 0 r
F
.3747 .2661 m .37898 .26678 L .37344 .26531 L F
.37593 .26664 m .37624 .26634 L .3747 .2661 L 1 1 0 r
F
.37861 .26782 m .37898 .26678 L .37593 .26664 L F
.37898 .26678 m .37898 .26674 L .37344 .26531 L 1 .663 0 r
F
.37898 .26674 m .37871 .25723 L .37327 .26521 L F
.37898 .26678 m .38068 .26198 L .37593 .26664 L 1 1 0 r
F
.38738 .26899 m .37898 .26678 L .37861 .26782 L F
.37235 .27506 m .37441 .26901 L .34507 .26262 L F
.37441 .26901 m .3478 .25674 L .34507 .26262 L F
.37656 .2737 m .37861 .26782 L .37455 .26704 L F
.37235 .27506 m .34507 .26262 L .34238 .26856 L F
.37153 .27264 m .34793 .25697 L .3452 .26285 L .977 .852 0 r
F
.37159 .27253 m .34793 .25697 L .37153 .27264 L F
.37204 .27281 m .34793 .25697 L .37203 .27282 L F
.40229 .28603 m .37235 .27506 L .37031 .28115 L 1 .972 0 r
F
.40229 .28603 m .40369 .27986 L .37235 .27506 L F
.37455 .27962 m .37656 .2737 L .37209 .27283 L 1 1 0 r
F
.37206 .27291 m .37209 .27283 L .37203 .27282 L F
.37455 .27962 m .37209 .27283 L .37206 .27291 L F
.37239 .27186 m .37395 .26687 L .34793 .25697 L .977 .852 0 r
F
.37247 .27191 m .37395 .26687 L .37239 .27186 L F
.37247 .27191 m .37455 .26704 L .37426 .26699 L 1 1 0 r
F
.37656 .2737 m .37455 .26704 L .37247 .27191 L F
.40501 .28377 m .37656 .2737 L .37455 .27962 L 1 .992 0 r
F
.40501 .28377 m .4064 .27773 L .37656 .2737 L F
.37247 .27191 m .34793 .25697 L .37204 .27281 L .977 .852 0 r
F
.37209 .27283 m .37204 .27281 L .37203 .27282 L 1 1 0 r
F
.37247 .27191 m .35099 .26252 L .37209 .27283 L F
.37247 .27191 m .37204 .27281 L .37207 .27284 L .977 .852 0 r
F
.37031 .28115 m .34238 .26856 L .33973 .27453 L 1 1 0 r
F
.37031 .28115 m .37235 .27506 L .34238 .26856 L F
.40091 .29224 m .37031 .28115 L .36831 .28728 L 1 .968 0 r
F
.40091 .29224 m .40229 .28603 L .37031 .28115 L F
.37455 .27962 m .37217 .27321 L .37026 .27776 L 1 1 0 r
F
.37217 .27321 m .37203 .27282 L .37026 .27776 L F
.40364 .28984 m .37455 .27962 L .37256 .28558 L 1 .987 0 r
F
.40364 .28984 m .40501 .28377 L .37455 .27962 L F
.37501 .28059 m .37701 .27467 L .37171 .2727 L .983 .853 0 r
F
.37018 .27771 m .37171 .2727 L .3452 .26285 L F
.37256 .28558 m .37455 .27962 L .36988 .27871 L 1 1 0 r
F
.36982 .2787 m .3452 .26285 L .34252 .26878 L .983 .853 0 r
F
.36988 .27871 m .36983 .27869 L .36982 .2787 L 1 1 0 r
F
.36986 .27872 m .36982 .27869 L .36982 .2787 L .983 .853 0 r
F
.36982 .27869 m .36982 .27869 L .36982 .2787 L F
.36831 .28728 m .33973 .27453 L .33712 .28055 L 1 1 0 r
F
.36831 .28728 m .37031 .28115 L .33973 .27453 L F
.39955 .29848 m .36831 .28728 L .36633 .29344 L 1 .964 0 r
F
.39955 .29848 m .40091 .29224 L .36831 .28728 L F
.37256 .28558 m .36997 .27906 L .36808 .28365 L 1 1 0 r
F
.36997 .27906 m .36982 .2787 L .36808 .28365 L F
.36985 .27878 m .36988 .27871 L .36982 .2787 L F
.37256 .28558 m .36988 .27871 L .36985 .27878 L F
.40229 .29594 m .37256 .28558 L .3706 .29158 L 1 .982 0 r
F
.40229 .29594 m .40364 .28984 L .37256 .28558 L F
.37305 .28654 m .37501 .28059 L .36949 .27858 L .988 .852 0 r
F
.36799 .2836 m .36949 .27858 L .34252 .26878 L F
.3706 .29158 m .37256 .28558 L .36769 .28463 L 1 1 0 r
F
.36763 .28462 m .34252 .26878 L .33987 .27475 L .988 .852 0 r
F
.36769 .28463 m .36764 .2846 L .36763 .28462 L 1 1 0 r
F
.36767 .28463 m .36763 .28461 L .36763 .28462 L .988 .852 0 r
F
.36763 .28461 m .36763 .28461 L .36763 .28462 L F
.36633 .29344 m .33712 .28055 L .33455 .28662 L 1 1 0 r
F
.36633 .29344 m .36831 .28728 L .33712 .28055 L F
.39821 .30476 m .39955 .29848 L .36633 .29344 L 1 .96 0 r
F
.3706 .29158 m .36778 .28496 L .36591 .28957 L 1 1 0 r
F
.36778 .28496 m .36763 .28462 L .36591 .28957 L F
.36766 .2847 m .36769 .28463 L .36763 .28462 L F
.3706 .29158 m .36769 .28463 L .36766 .2847 L F
.40097 .30208 m .3706 .29158 L .36868 .29762 L 1 .977 0 r
F
.40097 .30208 m .40229 .29594 L .3706 .29158 L F
.37111 .29253 m .37305 .28654 L .3673 .2845 L .994 .852 0 r
F
.36582 .28952 m .3673 .2845 L .33987 .27475 L F
.36868 .29762 m .3706 .29158 L .36552 .29058 L 1 1 0 r
F
.36546 .29057 m .33987 .27475 L .33727 .28077 L .994 .852 0 r
F
.36552 .29058 m .36547 .29055 L .36546 .29057 L 1 1 0 r
F
.3655 .29058 m .36546 .29056 L .36546 .29057 L .994 .852 0 r
F
.36546 .29056 m .36546 .29056 L .36546 .29057 L F
.36439 .29965 m .36633 .29344 L .33455 .28662 L 1 .999 0 r
F
.36868 .29762 m .36561 .29089 L .36376 .29553 L 1 1 0 r
F
.36561 .29089 m .36546 .29057 L .36376 .29553 L F
.3655 .29065 m .36552 .29058 L .36546 .29057 L F
.36868 .29762 m .36552 .29058 L .3655 .29065 L F
.39966 .30825 m .40097 .30208 L .36868 .29762 L 1 .972 0 r
F
.36921 .29856 m .37111 .29253 L .36512 .29045 L .999 .851 0 r
F
.36368 .29548 m .36512 .29045 L .33727 .28077 L F
.36679 .30369 m .36868 .29762 L .36336 .29657 L 1 1 0 r
F
.36331 .29656 m .33727 .28077 L .3347 .28683 L .999 .851 0 r
F
.36336 .29657 m .36332 .29654 L .36331 .29656 L 1 1 0 r
F
.36335 .29657 m .36331 .29655 L .36331 .29656 L .999 .851 0 r
F
.36331 .29655 m .36331 .29655 L .36331 .29656 L F
.36335 .29663 m .36336 .29657 L .36331 .29656 L 1 1 0 r
F
.36679 .30369 m .36336 .29657 L .36335 .29663 L F
.36679 .30369 m .36331 .29656 L .36164 .30152 L F
.36164 .30152 m .36349 .29662 L .36331 .29656 L 1 .85 0 r
F
.36164 .30152 m .36331 .29656 L .3347 .28683 L F
.36164 .30152 m .35598 .29843 L .33612 .29617 L F
.35598 .29843 m .3347 .28683 L .33612 .29617 L F
.32856 .29363 m .33612 .29613 L .32836 .2935 L 1 .562 0 r
F
.33038 .29481 m .33612 .29617 L .32856 .29363 L F
.33212 .29571 m .33264 .29534 L .33038 .29481 L 1 1 0 r
F
.33557 .2975 m .33612 .29617 L .33212 .29571 L F
.33612 .29617 m .33612 .29613 L .32856 .29363 L 1 .562 0 r
F
.33612 .29613 m .3347 .28683 L .32836 .2935 L F
.33612 .29617 m .33804 .29156 L .33212 .29571 L 1 1 0 r
F
.34669 .2997 m .33612 .29617 L .33557 .2975 L F
.33652 .29878 m .33612 .29617 L .33038 .29481 L 1 .562 0 r
F
.33038 .29481 m .33804 .29156 L .30957 .28403 L 1 1 0 r
F
.33264 .29534 m .33804 .29156 L .33038 .29481 L F
.36164 .30152 m .36331 .29656 L .36162 .30151 L F
.36331 .29656 m .34055 .28566 L .33804 .29156 L F
.36331 .29655 m .33727 .28077 L .36331 .29656 L .999 .851 0 r
F
.36376 .29553 m .33727 .28077 L .36331 .29655 L F
.36376 .29553 m .36332 .29654 L .36336 .29657 L 1 1 0 r
F
.36376 .29553 m .36331 .29655 L .36335 .29657 L .999 .851 0 r
F
.36376 .29553 m .34055 .28566 L .36332 .29654 L 1 1 0 r
F
.36332 .29654 m .34055 .28566 L .36331 .29656 L F
.36868 .29762 m .36376 .29553 L .36336 .29657 L F
.36376 .29553 m .36512 .29045 L .36368 .29548 L .999 .851 0 r
F
.36921 .29856 m .36546 .29111 L .36376 .29553 L F
.36546 .29111 m .36512 .29045 L .36376 .29553 L F
.36162 .30151 m .36331 .29656 L .33804 .29156 L 1 1 0 r
F
.36921 .29856 m .36376 .29553 L .36335 .29657 L .999 .851 0 r
F
.36376 .29553 m .36546 .29057 L .36373 .29551 L 1 1 0 r
F
.36546 .29057 m .34311 .27981 L .34055 .28566 L F
.36546 .29056 m .33987 .27475 L .36546 .29057 L .994 .852 0 r
F
.36591 .28957 m .33987 .27475 L .36546 .29056 L F
.36591 .28957 m .36547 .29055 L .36552 .29058 L 1 1 0 r
F
.36591 .28957 m .36546 .29056 L .3655 .29058 L .994 .852 0 r
F
.36591 .28957 m .34311 .27981 L .36547 .29055 L 1 1 0 r
F
.36547 .29055 m .34311 .27981 L .36546 .29057 L F
.3706 .29158 m .36591 .28957 L .36552 .29058 L F
.36591 .28957 m .3673 .2845 L .36582 .28952 L .994 .852 0 r
F
.37111 .29253 m .36762 .28518 L .36591 .28957 L F
.36762 .28518 m .3673 .2845 L .36591 .28957 L F
.36373 .29551 m .36546 .29057 L .34055 .28566 L 1 1 0 r
F
.37111 .29253 m .36591 .28957 L .3655 .29058 L .994 .852 0 r
F
.36591 .28957 m .36763 .28462 L .36587 .28955 L 1 1 0 r
F
.36763 .28462 m .3457 .274 L .34311 .27981 L F
.36763 .28461 m .34252 .26878 L .36763 .28462 L .988 .852 0 r
F
.36808 .28365 m .34252 .26878 L .36763 .28461 L F
.36808 .28365 m .36764 .2846 L .36769 .28463 L 1 1 0 r
F
.36808 .28365 m .36763 .28461 L .36767 .28463 L .988 .852 0 r
F
.36808 .28365 m .3457 .274 L .36764 .2846 L 1 1 0 r
F
.36764 .2846 m .3457 .274 L .36763 .28462 L F
.37256 .28558 m .36808 .28365 L .36769 .28463 L F
.36808 .28365 m .36949 .27858 L .36799 .2836 L .988 .852 0 r
F
.37305 .28654 m .36981 .27929 L .36808 .28365 L F
.36981 .27929 m .36949 .27858 L .36808 .28365 L F
.36587 .28955 m .36763 .28462 L .34311 .27981 L 1 1 0 r
F
.37305 .28654 m .36808 .28365 L .36767 .28463 L .988 .852 0 r
F
.36808 .28365 m .36982 .2787 L .36802 .28362 L 1 1 0 r
F
.36982 .2787 m .34832 .26824 L .3457 .274 L F
.36982 .27869 m .3452 .26285 L .36982 .2787 L .983 .853 0 r
F
.37026 .27776 m .3452 .26285 L .36982 .27869 L F
.37026 .27776 m .36983 .27869 L .36988 .27871 L 1 1 0 r
F
.37026 .27776 m .36982 .27869 L .36986 .27872 L .983 .853 0 r
F
.37026 .27776 m .34832 .26824 L .36983 .27869 L 1 1 0 r
F
.36983 .27869 m .34832 .26824 L .36982 .2787 L F
.37455 .27962 m .37026 .27776 L .36988 .27871 L F
.37026 .27776 m .37171 .2727 L .37018 .27771 L .983 .853 0 r
F
.37501 .28059 m .37202 .27344 L .37026 .27776 L F
.37202 .27344 m .37171 .2727 L .37026 .27776 L F
.36802 .28362 m .36982 .2787 L .3457 .274 L 1 1 0 r
F
.37501 .28059 m .37026 .27776 L .36986 .27872 L .983 .853 0 r
F
.37026 .27776 m .37203 .27282 L .3702 .27773 L 1 1 0 r
F
.37203 .27282 m .35099 .26252 L .34832 .26824 L F
.37203 .27282 m .37159 .27253 L .37153 .27264 L .977 .852 0 r
F
.37204 .27281 m .35099 .26252 L .37203 .27282 L 1 1 0 r
F
.37656 .2737 m .37247 .27191 L .37209 .27283 L F
.37701 .27467 m .37425 .26762 L .37247 .27191 L .977 .852 0 r
F
.37425 .26762 m .37414 .26734 L .37247 .27191 L F
.37414 .26734 m .37395 .26687 L .37247 .27191 L F
.37412 .2673 m .37426 .26699 L .37395 .26687 L F
.37701 .27467 m .37426 .26699 L .37412 .2673 L F
.37247 .27191 m .37426 .26699 L .35099 .26252 L 1 1 0 r
F
.37376 .2668 m .35069 .25114 L .34793 .25697 L 1 .663 0 r
F
.37382 .26669 m .35069 .25114 L .37376 .2668 L F
.3747 .2661 m .35069 .25114 L .37426 .26699 L F
.37863 .25705 m .35337 .24512 L .35056 .25091 L 1 1 0 r
F
.37871 .25723 m .35349 .24536 L .35069 .25114 L F
.37682 .26125 m .35644 .25123 L .3537 .25685 L F
.38068 .26198 m .37725 .26046 L .37682 .26125 L F
.37725 .26046 m .35644 .25123 L .37682 .26125 L F
.37426 .26699 m .37382 .26669 L .37376 .2668 L 1 .663 0 r
F
.37455 .26704 m .3743 .26692 L .37426 .26699 L 1 1 0 r
F
.37861 .26782 m .37499 .26623 L .37455 .26704 L F
.37499 .26623 m .3537 .25685 L .37455 .26704 L F
.37904 .2688 m .3747 .2661 L .37426 .26699 L 1 .663 0 r
F
.3743 .26692 m .3743 .26692 L .37426 .26699 L 1 1 0 r
F
.37426 .26699 m .3537 .25685 L .35099 .26252 L F
.3743 .26692 m .3537 .25685 L .37426 .26699 L F
.37701 .27467 m .37904 .2688 L .37426 .26699 L .977 .852 0 r
F
.37207 .27284 m .37204 .27281 L .37203 .27282 L F
.3702 .27773 m .37203 .27282 L .34832 .26824 L 1 1 0 r
F
.37701 .27467 m .37247 .27191 L .37207 .27284 L .977 .852 0 r
F
.37904 .2688 m .37898 .26678 L .3747 .2661 L 1 .663 0 r
F
.3747 .2661 m .38068 .26198 L .3537 .25685 L 1 1 0 r
F
.37624 .26634 m .38068 .26198 L .3747 .2661 L F
.40433 .27048 m .39885 .26765 L .37898 .26678 L .955 .842 0 r
F
.40415 .2711 m .40148 .27006 L .37898 .26678 L 1 1 0 r
F
.40433 .27048 m .38068 .26198 L .40415 .2711 L F
.40433 .27048 m .37898 .26678 L .37898 .26684 L .955 .842 0 r
F
.40148 .27006 m .38068 .26198 L .37898 .26678 L 1 1 0 r
F
.40368 .27336 m .40411 .27123 L .38738 .26899 L 1 .996 0 r
F
.4064 .27773 m .40411 .27123 L .40304 .27653 L F
.40426 .27044 m .40532 .26519 L .37871 .25723 L .955 .842 0 r
F
.40801 .27238 m .40433 .27048 L .37904 .2688 L F
.40433 .27048 m .37898 .26684 L .37904 .2688 L F
.40433 .27048 m .40568 .26529 L .38068 .26198 L 1 1 0 r
F
.40568 .26529 m .38279 .25619 L .38068 .26198 L F
.40568 .26529 m .38086 .25132 L .40568 .26529 L .95 .843 0 r
F
.40593 .26457 m .38086 .25132 L .40568 .26529 L F
.40593 .26457 m .40568 .26529 L .40571 .2653 L 1 1 0 r
F
.40593 .26457 m .40568 .26529 L .40571 .2653 L .95 .843 0 r
F
.40593 .26457 m .38279 .25619 L .40568 .26529 L 1 1 0 r
F
.40568 .26529 m .38279 .25619 L .40568 .26529 L F
.40924 .26577 m .40593 .26457 L .40571 .2653 L F
.40943 .26642 m .41087 .26049 L .40749 .25946 L .95 .843 0 r
F
.40727 .26021 m .40749 .25946 L .40695 .25929 L F
.40943 .26642 m .40749 .25946 L .40727 .26021 L F
.40587 .26453 m .40695 .25929 L .38086 .25132 L F
.40596 .26458 m .40612 .26398 L .40593 .26457 L 1 1 0 r
F
.40943 .26642 m .40695 .25929 L .40587 .26453 L .95 .843 0 r
F
.40943 .26642 m .40593 .26457 L .40571 .2653 L F
.40593 .26457 m .40729 .2594 L .38279 .25619 L 1 1 0 r
F
.40729 .2594 m .38492 .25043 L .38279 .25619 L F
.4073 .25939 m .38305 .24546 L .40729 .2594 L .944 .844 0 r
F
.40755 .2587 m .38305 .24546 L .4073 .25939 L F
.40755 .2587 m .4073 .25939 L .40733 .2594 L 1 1 0 r
F
.40755 .2587 m .4073 .25939 L .40732 .25941 L .944 .844 0 r
F
.40755 .2587 m .38492 .25043 L .4073 .25939 L 1 1 0 r
F
.4073 .25939 m .38492 .25043 L .40729 .2594 L F
.41069 .25984 m .40755 .2587 L .40733 .2594 L F
.41087 .26049 m .41233 .25461 L .40913 .25361 L .944 .844 0 r
F
.40889 .25438 m .40913 .25361 L .40859 .25344 L F
.41087 .26049 m .40913 .25361 L .40889 .25438 L F
.40748 .25866 m .40859 .25344 L .38305 .24546 L F
.40757 .2587 m .40769 .25823 L .40755 .2587 L 1 1 0 r
F
.41087 .26049 m .40859 .25344 L .40748 .25866 L .944 .844 0 r
F
.41087 .26049 m .40755 .2587 L .40732 .25941 L F
.40755 .2587 m .40893 .25354 L .38492 .25043 L 1 1 0 r
F
.40893 .25354 m .38708 .24473 L .38492 .25043 L F
.40893 .25354 m .38526 .23964 L .40893 .25354 L .939 .844 0 r
F
.40918 .25286 m .38526 .23964 L .40893 .25354 L F
.40918 .25286 m .40893 .25353 L .40896 .25355 L 1 1 0 r
F
.40918 .25286 m .40893 .25354 L .40896 .25355 L .939 .844 0 r
F
.40918 .25286 m .38708 .24473 L .40893 .25353 L 1 1 0 r
F
.40893 .25353 m .38708 .24473 L .40893 .25354 L F
.41216 .25396 m .40918 .25286 L .40896 .25355 L F
.41233 .25461 m .41381 .24876 L .41079 .24779 L .939 .844 0 r
F
.41053 .2486 m .41079 .24779 L .41024 .24762 L F
.41233 .25461 m .41079 .24779 L .41053 .2486 L F
.40911 .25283 m .41024 .24762 L .38526 .23964 L F
.40919 .25287 m .40929 .25251 L .40918 .25286 L 1 1 0 r
F
.41233 .25461 m .41024 .24762 L .40911 .25283 L .939 .844 0 r
F
.41233 .25461 m .40918 .25286 L .40896 .25355 L F
.40918 .25286 m .41057 .24773 L .38708 .24473 L 1 1 0 r
F
.41057 .24773 m .38927 .23907 L .38708 .24473 L F
.41057 .24772 m .3875 .23387 L .41057 .24773 L .933 .845 0 r
F
.41082 .24707 m .3875 .23387 L .41058 .24772 L F
.41082 .24707 m .41058 .24772 L .4106 .24773 L 1 1 0 r
F
.41082 .24707 m .41058 .24772 L .4106 .24774 L .933 .845 0 r
F
.41082 .24707 m .38927 .23907 L .41058 .24772 L 1 1 0 r
F
.41058 .24772 m .38927 .23907 L .41057 .24773 L F
.41365 .24812 m .41082 .24707 L .4106 .24773 L F
.41381 .24876 m .41531 .24296 L .41246 .24202 L .933 .845 0 r
F
.41219 .24285 m .41246 .24202 L .41191 .24184 L F
.41381 .24876 m .41246 .24202 L .41219 .24285 L F
.41076 .24703 m .41191 .24184 L .3875 .23387 L F
.41083 .24707 m .4109 .24682 L .41082 .24707 L 1 1 0 r
F
.41381 .24876 m .41191 .24184 L .41076 .24703 L .933 .845 0 r
F
.41381 .24876 m .41082 .24707 L .4106 .24774 L F
.41082 .24707 m .41223 .24195 L .38927 .23907 L 1 1 0 r
F
.41223 .24195 m .39149 .23346 L .38927 .23907 L F
.41223 .24195 m .41176 .24166 L .4117 .24178 L .927 .845 0 r
F
.41248 .24131 m .39149 .23346 L .41223 .24195 L 1 1 0 r
F
.41226 .24196 m .41224 .24194 L .41223 .24195 L .927 .845 0 r
F
.41531 .24296 m .41248 .24131 L .41226 .24196 L F
.41684 .23719 m .41689 .23583 L .41415 .2356 L 1 .731 0 r
F
.41415 .2356 m .41824 .23085 L .39373 .22789 L 1 1 0 r
F
.41503 .23567 m .41824 .23085 L .41415 .2356 L F
.44088 .2378 m .43577 .23532 L .41689 .23583 L .906 .838 0 r
F
.4408 .23822 m .43907 .23766 L .41689 .23583 L 1 .99 0 r
F
.44088 .2378 m .41824 .23085 L .4408 .23822 L F
.44088 .2378 m .41689 .23583 L .41689 .2359 L .906 .838 0 r
F
.43907 .23766 m .41824 .23085 L .41689 .23583 L 1 .99 0 r
F
.44057 .24054 m .44079 .23828 L .42293 .23701 L 1 .985 0 r
F
.4421 .24429 m .44079 .23828 L .44026 .24373 L F
.44084 .23778 m .44136 .23239 L .41728 .22635 L .906 .838 0 r
F
.44297 .23882 m .44088 .2378 L .41684 .23719 L F
.44088 .2378 m .41689 .2359 L .41684 .23719 L F
.44088 .2378 m .44173 .23248 L .41824 .23085 L 1 .99 0 r
F
.44173 .23248 m .41981 .22518 L .41824 .23085 L 1 .995 0 r
F
.44173 .23247 m .41889 .22063 L .44173 .23248 L .9 .839 0 r
F
.44173 .23248 m .41981 .22518 L .44173 .23248 L 1 .995 0 r
F
.44376 .23262 m .44183 .23202 L .44174 .23248 L F
.44183 .23202 m .41889 .22063 L .44173 .23247 L .9 .839 0 r
F
.44183 .23202 m .44173 .23248 L .44174 .23248 L 1 .995 0 r
F
.44183 .23202 m .44173 .23247 L .44175 .23248 L .9 .839 0 r
F
.44183 .23202 m .41981 .22518 L .44173 .23248 L 1 .995 0 r
F
.44381 .233 m .44465 .22722 L .4429 .22677 L .9 .839 0 r
F
.44265 .22801 m .4429 .22677 L .44233 .22663 L F
.44381 .233 m .4429 .22677 L .44265 .22801 L F
.44179 .232 m .44233 .22663 L .41889 .22063 L F
.44197 .23206 m .4423 .22962 L .44183 .23202 L 1 .995 0 r
F
.44381 .233 m .44233 .22663 L .44179 .232 L .9 .839 0 r
F
.44381 .233 m .44183 .23202 L .44175 .23248 L F
.44183 .23202 m .44269 .22672 L .41981 .22518 L 1 .995 0 r
F
.44269 .22672 m .4214 .21955 L .41981 .22518 L 1 1 0 r
F
.44269 .22672 m .42051 .21495 L .44269 .22672 L .894 .84 0 r
F
.44269 .22672 m .4214 .21955 L .44269 .22672 L 1 1 0 r
F
.44461 .22685 m .44279 .22628 L .4427 .22672 L F
.44279 .22628 m .42051 .21495 L .44269 .22672 L .894 .84 0 r
F
.44279 .22628 m .44269 .22672 L .4427 .22672 L 1 1 0 r
F
.44279 .22628 m .44269 .22672 L .44271 .22673 L .894 .84 0 r
F
.44279 .22628 m .4214 .21955 L .44269 .22672 L 1 1 0 r
F
.44465 .22722 m .44551 .22149 L .44387 .22106 L .894 .84 0 r
F
.44361 .22234 m .44387 .22106 L .4433 .22091 L F
.44465 .22722 m .44387 .22106 L .44361 .22234 L F
.44275 .22626 m .4433 .22091 L .42051 .21495 L F
.44293 .22632 m .44327 .22386 L .44279 .22628 L 1 1 0 r
F
.44465 .22722 m .4433 .22091 L .44275 .22626 L .894 .84 0 r
F
.44465 .22722 m .44279 .22628 L .44271 .22673 L F
.44279 .22628 m .44366 .22101 L .4214 .21955 L 1 1 0 r
F
.44366 .22101 m .423 .21398 L .4214 .21955 L F
.44366 .221 m .42216 .20933 L .44366 .22101 L .888 .841 0 r
F
.44366 .221 m .423 .21398 L .44366 .22101 L 1 1 0 r
F
.44547 .22112 m .44376 .22058 L .44367 .22101 L F
.44376 .22058 m .42216 .20933 L .44366 .221 L .888 .841 0 r
F
.44376 .22058 m .44366 .221 L .44367 .22101 L 1 1 0 r
F
.44376 .22058 m .44366 .221 L .44368 .22101 L .888 .841 0 r
F
.44376 .22058 m .423 .21398 L .44366 .221 L 1 1 0 r
F
.44551 .22149 m .44637 .2158 L .44485 .21539 L .888 .841 0 r
F
.44457 .21672 m .44485 .21539 L .44428 .21524 L F
.44551 .22149 m .44485 .21539 L .44457 .21672 L F
.44372 .22056 m .44428 .21524 L .42216 .20933 L F
.4439 .22062 m .44425 .21812 L .44376 .22058 L 1 1 0 r
F
.44551 .22149 m .44428 .21524 L .44372 .22056 L .888 .841 0 r
F
.44551 .22149 m .44376 .22058 L .44368 .22101 L F
.44376 .22058 m .44463 .21534 L .423 .21398 L 1 1 0 r
F
.44463 .21534 m .42462 .20845 L .423 .21398 L F
.44463 .21533 m .42382 .20376 L .44463 .21534 L .882 .841 0 r
F
.44463 .21533 m .42462 .20845 L .44463 .21534 L 1 1 0 r
F
.44634 .21544 m .44473 .21493 L .44465 .21534 L F
.44473 .21493 m .42382 .20376 L .44463 .21533 L .882 .841 0 r
F
.44473 .21493 m .44463 .21533 L .44465 .21534 L 1 1 0 r
F
.44473 .21493 m .44463 .21533 L .44465 .21534 L .882 .841 0 r
F
.44473 .21493 m .42462 .20845 L .44463 .21533 L 1 1 0 r
F
.44637 .2158 m .44725 .21015 L .44584 .20977 L .882 .841 0 r
F
.44555 .21114 m .44584 .20977 L .44527 .20962 L F
.44637 .2158 m .44584 .20977 L .44555 .21114 L F
.44469 .2149 m .44527 .20962 L .42382 .20376 L F
.44487 .21497 m .44524 .2124 L .44473 .21493 L 1 1 0 r
F
.44637 .2158 m .44527 .20962 L .44469 .2149 L .882 .841 0 r
F
.44637 .2158 m .44473 .21493 L .44465 .21534 L F
.44473 .21493 m .44562 .20971 L .42462 .20845 L 1 1 0 r
F
.44562 .20971 m .42627 .20296 L .42462 .20845 L F
.44562 .2097 m .4255 .19825 L .44562 .20971 L .876 .842 0 r
F
.44562 .20971 m .42627 .20296 L .44562 .20971 L 1 1 0 r
F
.44722 .2098 m .44571 .20931 L .44563 .20971 L F
.44571 .20931 m .4255 .19825 L .44562 .2097 L .876 .842 0 r
F
.44571 .20931 m .44562 .20971 L .44563 .20971 L 1 1 0 r
F
.44571 .20931 m .44562 .2097 L .44563 .20971 L .876 .842 0 r
F
.44571 .20931 m .42627 .20296 L .44562 .20971 L 1 1 0 r
F
.44725 .21015 m .44813 .20455 L .44684 .20419 L .876 .842 0 r
F
.44652 .20562 m .44684 .20419 L .44627 .20403 L F
.44725 .21015 m .44684 .20419 L .44652 .20562 L F
.44567 .20929 m .44627 .20403 L .4255 .19825 L F
.44585 .20936 m .44623 .20671 L .44571 .20931 L 1 1 0 r
F
.44725 .21015 m .44627 .20403 L .44567 .20929 L .876 .842 0 r
F
.44725 .21015 m .44571 .20931 L .44563 .20971 L F
.44571 .20931 m .44661 .20413 L .42627 .20296 L 1 1 0 r
F
.44661 .20413 m .42792 .19753 L .42627 .20296 L F
.44661 .20412 m .42792 .19753 L .44661 .20413 L F
.4481 .20421 m .4467 .20375 L .44662 .20413 L F
.44813 .20455 m .44903 .199 L .44784 .19866 L .87 .842 0 r
F
.44813 .20455 m .44784 .19866 L .44751 .20014 L F
.44813 .20455 m .4467 .20375 L .44662 .20413 L F
.4467 .20375 m .4476 .19859 L .42792 .19753 L 1 1 0 r
F
.44762 .1986 m .4476 .19859 L .4476 .19859 L 1 .796 0 r
F
.44903 .199 m .44769 .19823 L .44762 .1986 L F
.44769 .19823 m .44873 .19311 L .4296 .19215 L 1 1 0 r
F
.44802 .19834 m .44873 .19311 L .44769 .19823 L F
.47059 .19899 m .46533 .19654 L .44907 .19823 L .85 .84 0 r
F
.44921 .199 m .44907 .19823 L .449 .19867 L .341 .07 0 r
F
.44921 .199 m .44907 .19823 L .44903 .199 L .85 .84 0 r
F
.47059 .19899 m .44907 .19823 L .44921 .199 L F
.44921 .199 m .44991 .19317 L .44907 .19823 L .341 .07 0 r
F
.44921 .199 m .44907 .19823 L .44921 .199 L F
.47047 .2046 m .4492 .19904 L .44836 .20455 L 1 .987 0 r
F
.49612 .2323 m .46999 .22748 L .46987 .23331 L .977 .924 0 r
F
.49363 .20914 m .49298 .20349 L .47047 .20442 L .966 .943 0 r
F
.47047 .2046 m .44921 .199 L .44921 .199 L 1 .987 0 r
F
.47047 .2046 m .4492 .199 L .44919 .19904 L F
.49732 .24409 m .49673 .23818 L .46975 .23918 L .98 .913 0 r
F
.49673 .23818 m .46987 .23331 L .46975 .23918 L .979 .919 0 r
F
.49673 .23818 m .49612 .2323 L .46987 .23331 L F
.4706 .24139 m .4707 .23308 L .44921 .199 L .328 .065 0 r
F
.44919 .19904 m .44921 .199 L .449 .19867 L F
.4492 .19904 m .44919 .19904 L .44836 .20455 L 1 .987 0 r
F
.4706 .24139 m .44921 .199 L .44919 .19904 L .328 .065 0 r
F
.47047 .2046 m .47059 .19899 L .44921 .199 L 1 .987 0 r
F
.44921 .199 m .44921 .199 L .4492 .199 L F
.44919 .19904 m .4492 .199 L .44903 .199 L F
.44833 .20459 m .44915 .19896 L .44831 .20455 L .328 .065 0 r
F
.4706 .24139 m .44919 .19904 L .44833 .20459 L F
.44836 .20455 m .44919 .19904 L .44831 .20455 L 1 .987 0 r
F
.44919 .19904 m .44915 .19896 L .44833 .20459 L .328 .065 0 r
F
.4707 .23308 m .45005 .19345 L .44921 .199 L .341 .07 0 r
F
.45005 .19345 m .44991 .19317 L .44921 .199 L F
.44919 .19904 m .44903 .199 L .44831 .20455 L 1 .987 0 r
F
.44831 .20455 m .44831 .20455 L .44831 .20455 L .328 .065 0 r
F
.44747 .21015 m .44829 .20459 L .44742 .21015 L 1 .982 0 r
F
.44829 .20459 m .44813 .20455 L .44742 .21015 L F
.47051 .24978 m .44825 .20452 L .44742 .21015 L .315 .061 0 r
F
.47042 .25821 m .4474 .21019 L .44654 .2158 L .302 .057 0 r
F
.4474 .21019 m .44654 .21578 L .44654 .2158 L F
.44654 .2158 m .44687 .21365 L .44653 .2158 L 1 .977 0 r
F
.44653 .2158 m .44725 .21015 L .44637 .2158 L F
.47034 .26666 m .44652 .21584 L .44567 .22149 L .287 .052 0 r
F
.44652 .21584 m .44567 .22147 L .44567 .22149 L F
.44567 .22149 m .446 .21932 L .44566 .22149 L 1 .971 0 r
F
.44566 .22149 m .44637 .2158 L .44551 .22149 L F
.47026 .27506 m .44566 .22153 L .44481 .22723 L .272 .048 0 r
F
.44566 .22153 m .44481 .22721 L .44481 .22723 L F
.44481 .22723 m .44513 .22506 L .4448 .22723 L 1 .966 0 r
F
.4448 .22723 m .44551 .22149 L .44465 .22722 L F
.47019 .28339 m .4448 .22726 L .44396 .233 L .256 .044 0 r
F
.4448 .22726 m .44397 .23299 L .44396 .233 L F
.44396 .233 m .44427 .23085 L .44395 .233 L 1 .961 0 r
F
.44395 .233 m .44465 .22722 L .44381 .233 L F
.47012 .29158 m .44395 .23303 L .44312 .23882 L .238 .039 0 r
F
.44395 .23303 m .44313 .23881 L .44312 .23882 L F
.44312 .23882 m .44342 .23671 L .44312 .23882 L 1 .956 0 r
F
.44312 .23882 m .44381 .233 L .44297 .23882 L F
.47006 .29962 m .44311 .23885 L .4423 .24468 L .22 .035 0 r
F
.44311 .23885 m .4423 .24467 L .4423 .24468 L F
.4423 .24468 m .44258 .24263 L .44229 .24468 L 1 .951 0 r
F
.44229 .24468 m .44297 .23882 L .44215 .24468 L F
.44229 .24471 m .44215 .24468 L .44148 .25058 L 1 .945 0 r
F
.44151 .25058 m .44153 .25046 L .44148 .25058 L F
.46999 .30745 m .44229 .24471 L .44148 .25058 L .201 .031 0 r
F
.44229 .24471 m .44148 .25057 L .44148 .25058 L F
.44147 .25061 m .44148 .25058 L .44147 .25061 L .181 .026 0 r
F
.46994 .31505 m .44148 .25058 L .44147 .25061 L F
.44147 .25061 m .44148 .25058 L .44133 .25058 L 1 .94 0 r
F
.46994 .31505 m .44147 .25061 L .45157 .33645 L .181 .026 0 r
F
.44147 .25061 m .44133 .25059 L .45157 .33645 L F
.44071 .25652 m .44139 .25124 L .44053 .25651 L 1 .94 0 r
F
.44133 .25059 m .43506 .24986 L .41395 .2488 L .972 .152 0 r
F
.44053 .25651 m .44133 .25058 L .41381 .24876 L 1 .981 0 r
F
.44134 .25063 m .44133 .25059 L .41395 .2488 L .972 .152 0 r
F
.44133 .25059 m .44128 .25018 L .43506 .24986 L F
.45157 .33645 m .44134 .25063 L .41395 .2488 L F
.44857 .33019 m .41395 .2488 L .41248 .25462 L F
.45157 .33645 m .44862 .32959 L .44857 .33019 L F
.44862 .32959 m .41395 .2488 L .44857 .33019 L F
.44133 .25058 m .41531 .24296 L .41381 .24876 L 1 .986 0 r
F
.44133 .25058 m .44215 .24468 L .41531 .24296 L F
.44215 .24468 m .41684 .23719 L .41531 .24296 L 1 .991 0 r
F
.44215 .24468 m .44297 .23882 L .41684 .23719 L F
.44888 .31107 m .41994 .2258 L .41838 .23148 L .165 .022 0 r
F
.44894 .31121 m .44889 .31105 L .44888 .31107 L F
.44889 .31105 m .41994 .2258 L .44888 .31107 L F
.44894 .31113 m .41994 .2258 L .44894 .31121 L F
.44928 .31074 m .44906 .31011 L .44919 .31186 L F
.44906 .31011 m .41994 .2258 L .44898 .31125 L F
.44906 .31011 m .44898 .31125 L .44919 .31186 L F
.44859 .33603 m .44914 .33137 L .44857 .33019 L .145 .021 0 r
F
.44859 .33603 m .44857 .33019 L .44811 .33494 L F
.44859 .33603 m .41248 .25462 L .41247 .25465 L F
.4511 .34773 m .45133 .34221 L .44824 .33595 L .135 .02 0 r
F
.4511 .34773 m .44824 .33595 L .44777 .34047 L F
.41102 .26053 m .41101 .26053 L .40958 .26643 L 1 .97 0 r
F
.4511 .34773 m .41102 .2605 L .41101 .26053 L .135 .02 0 r
F
.41102 .2605 m .41102 .2605 L .41101 .26053 L F
.41101 .26053 m .41087 .26049 L .4105 .26221 L 1 .97 0 r
F
.41101 .26053 m .4105 .26221 L .40958 .26643 L F
.44939 .33784 m .44914 .33137 L .44859 .33603 L .145 .021 0 r
F
.45086 .35302 m .40958 .26643 L .40957 .26646 L .126 .018 0 r
F
.44773 .34712 m .40957 .26646 L .40818 .27242 L F
.45086 .35302 m .44779 .34659 L .44773 .34712 L F
.44779 .34659 m .40957 .26646 L .44773 .34712 L F
.40816 .27242 m .40815 .27242 L .40676 .27839 L 1 .96 0 r
F
.45062 .35812 m .40816 .27239 L .40815 .27242 L .119 .017 0 r
F
.40816 .27239 m .40816 .27239 L .40815 .27242 L F
.40815 .27242 m .40801 .27238 L .40752 .27475 L 1 .96 0 r
F
.40815 .27242 m .40752 .27475 L .40676 .27839 L F
.45035 .33999 m .45002 .33322 L .44939 .33784 L .145 .021 0 r
F
.44824 .33595 m .41244 .25458 L .41102 .2605 L F
.45133 .34221 m .4483 .33537 L .44824 .33595 L F
.4483 .33537 m .41244 .25458 L .44824 .33595 L F
.45184 .31801 m .45014 .32064 L .45182 .31816 L 1 .78 0 r
F
.44797 .3416 m .41101 .26053 L .40958 .26643 L .135 .02 0 r
F
.4511 .34773 m .44802 .34104 L .44797 .3416 L F
.44802 .34104 m .41101 .26053 L .44797 .3416 L F
.44897 .31733 m .41838 .23148 L .44175 .33595 L .147 .019 0 r
F
.44989 .31369 m .44928 .31074 L .44919 .31186 L .165 .022 0 r
F
.45033 .31484 m .44993 .31328 L .44989 .31369 L F
.44993 .31328 m .44928 .31074 L .44989 .31369 L F
.45036 .31453 m .44928 .31074 L .45033 .31484 L F
.45138 .31261 m .45038 .31439 L .45033 .31484 L 1 .739 0 r
F
.45041 .31402 m .44928 .31074 L .45036 .31453 L .165 .022 0 r
F
.45204 .3111 m .45063 .31363 L .45202 .31127 L 1 .739 0 r
F
.45063 .31363 m .45045 .31396 L .45063 .31365 L F
.45063 .31363 m .45063 .31365 L .45202 .31127 L F
.45045 .31396 m .45043 .31412 L .45202 .31127 L F
.45202 .31127 m .45141 .31236 L .45138 .31261 L F
.45047 .29066 m .42473 .20904 L .42311 .21458 L .234 .034 0 r
F
.45067 .2912 m .45048 .29059 L .45047 .29066 L F
.45048 .29059 m .42473 .20904 L .45047 .29066 L F
.45067 .29116 m .42473 .20904 L .45067 .2912 L F
.4508 .29147 m .42473 .20904 L .45079 .29155 L F
.45102 .2921 m .42473 .20904 L .45102 .29217 L F
.45129 .29182 m .45111 .29126 L .45122 .29272 L F
.45111 .29126 m .42473 .20904 L .45109 .29232 L F
.45111 .29126 m .45109 .29232 L .45122 .29272 L F
.452 .26444 m .44993 .19349 L .42968 .1927 L 1 .359 0 r
F
.45234 .27414 m .45197 .27481 L .45192 .27575 L 1 .496 0 r
F
.4536 .26922 m .45237 .27344 L .45234 .27414 L F
.45237 .27344 m .45197 .27481 L .45234 .27414 L F
.49612 .2323 m .49551 .22647 L .46999 .22748 L .977 .924 0 r
F
.49113 .22732 m .4707 .23308 L .4706 .24139 L 1 1 0 r
F
.47071 .23798 m .46172 .21873 L .45555 .26968 L .333 .064 0 r
F
.47071 .23798 m .45555 .26968 L .45588 .27216 L F
.46172 .21873 m .44993 .19349 L .45396 .25748 L F
.45588 .27216 m .45396 .25748 L .45388 .25993 L 0 0 0 r
F
.45557 .28038 m .45388 .25993 L .4536 .26922 L F
.45582 .28174 m .45585 .27382 L .45557 .28038 L F
.45585 .27382 m .45388 .25993 L .45557 .28038 L F
.49191 .2423 m .47051 .24978 L .47042 .25821 L 1 .985 0 r
F
.49191 .2423 m .49154 .23476 L .47051 .24978 L F
.49154 .23476 m .4706 .24139 L .47051 .24978 L 1 .996 0 r
F
.47054 .25612 m .47062 .247 L .45968 .27267 L 1 .859 0 r
F
.45973 .27434 m .45968 .27267 L .45704 .27887 L F
.45973 .27434 m .45704 .27887 L .45704 .27888 L F
.50603 .34976 m .46789 .34417 L .46779 .3506 L 1 .818 0 r
F
.50603 .34976 m .50559 .34332 L .46789 .34417 L F
.50559 .34332 m .46799 .33777 L .46789 .34417 L 1 .823 0 r
F
.50559 .34332 m .50515 .33692 L .46799 .33777 L F
.49398 .34095 m .46968 .34921 L .46963 .35529 L 1 .821 0 r
F
.49399 .34777 m .49398 .34095 L .46963 .35529 L 1 .812 0 r
F
.49399 .34777 m .46963 .35529 L .46958 .36114 L F
.49399 .35439 m .49399 .34777 L .46958 .36114 L 1 .804 0 r
F
.49399 .35439 m .46958 .36114 L .46954 .36679 L F
.50515 .33692 m .4681 .3314 L .46799 .33777 L .999 .829 0 r
F
.50515 .33692 m .50469 .33053 L .4681 .3314 L F
.49398 .34095 m .49396 .33393 L .46968 .34921 L 1 .821 0 r
F
.49325 .33858 m .46984 .35211 L .4698 .35812 L 1 .839 0 r
F
.49323 .34562 m .49325 .33858 L .4698 .35812 L 1 .833 0 r
F
.49323 .34562 m .4698 .35812 L .46976 .36387 L F
.4932 .35242 m .49323 .34562 L .46976 .36387 L 1 .827 0 r
F
.49399 .36081 m .49399 .35439 L .46954 .36679 L 1 .797 0 r
F
.49399 .36081 m .46954 .36679 L .46949 .37225 L F
.4932 .35242 m .46976 .36387 L .46971 .36938 L 1 .827 0 r
F
.50423 .32416 m .4683 .31871 L .4682 .32504 L .997 .841 0 r
F
.50423 .32416 m .50375 .31783 L .4683 .31871 L F
.46988 .3224 m .46994 .31505 L .45157 .33645 L 1 .892 0 r
F
.45145 .34209 m .45157 .33645 L .45133 .34221 L F
.46172 .21873 m .45397 .25746 L .45558 .26948 L .333 .064 0 r
F
.45516 .25678 m .45456 .24076 L .4542 .25041 L .996 .305 0 r
F
.45833 .33473 m .45365 .33581 L .45391 .33946 L 1 .892 0 r
F
.45816 .33139 m .45428 .33437 L .45833 .33473 L F
.45428 .33437 m .45223 .33594 L .45436 .33565 L F
.45223 .33594 m .45224 .33614 L .45436 .33565 L F
.45365 .33581 m .45187 .33622 L .45391 .33946 L F
.49399 .37886 m .46941 .38264 L .46936 .38761 L 1 .779 0 r
F
.49399 .3845 m .49399 .37886 L .46936 .38761 L 1 .774 0 r
F
.49399 .3845 m .46936 .38761 L .46932 .39245 L F
.50469 .33053 m .4682 .32504 L .4681 .3314 L .998 .835 0 r
F
.50469 .33053 m .50423 .32416 L .4682 .32504 L F
.46983 .32949 m .46988 .3224 L .45133 .34221 L 1 .891 0 r
F
.49399 .37304 m .49399 .36702 L .46945 .37752 L 1 .784 0 r
F
.49399 .37304 m .46945 .37752 L .46941 .38264 L F
.49399 .37886 m .49399 .37304 L .46941 .38264 L 1 .779 0 r
F
.49312 .37138 m .46963 .37977 L .46959 .38469 L 1 .817 0 r
F
.49311 .37724 m .49312 .37138 L .46959 .38469 L 1 .816 0 r
F
.45298 .3459 m .45133 .34221 L .4511 .34773 L 1 .891 0 r
F
.45867 .34036 m .45469 .33991 L .45496 .34397 L F
.46983 .32949 m .46073 .33575 L .46081 .33827 L F
.46988 .3224 m .45816 .33139 L .45833 .33473 L 1 .892 0 r
F
.47054 .25612 m .45968 .27267 L .45973 .27434 L 1 .859 0 r
F
.45937 .27554 m .45702 .27892 L .45705 .27957 L F
.47054 .25612 m .45935 .27499 L .45937 .27554 L F
.45935 .27499 m .45702 .27892 L .45937 .27554 L F
.45938 .27595 m .45645 .28069 L .45647 .28113 L F
.45937 .27554 m .45644 .28062 L .45938 .27595 L F
.45644 .28062 m .45586 .28163 L .45645 .28069 L F
.45644 .28062 m .45645 .28069 L .45938 .27595 L F
.45643 .28031 m .4559 .27261 L .45582 .28174 L 1 .875 0 r
F
.47062 .247 m .4559 .27261 L .45643 .28031 L F
.45588 .27237 m .45504 .26702 L .45504 .26708 L 0 0 0 r
F
.45607 .27356 m .45588 .27236 L .45588 .27237 L F
.45588 .27236 m .45504 .26702 L .45588 .27237 L F
.45705 .27957 m .45702 .27892 L .45643 .28031 L 1 .859 0 r
F
.45644 .28062 m .45643 .28031 L .45586 .28163 L F
.45705 .27957 m .45643 .28031 L .45644 .28062 L F
.4559 .27261 m .45592 .27205 L .45588 .27216 L 1 .875 0 r
F
.45559 .27064 m .4548 .26554 L .45481 .26575 L 0 0 0 r
F
.4559 .27261 m .45558 .27058 L .45559 .27064 L F
.45558 .27058 m .4548 .26554 L .45559 .27064 L F
.4559 .27258 m .4548 .26554 L .4559 .27261 L F
.45901 .2672 m .45726 .26995 L .45727 .27022 L 1 .875 0 r
F
.45943 .26647 m .459 .26682 L .45901 .2672 L F
.47062 .247 m .45972 .26558 L .45973 .26595 L F
.47054 .25612 m .45937 .27554 L .45938 .27595 L 1 .859 0 r
F
.49551 .22647 m .47011 .2217 L .46999 .22748 L .975 .93 0 r
F
.47059 .19881 m .47071 .19326 L .44961 .18915 L .852 .843 0 r
F
.49298 .20349 m .49233 .19787 L .47059 .19881 L .964 .948 0 r
F
.49233 .19787 m .47071 .19326 L .47059 .19881 L .962 .953 0 r
F
.47059 .19899 m .47072 .19343 L .44961 .18924 L .85 .84 0 r
F
.47071 .19326 m .45054 .18372 L .44961 .18915 L 1 .796 0 r
F
.47072 .19343 m .45055 .18381 L .44961 .18924 L .844 .841 0 r
F
.4708 .22487 m .45082 .18771 L .44991 .19317 L 1 .398 0 r
F
.4707 .23308 m .4708 .22487 L .44991 .19317 L .341 .07 0 r
F
.49551 .22647 m .49489 .22068 L .47011 .2217 L .975 .93 0 r
F
.49489 .22068 m .47023 .21595 L .47011 .2217 L .973 .935 0 r
F
.4907 .21998 m .4708 .22487 L .4707 .23308 L 1 1 0 r
F
.49489 .22068 m .49426 .21493 L .47023 .21595 L .973 .935 0 r
F
.49426 .21493 m .47035 .21026 L .47023 .21595 L .972 .94 0 r
F
.49426 .21493 m .49362 .20922 L .47035 .21026 L F
.49362 .20922 m .47047 .2046 L .47035 .21026 L .97 .946 0 r
F
.49362 .20922 m .49298 .20356 L .47047 .2046 L F
.49298 .20356 m .47059 .19899 L .47047 .2046 L .968 .951 0 r
F
.49298 .20356 m .49232 .19795 L .47059 .19899 L F
.49233 .19787 m .49167 .19231 L .47071 .19326 L .962 .953 0 r
F
.49232 .19795 m .47072 .19343 L .47059 .19899 L .966 .956 0 r
F
.49232 .19795 m .49166 .19238 L .47072 .19343 L F
.49167 .19231 m .47083 .18438 L .47071 .19326 L .826 .834 0 r
F
.47071 .19326 m .47083 .18438 L .45054 .18372 L 1 .796 0 r
F
.47096 .19341 m .47099 .18794 L .47072 .19343 L .964 .962 0 r
F
.49166 .19238 m .471 .18794 L .47096 .19341 L F
.471 .18794 m .47099 .18794 L .47096 .19341 L F
.49167 .19231 m .491 .18679 L .47083 .18438 L .826 .834 0 r
F
.491 .18679 m .47096 .17896 L .47083 .18438 L .822 .837 0 r
F
.471 .1879 m .47096 .18228 L .47084 .18775 L .382 .215 0 r
F
.49023 .21275 m .47099 .18794 L .4708 .22487 L .368 .175 0 r
F
.47099 .18794 m .47084 .18775 L .47084 .18793 L F
.47099 .18794 m .47099 .18794 L .47084 .18793 L .964 .962 0 r
F
.47099 .18794 m .47099 .18794 L .47072 .19343 L F
.47099 .18794 m .47084 .18793 L .47083 .1885 L F
.47099 .18794 m .47083 .1885 L .47072 .19343 L F
.49166 .19238 m .49099 .18686 L .47084 .18791 L F
.49023 .21275 m .48974 .20563 L .471 .1879 L .368 .175 0 r
F
.47099 .18794 m .471 .1879 L .47084 .18775 L F
.49023 .21275 m .471 .1879 L .47099 .18794 L F
.47099 .18794 m .47084 .18793 L .4708 .22487 L F
.47099 .18794 m .47084 .18791 L .47084 .18793 L .964 .962 0 r
F
.471 .1879 m .47096 .18244 L .47084 .18791 L .962 .967 0 r
F
.491 .18679 m .49032 .18132 L .47096 .17896 L .822 .837 0 r
F
.49032 .18132 m .47109 .1736 L .47096 .17896 L .817 .839 0 r
F
.47113 .18243 m .47109 .17687 L .47096 .18228 L .402 .256 0 r
F
.49099 .18686 m .47113 .18247 L .47109 .18789 L .962 .967 0 r
F
.47113 .18247 m .47112 .18247 L .47109 .18789 L F
.49099 .18686 m .47113 .18243 L .47112 .18247 L F
.48974 .20563 m .48923 .19863 L .47113 .18243 L .382 .215 0 r
F
.47112 .18247 m .47113 .18243 L .47096 .18228 L F
.48974 .20563 m .47113 .18243 L .47112 .18247 L F
.49099 .18686 m .49031 .18139 L .47113 .18243 L .962 .967 0 r
F
.47103 .18793 m .47104 .18238 L .471 .1879 L .382 .215 0 r
F
.47109 .18789 m .47112 .18247 L .471 .1879 L .962 .967 0 r
F
.48974 .20563 m .47112 .18247 L .47103 .18793 L .382 .215 0 r
F
.47112 .18247 m .47104 .18238 L .47103 .18793 L F
.47112 .18247 m .47113 .18243 L .47112 .18243 L .962 .967 0 r
F
.47112 .18247 m .47112 .18243 L .47096 .18244 L F
.47113 .18243 m .47109 .17701 L .47096 .18244 L .96 .972 0 r
F
.49032 .18132 m .48963 .17591 L .47109 .1736 L .817 .839 0 r
F
.48963 .17591 m .47121 .1683 L .47109 .1736 L .812 .842 0 r
F
.47125 .17701 m .47122 .1715 L .47109 .17687 L .425 .297 0 r
F
.49031 .18139 m .47125 .17705 L .47122 .18242 L .96 .972 0 r
F
.47125 .17705 m .47124 .17705 L .47122 .18242 L F
.49031 .18139 m .47125 .17701 L .47124 .17705 L F
.48923 .19863 m .48869 .19173 L .47125 .17701 L .402 .256 0 r
F
.47124 .17705 m .47125 .17701 L .47109 .17687 L F
.48923 .19863 m .47125 .17701 L .47124 .17705 L F
.49031 .18139 m .48963 .17597 L .47125 .17701 L .96 .972 0 r
F
.47116 .18246 m .47116 .17696 L .47113 .18243 L .402 .256 0 r
F
.47122 .18242 m .47124 .17705 L .47113 .18243 L .96 .972 0 r
F
.48923 .19863 m .47124 .17705 L .47116 .18246 L .402 .256 0 r
F
.47124 .17705 m .47116 .17696 L .47116 .18246 L F
.47124 .17705 m .47125 .17701 L .47124 .17701 L .96 .972 0 r
F
.47124 .17705 m .47124 .17701 L .47109 .17701 L F
.47125 .17701 m .47122 .17164 L .47109 .17701 L .957 .977 0 r
F
.48963 .17591 m .48894 .17054 L .47121 .1683 L .812 .842 0 r
F
.48894 .17054 m .47134 .16305 L .47121 .1683 L .807 .845 0 r
F
.47138 .17163 m .47134 .16618 L .47122 .1715 L .449 .337 0 r
F
.48963 .17597 m .47138 .17168 L .47135 .177 L .957 .977 0 r
F
.47138 .17168 m .47137 .17167 L .47135 .177 L F
.48963 .17597 m .47138 .17163 L .47137 .17167 L F
.48869 .19173 m .48812 .18496 L .47138 .17163 L .425 .297 0 r
F
.47137 .17167 m .47138 .17163 L .47122 .1715 L F
.48869 .19173 m .47138 .17163 L .47137 .17167 L F
.48963 .17597 m .48893 .17059 L .47138 .17163 L .957 .977 0 r
F
.47129 .17703 m .47129 .17158 L .47125 .17701 L .425 .297 0 r
F
.47135 .177 m .47137 .17167 L .47125 .17701 L .957 .977 0 r
F
.48869 .19173 m .47137 .17167 L .47129 .17703 L .425 .297 0 r
F
.47137 .17167 m .47129 .17158 L .47129 .17703 L F
.47137 .17167 m .47138 .17163 L .47137 .17163 L .957 .977 0 r
F
.47137 .17167 m .47137 .17163 L .47122 .17164 L F
.47138 .17163 m .47134 .16631 L .47122 .17164 L .955 .982 0 r
F
.48894 .17054 m .48823 .16522 L .47134 .16305 L .807 .845 0 r
F
.48823 .16522 m .47147 .15787 L .47134 .16305 L .802 .848 0 r
F
.47151 .1663 m .47147 .16091 L .47134 .16618 L .473 .378 0 r
F
.48893 .17059 m .47151 .16635 L .47149 .17162 L .955 .982 0 r
F
.47151 .16635 m .47149 .16635 L .47149 .17162 L F
.48893 .17059 m .47151 .1663 L .47149 .16635 L F
.48812 .18496 m .48754 .1783 L .47151 .1663 L .449 .337 0 r
F
.47149 .16635 m .47151 .1663 L .47134 .16618 L F
.48812 .18496 m .47151 .1663 L .47149 .16635 L F
.48893 .17059 m .48823 .16527 L .47151 .1663 L .955 .982 0 r
F
.47142 .17166 m .47141 .16625 L .47138 .17163 L .449 .337 0 r
F
.47149 .17162 m .47149 .16635 L .47138 .17163 L .955 .982 0 r
F
.48812 .18496 m .47149 .16635 L .47142 .17166 L .449 .337 0 r
F
.47149 .16635 m .47141 .16625 L .47142 .17166 L F
.47149 .16635 m .47151 .1663 L .47149 .1663 L .955 .982 0 r
F
.47149 .16635 m .47149 .1663 L .47134 .16631 L F
.47151 .1663 m .47147 .16104 L .47134 .16631 L .953 .987 0 r
F
.48823 .16522 m .48752 .15995 L .47147 .15787 L .802 .848 0 r
F
.48752 .15995 m .4716 .15275 L .47147 .15787 L .797 .85 0 r
F
.47163 .16103 m .4716 .15569 L .47147 .16091 L .497 .419 0 r
F
.47163 .16103 m .4716 .15581 L .47147 .16104 L .951 .992 0 r
F
.48752 .15995 m .4868 .15473 L .4716 .15275 L .797 .85 0 r
F
.4868 .15473 m .47173 .14769 L .4716 .15275 L .793 .854 0 r
F
.48325 .15311 m .47173 .14772 L .47161 .15549 L .793 .853 0 r
F
.47147 .15787 m .4716 .15275 L .45634 .15238 L .94 1 0 r
F
.4716 .15275 m .45734 .14737 L .45634 .15238 L .936 1 0 r
F
.4716 .15275 m .47173 .14769 L .45734 .14737 L F
.47147 .15787 m .45634 .15238 L .45535 .15745 L .94 1 0 r
F
.47134 .16305 m .47147 .15787 L .45535 .15745 L .944 .996 0 r
F
.47147 .16091 m .4716 .15569 L .47113 .1557 L .979 1 0 r
F
.47134 .16305 m .45535 .15745 L .45437 .16259 L .944 .996 0 r
F
.47121 .1683 m .47134 .16305 L .45437 .16259 L .948 .992 0 r
F
.47134 .16618 m .47147 .16091 L .47095 .16092 L .981 1 0 r
F
.47121 .1683 m .45437 .16259 L .4534 .16778 L .948 .992 0 r
F
.47109 .1736 m .47121 .1683 L .4534 .16778 L .953 .988 0 r
F
.47122 .1715 m .47134 .16618 L .47077 .16619 L .983 1 0 r
F
.47109 .1736 m .4534 .16778 L .45244 .17304 L .953 .988 0 r
F
.47096 .17896 m .47109 .1736 L .45244 .17304 L .957 .984 0 r
F
.47109 .17687 m .47122 .1715 L .47058 .17151 L .985 1 0 r
F
.47096 .17896 m .45244 .17304 L .45149 .17835 L .957 .984 0 r
F
.47083 .18438 m .47096 .17896 L .45149 .17835 L .961 .98 0 r
F
.47096 .18228 m .47109 .17687 L .4704 .17687 L .987 1 0 r
F
.47083 .18438 m .45149 .17835 L .45054 .18372 L .961 .98 0 r
F
.47084 .18775 m .47096 .18228 L .47021 .18228 L .989 .998 0 r
F
.47003 .18774 m .45149 .17843 L .45055 .18381 L .838 .843 0 r
F
.47072 .19343 m .47084 .18793 L .45055 .18381 L .844 .841 0 r
F
.47084 .18793 m .47084 .18775 L .47003 .18774 L 1 .398 0 r
F
.47084 .18793 m .47084 .18791 L .47003 .18774 L .844 .841 0 r
F
.47084 .18793 m .47003 .18774 L .45055 .18381 L F
.47084 .18793 m .47003 .18774 L .46711 .18774 L 1 .398 0 r
F
.47003 .18774 m .45175 .18231 L .45082 .18771 L .989 .998 0 r
F
.47084 .18775 m .47005 .18752 L .47003 .18774 L F
.47003 .18774 m .45149 .17843 L .47003 .18774 L .838 .843 0 r
F
.47005 .18752 m .45149 .17843 L .47004 .18775 L F
.47005 .18752 m .45175 .18231 L .47003 .18774 L .989 .998 0 r
F
.47004 .18775 m .47003 .18774 L .47003 .18774 L .838 .843 0 r
F
.47084 .18791 m .47005 .18752 L .47004 .18775 L F
.47037 .18761 m .47023 .18284 L .47005 .18752 L .989 .998 0 r
F
.47023 .18284 m .47021 .18228 L .47005 .18752 L F
.47084 .18775 m .47021 .18228 L .47037 .18761 L F
.47084 .18791 m .47096 .18244 L .47021 .18228 L .838 .843 0 r
F
.46951 .18726 m .47021 .18228 L .45149 .17843 L F
.47084 .18791 m .47021 .18228 L .46951 .18726 L F
.47021 .18228 m .45244 .17312 L .45149 .17843 L .833 .844 0 r
F
.47021 .18228 m .45268 .17695 L .45175 .18231 L .987 1 0 r
F
.47096 .18228 m .47024 .18207 L .47021 .18228 L F
.47021 .18228 m .45244 .17312 L .47021 .18228 L .833 .844 0 r
F
.47023 .18207 m .45244 .17312 L .47021 .18228 L F
.47024 .18207 m .47023 .18207 L .47021 .18228 L .987 1 0 r
F
.47023 .18207 m .47021 .18228 L .47022 .18228 L .833 .844 0 r
F
.47023 .18207 m .45268 .17695 L .47021 .18228 L .987 1 0 r
F
.47005 .18752 m .47021 .18228 L .45175 .18231 L .989 .998 0 r
F
.47022 .18228 m .47021 .18228 L .47021 .18228 L .833 .844 0 r
F
.47096 .18244 m .47023 .18207 L .47022 .18228 L F
.47056 .18216 m .47041 .17721 L .47023 .18207 L .987 1 0 r
F
.47041 .17721 m .4704 .17687 L .47023 .18207 L F
.47096 .18228 m .4704 .17687 L .47056 .18216 L F
.47096 .18244 m .47109 .17701 L .4704 .17687 L .833 .844 0 r
F
.4697 .1818 m .4704 .17687 L .45244 .17312 L F
.47096 .18244 m .4704 .17687 L .4697 .1818 L F
.4704 .17687 m .45341 .16786 L .45244 .17312 L .827 .846 0 r
F
.4704 .17687 m .45363 .17165 L .45268 .17695 L .985 1 0 r
F
.47109 .17687 m .47043 .17667 L .4704 .17687 L F
.4704 .17687 m .45341 .16786 L .4704 .17687 L .827 .846 0 r
F
.47042 .17667 m .45341 .16786 L .4704 .17687 L F
.47043 .17667 m .47042 .17667 L .4704 .17687 L .985 1 0 r
F
.47042 .17667 m .4704 .17687 L .47041 .17687 L .827 .846 0 r
F
.47042 .17667 m .45363 .17165 L .4704 .17687 L .985 1 0 r
F
.47023 .18207 m .4704 .17687 L .45268 .17695 L .987 1 0 r
F
.47041 .17687 m .4704 .17687 L .4704 .17687 L .827 .846 0 r
F
.47109 .17701 m .47042 .17667 L .47041 .17687 L F
.47076 .17677 m .47059 .1716 L .47042 .17667 L .985 1 0 r
F
.47059 .1716 m .47058 .17151 L .47042 .17667 L F
.47109 .17687 m .47058 .17151 L .47076 .17677 L F
.47109 .17701 m .47122 .17164 L .47058 .17151 L .827 .846 0 r
F
.46989 .17639 m .47058 .17151 L .45341 .16786 L F
.47109 .17701 m .47058 .17151 L .46989 .17639 L F
.47058 .17151 m .45438 .16266 L .45341 .16786 L .821 .847 0 r
F
.47058 .17151 m .45458 .16639 L .45363 .17165 L .983 1 0 r
F
.47122 .1715 m .47061 .17131 L .47058 .17151 L F
.47058 .1715 m .45438 .16266 L .47058 .17151 L .821 .847 0 r
F
.4706 .17131 m .45438 .16266 L .47059 .1715 L F
.47061 .17131 m .4706 .17131 L .47058 .17151 L .983 1 0 r
F
.4706 .17131 m .47059 .1715 L .47059 .17151 L .821 .847 0 r
F
.4706 .17131 m .45458 .16639 L .47058 .17151 L .983 1 0 r
F
.47042 .17667 m .47058 .17151 L .45363 .17165 L .985 1 0 r
F
.47059 .17151 m .47058 .1715 L .47058 .17151 L .821 .847 0 r
F
.47122 .17164 m .4706 .17131 L .47059 .17151 L F
.47122 .17164 m .47134 .16631 L .47077 .16619 L F
.47007 .17103 m .47077 .16619 L .45438 .16266 L F
.47077 .16619 m .45536 .15753 L .45438 .16266 L .815 .849 0 r
F
.47077 .16619 m .45554 .16118 L .45458 .16639 L .981 1 0 r
F
.47134 .16618 m .47079 .16601 L .47077 .16619 L F
.47077 .16619 m .45536 .15753 L .47077 .16619 L .815 .849 0 r
F
.47078 .166 m .45536 .15753 L .47077 .16619 L F
.47079 .16601 m .47078 .166 L .47077 .16619 L .981 1 0 r
F
.47078 .166 m .47077 .16619 L .47078 .16619 L .815 .849 0 r
F
.47078 .166 m .45554 .16118 L .47077 .16619 L .981 1 0 r
F
.4706 .17131 m .47077 .16619 L .47007 .17103 L .821 .847 0 r
F
.47096 .17142 m .47077 .16619 L .47076 .16635 L .983 1 0 r
F
.47096 .17142 m .47076 .16619 L .4706 .17131 L F
.47122 .1715 m .47077 .16619 L .47096 .17142 L F
.47122 .17164 m .47077 .16619 L .4706 .17131 L .821 .847 0 r
F
.47076 .16635 m .47077 .16619 L .47076 .16619 L .983 1 0 r
F
.4706 .17131 m .47076 .16619 L .45458 .16639 L F
.47078 .16619 m .47077 .16619 L .47077 .16619 L .815 .849 0 r
F
.47134 .16631 m .47078 .166 L .47078 .16619 L F
.47134 .16631 m .47147 .16104 L .47095 .16092 L F
.47026 .16572 m .47095 .16092 L .45536 .15753 L F
.47095 .16092 m .45634 .15245 L .45536 .15753 L .81 .85 0 r
F
.47095 .16092 m .45651 .15601 L .45554 .16118 L .979 1 0 r
F
.47147 .16091 m .47097 .16075 L .47095 .16092 L F
.47095 .16092 m .45634 .15245 L .47095 .16092 L .81 .85 0 r
F
.47096 .16075 m .45634 .15245 L .47095 .16092 L F
.47097 .16075 m .47096 .16075 L .47095 .16092 L .979 1 0 r
F
.47096 .16075 m .47095 .16092 L .47096 .16092 L .81 .85 0 r
F
.47096 .16075 m .45651 .15601 L .47095 .16092 L .979 1 0 r
F
.47078 .166 m .47095 .16092 L .47026 .16572 L .815 .849 0 r
F
.47115 .16612 m .47095 .16092 L .47094 .16132 L .981 1 0 r
F
.47115 .16612 m .47092 .16092 L .47078 .166 L F
.47134 .16618 m .47095 .16092 L .47115 .16612 L F
.47134 .16631 m .47095 .16092 L .47078 .166 L .815 .849 0 r
F
.47094 .16132 m .47095 .16092 L .47092 .16092 L .981 1 0 r
F
.47078 .166 m .47092 .16092 L .45554 .16118 L F
.47096 .16092 m .47095 .16092 L .47095 .16092 L .81 .85 0 r
F
.47147 .16104 m .47096 .16075 L .47096 .16092 L F
.47147 .16104 m .4716 .15581 L .47113 .1557 L F
.47044 .16045 m .47113 .1557 L .45634 .15245 L F
.47113 .1557 m .45734 .14744 L .45634 .15245 L 1 .876 0 r
F
.47113 .1557 m .45749 .1509 L .45651 .15601 L .977 1 0 r
F
.4716 .15569 m .47115 .15554 L .47113 .1557 L F
.47113 .1557 m .45734 .14744 L .47113 .1557 L 1 .876 0 r
F
.47114 .15554 m .45734 .14744 L .47113 .1557 L F
.47115 .15554 m .47114 .15554 L .47113 .1557 L .977 1 0 r
F
.47114 .15554 m .47113 .1557 L .47114 .15571 L 1 .876 0 r
F
.47114 .15554 m .45749 .1509 L .47113 .1557 L .977 1 0 r
F
.47096 .16075 m .47113 .1557 L .47044 .16045 L .81 .85 0 r
F
.47135 .16087 m .47113 .1557 L .47111 .15631 L .979 1 0 r
F
.47135 .16087 m .47108 .1557 L .47096 .16075 L F
.47147 .16091 m .47113 .1557 L .47135 .16087 L F
.47147 .16104 m .47113 .1557 L .47096 .16075 L .81 .85 0 r
F
.47111 .15631 m .47113 .1557 L .47108 .1557 L .979 1 0 r
F
.47096 .16075 m .47108 .1557 L .45651 .15601 L F
.47114 .15571 m .47113 .1557 L .47113 .1557 L 1 .876 0 r
F
.4716 .15581 m .47114 .15554 L .47114 .15571 L F
.47114 .15554 m .47173 .14772 L .45734 .14744 L F
.47122 .15557 m .47123 .15553 L .47122 .15553 L .977 1 0 r
F
.4716 .15569 m .47161 .15549 L .47122 .15557 L F
.4716 .15581 m .47161 .15549 L .47114 .15554 L 1 .876 0 r
F
.47161 .15549 m .47173 .14772 L .47114 .15554 L F
.47122 .15553 m .47173 .15052 L .47123 .15054 L .977 1 0 r
F
.47123 .15553 m .47173 .15052 L .47122 .15553 L F
.47114 .15554 m .47123 .15054 L .45749 .1509 L F
.47122 .15557 m .47123 .15054 L .47114 .15554 L F
.47161 .15549 m .47173 .15052 L .47122 .15557 L F
.4868 .15477 m .48325 .15311 L .47161 .15549 L .793 .853 0 r
F
.47176 .1558 m .47161 .15549 L .4716 .15569 L .521 .46 0 r
F
.47176 .1558 m .47161 .15549 L .4716 .15581 L .793 .853 0 r
F
.4868 .15477 m .47161 .15549 L .47176 .1558 L F
.47176 .1558 m .47173 .15052 L .47161 .15549 L .521 .46 0 r
F
.47176 .1558 m .47161 .15549 L .47176 .1558 L F
.48752 .16 m .47176 .15585 L .47175 .16102 L .951 .992 0 r
F
.48823 .16527 m .47163 .16108 L .47162 .1663 L .953 .987 0 r
F
.48823 .16527 m .47163 .16103 L .47163 .16103 L F
.48823 .16527 m .47162 .16103 L .47162 .16107 L F
.48754 .1783 m .48693 .17175 L .47163 .16103 L .473 .378 0 r
F
.47162 .16107 m .47163 .16103 L .47147 .16091 L F
.47163 .16108 m .47162 .16107 L .47162 .1663 L .953 .987 0 r
F
.48754 .1783 m .47163 .16103 L .47162 .16107 L .473 .378 0 r
F
.48823 .16527 m .48752 .16 L .47163 .16103 L .953 .987 0 r
F
.47163 .16103 m .47163 .16103 L .47162 .16103 L F
.47162 .16107 m .47153 .16097 L .47155 .16633 L .473 .378 0 r
F
.47162 .16107 m .47162 .16103 L .47147 .16104 L .953 .987 0 r
F
.47155 .16633 m .47153 .16097 L .47151 .1663 L .473 .378 0 r
F
.47162 .1663 m .47162 .16107 L .47151 .1663 L .953 .987 0 r
F
.48754 .1783 m .47162 .16107 L .47155 .16633 L .473 .378 0 r
F
.48752 .16 m .47176 .1558 L .47176 .1558 L .951 .992 0 r
F
.48752 .16 m .47175 .1558 L .47174 .15584 L F
.48693 .17175 m .48631 .16532 L .47176 .1558 L .497 .419 0 r
F
.47174 .15584 m .47176 .1558 L .4716 .15569 L F
.47176 .15585 m .47174 .15584 L .47175 .16102 L .951 .992 0 r
F
.48693 .17175 m .47176 .1558 L .47174 .15584 L .497 .419 0 r
F
.48752 .16 m .4868 .15477 L .47176 .1558 L .951 .992 0 r
F
.47176 .1558 m .47176 .1558 L .47175 .1558 L F
.47174 .15584 m .47165 .15574 L .47168 .16106 L .497 .419 0 r
F
.47174 .15584 m .47175 .1558 L .4716 .15581 L .951 .992 0 r
F
.47168 .16106 m .47165 .15574 L .47163 .16103 L .497 .419 0 r
F
.47175 .16102 m .47174 .15584 L .47163 .16103 L .951 .992 0 r
F
.48693 .17175 m .47174 .15584 L .47168 .16106 L .497 .419 0 r
F
.47244 .15624 m .47176 .15056 L .47176 .1558 L .521 .46 0 r
F
.47382 .15264 m .47176 .15056 L .47244 .15624 L F
.47176 .15056 m .47173 .15052 L .47176 .1558 L F
.4868 .15473 m .48608 .14956 L .47173 .14769 L .793 .854 0 r
F
.4868 .15477 m .48608 .1496 L .47173 .14772 L .793 .853 0 r
F
.48608 .14956 m .47186 .14268 L .47173 .14769 L .789 .857 0 r
F
.48608 .1496 m .47186 .14272 L .47173 .14772 L F
.47234 .1509 m .47186 .1454 L .47173 .15052 L .545 .5 0 r
F
.48566 .15901 m .47371 .14722 L .47234 .1509 L F
.47371 .14722 m .47186 .1454 L .47234 .1509 L F
.48608 .14956 m .48535 .14445 L .47186 .14268 L .789 .857 0 r
F
.48608 .1496 m .48534 .14448 L .47186 .14272 L F
.48535 .14445 m .47199 .13775 L .47186 .14268 L .785 .86 0 r
F
.48534 .14448 m .47199 .13778 L .47186 .14272 L F
.47226 .14563 m .47199 .14033 L .47186 .1454 L .57 .541 0 r
F
.485 .15281 m .47361 .14188 L .47226 .14563 L F
.47361 .14188 m .47199 .14033 L .47226 .14563 L F
.48535 .14445 m .4846 .13938 L .47199 .13775 L .785 .86 0 r
F
.48534 .14448 m .4846 .13942 L .47199 .13778 L F
.4846 .13938 m .47213 .13287 L .47199 .13775 L .782 .864 0 r
F
.4846 .13942 m .47213 .1329 L .47199 .13778 L F
.48432 .14672 m .47212 .1353 L .47199 .14033 L .594 .582 0 r
F
.485 .15281 m .48432 .14672 L .47199 .14033 L .57 .541 0 r
F
.4738 .14136 m .47212 .13538 L .47199 .14041 L .594 .578 0 r
F
.48432 .14688 m .47499 .13808 L .4738 .14136 L F
.47499 .13808 m .47212 .13538 L .4738 .14136 L F
.48566 .15901 m .485 .15281 L .47186 .1454 L .545 .5 0 r
F
.47391 .14667 m .47199 .14041 L .47186 .1455 L .568 .536 0 r
F
.48499 .15301 m .47511 .14344 L .47391 .14667 L F
.47511 .14344 m .47199 .14041 L .47391 .14667 L F
.48631 .16532 m .48566 .15901 L .47173 .15052 L .521 .46 0 r
F
.47404 .15206 m .47186 .1455 L .47173 .15063 L .543 .494 0 r
F
.48565 .15926 m .47525 .14888 L .47404 .15206 L F
.47525 .14888 m .47186 .1455 L .47404 .15206 L F
.48631 .16532 m .47382 .15264 L .47244 .15624 L .521 .46 0 r
F
.47163 .16101 m .4716 .15569 L .47163 .16103 L .497 .419 0 r
F
.47165 .15574 m .4716 .15569 L .47163 .16103 L F
.47174 .15584 m .4716 .15581 L .47163 .16103 L .951 .992 0 r
F
.47163 .16103 m .47163 .16101 L .47163 .16103 L .497 .419 0 r
F
.47151 .16629 m .47147 .16091 L .47151 .1663 L .473 .378 0 r
F
.47153 .16097 m .47147 .16091 L .47151 .1663 L F
.47162 .16107 m .47147 .16104 L .47151 .1663 L .953 .987 0 r
F
.47151 .1663 m .47151 .16629 L .47151 .1663 L .473 .378 0 r
F
.47138 .17162 m .47134 .16618 L .47138 .17163 L .449 .337 0 r
F
.47141 .16625 m .47134 .16618 L .47138 .17163 L F
.47149 .16635 m .47134 .16631 L .47138 .17163 L .955 .982 0 r
F
.47138 .17163 m .47138 .17162 L .47138 .17163 L .449 .337 0 r
F
.47125 .17699 m .47122 .1715 L .47125 .17701 L .425 .297 0 r
F
.47129 .17158 m .47122 .1715 L .47125 .17701 L F
.47137 .17167 m .47122 .17164 L .47125 .17701 L .957 .977 0 r
F
.47125 .17701 m .47125 .17699 L .47125 .17701 L .425 .297 0 r
F
.47113 .18242 m .47109 .17687 L .47113 .18243 L .402 .256 0 r
F
.47116 .17696 m .47109 .17687 L .47113 .18243 L F
.47124 .17705 m .47109 .17701 L .47113 .18243 L .96 .972 0 r
F
.47113 .18243 m .47113 .18242 L .47113 .18243 L .402 .256 0 r
F
.471 .18789 m .47096 .18228 L .471 .1879 L .382 .215 0 r
F
.47104 .18238 m .47096 .18228 L .471 .1879 L F
.47112 .18247 m .47096 .18244 L .471 .1879 L .962 .967 0 r
F
.471 .1879 m .471 .18789 L .471 .1879 L .382 .215 0 r
F
.4708 .22487 m .47084 .18793 L .45082 .18771 L 1 .398 0 r
F
.47084 .18793 m .46711 .18774 L .45082 .18771 L F
.47097 .17183 m .47173 .15063 L .45749 .1511 L 1 .585 0 r
F
.47159 .17161 m .4716 .17104 L .47151 .17116 L 1 1 0 r
F
.4716 .17104 m .47173 .15063 L .47097 .17183 L 1 .585 0 r
F
.47159 .17161 m .47054 .16569 L .47097 .17183 L 1 1 0 r
F
.47149 .17751 m .47159 .17161 L .47102 .17216 L F
.471 .17212 m .45749 .1511 L .45652 .15624 L 1 .585 0 r
F
.47102 .17216 m .47099 .17211 L .471 .17212 L F
.47099 .17211 m .45749 .1511 L .471 .17212 L F
.47079 .17937 m .45652 .15624 L .45555 .16141 L .451 .264 0 r
F
.47079 .17935 m .45652 .15624 L .47079 .17937 L F
.47147 .17873 m .47076 .17904 L .47082 .17941 L 1 1 0 r
F
.47079 .17909 m .47076 .17904 L .47082 .17941 L .451 .264 0 r
F
.47076 .17904 m .45652 .15624 L .47082 .17941 L F
.47058 .1868 m .45555 .16141 L .45459 .16664 L .427 .219 0 r
F
.47057 .18678 m .45555 .16141 L .47058 .1868 L F
.47135 .18602 m .47055 .18644 L .47061 .18684 L 1 1 0 r
F
.47058 .18649 m .47055 .18644 L .47061 .18684 L .427 .219 0 r
F
.47055 .18644 m .45555 .16141 L .47061 .18684 L F
.47036 .19442 m .45459 .16664 L .45364 .17191 L .404 .176 0 r
F
.47036 .1944 m .45459 .16664 L .47036 .19442 L F
.47123 .19347 m .47033 .19403 L .4704 .19448 L 1 1 0 r
F
.47037 .19409 m .47033 .19403 L .4704 .19448 L .404 .176 0 r
F
.47033 .19403 m .45459 .16664 L .4704 .19448 L F
.47014 .20224 m .45364 .17191 L .4527 .17724 L .383 .135 0 r
F
.47014 .20222 m .45364 .17191 L .47014 .20224 L F
.47112 .20109 m .47011 .20181 L .47018 .2023 L 1 1 0 r
F
.47015 .20188 m .47011 .20181 L .47018 .2023 L .383 .135 0 r
F
.47011 .20181 m .45364 .17191 L .47018 .2023 L F
.46991 .21025 m .4527 .17724 L .45177 .1826 L .371 .096 0 r
F
.46991 .21022 m .4527 .17724 L .46991 .21025 L F
.47101 .20886 m .46988 .20977 L .46996 .21032 L 1 1 0 r
F
.46992 .20985 m .46988 .20977 L .46996 .21032 L .371 .096 0 r
F
.46988 .20977 m .4527 .17724 L .46996 .21032 L F
.46928 .2265 m .45084 .18802 L .44993 .19349 L .346 .069 0 r
F
.46926 .22621 m .45084 .18802 L .46928 .2265 L F
.46993 .2273 m .45084 .18802 L .46998 .22769 L F
.49113 .22732 m .4907 .21998 L .4707 .23308 L 1 1 0 r
F
.47071 .23798 m .47081 .22911 L .44993 .19349 L .333 .064 0 r
F
.46968 .21843 m .45177 .1826 L .45084 .18802 L .358 .074 0 r
F
.46966 .21819 m .45177 .1826 L .46968 .21843 L F
.46998 .22769 m .46926 .22621 L .46928 .2265 L .346 .069 0 r
F
.47081 .22911 m .46993 .2273 L .46998 .22769 L F
.49154 .23476 m .49113 .22732 L .4706 .24139 L 1 .996 0 r
F
.47062 .247 m .47071 .23798 L .45937 .26412 L 1 .875 0 r
F
.45937 .26442 m .45937 .26412 L .45894 .26509 L F
.47062 .247 m .45937 .26412 L .45937 .26442 L F
.459 .26682 m .45894 .26509 L .45592 .27205 L F
.47062 .247 m .45894 .26509 L .459 .26682 L F
.45973 .26595 m .45942 .2661 L .45943 .26647 L F
.45972 .26558 m .45942 .2661 L .45973 .26595 L F
.45942 .2661 m .459 .26682 L .45943 .26647 L F
.459 .26682 m .45592 .27205 L .45901 .2672 L F
.4907 .21998 m .49023 .21275 L .4708 .22487 L 1 1 0 r
F
.47081 .22911 m .47091 .22052 L .45084 .18802 L .346 .069 0 r
F
.47091 .22052 m .47091 .22048 L .4709 .2205 L .996 .305 0 r
F
.47091 .22048 m .4709 .21679 L .46973 .21851 L F
.47091 .22052 m .46973 .21851 L .45084 .18802 L .346 .069 0 r
F
.47091 .22048 m .46973 .21851 L .45456 .24076 L .996 .305 0 r
F
.49284 .26537 m .47026 .27506 L .47019 .28339 L 1 .948 0 r
F
.49284 .26537 m .49256 .25762 L .47026 .27506 L F
.49308 .27316 m .49284 .26537 L .47019 .28339 L 1 .935 0 r
F
.49308 .27316 m .47019 .28339 L .47012 .29158 L F
.49329 .28097 m .49308 .27316 L .47012 .29158 L 1 .921 0 r
F
.49256 .25762 m .47034 .26666 L .47026 .27506 L 1 .961 0 r
F
.49256 .25762 m .49225 .24992 L .47034 .26666 L F
.49329 .28097 m .47012 .29158 L .47006 .29962 L 1 .921 0 r
F
.49346 .28877 m .49329 .28097 L .47006 .29962 L 1 .907 0 r
F
.49225 .24992 m .47042 .25821 L .47034 .26666 L 1 .973 0 r
F
.49225 .24992 m .49191 .2423 L .47042 .25821 L F
.49346 .28877 m .47006 .29962 L .46999 .30745 L 1 .907 0 r
F
.49361 .29655 m .49346 .28877 L .46999 .30745 L 1 .894 0 r
F
.49361 .29655 m .46999 .30745 L .46994 .31505 L F
.49373 .30425 m .49361 .29655 L .46994 .31505 L 1 .88 0 r
F
.49234 .26003 m .47038 .27441 L .47031 .28344 L 1 .966 0 r
F
.47519 .27098 m .47507 .26957 L .47146 .2733 L F
.47519 .27098 m .47146 .2733 L .47146 .27333 L F
.47519 .27098 m .47138 .27338 L .47138 .27341 L F
.47571 .27092 m .4713 .27346 L .4713 .27381 L F
.49234 .26003 m .47569 .27066 L .47571 .27092 L F
.47569 .27066 m .4713 .27346 L .47571 .27092 L F
.47146 .27333 m .47146 .2733 L .47138 .27338 L F
.47138 .27341 m .47138 .27338 L .4713 .27346 L F
.4713 .27381 m .4713 .27346 L .47038 .27441 L F
.49257 .26807 m .49234 .26003 L .47652 .27684 L 1 .951 0 r
F
.47668 .27904 m .47652 .27684 L .47031 .28344 L F
.49257 .26807 m .47652 .27684 L .47668 .27904 L F
.49206 .25206 m .47046 .26528 L .47038 .27441 L 1 .98 0 r
F
.49206 .25206 m .49175 .24419 L .47539 .2604 L F
.47455 .26278 m .47443 .26134 L .47135 .26439 L F
.47135 .26443 m .47135 .26439 L .47128 .26447 L F
.47455 .26278 m .47135 .26439 L .47135 .26443 L F
.47455 .26278 m .47128 .26447 L .47128 .26478 L F
.47128 .26478 m .47128 .26447 L .47046 .26528 L F
.49257 .26807 m .47031 .28344 L .47025 .2923 L 1 .951 0 r
F
.49277 .27616 m .49257 .26807 L .47025 .2923 L 1 .937 0 r
F
.49175 .24419 m .47054 .25612 L .47046 .26528 L 1 .994 0 r
F
.49175 .24419 m .4914 .23642 L .4748 .25209 L F
.47492 .25366 m .4748 .25209 L .47054 .25612 L F
.49175 .24419 m .4748 .25209 L .47492 .25366 L F
.48918 .1994 m .48865 .19239 L .47126 .20357 L 1 1 0 r
F
.47123 .20311 m .47112 .20109 L .47119 .20715 L .749 .137 0 r
F
.47126 .20362 m .47126 .20357 L .47112 .20365 L 1 1 0 r
F
.48918 .1994 m .47126 .20357 L .47126 .20362 L F
.47121 .2058 m .47119 .20715 L .4712 .20828 L .749 .137 0 r
F
.47123 .20311 m .47119 .20715 L .47121 .2058 L F
.49373 .30425 m .46994 .31505 L .46988 .3224 L 1 .88 0 r
F
.49382 .31187 m .49373 .30425 L .46988 .3224 L 1 .867 0 r
F
.49277 .27616 m .47025 .2923 L .47019 .30092 L 1 .937 0 r
F
.49293 .28426 m .49277 .27616 L .47019 .30092 L 1 .922 0 r
F
.4914 .23642 m .47062 .247 L .47054 .25612 L 1 1 0 r
F
.4914 .23642 m .49102 .22876 L .47062 .247 L F
.49293 .28426 m .47019 .30092 L .47013 .30925 L 1 .922 0 r
F
.49305 .29235 m .49293 .28426 L .47013 .30925 L 1 .907 0 r
F
.49382 .31187 m .46988 .3224 L .46983 .32949 L 1 .867 0 r
F
.49388 .31938 m .49382 .31187 L .46983 .32949 L 1 .854 0 r
F
.49102 .22876 m .47071 .23798 L .47062 .247 L 1 1 0 r
F
.49102 .22876 m .49061 .22123 L .47071 .23798 L F
.49305 .29235 m .47013 .30925 L .47008 .31726 L 1 .907 0 r
F
.49315 .30039 m .49305 .29235 L .47008 .31726 L 1 .893 0 r
F
.49388 .31938 m .46983 .32949 L .46977 .33632 L 1 .854 0 r
F
.49393 .32674 m .49388 .31938 L .46977 .33632 L 1 .842 0 r
F
.49061 .22123 m .47081 .22911 L .47071 .23798 L 1 1 0 r
F
.49061 .22123 m .49016 .21382 L .47081 .22911 L F
.49315 .30039 m .47008 .31726 L .47003 .32492 L 1 .893 0 r
F
.49321 .30834 m .49315 .30039 L .47003 .32492 L 1 .88 0 r
F
.49393 .32674 m .46977 .33632 L .46973 .34289 L 1 .842 0 r
F
.49396 .33393 m .49393 .32674 L .46973 .34289 L 1 .831 0 r
F
.47178 .22834 m .47112 .22034 L .47111 .2206 L 1 1 0 r
F
.49016 .21382 m .47112 .22034 L .47178 .22834 L F
.47178 .22834 m .47111 .2206 L .47108 .2289 L F
.49321 .30834 m .47003 .32492 L .46998 .33222 L 1 .88 0 r
F
.49325 .31617 m .49321 .30834 L .46998 .33222 L 1 .868 0 r
F
.49396 .33393 m .46973 .34289 L .46968 .34921 L 1 .831 0 r
F
.49325 .31617 m .46998 .33222 L .46993 .33918 L 1 .868 0 r
F
.49326 .32384 m .49325 .31617 L .46993 .33918 L 1 .857 0 r
F
.49326 .32384 m .46993 .33918 L .46989 .3458 L F
.49326 .33132 m .49326 .32384 L .46989 .3458 L 1 .848 0 r
F
.49326 .33132 m .46989 .3458 L .46984 .35211 L F
.49325 .33858 m .49326 .33132 L .46984 .35211 L 1 .839 0 r
F
.47985 .36091 m .47112 .22034 L .47115 .36297 L .747 .135 0 r
F
.47181 .21975 m .47118 .21195 L .47112 .22025 L 1 1 0 r
F
.49016 .21382 m .48968 .20654 L .47111 .22026 L F
.47112 .22034 m .4709 .21679 L .47091 .22052 L .747 .135 0 r
F
.47112 .22034 m .47111 .22026 L .47091 .22041 L 1 1 0 r
F
.49016 .21382 m .47111 .22026 L .47112 .22034 L F
.47128 .2229 m .47127 .22272 L .47111 .22026 L .747 .135 0 r
F
.47111 .22026 m .47111 .22026 L .47111 .22025 L F
.47128 .2229 m .47111 .22026 L .47111 .22026 L F
.48968 .20654 m .48918 .1994 L .47118 .21181 L 1 1 0 r
F
.47115 .21136 m .47101 .20886 L .47113 .21561 L .749 .136 0 r
F
.47118 .21188 m .47118 .21181 L .47101 .21192 L 1 1 0 r
F
.48968 .20654 m .47118 .21181 L .47118 .21188 L F
.47126 .21321 m .47118 .21188 L .47127 .22272 L .749 .136 0 r
F
.47118 .21188 m .47115 .21136 L .47117 .2127 L F
.47118 .21188 m .47117 .2127 L .47127 .22272 L F
.47118 .21195 m .47116 .21507 L .47112 .22025 L 1 1 0 r
F
.47118 .21188 m .47118 .2118 L .47101 .20886 L .749 .136 0 r
F
.47126 .20363 m .47112 .20113 L .47112 .20114 L .749 .137 0 r
F
.48918 .1994 m .47128 .20362 L .47119 .21084 L 1 1 0 r
F
.47119 .21181 m .47119 .21084 L .47118 .21181 L F
.48918 .1994 m .47119 .21084 L .47119 .21181 L F
.47122 .20303 m .47122 .20305 L .47112 .20113 L .749 .137 0 r
F
.48968 .20654 m .47118 .21188 L .47181 .21975 L 1 1 0 r
F
.47118 .21188 m .47118 .21188 L .47181 .21975 L F
.47973 .35902 m .4796 .35817 L .47129 .22314 L .747 .135 0 r
F
.47973 .35902 m .47129 .22314 L .47129 .22315 L F
.47985 .36091 m .47127 .22272 L .47128 .2229 L F
.4796 .35817 m .47126 .21321 L .47126 .21957 L .749 .136 0 r
F
.47129 .22315 m .47129 .22314 L .47127 .22272 L .747 .135 0 r
F
.47138 .22465 m .47126 .21957 L .47127 .22272 L .749 .136 0 r
F
.4796 .35817 m .47126 .21957 L .47138 .22465 L F
.4796 .35817 m .47125 .21309 L .47126 .21321 L F
.4713 .2045 m .47123 .20311 L .4713 .21395 L .749 .137 0 r
F
.4713 .2045 m .47122 .20305 L .47122 .20303 L F
.4712 .20892 m .47112 .20109 L .47118 .21181 L F
.47123 .20323 m .4712 .20828 L .4712 .20892 L F
.47123 .20586 m .4712 .20892 L .47125 .21309 L F
.47123 .20323 m .4712 .20892 L .47123 .20586 L F
.47128 .20391 m .47125 .20387 L .47118 .21181 L 1 1 0 r
F
.47123 .20311 m .4712 .20828 L .47123 .20323 L .749 .137 0 r
F
.47125 .20387 m .47112 .20365 L .47118 .21142 L 1 1 0 r
F
.47125 .20387 m .47118 .21142 L .47118 .21181 L F
.47128 .20362 m .47126 .20362 L .47128 .20391 L F
.47126 .20362 m .47112 .20365 L .47128 .20391 L F
.4713 .2045 m .4713 .20441 L .47125 .20356 L .749 .137 0 r
F
.47125 .20359 m .47125 .20356 L .47122 .20305 L F
.4713 .2045 m .47125 .20356 L .47125 .20359 L F
.47125 .20356 m .4712 .19577 L .47122 .20305 L .747 .137 0 r
F
.47135 .20538 m .47126 .20363 L .47126 .20363 L .749 .137 0 r
F
.47179 .20188 m .47136 .19585 L .47127 .20217 L 1 1 0 r
F
.48865 .19239 m .47127 .20217 L .47126 .20356 L F
.47136 .19558 m .47134 .19558 L .47126 .20357 L F
.47131 .19801 m .47129 .19755 L .47129 .19993 L .747 .137 0 r
F
.47134 .19558 m .47126 .20319 L .47126 .20357 L 1 1 0 r
F
.47129 .19755 m .4712 .19577 L .4713 .20441 L .747 .137 0 r
F
.48865 .19239 m .48809 .18551 L .47134 .19554 L 1 1 0 r
F
.47134 .19558 m .47123 .19347 L .47131 .19776 L .747 .137 0 r
F
.47134 .19566 m .47131 .19776 L .47131 .19801 L F
.47134 .19558 m .47131 .19776 L .47134 .19566 L F
.47134 .19558 m .47134 .19554 L .47123 .19347 L F
.47134 .19554 m .47135 .18602 L .47123 .19347 L .74 .137 0 r
F
.47134 .19554 m .47135 .18778 L .47124 .1956 L 1 1 0 r
F
.48809 .18551 m .47145 .18776 L .47145 .18802 L F
.4718 .19355 m .47145 .18802 L .47137 .19376 L F
.48809 .18551 m .47145 .18802 L .4718 .19355 L F
.47135 .19554 m .47137 .19376 L .47134 .19554 L F
.48809 .18551 m .47137 .19376 L .47135 .19554 L F
.47145 .18776 m .47143 .18777 L .47134 .19554 L F
.47134 .19554 m .47139 .19003 L .47134 .19554 L .74 .137 0 r
F
.47139 .19003 m .47141 .18732 L .47139 .19004 L F
.47139 .19003 m .47139 .19004 L .47134 .19554 L F
.48809 .18551 m .48751 .17876 L .47143 .18773 L 1 1 0 r
F
.47141 .18732 m .47135 .18602 L .47134 .19381 L .74 .137 0 r
F
.47137 .19174 m .47134 .19381 L .47134 .19554 L F
.47141 .18732 m .47134 .19381 L .47137 .19174 L F
.47143 .18777 m .47143 .18773 L .47135 .18602 L F
.47143 .18773 m .47147 .17873 L .47135 .18602 L .726 .135 0 r
F
.47143 .18773 m .47147 .18017 L .47135 .18778 L 1 1 0 r
F
.48751 .17876 m .47155 .18017 L .47155 .18041 L F
.47182 .18546 m .47155 .18041 L .47147 .18561 L F
.48751 .17876 m .47155 .18041 L .47182 .18546 L F
.47144 .18773 m .47147 .18561 L .47143 .18773 L F
.48751 .17876 m .47147 .18561 L .47144 .18773 L F
.47155 .18017 m .47153 .18017 L .47143 .18773 L F
.47143 .18774 m .47149 .1825 L .47143 .18773 L .726 .135 0 r
F
.47149 .1825 m .47151 .17975 L .47149 .18251 L F
.47149 .1825 m .47149 .18251 L .47143 .18773 L F
.48751 .17876 m .48691 .17213 L .47153 .18014 L 1 1 0 r
F
.47153 .18017 m .47151 .17975 L .47147 .184 L .726 .135 0 r
F
.47153 .1802 m .47147 .184 L .47143 .18774 L F
.47153 .18017 m .47147 .184 L .47153 .1802 L F
.47151 .17975 m .47147 .17873 L .47143 .18773 L F
.47153 .18017 m .47153 .18014 L .47147 .17873 L F
.47153 .18014 m .47159 .17161 L .47147 .17873 L 0 0 0 r
F
.47153 .18014 m .47159 .17278 L .47147 .18017 L 1 1 0 r
F
.48076 .15993 m .47173 .15063 L .4716 .17104 L .518 .452 0 r
F
.4716 .17104 m .47172 .16466 L .47151 .17116 L 1 1 0 r
F
.4716 .17104 m .47151 .17116 L .47151 .17116 L F
.48629 .16564 m .48076 .15993 L .4716 .17104 L .518 .452 0 r
F
.47164 .17276 m .47164 .17275 L .47159 .17161 L 0 0 0 r
F
.47164 .17275 m .4716 .17104 L .47159 .17161 L F
.47162 .17238 m .47159 .17161 L .47155 .17694 L F
.47159 .17519 m .47155 .17694 L .47153 .18014 L F
.47162 .17238 m .47155 .17694 L .47159 .17519 L F
.48691 .17213 m .48629 .16564 L .47164 .17276 L 1 1 0 r
F
.48691 .17213 m .47166 .17278 L .47165 .17306 L F
.47182 .17758 m .47165 .17306 L .47157 .17767 L F
.48691 .17213 m .47165 .17306 L .47182 .17758 L F
.48691 .17213 m .47164 .17276 L .47164 .17278 L F
.48691 .17213 m .47157 .17767 L .47154 .18014 L F
.47153 .18014 m .47162 .17238 L .47153 .18014 L 0 0 0 r
F
.47166 .17278 m .47164 .17278 L .47153 .18014 L 1 1 0 r
F
.47164 .17278 m .47154 .17985 L .47153 .18014 L F
.47154 .18014 m .47157 .17767 L .47153 .18014 L F
.48751 .17876 m .47153 .18014 L .47153 .18017 L F
.47153 .18017 m .47143 .1874 L .47143 .18773 L F
.48809 .18551 m .47143 .18773 L .47143 .18777 L F
.47143 .18777 m .47134 .19518 L .47134 .19554 L F
.48865 .19239 m .47134 .19554 L .47134 .19558 L F
.4796 .35817 m .4713 .21395 L .4713 .21394 L .749 .136 0 r
F
.4796 .35817 m .47935 .35531 L .4713 .21395 L F
.47935 .35531 m .4713 .2045 L .4713 .21395 L .749 .137 0 r
F
.47935 .35531 m .47135 .20537 L .47135 .20538 L F
.47552 .26218 m .47539 .2604 L .47443 .26134 L 1 .98 0 r
F
.47552 .26218 m .47443 .26134 L .47455 .26278 L F
.47935 .35531 m .47911 .35229 L .4713 .20441 L .749 .137 0 r
F
.47935 .35531 m .4713 .20441 L .4713 .2045 L F
.47911 .35229 m .47134 .19558 L .47131 .19801 L .747 .137 0 r
F
.4713 .1977 m .47123 .19347 L .4712 .19577 L F
.47131 .19801 m .4713 .19742 L .4713 .1977 L F
.4713 .19742 m .47123 .19347 L .4713 .1977 L F
.47134 .19558 m .47124 .1956 L .47126 .20319 L 1 1 0 r
F
.47911 .35229 m .47131 .19801 L .4713 .20441 L .747 .137 0 r
F
.47911 .35229 m .47887 .34904 L .47134 .19554 L F
.47911 .35229 m .47134 .19554 L .47134 .19558 L F
.48865 .19239 m .47136 .19558 L .47136 .19585 L 1 1 0 r
F
.48865 .19239 m .47136 .19585 L .47179 .20188 L F
.49234 .26003 m .49206 .25206 L .47507 .26957 L 1 .966 0 r
F
.49234 .26003 m .47507 .26957 L .47519 .27098 L F
.47887 .34904 m .47143 .18777 L .47134 .19554 L .74 .137 0 r
F
.47143 .18777 m .47141 .18732 L .47134 .19554 L F
.47887 .34904 m .47795 .3303 L .47143 .18773 L F
.47887 .34904 m .47865 .34545 L .47795 .3303 L F
.47887 .34904 m .47143 .18773 L .47143 .18777 L F
.47865 .34545 m .47153 .18017 L .47143 .18774 L .726 .135 0 r
F
.47865 .34545 m .47808 .33306 L .47153 .18014 L F
.47865 .34545 m .47843 .34134 L .47808 .33306 L F
.47865 .34545 m .47153 .18014 L .47153 .18017 L F
.47843 .34134 m .47164 .17278 L .47153 .18014 L 0 0 0 r
F
.47164 .17278 m .47162 .17238 L .47153 .18014 L F
.47164 .17278 m .47159 .17278 L .47154 .17985 L 1 1 0 r
F
.47843 .34134 m .47829 .33756 L .47635 .28949 L 0 0 0 r
F
.47553 .26937 m .47635 .28949 L .47164 .17276 L F
.47843 .34134 m .47635 .28949 L .47553 .26937 L F
.48629 .16564 m .4716 .17104 L .47164 .17276 L .518 .452 0 r
F
.47825 .33644 m .47174 .16522 L .47164 .17276 L 0 0 0 r
F
.47174 .16522 m .47172 .16466 L .47164 .17276 L F
.49206 .25206 m .47539 .2604 L .47552 .26218 L 1 .98 0 r
F
.47825 .33644 m .4781 .33018 L .47175 .16556 L 0 0 0 r
F
.47175 .16557 m .47175 .16556 L .47172 .16466 L F
.47825 .33644 m .47175 .16556 L .47175 .16557 L F
.47164 .17275 m .47172 .16466 L .4716 .17104 L F
.47097 .17183 m .45749 .1511 L .47102 .17216 L 1 .585 0 r
F
.47151 .17116 m .47172 .16466 L .47054 .16569 L 1 1 0 r
F
.47123 .19347 m .47135 .18602 L .47061 .18684 L F
.47114 .19307 m .47061 .18684 L .47048 .19022 L F
.47123 .19347 m .47061 .18684 L .47114 .19307 L F
.47033 .19403 m .47061 .18684 L .45459 .16664 L .404 .176 0 r
F
.47123 .19347 m .46988 .18766 L .47033 .19403 L 1 1 0 r
F
.47112 .20109 m .47123 .19347 L .4704 .19448 L F
.47124 .1956 m .47135 .18778 L .47061 .18684 L .404 .176 0 r
F
.47124 .1956 m .47061 .18684 L .47033 .19403 L F
.47048 .19022 m .47061 .18684 L .46988 .18766 L 1 1 0 r
F
.47135 .18602 m .47136 .18564 L .47069 .18272 L F
.47135 .18602 m .47069 .18272 L .47069 .18288 L F
.47136 .18564 m .47147 .17873 L .47082 .17941 L F
.47055 .18644 m .47082 .17941 L .45555 .16141 L .427 .219 0 r
F
.47136 .18564 m .47082 .17941 L .47011 .18014 L 1 1 0 r
F
.47135 .18602 m .47011 .18014 L .47055 .18644 L F
.47135 .18778 m .47147 .18017 L .47082 .17941 L .427 .219 0 r
F
.47135 .18778 m .47082 .17941 L .47055 .18644 L F
.47069 .18288 m .47069 .18272 L .47011 .18014 L 1 1 0 r
F
.47147 .17873 m .47149 .17751 L .47091 .17517 L F
.47147 .17873 m .47091 .17517 L .47089 .17573 L F
.47076 .17904 m .47102 .17216 L .45652 .15624 L .451 .264 0 r
F
.47149 .17751 m .47102 .17216 L .47033 .17282 L 1 1 0 r
F
.47147 .17873 m .47033 .17282 L .47076 .17904 L F
.47147 .18017 m .47159 .17278 L .47102 .17216 L .451 .264 0 r
F
.47147 .18017 m .47102 .17216 L .47076 .17904 L F
.47089 .17573 m .47091 .17517 L .47033 .17282 L 1 1 0 r
F
.47097 .17183 m .47054 .16569 L .45856 .17614 L F
.47172 .16466 m .45933 .1679 L .45856 .17614 L F
.47172 .16466 m .47184 .15786 L .45933 .1679 L F
.4781 .33018 m .47184 .15786 L .47172 .16466 L 0 0 0 r
F
.47172 .1656 m .47174 .16421 L .45943 .17059 L 1 1 0 r
F
.47174 .16421 m .47184 .15861 L .4717 .15875 L F
.47174 .16421 m .4717 .15875 L .45943 .17059 L F
.47729 .31276 m .47806 .33102 L .47172 .1656 L 0 0 0 r
F
.47829 .33756 m .47825 .33644 L .47764 .32148 L F
.47829 .33756 m .47764 .32148 L .47164 .17276 L F
.47843 .34134 m .47164 .17276 L .47164 .17278 L F
.47822 .33709 m .47811 .33289 L .47729 .31276 L F
.47811 .33289 m .47806 .33102 L .47729 .31276 L F
.47153 .18017 m .47153 .18014 L .47147 .18017 L 1 1 0 r
F
.47153 .18017 m .47147 .18017 L .47143 .1874 L F
.47143 .18777 m .47143 .18773 L .47135 .18778 L F
.47143 .18777 m .47135 .18778 L .47134 .19518 L F
.47134 .19558 m .47134 .19554 L .47124 .1956 L F
.47126 .20168 m .4712 .19577 L .47125 .20356 L .747 .137 0 r
F
.47126 .20363 m .47112 .20113 L .47126 .20363 L .749 .137 0 r
F
.47112 .20114 m .47112 .20113 L .47112 .20109 L F
.47122 .20305 m .4712 .19577 L .47112 .20109 L .747 .137 0 r
F
.47125 .20351 m .47124 .1956 L .47114 .20217 L 1 1 0 r
F
.47126 .20357 m .47126 .20319 L .47125 .20351 L F
.47126 .20319 m .47124 .1956 L .47125 .20351 L F
.47131 .19801 m .47129 .19993 L .4713 .20441 L .747 .137 0 r
F
.47126 .20356 m .47127 .20217 L .47126 .20357 L 1 1 0 r
F
.47135 .20537 m .47112 .20113 L .47135 .20538 L .749 .137 0 r
F
.4713 .20441 m .47126 .20168 L .47125 .20356 L .747 .137 0 r
F
.47125 .20357 m .47114 .20217 L .47112 .20365 L 1 1 0 r
F
.47126 .20357 m .47114 .20217 L .47125 .20357 L F
.47115 .2114 m .47112 .20109 L .47101 .20886 L .749 .137 0 r
F
.47118 .21181 m .47117 .21025 L .47115 .2114 L F
.47117 .21025 m .47112 .20109 L .47115 .2114 L F
.47118 .21181 m .47118 .21142 L .47118 .21181 L 1 1 0 r
F
.47126 .21321 m .47125 .21309 L .47118 .2118 L .749 .136 0 r
F
.47126 .21321 m .47118 .2118 L .47118 .21188 L F
.47125 .21309 m .4712 .20892 L .47118 .21181 L .749 .137 0 r
F
.47118 .21181 m .47112 .20365 L .47101 .21192 L 1 1 0 r
F
.47118 .21142 m .47112 .20365 L .47118 .21181 L F
.47115 .21136 m .47113 .21561 L .47114 .21576 L .749 .136 0 r
F
.47117 .21302 m .47114 .21576 L .47127 .22272 L F
.47115 .21136 m .47114 .21576 L .47117 .21302 L F
.47108 .2289 m .47111 .2206 L .47081 .22911 L 1 1 0 r
F
.47112 .22034 m .47111 .22025 L .4709 .21679 L .747 .135 0 r
F
.47128 .2229 m .47111 .22025 L .47112 .22034 L F
.47112 .22034 m .47091 .22052 L .47081 .22911 L 1 1 0 r
F
.47112 .22034 m .47091 .22052 L .47115 .36297 L .747 .135 0 r
F
.47112 .22034 m .47091 .22041 L .47091 .22052 L 1 1 0 r
F
.47111 .22026 m .47101 .20886 L .4709 .21679 L .749 .136 0 r
F
.47127 .22272 m .47115 .21629 L .47111 .22026 L F
.47115 .21629 m .47101 .20886 L .47111 .22026 L F
.47118 .21195 m .47118 .21188 L .47116 .21507 L 1 1 0 r
F
.47112 .22025 m .47101 .21192 L .47091 .22041 L F
.47118 .21188 m .47101 .21192 L .47112 .22025 L F
.4713 .21394 m .4713 .21395 L .47125 .21309 L .749 .136 0 r
F
.4713 .21395 m .47123 .20311 L .47125 .21309 L .749 .137 0 r
F
.47091 .22052 m .47091 .22041 L .46973 .21851 L .346 .069 0 r
F
.45558 .28986 m .4536 .26922 L .45334 .27821 L 0 0 0 r
F
.45615 .27421 m .45607 .27356 L .45608 .27376 L F
.47046 .26528 m .47054 .25612 L .45921 .2827 L 1 .848 0 r
F
.47046 .26528 m .45921 .2827 L .45925 .2838 L F
.45875 .28497 m .4575 .2867 L .45752 .28705 L F
.47046 .26528 m .45874 .28466 L .45875 .28497 L F
.45874 .28466 m .4575 .2867 L .45875 .28497 L F
.45755 .28765 m .45693 .28802 L .45697 .28865 L F
.47046 .26528 m .45752 .28705 L .45755 .28765 L F
.45752 .28705 m .45693 .28802 L .45755 .28765 L F
.45634 .26498 m .4563 .26436 L .45633 .26488 L 0 0 0 r
F
.45925 .2838 m .45921 .2827 L .4575 .2867 L 1 .848 0 r
F
.457 .28918 m .45581 .29066 L .45579 .29133 L F
.47046 .26528 m .45697 .28865 L .457 .28918 L F
.45697 .28865 m .45693 .28802 L .45581 .29066 L F
.47054 .25612 m .4559 .28214 L .45589 .2829 L 1 .859 0 r
F
.45635 .28939 m .45589 .2829 L .45581 .29066 L F
.47054 .25612 m .45589 .2829 L .45635 .28939 L F
.45597 .28298 m .45594 .28243 L .4558 .28166 L 0 0 0 r
F
.45727 .27022 m .45592 .27205 L .4559 .27261 L 1 .875 0 r
F
.45726 .26995 m .45592 .27205 L .45727 .27022 L F
.4559 .26967 m .45517 .25701 L .45489 .26333 L 0 0 0 r
F
.45569 .29928 m .4556 .2983 L .45558 .29875 L F
.45569 .29919 m .4556 .2983 L .45569 .29928 L F
.45628 .29794 m .45579 .29133 L .45569 .29928 L 1 .848 0 r
F
.47046 .26528 m .45692 .28933 L .45733 .29551 L F
.45613 .2711 m .45597 .26248 L .4559 .26967 L 0 0 0 r
F
.47038 .27441 m .47046 .26528 L .45741 .29534 L 1 .841 0 r
F
.47038 .27441 m .45741 .29534 L .45741 .29538 L F
.45747 .29633 m .45733 .29551 L .45739 .29647 L F
.47038 .27441 m .45741 .29538 L .45747 .29633 L F
.45741 .29538 m .45733 .29551 L .45747 .29633 L F
.4561 .2737 m .45606 .27325 L .45607 .27351 L 0 0 0 r
F
.45742 .29694 m .45631 .2985 L .45633 .29882 L 1 .841 0 r
F
.45739 .29647 m .4563 .29831 L .45742 .29694 L F
.4563 .29831 m .4557 .29933 L .45631 .2985 L F
.45573 .29986 m .45569 .29928 L .4531 .28684 L 0 0 0 r
F
.4557 .29933 m .45569 .29934 L .4557 .29933 L 1 .841 0 r
F
.4557 .29933 m .4557 .29933 L .45631 .2985 L F
.45569 .29934 m .45569 .29937 L .45631 .2985 L F
.45573 .29986 m .4531 .28684 L .45558 .30706 L 0 0 0 r
F
.45573 .29986 m .45559 .29951 L .45558 .30013 L 1 .841 0 r
F
.45633 .29882 m .45575 .29937 L .45573 .29986 L F
.45575 .29937 m .45559 .29951 L .45573 .29986 L F
.45558 .30706 m .4531 .28684 L .45288 .29508 L 0 0 0 r
F
.49399 .36702 m .49399 .36081 L .46949 .37225 L 1 .79 0 r
F
.49399 .36702 m .46949 .37225 L .46945 .37752 L F
.49317 .35898 m .4932 .35242 L .46971 .36938 L 1 .823 0 r
F
.49317 .35898 m .46971 .36938 L .46967 .37467 L F
.49315 .3653 m .49317 .35898 L .46967 .37467 L 1 .819 0 r
F
.46073 .33575 m .45851 .33727 L .46081 .33827 L 1 .891 0 r
F
.46081 .33827 m .45851 .33727 L .45867 .34036 L F
.49315 .3653 m .46967 .37467 L .46963 .37977 L 1 .819 0 r
F
.49312 .37138 m .49315 .3653 L .46963 .37977 L 1 .817 0 r
F
.46977 .33632 m .46983 .32949 L .4511 .34773 L 1 .891 0 r
F
.47019 .30092 m .47025 .2923 L .45653 .31951 L 1 .839 0 r
F
.47019 .30092 m .45653 .31951 L .45658 .32007 L F
.45606 .3215 m .45544 .32167 L .4555 .32232 L F
.47019 .30092 m .45601 .32087 L .45606 .3215 L F
.45601 .32087 m .45544 .32167 L .45606 .3215 L F
.47025 .2923 m .47031 .28344 L .45609 .31351 L 1 .838 0 r
F
.47025 .2923 m .45609 .31351 L .45611 .3138 L F
.45617 .31442 m .45554 .31468 L .45559 .31532 L F
.47025 .2923 m .45611 .3138 L .45617 .31442 L F
.45611 .3138 m .45554 .31468 L .45617 .31442 L F
.45561 .30757 m .45541 .3063 L .45546 .3069 L 0 0 0 r
F
.45609 .31351 m .45567 .30785 L .45554 .31468 L 1 .838 0 r
F
.45719 .31117 m .45626 .30687 L .45665 .31234 L F
.47031 .28344 m .4574 .30495 L .45773 .31003 L F
.47031 .28344 m .47038 .27441 L .45619 .30597 L F
.45621 .30625 m .45619 .30597 L .45568 .3071 L F
.47031 .28344 m .45619 .30597 L .45621 .30625 L F
.4574 .30495 m .45684 .3059 L .45773 .31003 L F
.47031 .28344 m .45568 .3071 L .45567 .30785 L F
.47038 .27441 m .45573 .29986 L .45562 .30723 L 1 .841 0 r
F
.45631 .2985 m .45559 .29951 L .45633 .29882 L F
.4558 .29139 m .45334 .27821 L .4557 .29919 L 0 0 0 r
F
.45575 .29684 m .4557 .29919 L .45572 .2994 L F
.4558 .29139 m .4557 .29919 L .45575 .29684 L F
.45739 .29647 m .45733 .29551 L .45569 .29928 L 1 .841 0 r
F
.45569 .29934 m .45569 .29928 L .45559 .29951 L F
.45739 .29647 m .45569 .29928 L .45569 .29934 L F
.45707 .31843 m .45579 .31801 L .45598 .32059 L 1 .838 0 r
F
.45674 .31352 m .45559 .31532 L .45707 .31843 L F
.45548 .32221 m .45544 .32167 L .45281 .31173 L 0 0 0 r
F
.45549 .32225 m .45544 .32167 L .45548 .32221 L F
.45544 .32167 m .45266 .30292 L .45245 .31035 L F
.45559 .31532 m .45554 .31743 L .45579 .31801 L 1 .838 0 r
F
.45559 .31532 m .45266 .30292 L .45544 .32167 L 0 0 0 r
F
.45502 .31621 m .45514 .3178 L .45579 .31801 L 1 .838 0 r
F
.45559 .31532 m .45579 .31801 L .45707 .31843 L F
.45548 .32223 m .45281 .31173 L .45281 .31176 L 0 0 0 r
F
.45548 .32221 m .45281 .31173 L .45548 .32223 L F
.45549 .32227 m .45269 .31128 L .4527 .31133 L F
.45467 .34966 m .45308 .34702 L .45335 .35082 L 1 .891 0 r
F
.4608 .34425 m .45446 .34652 L .45467 .34966 L F
.45446 .34652 m .45308 .34702 L .45467 .34966 L F
.4526 .31872 m .45238 .31792 L .45238 .31795 L 0 0 0 r
F
.46072 .34185 m .4544 .34571 L .4608 .34425 L 1 .891 0 r
F
.4544 .34571 m .45443 .34613 L .4608 .34425 L F
.45305 .34654 m .45308 .34702 L .4608 .34425 L F
.45538 .32883 m .45259 .31869 L .4526 .31872 L 0 0 0 r
F
.47013 .30925 m .47019 .30092 L .45533 .32823 L 1 .842 0 r
F
.4554 .3289 m .45538 .32883 L .45538 .32883 L 0 0 0 r
F
.45538 .32883 m .45259 .31869 L .45538 .32883 L F
.47013 .30925 m .45533 .32823 L .4554 .3289 L 1 .842 0 r
F
.4554 .32888 m .4554 .32888 L .4554 .32891 L 0 0 0 r
F
.4554 .32888 m .45259 .31869 L .4554 .3289 L F
.4554 .32888 m .4554 .3289 L .4554 .32891 L F
.45851 .33727 m .45469 .33991 L .45867 .34036 L 1 .891 0 r
F
.45514 .34089 m .45194 .33086 L .45194 .33087 L 0 0 0 r
F
.45514 .3409 m .45194 .33086 L .45514 .3409 L F
.49311 .37724 m .46959 .38469 L .46955 .38945 L 1 .816 0 r
F
.49309 .38289 m .49311 .37724 L .46955 .38945 L 1 .815 0 r
F
.46973 .34289 m .46977 .33632 L .45086 .35302 L 1 .892 0 r
F
.49399 .38996 m .49399 .3845 L .46932 .39245 L 1 .77 0 r
F
.49399 .38996 m .46932 .39245 L .46928 .39717 L F
.49309 .38289 m .46955 .38945 L .46951 .39408 L 1 .815 0 r
F
.46071 .35007 m .45344 .35164 L .45372 .35565 L 1 .892 0 r
F
.46973 .34289 m .46063 .34777 L .46071 .35007 L F
.46063 .34777 m .45344 .35164 L .46071 .35007 L F
.45533 .32823 m .45245 .31035 L .45223 .3174 L 0 0 0 r
F
.45586 .32726 m .45542 .32525 L .45533 .32823 L 1 .839 0 r
F
.4556 .31497 m .45555 .31472 L .45555 .31475 L 0 0 0 r
F
.45748 .32429 m .45609 .32186 L .4564 .32627 L 1 .839 0 r
F
.45733 .29551 m .45579 .29133 L .45628 .29794 L 1 .848 0 r
F
.45614 .2932 m .45584 .29122 L .45588 .29178 L 0 0 0 r
F
.46083 .31812 m .45783 .32049 L .45801 .32332 L 1 .839 0 r
F
.46114 .31757 m .4607 .31475 L .46083 .31812 L F
.47019 .30092 m .46102 .31428 L .46114 .31757 L F
.46102 .31428 m .4607 .31475 L .46114 .31757 L F
.46965 .21792 m .45177 .1826 L .46969 .21825 L .358 .074 0 r
F
.4709 .21679 m .46965 .21792 L .46973 .21851 L 1 1 0 r
F
.4709 .21679 m .46977 .21477 L .46965 .21792 L F
.4709 .21679 m .47101 .20886 L .46996 .21032 L F
.4709 .21679 m .46996 .21032 L .47042 .21593 L F
.47091 .22041 m .47101 .21192 L .46996 .21032 L .358 .074 0 r
F
.46965 .21792 m .46996 .21032 L .45177 .1826 L F
.47042 .21593 m .46996 .21032 L .46845 .2124 L 1 1 0 r
F
.47091 .22041 m .46996 .21032 L .46965 .21792 L .358 .074 0 r
F
.46977 .21477 m .46937 .21405 L .46965 .21792 L 1 1 0 r
F
.47101 .20886 m .47112 .20109 L .47018 .2023 L F
.47101 .20886 m .47018 .2023 L .47061 .20746 L F
.46988 .20977 m .47018 .2023 L .4527 .17724 L .371 .096 0 r
F
.47101 .20886 m .46942 .20328 L .46988 .20977 L 1 1 0 r
F
.47101 .21192 m .47112 .20365 L .47018 .2023 L .371 .096 0 r
F
.47061 .20746 m .47018 .2023 L .47005 .20549 L 1 1 0 r
F
.47101 .21192 m .47018 .2023 L .46988 .20977 L .371 .096 0 r
F
.47005 .20549 m .47018 .2023 L .46942 .20328 L 1 1 0 r
F
.47018 .2023 m .45595 .21191 L .45543 .22143 L F
.45744 .21484 m .4573 .21339 L .45731 .21349 L 0 0 0 r
F
.4614 .32399 m .46063 .32193 L .46076 .32507 L 1 .842 0 r
F
.47112 .20109 m .4704 .19448 L .47087 .20013 L 1 1 0 r
F
.47011 .20181 m .4704 .19448 L .45364 .17191 L .383 .135 0 r
F
.47112 .20109 m .46966 .19537 L .47011 .20181 L 1 1 0 r
F
.47112 .20365 m .47124 .1956 L .4704 .19448 L .383 .135 0 r
F
.47087 .20013 m .4704 .19448 L .47027 .19776 L 1 1 0 r
F
.47112 .20365 m .4704 .19448 L .47011 .20181 L .383 .135 0 r
F
.47027 .19776 m .4704 .19448 L .46966 .19537 L 1 1 0 r
F
.4704 .19448 m .45652 .20258 L .45595 .21191 L F
.45819 .20725 m .45785 .20354 L .45785 .2036 L 0 0 0 r
F
.46162 .32363 m .46149 .32077 L .46158 .32369 L 1 .842 0 r
F
.47013 .30925 m .46155 .3207 L .46162 .32363 L F
.46155 .3207 m .46149 .32077 L .46162 .32363 L F
.46182 .32996 m .46095 .32828 L .46106 .33112 L 1 .846 0 r
F
.47008 .31726 m .46176 .32729 L .46182 .32996 L F
.46176 .32729 m .46095 .32828 L .46182 .32996 L F
.45814 .31632 m .45674 .31352 L .45707 .31843 L 1 .838 0 r
F
.45573 .26715 m .45553 .26584 L .45553 .26585 L 0 0 0 r
F
.45865 .31531 m .45831 .31104 L .45857 .31545 L 1 .838 0 r
F
.45645 .26572 m .45631 .26444 L .45634 .26498 L 0 0 0 r
F
.46013 .31236 m .4589 .31012 L .45913 .31434 L 1 .838 0 r
F
.47025 .2923 m .45995 .30847 L .46013 .31236 L F
.45995 .30847 m .4589 .31012 L .46013 .31236 L F
.46895 .21966 m .45497 .23107 L .45456 .24076 L 1 1 0 r
F
.45653 .2352 m .4565 .23484 L .45651 .23499 L 0 0 0 r
F
.46977 .33632 m .46072 .34185 L .4608 .34425 L 1 .891 0 r
F
.47038 .27441 m .45739 .29647 L .45742 .29694 L 1 .841 0 r
F
.46968 .34921 m .46973 .34289 L .45062 .35812 L 1 .893 0 r
F
.45407 .3604 m .45062 .35812 L .45037 .36305 L F
.46968 .34921 m .46048 .35351 L .46057 .35574 L F
.46963 .35529 m .46968 .34921 L .45037 .36305 L 1 .894 0 r
F
.47008 .31726 m .47013 .30925 L .45574 .33356 L 1 .846 0 r
F
.47008 .31726 m .45574 .33356 L .45578 .33403 L F
.45428 .33437 m .45436 .33565 L .45833 .33473 L 1 .892 0 r
F
.45522 .33443 m .45223 .3174 L .45201 .32408 L 0 0 0 r
F
.45526 .33502 m .45201 .32408 L .45511 .3398 L F
.45519 .32816 m .45223 .3174 L .45522 .33443 L F
.45583 .33446 m .45529 .33486 L .45529 .33511 L 1 .846 0 r
F
.45526 .33502 m .45522 .33443 L .45201 .32408 L 0 0 0 r
F
.45578 .33403 m .45524 .33467 L .45583 .33446 L 1 .846 0 r
F
.45529 .33511 m .45522 .33443 L .45526 .33502 L 0 0 0 r
F
.45524 .33467 m .45471 .33529 L .45526 .33488 L 1 .846 0 r
F
.45524 .33467 m .45526 .33488 L .45583 .33446 L F
.45578 .33403 m .45574 .33356 L .45471 .33529 L F
.45718 .3371 m .45586 .33494 L .45612 .33873 L F
.45626 .30687 m .45567 .30785 L .45665 .31234 L 1 .838 0 r
F
.45607 .30967 m .45563 .3073 L .45567 .30785 L 0 0 0 r
F
.46106 .33112 m .45755 .3337 L .45771 .33628 L 1 .846 0 r
F
.47008 .31726 m .45578 .33403 L .45583 .33446 L F
.45786 .31176 m .45674 .31352 L .45814 .31632 L 1 .838 0 r
F
.45596 .30099 m .45573 .29983 L .45573 .29986 L 0 0 0 r
F
.4607 .31475 m .45774 .31906 L .46083 .31812 L 1 .839 0 r
F
.45774 .31906 m .45719 .31986 L .45777 .31958 L F
.45774 .31906 m .45777 .31958 L .46083 .31812 L F
.46149 .32077 m .4613 .32103 L .46158 .32369 L 1 .842 0 r
F
.4563 .29831 m .45631 .2985 L .45742 .29694 L 1 .841 0 r
F
.45443 .36506 m .45037 .36305 L .45012 .36783 L 1 .894 0 r
F
.46963 .35529 m .45419 .36151 L .45443 .36506 L F
.45419 .36151 m .45037 .36305 L .45443 .36506 L F
.45223 .33175 m .45212 .3314 L .45212 .33142 L 0 0 0 r
F
.46057 .35574 m .45382 .35663 L .45407 .3604 L 1 .893 0 r
F
.46048 .35351 m .45382 .35663 L .46057 .35574 L F
.46958 .36114 m .46963 .35529 L .45012 .36783 L 1 .894 0 r
F
.45478 .36966 m .45012 .36783 L .44987 .37248 L F
.46958 .36114 m .45456 .36631 L .45478 .36966 L F
.45456 .36631 m .45012 .36783 L .45478 .36966 L F
.45234 .33209 m .45223 .33173 L .45223 .33175 L 0 0 0 r
F
.46954 .36679 m .46958 .36114 L .44987 .37248 L 1 .895 0 r
F
.47003 .32492 m .47008 .31726 L .45509 .34031 L 1 .851 0 r
F
.45516 .34095 m .45233 .33207 L .45234 .33209 L 0 0 0 r
F
.45516 .34093 m .45233 .33207 L .45516 .34095 L F
.47003 .32492 m .45509 .34031 L .45517 .34099 L 1 .851 0 r
F
.45529 .33486 m .45522 .33491 L .45529 .33511 L 1 .846 0 r
F
.46095 .32828 m .45748 .33247 L .46106 .33112 L F
.45748 .33247 m .45692 .33314 L .4575 .33286 L F
.45748 .33247 m .4575 .33286 L .46106 .33112 L F
.45692 .33314 m .45698 .33395 L .45754 .33356 L F
.4575 .33286 m .45754 .33356 L .46106 .33112 L F
.45692 .33314 m .45754 .33356 L .4575 .33286 L F
.45604 .30918 m .45556 .30695 L .45556 .30699 L 0 0 0 r
F
.45546 .32909 m .45519 .32809 L .45519 .32813 L F
.45585 .33478 m .45586 .33494 L .45699 .33411 L 1 .846 0 r
F
.45584 .33473 m .45699 .33411 L .45698 .33395 L F
.45529 .33511 m .45585 .33478 L .45584 .33473 L F
.45585 .33478 m .45699 .33411 L .45584 .33473 L F
.45698 .33395 m .45699 .33411 L .46106 .33112 L F
.45692 .33314 m .45583 .33446 L .45698 .33395 L F
.45583 .33446 m .45529 .33511 L .45584 .33473 L F
.45583 .33446 m .45584 .33473 L .45698 .33395 L F
.45545 .32906 m .45513 .32753 L .45519 .32809 L 0 0 0 r
F
.45649 .34376 m .45573 .34087 L .45597 .34449 L 1 .851 0 r
F
.45911 .34012 m .45629 .34074 L .45649 .34376 L F
.45629 .34074 m .45573 .34087 L .45649 .34376 L F
.45597 .3285 m .4554 .3289 L .45626 .33267 L 1 .842 0 r
F
.45554 .32939 m .45542 .32859 L .45545 .32906 L 0 0 0 r
F
.45893 .33692 m .45623 .33984 L .45911 .34012 L 1 .851 0 r
F
.45623 .33984 m .45517 .34099 L .45629 .34074 L F
.45623 .33984 m .45629 .34074 L .45911 .34012 L F
.45771 .33628 m .45699 .33411 L .45718 .3371 L 1 .846 0 r
F
.45755 .3337 m .45699 .33411 L .45771 .33628 L F
.45699 .33411 m .45586 .33494 L .45718 .3371 L F
.4568 .33177 m .45597 .3285 L .45626 .33267 L 1 .842 0 r
F
.46076 .32507 m .45655 .32808 L .4568 .33177 L F
.45655 .32808 m .45597 .3285 L .4568 .33177 L F
.45569 .31533 m .45555 .31472 L .45555 .31472 L 0 0 0 r
F
.46096 .33754 m .45893 .33692 L .45911 .34012 L 1 .851 0 r
F
.46202 .33607 m .46126 .3344 L .46135 .33699 L F
.47018 .2023 m .47014 .20222 L .47014 .20224 L .383 .135 0 r
F
.47011 .20181 m .45595 .21191 L .47018 .2023 L 1 1 0 r
F
.47011 .20181 m .46966 .19537 L .45595 .21191 L F
.46988 .20977 m .46942 .20328 L .45543 .22143 L F
.45909 .21699 m .45818 .20718 L .45819 .20725 L 0 0 0 r
F
.47003 .32492 m .46198 .33362 L .46204 .33604 L 1 .851 0 r
F
.46998 .33222 m .47003 .32492 L .45546 .3452 L 1 .857 0 r
F
.45556 .34608 m .45546 .3452 L .45321 .34834 L F
.46998 .33222 m .45546 .3452 L .45556 .34608 L F
.45491 .34015 m .45202 .33111 L .45202 .33112 L 0 0 0 r
F
.45573 .34087 m .45517 .34099 L .45597 .34449 L 1 .851 0 r
F
.45512 .37418 m .44987 .37248 L .44962 .377 L 1 .895 0 r
F
.46954 .36679 m .45492 .37102 L .45512 .37418 L F
.45492 .37102 m .44987 .37248 L .45512 .37418 L F
.45245 .33246 m .45194 .33085 L .45194 .33086 L 0 0 0 r
F
.46949 .37225 m .46954 .36679 L .44962 .377 L 1 .895 0 r
F
.45546 .37865 m .44962 .377 L .44937 .38143 L F
.46949 .37225 m .45527 .37565 L .45546 .37865 L F
.45527 .37565 m .44962 .377 L .45546 .37865 L F
.45255 .33278 m .45244 .33244 L .45245 .33246 L 0 0 0 r
F
.46945 .37752 m .46949 .37225 L .44937 .38143 L 1 .895 0 r
F
.45581 .38305 m .44937 .38143 L .44912 .38576 L F
.46945 .37752 m .45563 .38021 L .45581 .38305 L F
.45563 .38021 m .44937 .38143 L .45581 .38305 L F
.45265 .3331 m .45182 .33049 L .45182 .3305 L 0 0 0 r
F
.46941 .38264 m .46945 .37752 L .44912 .38576 L 1 .894 0 r
F
.46941 .38264 m .44912 .38576 L .44887 .39 L F
.46936 .38761 m .46941 .38264 L .44887 .39 L 1 .892 0 r
F
.45344 .35164 m .45086 .35302 L .45372 .35565 L F
.45335 .35082 m .4511 .34773 L .45086 .35302 L 1 .891 0 r
F
.45308 .34702 m .4511 .34773 L .45335 .35082 L F
.45582 .34998 m .45321 .34834 L .45298 .35354 L 1 .857 0 r
F
.46919 .21138 m .45543 .22143 L .45497 .23107 L 1 1 0 r
F
.46913 .21095 m .45543 .22143 L .46919 .21138 L F
.46996 .21032 m .46991 .21022 L .46991 .21025 L .371 .096 0 r
F
.46988 .20977 m .45543 .22143 L .46996 .21032 L 1 1 0 r
F
.45949 .22137 m .45908 .21693 L .45909 .21699 L 0 0 0 r
F
.46998 .33222 m .46221 .33969 L .46226 .3419 L 1 .857 0 r
F
.46993 .33918 m .46998 .33222 L .45582 .34998 L 1 .863 0 r
F
.45593 .35104 m .45582 .34998 L .45298 .35354 L F
.46993 .33918 m .45582 .34998 L .45593 .35104 L F
.45464 .33934 m .45255 .33277 L .45255 .33278 L 0 0 0 r
F
.45791 .34736 m .45556 .34608 L .45582 .34998 L 1 .857 0 r
F
.46226 .3419 m .45775 .34471 L .45791 .34736 L F
.45775 .34471 m .45556 .34608 L .45791 .34736 L F
.45613 .31719 m .45569 .31533 L .45569 .31533 L 0 0 0 r
F
.45613 .31719 m .45581 .31585 L .45581 .31586 L F
.46221 .33969 m .45771 .34401 L .46226 .3419 L 1 .857 0 r
F
.45771 .34401 m .45774 .34443 L .46226 .3419 L F
.45662 .34505 m .45665 .3454 L .45775 .34471 L F
.45774 .34443 m .45775 .34471 L .46226 .3419 L F
.45662 .34505 m .45775 .34471 L .45774 .34443 L F
.46135 .33699 m .46085 .33484 L .46096 .33754 L 1 .851 0 r
F
.46085 .33484 m .45893 .33692 L .46096 .33754 L F
.45719 .31986 m .45606 .3215 L .45724 .32067 L 1 .839 0 r
F
.45606 .3215 m .45609 .32186 L .45726 .32094 L F
.45724 .32067 m .45726 .32094 L .46083 .31812 L F
.45606 .3215 m .45726 .32094 L .45724 .32067 L F
.45719 .31986 m .45724 .32067 L .46083 .31812 L F
.45913 .31434 m .45839 .31092 L .45865 .31531 L 1 .838 0 r
F
.45839 .31092 m .45831 .31104 L .45865 .31531 L F
.45831 .31104 m .45786 .31176 L .45857 .31545 L F
.46063 .32193 m .45761 .32595 L .46076 .32507 L 1 .842 0 r
F
.45555 .3225 m .45548 .32221 L .45548 .32223 L 0 0 0 r
F
.45761 .32595 m .45595 .32817 L .4577 .32726 L 1 .842 0 r
F
.45595 .32817 m .45597 .3285 L .4577 .32726 L F
.45609 .32186 m .4555 .32232 L .4564 .32627 L 1 .839 0 r
F
.45382 .35663 m .45062 .35812 L .45407 .3604 L 1 .893 0 r
F
.45372 .35565 m .45086 .35302 L .45062 .35812 L 1 .892 0 r
F
.45774 .35291 m .45298 .35354 L .45275 .35852 L 1 .863 0 r
F
.46191 .34821 m .45915 .34832 L .4593 .35115 L F
.46993 .33918 m .46213 .34579 L .4622 .34789 L F
.46989 .3458 m .46993 .33918 L .45396 .35716 L 1 .87 0 r
F
.46989 .3458 m .45396 .35716 L .45396 .35721 L F
.46989 .3458 m .45385 .35729 L .45384 .35771 L F
.45704 .27888 m .45704 .27887 L .45702 .27892 L 1 .859 0 r
F
.45607 .27356 m .4548 .26554 L .45608 .27376 L 0 0 0 r
F
.45558 .26948 m .45396 .25748 L .45415 .26045 L .333 .064 0 r
F
.45607 .27351 m .45504 .26702 L .45607 .27356 L 0 0 0 r
F
.45607 .27351 m .45607 .27343 L .45504 .26702 L F
.45607 .27343 m .45606 .27325 L .45588 .27216 L F
.45607 .27343 m .45588 .27216 L .45504 .26702 L F
.45588 .27216 m .45555 .26968 L .45554 .26983 L .333 .064 0 r
F
.45651 .27647 m .45388 .25993 L .4616 .31439 L 0 0 0 r
F
.45588 .27216 m .45554 .26983 L .45501 .27415 L .333 .064 0 r
F
.45504 .26708 m .45504 .26702 L .4548 .26554 L 0 0 0 r
F
.45481 .26575 m .4548 .26554 L .45388 .25993 L F
.45554 .26983 m .45415 .26045 L .45501 .27415 L .333 .064 0 r
F
.45558 .26948 m .45415 .26045 L .45554 .26983 L F
.4537 .36211 m .45275 .35852 L .45252 .3633 L 1 .87 0 r
F
.46989 .3458 m .46211 .35157 L .46218 .35357 L F
.46984 .35211 m .46989 .3458 L .45252 .3633 L 1 .876 0 r
F
.45344 .36688 m .45252 .3633 L .45228 .36792 L F
.46044 .36057 m .45984 .35857 L .45996 .361 L F
.45866 .28075 m .45642 .26518 L .45645 .26572 L 0 0 0 r
F
.46984 .35211 m .46164 .35741 L .46172 .35942 L 1 .876 0 r
F
.4698 .35812 m .46984 .35211 L .45228 .36792 L 1 .882 0 r
F
.4711 .3654 m .45864 .28036 L .45866 .28075 L 0 0 0 r
F
.45864 .28036 m .45642 .26518 L .45866 .28075 L F
.46172 .35942 m .46033 .35825 L .46044 .36057 L 1 .876 0 r
F
.46164 .35741 m .46033 .35825 L .46172 .35942 L F
.46033 .35825 m .45984 .35857 L .46044 .36057 L F
.45763 .30088 m .4561 .29258 L .45611 .29265 L 0 0 0 r
F
.46076 .36539 m .45228 .36792 L .45205 .37239 L 1 .882 0 r
F
.45853 .28897 m .45626 .27454 L .45628 .27481 L 0 0 0 r
F
.4698 .35812 m .46154 .36274 L .46162 .36469 L 1 .882 0 r
F
.46976 .36387 m .4698 .35812 L .45205 .37239 L 1 .888 0 r
F
.47105 .3678 m .45852 .28878 L .45853 .28897 L 0 0 0 r
F
.45852 .28878 m .45626 .27454 L .45853 .28897 L F
.46162 .36469 m .46066 .36324 L .46076 .36539 L 1 .882 0 r
F
.46154 .36274 m .46066 .36324 L .46162 .36469 L F
.46066 .36324 m .45228 .36792 L .46076 .36539 L F
.45783 .30193 m .45763 .30082 L .45763 .30088 L 0 0 0 r
F
.46107 .3701 m .45205 .37239 L .45181 .37674 L 1 .888 0 r
F
.46976 .36387 m .46098 .3681 L .46107 .3701 L F
.46098 .3681 m .45205 .37239 L .46107 .3701 L F
.458 .30287 m .45783 .30187 L .45783 .30193 L 0 0 0 r
F
.46971 .36938 m .46976 .36387 L .45181 .37674 L 1 .893 0 r
F
.47096 .37257 m .458 .30281 L .458 .30287 L 0 0 0 r
F
.458 .30281 m .45783 .30187 L .458 .30287 L F
.45783 .30187 m .45763 .30082 L .45783 .30193 L F
.45763 .30082 m .4561 .29258 L .45763 .30088 L F
.47091 .37496 m .47096 .37257 L .45728 .30691 L F
.45729 .30701 m .45728 .30691 L .45688 .30497 L F
.47091 .37496 m .45728 .30691 L .45729 .30701 L F
.45996 .361 m .4537 .36254 L .45344 .36688 L 1 .876 0 r
F
.45984 .35857 m .4537 .36254 L .45996 .361 L F
.4537 .36254 m .45252 .3633 L .45344 .36688 L F
.45829 .2869 m .45815 .28384 L .45806 .28549 L 0 0 0 r
F
.4711 .3654 m .45838 .2853 L .45829 .2869 L F
.45838 .2853 m .45815 .28384 L .45829 .2869 L F
.47012 .35477 m .45772 .23685 L .45562 .23946 L .996 .305 0 r
F
.45901 .25596 m .45871 .25334 L .45871 .25345 L 0 0 0 r
F
.47115 .36297 m .47091 .22052 L .45772 .23685 L .996 .305 0 r
F
.47115 .36297 m .45772 .23685 L .47012 .35477 L F
.47126 .35845 m .45901 .25585 L .45901 .25596 L 0 0 0 r
F
.45901 .25585 m .45871 .25334 L .45901 .25596 L F
.45542 .34176 m .45464 .33933 L .45464 .33934 L F
.46218 .35357 m .45634 .35645 L .45651 .35928 L 1 .87 0 r
F
.46211 .35157 m .45737 .35509 L .46218 .35357 L F
.45737 .35509 m .45396 .35763 L .45742 .35592 L F
.45737 .35509 m .45742 .35592 L .46218 .35357 L F
.46184 .34604 m .45915 .34832 L .46191 .34821 L 1 .863 0 r
F
.45891 .37628 m .45181 .37674 L .45157 .38097 L 1 .893 0 r
F
.45726 .32094 m .45609 .32186 L .45748 .32429 L 1 .839 0 r
F
.45713 .32183 m .45542 .3142 L .45547 .31482 L 0 0 0 r
F
.46971 .36938 m .45983 .37344 L .45994 .37562 L 1 .893 0 r
F
.45761 .32595 m .4577 .32726 L .46076 .32507 L 1 .842 0 r
F
.45801 .32332 m .45726 .32094 L .45748 .32429 L 1 .839 0 r
F
.46967 .37467 m .46971 .36938 L .45157 .38097 L 1 .897 0 r
F
.46026 .38003 m .45157 .38097 L .45133 .38511 L F
.46967 .37467 m .46015 .37798 L .46026 .38003 L F
.46015 .37798 m .45157 .38097 L .46026 .38003 L F
.45725 .32234 m .45711 .32138 L .45713 .32183 L 0 0 0 r
F
.46963 .37977 m .46967 .37467 L .45133 .38511 L 1 .9 0 r
F
.47081 .37973 m .45723 .3219 L .45725 .32234 L 0 0 0 r
F
.45723 .3219 m .45711 .32138 L .45725 .32234 L F
.45711 .32138 m .45542 .3142 L .45713 .32183 L F
.45994 .37562 m .45878 .37387 L .45891 .37628 L 1 .893 0 r
F
.45983 .37344 m .45878 .37387 L .45994 .37562 L F
.45878 .37387 m .45181 .37674 L .45891 .37628 L F
.45957 .38487 m .45133 .38511 L .45109 .38916 L 1 .9 0 r
F
.46963 .37977 m .45945 .38274 L .45957 .38487 L F
.45945 .38274 m .45133 .38511 L .45957 .38487 L F
.46959 .38469 m .46963 .37977 L .45109 .38916 L 1 .902 0 r
F
.47071 .38453 m .47076 .38212 L .45664 .33278 L 0 0 0 r
F
.45664 .33283 m .45664 .33278 L .45643 .33207 L F
.47071 .38453 m .45664 .33278 L .45664 .33283 L F
.45644 .33219 m .45643 .33207 L .45589 .33019 L F
.47071 .38453 m .45643 .33207 L .45644 .33219 L F
.4559 .33025 m .45589 .33019 L .45562 .32924 L F
.47071 .38453 m .45589 .33019 L .4559 .33025 L F
.4593 .35115 m .45755 .34967 L .45774 .35291 L 1 .863 0 r
F
.45915 .34832 m .45755 .34967 L .4593 .35115 L F
.45662 .34505 m .45556 .34608 L .45665 .3454 L 1 .857 0 r
F
.46936 .38761 m .44887 .39 L .44862 .39418 L 1 .892 0 r
F
.45886 .38953 m .45109 .38916 L .45086 .39314 L 1 .902 0 r
F
.46959 .38469 m .45873 .38732 L .45886 .38953 L F
.45873 .38732 m .45109 .38916 L .45886 .38953 L F
.45613 .344 m .45542 .34175 L .45542 .34176 L 0 0 0 r
F
.46932 .39245 m .46936 .38761 L .44862 .39418 L 1 .89 0 r
F
.46955 .38945 m .46959 .38469 L .45086 .39314 L 1 .904 0 r
F
.47062 .38937 m .45613 .34399 L .45613 .344 L 0 0 0 r
F
.45613 .34399 m .45542 .34175 L .45613 .344 L F
.45542 .34175 m .45464 .33933 L .45542 .34176 L F
.45651 .35928 m .45396 .35763 L .4537 .36211 L 1 .87 0 r
F
.45634 .35645 m .45396 .35763 L .45651 .35928 L F
.45396 .35763 m .45275 .35852 L .4537 .36211 L F
.45806 .28549 m .45427 .25941 L .45588 .27216 L 0 0 0 r
F
.45815 .28384 m .45427 .25941 L .45806 .28549 L F
.45427 .25941 m .45396 .25748 L .45427 .25982 L F
.45397 .25746 m .45396 .25748 L .45558 .26948 L .333 .064 0 r
F
.45427 .25941 m .45427 .25982 L .45588 .27216 L 0 0 0 r
F
.45396 .35721 m .45396 .35716 L .45385 .35729 L 1 .87 0 r
F
.45384 .35771 m .45385 .35729 L .45275 .35852 L F
.45697 .28865 m .45637 .28969 L .457 .28918 L 1 .848 0 r
F
.45637 .28969 m .45639 .28995 L .457 .28918 L F
.4559 .28214 m .45584 .28224 L .45581 .29066 L 1 .859 0 r
F
.45584 .28224 m .45579 .28763 L .45581 .29066 L F
.45424 .27295 m .45424 .27309 L .46622 .34526 L 0 0 0 r
F
.45741 .29538 m .45741 .29534 L .45733 .29551 L 1 .841 0 r
F
.45692 .28933 m .45579 .29133 L .45733 .29551 L 1 .848 0 r
F
.45637 .28969 m .45581 .29066 L .45639 .28995 L F
.45576 .29079 m .45583 .28266 L .45558 .28986 L 0 0 0 r
F
.45579 .29133 m .45581 .29066 L .45576 .29079 L 1 .848 0 r
F
.46622 .34526 m .45596 .28344 L .45576 .29079 L 0 0 0 r
F
.45596 .28344 m .45583 .28266 L .45576 .29079 L F
.45579 .29133 m .45575 .29074 L .45334 .27821 L F
.45558 .29875 m .45334 .27821 L .4531 .28684 L F
.4556 .2983 m .45334 .27821 L .45558 .29875 L F
.45574 .29142 m .45576 .29079 L .45469 .29329 L 1 .848 0 r
F
.45579 .29133 m .45576 .29079 L .45574 .29142 L F
.45584 .28224 m .45575 .2824 L .45579 .28763 L 1 .859 0 r
F
.46416 .33047 m .45584 .28224 L .46622 .34526 L 0 0 0 r
F
.45584 .28224 m .45424 .27295 L .45584 .2826 L F
.45584 .28224 m .45584 .2826 L .46622 .34526 L F
.45424 .27295 m .4536 .26922 L .45424 .27309 L F
.47114 .35437 m .47113 .35128 L .45908 .24374 L F
.47131 .35591 m .47113 .35128 L .47114 .35437 L F
.47131 .35591 m .47136 .35329 L .47113 .35128 L F
.47091 .22052 m .4709 .2205 L .45456 .24076 L .996 .305 0 r
F
.46882 .21866 m .46845 .2124 L .45497 .23107 L 1 1 0 r
F
.46882 .21866 m .45497 .23107 L .46895 .21966 L F
.4591 .24432 m .45908 .24374 L .45717 .22666 L 0 0 0 r
F
.47131 .35591 m .45908 .24374 L .4591 .24432 L F
.4622 .34789 m .46184 .34604 L .46191 .34821 L 1 .863 0 r
F
.46213 .34579 m .46184 .34604 L .4622 .34789 L F
.45871 .25345 m .45803 .24762 L .45803 .24775 L 0 0 0 r
F
.45871 .25334 m .45803 .24762 L .45871 .25345 L F
.45689 .30516 m .45688 .30497 L .45608 .30112 L F
.47091 .37496 m .45688 .30497 L .45689 .30516 L F
.45755 .34967 m .45298 .35354 L .45774 .35291 L 1 .863 0 r
F
.45605 .32445 m .45555 .32248 L .45555 .3225 L 0 0 0 r
F
.47076 .38212 m .45605 .32443 L .45605 .32445 L F
.45605 .32443 m .45555 .32248 L .45605 .32445 L F
.45555 .32248 m .45548 .32221 L .45555 .3225 L F
.45595 .32817 m .4554 .3289 L .45597 .3285 L 1 .842 0 r
F
.45608 .30116 m .45608 .30112 L .45592 .30038 L 0 0 0 r
F
.47091 .37496 m .45608 .30112 L .45608 .30116 L F
.45593 .30043 m .45592 .30038 L .45572 .29943 L F
.47091 .37496 m .45592 .30038 L .45593 .30043 L F
.47081 .37973 m .47086 .37734 L .45612 .31706 L F
.45612 .31713 m .45612 .31706 L .45581 .3158 L F
.47081 .37973 m .45612 .31706 L .45612 .31713 L F
.47081 .37973 m .45613 .31718 L .45613 .31719 L F
.45613 .31718 m .45581 .31585 L .45613 .31719 L F
.45771 .34401 m .45662 .34505 L .45774 .34443 L 1 .857 0 r
F
.45562 .32927 m .45562 .32924 L .45551 .32884 L 0 0 0 r
F
.47071 .38453 m .45562 .32924 L .45562 .32927 L F
.47081 .37973 m .45613 .31719 L .45613 .31719 L F
.45613 .31719 m .45569 .31533 L .45613 .31719 L F
.45464 .33933 m .45255 .33277 L .45464 .33934 L F
.47141 .35054 m .45949 .22132 L .45949 .22137 L F
.45949 .22132 m .45908 .21693 L .45949 .22137 L F
.45556 .34608 m .45321 .34834 L .45582 .34998 L 1 .857 0 r
F
.45523 .34119 m .45265 .33309 L .45265 .3331 L 0 0 0 r
F
.47062 .38937 m .45523 .34118 L .45523 .34119 L F
.45523 .34118 m .45265 .33309 L .45523 .34119 L F
.45265 .33309 m .45182 .33049 L .45265 .3331 L F
.45255 .33277 m .45244 .33244 L .45255 .33278 L F
.45244 .33244 m .45194 .33085 L .45245 .33246 L F
.47062 .38937 m .45491 .34014 L .45491 .34015 L F
.45491 .34014 m .45202 .33111 L .45491 .34015 L F
.45908 .21693 m .45818 .20718 L .45909 .21699 L F
.46204 .33604 m .46197 .33363 L .46202 .33607 L 1 .851 0 r
F
.46198 .33362 m .46197 .33363 L .46204 .33604 L F
.46197 .33363 m .46126 .3344 L .46202 .33607 L F
.47146 .3476 m .47152 .34441 L .45942 .2051 L 0 0 0 r
F
.4704 .19448 m .47036 .1944 L .47036 .19442 L .404 .176 0 r
F
.47033 .19403 m .45652 .20258 L .4704 .19448 L 1 1 0 r
F
.47033 .19403 m .46988 .18766 L .45652 .20258 L F
.45943 .20529 m .45942 .2051 L .45897 .19985 L 0 0 0 r
F
.47146 .3476 m .45942 .2051 L .45943 .20529 L F
.45803 .24775 m .45652 .23505 L .45653 .2352 L F
.45803 .24762 m .45652 .23505 L .45803 .24775 L F
.46126 .3344 m .46085 .33484 L .46135 .33699 L 1 .851 0 r
F
.47034 .357 m .45562 .23946 L .45474 .24055 L .996 .305 0 r
F
.46753 .33628 m .45474 .24055 L .45456 .24076 L F
.47034 .357 m .45474 .24055 L .46753 .33628 L F
.45766 .25706 m .45646 .24773 L .45646 .24788 L 0 0 0 r
F
.47115 .36297 m .45562 .23946 L .47034 .357 L .996 .305 0 r
F
.47121 .36093 m .45765 .25691 L .45766 .25706 L 0 0 0 r
F
.45765 .25691 m .45646 .24773 L .45766 .25706 L F
.45569 .31533 m .45555 .31472 L .45569 .31533 L F
.45551 .32886 m .45551 .32884 L .45542 .32853 L F
.47071 .38453 m .45551 .32884 L .45551 .32886 L F
.47071 .38453 m .45551 .32893 L .45554 .32939 L F
.45551 .32893 m .45542 .32859 L .45554 .32939 L F
.45542 .32859 m .45513 .32753 L .45545 .32906 L F
.45542 .32859 m .45542 .32853 L .45513 .32753 L F
.47071 .38453 m .45542 .32853 L .45542 .32859 L F
.47071 .38453 m .45545 .32906 L .45546 .32909 L F
.45545 .32906 m .45519 .32809 L .45546 .32909 L F
.45529 .33511 m .4553 .33535 L .45586 .33494 L 1 .846 0 r
F
.45529 .33511 m .45586 .33494 L .45585 .33478 L F
.45581 .31586 m .4556 .31493 L .4556 .31494 L 0 0 0 r
F
.45581 .31585 m .4556 .31493 L .45581 .31586 L F
.47086 .37734 m .45604 .30915 L .45604 .30918 L F
.45604 .30915 m .45556 .30695 L .45604 .30918 L F
.47086 .37734 m .47091 .37496 L .45603 .30904 L F
.45604 .30915 m .45603 .30904 L .45556 .30695 L F
.47086 .37734 m .45603 .30904 L .45604 .30915 L F
.45581 .31585 m .45581 .3158 L .4556 .31493 L F
.47081 .37973 m .45581 .3158 L .45581 .31585 L F
.45529 .33511 m .45476 .33575 L .4553 .33535 L 1 .846 0 r
F
.45535 .33532 m .45526 .33472 L .45529 .33511 L 0 0 0 r
F
.45526 .33472 m .45522 .33443 L .45529 .33511 L F
.45586 .33494 m .4553 .33535 L .45612 .33873 L 1 .846 0 r
F
.45529 .33511 m .45526 .33502 L .45511 .3398 L 0 0 0 r
F
.4553 .33535 m .45476 .33575 L .45544 .33723 L 1 .846 0 r
F
.4553 .33535 m .45544 .33723 L .45612 .33873 L F
.47067 .38694 m .47071 .38453 L .45525 .33453 L 0 0 0 r
F
.45525 .33453 m .45525 .33453 L .45522 .33443 L F
.47067 .38694 m .45525 .33453 L .45525 .33453 L F
.47067 .38694 m .45531 .33475 L .45535 .33532 L F
.45531 .33475 m .45522 .33443 L .45535 .33532 L F
.45597 .34449 m .45517 .34099 L .45546 .3452 L 1 .851 0 r
F
.47096 .37257 m .471 .37019 L .45672 .29583 L 0 0 0 r
F
.45673 .29598 m .45672 .29583 L .4561 .29258 L F
.47096 .37257 m .45672 .29583 L .45673 .29598 L F
.4554 .34166 m .45532 .341 L .45513 .34041 L F
.45516 .34094 m .45513 .34041 L .45212 .3314 L F
.4554 .34166 m .45513 .34041 L .45516 .34094 L F
.4544 .34571 m .45305 .34654 L .45443 .34613 L 1 .891 0 r
F
.45496 .34397 m .45265 .34131 L .45298 .3459 L F
.45086 .35302 m .4511 .34773 L .44797 .3416 L .126 .018 0 r
F
.45086 .35302 m .44797 .3416 L .44748 .34593 L F
.45037 .36305 m .40677 .27839 L .40676 .27842 L .113 .016 0 r
F
.44734 .35775 m .40676 .27842 L .4054 .28445 L F
.45037 .36305 m .4474 .35728 L .44734 .35775 L F
.4474 .35728 m .40676 .27842 L .44734 .35775 L F
.44793 .35324 m .40815 .27242 L .40677 .27839 L .119 .017 0 r
F
.45062 .35812 m .44798 .3528 L .44793 .35324 L F
.44798 .3528 m .40815 .27242 L .44793 .35324 L F
.45164 .32457 m .45128 .32505 L .45163 .3247 L 1 .819 0 r
F
.45128 .32505 m .43994 .34015 L .45127 .32517 L F
.45128 .32505 m .45127 .32517 L .45163 .3247 L F
.45123 .32535 m .43994 .34015 L .43933 .3446 L F
.45163 .3247 m .45124 .32521 L .45123 .32535 L F
.45124 .32521 m .43994 .34015 L .45123 .32535 L F
.4054 .28446 m .40538 .28446 L .40404 .2905 L 1 .95 0 r
F
.45012 .36783 m .40539 .28443 L .40538 .28446 L .107 .016 0 r
F
.40539 .28443 m .40539 .28443 L .40538 .28446 L F
.40538 .28446 m .40523 .28442 L .40459 .28771 L 1 .95 0 r
F
.40538 .28446 m .40459 .28771 L .40404 .2905 L F
.44717 .36287 m .40538 .28446 L .40404 .2905 L .107 .016 0 r
F
.45012 .36783 m .44722 .36243 L .44717 .36287 L F
.44722 .36243 m .40538 .28446 L .44717 .36287 L F
.45114 .33134 m .43933 .3446 L .43871 .34889 L 1 .854 0 r
F
.45143 .33092 m .45115 .33124 L .45114 .33134 L F
.45115 .33124 m .43933 .3446 L .45114 .33134 L F
.44282 .35716 m .45179 .33042 L .43871 .34889 L 1 .172 0 r
F
.45546 .3452 m .45376 .34326 L .45321 .34834 L 1 .851 0 r
F
.45376 .34326 m .45339 .34372 L .45321 .34834 L F
.45305 .34654 m .4511 .34773 L .45308 .34702 L 1 .891 0 r
F
.45265 .34131 m .45133 .34221 L .45298 .3459 L F
.45062 .35812 m .45086 .35302 L .44773 .34712 L .119 .017 0 r
F
.45062 .35812 m .44773 .34712 L .44723 .35129 L F
.45037 .36305 m .45062 .35812 L .44753 .3525 L .113 .016 0 r
F
.45037 .36305 m .44753 .3525 L .44702 .35655 L F
.45012 .36783 m .45037 .36305 L .44734 .35775 L .107 .016 0 r
F
.45012 .36783 m .44734 .35775 L .44683 .36169 L F
.44987 .37248 m .45012 .36783 L .44717 .36287 L .103 .015 0 r
F
.44987 .37248 m .44717 .36287 L .44665 .36672 L F
.44286 .35723 m .45339 .34372 L .44282 .35716 L 1 .172 0 r
F
.45469 .33991 m .45265 .34131 L .45496 .34397 L 1 .891 0 r
F
.45223 .33594 m .45187 .33622 L .45224 .33614 L 1 .892 0 r
F
.45391 .33946 m .45187 .33622 L .45163 .3419 L F
.45163 .3419 m .4517 .33635 L .45145 .34209 L F
.45187 .33622 m .4517 .33635 L .45163 .3419 L F
.4517 .33635 m .45157 .33645 L .45145 .34209 L F
.45133 .34221 m .45104 .33536 L .45035 .33999 L .145 .021 0 r
F
.45339 .34372 m .45179 .33042 L .44282 .35716 L 1 .172 0 r
F
.44987 .37248 m .40404 .2905 L .40403 .29053 L .103 .015 0 r
F
.44987 .37248 m .40403 .29053 L .40272 .29663 L F
.47062 .38937 m .45517 .34099 L .45889 .3895 L 0 0 0 r
F
.45517 .34099 m .45179 .33042 L .45339 .34372 L F
.45376 .34326 m .45372 .34322 L .45339 .34372 L 1 .851 0 r
F
.45517 .34099 m .45342 .34288 L .45546 .3452 L F
.45517 .34099 m .45339 .34372 L .45889 .3895 L 0 0 0 r
F
.45372 .34322 m .45342 .34288 L .45339 .34372 L 1 .851 0 r
F
.44225 .36035 m .43871 .34889 L .4381 .35307 L 1 .172 0 r
F
.44233 .35991 m .43871 .34889 L .44225 .36035 L F
.44286 .35723 m .43871 .34889 L .44239 .36009 L F
.45321 .34834 m .44286 .35723 L .44232 .36048 L 1 .912 0 r
F
.45298 .35354 m .45321 .34834 L .44232 .36048 L 1 .94 0 r
F
.44962 .377 m .4027 .29664 L .4014 .30275 L .1 .015 0 r
F
.46932 .39245 m .44862 .39418 L .44837 .39829 L 1 .89 0 r
F
.46955 .38945 m .45086 .39314 L .45063 .39705 L 1 .904 0 r
F
.46928 .39717 m .46932 .39245 L .44837 .39829 L 1 .887 0 r
F
.46951 .39408 m .46955 .38945 L .45063 .39705 L 1 .904 0 r
F
.46928 .39717 m .44837 .39829 L .44813 .40234 L 1 .887 0 r
F
.46951 .39408 m .45063 .39705 L .4504 .40091 L 1 .904 0 r
F
.44887 .39 m .44912 .38576 L .43209 .39109 L 1 1 0 r
F
.44862 .39418 m .44887 .39 L .43153 .39469 L F
.44887 .39 m .43209 .39109 L .43153 .39469 L F
.4382 .39315 m .43325 .38382 L .43267 .38747 L .196 .046 0 r
F
.4382 .3931 m .43325 .38382 L .4382 .39315 L F
.43843 .39011 m .43325 .38382 L .43827 .39323 L F
.4386 .38965 m .43384 .38015 L .43325 .38382 L .183 .044 0 r
F
.43861 .3896 m .43384 .38015 L .4386 .38965 L F
.43912 .38691 m .43384 .38015 L .43867 .38973 L F
.43901 .38612 m .43444 .37644 L .43384 .38015 L .169 .041 0 r
F
.43902 .38607 m .43444 .37644 L .43901 .38612 L F
.43955 .38335 m .43444 .37644 L .43909 .38621 L F
.43944 .38257 m .43504 .37269 L .43444 .37644 L .155 .039 0 r
F
.43945 .38251 m .43504 .37269 L .43944 .38257 L F
.43999 .37977 m .43504 .37269 L .43952 .38266 L F
.44013 .3838 m .43984 .38329 L .43981 .38388 L 1 1 0 r
F
.44082 .38363 m .4405 .38316 L .44047 .38371 L F
.45157 .38097 m .44122 .38302 L .44119 .38354 L F
.45157 .38097 m .43951 .38395 L .43938 .38609 L F
.45205 .37239 m .44178 .37572 L .44175 .37621 L F
.45205 .37239 m .44041 .37671 L .44026 .37892 L F
.45181 .37674 m .44005 .37975 L .43958 .38263 L F
.45252 .3633 m .44138 .36877 L .44088 .37181 L 1 .981 0 r
F
.45252 .3633 m .45275 .35852 L .44141 .36804 L F
.45252 .3633 m .44141 .36804 L .44138 .36877 L F
.44166 .36783 m .44187 .365 L .44135 .36809 L 1 .963 0 r
F
.45275 .35852 m .44187 .365 L .44166 .36783 L F
.45275 .35852 m .44189 .36427 L .44187 .365 L F
.44212 .36545 m .44215 .36485 L .44191 .36445 L .093 .027 0 r
F
.44187 .365 m .44189 .36427 L .44183 .36432 L 1 .963 0 r
F
.44179 .36486 m .44183 .36432 L .43748 .35715 L .093 .027 0 r
F
.44187 .365 m .44183 .36432 L .44179 .36486 L F
.45275 .35852 m .45298 .35354 L .44189 .36427 L 1 .963 0 r
F
.44215 .36402 m .44236 .36116 L .44183 .36432 L 1 .94 0 r
F
.45298 .35354 m .44236 .36116 L .44215 .36402 L F
.45298 .35354 m .44238 .36044 L .44236 .36116 L F
.44262 .36165 m .44266 .36106 L .4424 .36061 L .077 .023 0 r
F
.44238 .36044 m .44232 .36048 L .44236 .36116 L 1 .94 0 r
F
.44286 .35723 m .44255 .3575 L .44232 .36048 L 1 .912 0 r
F
.44228 .36101 m .44232 .36048 L .4381 .35307 L .077 .023 0 r
F
.44232 .36048 m .44233 .35991 L .44225 .36035 L 1 .172 0 r
F
.44234 .35995 m .44233 .35991 L .44232 .36048 L F
.44255 .3575 m .44115 .3587 L .44232 .36048 L 1 .912 0 r
F
.44236 .36116 m .4424 .36061 L .44232 .36048 L .077 .023 0 r
F
.44236 .36116 m .44232 .36048 L .44228 .36101 L F
.44262 .36165 m .4424 .36061 L .44236 .36116 L F
.44236 .36116 m .4381 .35307 L .44226 .36502 L F
.44236 .36116 m .44206 .36137 L .44183 .36432 L 1 .94 0 r
F
.44183 .36432 m .4381 .35307 L .43748 .35715 L .077 .023 0 r
F
.44189 .36397 m .4381 .35307 L .44183 .36432 L F
.44206 .36137 m .44055 .36245 L .44183 .36432 L 1 .94 0 r
F
.44159 .36912 m .44162 .36851 L .44135 .36809 L .109 .03 0 r
F
.44187 .365 m .43748 .35715 L .44175 .36872 L .093 .027 0 r
F
.44187 .365 m .44157 .36518 L .44135 .36809 L 1 .963 0 r
F
.44131 .36865 m .44135 .36809 L .43687 .36113 L .109 .03 0 r
F
.44135 .36809 m .43748 .35715 L .43687 .36113 L .093 .027 0 r
F
.44141 .36777 m .43748 .35715 L .44135 .36809 L F
.44157 .36518 m .43996 .36614 L .44135 .36809 L 1 .963 0 r
F
.44138 .36877 m .44135 .36809 L .44131 .36865 L .109 .03 0 r
F
.44138 .36877 m .44141 .36804 L .44135 .36809 L 1 .981 0 r
F
.44159 .36912 m .44135 .36809 L .44138 .36877 L .109 .03 0 r
F
.44084 .37237 m .44088 .37181 L .43625 .36505 L .125 .033 0 r
F
.45228 .36792 m .45252 .3633 L .44088 .37181 L 1 .995 0 r
F
.44091 .37248 m .44088 .37181 L .44084 .37237 L .125 .033 0 r
F
.44037 .37604 m .44041 .37547 L .43564 .3689 L .14 .036 0 r
F
.44044 .37615 m .44041 .37547 L .44037 .37604 L F
.43992 .37967 m .43996 .37908 L .43504 .37269 L .155 .039 0 r
F
.45181 .37674 m .45205 .37239 L .43996 .37908 L 1 1 0 r
F
.43999 .37977 m .43996 .37908 L .43992 .37967 L .155 .039 0 r
F
.4394 .38316 m .43944 .38257 L .43444 .37644 L .169 .041 0 r
F
.43999 .37977 m .43996 .37908 L .43763 .38037 L 1 1 0 r
F
.45181 .37674 m .43996 .37908 L .43999 .37977 L F
.44005 .37985 m .43996 .37908 L .43999 .37977 L .155 .039 0 r
F
.44005 .37985 m .44008 .37924 L .43996 .37908 L F
.43996 .37908 m .43564 .3689 L .43504 .37269 L .14 .036 0 r
F
.44002 .37905 m .43997 .37899 L .43996 .37908 L 1 1 0 r
F
.44175 .37621 m .4405 .37613 L .44041 .37671 L F
.44026 .37892 m .44041 .37671 L .44002 .37905 L F
.44044 .37615 m .43564 .3689 L .43996 .37908 L .14 .036 0 r
F
.4405 .37613 m .4382 .37687 L .44002 .37905 L 1 1 0 r
F
.45133 .38511 m .43918 .3869 L .43908 .38753 L F
.43896 .38963 m .43908 .38753 L .43874 .38971 L F
.45133 .38511 m .43908 .38753 L .43896 .38963 L F
.45086 .39314 m .45109 .38916 L .43855 .39314 L F
.43856 .39322 m .43855 .39314 L .43827 .39323 L F
.45086 .39314 m .43855 .39314 L .43856 .39322 L F
.43823 .39387 m .43827 .39323 L .43267 .38747 L .208 .049 0 r
F
.4383 .39394 m .43827 .39323 L .43823 .39387 L F
.46924 .40178 m .44813 .40234 L .44788 .40634 L 1 .883 0 r
F
.4692 .40628 m .46924 .40178 L .44788 .40634 L 1 .879 0 r
F
.4692 .40628 m .44788 .40634 L .44764 .41029 L F
.46916 .4107 m .4692 .40628 L .44764 .41029 L 1 .874 0 r
F
.46916 .4107 m .44764 .41029 L .4474 .41421 L F
.46912 .41504 m .46916 .4107 L .4474 .41421 L 1 .869 0 r
F
.49401 .40042 m .46924 .40178 L .4692 .40628 L 1 .762 0 r
F
.46943 .40296 m .45017 .4047 L .44995 .40846 L 1 .902 0 r
F
.49403 .40543 m .49401 .40042 L .4692 .40628 L 1 .758 0 r
F
.49403 .40543 m .4692 .40628 L .46916 .4107 L F
.46939 .40725 m .46943 .40296 L .44995 .40846 L 1 .9 0 r
F
.46939 .40725 m .44995 .40846 L .44973 .41216 L F
.49405 .41031 m .49403 .40543 L .46916 .4107 L 1 .754 0 r
F
.49405 .41031 m .46916 .4107 L .46912 .41504 L F
.46935 .41144 m .46939 .40725 L .44973 .41216 L 1 .898 0 r
F
.46912 .41504 m .4474 .41421 L .44717 .41808 L 1 .869 0 r
F
.46935 .41144 m .44973 .41216 L .44952 .41583 L 1 .898 0 r
F
.4474 .41421 m .44764 .41029 L .42882 .41244 L 1 .98 0 r
F
.44764 .41029 m .42934 .40892 L .42882 .41244 L 1 .988 0 r
F
.44764 .41029 m .44788 .40634 L .42934 .40892 L F
.44788 .40634 m .42987 .40538 L .42934 .40892 L 1 .995 0 r
F
.44788 .40634 m .44813 .40234 L .42987 .40538 L F
.44813 .40234 m .43042 .40183 L .42987 .40538 L 1 1 0 r
F
.44813 .40234 m .44837 .39829 L .43042 .40183 L F
.44837 .39829 m .43097 .39827 L .43042 .40183 L F
.44837 .39829 m .44862 .39418 L .43097 .39827 L F
.44862 .39418 m .43153 .39469 L .43097 .39827 L F
.44717 .41808 m .4474 .41421 L .4283 .41596 L 1 .972 0 r
F
.4474 .41421 m .42882 .41244 L .4283 .41596 L 1 .98 0 r
F
.44952 .41583 m .44973 .41216 L .4325 .41428 L 1 .971 0 r
F
.44973 .41216 m .43296 .41095 L .4325 .41428 L 1 .979 0 r
F
.44973 .41216 m .44995 .40846 L .43296 .41095 L F
.44995 .40846 m .43343 .40761 L .43296 .41095 L 1 .987 0 r
F
.44995 .40846 m .45017 .4047 L .43343 .40761 L F
.43798 .40682 m .43391 .40426 L .43343 .40761 L 1 .994 0 r
F
.45017 .4047 m .43805 .40437 L .43798 .40682 L F
.43805 .40437 m .43391 .40426 L .43798 .40682 L F
.45086 .39314 m .44001 .39331 L .4383 .39394 L 1 1 0 r
F
.44001 .39331 m .43791 .39334 L .4383 .39394 L F
.46924 .40178 m .46928 .39717 L .44813 .40234 L 1 .883 0 r
F
.45017 .4047 m .4504 .40091 L .43391 .40426 L 1 .994 0 r
F
.43801 .40342 m .43441 .40089 L .43391 .40426 L 1 1 0 r
F
.4504 .40091 m .43811 .4009 L .43801 .40342 L F
.43811 .4009 m .43441 .40089 L .43801 .40342 L F
.4504 .40091 m .45063 .39705 L .43441 .40089 L F
.43808 .40003 m .43492 .39752 L .43441 .40089 L F
.45063 .39705 m .43819 .39742 L .43808 .40003 L F
.43819 .39742 m .43492 .39752 L .43808 .40003 L F
.4383 .39394 m .43267 .38747 L .43532 .39493 L .208 .049 0 r
F
.43816 .39663 m .43616 .39478 L .43492 .39752 L 1 1 0 r
F
.43616 .39478 m .43605 .39468 L .436 .39481 L F
.43616 .39478 m .436 .39481 L .43492 .39752 L F
.39887 .31512 m .39962 .3114 L .39867 .31511 L 1 .929 0 r
F
.36754 .30469 m .39993 .30893 L .36753 .30469 L .867 .059 0 r
F
.39867 .31511 m .39993 .30893 L .36754 .30469 L 1 .973 0 r
F
.43209 .39109 m .39993 .30893 L .36754 .30469 L .867 .059 0 r
F
.39993 .30893 m .39966 .30825 L .36753 .30469 L F
.3675 .30464 m .36679 .30369 L .36577 .31041 L F
.3675 .30464 m .36577 .31041 L .36661 .30768 L F
.3675 .30464 m .36572 .31076 L .36572 .31074 L F
.36572 .31076 m .36573 .31069 L .36572 .31076 L 1 .973 0 r
F
.36574 .31078 m .3675 .30464 L .36572 .31076 L .867 .059 0 r
F
.43209 .39109 m .36754 .30469 L .36574 .31078 L F
.36754 .30469 m .36573 .31069 L .36572 .31076 L 1 .973 0 r
F
.36754 .30469 m .3675 .30464 L .36574 .31078 L .867 .059 0 r
F
.36754 .30469 m .39993 .30891 L .36755 .30465 L 1 .973 0 r
F
.36754 .30469 m .36755 .30465 L .36734 .30463 L F
.39993 .30893 m .39993 .30893 L .39992 .30893 L .867 .059 0 r
F
.39993 .30893 m .39992 .30893 L .36753 .30469 L F
.39993 .30893 m .39993 .30891 L .36754 .30469 L 1 .973 0 r
F
.43153 .39469 m .43209 .39109 L .36572 .31076 L .201 .035 0 r
F
.36572 .3108 m .3655 .31073 L .36392 .31689 L 1 .967 0 r
F
.43153 .39469 m .36572 .31076 L .36571 .3108 L .201 .035 0 r
F
.36466 .31522 m .36565 .31102 L .36443 .31518 L 1 .967 0 r
F
.36393 .31689 m .36443 .31518 L .36392 .31689 L F
.43153 .39469 m .36571 .3108 L .36392 .31689 L .201 .035 0 r
F
.43097 .39827 m .36387 .31688 L .36216 .32306 L .204 .036 0 r
F
.36043 .3293 m .36038 .3292 L .36037 .32924 L .21 .037 0 r
F
.42987 .40538 m .36043 .32926 L .36043 .3293 L F
.36043 .32926 m .36038 .3292 L .36043 .3293 L F
.36043 .3293 m .36037 .32924 L .35911 .33415 L F
.36038 .32953 m .36037 .32952 L .35875 .33549 L 1 .952 0 r
F
.36037 .32952 m .35876 .33543 L .35875 .33549 L F
.36043 .3293 m .35911 .33415 L .35876 .3355 L .21 .037 0 r
F
.36037 .32924 m .35877 .33538 L .35876 .3355 L F
.36037 .32952 m .3602 .32923 L .35876 .33543 L 1 .952 0 r
F
.36044 .32931 m .36043 .3293 L .36038 .32953 L F
.36043 .3293 m .3602 .32923 L .36038 .32953 L F
.35907 .33559 m .35908 .33553 L .35875 .33549 L 1 .946 0 r
F
.42987 .40538 m .36043 .3293 L .35876 .3355 L .21 .037 0 r
F
.42882 .41244 m .42934 .40892 L .35709 .34174 L .216 .038 0 r
F
.35874 .33553 m .3587 .33545 L .35869 .33549 L .213 .037 0 r
F
.42934 .40892 m .35874 .33549 L .35874 .33553 L F
.35874 .33549 m .3587 .33545 L .35874 .33553 L F
.35874 .33553 m .35873 .33553 L .35711 .34165 L F
.35873 .33553 m .35779 .33455 L .35714 .34135 L F
.35873 .33553 m .35714 .34135 L .35711 .34165 L F
.35869 .33577 m .35849 .33545 L .35709 .34174 L 1 .946 0 r
F
.35875 .33554 m .35874 .33553 L .35869 .33577 L F
.35874 .33553 m .35849 .33545 L .35869 .33577 L F
.42934 .40892 m .35874 .33553 L .3571 .34176 L .213 .037 0 r
F
.42287 .40181 m .41735 .39383 L .41644 .39699 L .38 .111 0 r
F
.44717 .41808 m .4283 .41596 L .4278 .41947 L 1 .972 0 r
F
.44952 .41583 m .4325 .41428 L .43205 .41761 L 1 .971 0 r
F
.35709 .34179 m .35708 .34179 L .35547 .34803 L 1 .941 0 r
F
.35708 .34179 m .35549 .34797 L .35547 .34803 L F
.42882 .41244 m .35708 .34179 L .35547 .34803 L .216 .038 0 r
F
.42882 .41244 m .35709 .34175 L .35708 .34179 L F
.42882 .41244 m .35709 .34174 L .35709 .34175 L F
.35422 .35438 m .35475 .35091 L .35464 .35134 L 1 .936 0 r
F
.35531 .34794 m .35442 .3471 L .35384 .35429 L .218 .038 0 r
F
.35422 .35438 m .355 .34878 L .35389 .35434 L 1 .936 0 r
F
.35546 .34808 m .3552 .34799 L .35422 .35438 L F
.4283 .41596 m .35546 .34808 L .35389 .35434 L .218 .038 0 r
F
.4283 .41596 m .42882 .41244 L .35547 .34803 L F
.4283 .41596 m .35547 .34803 L .35547 .34803 L F
.4278 .41947 m .4283 .41596 L .35389 .35434 L .221 .039 0 r
F
.43296 .41095 m .43343 .40761 L .42233 .40807 L 1 1 0 r
F
.42354 .39871 m .41827 .39069 L .41735 .39383 L .918 .067 0 r
F
.42355 .39866 m .41827 .39069 L .42354 .39871 L F
.42425 .39639 m .41827 .39069 L .42363 .39878 L F
.42425 .39639 m .43267 .38747 L .41827 .39069 L F
.42436 .39568 m .42231 .39308 L .42147 .39609 L 1 1 0 r
F
.43492 .39752 m .43532 .39493 L .42425 .39639 L F
.42507 .39629 m .42509 .39628 L .42425 .39639 L .918 .067 0 r
F
.42509 .39628 m .43267 .38747 L .42425 .39639 L F
.43492 .39752 m .42431 .39639 L .42368 .39877 L 1 1 0 r
F
.43532 .39493 m .43267 .38747 L .42466 .39677 L .918 .067 0 r
F
.42425 .39639 m .43544 .39412 L .42147 .39609 L 1 1 0 r
F
.43532 .39493 m .43544 .39412 L .42425 .39639 L F
.43544 .39412 m .42502 .3933 L .42436 .39568 L F
.42502 .3933 m .42231 .39308 L .42436 .39568 L F
.42363 .39878 m .42355 .39866 L .42354 .39871 L .918 .067 0 r
F
.42368 .39877 m .42425 .39639 L .42377 .39825 L 1 1 0 r
F
.42431 .39639 m .42425 .39639 L .42368 .39877 L F
.43343 .40761 m .43391 .40426 L .42272 .40496 L F
.42266 .4058 m .42272 .40496 L .42233 .40498 L F
.43343 .40761 m .42272 .40496 L .42266 .4058 L F
.43296 .41095 m .42233 .40807 L .42232 .40814 L F
.43296 .41095 m .4221 .40808 L .4221 .40814 L F
.43296 .41095 m .4219 .40809 L .4219 .40813 L F
.43296 .41095 m .42178 .4081 L .42167 .40887 L F
.44694 .42192 m .44717 .41808 L .4278 .41947 L 1 .964 0 r
F
.46908 .41931 m .44717 .41808 L .44694 .42192 L 1 .863 0 r
F
.46904 .4235 m .46908 .41931 L .44694 .42192 L 1 .857 0 r
F
.46904 .4235 m .44694 .42192 L .44671 .42573 L F
.44671 .42573 m .44694 .42192 L .4273 .42297 L 1 .956 0 r
F
.44694 .42192 m .4278 .41947 L .4273 .42297 L 1 .964 0 r
F
.4491 .42306 m .44931 .41946 L .43162 .42092 L 1 .954 0 r
F
.44931 .41946 m .43205 .41761 L .43162 .42092 L 1 .962 0 r
F
.46908 .41931 m .46912 .41504 L .44717 .41808 L 1 .863 0 r
F
.44931 .41946 m .44952 .41583 L .43205 .41761 L 1 .962 0 r
F
.4325 .41428 m .43296 .41095 L .42132 .41122 L 1 1 0 r
F
.4325 .41428 m .42132 .41122 L .42131 .41127 L F
.4325 .41428 m .42119 .41124 L .42109 .41201 L F
.42119 .41124 m .42114 .41123 L .42109 .41201 L F
.44671 .42573 m .4273 .42297 L .42682 .42647 L 1 .956 0 r
F
.469 .42764 m .44671 .42573 L .44649 .4295 L 1 .851 0 r
F
.44649 .4295 m .42682 .42647 L .42635 .42996 L 1 .947 0 r
F
.44649 .4295 m .44671 .42573 L .42682 .42647 L F
.4489 .42662 m .43119 .42422 L .43079 .42751 L 1 .945 0 r
F
.469 .42764 m .46904 .4235 L .44671 .42573 L 1 .851 0 r
F
.4489 .42662 m .4491 .42306 L .43119 .42422 L 1 .945 0 r
F
.4491 .42306 m .43162 .42092 L .43119 .42422 L 1 .954 0 r
F
.4278 .41947 m .35389 .35434 L .35389 .35434 L .221 .039 0 r
F
.4273 .42297 m .4278 .41947 L .41054 .41938 L 1 1 0 r
F
.43162 .42092 m .43205 .41761 L .42042 .4175 L F
.41947 .4206 m .41215 .41293 L .41134 .41615 L .446 .164 0 r
F
.42037 .41841 m .42042 .4175 L .42012 .4175 L 1 1 0 r
F
.41995 .41829 m .41215 .41293 L .41947 .4206 L .446 .164 0 r
F
.41997 .41745 m .41298 .40972 L .41215 .41293 L .435 .157 0 r
F
.41998 .41741 m .41298 .40972 L .41997 .41745 L F
.42036 .41504 m .41298 .40972 L .42006 .4175 L F
.4205 .4143 m .41382 .40652 L .41298 .40972 L .424 .149 0 r
F
.4205 .41426 m .41382 .40652 L .4205 .4143 L F
.4206 .41429 m .41382 .40652 L .42059 .41436 L F
.4212 .41133 m .4212 .41127 L .42114 .41123 L F
.42113 .41128 m .42114 .41123 L .42074 .41097 L F
.4212 .41133 m .42114 .41123 L .42113 .41128 L F
.4207 .41172 m .42074 .41097 L .41382 .40652 L F
.42109 .41201 m .42074 .41097 L .4207 .41172 L F
.4325 .41428 m .42115 .41203 L .42097 .41284 L 1 1 0 r
F
.4325 .41428 m .42097 .41284 L .42076 .41436 L F
.42115 .41203 m .42109 .41201 L .42064 .41436 L F
.42109 .41201 m .41382 .40652 L .4206 .41429 L .424 .149 0 r
F
.42109 .41201 m .41755 .41131 L .4206 .41431 L 1 1 0 r
F
.42109 .41201 m .4206 .41431 L .42064 .41436 L F
.42076 .41436 m .42097 .41284 L .42064 .41436 L F
.43205 .41761 m .4325 .41428 L .42064 .41436 L F
.42016 .41728 m .42011 .41724 L .42012 .4175 L F
.42011 .41724 m .42007 .41746 L .42012 .4175 L F
.42028 .4164 m .42036 .41504 L .42006 .4175 L .435 .157 0 r
F
.42071 .41521 m .42053 .41517 L .42042 .4175 L 1 1 0 r
F
.42053 .41517 m .42036 .41504 L .42028 .4164 L .435 .157 0 r
F
.42053 .41517 m .41682 .41438 L .42011 .41724 L 1 1 0 r
F
.42053 .41517 m .42011 .41724 L .42042 .4175 L F
.42042 .4175 m .42016 .41728 L .42012 .4175 L F
.42053 .41517 m .42028 .4164 L .42022 .41759 L .435 .157 0 r
F
.42022 .41759 m .42028 .4164 L .42006 .4175 L F
.42011 .41724 m .41682 .41438 L .42007 .41746 L 1 1 0 r
F
.43205 .41761 m .42064 .41436 L .42053 .41517 L F
.43205 .41761 m .42071 .41521 L .42042 .4175 L F
.43162 .42092 m .42042 .4175 L .42037 .41841 L F
.46896 .43172 m .469 .42764 L .44649 .4295 L 1 .844 0 r
F
.46896 .43172 m .44649 .4295 L .44627 .43326 L F
.44627 .43326 m .44649 .4295 L .42635 .42996 L 1 .939 0 r
F
.44871 .43015 m .4489 .42662 L .43079 .42751 L 1 .937 0 r
F
.42682 .42647 m .4273 .42297 L .40976 .42262 L 1 1 0 r
F
.4273 .42297 m .41054 .41938 L .40976 .42262 L F
.43119 .42422 m .43162 .42092 L .41972 .42065 L F
.43119 .42422 m .41972 .42065 L .41972 .4207 L F
.43119 .42422 m .4223 .42149 L .41951 .4215 L F
.4223 .42149 m .41956 .42065 L .41951 .4215 L F
.44606 .43698 m .44627 .43326 L .42589 .43344 L 1 .93 0 r
F
.44627 .43326 m .42635 .42996 L .42589 .43344 L 1 .939 0 r
F
.44871 .43015 m .43079 .42751 L .43039 .4308 L 1 .937 0 r
F
.46892 .43574 m .46896 .43172 L .44627 .43326 L 1 .838 0 r
F
.46892 .43574 m .44627 .43326 L .44606 .43698 L F
.44852 .43366 m .44871 .43015 L .43039 .4308 L 1 .928 0 r
F
.44852 .43366 m .43039 .4308 L .43001 .43407 L F
.42635 .42996 m .42682 .42647 L .409 .42587 L 1 1 0 r
F
.43039 .4308 m .43079 .42751 L .41898 .42697 L 1 .979 0 r
F
.42682 .42647 m .40976 .42262 L .409 .42587 L 1 1 0 r
F
.41898 .42697 m .41479 .42365 L .41415 .42674 L 1 .99 0 r
F
.43079 .42751 m .41921 .42472 L .41898 .42697 L F
.41921 .42472 m .41479 .42365 L .41898 .42697 L F
.43079 .42751 m .43119 .42422 L .41925 .4238 L F
.41921 .42472 m .41925 .4238 L .41479 .42365 L F
.43079 .42751 m .41925 .4238 L .41921 .42472 L F
.41936 .4214 m .41921 .42045 L .41918 .42128 L .456 .172 0 r
F
.41945 .42146 m .41134 .41615 L .41525 .42148 L F
.38249 .41093 m .38339 .40442 L .34348 .39903 L 1 .892 0 r
F
.38339 .40442 m .34481 .39259 L .34348 .39903 L 1 .898 0 r
F
.38339 .40442 m .38432 .39793 L .34481 .39259 L F
.38432 .39793 m .34618 .38616 L .34481 .39259 L 1 .903 0 r
F
.38432 .39793 m .38528 .39145 L .34618 .38616 L F
.38528 .39145 m .34759 .37975 L .34618 .38616 L 1 .909 0 r
F
.34511 .38536 m .34658 .37893 L .30506 .36875 L 1 .846 0 r
F
.31472 .35991 m .31519 .35259 L .31314 .35887 L .325 .058 0 r
F
.34368 .39181 m .34511 .38536 L .3031 .37527 L 1 .843 0 r
F
.34511 .38536 m .30506 .36875 L .3031 .37527 L 1 .846 0 r
F
.34618 .38616 m .34759 .37975 L .31198 .37282 L 1 .953 0 r
F
.34368 .39181 m .3031 .37527 L .30119 .38182 L 1 .843 0 r
F
.30927 .37897 m .30918 .37152 L .30726 .37788 L .333 .059 0 r
F
.38249 .41093 m .34348 .39903 L .34219 .40549 L 1 .892 0 r
F
.34228 .39827 m .34368 .39181 L .30119 .38182 L 1 .84 0 r
F
.34092 .40475 m .34228 .39827 L .30357 .39066 L 1 .936 0 r
F
.34228 .39827 m .30119 .38182 L .30357 .39066 L 1 .84 0 r
F
.34348 .39903 m .34481 .39259 L .30837 .38552 L 1 .941 0 r
F
.30835 .38559 m .30837 .38552 L .30795 .38544 L F
.34348 .39903 m .30837 .38552 L .30835 .38559 L F
.34618 .38616 m .31117 .37266 L .31115 .37273 L 1 .953 0 r
F
.30757 .38536 m .30726 .37788 L .30539 .38426 L .336 .059 0 r
F
.30795 .38544 m .30844 .38224 L .30757 .38536 L 1 .947 0 r
F
.34481 .39259 m .30932 .37907 L .30795 .38544 L F
.30932 .37907 m .30924 .37903 L .30757 .38536 L .336 .059 0 r
F
.30924 .37903 m .30726 .37788 L .30756 .38515 L F
.30833 .38248 m .30756 .38515 L .30757 .38536 L F
.30924 .37903 m .30756 .38515 L .30833 .38248 L F
.30933 .379 m .30933 .379 L .30926 .37896 L F
.31113 .37272 m .30918 .37152 L .30927 .37897 L .333 .059 0 r
F
.30934 .379 m .31077 .37259 L .31077 .3726 L 1 .953 0 r
F
.30924 .37903 m .30926 .37896 L .30726 .37788 L .336 .059 0 r
F
.30933 .379 m .31077 .3726 L .30894 .37892 L 1 .953 0 r
F
.30934 .379 m .31077 .3726 L .30933 .379 L F
.34618 .38616 m .31114 .37273 L .31108 .37295 L F
.34618 .38616 m .31108 .37295 L .30972 .37908 L F
.31107 .37262 m .31114 .36518 L .30918 .37152 L .331 .059 0 r
F
.34481 .39259 m .34618 .38616 L .30935 .37901 L 1 .947 0 r
F
.30935 .37901 m .30935 .37901 L .30934 .379 L F
.34481 .39259 m .30935 .37901 L .30935 .37901 L F
.3128 .36622 m .31314 .35887 L .31114 .36518 L .328 .058 0 r
F
.34759 .37975 m .31299 .3664 L .31155 .37274 L 1 .959 0 r
F
.34618 .38616 m .31198 .37282 L .31196 .3729 L 1 .953 0 r
F
.34618 .38616 m .31155 .37274 L .31153 .37281 L F
.31669 .35364 m .31729 .34634 L .31519 .35259 L .646 .019 0 r
F
.34759 .37975 m .34904 .37336 L .31386 .36651 L 1 .959 0 r
F
.31383 .36666 m .31386 .36651 L .31303 .36635 L F
.34759 .37975 m .31386 .36651 L .31383 .36666 L F
.31301 .36634 m .31453 .35984 L .3128 .36622 L .328 .058 0 r
F
.31484 .36006 m .31453 .35984 L .31301 .36634 L F
.31453 .35984 m .31314 .35887 L .3128 .36622 L F
.31279 .36627 m .31114 .36518 L .31107 .37262 L .331 .059 0 r
F
.31301 .36634 m .31301 .36634 L .31293 .3663 L F
.31301 .36634 m .31459 .35998 L .31432 .36084 L 1 .964 0 r
F
.31292 .36636 m .31293 .3663 L .31114 .36518 L .331 .059 0 r
F
.31301 .36634 m .31432 .36084 L .31265 .36627 L 1 .964 0 r
F
.34904 .37336 m .31491 .36011 L .31342 .36642 L F
.34759 .37975 m .31303 .36635 L .31303 .36635 L 1 .959 0 r
F
.34759 .37975 m .31301 .36634 L .31299 .3664 L F
.31301 .36634 m .31301 .36634 L .31299 .3664 L F
.40826 .42913 m .31293 .3663 L .31292 .36636 L .331 .059 0 r
F
.31299 .3664 m .31301 .36634 L .31299 .3664 L 1 .959 0 r
F
.31212 .3694 m .31213 .36932 L .31115 .37266 L F
.31114 .37266 m .31279 .36627 L .31107 .37262 L .331 .059 0 r
F
.3113 .37214 m .31279 .36627 L .31114 .37266 L F
.31213 .36932 m .31265 .36627 L .31116 .37259 L 1 .959 0 r
F
.31213 .36932 m .31116 .37259 L .31115 .37266 L F
.31155 .37274 m .31212 .3694 L .31115 .37266 L F
.31116 .37267 m .3113 .37214 L .31114 .37266 L .331 .059 0 r
F
.31299 .3664 m .31279 .36627 L .3113 .37214 L F
.31299 .3664 m .31265 .36627 L .31213 .36932 L 1 .959 0 r
F
.31299 .3664 m .31213 .36932 L .31155 .37274 L F
.31299 .3664 m .3113 .37214 L .31116 .37267 L .331 .059 0 r
F
.31196 .3729 m .31198 .37282 L .31155 .37274 L 1 .953 0 r
F
.31153 .37281 m .31155 .37274 L .31117 .37266 L F
.40826 .42913 m .31299 .3664 L .31116 .37267 L .331 .059 0 r
F
.31491 .36011 m .31484 .36006 L .31301 .36634 L .328 .058 0 r
F
.34904 .37336 m .35052 .36698 L .31492 .36005 L 1 .964 0 r
F
.31491 .36011 m .31492 .36005 L .31459 .35998 L F
.34904 .37336 m .31492 .36005 L .31491 .36011 L F
.35052 .36698 m .31688 .35384 L .31658 .35507 L 1 .97 0 r
F
.31492 .36005 m .31649 .35355 L .31472 .35991 L .325 .058 0 r
F
.31535 .36013 m .31582 .35721 L .31492 .36005 L 1 .97 0 r
F
.35052 .36698 m .31658 .35507 L .31535 .36013 L F
.31688 .35384 m .31649 .35355 L .31492 .36005 L .325 .058 0 r
F
.31658 .35507 m .31618 .35493 L .31535 .36013 L 1 .97 0 r
F
.40976 .42262 m .31688 .35384 L .31492 .36005 L .325 .058 0 r
F
.31582 .35721 m .31618 .35493 L .31492 .36005 L 1 .97 0 r
F
.31689 .35378 m .31851 .3473 L .31669 .35364 L .646 .019 0 r
F
.35204 .36063 m .31889 .3476 L .3184 .34912 L 1 .975 0 r
F
.31889 .3476 m .31851 .3473 L .31689 .35378 L .646 .019 0 r
F
.35204 .36063 m .3181 .34902 L .31689 .35378 L 1 .975 0 r
F
.35052 .36698 m .35204 .36063 L .31657 .35372 L 1 .97 0 r
F
.41054 .41938 m .31889 .3476 L .31689 .35378 L .646 .019 0 r
F
.3184 .34912 m .3186 .34748 L .3181 .34902 L 1 .975 0 r
F
.31889 .3476 m .3186 .34748 L .3184 .34912 L F
.31688 .35384 m .31669 .35364 L .31667 .35369 L .325 .058 0 r
F
.31689 .35379 m .31669 .35364 L .31688 .35384 L F
.31689 .35379 m .31689 .35378 L .31669 .35364 L F
.31667 .35369 m .31669 .35364 L .31519 .35259 L F
.31851 .3473 m .31729 .34634 L .31669 .35364 L .646 .019 0 r
F
.31689 .35378 m .3181 .34902 L .31657 .35372 L 1 .975 0 r
F
.40976 .42262 m .31689 .35379 L .31688 .35384 L .325 .058 0 r
F
.40976 .42262 m .41054 .41938 L .31689 .35378 L F
.40976 .42262 m .31689 .35378 L .31689 .35379 L F
.31658 .35507 m .31657 .35372 L .31618 .35493 L 1 .97 0 r
F
.31688 .35384 m .31657 .35372 L .31658 .35507 L F
.31491 .36011 m .31472 .35991 L .31471 .35997 L .328 .058 0 r
F
.31492 .36006 m .31472 .35991 L .31491 .36011 L F
.31492 .36006 m .31492 .36005 L .31472 .35991 L F
.31471 .35997 m .31472 .35991 L .31314 .35887 L F
.31649 .35355 m .31519 .35259 L .31472 .35991 L .325 .058 0 r
F
.31492 .36005 m .31618 .35493 L .31459 .35998 L 1 .97 0 r
F
.409 .42587 m .31492 .36006 L .31491 .36011 L .328 .058 0 r
F
.409 .42587 m .40976 .42262 L .31492 .36005 L F
.409 .42587 m .31492 .36005 L .31492 .36006 L F
.31342 .36642 m .31491 .36011 L .31301 .36634 L 1 .964 0 r
F
.31491 .36011 m .31459 .35998 L .31301 .36634 L F
.31303 .36635 m .31303 .36635 L .31301 .36634 L 1 .959 0 r
F
.409 .42587 m .31491 .36011 L .31301 .36634 L .328 .058 0 r
F
.31299 .3664 m .31301 .36634 L .31265 .36627 L 1 .959 0 r
F
.30934 .379 m .30934 .379 L .30933 .379 L 1 .947 0 r
F
.34481 .39259 m .30934 .379 L .30934 .379 L F
.30932 .37907 m .30926 .37896 L .30924 .37903 L .336 .059 0 r
F
.30933 .379 m .30926 .37896 L .30932 .37907 L F
.30932 .37907 m .30933 .379 L .30894 .37892 L 1 .947 0 r
F
.34481 .39259 m .30933 .379 L .30932 .37907 L F
.40682 .43567 m .30933 .379 L .30932 .37907 L .336 .059 0 r
F
.40753 .43239 m .40826 .42913 L .31114 .37266 L .333 .059 0 r
F
.31115 .37266 m .31265 .36627 L .31252 .36673 L 1 .959 0 r
F
.31114 .37267 m .31114 .37266 L .31094 .37254 L .333 .059 0 r
F
.31093 .3726 m .31094 .37254 L .30918 .37152 L F
.31114 .37266 m .31252 .36673 L .31077 .37259 L 1 .959 0 r
F
.31115 .37266 m .31252 .36673 L .31114 .37266 L F
.31115 .37273 m .31117 .37266 L .31114 .37266 L 1 .953 0 r
F
.31113 .37273 m .31114 .37266 L .31077 .37259 L F
.31115 .37273 m .31114 .37266 L .31113 .37273 L F
.31114 .37267 m .31114 .37266 L .31114 .37267 L .333 .059 0 r
F
.31114 .37267 m .31114 .37266 L .31114 .37266 L F
.40753 .43239 m .31114 .37266 L .31114 .37267 L F
.30972 .37908 m .31108 .37295 L .30934 .379 L 1 .953 0 r
F
.31113 .37273 m .31094 .37254 L .31093 .3726 L .333 .059 0 r
F
.40753 .43239 m .31114 .37267 L .31113 .37273 L F
.31114 .37267 m .31094 .37254 L .31113 .37273 L F
.31108 .37295 m .31077 .37259 L .30934 .379 L 1 .953 0 r
F
.31114 .37273 m .31113 .37273 L .31108 .37295 L F
.31113 .37273 m .31077 .37259 L .31108 .37295 L F
.30932 .37907 m .30894 .37892 L .30795 .38544 L 1 .947 0 r
F
.30794 .3855 m .30795 .38544 L .30757 .38536 L 1 .941 0 r
F
.34348 .39903 m .30795 .38544 L .30794 .3855 L F
.34348 .39903 m .30799 .38552 L .30756 .38543 L F
.30799 .38552 m .30757 .38536 L .30756 .38543 L F
.34219 .40549 m .34348 .39903 L .30624 .39182 L 1 .935 0 r
F
.26967 .37495 m .30539 .38426 L .26941 .37482 L .478 0 0 r
F
.30624 .39182 m .30715 .38535 L .30543 .39166 L 1 .941 0 r
F
.30715 .38535 m .30714 .38535 L .30543 .39166 L F
.34348 .39903 m .30756 .38543 L .30624 .39182 L F
.30756 .38543 m .30716 .38528 L .30624 .39182 L F
.30621 .39195 m .30624 .39182 L .30543 .39166 L 1 .935 0 r
F
.34219 .40549 m .30624 .39182 L .30621 .39195 L F
.27212 .37621 m .30714 .38535 L .26967 .37495 L .478 0 0 r
F
.30714 .38535 m .30539 .38426 L .26967 .37495 L F
.30756 .38543 m .30539 .38426 L .30714 .38535 L .338 .06 0 r
F
.30756 .38543 m .30714 .38535 L .30714 .38535 L F
.30715 .38535 m .30715 .38535 L .30714 .38535 L 1 .941 0 r
F
.30715 .38535 m .30716 .38528 L .30714 .38535 L F
.27212 .37621 m .30716 .38528 L .27174 .37604 L 1 .985 0 r
F
.30543 .39166 m .30714 .38535 L .27212 .37621 L F
.30714 .38535 m .30716 .38528 L .27212 .37621 L F
.3891 .43646 m .30714 .38535 L .27212 .37621 L .478 0 0 r
F
.40613 .43895 m .40682 .43567 L .30757 .38536 L .338 .06 0 r
F
.30757 .38537 m .30757 .38536 L .3075 .38533 L F
.40613 .43895 m .30757 .38536 L .30757 .38537 L F
.30748 .38539 m .3075 .38533 L .30539 .38426 L F
.40613 .43895 m .3075 .38533 L .30748 .38539 L F
.30756 .38543 m .30757 .38536 L .30755 .38543 L 1 .941 0 r
F
.40613 .43895 m .30756 .38543 L .3891 .43646 L .338 .06 0 r
F
.30756 .38543 m .30714 .38535 L .3891 .43646 L F
.40682 .43567 m .30932 .37907 L .30757 .38536 L .336 .059 0 r
F
.30757 .38536 m .30894 .37892 L .30716 .38528 L 1 .947 0 r
F
.30844 .38224 m .30894 .37892 L .30757 .38536 L F
.40682 .43567 m .40753 .43239 L .30933 .379 L .336 .059 0 r
F
.40682 .43567 m .30933 .379 L .30933 .379 L F
.30755 .38543 m .30757 .38536 L .30716 .38528 L 1 .941 0 r
F
.40753 .43239 m .31113 .37272 L .30927 .37897 L .333 .059 0 r
F
.40826 .42913 m .409 .42587 L .31301 .36634 L .331 .059 0 r
F
.40826 .42913 m .31301 .36634 L .31301 .36634 L F
.35266 .36077 m .35267 .36071 L .35235 .36067 L 1 .925 0 r
F
.35234 .36072 m .35235 .36067 L .35204 .36063 L F
.31889 .3476 m .35359 .35434 L .31729 .34634 L .646 .019 0 r
F
.35204 .36063 m .35359 .35434 L .31889 .3476 L 1 .975 0 r
F
.41054 .41938 m .35359 .35434 L .31889 .3476 L .646 .019 0 r
F
.35359 .35434 m .35278 .35342 L .32262 .3474 L F
.35359 .35434 m .32262 .3474 L .31729 .34634 L F
.31889 .3476 m .3536 .3543 L .3186 .34748 L 1 .975 0 r
F
.35359 .35434 m .3536 .3543 L .31889 .3476 L F
.40429 .42007 m .41134 .41615 L .39615 .415 L .751 .037 0 r
F
.40855 .42152 m .4119 .42105 L .40429 .42007 L 1 1 0 r
F
.41479 .42365 m .41525 .42148 L .40855 .42152 L F
.41525 .42148 m .41134 .41615 L .40429 .42007 L .751 .037 0 r
F
.41525 .42148 m .41545 .42055 L .40855 .42152 L 1 1 0 r
F
.41925 .4238 m .41654 .42149 L .41479 .42365 L F
.41654 .42149 m .41525 .42148 L .41479 .42365 L F
.41895 .42794 m .41898 .42697 L .41415 .42674 L 1 .979 0 r
F
.43039 .4308 m .41898 .42697 L .41895 .42794 L F
.42589 .43344 m .42635 .42996 L .40826 .42913 L 1 1 0 r
F
.42635 .42996 m .409 .42587 L .40826 .42913 L F
.43001 .43407 m .43039 .4308 L .41354 .42985 L 1 .969 0 r
F
.43039 .4308 m .41415 .42674 L .41354 .42985 L 1 .979 0 r
F
.41415 .42674 m .41479 .42365 L .40374 .42223 L 1 1 0 r
F
.41354 .42985 m .41415 .42674 L .40313 .42525 L F
.40313 .42528 m .40313 .42525 L .40302 .42523 L F
.41354 .42985 m .40313 .42525 L .40313 .42528 L F
.40358 .42308 m .40374 .42223 L .4037 .42223 L F
.40342 .42299 m .40353 .42215 L .39508 .41801 L .636 .341 0 r
F
.41415 .42674 m .40374 .42223 L .40358 .42308 L 1 1 0 r
F
.42544 .43692 m .42589 .43344 L .40753 .43239 L F
.42589 .43344 m .40826 .42913 L .40753 .43239 L F
.44585 .44069 m .44606 .43698 L .42544 .43692 L 1 .921 0 r
F
.44606 .43698 m .42589 .43344 L .42544 .43692 L 1 .93 0 r
F
.42965 .43733 m .43001 .43407 L .41295 .43295 L 1 .958 0 r
F
.43001 .43407 m .41354 .42985 L .41295 .43295 L 1 .969 0 r
F
.4037 .42225 m .4037 .42223 L .40353 .42215 L .636 .341 0 r
F
.40342 .42299 m .39508 .41801 L .40303 .42519 L F
.4037 .42223 m .39615 .415 L .39508 .41801 L .751 .037 0 r
F
.41479 .42365 m .40429 .42007 L .4037 .42223 L 1 1 0 r
F
.41415 .42674 m .40358 .42308 L .40313 .42525 L F
.42256 .43146 m .40429 .42007 L .4037 .42223 L .751 .037 0 r
F
.40423 .42003 m .39615 .415 L .40361 .42214 L F
.40445 .41924 m .40141 .41586 L .40049 .41877 L 1 1 0 r
F
.41545 .42055 m .40508 .41708 L .40445 .41924 L F
.40508 .41708 m .40141 .41586 L .40445 .41924 L F
.40429 .42007 m .40423 .42003 L .4037 .42223 L .751 .037 0 r
F
.40423 .42003 m .40361 .42214 L .4037 .42223 L F
.40429 .42007 m .4042 .42004 L .4037 .42223 L 1 1 0 r
F
.4037 .42223 m .40049 .41877 L .39959 .4217 L F
.4042 .42004 m .40049 .41877 L .4037 .42223 L F
.40352 .42305 m .40353 .42215 L .40342 .42299 L .636 .341 0 r
F
.40358 .42308 m .40356 .42283 L .40352 .42305 L F
.40356 .42283 m .40353 .42215 L .40352 .42305 L F
.42191 .43403 m .40374 .42228 L .40358 .42308 L F
.40374 .42228 m .40353 .42215 L .40358 .42308 L F
.40302 .42523 m .39508 .41801 L .39403 .42104 L F
.40313 .42525 m .40304 .42516 L .40302 .42523 L 1 1 0 r
F
.40315 .42529 m .40304 .42519 L .40302 .42523 L .636 .341 0 r
F
.40304 .42519 m .39508 .41801 L .40302 .42523 L F
.41295 .43295 m .41354 .42985 L .40249 .42827 L 1 1 0 r
F
.41354 .42985 m .40306 .42525 L .4029 .42612 L F
.40306 .42525 m .40302 .42523 L .4029 .42612 L F
.42544 .43692 m .40753 .43239 L .40682 .43567 L F
.44585 .44069 m .42544 .43692 L .425 .44039 L 1 .921 0 r
F
.425 .44039 m .42544 .43692 L .40682 .43567 L 1 .994 0 r
F
.42965 .43733 m .41295 .43295 L .41239 .43605 L 1 .958 0 r
F
.40239 .42825 m .39403 .42104 L .39299 .42409 L .642 .344 0 r
F
.40249 .42827 m .4024 .42818 L .40239 .42825 L 1 1 0 r
F
.40248 .42829 m .40249 .42827 L .40239 .42825 L F
.4025 .4283 m .40239 .42821 L .40239 .42825 L .642 .344 0 r
F
.40239 .42821 m .40239 .42821 L .40239 .42825 L F
.40239 .42821 m .39403 .42104 L .40239 .42825 L F
.4029 .42612 m .39403 .42104 L .40239 .42821 L F
.4029 .42612 m .4024 .42818 L .40249 .42827 L 1 1 0 r
F
.4029 .42612 m .40239 .42821 L .4025 .4283 L .642 .344 0 r
F
.4029 .42612 m .39872 .42465 L .4024 .42818 L 1 1 0 r
F
.41239 .43605 m .41295 .43295 L .40188 .43129 L 1 .996 0 r
F
.41295 .43295 m .40242 .42827 L .40227 .42916 L 1 1 0 r
F
.40242 .42827 m .40239 .42825 L .40227 .42916 L F
.44564 .44437 m .44585 .44069 L .425 .44039 L 1 .912 0 r
F
.425 .44039 m .40682 .43567 L .40613 .43895 L 1 .994 0 r
F
.4293 .44058 m .41239 .43605 L .41184 .43915 L 1 .948 0 r
F
.4293 .44058 m .42965 .43733 L .41239 .43605 L F
.40178 .43128 m .39299 .42409 L .39199 .42716 L .648 .347 0 r
F
.40188 .43129 m .4018 .43122 L .40178 .43128 L 1 1 0 r
F
.40188 .43132 m .40188 .43129 L .40178 .43128 L 1 .996 0 r
F
.40189 .43132 m .40179 .43124 L .40178 .43128 L .648 .347 0 r
F
.40179 .43124 m .40179 .43124 L .40178 .43128 L F
.40179 .43124 m .39299 .42409 L .40178 .43128 L F
.40227 .42916 m .39299 .42409 L .40179 .43124 L F
.40227 .42916 m .4018 .43122 L .40188 .43129 L 1 1 0 r
F
.40227 .42916 m .40179 .43124 L .40189 .43132 L .648 .347 0 r
F
.40227 .42916 m .39788 .42761 L .4018 .43122 L 1 1 0 r
F
.41184 .43915 m .41239 .43605 L .40131 .43433 L 1 .985 0 r
F
.41239 .43605 m .40182 .4313 L .40167 .43222 L 1 .996 0 r
F
.40182 .4313 m .40178 .43128 L .40167 .43222 L F
.41239 .43605 m .40188 .43129 L .40188 .43132 L F
.42457 .44386 m .425 .44039 L .40613 .43895 L 1 .985 0 r
F
.44564 .44437 m .425 .44039 L .42457 .44386 L 1 .912 0 r
F
.42457 .44386 m .40613 .43895 L .40546 .44223 L 1 .985 0 r
F
.42896 .44382 m .41184 .43915 L .41132 .44225 L 1 .937 0 r
F
.42896 .44382 m .4293 .44058 L .41184 .43915 L F
.40122 .43432 m .39199 .42716 L .391 .43024 L .654 .349 0 r
F
.40131 .43433 m .40123 .43426 L .40122 .43432 L 1 .996 0 r
F
.40131 .43436 m .40131 .43433 L .40122 .43432 L 1 .985 0 r
F
.40132 .43436 m .40123 .43428 L .40122 .43432 L .654 .349 0 r
F
.40123 .43428 m .40122 .43428 L .40122 .43432 L F
.40122 .43428 m .39199 .42716 L .40122 .43432 L F
.40167 .43222 m .39199 .42716 L .40123 .43428 L F
.40167 .43222 m .40123 .43426 L .40131 .43433 L 1 .996 0 r
F
.40167 .43222 m .40123 .43428 L .40132 .43436 L .654 .349 0 r
F
.40167 .43222 m .39707 .43057 L .40123 .43426 L 1 .996 0 r
F
.40546 .44223 m .40613 .43895 L .3891 .43646 L 1 1 0 r
F
.41132 .44225 m .41184 .43915 L .40078 .43738 L 1 .974 0 r
F
.41184 .43915 m .40126 .43433 L .40111 .43529 L 1 .985 0 r
F
.40126 .43433 m .40122 .43432 L .40111 .43529 L F
.41184 .43915 m .40131 .43433 L .40131 .43436 L F
.42415 .44733 m .42457 .44386 L .40546 .44223 L 1 .975 0 r
F
.44545 .44804 m .44564 .44437 L .42457 .44386 L 1 .903 0 r
F
.44545 .44804 m .42457 .44386 L .42415 .44733 L F
.42864 .44705 m .42896 .44382 L .41132 .44225 L 1 .927 0 r
F
.40069 .43736 m .391 .43024 L .39004 .43335 L .66 .351 0 r
F
.40078 .43738 m .4007 .43731 L .40069 .43736 L 1 .985 0 r
F
.40078 .4374 m .40078 .43738 L .40069 .43736 L 1 .974 0 r
F
.40079 .4374 m .4007 .43733 L .40069 .43736 L .66 .351 0 r
F
.4007 .43733 m .4007 .43733 L .40069 .43736 L F
.4007 .43733 m .391 .43024 L .40069 .43736 L F
.40111 .43529 m .391 .43024 L .4007 .43733 L F
.40111 .43529 m .4007 .43731 L .40078 .43738 L 1 .985 0 r
F
.40111 .43529 m .4007 .43733 L .40079 .4374 L .66 .351 0 r
F
.40111 .43529 m .39629 .43355 L .4007 .43731 L 1 .985 0 r
F
.42375 .45079 m .42415 .44733 L .4048 .44553 L 1 .966 0 r
F
.42415 .44733 m .40546 .44223 L .4048 .44553 L 1 .975 0 r
F
.4048 .44553 m .40546 .44223 L .38818 .43959 L 1 1 0 r
F
.40546 .44223 m .3891 .43646 L .38818 .43959 L F
.42864 .44705 m .41132 .44225 L .41082 .44535 L 1 .927 0 r
F
.44525 .45168 m .44545 .44804 L .42415 .44733 L 1 .894 0 r
F
.44525 .45168 m .42415 .44733 L .42375 .45079 L F
.42833 .45026 m .42864 .44705 L .41082 .44535 L 1 .917 0 r
F
.42375 .45079 m .4048 .44553 L .40417 .44883 L 1 .966 0 r
F
.42833 .45026 m .41082 .44535 L .41035 .44844 L 1 .917 0 r
F
.40417 .44883 m .4048 .44553 L .38729 .44274 L 1 1 0 r
F
.4048 .44553 m .38818 .43959 L .38729 .44274 L F
.41035 .44844 m .41082 .44535 L .39413 .44252 L 1 .953 0 r
F
.41082 .44535 m .39482 .43952 L .39413 .44252 L 1 .963 0 r
F
.41082 .44535 m .41132 .44225 L .40029 .44043 L F
.4002 .44148 m .40029 .44043 L .39482 .43952 L F
.41082 .44535 m .40029 .44043 L .4002 .44148 L F
.41132 .44225 m .40392 .43885 L .40059 .43837 L 1 .974 0 r
F
.40392 .43885 m .40069 .43736 L .40059 .43837 L F
.41132 .44225 m .40078 .43738 L .40078 .4374 L F
.4003 .43823 m .39004 .43335 L .39528 .43758 L .665 .353 0 r
F
.3848 .43492 m .39004 .43335 L .37498 .43007 L .574 0 0 r
F
.38876 .43674 m .39162 .43665 L .3848 .43492 L 1 1 0 r
F
.39482 .43952 m .39528 .43758 L .38876 .43674 L F
.39528 .43758 m .39004 .43335 L .3848 .43492 L .574 0 0 r
F
.39528 .43758 m .39554 .43653 L .38876 .43674 L 1 1 0 r
F
.40029 .44043 m .39715 .43786 L .39482 .43952 L 1 .974 0 r
F
.39715 .43786 m .39528 .43758 L .39482 .43952 L F
.39413 .44252 m .39482 .43952 L .38429 .43696 L 1 1 0 r
F
.40417 .44883 m .38729 .44274 L .38642 .44589 L F
.3841 .43792 m .38429 .43696 L .38427 .43695 L F
.38426 .43697 m .38427 .43695 L .38412 .4369 L .79 .472 0 r
F
.38397 .43786 m .38412 .4369 L .37381 .43304 L F
.39347 .44551 m .39413 .44252 L .38366 .43994 L 1 .994 0 r
F
.39413 .44252 m .38429 .43696 L .3841 .43792 L 1 1 0 r
F
.41035 .44844 m .39413 .44252 L .39347 .44551 L 1 .953 0 r
F
.38397 .43786 m .37381 .43304 L .38361 .4399 L .79 .472 0 r
F
.38427 .43695 m .37498 .43007 L .37381 .43304 L .574 0 0 r
F
.39482 .43952 m .3848 .43492 L .38427 .43695 L 1 1 0 r
F
.40335 .44409 m .3848 .43492 L .38427 .43695 L .574 0 0 r
F
.38474 .43489 m .37498 .43007 L .38417 .43688 L F
.39004 .43335 m .37618 .42712 L .37498 .43007 L 1 1 0 r
F
.38499 .434 m .38131 .43 L .38035 .43288 L F
.39554 .43653 m .38558 .43196 L .38499 .434 L F
.38558 .43196 m .38131 .43 L .38499 .434 L F
.3848 .43492 m .38474 .43489 L .38427 .43695 L .574 0 0 r
F
.38474 .43489 m .38417 .43688 L .38427 .43695 L F
.3848 .43492 m .38476 .43491 L .38427 .43695 L 1 1 0 r
F
.38427 .43695 m .38035 .43288 L .37942 .43577 L F
.38476 .43491 m .38035 .43288 L .38427 .43695 L F
.38404 .43789 m .38412 .4369 L .38397 .43786 L .79 .472 0 r
F
.3841 .43792 m .3841 .43762 L .38404 .43789 L F
.3841 .43762 m .38412 .4369 L .38404 .43789 L F
.39413 .44252 m .3841 .43792 L .38366 .43994 L 1 1 0 r
F
.40261 .44669 m .3843 .437 L .3841 .43792 L .79 .472 0 r
F
.3843 .437 m .38412 .4369 L .3841 .43792 L F
.3836 .43993 m .37381 .43304 L .37267 .43604 L F
.38366 .43994 m .38361 .4399 L .3836 .43993 L 1 1 0 r
F
.38366 .43995 m .38366 .43994 L .38363 .43993 L 1 .994 0 r
F
.38369 .43996 m .38361 .4399 L .3836 .43993 L .79 .472 0 r
F
.38361 .4399 m .37381 .43304 L .3836 .43993 L F
.39347 .44551 m .38366 .43994 L .38366 .43995 L 1 .994 0 r
F
.38363 .43994 m .38363 .43993 L .3836 .43993 L F
.39347 .44551 m .38363 .43993 L .38363 .43994 L F
.40355 .45213 m .40417 .44883 L .38642 .44589 L 1 1 0 r
F
.42335 .45424 m .40417 .44883 L .40355 .45213 L 1 .956 0 r
F
.42335 .45424 m .42375 .45079 L .40417 .44883 L F
.40989 .45153 m .41035 .44844 L .39347 .44551 L 1 .942 0 r
F
.40355 .45213 m .38642 .44589 L .38558 .44906 L 1 1 0 r
F
.40989 .45153 m .39347 .44551 L .39284 .44851 L 1 .942 0 r
F
.4019 .4493 m .40261 .44669 L .3836 .43993 L .793 .472 0 r
F
.38345 .44093 m .3836 .43993 L .37267 .43604 L F
.39347 .44551 m .3836 .43993 L .38345 .44093 L 1 .994 0 r
F
.4019 .4493 m .3836 .43993 L .38345 .44093 L .793 .472 0 r
F
.38345 .44093 m .3836 .43993 L .38343 .44092 L 1 .994 0 r
F
.3836 .43993 m .37942 .43577 L .37854 .43868 L 1 1 0 r
F
.38361 .4399 m .37942 .43577 L .3836 .43993 L F
.3841 .43792 m .38397 .43786 L .3838 .43912 L .79 .472 0 r
F
.3841 .43792 m .38361 .4399 L .38366 .43994 L 1 1 0 r
F
.3841 .43792 m .3838 .43912 L .38369 .43996 L .79 .472 0 r
F
.38397 .43786 m .38361 .4399 L .38369 .43996 L F
.3841 .43792 m .37942 .43577 L .38361 .4399 L 1 1 0 r
F
.3841 .43792 m .38427 .43695 L .37942 .43577 L F
.40261 .44669 m .40335 .44409 L .38427 .43695 L .79 .472 0 r
F
.40261 .44669 m .38427 .43695 L .38426 .43697 L F
.38241 .4459 m .37156 .43905 L .37047 .44208 L .796 .471 0 r
F
.38242 .44588 m .37156 .43905 L .38241 .4459 L F
.39284 .44851 m .38284 .44394 L .38241 .4459 L 1 .984 0 r
F
.38284 .44394 m .38271 .44389 L .3825 .44593 L .796 .471 0 r
F
.38271 .44389 m .37156 .43905 L .38242 .44588 L F
.38271 .44389 m .38242 .44588 L .3825 .44593 L F
.40295 .45544 m .40355 .45213 L .38558 .44906 L 1 1 0 r
F
.39224 .4515 m .39264 .44948 L .38578 .44782 L 1 .974 0 r
F
.38227 .44697 m .38241 .4459 L .37047 .44208 L .799 .47 0 r
F
.38227 .44697 m .38241 .4459 L .38225 .44696 L 1 .974 0 r
F
.39224 .4515 m .38241 .4459 L .38227 .44697 L F
.38578 .44782 m .39284 .44851 L .38241 .4459 L F
.39264 .44948 m .39284 .44851 L .38578 .44782 L F
.42297 .45769 m .40355 .45213 L .40295 .45544 L 1 .947 0 r
F
.40946 .45461 m .39284 .44851 L .39224 .4515 L 1 .931 0 r
F
.4226 .46114 m .40295 .45544 L .40237 .45875 L 1 .938 0 r
F
.4226 .46114 m .42297 .45769 L .40295 .45544 L F
.40906 .45768 m .40946 .45461 L .39224 .4515 L 1 .921 0 r
F
.40053 .45455 m .40121 .45192 L .38241 .4459 L .799 .47 0 r
F
.40053 .45455 m .38241 .4459 L .38227 .44697 L F
.40295 .45544 m .38558 .44906 L .38476 .45224 L 1 1 0 r
F
.38476 .45224 m .38558 .44906 L .36942 .44512 L F
.40237 .45875 m .40295 .45544 L .38476 .45224 L 1 .998 0 r
F
.40906 .45768 m .39224 .4515 L .39167 .4545 L 1 .921 0 r
F
.36524 .44151 m .37047 .44208 L .35632 .43746 L .45 0 0 r
F
.39224 .4515 m .3892 .45012 L .37609 .44744 L 1 .974 0 r
F
.3892 .45012 m .38075 .44709 L .37609 .44744 L F
.38227 .44697 m .37658 .44559 L .37609 .44744 L F
.39167 .4545 m .39224 .4515 L .37609 .44744 L 1 .964 0 r
F
.3665 .44208 m .37658 .44559 L .36524 .44151 L .45 0 0 r
F
.37658 .44559 m .37047 .44208 L .36524 .44151 L F
.38227 .44697 m .37047 .44208 L .37658 .44559 L .799 .47 0 r
F
.3665 .44208 m .37687 .44452 L .36211 .43962 L 1 1 0 r
F
.37609 .44744 m .37658 .44559 L .3665 .44208 L F
.37658 .44559 m .37687 .44452 L .3665 .44208 L F
.38551 .45071 m .37658 .44559 L .3665 .44208 L .45 0 0 r
F
.3892 .45012 m .38227 .44697 L .38075 .44709 L 1 .974 0 r
F
.38227 .44697 m .37687 .44452 L .37658 .44559 L F
.38227 .44697 m .37658 .44559 L .37661 .4456 L .799 .47 0 r
F
.40053 .45455 m .38227 .44697 L .38551 .45071 L F
.38227 .44697 m .37661 .4456 L .38551 .45071 L F
.38225 .44696 m .38241 .4459 L .37687 .44452 L 1 .974 0 r
F
.39284 .44851 m .39347 .44551 L .38301 .44292 L 1 .984 0 r
F
.38301 .44292 m .38301 .44292 L .38299 .44291 L F
.39284 .44851 m .38301 .44292 L .38301 .44292 L F
.42297 .45769 m .42335 .45424 L .40355 .45213 L 1 .947 0 r
F
.40946 .45461 m .40989 .45153 L .39284 .44851 L 1 .931 0 r
F
.40121 .45192 m .4019 .4493 L .38299 .44291 L .796 .471 0 r
F
.38277 .44392 m .38299 .44291 L .37156 .43905 L F
.38299 .44291 m .37267 .43604 L .37156 .43905 L .793 .472 0 r
F
.38299 .44289 m .37267 .43604 L .38299 .44291 L F
.38345 .44093 m .37267 .43604 L .38299 .44289 L F
.39347 .44551 m .38345 .44093 L .38299 .44291 L 1 .994 0 r
F
.38345 .44093 m .38299 .44289 L .38307 .44294 L .793 .472 0 r
F
.38345 .44093 m .38341 .44091 L .38299 .44291 L 1 .994 0 r
F
.38299 .44291 m .37854 .43868 L .37769 .44159 L F
.38341 .44091 m .37854 .43868 L .38299 .44291 L F
.38284 .44394 m .38299 .44291 L .38277 .44392 L .796 .471 0 r
F
.39284 .44851 m .38299 .44291 L .38284 .44394 L 1 .984 0 r
F
.40121 .45192 m .38299 .44291 L .38284 .44394 L .796 .471 0 r
F
.38284 .44394 m .38299 .44291 L .38282 .44394 L 1 .984 0 r
F
.38241 .4459 m .37769 .44159 L .37687 .44452 L F
.38284 .44394 m .37769 .44159 L .38241 .4459 L F
.3825 .44593 m .38242 .44588 L .38241 .4459 L .796 .471 0 r
F
.40121 .45192 m .38284 .44394 L .3825 .44593 L F
.38282 .44394 m .38299 .44291 L .37769 .44159 L 1 .984 0 r
F
.38307 .44294 m .38299 .44289 L .38299 .44291 L .793 .472 0 r
F
.4019 .4493 m .38345 .44093 L .38307 .44294 L F
.38343 .44092 m .3836 .43993 L .37854 .43868 L 1 .994 0 r
F
.40261 .44669 m .3841 .43792 L .38369 .43996 L .79 .472 0 r
F
.40335 .44409 m .39528 .43758 L .3848 .43492 L .574 0 0 r
F
.3848 .43492 m .39554 .43653 L .38035 .43288 L 1 1 0 r
F
.39162 .43665 m .39554 .43653 L .3848 .43492 L F
.40059 .43837 m .4003 .43823 L .39528 .43758 L .665 .353 0 r
F
.40059 .43837 m .39554 .43653 L .40029 .44043 L 1 .974 0 r
F
.40059 .43837 m .39528 .43758 L .39531 .4376 L .665 .353 0 r
F
.39715 .43786 m .39554 .43653 L .39528 .43758 L 1 .974 0 r
F
.41132 .44225 m .40059 .43837 L .40029 .44043 L F
.41886 .44705 m .41944 .44443 L .40074 .43738 L .665 .353 0 r
F
.40073 .43741 m .40074 .43738 L .40055 .43731 L F
.41886 .44705 m .40074 .43738 L .40073 .43741 L F
.40047 .43831 m .40055 .43731 L .39004 .43335 L F
.41886 .44705 m .40055 .43731 L .40047 .43831 L F
.41886 .44705 m .40059 .43837 L .40335 .44409 L F
.40059 .43837 m .39531 .4376 L .40335 .44409 L F
.40059 .43837 m .40069 .43736 L .40056 .43835 L 1 .974 0 r
F
.40069 .43736 m .39629 .43355 L .39554 .43653 L 1 .985 0 r
F
.4007 .43731 m .39629 .43355 L .40069 .43736 L F
.41184 .43915 m .40111 .43529 L .40078 .43738 L F
.41944 .44443 m .42003 .44181 L .40126 .43433 L .66 .351 0 r
F
.40126 .43436 m .40126 .43433 L .40107 .43426 L F
.41944 .44443 m .40126 .43433 L .40126 .43436 L F
.40098 .43522 m .40107 .43426 L .391 .43024 L F
.41944 .44443 m .40107 .43426 L .40098 .43522 L F
.40056 .43835 m .40069 .43736 L .39554 .43653 L 1 .974 0 r
F
.41944 .44443 m .40111 .43529 L .40079 .4374 L .66 .351 0 r
F
.40111 .43529 m .40122 .43432 L .40108 .43528 L 1 .985 0 r
F
.40122 .43432 m .39707 .43057 L .39629 .43355 L 1 .996 0 r
F
.40123 .43426 m .39707 .43057 L .40122 .43432 L F
.41239 .43605 m .40167 .43222 L .40131 .43433 L F
.42003 .44181 m .42064 .43921 L .40183 .4313 L .654 .349 0 r
F
.40182 .43133 m .40183 .4313 L .40163 .43121 L F
.42003 .44181 m .40183 .4313 L .40182 .43133 L F
.40154 .43215 m .40163 .43121 L .39199 .42716 L F
.42003 .44181 m .40163 .43121 L .40154 .43215 L F
.40108 .43528 m .40122 .43432 L .39629 .43355 L 1 .985 0 r
F
.42003 .44181 m .40167 .43222 L .40132 .43436 L .654 .349 0 r
F
.40167 .43222 m .40178 .43128 L .40164 .43221 L 1 .996 0 r
F
.40178 .43128 m .39788 .42761 L .39707 .43057 L 1 1 0 r
F
.4018 .43122 m .39788 .42761 L .40178 .43128 L F
.41295 .43295 m .40227 .42916 L .40188 .43129 L F
.42064 .43921 m .42127 .43661 L .40243 .42827 L .648 .347 0 r
F
.40242 .4283 m .40243 .42827 L .40223 .42818 L F
.42064 .43921 m .40243 .42827 L .40242 .4283 L F
.40213 .42909 m .40223 .42818 L .39299 .42409 L F
.42064 .43921 m .40223 .42818 L .40213 .42909 L F
.40164 .43221 m .40178 .43128 L .39707 .43057 L 1 .996 0 r
F
.42064 .43921 m .40227 .42916 L .40189 .43132 L .648 .347 0 r
F
.40227 .42916 m .40239 .42825 L .40223 .42915 L 1 1 0 r
F
.40239 .42825 m .39872 .42465 L .39788 .42761 L F
.4024 .42818 m .39872 .42465 L .40239 .42825 L F
.41354 .42985 m .4029 .42612 L .40249 .42827 L F
.42127 .43661 m .42191 .43403 L .40307 .42525 L .642 .344 0 r
F
.40306 .42528 m .40307 .42525 L .40286 .42516 L F
.42127 .43661 m .40307 .42525 L .40306 .42528 L F
.40276 .42603 m .40286 .42516 L .39403 .42104 L F
.42127 .43661 m .40286 .42516 L .40276 .42603 L F
.41295 .43295 m .40249 .42827 L .40248 .42829 L 1 1 0 r
F
.40223 .42915 m .40239 .42825 L .39788 .42761 L F
.42127 .43661 m .4029 .42612 L .4025 .4283 L .642 .344 0 r
F
.4029 .42612 m .40302 .42523 L .40287 .4261 L 1 1 0 r
F
.40302 .42523 m .39959 .4217 L .39872 .42465 L F
.40304 .42516 m .39959 .4217 L .40302 .42523 L F
.40358 .42308 m .40342 .42299 L .40327 .42429 L .636 .341 0 r
F
.40358 .42308 m .40304 .42516 L .40313 .42525 L 1 1 0 r
F
.40358 .42308 m .40327 .42429 L .40315 .42529 L .636 .341 0 r
F
.40342 .42299 m .40303 .42519 L .40315 .42529 L F
.40358 .42308 m .39959 .4217 L .40304 .42516 L 1 1 0 r
F
.40358 .42308 m .4037 .42223 L .39959 .4217 L F
.42191 .43403 m .42256 .43146 L .4037 .42223 L .636 .341 0 r
F
.42191 .43403 m .4037 .42223 L .4037 .42225 L F
.40287 .4261 m .40302 .42523 L .39872 .42465 L 1 1 0 r
F
.42191 .43403 m .40358 .42308 L .40315 .42529 L .636 .341 0 r
F
.42256 .43146 m .41525 .42148 L .40429 .42007 L .751 .037 0 r
F
.40429 .42007 m .41545 .42055 L .40049 .41877 L 1 1 0 r
F
.4119 .42105 m .41545 .42055 L .40429 .42007 L F
.41951 .4215 m .41945 .42146 L .41525 .42148 L .456 .172 0 r
F
.41951 .4215 m .41545 .42055 L .41925 .4238 L 1 1 0 r
F
.41951 .4215 m .41525 .42148 L .41527 .42152 L .456 .172 0 r
F
.41654 .42149 m .41545 .42055 L .41525 .42148 L 1 1 0 r
F
.43119 .42422 m .41951 .4215 L .41925 .4238 L F
.41961 .42074 m .41962 .42068 L .41921 .42045 L .456 .172 0 r
F
.41918 .42128 m .41921 .42045 L .41134 .41615 L F
.41956 .42065 m .41612 .41746 L .41545 .42055 L 1 1 0 r
F
.43162 .42092 m .42001 .41833 L .41972 .42065 L F
.43826 .43086 m .43873 .42828 L .42011 .41753 L .446 .164 0 r
F
.42006 .41752 m .42006 .4175 L .41989 .4174 L F
.41984 .41822 m .41989 .4174 L .41215 .41293 L F
.42001 .41833 m .42012 .4175 L .42006 .4175 L 1 1 0 r
F
.42037 .41841 m .42012 .4175 L .42001 .41833 L F
.43826 .43086 m .41989 .4174 L .41984 .41822 L .446 .164 0 r
F
.42006 .4175 m .41998 .41741 L .41997 .41745 L .435 .157 0 r
F
.42006 .4175 m .41682 .41438 L .41612 .41746 L 1 1 0 r
F
.42012 .4175 m .42007 .41745 L .42006 .4175 L F
.42007 .41745 m .41682 .41438 L .42006 .4175 L F
.42011 .41756 m .42011 .41753 L .42006 .4175 L .446 .164 0 r
F
.42011 .41756 m .42006 .4175 L .42006 .41752 L F
.43826 .43086 m .42011 .41753 L .42011 .41756 L F
.4197 .41995 m .41995 .41829 L .41969 .41955 L F
.41972 .42065 m .4198 .41943 L .41956 .42065 L 1 1 0 r
F
.41988 .419 m .41995 .41829 L .4197 .41995 L .446 .164 0 r
F
.42001 .41833 m .41995 .41829 L .41988 .419 L F
.42001 .41833 m .41986 .4183 L .4198 .41943 L 1 1 0 r
F
.42001 .41833 m .4198 .41943 L .41972 .42065 L F
.42001 .41833 m .41988 .419 L .41971 .42073 L .446 .164 0 r
F
.41971 .42073 m .41988 .419 L .4197 .41995 L F
.4198 .41943 m .41986 .4183 L .41956 .42065 L 1 1 0 r
F
.41956 .42065 m .41969 .41955 L .41947 .4206 L .446 .164 0 r
F
.41986 .4183 m .41612 .41746 L .41956 .42065 L 1 1 0 r
F
.41946 .42146 m .41939 .42058 L .41936 .4214 L .456 .172 0 r
F
.41951 .4215 m .41948 .42126 L .41946 .42146 L F
.41948 .42126 m .41939 .42058 L .41946 .42146 L F
.4378 .43346 m .4196 .42073 L .41951 .4215 L F
.4196 .42073 m .41939 .42058 L .41951 .4215 L F
.41939 .42058 m .41921 .42045 L .41936 .4214 L F
.4378 .43346 m .43826 .43086 L .41962 .42068 L F
.4378 .43346 m .41962 .42068 L .41961 .42074 L F
.41951 .4215 m .41956 .42065 L .41946 .42149 L 1 1 0 r
F
.4378 .43346 m .41951 .4215 L .42256 .43146 L .456 .172 0 r
F
.41951 .4215 m .41527 .42152 L .42256 .43146 L F
.41972 .4207 m .41972 .42065 L .41956 .42065 L 1 1 0 r
F
.41946 .42149 m .41956 .42065 L .41545 .42055 L F
.41971 .42073 m .41969 .41955 L .41956 .42065 L .446 .164 0 r
F
.43873 .42828 m .43921 .42571 L .42059 .41436 L .435 .157 0 r
F
.42053 .41517 m .42059 .41436 L .41298 .40972 L F
.42053 .41517 m .42064 .41436 L .42059 .41436 L 1 1 0 r
F
.43873 .42828 m .42059 .41436 L .42053 .41517 L .435 .157 0 r
F
.42053 .41517 m .42059 .41436 L .41682 .41438 L 1 1 0 r
F
.43873 .42828 m .42053 .41517 L .42022 .41759 L .435 .157 0 r
F
.42109 .41201 m .4206 .41429 L .42075 .41446 L .424 .149 0 r
F
.43921 .42571 m .42118 .41132 L .42109 .41201 L F
.42118 .41132 m .42074 .41097 L .42109 .41201 L F
.42105 .41117 m .41468 .40333 L .41382 .40652 L .413 .14 0 r
F
.42114 .41123 m .42106 .41113 L .42105 .41117 L F
.42106 .41113 m .41468 .40333 L .42105 .41117 L F
.43296 .41095 m .42173 .40888 L .42155 .40967 L 1 1 0 r
F
.42132 .41122 m .42155 .40967 L .42119 .41122 L F
.43296 .41095 m .42155 .40967 L .42132 .41122 L F
.42167 .40887 m .42152 .40797 L .42148 .40872 L .413 .14 0 r
F
.42115 .41114 m .41468 .40333 L .42114 .41123 L F
.42173 .40888 m .42167 .40887 L .42119 .41122 L 1 1 0 r
F
.42167 .40887 m .41468 .40333 L .42116 .41115 L .413 .14 0 r
F
.42167 .40887 m .41829 .40824 L .42115 .41118 L 1 1 0 r
F
.42167 .40887 m .42115 .41118 L .42119 .41122 L F
.42131 .41127 m .42132 .41122 L .42114 .41123 L F
.42167 .40887 m .42116 .41115 L .42132 .41134 L .413 .14 0 r
F
.4397 .42315 m .42177 .40817 L .42167 .40887 L F
.42167 .40887 m .42178 .4081 L .42172 .4081 L 1 1 0 r
F
.42172 .40813 m .42152 .40797 L .42167 .40887 L .413 .14 0 r
F
.42148 .40872 m .42152 .40797 L .41468 .40333 L F
.42167 .40887 m .42172 .4081 L .41829 .40824 L 1 1 0 r
F
.42177 .40817 m .42172 .40813 L .42167 .40887 L .413 .14 0 r
F
.4397 .42315 m .4402 .42061 L .42172 .4081 L F
.42172 .40813 m .42172 .4081 L .42152 .40797 L F
.4397 .42315 m .42172 .4081 L .42172 .40813 L F
.42163 .40804 m .41555 .40016 L .41468 .40333 L .401 .131 0 r
F
.42164 .408 m .41555 .40016 L .42163 .40804 L F
.42227 .40573 m .41555 .40016 L .42172 .4081 L F
.42233 .40501 m .42233 .40498 L .42212 .40483 L F
.42233 .40501 m .42233 .40498 L .42233 .40501 L F
.42207 .40556 m .42212 .40483 L .41555 .40016 L F
.42227 .40573 m .42212 .40483 L .42207 .40556 L F
.43343 .40761 m .42233 .40574 L .42215 .40651 L 1 1 0 r
F
.43343 .40761 m .42215 .40651 L .4219 .40809 L F
.42233 .40574 m .41905 .40519 L .42178 .4081 L F
.42266 .4058 m .42233 .40498 L .42227 .40573 L F
.4402 .42061 m .42238 .40506 L .42227 .40573 L .401 .131 0 r
F
.42238 .40506 m .42212 .40483 L .42227 .40573 L F
.4219 .40809 m .42215 .40651 L .42178 .4081 L 1 1 0 r
F
.42224 .40492 m .41644 .39699 L .41555 .40016 L .39 .121 0 r
F
.42225 .40487 m .41644 .39699 L .42224 .40492 L F
.42291 .4026 m .41644 .39699 L .42233 .40498 L F
.43391 .40426 m .42297 .40261 L .42278 .40336 L 1 1 0 r
F
.42251 .40497 m .42278 .40336 L .42238 .40498 L F
.43391 .40426 m .42278 .40336 L .42251 .40497 L F
.42291 .4026 m .42252 .40154 L .42248 .40223 L .39 .121 0 r
F
.42297 .40261 m .41984 .40214 L .42238 .40498 L 1 1 0 r
F
.43391 .40426 m .43441 .40089 L .42297 .40187 L F
.42296 .40194 m .42252 .40154 L .42291 .4026 L .39 .121 0 r
F
.42248 .40223 m .42252 .40154 L .41644 .39699 L F
.42291 .4026 m .42297 .40187 L .41984 .40214 L 1 1 0 r
F
.43391 .40426 m .42297 .40187 L .42291 .4026 L F
.42301 .40199 m .42296 .40194 L .42291 .4026 L .39 .121 0 r
F
.44071 .41808 m .42301 .40199 L .42291 .4026 L F
.44071 .41808 m .44123 .41556 L .42297 .40187 L F
.42296 .40194 m .42297 .40187 L .42252 .40154 L F
.44071 .41808 m .42297 .40187 L .42296 .40194 L F
.42297 .40187 m .42064 .39911 L .41984 .40214 L 1 1 0 r
F
.42297 .40187 m .4235 .39943 L .42287 .40181 L .38 .111 0 r
F
.42302 .40187 m .42298 .40182 L .42297 .40187 L 1 1 0 r
F
.43441 .40089 m .42362 .3995 L .42344 .40022 L F
.42315 .40186 m .42344 .40022 L .42302 .40187 L F
.43441 .40089 m .42344 .40022 L .42315 .40186 L F
.42357 .39949 m .42316 .39845 L .42312 .39908 L .38 .111 0 r
F
.42357 .39949 m .4235 .39943 L .42297 .40187 L F
.4235 .39943 m .41735 .39383 L .42287 .40181 L F
.42362 .3995 m .42064 .39911 L .42302 .40187 L 1 1 0 r
F
.43441 .40089 m .43492 .39752 L .42363 .39878 L F
.42362 .39888 m .42316 .39845 L .42357 .39949 L .38 .111 0 r
F
.42357 .39949 m .42363 .39878 L .42064 .39911 L 1 1 0 r
F
.43441 .40089 m .42363 .39878 L .42357 .39949 L F
.42367 .39893 m .42362 .39888 L .42357 .39949 L .38 .111 0 r
F
.44123 .41556 m .42367 .39893 L .42357 .39949 L F
.44123 .41556 m .42357 .39949 L .42297 .40187 L F
.42298 .40182 m .42298 .40182 L .42297 .40187 L 1 1 0 r
F
.42298 .40182 m .42064 .39911 L .42297 .40187 L F
.42233 .40498 m .42225 .40487 L .42224 .40492 L .39 .121 0 r
F
.42238 .40498 m .42234 .40493 L .42233 .40498 L 1 1 0 r
F
.44071 .41808 m .42291 .4026 L .42233 .40498 L .39 .121 0 r
F
.42234 .40493 m .42234 .40493 L .42233 .40498 L 1 1 0 r
F
.42233 .40498 m .41984 .40214 L .41905 .40519 L F
.42234 .40493 m .41984 .40214 L .42233 .40498 L F
.42172 .4081 m .42164 .408 L .42163 .40804 L .401 .131 0 r
F
.42178 .4081 m .42173 .40805 L .42172 .4081 L 1 1 0 r
F
.42232 .40814 m .42233 .40807 L .4221 .40808 L F
.4221 .40814 m .4221 .40808 L .4219 .40809 L F
.4219 .40813 m .4219 .40809 L .42178 .4081 L F
.4402 .42061 m .42227 .40573 L .42172 .4081 L .401 .131 0 r
F
.42173 .40805 m .42173 .40805 L .42172 .4081 L 1 1 0 r
F
.42172 .4081 m .41905 .40519 L .41829 .40824 L F
.42173 .40805 m .41905 .40519 L .42172 .4081 L F
.42114 .41123 m .41829 .40824 L .41755 .41131 L F
.42119 .41122 m .42115 .41118 L .42114 .41123 L F
.42132 .41134 m .42116 .41115 L .42114 .41123 L .413 .14 0 r
F
.42116 .41115 m .42115 .41114 L .42114 .41123 L F
.42115 .41118 m .42115 .41118 L .42114 .41123 L 1 1 0 r
F
.42115 .41118 m .41829 .40824 L .42114 .41123 L F
.42059 .41436 m .4205 .41426 L .4205 .4143 L .424 .149 0 r
F
.42064 .41436 m .4206 .41431 L .42059 .41436 L 1 1 0 r
F
.42075 .41446 m .4206 .41429 L .42059 .41436 L .424 .149 0 r
F
.42059 .41436 m .41755 .41131 L .41682 .41438 L 1 1 0 r
F
.4206 .41431 m .41755 .41131 L .42059 .41436 L F
.41996 .41832 m .42006 .4175 L .41612 .41746 L F
.42001 .41833 m .42006 .4175 L .41996 .41832 L F
.43826 .43086 m .42001 .41833 L .41971 .42073 L .446 .164 0 r
F
.43921 .42571 m .4397 .42315 L .4212 .41127 L .424 .149 0 r
F
.43921 .42571 m .4212 .41127 L .4212 .41133 L F
.42109 .41201 m .42114 .41123 L .42104 .412 L 1 1 0 r
F
.43921 .42571 m .42109 .41201 L .42075 .41446 L .424 .149 0 r
F
.42104 .412 m .42114 .41123 L .41755 .41131 L 1 1 0 r
F
.4402 .42061 m .44071 .41808 L .42233 .40498 L .401 .131 0 r
F
.4402 .42061 m .42233 .40498 L .42233 .40501 L F
.42227 .40573 m .42233 .40498 L .41905 .40519 L 1 1 0 r
F
.42312 .39908 m .42292 .39822 L .42288 .39886 L .38 .111 0 r
F
.42316 .39845 m .42292 .39822 L .42312 .39908 L F
.44176 .41306 m .42425 .39639 L .42363 .39878 L .918 .067 0 r
F
.42377 .39825 m .42425 .39639 L .42405 .39654 L 1 1 0 r
F
.42361 .39887 m .42363 .39878 L .42292 .39822 L .38 .111 0 r
F
.42288 .39886 m .42292 .39822 L .41735 .39383 L F
.42363 .39878 m .42405 .39654 L .42064 .39911 L 1 1 0 r
F
.42368 .39877 m .42405 .39654 L .42363 .39878 L F
.44123 .41556 m .44176 .41306 L .42363 .39878 L .38 .111 0 r
F
.44123 .41556 m .42363 .39878 L .42361 .39887 L F
.4397 .42315 m .42167 .40887 L .42132 .41134 L .413 .14 0 r
F
.42425 .39639 m .42147 .39609 L .4213 .39671 L 1 1 0 r
F
.42425 .39639 m .4213 .39671 L .42064 .39911 L F
.42466 .39677 m .42507 .39629 L .42425 .39639 L .918 .067 0 r
F
.43605 .39468 m .43532 .39493 L .43492 .39752 L 1 1 0 r
F
.45063 .39705 m .45086 .39314 L .43492 .39752 L F
.44176 .41306 m .43532 .39493 L .42466 .39677 L .918 .067 0 r
F
.4383 .39394 m .43544 .39412 L .43816 .39663 L 1 1 0 r
F
.4383 .39394 m .43532 .39493 L .43535 .39503 L .208 .049 0 r
F
.43605 .39468 m .43544 .39412 L .43532 .39493 L 1 1 0 r
F
.45086 .39314 m .4383 .39394 L .43816 .39663 L F
.43834 .39399 m .43831 .39366 L .4383 .39394 L .208 .049 0 r
F
.43831 .39366 m .43827 .39323 L .4383 .39394 L F
.45578 .41405 m .43837 .39335 L .43834 .39399 L F
.43837 .39335 m .43827 .39323 L .43834 .39399 L F
.45578 .41405 m .45608 .41152 L .43839 .39335 L F
.45086 .39314 m .43827 .39323 L .43828 .39334 L 1 1 0 r
F
.43839 .39337 m .43839 .39335 L .43827 .39323 L .208 .049 0 r
F
.45578 .41405 m .43839 .39335 L .43839 .39337 L F
.45578 .41405 m .4383 .39394 L .44176 .41306 L F
.4383 .39394 m .43535 .39503 L .44176 .41306 L F
.4383 .39394 m .43791 .39334 L .43787 .39397 L 1 1 0 r
F
.43827 .39323 m .43597 .39072 L .43544 .39412 L F
.45109 .38916 m .4387 .39044 L .43855 .39314 L F
.494 .39527 m .46928 .39717 L .46924 .40178 L 1 .766 0 r
F
.46947 .39858 m .4504 .40091 L .45017 .4047 L 1 .904 0 r
F
.49401 .40042 m .494 .39527 L .46924 .40178 L 1 .762 0 r
F
.46943 .40296 m .46947 .39858 L .45017 .4047 L 1 .902 0 r
F
.45109 .38916 m .45133 .38511 L .43867 .38973 L 1 1 0 r
F
.43843 .39011 m .43841 .38944 L .43325 .38382 L .196 .046 0 r
F
.45109 .38916 m .43867 .38973 L .4387 .39044 L 1 1 0 r
F
.45608 .41152 m .43841 .38944 L .43843 .39011 L .196 .046 0 r
F
.43855 .39314 m .43849 .3918 L .43827 .39323 L 1 1 0 r
F
.4387 .39044 m .43843 .39011 L .43827 .39323 L .196 .046 0 r
F
.4387 .39044 m .43843 .39046 L .43855 .39314 L 1 1 0 r
F
.45608 .41152 m .4387 .39044 L .43827 .39323 L .196 .046 0 r
F
.43849 .3918 m .43843 .39046 L .43827 .39323 L 1 1 0 r
F
.4387 .39044 m .43867 .38973 L .43597 .39072 L F
.43873 .38985 m .43873 .3898 L .43867 .38973 L .196 .046 0 r
F
.43867 .38978 m .43867 .38973 L .43841 .38944 L F
.43873 .38985 m .43867 .38973 L .43867 .38978 L F
.45608 .41152 m .45637 .40901 L .43873 .3898 L F
.45608 .41152 m .43873 .3898 L .43873 .38985 L F
.43827 .39323 m .4382 .3931 L .4382 .39315 L F
.43843 .39046 m .43597 .39072 L .43827 .39323 L 1 1 0 r
F
.43828 .39334 m .43827 .39323 L .43827 .39334 L F
.494 .39527 m .49399 .38996 L .46928 .39717 L 1 .766 0 r
F
.46947 .39858 m .46951 .39408 L .4504 .40091 L 1 .904 0 r
F
.45133 .38511 m .45157 .38097 L .43909 .38621 L 1 1 0 r
F
.43912 .38691 m .43909 .38621 L .43384 .38015 L .183 .044 0 r
F
.43912 .38691 m .43909 .38621 L .43652 .38729 L 1 1 0 r
F
.45133 .38511 m .43909 .38621 L .43912 .38691 L F
.43912 .38691 m .43915 .38628 L .43909 .38621 L .183 .044 0 r
F
.45637 .40901 m .45667 .40652 L .43915 .38628 L F
.43918 .3869 m .43652 .38729 L .43874 .38971 L 1 1 0 r
F
.45637 .40901 m .43915 .38628 L .43912 .38691 L .183 .044 0 r
F
.43955 .38335 m .43944 .38257 L .4394 .38316 L .169 .041 0 r
F
.45157 .38097 m .45181 .37674 L .43952 .38266 L 1 1 0 r
F
.43952 .38268 m .43944 .38257 L .43955 .38335 L .169 .041 0 r
F
.45157 .38097 m .43952 .38266 L .43955 .38335 L 1 1 0 r
F
.44047 .38371 m .44016 .38323 L .44013 .3838 L F
.44016 .38323 m .43984 .38329 L .44013 .3838 L F
.45667 .40652 m .45697 .40404 L .43944 .38257 L .169 .041 0 r
F
.43955 .38335 m .43952 .38266 L .43707 .38384 L 1 1 0 r
F
.43958 .38277 m .43952 .38268 L .43955 .38335 L .169 .041 0 r
F
.45728 .40158 m .44044 .37615 L .43996 .37908 L .14 .036 0 r
F
.43997 .37899 m .43997 .37898 L .43996 .37908 L 1 1 0 r
F
.43996 .37908 m .43972 .37869 L .43968 .37924 L F
.43997 .37898 m .43972 .37869 L .43996 .37908 L F
.45205 .37239 m .45228 .36792 L .44041 .37547 L F
.44038 .37617 m .44041 .37547 L .4382 .37687 L F
.45205 .37239 m .44041 .37547 L .44038 .37617 L F
.44041 .37547 m .43928 .36993 L .43907 .37361 L .125 .033 0 r
F
.45228 .36792 m .44091 .37248 L .44041 .37547 L 1 .995 0 r
F
.4409 .37254 m .44056 .372 L .44041 .37547 L .125 .033 0 r
F
.44971 .38654 m .43625 .36505 L .45619 .39719 L F
.44091 .37248 m .44062 .3726 L .44041 .37547 L 1 .995 0 r
F
.44178 .37572 m .4405 .37613 L .44175 .37621 L 1 1 0 r
F
.45619 .39719 m .4409 .37254 L .44041 .37547 L .125 .033 0 r
F
.44056 .372 m .43928 .36993 L .44041 .37547 L F
.44044 .37615 m .44048 .37556 L .44041 .37547 L .14 .036 0 r
F
.44041 .37547 m .43878 .37334 L .4382 .37687 L 1 .995 0 r
F
.43907 .37361 m .43625 .36505 L .43564 .3689 L .125 .033 0 r
F
.43928 .36993 m .43625 .36505 L .43907 .37361 L F
.44062 .3726 m .43878 .37334 L .44041 .37547 L 1 .995 0 r
F
.44091 .37248 m .44088 .37181 L .43878 .37334 L F
.45228 .36792 m .44088 .37181 L .44091 .37248 L F
.44107 .37274 m .44088 .37181 L .44091 .37248 L .125 .033 0 r
F
.44107 .37274 m .4411 .37213 L .44088 .37181 L F
.44138 .36877 m .43687 .36113 L .44126 .37236 L .109 .03 0 r
F
.44138 .36877 m .44109 .36892 L .44088 .37181 L 1 .981 0 r
F
.44088 .37181 m .43687 .36113 L .43625 .36505 L .109 .03 0 r
F
.44093 .37151 m .43687 .36113 L .44088 .37181 L F
.44109 .36892 m .43936 .36976 L .44088 .37181 L 1 .981 0 r
F
.44138 .36877 m .44135 .36809 L .43936 .36976 L F
.44187 .365 m .44183 .36432 L .43996 .36614 L 1 .963 0 r
F
.44187 .365 m .44191 .36445 L .44183 .36432 L .093 .027 0 r
F
.44212 .36545 m .44191 .36445 L .44187 .365 L F
.45856 .39188 m .45889 .3895 L .44266 .36106 L .077 .023 0 r
F
.45856 .39188 m .44266 .36106 L .44262 .36165 L F
.44055 .37631 m .44059 .37571 L .44048 .37556 L .14 .036 0 r
F
.44055 .37631 m .44048 .37556 L .44044 .37615 L F
.45823 .39428 m .45856 .39188 L .44215 .36485 L .093 .027 0 r
F
.45823 .39428 m .44215 .36485 L .44212 .36545 L F
.44119 .38354 m .44085 .38309 L .44082 .38363 L 1 1 0 r
F
.44122 .38302 m .44085 .38309 L .44119 .38354 L F
.44085 .38309 m .4405 .38316 L .44082 .38363 L F
.45791 .3967 m .45823 .39428 L .44162 .36851 L .109 .03 0 r
F
.45791 .3967 m .44162 .36851 L .44159 .36912 L F
.4576 .39913 m .45791 .3967 L .4411 .37213 L .125 .033 0 r
F
.4576 .39913 m .4411 .37213 L .44107 .37274 L F
.4405 .38316 m .44016 .38323 L .44047 .38371 L 1 1 0 r
F
.45728 .40158 m .4576 .39913 L .44059 .37571 L .14 .036 0 r
F
.45728 .40158 m .44059 .37571 L .44055 .37631 L F
.45697 .40404 m .45728 .40158 L .44008 .37924 L .155 .039 0 r
F
.45697 .40404 m .44008 .37924 L .44005 .37985 L F
.43981 .38388 m .43961 .38334 L .43951 .38395 L 1 1 0 r
F
.43984 .38329 m .43961 .38334 L .43981 .38388 L F
.43938 .38609 m .43951 .38395 L .43915 .38618 L F
.43961 .38334 m .43707 .38384 L .43915 .38618 L F
.45667 .40652 m .43958 .38277 L .43955 .38335 L .169 .041 0 r
F
.43968 .37924 m .4382 .37687 L .43763 .38037 L 1 1 0 r
F
.43972 .37869 m .4382 .37687 L .43968 .37924 L F
.43952 .38266 m .43945 .38251 L .43944 .38257 L .155 .039 0 r
F
.43958 .38263 m .43953 .38258 L .43952 .38266 L 1 1 0 r
F
.44005 .37975 m .43763 .38037 L .43958 .38263 L F
.45697 .40404 m .43999 .37977 L .43952 .38266 L .155 .039 0 r
F
.43952 .38266 m .43763 .38037 L .43707 .38384 L 1 1 0 r
F
.43953 .38258 m .43763 .38037 L .43952 .38266 L F
.43909 .38621 m .43902 .38607 L .43901 .38612 L .169 .041 0 r
F
.43915 .38618 m .4391 .38613 L .43909 .38621 L 1 1 0 r
F
.45667 .40652 m .43955 .38335 L .43909 .38621 L .169 .041 0 r
F
.43909 .38621 m .43707 .38384 L .43652 .38729 L 1 1 0 r
F
.4391 .38613 m .43707 .38384 L .43909 .38621 L F
.43867 .38973 m .43861 .3896 L .4386 .38965 L .183 .044 0 r
F
.43874 .38971 m .43869 .38965 L .43867 .38973 L 1 1 0 r
F
.45637 .40901 m .43912 .38691 L .43867 .38973 L .183 .044 0 r
F
.43867 .38973 m .43652 .38729 L .43597 .39072 L 1 1 0 r
F
.43869 .38965 m .43652 .38729 L .43867 .38973 L F
.43827 .39334 m .43827 .39323 L .43791 .39334 L F
.43787 .39397 m .43791 .39334 L .43544 .39412 L F
.4576 .39913 m .44971 .38654 L .45619 .39719 L .125 .033 0 r
F
.43444 .37644 m .42209 .3782 L .42111 .38131 L 1 1 0 r
F
.43444 .37644 m .43504 .37269 L .42209 .3782 L F
.43504 .37269 m .42308 .3751 L .42209 .3782 L F
.43504 .37269 m .43564 .3689 L .42308 .3751 L F
.43564 .3689 m .42408 .372 L .42308 .3751 L F
.4361 .36599 m .43625 .36505 L .42775 .36991 L F
.36661 .30768 m .36577 .31041 L .36572 .31076 L .867 .059 0 r
F
.36754 .30469 m .36734 .30463 L .36573 .31069 L 1 .973 0 r
F
.36572 .31076 m .36734 .30463 L .3655 .31073 L F
.36573 .31069 m .36734 .30463 L .36572 .31076 L F
.36679 .30369 m .33612 .29617 L .34669 .2997 L 1 1 0 r
F
.36601 .30624 m .36679 .30369 L .34669 .2997 L F
.36734 .30463 m .36349 .29662 L .36164 .30152 L 1 .85 0 r
F
.36734 .30463 m .36164 .30152 L .33652 .29878 L F
.36164 .30152 m .33612 .29617 L .33652 .29878 L F
.36164 .30152 m .33804 .29156 L .33612 .29617 L 1 1 0 r
F
.36571 .3108 m .36572 .31076 L .36492 .3098 L .201 .035 0 r
F
.3655 .31073 m .36734 .30463 L .33652 .29878 L 1 1 0 r
F
.41908 .38053 m .34654 .27539 L .34397 .28117 L .279 .049 0 r
F
.43267 .38747 m .43325 .38382 L .4192 .38755 L 1 1 0 r
F
.43325 .38382 m .42015 .38443 L .4192 .38755 L F
.43325 .38382 m .43384 .38015 L .42015 .38443 L F
.43384 .38015 m .42111 .38131 L .42015 .38443 L F
.43384 .38015 m .43444 .37644 L .42111 .38131 L F
.39993 .30891 m .36941 .29863 L .36755 .30465 L 1 .978 0 r
F
.39993 .30891 m .40123 .30274 L .36921 .29856 L F
.40123 .30274 m .37111 .29253 L .36921 .29856 L 1 .983 0 r
F
.40123 .30274 m .40254 .2966 L .37111 .29253 L F
.40254 .2966 m .37305 .28654 L .37111 .29253 L 1 .988 0 r
F
.4227 .37199 m .35447 .25833 L .35179 .26397 L 1 .107 0 r
F
.42271 .37198 m .35447 .25833 L .4227 .37199 L F
.42308 .37208 m .35447 .25833 L .42294 .37236 L F
.42202 .37509 m .4229 .37231 L .35179 .26397 L .271 .048 0 r
F
.36755 .30465 m .36921 .29856 L .36734 .30463 L 1 .978 0 r
F
.36941 .29863 m .36921 .29856 L .36755 .30465 L F
.36734 .30463 m .36921 .29856 L .36349 .29662 L 1 .85 0 r
F
.42079 .37786 m .42186 .37536 L .34915 .26965 L .275 .048 0 r
F
.42098 .37814 m .42173 .37579 L .42079 .37786 L F
.42173 .37579 m .42186 .37536 L .42079 .37786 L F
.42209 .3782 m .42308 .3751 L .42192 .3754 L 1 1 0 r
F
.42209 .3782 m .42192 .3754 L .4219 .37546 L F
.42209 .3782 m .4219 .37541 L .42101 .37818 L F
.42111 .38131 m .42209 .3782 L .42088 .37846 L F
.42101 .37818 m .42186 .37536 L .42098 .37814 L .275 .048 0 r
F
.42209 .3782 m .42101 .37818 L .42088 .37846 L 1 1 0 r
F
.42496 .38414 m .42203 .37584 L .42101 .37818 L .275 .048 0 r
F
.42203 .37584 m .42186 .37536 L .42101 .37818 L F
.41996 .38121 m .42083 .37842 L .34654 .27539 L .279 .049 0 r
F
.42111 .38131 m .42088 .37846 L .42087 .37851 L 1 1 0 r
F
.42111 .38131 m .42086 .37847 L .41999 .38124 L F
.42015 .38443 m .42111 .38131 L .41986 .38153 L F
.36392 .31689 m .3655 .31073 L .3637 .31686 L 1 .967 0 r
F
.36394 .31683 m .3655 .31073 L .36392 .31689 L F
.36216 .32306 m .3637 .31686 L .36193 .32303 L 1 .962 0 r
F
.36391 .31693 m .3637 .31686 L .36216 .32306 L F
.36193 .32303 m .3637 .31686 L .33177 .31073 L 1 1 0 r
F
.3637 .31686 m .33412 .30473 L .33177 .31073 L F
.3637 .31686 m .3655 .31073 L .33412 .30473 L F
.3655 .31073 m .33652 .29878 L .33412 .30473 L F
.43267 .38747 m .4192 .38755 L .41827 .39069 L F
.41763 .38746 m .34145 .28699 L .33896 .29286 L .286 .05 0 r
F
.41764 .38744 m .34145 .28699 L .41763 .38746 L F
.41796 .38737 m .34145 .28699 L .41784 .3877 L F
.41644 .39699 m .40427 .39454 L .40305 .39739 L 1 1 0 r
F
.41644 .39699 m .41735 .39383 L .40427 .39454 L F
.41735 .39383 m .40551 .39172 L .40427 .39454 L F
.41735 .39383 m .41795 .39177 L .40551 .39172 L F
.41822 .39036 m .41784 .3877 L .41699 .39049 L F
.41827 .39069 m .4192 .38755 L .41786 .3877 L F
.41784 .38774 m .41786 .3877 L .41784 .3877 L F
.41827 .39069 m .41786 .3877 L .41784 .38774 L F
.41778 .38714 m .4188 .38457 L .34145 .28699 L .286 .05 0 r
F
.41796 .38737 m .41865 .38505 L .41778 .38714 L F
.41865 .38505 m .4188 .38457 L .41778 .38714 L F
.41883 .38461 m .34397 .28117 L .34145 .28699 L .282 .05 0 r
F
.41912 .38433 m .41898 .38431 L .419 .38459 L 1 1 0 r
F
.41898 .38431 m .41896 .38434 L .419 .38459 L F
.41896 .38431 m .41885 .38457 L .419 .38459 L F
.419 .38459 m .41885 .38457 L .41883 .38461 L F
.42015 .38443 m .41912 .38433 L .419 .38459 L F
.36572 .31074 m .36572 .31076 L .36572 .31076 L .867 .059 0 r
F
.36571 .3108 m .36572 .31076 L .3655 .31073 L 1 .967 0 r
F
.36571 .3108 m .36572 .31076 L .36572 .31076 L .201 .035 0 r
F
.41895 .38428 m .41981 .38149 L .34397 .28117 L .282 .05 0 r
F
.4192 .38755 m .42015 .38443 L .41885 .38461 L 1 1 0 r
F
.42015 .38443 m .41986 .38153 L .41985 .38158 L F
.41898 .38431 m .41983 .38156 L .41895 .38428 L .282 .05 0 r
F
.41984 .38156 m .41983 .38156 L .41898 .38431 L F
.41983 .38156 m .41967 .38195 L .41895 .38428 L F
.41898 .38431 m .34397 .28117 L .41883 .38461 L F
.41898 .38431 m .41984 .38153 L .41883 .3843 L 1 1 0 r
F
.42015 .38443 m .41984 .38153 L .41898 .38431 L F
.42318 .39009 m .41984 .38156 L .41898 .38431 L .282 .05 0 r
F
.41983 .38156 m .41981 .38149 L .41967 .38195 L F
.41999 .38124 m .41992 .38138 L .41986 .38153 L 1 1 0 r
F
.41997 .38124 m .41985 .38153 L .41986 .38153 L F
.41986 .38153 m .41985 .38153 L .41984 .38153 L F
.42111 .38131 m .41999 .38124 L .41986 .38153 L F
.42406 .38711 m .41999 .38124 L .41984 .38153 L .279 .049 0 r
F
.41999 .38124 m .41996 .38121 L .41984 .38153 L F
.41999 .38124 m .41997 .38124 L .41992 .38138 L 1 1 0 r
F
.41983 .38156 m .41984 .38153 L .41981 .38149 L .282 .05 0 r
F
.4168 .39025 m .4178 .38766 L .33896 .29286 L .29 .051 0 r
F
.41697 .39046 m .41765 .38815 L .4168 .39025 L F
.41765 .38815 m .4178 .38766 L .4168 .39025 L F
.42147 .39609 m .42231 .39308 L .4178 .38766 L F
.41795 .39177 m .41827 .39069 L .41687 .3908 L 1 1 0 r
F
.41827 .39069 m .41822 .39036 L .41699 .39049 L F
.41699 .39049 m .4178 .38766 L .41697 .39046 L .29 .051 0 r
F
.41827 .39069 m .41699 .39049 L .41687 .3908 L 1 1 0 r
F
.42147 .39609 m .41796 .38802 L .41699 .39049 L .29 .051 0 r
F
.41796 .38802 m .4178 .38766 L .41699 .39049 L F
.35874 .33553 m .35711 .34165 L .3571 .34176 L .213 .037 0 r
F
.3571 .3417 m .35849 .33545 L .35813 .33682 L 1 .946 0 r
F
.35711 .34168 m .35849 .33545 L .3571 .3417 L F
.35709 .34174 m .35711 .34168 L .3571 .3417 L F
.3571 .34176 m .35779 .33455 L .35609 .34081 L .213 .037 0 r
F
.35709 .34174 m .35813 .33682 L .35683 .34171 L 1 .946 0 r
F
.35709 .34174 m .35813 .33682 L .35709 .34174 L F
.35869 .33549 m .3587 .33545 L .35779 .33455 L .213 .037 0 r
F
.35874 .33553 m .35874 .33549 L .35873 .33553 L 1 .946 0 r
F
.36037 .32924 m .36038 .3292 L .35953 .32832 L .21 .037 0 r
F
.35873 .33553 m .35874 .33549 L .35849 .33545 L 1 .946 0 r
F
.36043 .3293 m .36044 .32926 L .3602 .32923 L 1 .952 0 r
F
.32974 .29595 m .32932 .29566 L .32926 .29575 L 1 .562 0 r
F
.33652 .29878 m .33038 .29481 L .32974 .29595 L F
.33038 .29481 m .33035 .29479 L .32974 .29595 L 1 1 0 r
F
.32974 .29595 m .30957 .28403 L .30653 .28979 L F
.33035 .29479 m .30957 .28403 L .32974 .29595 L F
.32772 .30069 m .32974 .29595 L .30653 .28979 L F
.33412 .30473 m .33652 .29878 L .32974 .29595 L 1 .865 0 r
F
.33412 .30473 m .32974 .29595 L .32963 .2962 L F
.32713 .30196 m .32716 .30188 L .32708 .30186 L 1 1 0 r
F
.32697 .30211 m .32708 .30186 L .32676 .30173 L 1 .865 0 r
F
.32509 .3066 m .32708 .30186 L .30354 .2956 L 1 1 0 r
F
.33177 .31073 m .33412 .30473 L .32708 .30186 L 1 .865 0 r
F
.33177 .31073 m .32708 .30186 L .32697 .30211 L F
.35704 .34175 m .35705 .3417 L .35609 .34081 L .216 .038 0 r
F
.35442 .3471 m .35609 .34081 L .3216 .33392 L 1 .983 0 r
F
.35683 .34171 m .35849 .33545 L .32498 .32895 L 1 .991 0 r
F
.35849 .33545 m .3272 .32284 L .32498 .32895 L 1 .997 0 r
F
.35849 .33545 m .3602 .32923 L .3272 .32284 L F
.3602 .32923 m .32946 .31677 L .3272 .32284 L 1 1 0 r
F
.3602 .32923 m .36193 .32303 L .32946 .31677 L F
.36193 .32303 m .33177 .31073 L .32946 .31677 L F
.40462 .39141 m .33896 .29286 L .31098 .28575 L .91 .064 0 r
F
.40561 .39144 m .33896 .29286 L .40462 .39141 L F
.41699 .39049 m .33896 .29286 L .40562 .39146 L .29 .051 0 r
F
.41687 .3908 m .41577 .39059 L .40562 .39146 L 1 1 0 r
F
.40811 .39151 m .40562 .39146 L .40551 .39172 L F
.41687 .3908 m .40562 .39146 L .40811 .39151 L F
.41699 .39049 m .40677 .38892 L .41687 .3908 L F
.41699 .39049 m .40562 .39146 L .40576 .39167 L .29 .051 0 r
F
.41577 .39059 m .40677 .38892 L .40562 .39146 L 1 1 0 r
F
.35543 .34799 m .35695 .34166 L .35543 .34799 L .216 .038 0 r
F
.35547 .34803 m .35584 .34643 L .35543 .34799 L F
.35584 .34643 m .35695 .34166 L .35543 .34799 L F
.35708 .34179 m .35695 .34166 L .35547 .34803 L F
.35708 .34179 m .35683 .34171 L .35549 .34797 L 1 .941 0 r
F
.32435 .30806 m .32445 .30781 L .32413 .30768 L 1 .865 0 r
F
.32249 .31255 m .32445 .30781 L .3006 .30146 L 1 1 0 r
F
.3245 .30791 m .32452 .30783 L .32445 .30781 L F
.32946 .31677 m .33177 .31073 L .32445 .30781 L 1 .865 0 r
F
.32946 .31677 m .32445 .30781 L .32435 .30806 L F
.32189 .31388 m .32191 .31382 L .32184 .3138 L 1 1 0 r
F
.32174 .31404 m .32184 .3138 L .32152 .31367 L 1 .864 0 r
F
.31991 .31853 m .32184 .3138 L .29772 .30736 L 1 1 0 r
F
.3272 .32284 m .32946 .31677 L .32184 .3138 L 1 .864 0 r
F
.3272 .32284 m .32184 .3138 L .32174 .31404 L F
.35384 .35429 m .35442 .3471 L .35278 .35342 L .218 .038 0 r
F
.35278 .35342 m .35442 .3471 L .31942 .34012 L 1 .978 0 r
F
.35442 .3471 m .3216 .33392 L .31942 .34012 L 1 .983 0 r
F
.3552 .34799 m .35683 .34171 L .3228 .3351 L 1 .986 0 r
F
.35683 .34171 m .32498 .32895 L .3228 .3351 L 1 .991 0 r
F
.40306 .39431 m .30796 .29145 L .305 .29721 L .382 .068 0 r
F
.40307 .3943 m .30796 .29145 L .40306 .39431 L F
.40335 .39422 m .30796 .29145 L .40322 .39446 L F
.35464 .35134 m .3552 .34799 L .355 .34878 L 1 .936 0 r
F
.35475 .35091 m .3552 .34799 L .35464 .35134 L F
.35389 .35434 m .35422 .35287 L .35384 .3543 L .218 .038 0 r
F
.35389 .35434 m .355 .34878 L .3536 .3543 L 1 .936 0 r
F
.32498 .32895 m .3272 .32284 L .31942 .31987 L 1 .863 0 r
F
.35278 .35342 m .31942 .34012 L .31729 .34634 L 1 .978 0 r
F
.3536 .3543 m .3552 .34799 L .32068 .34127 L 1 .981 0 r
F
.3552 .34799 m .3228 .3351 L .32068 .34127 L 1 .986 0 r
F
.41468 .40333 m .40185 .40027 L .40067 .40317 L 1 1 0 r
F
.41468 .40333 m .41555 .40016 L .40185 .40027 L F
.41555 .40016 m .40305 .39739 L .40185 .40027 L F
.4018 .39715 m .305 .29721 L .30209 .30302 L .386 .068 0 r
F
.40181 .39714 m .305 .29721 L .4018 .39715 L F
.40208 .39704 m .305 .29721 L .40195 .39729 L F
.402 .39721 m .40195 .39729 L .40195 .39729 L F
.40208 .39704 m .40195 .39729 L .402 .39721 L F
.40427 .39454 m .40551 .39172 L .40485 .39168 L 1 1 0 r
F
.40351 .39428 m .40336 .39423 L .40339 .39448 L F
.40322 .39446 m .40335 .39422 L .40322 .39446 L .382 .068 0 r
F
.40329 .39434 m .40335 .39422 L .40322 .39446 L F
.40322 .39446 m .40307 .3943 L .40306 .39431 L F
.40185 .40027 m .40305 .39739 L .40197 .39729 L 1 1 0 r
F
.40195 .39734 m .40197 .39729 L .40195 .39729 L F
.40185 .40027 m .40197 .39729 L .40195 .39734 L F
.40321 .39448 m .40322 .39446 L .40318 .39443 L .386 .068 0 r
F
.40208 .39704 m .40318 .39443 L .305 .29721 L F
.41555 .40016 m .41644 .39699 L .40305 .39739 L 1 1 0 r
F
.40209 .39705 m .40318 .39443 L .40208 .39704 L .386 .068 0 r
F
.40305 .39739 m .40209 .39705 L .40197 .39729 L 1 1 0 r
F
.40351 .39428 m .40485 .39168 L .40468 .39167 L F
.40336 .39423 m .40468 .39167 L .4045 .39166 L F
.40321 .39407 m .40447 .39162 L .30796 .29145 L .382 .068 0 r
F
.40334 .39422 m .40423 .39217 L .40321 .39407 L F
.40423 .39217 m .40447 .39162 L .40321 .39407 L F
.40449 .39168 m .4045 .39166 L .40447 .39162 L F
.40305 .39739 m .40427 .39454 L .40324 .39447 L 1 1 0 r
F
.40351 .39428 m .40468 .39167 L .40336 .39423 L F
.40427 .39454 m .40485 .39168 L .40351 .39428 L F
.40427 .39454 m .40351 .39428 L .40339 .39448 L F
.40759 .39879 m .40447 .39162 L .40334 .39422 L .382 .068 0 r
F
.31931 .3199 m .31933 .31983 L .31926 .31981 L 1 1 0 r
F
.31736 .32453 m .31926 .31981 L .29488 .31331 L F
.32383 .32776 m .31926 .31981 L .31736 .32453 L F
.31736 .32453 m .31942 .31987 L .31926 .31981 L 1 .863 0 r
F
.32383 .32776 m .29279 .3178 L .30453 .32261 L 1 1 0 r
F
.32294 .33021 m .32383 .32776 L .30453 .32261 L F
.32498 .32895 m .31942 .31987 L .31736 .32453 L 1 .863 0 r
F
.40052 .39958 m .4018 .39715 L .30209 .30302 L .391 .069 0 r
F
.4045 .39166 m .39565 .38854 L .39411 .3911 L 1 1 0 r
F
.35709 .34175 m .35705 .3417 L .35708 .34179 L .216 .038 0 r
F
.35708 .34179 m .35709 .34174 L .35683 .34171 L 1 .941 0 r
F
.40434 .3915 m .31098 .28575 L .30796 .29145 L .91 .064 0 r
F
.40435 .39149 m .31098 .28575 L .40434 .3915 L F
.40464 .39144 m .40463 .39142 L .4045 .39166 L F
.40463 .39142 m .31098 .28575 L .4045 .39166 L F
.40463 .39142 m .4045 .39166 L .4045 .39166 L F
.40677 .38892 m .40804 .38615 L .40748 .38614 L 1 1 0 r
F
.40609 .38871 m .40748 .38614 L .39722 .38602 L F
.40677 .38892 m .40748 .38614 L .40609 .38871 L F
.40598 .38889 m .39722 .38602 L .39565 .38854 L F
.40677 .38892 m .40609 .38871 L .40598 .38889 L F
.40609 .38871 m .39722 .38602 L .40598 .38889 L F
.4045 .39166 m .40435 .39149 L .40434 .3915 L .91 .064 0 r
F
.40468 .39167 m .40453 .39162 L .4045 .39166 L 1 1 0 r
F
.40871 .39603 m .40464 .39144 L .4045 .39166 L .91 .064 0 r
F
.40453 .39162 m .40453 .39162 L .4045 .39166 L 1 1 0 r
F
.40453 .39162 m .39565 .38854 L .4045 .39166 L F
.40336 .39423 m .4045 .39166 L .39411 .3911 L F
.40759 .39879 m .40871 .39603 L .4045 .39166 L .382 .068 0 r
F
.40759 .39879 m .4045 .39166 L .40449 .39168 L F
.40322 .39451 m .40324 .39447 L .40322 .39446 L 1 1 0 r
F
.40305 .39739 m .40324 .39447 L .40322 .39451 L F
.40321 .39449 m .40318 .39443 L .40209 .39705 L .386 .068 0 r
F
.32498 .32895 m .31736 .32453 L .2937 .32074 L 1 .863 0 r
F
.31736 .32453 m .29279 .3178 L .2937 .32074 L F
.31736 .32453 m .29488 .31331 L .29279 .3178 L 1 1 0 r
F
.3536 .3543 m .32068 .34127 L .3186 .34748 L 1 .981 0 r
F
.3228 .3351 m .32498 .32895 L .2937 .32074 L 1 1 0 r
F
.40083 .39989 m .4018 .39715 L .40052 .39958 L .391 .069 0 r
F
.40067 .40317 m .40185 .40027 L .40072 .40015 L 1 1 0 r
F
.40185 .40027 m .40194 .39767 L .40085 .3999 L F
.40194 .39767 m .40195 .39729 L .40085 .3999 L F
.41382 .40652 m .40067 .40317 L .39951 .40609 L F
.41382 .40652 m .41468 .40333 L .40067 .40317 L F
.40071 .40015 m .30209 .30302 L .29924 .30888 L .391 .069 0 r
F
.40071 .40015 m .30209 .30302 L .40071 .40015 L F
.40085 .3999 m .30209 .30302 L .40071 .40015 L F
.40072 .40015 m .40071 .40014 L .40071 .40015 L 1 1 0 r
F
.32068 .34127 m .3228 .3351 L .29102 .32674 L F
.3228 .3351 m .2937 .32074 L .29102 .32674 L F
.4007 .40051 m .40071 .40015 L .39961 .40277 L F
.40085 .3999 m .40083 .39989 L .40072 .40015 L F
.3996 .40276 m .40067 .40011 L .29924 .30888 L .395 .069 0 r
F
.39951 .40609 m .40067 .40317 L .39949 .40303 L 1 1 0 r
F
.40067 .40317 m .4007 .40051 L .39961 .40277 L F
.40067 .40317 m .40072 .40015 L .40071 .40019 L F
.41298 .40972 m .41382 .40652 L .39951 .40609 L F
.39947 .40302 m .29924 .30888 L .29644 .31478 L .395 .069 0 r
F
.39948 .40302 m .29924 .30888 L .39947 .40302 L F
.39961 .40277 m .29924 .30888 L .39948 .40302 L F
.39949 .40303 m .39948 .40302 L .39947 .40302 L 1 1 0 r
F
.41215 .41293 m .39837 .40904 L .39725 .41201 L F
.41215 .41293 m .41298 .40972 L .39837 .40904 L F
.41298 .40972 m .39951 .40609 L .39837 .40904 L F
.39725 .41201 m .39837 .40904 L .38532 .40713 L F
.39837 .40904 m .38672 .40438 L .38532 .40713 L F
.39837 .40904 m .39907 .40722 L .38672 .40438 L F
.3995 .4058 m .39947 .40302 L .3984 .40566 L F
.39961 .40277 m .3996 .40276 L .39949 .40303 L F
.39839 .40565 m .39944 .40299 L .29644 .31478 L .4 .07 0 r
F
.39907 .40722 m .39951 .40609 L .39828 .40593 L 1 1 0 r
F
.39951 .40609 m .3995 .4058 L .3984 .40566 L F
.39951 .40609 m .39949 .40303 L .39948 .40307 L F
.38597 .40395 m .38683 .40416 L .38595 .40394 L .705 .034 0 r
F
.38885 .40466 m .38684 .40417 L .38672 .40438 L 1 1 0 r
F
.39907 .40722 m .38885 .40466 L .38672 .40438 L F
.38532 .40713 m .38672 .40438 L .38602 .4042 L F
.28244 .32317 m .28254 .32296 L .28223 .32282 L 1 .885 0 r
F
.28038 .32756 m .28254 .32296 L .25987 .31512 L 1 1 0 r
F
.28259 .32307 m .28263 .32299 L .28254 .32296 L F
.2884 .33278 m .29102 .32674 L .28254 .32296 L 1 .885 0 r
F
.2884 .33278 m .28254 .32296 L .28244 .32317 L F
.27963 .32903 m .27966 .32896 L .27957 .32893 L 1 1 0 r
F
.27948 .32913 m .27957 .32893 L .27926 .3288 L 1 .884 0 r
F
.27745 .33352 m .27957 .32893 L .2567 .32103 L 1 1 0 r
F
.28584 .33885 m .2884 .33278 L .27957 .32893 L 1 .884 0 r
F
.28584 .33885 m .27957 .32893 L .27948 .32913 L F
.31459 .35998 m .31657 .35372 L .28334 .34497 L 1 1 0 r
F
.31657 .35372 m .28584 .33885 L .28334 .34497 L F
.31657 .35372 m .3186 .34748 L .28584 .33885 L F
.3186 .34748 m .2884 .33278 L .28584 .33885 L F
.3186 .34748 m .32068 .34127 L .2884 .33278 L F
.32068 .34127 m .29102 .32674 L .2884 .33278 L F
.38429 .4068 m .26499 .31081 L .26179 .31663 L .533 .148 0 r
F
.38429 .4068 m .26499 .31081 L .38429 .4068 L F
.38441 .40689 m .26499 .31081 L .38441 .40689 L F
.38454 .40669 m .26499 .31081 L .38441 .40689 L F
.38443 .4069 m .38454 .40669 L .38441 .40689 L 1 1 0 r
F
.38532 .40713 m .38454 .40669 L .38443 .4069 L F
.38454 .40669 m .38602 .4042 L .38586 .40416 L F
.38427 .40647 m .38574 .40407 L .26499 .31081 L .533 .148 0 r
F
.28553 .31702 m .28514 .31673 L .28508 .31682 L 1 .422 0 r
F
.2937 .32074 m .28632 .31574 L .28553 .31702 L F
.28632 .31574 m .28629 .31571 L .28553 .31702 L 1 1 0 r
F
.28553 .31702 m .26639 .30345 L .2631 .30926 L F
.28629 .31571 m .26639 .30345 L .28553 .31702 L F
.28333 .32163 m .28553 .31702 L .2631 .30926 L F
.29102 .32674 m .2937 .32074 L .28553 .31702 L 1 .885 0 r
F
.29102 .32674 m .28553 .31702 L .28543 .31723 L F
.38595 .40394 m .29644 .31478 L .26826 .30506 L .705 .034 0 r
F
.38683 .40416 m .29644 .31478 L .38595 .40394 L F
.39814 .40543 m .29644 .31478 L .38684 .40417 L .4 .07 0 r
F
.38612 .40404 m .38599 .40397 L .38602 .4042 L 1 1 0 r
F
.38586 .40416 m .26826 .30506 L .26499 .31081 L .705 .034 0 r
F
.38586 .40416 m .26826 .30506 L .38586 .40416 L F
.38599 .40397 m .26826 .30506 L .38587 .40417 L F
.38599 .40397 m .37708 .39905 L .38589 .40413 L 1 1 0 r
F
.38599 .40397 m .38589 .40413 L .38602 .4042 L F
.38587 .40417 m .38586 .40416 L .38586 .40416 L .705 .034 0 r
F
.38602 .4042 m .38589 .40413 L .38586 .40416 L 1 1 0 r
F
.38532 .40713 m .38602 .4042 L .38454 .40669 L F
.3903 .40759 m .38599 .40397 L .38587 .40417 L .705 .034 0 r
F
.38622 .4041 m .38816 .40166 L .38749 .4015 L 1 1 0 r
F
.38599 .40397 m .38749 .4015 L .37708 .39905 L F
.38622 .4041 m .38749 .4015 L .38599 .40397 L F
.38672 .40438 m .38684 .40417 L .38622 .4041 L F
.38684 .40417 m .38683 .40416 L .38597 .40395 L .705 .034 0 r
F
.38684 .40417 m .38816 .40166 L .38622 .4041 L 1 1 0 r
F
.3984 .40566 m .39814 .40543 L .38684 .40417 L .4 .07 0 r
F
.39828 .40593 m .39731 .40552 L .38684 .40417 L 1 1 0 r
F
.39828 .40593 m .38684 .40417 L .38885 .40466 L F
.3984 .40566 m .38816 .40166 L .39828 .40593 L F
.3984 .40566 m .38684 .40417 L .38693 .40426 L .4 .07 0 r
F
.39731 .40552 m .38816 .40166 L .38684 .40417 L 1 1 0 r
F
.38733 .40146 m .37878 .39653 L .37708 .39905 L F
.38816 .40166 m .38745 .40127 L .38733 .40146 L F
.38745 .40127 m .37878 .39653 L .38733 .40146 L F
.38443 .4066 m .38586 .40416 L .38574 .40407 L .533 .148 0 r
F
.38443 .4066 m .38574 .40407 L .38427 .40647 L F
.38454 .40669 m .38586 .40416 L .38443 .4066 L F
.38454 .40669 m .38453 .40669 L .38441 .40689 L 1 1 0 r
F
.38285 .40923 m .38429 .4068 L .26179 .31663 L .537 .151 0 r
F
.38394 .4099 m .38532 .40713 L .38441 .40689 L 1 1 0 r
F
.38312 .40944 m .38429 .4068 L .38285 .40923 L .537 .151 0 r
F
.38394 .4099 m .38441 .40689 L .38312 .40944 L 1 1 0 r
F
.39615 .415 m .38394 .4099 L .38258 .41271 L F
.39615 .415 m .39725 .41201 L .38394 .4099 L F
.39725 .41201 m .38532 .40713 L .38394 .4099 L F
.38258 .41271 m .38394 .4099 L .38313 .40969 L F
.27655 .33513 m .27664 .33494 L .27633 .3348 L 1 .882 0 r
F
.27456 .3395 m .27664 .33494 L .25359 .32699 L 1 1 0 r
F
.27669 .33503 m .27672 .33496 L .27664 .33494 L F
.28334 .34497 m .28584 .33885 L .27664 .33494 L 1 .882 0 r
F
.28334 .34497 m .27664 .33494 L .27655 .33513 L F
.27379 .34105 m .27382 .34099 L .27374 .34097 L 1 1 0 r
F
.28089 .35112 m .28334 .34497 L .27374 .34097 L 1 .881 0 r
F
.30918 .37152 m .31114 .36518 L .27649 .35601 L 1 1 0 r
F
.30726 .37788 m .30918 .37152 L .27407 .36225 L F
.30918 .37152 m .27649 .35601 L .27407 .36225 L F
.31077 .37259 m .31265 .36627 L .27851 .35731 L F
.31265 .36627 m .28089 .35112 L .27851 .35731 L F
.31265 .36627 m .31459 .35998 L .28089 .35112 L F
.31459 .35998 m .28334 .34497 L .28089 .35112 L F
.38146 .41236 m .25867 .3225 L .25562 .32842 L .541 .153 0 r
F
.38146 .41235 m .25867 .3225 L .38146 .41236 L F
.38158 .41244 m .25867 .3225 L .38158 .41244 L F
.38171 .41222 m .25867 .3225 L .38158 .41244 L F
.38159 .41244 m .38171 .41222 L .38158 .41244 L 1 1 0 r
F
.38258 .41271 m .38171 .41222 L .38159 .41244 L F
.38171 .41222 m .38313 .40969 L .38299 .40965 L F
.3816 .41214 m .38299 .40965 L .25867 .3225 L .541 .153 0 r
F
.38171 .41222 m .38299 .40965 L .3816 .41214 L F
.38171 .41222 m .3817 .41221 L .38158 .41244 L 1 1 0 r
F
.27366 .34116 m .27374 .34097 L .27343 .34084 L 1 .881 0 r
F
.2717 .34551 m .27374 .34097 L .25054 .33299 L 1 1 0 r
F
.28089 .35112 m .27374 .34097 L .27366 .34116 L 1 .881 0 r
F
.38007 .41483 m .38146 .41236 L .25562 .32842 L .545 .156 0 r
F
.38125 .41554 m .38258 .41271 L .38158 .41244 L 1 1 0 r
F
.38033 .41502 m .38146 .41236 L .38007 .41483 L .545 .156 0 r
F
.38125 .41554 m .38158 .41244 L .38033 .41502 L 1 1 0 r
F
.39403 .42104 m .38125 .41554 L .37994 .4184 L F
.39403 .42104 m .39508 .41801 L .38125 .41554 L F
.39508 .41801 m .38258 .41271 L .38125 .41554 L F
.37994 .4184 m .38125 .41554 L .3802 .41525 L F
.39299 .42409 m .37994 .4184 L .37866 .42128 L F
.37866 .42128 m .36747 .41482 L .36596 .41756 L F
.37866 .42128 m .37944 .41952 L .36747 .41482 L F
.37996 .41812 m .3802 .41525 L .37898 .41785 L F
.39299 .42409 m .39403 .42104 L .37994 .4184 L F
.30539 .38426 m .30726 .37788 L .27171 .36852 L 1 .995 0 r
F
.30726 .37788 m .27407 .36225 L .27171 .36852 L 1 1 0 r
F
.30894 .37892 m .31077 .37259 L .27619 .36352 L 1 .997 0 r
F
.31077 .37259 m .27851 .35731 L .27619 .36352 L 1 1 0 r
F
.27851 .35731 m .28089 .35112 L .24975 .34041 L F
.37897 .41784 m .38016 .41522 L .25265 .33439 L .549 .158 0 r
F
.37944 .41952 m .37994 .4184 L .37885 .41809 L 1 1 0 r
F
.37994 .4184 m .37996 .41812 L .37898 .41785 L F
.37898 .41785 m .38016 .41522 L .37897 .41784 L .549 .158 0 r
F
.38441 .42144 m .38025 .41535 L .37898 .41785 L F
.38025 .41535 m .38016 .41522 L .37898 .41785 L F
.36682 .41434 m .36756 .41464 L .36681 .41433 L .533 0 0 r
F
.37944 .41952 m .36926 .41534 L .36747 .41482 L 1 1 0 r
F
.36756 .41464 m .25265 .33439 L .36681 .41433 L .533 0 0 r
F
.36766 .41467 m .25265 .33439 L .36757 .41464 L .549 .158 0 r
F
.37847 .41751 m .25265 .33439 L .36766 .41467 L F
.36681 .41433 m .25265 .33439 L .22509 .32212 L .533 0 0 r
F
.22696 .32342 m .22509 .32212 L .22469 .32195 L F
.36681 .41433 m .22509 .32212 L .22696 .32342 L F
.24975 .34041 m .24831 .33753 L .24195 .33488 L 1 .214 0 r
F
.24111 .33619 m .23723 .33291 L .21945 .32666 L 1 1 0 r
F
.23723 .33291 m .22288 .32078 L .22 .32572 L F
.23723 .33291 m .22 .32572 L .21945 .32666 L F
.24192 .33486 m .22288 .32078 L .24111 .33619 L F
.23873 .34078 m .24111 .33619 L .23842 .34056 L 1 .913 0 r
F
.24692 .34647 m .24111 .33619 L .23873 .34078 L F
.23873 .34078 m .24111 .33619 L .21945 .32666 L 1 1 0 r
F
.30539 .38426 m .27171 .36852 L .26941 .37482 L 1 .995 0 r
F
.30716 .38528 m .30894 .37892 L .27394 .36977 L 1 .991 0 r
F
.30894 .37892 m .27619 .36352 L .27394 .36977 L 1 .997 0 r
F
.27619 .36352 m .27851 .35731 L .24692 .34647 L 1 1 0 r
F
.27851 .35731 m .24975 .34041 L .24692 .34647 L F
.36676 .41454 m .22469 .32195 L .22135 .32782 L .533 0 0 r
F
.36747 .41482 m .36706 .41451 L .36682 .41445 L 1 1 0 r
F
.36747 .41482 m .36682 .41445 L .36676 .41454 L F
.36596 .41756 m .36747 .41482 L .36688 .41459 L F
.36533 .41708 m .36688 .41459 L .36676 .41454 L F
.36596 .41756 m .36688 .41459 L .36533 .41708 L F
.37741 .42419 m .36596 .41756 L .36449 .42033 L F
.37741 .42419 m .37866 .42128 L .36596 .41756 L F
.36997 .41995 m .37126 .41722 L .36676 .41454 L .659 .257 0 r
F
.36687 .41437 m .22469 .32195 L .36676 .41454 L .533 0 0 r
F
.36676 .41454 m .36682 .41445 L .36681 .41445 L 1 1 0 r
F
.36523 .41702 m .36676 .41454 L .22135 .32782 L .659 .257 0 r
F
.36676 .41454 m .36681 .41445 L .36602 .41424 L 1 1 0 r
F
.36533 .41708 m .36676 .41454 L .36523 .41702 L .659 .257 0 r
F
.36997 .41995 m .36676 .41454 L .36533 .41708 L F
.36533 .41708 m .36676 .41454 L .35662 .41043 L 1 1 0 r
F
.23793 .34217 m .23873 .34078 L .23788 .34215 L 1 .913 0 r
F
.24692 .34647 m .23873 .34078 L .23793 .34217 L F
.23873 .34078 m .21081 .32138 L .23788 .34215 L F
.23873 .34078 m .23871 .34077 L .23788 .34215 L 1 1 0 r
F
.23788 .34215 m .21945 .32666 L .21609 .33259 L F
.23871 .34077 m .21945 .32666 L .23788 .34215 L F
.23556 .34672 m .23788 .34215 L .23525 .34651 L 1 .911 0 r
F
.24416 .35257 m .23788 .34215 L .23556 .34672 L F
.23556 .34672 m .23788 .34215 L .21609 .33259 L 1 1 0 r
F
.27394 .36977 m .27619 .36352 L .24416 .35257 L F
.27619 .36352 m .24692 .34647 L .24416 .35257 L F
.23474 .34816 m .23556 .34672 L .2347 .34814 L 1 .911 0 r
F
.24416 .35257 m .23556 .34672 L .23474 .34816 L F
.23556 .34672 m .20745 .32758 L .2347 .34814 L F
.23556 .34672 m .23555 .34671 L .2347 .34814 L 1 1 0 r
F
.2347 .34814 m .21609 .33259 L .21281 .33857 L F
.23555 .34671 m .21609 .33259 L .2347 .34814 L F
.23243 .35267 m .2347 .34814 L .21281 .33857 L F
.23899 .35739 m .2347 .34814 L .23243 .35267 L F
.24148 .35871 m .24416 .35257 L .2347 .34814 L 1 .91 0 r
F
.24148 .35871 m .2347 .34814 L .23243 .35267 L F
.30716 .38528 m .27394 .36977 L .27174 .37604 L 1 .991 0 r
F
.27174 .37604 m .27394 .36977 L .24148 .35871 L 1 1 0 r
F
.27394 .36977 m .24416 .35257 L .24148 .35871 L F
.36223 .42252 m .3637 .42 L .21492 .33973 L .665 .26 0 r
F
.36233 .42257 m .3637 .42 L .36223 .42252 L F
.3637 .42 m .21809 .33375 L .21492 .33973 L .662 .258 0 r
F
.36381 .41981 m .21809 .33375 L .3637 .42 L F
.36449 .42033 m .36596 .41756 L .36533 .4173 L 1 1 0 r
F
.36449 .42033 m .36533 .4173 L .36512 .41766 L F
.37618 .42712 m .37741 .42419 L .36449 .42033 L F
.36872 .42271 m .36997 .41995 L .36527 .41729 L .662 .258 0 r
F
.36372 .41975 m .36521 .41725 L .21809 .33375 L F
.36521 .41725 m .22135 .32782 L .21809 .33375 L .659 .257 0 r
F
.36533 .41708 m .22135 .32782 L .36522 .41726 L F
.36521 .41725 m .35662 .41043 L .35492 .41304 L 1 1 0 r
F
.36596 .41756 m .36532 .41707 L .36521 .41725 L F
.36532 .41707 m .35662 .41043 L .36521 .41725 L F
.36381 .41981 m .36521 .41725 L .36372 .41975 L .662 .258 0 r
F
.36449 .42033 m .36521 .41725 L .36371 .41974 L 1 1 0 r
F
.36381 .41981 m .36527 .41729 L .36521 .41725 L .662 .258 0 r
F
.36512 .41766 m .36533 .4173 L .36521 .41725 L 1 1 0 r
F
.36872 .42271 m .36527 .41729 L .36381 .41981 L .662 .258 0 r
F
.36371 .42 m .36381 .41981 L .3637 .42 L 1 1 0 r
F
.36449 .42033 m .36381 .41981 L .36371 .42 L F
.36381 .41981 m .36381 .41981 L .36371 .42 L F
.3637 .42 m .35492 .41304 L .35326 .41568 L F
.36381 .41981 m .35492 .41304 L .3637 .42 L F
.36233 .42257 m .3637 .42 L .36223 .4225 L F
.36305 .42312 m .3637 .42 L .36233 .42257 L F
.3631 .42289 m .36449 .42033 L .3637 .42 L F
.36316 .42291 m .36449 .42033 L .3631 .42289 L F
.37498 .43007 m .37618 .42712 L .36305 .42312 L F
.37618 .42712 m .36449 .42033 L .36305 .42312 L F
.36751 .42548 m .36872 .42271 L .3637 .42 L .665 .26 0 r
F
.36305 .42312 m .36316 .42291 L .3631 .42289 L 1 1 0 r
F
.36751 .42548 m .3637 .42 L .36233 .42257 L .665 .26 0 r
F
.37498 .43007 m .36305 .42312 L .36164 .42594 L 1 1 0 r
F
.35262 .41908 m .36305 .42312 L .35202 .41851 L F
.36231 .42459 m .36305 .42312 L .35258 .41906 L F
.35174 .41822 m .35174 .41822 L .35171 .41821 L .665 .26 0 r
F
.35174 .41822 m .21492 .33973 L .35171 .41821 L F
.36155 .42214 m .21492 .33973 L .35174 .41822 L F
.35146 .41795 m .35326 .41568 L .34396 .41042 L 1 1 0 r
F
.35171 .41821 m .35171 .41821 L .35169 .41818 L 0 .076 0 r
F
.35171 .41821 m .21492 .33973 L .34308 .40994 L F
.35171 .41821 m .35326 .41568 L .35146 .41795 L 1 1 0 r
F
.35171 .41821 m .35146 .41795 L .35136 .41807 L F
.35171 .41821 m .34308 .40994 L .34396 .41042 L 0 .076 0 r
F
.21492 .33973 m .34565 .40789 L .34396 .41042 L .536 .073 0 r
F
.34565 .40789 m .34572 .40793 L .34396 .41042 L F
.35136 .41807 m .35146 .41795 L .34392 .41047 L 1 1 0 r
F
.34392 .41048 m .34392 .41047 L .34376 .41031 L F
.35136 .41807 m .34392 .41047 L .34392 .41048 L F
.21492 .33973 m .21809 .33375 L .34575 .40788 L .536 .073 0 r
F
.35326 .41568 m .35492 .41304 L .34575 .40789 L 1 1 0 r
F
.34575 .40789 m .34575 .40789 L .34575 .40788 L F
.35326 .41568 m .34575 .40789 L .34575 .40789 L F
.35326 .41568 m .34575 .40789 L .34572 .40793 L F
.34575 .40789 m .34575 .40788 L .34572 .40793 L F
.35326 .41568 m .34572 .40793 L .34396 .41042 L F
.34572 .40793 m .3468 .4085 L .34405 .41036 L .536 .073 0 r
F
.34572 .40793 m .34405 .41036 L .34396 .41042 L F
.34399 .41044 m .3467 .40857 L .3452 .4111 L F
.34396 .41042 m .34405 .41036 L .34399 .41044 L F
.34405 .41036 m .3468 .4085 L .34399 .41044 L F
.21492 .33973 m .34575 .40788 L .34572 .40793 L F
.34396 .41042 m .34558 .40779 L .34376 .41031 L 1 1 0 r
F
.34572 .40793 m .34558 .40779 L .34396 .41042 L F
.35169 .41818 m .34396 .41042 L .3452 .4111 L 0 .076 0 r
F
.35171 .41821 m .34396 .41042 L .35169 .41818 L F
.35146 .41795 m .34396 .41042 L .34376 .41031 L 1 1 0 r
F
.3422 .413 m .34376 .41031 L .34197 .41286 L F
.35064 .41778 m .34391 .41048 L .3422 .413 L F
.34391 .41048 m .34376 .41031 L .3422 .413 L F
.35163 .41834 m .35171 .41821 L .35136 .41807 L F
.35136 .41807 m .34376 .41031 L .35064 .41778 L F
.36305 .42312 m .36233 .42257 L .35163 .41834 L F
.36233 .42257 m .35171 .41821 L .35163 .41834 L F
.34138 .4127 m .34408 .41416 L .34216 .41306 L 0 .076 0 r
F
.35155 .41848 m .35163 .41834 L .34216 .41306 L 1 1 0 r
F
.34408 .41416 m .3441 .41418 L .34216 .41306 L 0 .076 0 r
F
.34216 .41306 m .35163 .41834 L .3422 .413 L 1 1 0 r
F
.23361 .36981 m .23552 .36533 L .22864 .36033 L F
.23552 .36533 m .23627 .36358 L .22864 .36033 L F
.23361 .36981 m .22861 .36026 L .22856 .36036 L F
.22856 .36036 m .22861 .36026 L .22847 .3602 L F
.23634 .37108 m .23887 .36488 L .22847 .3602 L 1 .905 0 r
F
.22632 .36467 m .22847 .3602 L .19783 .34643 L F
.23361 .36981 m .22847 .3602 L .22632 .36467 L 1 1 0 r
F
.23634 .37108 m .22847 .3602 L .22632 .36467 L 1 .905 0 r
F
.22632 .36467 m .22847 .3602 L .20647 .35067 L 1 1 0 r
F
.26961 .38233 m .23887 .36488 L .23634 .37108 L F
.26961 .38233 m .27174 .37604 L .23887 .36488 L F
.34135 .41268 m .35155 .41848 L .34138 .4127 L 0 .076 0 r
F
.20882 .35182 m .35155 .41848 L .34135 .41268 L F
.35155 .41848 m .35155 .41848 L .34135 .41268 L F
.36164 .42594 m .35258 .41906 L .35245 .41917 L 1 1 0 r
F
.36075 .42556 m .35155 .41848 L .20882 .35182 L F
.26754 .38865 m .26961 .38233 L .23634 .37108 L F
.37267 .43604 m .37381 .43304 L .36026 .42878 L F
.37381 .43304 m .36164 .42594 L .36026 .42878 L F
.37381 .43304 m .37498 .43007 L .36164 .42594 L F
.23361 .36981 m .22632 .36467 L .22543 .36628 L F
.22547 .3663 m .22632 .36467 L .22543 .36628 L 1 .905 0 r
F
.23634 .37108 m .22632 .36467 L .22547 .3663 L F
.22543 .36628 m .20647 .35067 L .20342 .35678 L 1 1 0 r
F
.22632 .36467 m .22622 .3646 L .22543 .36628 L 1 .905 0 r
F
.22632 .36467 m .20647 .35067 L .22543 .36628 L 1 1 0 r
F
.23102 .37607 m .22554 .36633 L .22334 .3707 L F
.23388 .37732 m .23634 .37108 L .22543 .36628 L 1 .902 0 r
F
.23388 .37732 m .22543 .36628 L .22334 .3707 L F
.22334 .3707 m .22543 .36628 L .20342 .35678 L 1 1 0 r
F
.26754 .38865 m .23634 .37108 L .23388 .37732 L F
.35932 .42838 m .20882 .35182 L .2059 .35793 L .67 .262 0 r
F
.35933 .42839 m .35932 .42838 L .35932 .42838 L 1 1 0 r
F
.35945 .42817 m .20882 .35182 L .35932 .42838 L .67 .262 0 r
F
.35945 .42817 m .35932 .42838 L .35933 .42839 L 1 1 0 r
F
.35945 .42817 m .35932 .42838 L .35932 .42839 L .67 .262 0 r
F
.35945 .42817 m .36075 .42556 L .20882 .35182 L F
.35945 .42817 m .35004 .42104 L .35932 .42838 L 1 1 0 r
F
.37156 .43905 m .37267 .43604 L .35892 .43165 L F
.37267 .43604 m .36026 .42878 L .35892 .43165 L F
.22248 .3724 m .22334 .3707 L .22244 .37239 L 1 .902 0 r
F
.23388 .37732 m .22334 .3707 L .22248 .3724 L F
.22334 .3707 m .19478 .35279 L .22244 .37239 L F
.22334 .3707 m .20342 .35678 L .22244 .37239 L 1 1 0 r
F
.22244 .37239 m .20342 .35678 L .20044 .36293 L F
.2204 .37676 m .22244 .37239 L .22013 .37659 L 1 .899 0 r
F
.2315 .38358 m .22244 .37239 L .2204 .37676 L F
.2204 .37676 m .22244 .37239 L .20044 .36293 L 1 1 0 r
F
.26554 .39499 m .23388 .37732 L .2315 .38358 L F
.26554 .39499 m .26754 .38865 L .23388 .37732 L F
.35792 .43123 m .2059 .35793 L .20307 .36407 L .673 .263 0 r
F
.35793 .43123 m .35792 .43122 L .35792 .43123 L 1 1 0 r
F
.35805 .431 m .2059 .35793 L .35792 .43123 L .673 .263 0 r
F
.35805 .431 m .35792 .43122 L .35793 .43123 L 1 1 0 r
F
.35805 .431 m .35792 .43123 L .35792 .43123 L .673 .263 0 r
F
.35805 .431 m .35932 .42838 L .2059 .35793 L F
.35805 .431 m .34848 .42377 L .35792 .43122 L 1 1 0 r
F
.37047 .44208 m .37156 .43905 L .3576 .43454 L F
.37156 .43905 m .35892 .43165 L .3576 .43454 L F
.2195 .37852 m .20044 .36293 L .19754 .36912 L F
.2204 .37676 m .20044 .36293 L .2195 .37852 L F
.26361 .40135 m .26554 .39499 L .2315 .38358 L F
.35655 .43409 m .20307 .36407 L .20032 .37026 L .675 .264 0 r
F
.35656 .43409 m .35655 .43409 L .35655 .43409 L 1 1 0 r
F
.35668 .43385 m .20307 .36407 L .35655 .43409 L .675 .264 0 r
F
.35668 .43385 m .35655 .43409 L .35656 .43409 L 1 1 0 r
F
.35668 .43385 m .35655 .43409 L .35656 .43409 L .675 .264 0 r
F
.35668 .43385 m .35792 .43123 L .20307 .36407 L F
.35668 .43385 m .34695 .42652 L .35655 .43409 L 1 1 0 r
F
.35655 .43409 m .34695 .42652 L .34546 .4293 L F
.35655 .43409 m .34695 .42652 L .35655 .43409 L F
.3576 .43454 m .35892 .43165 L .35802 .43127 L F
.3576 .43454 m .35802 .43127 L .35789 .43151 L F
.3576 .43454 m .35792 .43123 L .35668 .43385 L F
.3576 .43454 m .35668 .43385 L .35656 .43409 L F
.3631 .43677 m .35668 .43385 L .35656 .43409 L .675 .264 0 r
F
.35789 .43151 m .35802 .43127 L .35792 .43123 L 1 1 0 r
F
.35668 .43385 m .35792 .43123 L .34695 .42652 L F
.35668 .43385 m .35797 .43125 L .35792 .43123 L .675 .264 0 r
F
.3631 .43677 m .36414 .43392 L .35797 .43125 L F
.3631 .43677 m .35797 .43125 L .35668 .43385 L F
.35792 .43123 m .34848 .42377 L .34695 .42652 L 1 1 0 r
F
.35792 .43122 m .34848 .42377 L .35792 .43123 L F
.35892 .43165 m .36026 .42878 L .35942 .42843 L F
.35892 .43165 m .35942 .42843 L .35928 .42869 L F
.35892 .43165 m .35932 .42838 L .35805 .431 L F
.35892 .43165 m .35805 .431 L .35793 .43123 L F
.36414 .43392 m .35805 .431 L .35792 .43123 L .673 .263 0 r
F
.35928 .42869 m .35942 .42843 L .35932 .42838 L 1 1 0 r
F
.35805 .431 m .35932 .42838 L .34848 .42377 L F
.35805 .431 m .35937 .42841 L .35932 .42838 L .673 .263 0 r
F
.36414 .43392 m .36522 .43109 L .35937 .42841 L F
.36414 .43392 m .35937 .42841 L .35805 .431 L F
.35932 .42838 m .35004 .42104 L .34848 .42377 L 1 1 0 r
F
.35932 .42838 m .35004 .42104 L .35932 .42838 L F
.36026 .42878 m .36164 .42594 L .36086 .42561 L F
.36026 .42878 m .36086 .42561 L .3607 .42589 L F
.36026 .42878 m .36075 .42556 L .35945 .42817 L F
.36026 .42878 m .35945 .42817 L .35933 .42839 L F
.36522 .43109 m .35945 .42817 L .35932 .42839 L .67 .262 0 r
F
.3607 .42589 m .36086 .42561 L .36075 .42556 L 1 1 0 r
F
.35945 .42817 m .36075 .42556 L .35004 .42104 L F
.35945 .42817 m .3608 .42559 L .36075 .42556 L .67 .262 0 r
F
.36522 .43109 m .36635 .42828 L .3608 .42559 L F
.36522 .43109 m .3608 .42559 L .35945 .42817 L F
.35258 .41906 m .35155 .41848 L .35004 .42104 L 1 1 0 r
F
.35258 .41906 m .35262 .41908 L .35163 .41834 L F
.36164 .42594 m .36231 .42459 L .35258 .41906 L F
.36635 .42828 m .35495 .42007 L .35155 .41848 L F
.36164 .42594 m .35245 .41917 L .36075 .42556 L F
.36635 .42828 m .35155 .41848 L .36075 .42556 L F
.36075 .42556 m .35245 .41917 L .35004 .42104 L F
.35258 .41906 m .35163 .41834 L .35155 .41848 L F
.35163 .41834 m .35136 .41807 L .35064 .41778 L F
.35262 .41908 m .35202 .41851 L .35163 .41834 L F
.35155 .41848 m .35495 .42007 L .34138 .4127 L 0 .076 0 r
F
.35004 .42104 m .35155 .41848 L .34216 .41306 L 1 1 0 r
F
.34216 .41306 m .35075 .41777 L .34365 .41374 L 0 .076 0 r
F
.3441 .41418 m .35495 .42007 L .34216 .41306 L F
.34045 .41558 m .34053 .41553 L .34049 .4156 L F
.20882 .35182 m .34209 .41303 L .34045 .41558 L F
.34209 .41303 m .34213 .41304 L .34137 .41419 L F
.34209 .41303 m .34137 .41419 L .34045 .41558 L F
.34848 .42377 m .35004 .42104 L .34049 .4156 L 1 1 0 r
F
.34848 .42377 m .34049 .4156 L .34049 .41561 L F
.2059 .35793 m .34049 .4156 L .34045 .41568 L .532 .072 0 r
F
.34045 .41568 m .34049 .4156 L .34044 .41567 L 1 1 0 r
F
.34848 .42377 m .34049 .4156 L .34045 .41568 L F
.2059 .35793 m .20882 .35182 L .34049 .4156 L .532 .072 0 r
F
.34049 .41561 m .34049 .4156 L .34049 .4156 L 1 1 0 r
F
.35004 .42104 m .34216 .41306 L .34049 .4156 L F
.34045 .41568 m .34049 .4156 L .34216 .41641 L .532 .072 0 r
F
.34695 .42652 m .34848 .42377 L .33882 .41825 L 1 1 0 r
F
.34695 .42652 m .33882 .41825 L .33882 .41825 L F
.20307 .36407 m .33881 .41824 L .33877 .41833 L .53 .072 0 r
F
.33877 .41833 m .33881 .41824 L .33876 .41833 L 1 1 0 r
F
.34695 .42652 m .33881 .41824 L .33877 .41833 L F
.20307 .36407 m .2059 .35793 L .33881 .41824 L .53 .072 0 r
F
.33882 .41825 m .33882 .41825 L .33881 .41824 L 1 1 0 r
F
.34848 .42377 m .34045 .41568 L .33881 .41824 L F
.33877 .41833 m .33881 .41824 L .34071 .4191 L .53 .072 0 r
F
.18853 .36546 m .19145 .35903 L .16294 .34342 L 1 1 0 r
F
.18853 .36546 m .16294 .34342 L .15969 .34976 L F
.19145 .35903 m .19445 .35264 L .16629 .33712 L F
.19145 .35903 m .16629 .33712 L .16294 .34342 L F
.1889 .36561 m .1918 .35918 L .17817 .35068 L F
.1889 .36561 m .17817 .35068 L .17814 .35076 L F
.1889 .36561 m .178 .35057 L .17759 .35163 L F
.21752 .38284 m .2195 .37852 L .1889 .36561 L 1 .896 0 r
F
.18569 .37192 m .18853 .36546 L .15969 .34976 L 1 1 0 r
F
.19445 .35264 m .16971 .33086 L .16629 .33712 L F
.178 .35057 m .17705 .34218 L .17371 .3482 L F
.1889 .36561 m .17757 .35159 L .15994 .34987 L F
.17814 .35076 m .17817 .35068 L .178 .35057 L F
.17759 .35163 m .178 .35057 L .17757 .35159 L F
.19445 .35264 m .19752 .34628 L .16971 .33086 L F
.1918 .35918 m .19478 .35279 L .18111 .34444 L F
.18016 .34494 m .17705 .34218 L .178 .35057 L F
.18066 .34542 m .18111 .34444 L .18092 .34432 L F
.1918 .35918 m .18111 .34444 L .18066 .34542 L F
.19752 .34628 m .17322 .32464 L .16971 .33086 L F
.18093 .34433 m .18048 .3362 L .17705 .34218 L F
.18358 .33898 m .18048 .3362 L .18093 .34433 L F
.19752 .34628 m .20067 .33996 L .17322 .32464 L F
.19783 .34643 m .20894 .34589 L .18925 .33586 L .389 .572 0 r
F
.22243 .35749 m .20882 .3459 L .19783 .34643 L 1 1 0 r
F
.22847 .3602 m .20964 .3465 L .22243 .35749 L F
.20964 .3465 m .20882 .3459 L .22243 .35749 L F
.20067 .33996 m .17682 .31847 L .17322 .32464 L F
.20067 .33996 m .20389 .33368 L .17682 .31847 L F
.20894 .34589 m .20338 .34111 L .18712 .33202 L F
.18704 .33218 m .18712 .33202 L .18399 .33027 L F
.20894 .34589 m .18712 .33202 L .18704 .33218 L F
.18673 .33275 m .20894 .34589 L .18399 .33027 L F
.18396 .33813 m .18399 .33027 L .18048 .3362 L F
.19783 .34643 m .18673 .33275 L .18396 .33813 L .389 .572 0 r
F
.20894 .34589 m .20885 .34584 L .18925 .33586 L F
.20894 .34589 m .2096 .3446 L .20338 .34111 L 1 1 0 r
F
.21768 .35035 m .2179 .35042 L .2096 .3446 L F
.20895 .34589 m .21183 .34575 L .18956 .33599 L .389 .572 0 r
F
.20895 .34589 m .18956 .33599 L .18925 .33586 L F
.21343 .34627 m .21028 .34334 L .2096 .3446 L 1 1 0 r
F
.20389 .33368 m .18049 .31235 L .17682 .31847 L F
.2096 .3446 m .18759 .3244 L .18399 .33027 L F
.22699 .34905 m .20417 .33383 L .21028 .34334 L 1 .91 0 r
F
.21028 .34334 m .21011 .34318 L .20972 .34285 L .798 .077 0 r
F
.20702 .34222 m .20817 .3415 L .18759 .3244 L 1 1 0 r
F
.20817 .3415 m .1903 .32592 L .18759 .3244 L F
.21028 .34334 m .21026 .34331 L .21011 .34318 L .798 .077 0 r
F
.20389 .33368 m .20719 .32743 L .18049 .31235 L 1 1 0 r
F
.21026 .34331 m .20417 .33383 L .19357 .32779 L .798 .077 0 r
F
.21026 .34331 m .19357 .32779 L .1903 .32592 L F
.21026 .34331 m .1903 .32592 L .20972 .34285 L F
.21028 .34334 m .21281 .33857 L .20817 .3415 L 1 1 0 r
F
.21028 .34334 m .20817 .3415 L .20702 .34222 L F
.1903 .32592 m .19128 .31858 L .18759 .3244 L F
.20417 .33383 m .19334 .32049 L .1903 .32592 L F
.20417 .33383 m .20745 .32758 L .19382 .32002 L F
.20417 .33383 m .19382 .32002 L .19377 .32011 L F
.20417 .33383 m .19362 .31991 L .19334 .32049 L F
.19334 .32049 m .19362 .31991 L .19128 .31858 L F
.19362 .31991 m .19362 .3199 L .19334 .32049 L F
.19377 .32011 m .19382 .32002 L .19362 .3199 L F
.21281 .33857 m .21609 .33259 L .19362 .31991 L F
.21281 .33857 m .19362 .31991 L .19334 .32049 L F
.20817 .3415 m .21281 .33857 L .19067 .32613 L F
.19063 .32621 m .19067 .32613 L .1903 .32592 L F
.20817 .3415 m .19067 .32613 L .19063 .32621 L F
.19334 .32049 m .19362 .3199 L .19223 .31914 L F
.19067 .32613 m .19334 .32049 L .1903 .32592 L F
.21281 .33857 m .19334 .32049 L .19067 .32613 L F
.19334 .32049 m .19128 .31858 L .1903 .32592 L F
.1903 .32592 m .19223 .31914 L .18869 .325 L F
.19334 .32049 m .19223 .31914 L .1903 .32592 L F
.20972 .34285 m .1903 .32592 L .18869 .325 L .798 .077 0 r
F
.21028 .34334 m .20972 .34285 L .18869 .325 L F
.2096 .3446 m .21028 .34334 L .20702 .34222 L 1 1 0 r
F
.23243 .35267 m .22699 .34905 L .21028 .34334 L 1 .91 0 r
F
.18925 .33586 m .21183 .34575 L .18525 .33093 L .389 .572 0 r
F
.20647 .35067 m .18673 .33275 L .18396 .33813 L 1 1 0 r
F
.18673 .33275 m .18399 .33027 L .18396 .33813 L F
.18396 .33813 m .18673 .33275 L .18389 .33809 L .389 .572 0 r
F
.18389 .33809 m .18525 .33093 L .18189 .3369 L F
.18673 .33275 m .18525 .33093 L .18389 .33809 L F
.20894 .34589 m .20895 .34589 L .20885 .34584 L F
.23627 .36358 m .23762 .36052 L .21768 .35035 L 1 1 0 r
F
.23627 .36358 m .21768 .35035 L .20894 .34589 L F
.23627 .36358 m .20894 .34589 L .22847 .3602 L F
.22864 .36033 m .23627 .36358 L .22861 .36026 L F
.23887 .36488 m .20882 .3459 L .22847 .3602 L F
.20647 .35067 m .20894 .34589 L .18673 .33275 L F
.19478 .35279 m .19783 .34643 L .18414 .33824 L F
.19478 .35279 m .18414 .33824 L .1841 .33833 L F
.19478 .35279 m .18396 .33813 L .18358 .33898 L F
.19478 .35279 m .18358 .33898 L .18093 .34433 L F
.20044 .36293 m .20342 .35678 L .18119 .34447 L F
.18116 .34453 m .18119 .34447 L .18097 .34435 L F
.20044 .36293 m .18119 .34447 L .18116 .34453 L F
.1841 .33833 m .18414 .33824 L .18396 .33813 L F
.18358 .33898 m .18396 .33813 L .18048 .3362 L F
.18358 .33898 m .18396 .33813 L .18189 .3369 L F
.18358 .33898 m .184 .33816 L .18396 .33813 L F
.20342 .35678 m .20647 .35067 L .184 .33816 L F
.20342 .35678 m .184 .33816 L .18358 .33898 L F
.18087 .34429 m .18189 .3369 L .17863 .34292 L F
.18093 .34433 m .18096 .34412 L .18087 .34429 L F
.18096 .34412 m .18189 .3369 L .18087 .34429 L F
.18358 .33898 m .18189 .3369 L .18093 .34433 L F
.20342 .35678 m .18358 .33898 L .18093 .34433 L F
.18052 .34526 m .18097 .34435 L .17705 .34218 L F
.18066 .34542 m .18092 .34432 L .18052 .34526 L F
.20044 .36293 m .18097 .34435 L .18052 .34526 L F
.17794 .35053 m .17863 .34292 L .17546 .34898 L F
.178 .35057 m .17801 .35039 L .17794 .35053 L F
.17801 .35039 m .17863 .34292 L .17794 .35053 L F
.1918 .35918 m .18052 .34526 L .178 .35057 L F
.17892 .34862 m .18016 .34494 L .178 .35057 L F
.18052 .34526 m .18016 .34494 L .17823 .3507 L F
.18052 .34526 m .17863 .34292 L .178 .35057 L F
.17823 .3507 m .17892 .34862 L .178 .35057 L F
.20044 .36293 m .18052 .34526 L .17823 .3507 L F
.18052 .34526 m .18092 .34432 L .17863 .34292 L F
.17757 .35159 m .17777 .35169 L .178 .35057 L F
.17777 .35169 m .20044 .36293 L .17823 .3507 L F
.17777 .35169 m .17823 .3507 L .178 .35057 L F
.17757 .35159 m .178 .35057 L .17371 .3482 L F
.17757 .35159 m .178 .35057 L .17546 .34898 L F
.19754 .36912 m .17757 .35159 L .17045 .35428 L F
.17757 .35159 m .17371 .3482 L .17322 .34911 L F
.17668 .35151 m .17322 .34911 L .15994 .34987 L F
.17757 .35159 m .17322 .34911 L .17668 .35151 L F
.16294 .34342 m .16629 .33712 L .14241 .32003 L F
.16294 .34342 m .14241 .32003 L .13876 .32623 L F
.15969 .34976 m .16294 .34342 L .13876 .32623 L F
.15969 .34976 m .13876 .32623 L .1352 .33247 L F
.16629 .33712 m .14616 .31388 L .14241 .32003 L F
.17371 .3482 m .15491 .32612 L .15124 .33202 L F
.1487 .3387 m .15124 .33202 L .14766 .33796 L F
.15994 .34987 m .15185 .33282 L .1487 .3387 L .46 .707 0 r
F
.15185 .33282 m .15176 .33262 L .1487 .3387 L F
.18569 .37192 m .15969 .34976 L .15652 .35615 L 1 1 0 r
F
.18608 .37207 m .1889 .36561 L .15994 .34987 L F
.18608 .37207 m .15994 .34987 L .15679 .35626 L F
.15652 .35615 m .15969 .34976 L .1352 .33247 L F
.15234 .33307 m .17371 .3482 L .15185 .33245 L F
.15994 .34987 m .17322 .34911 L .15176 .33262 L .46 .707 0 r
F
.15525 .33667 m .15185 .33245 L .15176 .33262 L 1 1 0 r
F
.16629 .33712 m .16971 .33086 L .14616 .31388 L F
.17371 .3482 m .17705 .34218 L .15491 .32612 L F
.15176 .33262 m .17546 .34898 L .15154 .33216 L .46 .707 0 r
F
.16478 .34262 m .17371 .3482 L .15234 .33307 L 1 1 0 r
F
.17322 .34911 m .17371 .3482 L .15525 .33667 L F
.17322 .34911 m .17546 .34898 L .15176 .33262 L .46 .707 0 r
F
.15525 .33667 m .16478 .34262 L .15234 .33307 L 1 1 0 r
F
.14855 .33898 m .1487 .3387 L .14766 .33796 L F
.15679 .35626 m .15994 .34987 L .14883 .33883 L F
.15679 .35626 m .14883 .33883 L .14879 .33891 L F
.15679 .35626 m .1487 .3387 L .14856 .33899 L F
.18292 .37841 m .18569 .37192 L .15652 .35615 L F
.18292 .37841 m .15652 .35615 L .15343 .36257 L F
.18334 .37856 m .18608 .37207 L .15679 .35626 L F
.18334 .37856 m .15679 .35626 L .15373 .36268 L F
.15652 .35615 m .1352 .33247 L .13173 .33877 L F
.15343 .36257 m .15652 .35615 L .13173 .33877 L F
.15679 .35626 m .14866 .33918 L .14565 .34501 L F
.14565 .34501 m .14766 .33796 L .14419 .34397 L F
.14866 .33918 m .14856 .33899 L .14565 .34501 L F
.16728 .3604 m .14856 .33899 L .14565 .34501 L F
.14856 .33899 m .14766 .33796 L .14565 .34501 L F
.14856 .33899 m .14818 .33819 L .14565 .34501 L F
.14565 .34501 m .14818 .33819 L .14492 .34427 L F
.14545 .34539 m .14565 .34501 L .14419 .34397 L F
.15373 .36268 m .15679 .35626 L .14577 .34513 L F
.15373 .36268 m .14577 .34513 L .14574 .34521 L F
.15373 .36268 m .14565 .34501 L .14547 .34541 L F
.18024 .38494 m .18292 .37841 L .15343 .36257 L F
.18024 .38494 m .15343 .36257 L .15043 .36903 L F
.18068 .38508 m .18334 .37856 L .15373 .36268 L F
.18068 .38508 m .15373 .36268 L .15076 .36914 L F
.15343 .36257 m .13173 .33877 L .12836 .34511 L F
.15043 .36903 m .15343 .36257 L .12836 .34511 L F
.15373 .36268 m .14556 .3456 L .14269 .35136 L F
.14269 .35136 m .14419 .34397 L .14081 .35002 L F
.14556 .3456 m .14547 .34541 L .14269 .35136 L F
.1642 .36656 m .14547 .34541 L .14269 .35136 L F
.14547 .34541 m .14419 .34397 L .14269 .35136 L F
.14547 .34541 m .14492 .34427 L .14269 .35136 L F
.14269 .35136 m .14492 .34427 L .14176 .3504 L F
.14245 .35185 m .14269 .35136 L .14081 .35002 L F
.15076 .36914 m .15373 .36268 L .14282 .35148 L F
.15076 .36914 m .14282 .35148 L .14278 .35156 L F
.15076 .36914 m .14269 .35136 L .14247 .35188 L F
.17763 .39149 m .18024 .38494 L .15043 .36903 L F
.17763 .39149 m .15043 .36903 L .14752 .37552 L F
.17809 .39163 m .18068 .38508 L .15076 .36914 L F
.17809 .39163 m .15076 .36914 L .14788 .37563 L F
.15043 .36903 m .12836 .34511 L .12508 .35149 L F
.14752 .37552 m .15043 .36903 L .12508 .35149 L F
.14247 .35188 m .14269 .35136 L .14245 .35185 L F
.15076 .36914 m .14247 .35188 L .12523 .35155 L F
.14247 .35188 m .14081 .35002 L .14056 .35048 L F
.14247 .35188 m .14176 .3504 L .14056 .35048 L F
.12836 .34511 m .13173 .33877 L .11188 .31997 L F
.12836 .34511 m .11188 .31997 L .10826 .32622 L F
.12508 .35149 m .12836 .34511 L .10826 .32622 L F
.12523 .35155 m .14056 .35048 L .12154 .33186 L .561 .813 0 r
F
.13476 .34454 m .14081 .35002 L .12967 .33932 L 1 1 0 r
F
.14056 .35048 m .12967 .33932 L .12154 .33186 L .561 .813 0 r
F
.14056 .35048 m .14081 .35002 L .12374 .33454 L 1 1 0 r
F
.13173 .33877 m .1352 .33247 L .11561 .31378 L F
.13173 .33877 m .11561 .31378 L .11188 .31997 L F
.12967 .33932 m .12492 .3258 L .12154 .33186 L F
.12374 .33454 m .12934 .33962 L .12222 .33215 L F
.12934 .33962 m .13476 .34454 L .12957 .33941 L F
.12934 .33962 m .12957 .33941 L .12222 .33215 L F
.12972 .33928 m .12492 .3258 L .12967 .33932 L F
.14081 .35002 m .13301 .33762 L .12967 .33932 L F
.13301 .33762 m .12492 .3258 L .12976 .3394 L F
.1352 .33247 m .13876 .32623 L .11943 .30764 L F
.1352 .33247 m .11943 .30764 L .11561 .31378 L F
.13578 .33583 m .1284 .31978 L .12492 .3258 L F
.14081 .35002 m .14419 .34397 L .13596 .336 L F
.13586 .33605 m .13596 .336 L .13578 .33583 L F
.14081 .35002 m .13596 .336 L .13586 .33605 L F
.14419 .34397 m .14766 .33796 L .14287 .33329 L F
.13793 .33391 m .1284 .31978 L .13578 .33583 L F
.13876 .32623 m .14241 .32003 L .12335 .30156 L F
.13876 .32623 m .12335 .30156 L .11943 .30764 L F
.14188 .33232 m .13198 .31381 L .1284 .31978 L F
.14766 .33796 m .15124 .33202 L .14896 .32978 L F
.14766 .33796 m .14896 .32978 L .14822 .33004 L F
.14766 .33796 m .14829 .32912 L .14371 .33146 L F
.14069 .33333 m .14213 .33257 L .14188 .33232 L F
.13857 .33488 m .14287 .33329 L .14213 .33257 L F
.13857 .33488 m .14213 .33257 L .13837 .33456 L F
.14419 .34397 m .14287 .33329 L .13857 .33488 L F
.14341 .33101 m .13198 .31381 L .14188 .33232 L F
.14241 .32003 m .14616 .31388 L .12736 .29553 L F
.14241 .32003 m .12736 .29553 L .12335 .30156 L F
.14795 .32879 m .13566 .30789 L .13198 .31381 L F
.15124 .33202 m .15478 .32633 L .15394 .32664 L F
.15124 .33202 m .15443 .32566 L .14902 .32831 L F
.14629 .33014 m .14829 .32912 L .14795 .32879 L F
.14822 .33004 m .14896 .32978 L .14829 .32912 L F
.15176 .33262 m .15124 .33202 L .1487 .3387 L F
.14886 .32806 m .13566 .30789 L .14795 .32879 L F
.16971 .33086 m .14999 .30778 L .14616 .31388 L F
.14616 .31388 m .14999 .30778 L .13147 .28957 L F
.14616 .31388 m .13147 .28957 L .12736 .29553 L F
.154 .32523 m .13944 .30203 L .13566 .30789 L F
.15426 .32503 m .13944 .30203 L .154 .32523 L F
.17322 .32464 m .15392 .30174 L .14999 .30778 L F
.16971 .33086 m .17322 .32464 L .14999 .30778 L F
.14999 .30778 m .15392 .30174 L .13568 .28367 L F
.14999 .30778 m .13568 .28367 L .13147 .28957 L F
.15854 .32023 m .14331 .29622 L .13944 .30203 L F
.156 .32691 m .15638 .32384 L .15491 .32612 L F
.15431 .3251 m .15638 .32384 L .13944 .30203 L F
.15638 .32384 m .15854 .32023 L .15702 .31878 L F
.15638 .32384 m .15702 .31878 L .13944 .30203 L F
.16039 .32155 m .16218 .31434 L .15854 .32023 L F
.16046 .32151 m .16218 .31434 L .16039 .32155 L F
.18048 .3362 m .16638 .31917 L .16039 .32155 L F
.16638 .31917 m .16589 .31858 L .16039 .32155 L F
.17322 .32464 m .17682 .31847 L .15392 .30174 L F
.18048 .3362 m .18399 .33027 L .16784 .31842 L F
.16099 .32198 m .16503 .3176 L .16044 .32158 L F
.16638 .31917 m .16784 .31842 L .167 .3178 L F
.16638 .31917 m .167 .3178 L .16589 .31858 L F
.18048 .3362 m .16784 .31842 L .16638 .31917 L F
.18189 .3369 m .16589 .31858 L .16099 .32198 L F
.16589 .31858 m .16503 .3176 L .16099 .32198 L F
.17682 .31847 m .15793 .29575 L .15392 .30174 L F
.16691 .31774 m .16592 .3085 L .16218 .31434 L F
.17682 .31847 m .18049 .31235 L .15793 .29575 L F
.18399 .33027 m .18759 .3244 L .17417 .31449 L F
.18399 .33027 m .17417 .31449 L .17389 .31465 L F
.18399 .33027 m .17344 .31395 L .17168 .31518 L F
.17054 .31386 m .16592 .3085 L .16691 .31774 L F
.18049 .31235 m .16203 .28982 L .15793 .29575 L F
.17328 .31384 m .16975 .30272 L .16592 .3085 L F
.17264 .31452 m .17344 .31395 L .17328 .31384 L F
.17389 .31465 m .17417 .31449 L .17344 .31395 L F
.1734 .31371 m .16975 .30272 L .17328 .31384 L F
.18759 .3244 m .17736 .31168 L .17328 .31384 L F
.17693 .31117 m .16975 .30272 L .1735 .31399 L F
.20719 .32743 m .18425 .30627 L .18049 .31235 L F
.20719 .32743 m .21056 .32123 L .18425 .30627 L F
.19362 .31991 m .19505 .31283 L .19128 .31858 L F
.20745 .32758 m .19679 .31447 L .19362 .31991 L F
.20745 .32758 m .21081 .32138 L .19705 .31396 L F
.21609 .33259 m .21945 .32666 L .19705 .31396 L F
.19679 .31447 m .19705 .31396 L .19505 .31283 L F
.20745 .32758 m .19705 .31396 L .19705 .31397 L F
.20745 .32758 m .19704 .31396 L .19679 .31447 L F
.21609 .33259 m .19705 .31396 L .19679 .31447 L F
.19705 .31397 m .19705 .31396 L .19704 .31396 L F
.19679 .31447 m .19704 .31396 L .19587 .31332 L F
.19404 .32014 m .19679 .31447 L .19362 .31991 L F
.21609 .33259 m .19679 .31447 L .19404 .32014 L F
.19679 .31447 m .19505 .31283 L .19362 .31991 L F
.19362 .31991 m .19587 .31332 L .19223 .31914 L F
.19679 .31447 m .19587 .31332 L .19362 .31991 L F
.18425 .30627 m .16621 .28394 L .16203 .28982 L F
.18049 .31235 m .18425 .30627 L .16203 .28982 L F
.17949 .30983 m .17368 .297 L .16975 .30272 L F
.18213 .30708 m .17368 .297 L .17949 .30983 L F
.21056 .32123 m .18808 .30025 L .18425 .30627 L F
.21056 .32123 m .214 .31508 L .18808 .30025 L F
.19705 .31396 m .19891 .30714 L .19505 .31283 L F
.21081 .32138 m .20036 .30851 L .19705 .31396 L F
.21081 .32138 m .21424 .31523 L .20058 .30809 L F
.21945 .32666 m .22288 .32078 L .20058 .30809 L F
.20036 .30851 m .20058 .30809 L .19891 .30714 L F
.21081 .32138 m .20058 .30809 L .20058 .30809 L F
.21081 .32138 m .20057 .30808 L .20036 .30851 L F
.21945 .32666 m .20058 .30809 L .20036 .30851 L F
.20058 .30809 m .20058 .30809 L .20057 .30808 L F
.20036 .30851 m .20057 .30808 L .19959 .30757 L F
.19751 .31422 m .20036 .30851 L .19705 .31396 L F
.21945 .32666 m .20036 .30851 L .19751 .31422 L F
.20036 .30851 m .19891 .30714 L .19705 .31396 L F
.19705 .31396 m .19959 .30757 L .19587 .31332 L F
.20036 .30851 m .19959 .30757 L .19705 .31396 L F
.18425 .30627 m .18808 .30025 L .16621 .28394 L F
.18808 .30025 m .17049 .27813 L .16621 .28394 L F
.18553 .30572 m .1777 .29134 L .17368 .297 L F
.18772 .30347 m .1777 .29134 L .18553 .30572 L F
.214 .31508 m .192 .29428 L .18808 .30025 L F
.2435 .32828 m .21752 .30896 L .214 .31508 L F
.2435 .32828 m .24658 .32205 L .21752 .30896 L F
.24378 .32847 m .21774 .30911 L .21424 .31523 L F
.214 .31508 m .21752 .30896 L .192 .29428 L F
.20058 .30809 m .20285 .30151 L .19891 .30714 L F
.21424 .31523 m .20403 .30264 L .20058 .30809 L F
.21424 .31523 m .21774 .30911 L .20422 .30229 L F
.24378 .32847 m .24685 .32224 L .21774 .30911 L F
.22288 .32078 m .22638 .31495 L .20422 .30229 L F
.20403 .30264 m .20422 .30229 L .20285 .30151 L F
.21424 .31523 m .20422 .30229 L .20422 .30229 L F
.21424 .31523 m .20421 .30229 L .20403 .30264 L F
.22288 .32078 m .20422 .30229 L .20403 .30264 L F
.20422 .30229 m .20422 .30229 L .20421 .30229 L F
.20403 .30264 m .20421 .30229 L .20341 .30188 L F
.20109 .30838 m .20403 .30264 L .20058 .30809 L F
.22288 .32078 m .20403 .30264 L .20109 .30838 L F
.20403 .30264 m .20285 .30151 L .20058 .30809 L F
.20058 .30809 m .20341 .30188 L .19959 .30757 L F
.20403 .30264 m .20341 .30188 L .20058 .30809 L F
.18808 .30025 m .192 .29428 L .17049 .27813 L F
.19505 .31283 m .19891 .30714 L .19221 .30211 L F
.19505 .31283 m .19221 .30211 L .19194 .30227 L F
.19505 .31283 m .1918 .3018 L .19155 .30198 L F
.19505 .31283 m .19139 .30149 L .18837 .30425 L F
.19505 .31283 m .18849 .30441 L .18553 .30572 L F
.18849 .30441 m .18837 .30425 L .18553 .30572 L F
.19128 .31858 m .19505 .31283 L .18637 .30635 L F
.19128 .31858 m .18637 .30635 L .18609 .30651 L F
.19128 .31858 m .18586 .30596 L .18569 .30608 L F
.19128 .31858 m .18553 .30572 L .18309 .30824 L F
.19128 .31858 m .18312 .30827 L .17949 .30983 L F
.18312 .30827 m .18293 .30803 L .17949 .30983 L F
.18759 .3244 m .19128 .31858 L .18035 .31047 L F
.17997 .31069 m .18035 .31047 L .17949 .30983 L F
.18759 .3244 m .18035 .31047 L .17997 .31069 L F
.18759 .3244 m .17963 .31008 L .17753 .31188 L F
.17963 .31008 m .17949 .30983 L .17848 .31089 L F
.17963 .31008 m .17848 .31089 L .17753 .31188 L F
.17378 .31419 m .17693 .31117 L .1735 .31399 L F
.17679 .311 m .17949 .30983 L .16975 .30272 L F
.17736 .31167 m .17949 .30983 L .17679 .311 L F
.17736 .31168 m .17737 .31167 L .17736 .31167 L F
.17736 .31168 m .17949 .30983 L .17054 .30318 L F
.17753 .31188 m .17949 .30983 L .17736 .31168 L F
.18869 .325 m .17993 .31015 L .17737 .31167 L F
.18869 .325 m .17737 .31167 L .17736 .31168 L F
.18869 .325 m .17736 .31168 L .17378 .31419 L F
.17736 .31168 m .17693 .31117 L .17378 .31419 L F
.18525 .33093 m .18869 .325 L .17378 .31419 L F
.1736 .31429 m .17378 .31419 L .17328 .31384 L F
.18525 .33093 m .17378 .31419 L .1736 .31429 L F
.17736 .31167 m .17993 .31015 L .17949 .30983 L F
.18869 .325 m .19223 .31914 L .17993 .31015 L F
.18609 .30651 m .18637 .30635 L .18586 .30596 L F
.18569 .30608 m .18586 .30596 L .18553 .30572 L F
.17993 .31015 m .18293 .30803 L .17949 .30983 L F
.18283 .30791 m .18361 .30743 L .18553 .30572 L F
.18222 .30719 m .18553 .30572 L .17368 .297 L F
.18283 .30791 m .18553 .30572 L .18222 .30719 L F
.18309 .30824 m .18553 .30572 L .18293 .30803 L F
.19223 .31914 m .18591 .306 L .18283 .30791 L F
.18293 .30803 m .18553 .30572 L .17468 .29762 L F
.18361 .30743 m .18591 .306 L .18553 .30572 L F
.19223 .31914 m .18293 .30803 L .17993 .31015 L F
.19223 .31914 m .19587 .31332 L .18591 .306 L F
.19194 .30227 m .19221 .30211 L .1918 .3018 L F
.19155 .30198 m .1918 .3018 L .19139 .30149 L F
.18591 .306 m .18837 .30425 L .18553 .30572 L F
.19587 .31332 m .18837 .30425 L .18591 .306 L F
.192 .29428 m .17484 .27238 L .17049 .27813 L F
.19139 .30149 m .18181 .28575 L .1777 .29134 L F
.19368 .30032 m .18181 .28575 L .19139 .30149 L F
.21752 .30896 m .19599 .28836 L .192 .29428 L F
.24658 .32205 m .22111 .3029 L .21752 .30896 L F
.24658 .32205 m .24972 .31585 L .22111 .3029 L F
.24685 .32224 m .22132 .30305 L .21774 .30911 L F
.21752 .30896 m .22111 .3029 L .19599 .28836 L F
.20422 .30229 m .20687 .29595 L .20285 .30151 L F
.21774 .30911 m .20781 .29686 L .20422 .30229 L F
.21774 .30911 m .22132 .30305 L .20797 .29658 L F
.24685 .32224 m .24999 .31605 L .22132 .30305 L F
.22638 .31495 m .22996 .30918 L .20797 .29658 L F
.20781 .29686 m .20797 .29658 L .20687 .29595 L F
.21774 .30911 m .20797 .29658 L .20797 .29658 L F
.21774 .30911 m .20797 .29658 L .20781 .29686 L F
.22638 .31495 m .20797 .29658 L .20781 .29686 L F
.20797 .29658 m .20797 .29658 L .20797 .29658 L F
.20781 .29686 m .20797 .29658 L .20733 .29627 L F
.20479 .30262 m .20781 .29686 L .20422 .30229 L F
.22638 .31495 m .20781 .29686 L .20479 .30262 L F
.20781 .29686 m .20687 .29595 L .20422 .30229 L F
.20422 .30229 m .20733 .29627 L .20341 .30188 L F
.20781 .29686 m .20733 .29627 L .20422 .30229 L F
.192 .29428 m .19599 .28836 L .17484 .27238 L F
.19891 .30714 m .20285 .30151 L .19786 .29775 L F
.19891 .30714 m .19786 .29775 L .19762 .2979 L F
.19891 .30714 m .19757 .29752 L .19718 .2978 L F
.19891 .30714 m .19706 .29714 L .19368 .30032 L F
.19891 .30714 m .19368 .30032 L .19139 .30149 L F
.19587 .31332 m .19959 .30757 L .19172 .30173 L F
.19153 .30186 m .19172 .30173 L .19139 .30149 L F
.19587 .31332 m .19172 .30173 L .19153 .30186 L F
.19762 .2979 m .19786 .29775 L .19757 .29752 L F
.19718 .2978 m .19757 .29752 L .19706 .29714 L F
.19172 .30173 m .19368 .30032 L .19139 .30149 L F
.19959 .30757 m .19368 .30032 L .19172 .30173 L F
.19599 .28836 m .17929 .26669 L .17484 .27238 L F
.19706 .29714 m .18602 .28022 L .18181 .28575 L F
.19887 .29623 m .18602 .28022 L .19706 .29714 L F
.22111 .3029 m .20007 .28249 L .19599 .28836 L F
.24972 .31585 m .22477 .29688 L .22111 .3029 L F
.24972 .31585 m .25293 .3097 L .22477 .29688 L F
.24999 .31605 m .22497 .29703 L .22132 .30305 L F
.22111 .3029 m .22477 .29688 L .20007 .28249 L F
.20797 .29658 m .21098 .29046 L .20687 .29595 L F
.22132 .30305 m .21172 .29118 L .20797 .29658 L F
.22132 .30305 m .22497 .29703 L .21184 .29096 L F
.24999 .31605 m .25319 .3099 L .22497 .29703 L F
.22996 .30918 m .23361 .30346 L .21184 .29096 L F
.21172 .29118 m .21184 .29096 L .21098 .29046 L F
.22132 .30305 m .21184 .29096 L .21184 .29096 L F
.22132 .30305 m .21184 .29095 L .21172 .29118 L F
.22996 .30918 m .21184 .29096 L .21172 .29118 L F
.21184 .29096 m .21184 .29096 L .21184 .29095 L F
.21172 .29118 m .21184 .29095 L .21134 .29072 L F
.20861 .29694 m .21172 .29118 L .20797 .29658 L F
.22996 .30918 m .21172 .29118 L .20861 .29694 L F
.21172 .29118 m .21098 .29046 L .20797 .29658 L F
.20797 .29658 m .21134 .29072 L .20733 .29627 L F
.21172 .29118 m .21134 .29072 L .20797 .29658 L F
.19599 .28836 m .20007 .28249 L .17929 .26669 L F
.20285 .30151 m .20687 .29595 L .20333 .29326 L F
.20285 .30151 m .20333 .29326 L .20313 .29339 L F
.20285 .30151 m .20314 .29312 L .20257 .29353 L F
.20285 .30151 m .20254 .29266 L .19887 .29623 L F
.20285 .30151 m .19887 .29623 L .19706 .29714 L F
.19959 .30757 m .20341 .30188 L .19733 .29734 L F
.19714 .29747 m .19733 .29734 L .19706 .29714 L F
.19959 .30757 m .19733 .29734 L .19714 .29747 L F
.20313 .29339 m .20333 .29326 L .20314 .29312 L F
.20257 .29353 m .20314 .29312 L .20254 .29266 L F
.19733 .29734 m .19887 .29623 L .19706 .29714 L F
.20341 .30188 m .19887 .29623 L .19733 .29734 L F
.20007 .28249 m .18381 .26106 L .17929 .26669 L F
.20254 .29266 m .19032 .27476 L .18602 .28022 L F
.20393 .29197 m .19032 .27476 L .20254 .29266 L F
.22477 .29688 m .20421 .27668 L .20007 .28249 L F
.25293 .3097 m .22849 .29091 L .22477 .29688 L F
.25319 .3099 m .22869 .29106 L .22497 .29703 L F
.22477 .29688 m .22849 .29091 L .20421 .27668 L F
.21184 .29096 m .21518 .28505 L .21098 .29046 L F
.22497 .29703 m .21574 .28561 L .21184 .29096 L F
.22497 .29703 m .22869 .29106 L .21584 .28543 L F
.23361 .30346 m .23733 .2978 L .21584 .28543 L F
.21574 .28561 m .21584 .28543 L .21518 .28505 L F
.22497 .29703 m .21584 .28543 L .21584 .28543 L F
.22497 .29703 m .21584 .28543 L .21574 .28561 L F
.23361 .30346 m .21584 .28543 L .21574 .28561 L F
.21584 .28543 m .21584 .28543 L .21584 .28543 L F
.21574 .28561 m .21584 .28543 L .21546 .28526 L F
.21255 .29136 m .21574 .28561 L .21184 .29096 L F
.23361 .30346 m .21574 .28561 L .21255 .29136 L F
.21574 .28561 m .21518 .28505 L .21184 .29096 L F
.21184 .29096 m .21546 .28526 L .21134 .29072 L F
.21574 .28561 m .21546 .28526 L .21184 .29096 L F
.20007 .28249 m .20421 .27668 L .18381 .26106 L F
.20687 .29595 m .21098 .29046 L .2086 .28865 L F
.20687 .29595 m .2086 .28865 L .20849 .28873 L F
.20687 .29595 m .20852 .28859 L .20769 .2892 L F
.20687 .29595 m .20783 .28806 L .20393 .29197 L F
.20341 .30188 m .20733 .29627 L .20276 .29283 L F
.20257 .29297 m .20276 .29283 L .20254 .29266 L F
.20341 .30188 m .20276 .29283 L .20257 .29297 L F
.20849 .28873 m .2086 .28865 L .20852 .28859 L F
.20769 .2892 m .20852 .28859 L .20783 .28806 L F
.20687 .29595 m .20393 .29197 L .20254 .29266 L F
.20276 .29283 m .20393 .29197 L .20254 .29266 L F
.20733 .29627 m .20393 .29197 L .20276 .29283 L F
.20733 .29627 m .21134 .29072 L .20783 .28806 L F
.20393 .29197 m .20783 .28806 L .19032 .27476 L F
.20733 .29627 m .20783 .28806 L .20393 .29197 L F
.20421 .27668 m .18842 .2555 L .18381 .26106 L F
.20783 .28806 m .19471 .26938 L .19032 .27476 L F
.20864 .28725 m .19471 .26938 L .20783 .28806 L F
.22849 .29091 m .20844 .27093 L .20421 .27668 L F
.25293 .3097 m .2562 .30359 L .22849 .29091 L F
.25319 .3099 m .25645 .30379 L .22869 .29106 L F
.2562 .30359 m .23229 .28499 L .22849 .29091 L F
.25645 .30379 m .23248 .28515 L .22869 .29106 L F
.22849 .29091 m .23229 .28499 L .20844 .27093 L F
.21584 .28543 m .21946 .27972 L .21518 .28505 L F
.22869 .29106 m .21989 .28016 L .21584 .28543 L F
.22869 .29106 m .23248 .28515 L .21998 .28002 L F
.23733 .2978 m .24112 .29221 L .21998 .28002 L F
.21989 .28016 m .21998 .28002 L .21946 .27972 L F
.22869 .29106 m .21998 .28002 L .21997 .28002 L F
.22869 .29106 m .21997 .28001 L .21989 .28016 L F
.23733 .2978 m .21998 .28002 L .21989 .28016 L F
.21997 .28002 m .21998 .28002 L .21997 .28001 L F
.21989 .28016 m .21997 .28001 L .21968 .27989 L F
.21663 .28589 m .21989 .28016 L .21584 .28543 L F
.23733 .2978 m .21989 .28016 L .21663 .28589 L F
.21989 .28016 m .21946 .27972 L .21584 .28543 L F
.21584 .28543 m .21968 .27989 L .21546 .28526 L F
.21989 .28016 m .21968 .27989 L .21584 .28543 L F
.20421 .27668 m .20844 .27093 L .18842 .2555 L F
.21098 .29046 m .21518 .28505 L .21372 .28393 L F
.21253 .28482 m .21372 .28393 L .21293 .28333 L F
.21098 .29046 m .21372 .28393 L .21253 .28482 L F
.21098 .29046 m .20887 .28755 L .20783 .28806 L F
.20801 .28819 m .20887 .28755 L .20783 .28806 L F
.21098 .29046 m .21293 .28333 L .20887 .28755 L F
.21134 .29072 m .20887 .28755 L .20801 .28819 L F
.21134 .29072 m .21546 .28526 L .21293 .28333 L F
.20887 .28755 m .21293 .28333 L .19471 .26938 L F
.21134 .29072 m .21293 .28333 L .20887 .28755 L F
.21293 .28333 m .19921 .26408 L .19471 .26938 L F
.21353 .28274 m .19921 .26408 L .21293 .28333 L F
.21518 .28505 m .21946 .27972 L .21872 .27915 L F
.21707 .2804 m .21872 .27915 L .21785 .27848 L F
.21518 .28505 m .21872 .27915 L .21707 .2804 L F
.21518 .28505 m .21369 .28296 L .21293 .28333 L F
.21307 .28343 m .21369 .28296 L .21293 .28333 L F
.21518 .28505 m .21785 .27848 L .21369 .28296 L F
.21546 .28526 m .21369 .28296 L .21307 .28343 L F
.21546 .28526 m .21968 .27989 L .21785 .27848 L F
.21244 .28133 m .21785 .27848 L .19921 .26408 L F
.23229 .28499 m .21274 .26524 L .20844 .27093 L F
.20844 .27093 m .1931 .25001 L .18842 .2555 L F
.20844 .27093 m .21274 .26524 L .1931 .25001 L F
.21785 .27848 m .2038 .25887 L .19921 .26408 L F
.21946 .27972 m .21841 .27821 L .21785 .27848 L F
.2562 .30359 m .25953 .29752 L .23229 .28499 L F
.25645 .30379 m .25978 .29773 L .23248 .28515 L F
.25953 .29752 m .23615 .27912 L .23229 .28499 L F
.25978 .29773 m .23635 .27929 L .23248 .28515 L F
.23229 .28499 m .23615 .27912 L .21274 .26524 L F
.21998 .28002 m .22382 .27447 L .21946 .27972 L F
.23248 .28515 m .22418 .27484 L .21998 .28002 L F
.23248 .28515 m .23635 .27929 L .22426 .27472 L F
.24112 .29221 m .24498 .28668 L .22426 .27472 L F
.22418 .27484 m .22426 .27472 L .22382 .27447 L F
.23248 .28515 m .22426 .27472 L .22425 .27472 L F
.23248 .28515 m .22425 .27472 L .22418 .27484 L F
.24112 .29221 m .22426 .27472 L .22418 .27484 L F
.22425 .27472 m .22426 .27472 L .22425 .27472 L F
.22418 .27484 m .22425 .27472 L .22401 .27463 L F
.22086 .28052 m .22418 .27484 L .21998 .28002 L F
.24112 .29221 m .22418 .27484 L .22086 .28052 L F
.22418 .27484 m .22382 .27447 L .21998 .28002 L F
.21998 .28002 m .22401 .27463 L .21968 .27989 L F
.22418 .27484 m .22401 .27463 L .21998 .28002 L F
.21946 .27972 m .22382 .27447 L .22356 .27426 L F
.21841 .27821 m .22356 .27426 L .2226 .27353 L F
.21946 .27972 m .22356 .27426 L .21841 .27821 L F
.21968 .27989 m .22401 .27463 L .2226 .27353 L F
.21712 .2765 m .2226 .27353 L .2038 .25887 L F
.23615 .27912 m .21711 .25961 L .21274 .26524 L F
.21274 .26524 m .19787 .24459 L .1931 .25001 L F
.21274 .26524 m .21711 .25961 L .19787 .24459 L F
.2226 .27353 m .20849 .25375 L .2038 .25887 L F
.22382 .27447 m .22304 .27332 L .2226 .27353 L F
.25953 .29752 m .26292 .2915 L .23615 .27912 L F
.25978 .29773 m .26316 .29172 L .23635 .27929 L F
.26292 .2915 m .24009 .27331 L .23615 .27912 L F
.26316 .29172 m .24028 .27348 L .23635 .27929 L F
.23615 .27912 m .24009 .27331 L .21711 .25961 L F
.22426 .27472 m .22827 .26931 L .22382 .27447 L F
.23635 .27929 m .22862 .26967 L .22426 .27472 L F
.23635 .27929 m .24028 .27348 L .2287 .26955 L F
.24498 .28668 m .24892 .28122 L .2287 .26955 L F
.22862 .26967 m .2287 .26955 L .22827 .26931 L F
.23635 .27929 m .2287 .26955 L .22869 .26956 L F
.23635 .27929 m .22869 .26955 L .22862 .26967 L F
.24498 .28668 m .2287 .26955 L .22862 .26967 L F
.22869 .26956 m .2287 .26955 L .22869 .26955 L F
.22862 .26967 m .22869 .26955 L .22846 .26948 L F
.22524 .27529 m .22862 .26967 L .22426 .27472 L F
.24498 .28668 m .22862 .26967 L .22524 .27529 L F
.22862 .26967 m .22827 .26931 L .22426 .27472 L F
.22426 .27472 m .22846 .26948 L .22401 .27463 L F
.22862 .26967 m .22846 .26948 L .22426 .27472 L F
.22401 .27463 m .22304 .27332 L .2226 .27353 L F
.22304 .27332 m .20849 .25375 L .2226 .27353 L F
.22304 .27332 m .22302 .27329 L .2226 .27353 L F
.22382 .27447 m .22827 .26931 L .22719 .26847 L F
.22401 .27463 m .22846 .26948 L .22719 .26847 L F
.22171 .27153 m .22719 .26847 L .20849 .25375 L F
.24009 .27331 m .22156 .25405 L .21711 .25961 L F
.21711 .25961 m .20272 .23924 L .19787 .24459 L F
.21711 .25961 m .22156 .25405 L .20272 .23924 L F
.24009 .27331 m .24409 .26755 L .22156 .25405 L F
.22759 .26828 m .22159 .25407 L .21328 .24873 L .836 .103 0 r
F
.22835 .26922 m .22159 .25407 L .22759 .26828 L F
.26292 .2915 m .26638 .28553 L .24009 .27331 L 1 1 0 r
F
.26638 .28553 m .24409 .26755 L .24009 .27331 L F
.24028 .27348 m .22159 .25407 L .22835 .26922 L F
.2287 .26955 m .22835 .26922 L .22827 .26931 L F
.2287 .26955 m .22835 .26922 L .22846 .26948 L F
.24028 .27348 m .22835 .26922 L .2287 .26955 L F
.28971 .3084 m .29259 .30225 L .26292 .2915 L F
.29259 .30225 m .26638 .28553 L .26292 .2915 L F
.26316 .29172 m .26661 .28575 L .24028 .27348 L F
.26661 .28575 m .24429 .26774 L .24028 .27348 L F
.24028 .27348 m .24429 .26774 L .22159 .25407 L F
.24892 .28122 m .23281 .26425 L .22835 .26922 L F
.24892 .28122 m .22835 .26922 L .2287 .26955 L F
.22759 .26828 m .23281 .26425 L .21653 .25165 L F
.22827 .26931 m .22835 .26922 L .22759 .26828 L F
.22835 .26922 m .23281 .26425 L .22759 .26828 L F
.22835 .26923 m .22835 .26922 L .22759 .26828 L .836 .103 0 r
F
.22846 .26948 m .22835 .26923 L .22759 .26828 L F
.22719 .26847 m .21328 .24873 L .20849 .25375 L F
.22827 .26931 m .22759 .26828 L .22719 .26847 L 1 1 0 r
F
.22846 .26948 m .22759 .26828 L .22719 .26847 L .836 .103 0 r
F
.22759 .26828 m .21328 .24873 L .22719 .26847 L F
.22759 .26828 m .22757 .26826 L .22719 .26847 L 1 1 0 r
F
.22719 .26847 m .22516 .26526 L .21145 .25631 L F
.22516 .26526 m .21653 .25165 L .21518 .25289 L F
.22516 .26526 m .21518 .25289 L .21145 .25631 L F
.22757 .26826 m .21653 .25165 L .22719 .26847 L F
.22304 .27332 m .22719 .26847 L .22171 .27153 L F
.22382 .27447 m .22719 .26847 L .22304 .27332 L F
.22401 .27463 m .22719 .26847 L .22304 .27332 L F
.22304 .27332 m .22719 .26847 L .21145 .25631 L F
.2226 .27353 m .21145 .25631 L .20649 .2611 L F
.22302 .27329 m .21145 .25631 L .2226 .27353 L F
.21841 .27821 m .2226 .27353 L .21712 .2765 L F
.21968 .27989 m .2226 .27353 L .21841 .27821 L F
.21841 .27821 m .2226 .27353 L .20649 .2611 L F
.21796 .27856 m .21841 .27821 L .21785 .27848 L F
.21968 .27989 m .21841 .27821 L .21796 .27856 L F
.21841 .27821 m .2038 .25887 L .21785 .27848 L F
.21841 .27821 m .2184 .27819 L .21785 .27848 L F
.21785 .27848 m .20649 .2611 L .20163 .26601 L F
.2184 .27819 m .20649 .2611 L .21785 .27848 L F
.21369 .28296 m .21785 .27848 L .21244 .28133 L F
.21546 .28526 m .21785 .27848 L .21369 .28296 L F
.21369 .28296 m .21785 .27848 L .20163 .26601 L F
.21293 .28333 m .20163 .26601 L .19689 .27104 L F
.21369 .28296 m .21353 .28274 L .21293 .28333 L F
.21369 .28296 m .20163 .26601 L .21293 .28333 L F
.20878 .28742 m .21293 .28333 L .19689 .27104 L F
.20887 .28755 m .21293 .28333 L .20878 .28742 L F
.20783 .28806 m .19689 .27104 L .19225 .27617 L F
.20887 .28755 m .20864 .28725 L .20783 .28806 L F
.20887 .28755 m .19689 .27104 L .20783 .28806 L F
.20391 .29195 m .20783 .28806 L .19225 .27617 L F
.20393 .29197 m .20783 .28806 L .20391 .29195 L F
.20254 .29266 m .19225 .27617 L .18771 .2814 L F
.20393 .29197 m .19225 .27617 L .20254 .29266 L F
.19887 .29623 m .20254 .29266 L .18602 .28022 L F
.20341 .30188 m .20254 .29266 L .19887 .29623 L F
.19887 .29623 m .20254 .29266 L .18771 .2814 L F
.19706 .29714 m .18771 .2814 L .18327 .28673 L F
.19887 .29623 m .18771 .2814 L .19706 .29714 L F
.19368 .30032 m .19706 .29714 L .18181 .28575 L F
.19959 .30757 m .19706 .29714 L .19368 .30032 L F
.19368 .30032 m .19706 .29714 L .18327 .28673 L F
.19139 .30149 m .18327 .28673 L .17893 .29213 L F
.19368 .30032 m .18327 .28673 L .19139 .30149 L F
.18837 .30425 m .19139 .30149 L .1777 .29134 L F
.19587 .31332 m .19139 .30149 L .18837 .30425 L F
.18837 .30425 m .19139 .30149 L .17893 .29213 L F
.18553 .30572 m .17893 .29213 L .17468 .29762 L F
.18837 .30425 m .18772 .30347 L .18553 .30572 L F
.18837 .30425 m .17893 .29213 L .18553 .30572 L F
.17949 .30983 m .17468 .29762 L .17054 .30318 L F
.18293 .30803 m .18213 .30708 L .17949 .30983 L F
.18293 .30803 m .17468 .29762 L .17949 .30983 L F
.17328 .31384 m .17054 .30318 L .16648 .30882 L F
.17342 .31376 m .1734 .31371 L .17328 .31384 L F
.17736 .31168 m .17054 .30318 L .17328 .31384 L F
.1735 .31399 m .17342 .31376 L .17328 .31384 L F
.17168 .31518 m .17328 .31384 L .16592 .3085 L F
.17168 .31518 m .17264 .31452 L .17256 .31445 L F
.17264 .31452 m .17328 .31384 L .16648 .30882 L F
.18525 .33093 m .17328 .31384 L .17168 .31518 L F
.17168 .31518 m .17256 .31445 L .16648 .30882 L F
.17096 .31609 m .17072 .3157 L .16691 .31774 L F
.18399 .33027 m .17205 .31564 L .16691 .31774 L F
.16746 .31813 m .16826 .31701 L .16691 .31774 L F
.16826 .31701 m .17054 .31386 L .16691 .31774 L F
.17168 .31518 m .17054 .31386 L .16826 .31701 L F
.17168 .31518 m .16826 .31701 L .16746 .31813 L F
.17183 .31537 m .17168 .31518 L .17096 .31609 L F
.17168 .31518 m .16648 .30882 L .17072 .3157 L F
.17168 .31518 m .17072 .3157 L .17096 .31609 L F
.17072 .3157 m .16648 .30882 L .16691 .31774 L F
.17205 .31564 m .17183 .31537 L .17096 .31609 L F
.16691 .31774 m .16648 .30882 L .16253 .31452 L F
.16656 .31811 m .167 .3178 L .16691 .31774 L F
.16613 .31885 m .16746 .31813 L .16691 .31774 L F
.16561 .31826 m .16691 .31774 L .16218 .31434 L F
.16589 .31858 m .16656 .31811 L .16651 .31806 L F
.16589 .31858 m .16691 .31774 L .16561 .31826 L F
.16589 .31858 m .16651 .31806 L .16253 .31452 L F
.16613 .31885 m .16691 .31774 L .16589 .31858 L F
.18189 .3369 m .18525 .33093 L .16746 .31813 L F
.18189 .3369 m .16746 .31813 L .16613 .31885 L F
.18525 .33093 m .17168 .31518 L .16746 .31813 L F
.16656 .31811 m .16691 .31774 L .16253 .31452 L F
.15989 .32175 m .16039 .32155 L .15854 .32023 L F
.17705 .34218 m .18048 .3362 L .16042 .32157 L F
.17705 .34218 m .16042 .32157 L .16041 .32158 L F
.17705 .34218 m .16039 .32155 L .15999 .32187 L F
.1571 .32448 m .15759 .32318 L .15638 .32384 L F
.15999 .32187 m .15854 .32023 L .15638 .32384 L F
.15759 .32318 m .15867 .32029 L .15638 .32384 L F
.16004 .32193 m .15867 .32029 L .1571 .32448 L F
.17705 .34218 m .15638 .32384 L .156 .32691 L F
.15999 .32187 m .15638 .32384 L .15585 .32473 L F
.17705 .34218 m .16004 .32193 L .1571 .32448 L F
.17863 .34292 m .15999 .32187 L .15499 .32617 L F
.15999 .32187 m .15585 .32473 L .15499 .32617 L F
.16041 .32158 m .16042 .32157 L .16039 .32155 L F
.15999 .32187 m .16039 .32155 L .15989 .32175 L F
.15999 .32187 m .16039 .32155 L .15867 .32029 L F
.17863 .34292 m .16039 .32155 L .15999 .32187 L F
.17863 .34292 m .18189 .3369 L .16099 .32198 L F
.16083 .32206 m .16099 .32198 L .16039 .32155 L F
.17863 .34292 m .16099 .32198 L .16083 .32206 L F
.16503 .3176 m .16218 .31434 L .16044 .32158 L F
.16039 .32155 m .16253 .31452 L .15867 .32029 L F
.16589 .31858 m .16253 .31452 L .16039 .32155 L F
.16044 .32158 m .16046 .32151 L .16039 .32155 L F
.15854 .32023 m .16218 .31434 L .14331 .29622 L F
.15431 .3251 m .15867 .32029 L .14137 .30307 L F
.15175 .32697 m .15443 .32566 L .154 .32523 L F
.15394 .32664 m .15491 .32612 L .15443 .32566 L F
.15478 .32633 m .15491 .32612 L .15394 .32664 L F
.15154 .33216 m .15499 .32617 L .15401 .32524 L F
.14902 .32831 m .15175 .32697 L .15157 .32674 L F
.14836 .3273 m .15396 .32526 L .13566 .30789 L F
.15396 .32526 m .154 .32523 L .13566 .30789 L F
.15154 .33216 m .15401 .32524 L .15396 .32526 L F
.14902 .32831 m .15396 .32526 L .14836 .3273 L F
.15175 .32697 m .154 .32523 L .15157 .32674 L F
.15154 .33216 m .15396 .32526 L .14902 .32831 L F
.15157 .32674 m .154 .32523 L .13733 .30875 L F
.14902 .32831 m .15157 .32674 L .13733 .30875 L F
.15396 .32526 m .15401 .32524 L .154 .32523 L F
.15432 .32513 m .15638 .32384 L .15431 .3251 L F
.15491 .32612 m .15593 .32454 L .15432 .32513 L F
.15593 .32454 m .15638 .32384 L .15432 .32513 L F
.15638 .32384 m .15867 .32029 L .15431 .3251 L F
.15499 .32617 m .15638 .32384 L .15431 .3251 L F
.154 .32523 m .14137 .30307 L .13733 .30875 L F
.15491 .32612 m .15431 .3251 L .154 .32523 L F
.15431 .3251 m .15426 .32503 L .154 .32523 L F
.15431 .3251 m .14137 .30307 L .154 .32523 L F
.15499 .32617 m .15431 .3251 L .154 .32523 L F
.14795 .32879 m .13733 .30875 L .1334 .31451 L F
.15124 .33202 m .14909 .32842 L .14795 .32879 L F
.14799 .32882 m .14809 .32873 L .14795 .32879 L F
.14809 .32873 m .14886 .32806 L .14795 .32879 L F
.14909 .32842 m .14902 .32831 L .14795 .32879 L F
.14902 .32831 m .14886 .32806 L .14799 .32882 L F
.14902 .32831 m .13733 .30875 L .14795 .32879 L F
.14371 .33146 m .14629 .33014 L .14613 .32994 L F
.14314 .3306 m .1478 .32889 L .14795 .32879 L F
.14302 .33043 m .14795 .32879 L .13198 .31381 L F
.14314 .3306 m .14795 .32879 L .14302 .33043 L F
.14818 .33819 m .14799 .32882 L .1478 .32889 L F
.14371 .33146 m .1478 .32889 L .14314 .3306 L F
.14629 .33014 m .14795 .32879 L .14613 .32994 L F
.14818 .33819 m .1478 .32889 L .14371 .33146 L F
.14613 .32994 m .14795 .32879 L .1334 .31451 L F
.14371 .33146 m .14613 .32994 L .1334 .31451 L F
.1478 .32889 m .14799 .32882 L .14795 .32879 L F
.14818 .33819 m .15154 .33216 L .14799 .32882 L F
.15154 .33216 m .14902 .32831 L .14799 .32882 L F
.14188 .33232 m .1334 .31451 L .12957 .32033 L F
.14766 .33796 m .14383 .33166 L .14188 .33232 L F
.14193 .33237 m .14209 .33222 L .14188 .33232 L F
.14209 .33222 m .14341 .33101 L .14188 .33232 L F
.14383 .33166 m .14371 .33146 L .14188 .33232 L F
.14371 .33146 m .14341 .33101 L .14193 .33237 L F
.14371 .33146 m .1334 .31451 L .14188 .33232 L F
.13837 .33456 m .14069 .33333 L .14055 .33317 L F
.1379 .33386 m .14163 .33248 L .14188 .33232 L F
.13779 .33369 m .14188 .33232 L .1284 .31978 L F
.1379 .33386 m .14188 .33232 L .13779 .33369 L F
.14492 .34427 m .14193 .33237 L .14163 .33248 L F
.13837 .33456 m .14163 .33248 L .1379 .33386 L F
.14069 .33333 m .14188 .33232 L .14055 .33317 L F
.14492 .34427 m .14163 .33248 L .13837 .33456 L F
.14055 .33317 m .14188 .33232 L .12957 .32033 L F
.13837 .33456 m .14055 .33317 L .12957 .32033 L F
.14163 .33248 m .14193 .33237 L .14188 .33232 L F
.14492 .34427 m .14818 .33819 L .14193 .33237 L F
.14818 .33819 m .14371 .33146 L .14193 .33237 L F
.13578 .33583 m .12957 .32033 L .12584 .32621 L F
.14419 .34397 m .13837 .33456 L .13578 .33583 L F
.13607 .33568 m .13793 .33391 L .13578 .33583 L F
.13837 .33456 m .13793 .33391 L .13585 .33589 L F
.13837 .33456 m .12957 .32033 L .13578 .33583 L F
.13585 .33589 m .13607 .33568 L .13578 .33583 L F
.14492 .34427 m .13837 .33456 L .13585 .33589 L F
.14176 .3504 m .14492 .34427 L .13585 .33589 L F
.13581 .33591 m .13585 .33589 L .13578 .33583 L F
.14176 .3504 m .13585 .33589 L .13581 .33591 L F
.13301 .33762 m .13578 .33583 L .12492 .3258 L F
.13328 .33804 m .13578 .33583 L .13301 .33762 L F
.14081 .35002 m .13578 .33583 L .13328 .33804 L F
.14176 .3504 m .13578 .33583 L .13301 .33762 L F
.13301 .33762 m .13578 .33583 L .12584 .32621 L F
.12967 .33932 m .12584 .32621 L .12222 .33215 L F
.12972 .33929 m .12972 .33928 L .12967 .33932 L F
.13301 .33762 m .12584 .32621 L .12967 .33932 L F
.12976 .3394 m .12972 .33929 L .12967 .33932 L F
.14176 .3504 m .13301 .33762 L .12976 .3394 L F
.14056 .35048 m .14176 .3504 L .12967 .33932 L .561 .813 0 r
F
.13476 .34454 m .12967 .33932 L .12222 .33215 L 1 1 0 r
F
.14202 .35187 m .14056 .35048 L .12523 .35155 L F
.13752 .35613 m .14056 .35048 L .12374 .33454 L F
.14247 .35188 m .14056 .35048 L .14202 .35187 L F
.1612 .37277 m .14247 .35188 L .13752 .35613 L F
.14247 .35188 m .14056 .35048 L .13752 .35613 L F
.14788 .37563 m .15076 .36914 L .12523 .35155 L F
.1583 .37901 m .1612 .37277 L .13994 .35783 L F
.13965 .35847 m .13994 .35783 L .13752 .35613 L F
.1583 .37901 m .13994 .35783 L .13965 .35847 L F
.14278 .35156 m .14282 .35148 L .14269 .35136 L F
.14247 .35188 m .14269 .35136 L .14176 .3504 L F
.14257 .35199 m .14269 .35136 L .14247 .35188 L F
.14257 .35199 m .14282 .35145 L .14269 .35136 L F
.1612 .37277 m .1642 .36656 L .14282 .35145 L F
.1612 .37277 m .14282 .35145 L .14257 .35199 L F
.14574 .34521 m .14577 .34513 L .14565 .34501 L F
.14547 .34541 m .14565 .34501 L .14545 .34539 L F
.14547 .34541 m .14565 .34501 L .14492 .34427 L F
.14558 .34554 m .14565 .34501 L .14547 .34541 L F
.14558 .34554 m .14579 .34511 L .14565 .34501 L F
.1642 .36656 m .16728 .3604 L .14579 .34511 L F
.1642 .36656 m .14579 .34511 L .14558 .34554 L F
.14879 .33891 m .14883 .33883 L .1487 .3387 L F
.14856 .33899 m .1487 .3387 L .14855 .33898 L F
.14856 .33899 m .1487 .3387 L .14818 .33819 L F
.16728 .3604 m .1487 .3387 L .14856 .33899 L F
.16728 .3604 m .17045 .35428 L .1487 .3387 L F
.17045 .35428 m .15176 .33262 L .1487 .3387 L F
.1487 .3387 m .15176 .33262 L .14866 .33867 L .46 .707 0 r
F
.14866 .33867 m .15154 .33216 L .14818 .33819 L F
.15176 .33262 m .15185 .33245 L .15124 .33202 L 1 1 0 r
F
.15176 .33262 m .15154 .33216 L .14866 .33867 L .46 .707 0 r
F
.17045 .35428 m .17322 .34911 L .15525 .33667 L 1 1 0 r
F
.17757 .35159 m .17322 .34911 L .17045 .35428 L F
.17757 .35159 m .17323 .34911 L .17322 .34911 L F
.17757 .35159 m .17546 .34898 L .17323 .34911 L F
.19754 .36912 m .19979 .36432 L .17757 .35159 L F
.19979 .36432 m .20044 .36293 L .17757 .35159 L F
.19471 .37535 m .19754 .36912 L .17536 .35697 L F
.17486 .35811 m .17536 .35697 L .17045 .35428 L F
.19471 .37535 m .17536 .35697 L .17486 .35811 L F
.33747 .42121 m .34695 .42652 L .33718 .42092 L F
.20032 .37026 m .20307 .36407 L .33718 .42092 L .529 .072 0 r
F
.33736 .42124 m .33718 .42092 L .33713 .42101 L 1 1 0 r
F
.34546 .4293 m .33789 .42163 L .33736 .42124 L F
.33789 .42163 m .33718 .42092 L .33736 .42124 L F
.20307 .36407 m .3387 .4183 L .33718 .42092 L .53 .072 0 r
F
.3387 .4183 m .33873 .41831 L .33718 .42092 L F
.33873 .41831 m .33877 .41833 L .33722 .42085 L F
.33873 .41831 m .33722 .42085 L .33718 .42092 L F
.33718 .42092 m .33876 .41833 L .33717 .42091 L 1 1 0 r
F
.34695 .42652 m .33877 .41833 L .33718 .42092 L F
.33877 .41833 m .33876 .41833 L .33718 .42092 L F
.33718 .42092 m .33877 .41833 L .33721 .42093 L .53 .072 0 r
F
.33721 .42093 m .34071 .4191 L .33931 .42182 L F
.33877 .41833 m .34071 .4191 L .33721 .42093 L F
.2059 .35793 m .34038 .41565 L .33881 .41824 L .532 .072 0 r
F
.33717 .42091 m .33851 .41807 L .33684 .42072 L 1 1 0 r
F
.33876 .41833 m .33851 .41807 L .33717 .42091 L F
.32869 .41435 m .33043 .41176 L .32864 .41431 L F
.33684 .42072 m .33043 .41176 L .32869 .41435 L F
.33043 .41176 m .33043 .41176 L .32869 .41435 L F
.33684 .42072 m .33851 .41807 L .33043 .41176 L F
.32749 .41303 m .32195 .40368 L .32043 .40638 L F
.32258 .40961 m .3273 .41318 L .32043 .40638 L F
.3273 .41318 m .32752 .41306 L .32043 .40638 L F
.32864 .41431 m .33043 .41176 L .33032 .41164 L F
.32864 .41431 m .33032 .41164 L .33015 .41173 L F
.32864 .41431 m .33025 .41155 L .32814 .41271 L F
.32796 .41283 m .33012 .41141 L .33008 .41138 L F
.32796 .41283 m .33008 .41138 L .32195 .40368 L F
.32752 .41306 m .3275 .41303 L .32749 .41303 L F
.3275 .41303 m .32195 .40368 L .32749 .41303 L F
.32796 .41283 m .32195 .40368 L .32752 .41306 L F
.33008 .41138 m .32352 .40101 L .32195 .40368 L F
.33021 .4113 m .32352 .40101 L .33008 .41138 L F
.33208 .40914 m .32513 .39836 L .32352 .40101 L F
.33003 .41103 m .33208 .40914 L .32352 .40101 L F
.33024 .41135 m .33115 .41076 L .33003 .41103 L F
.33115 .41076 m .33208 .40914 L .33003 .41103 L F
.33287 .40971 m .33367 .4065 L .33208 .40914 L F
.33287 .40971 m .33367 .4065 L .33287 .40971 L F
.33509 .40817 m .33367 .4065 L .33287 .40971 L F
.33301 .40983 m .33311 .40957 L .33287 .40971 L F
.33295 .40966 m .33287 .40971 L .33287 .40972 L F
.33509 .40817 m .33287 .40971 L .33295 .40966 L F
.33522 .40832 m .33569 .40797 L .33367 .4065 L F
.33569 .40797 m .33531 .40389 L .33367 .4065 L F
.34197 .41286 m .33774 .40676 L .33569 .40797 L F
.34197 .41286 m .34376 .41031 L .33856 .40626 L F
.34197 .41286 m .33856 .40626 L .33855 .40627 L F
.34197 .41286 m .33853 .40625 L .33774 .40676 L F
.33295 .40977 m .33509 .40817 L .33287 .40972 L F
.33524 .40835 m .33571 .408 L .33522 .40832 L F
.34022 .41545 m .33573 .40804 L .33524 .40835 L F
.33573 .40804 m .33571 .408 L .33524 .40835 L F
.33522 .40832 m .33311 .40957 L .33301 .40983 L F
.34038 .41565 m .34041 .41566 L .33881 .41824 L .532 .072 0 r
F
.34041 .41566 m .34045 .41568 L .33886 .41818 L F
.34041 .41566 m .33886 .41818 L .33881 .41824 L F
.33881 .41824 m .34044 .41567 L .3388 .41824 L 1 1 0 r
F
.34045 .41568 m .34044 .41567 L .33881 .41824 L F
.33881 .41824 m .34045 .41568 L .33885 .41826 L .532 .072 0 r
F
.33885 .41826 m .34208 .41645 L .34071 .4191 L F
.34208 .41645 m .34216 .41641 L .34071 .4191 L F
.33851 .41807 m .33301 .41031 L .33043 .41176 L 1 1 0 r
F
.33876 .41833 m .33881 .41824 L .33851 .41807 L F
.34045 .41568 m .34216 .41641 L .33885 .41826 L .532 .072 0 r
F
.3388 .41824 m .34022 .41545 L .33851 .41807 L 1 1 0 r
F
.34044 .41567 m .34022 .41545 L .3388 .41824 L F
.33851 .41807 m .34022 .41545 L .33288 .40972 L F
.33851 .41807 m .33288 .40972 L .33287 .40972 L F
.33851 .41807 m .33287 .40971 L .33268 .40985 L F
.33301 .41031 m .33269 .40985 L .33151 .41067 L F
.33301 .41031 m .33115 .41076 L .33043 .41176 L F
.34071 .4191 m .33268 .40985 L .33054 .41181 L F
.33151 .41067 m .3316 .41049 L .33115 .41076 L F
.33268 .40985 m .33208 .40914 L .33115 .41076 L F
.3316 .41049 m .33225 .40923 L .33115 .41076 L F
.33269 .40985 m .33225 .40923 L .33151 .41067 L F
.33268 .40985 m .33115 .41076 L .33109 .41086 L F
.33268 .40985 m .33109 .41086 L .33054 .41181 L F
.33287 .40972 m .33288 .40972 L .33287 .40971 L F
.33268 .40985 m .33287 .40971 L .33208 .40914 L F
.33268 .40985 m .33287 .40971 L .33225 .40923 L F
.33274 .4099 m .33295 .40977 L .33287 .40971 L F
.33274 .4099 m .33287 .40971 L .33268 .40985 L F
.33931 .42181 m .34071 .4191 L .33054 .41181 L F
.33931 .42182 m .34071 .4191 L .33931 .42181 L F
.34044 .41567 m .34049 .4156 L .34022 .41545 L F
.34213 .41304 m .34137 .41422 L .34045 .41558 L 0 .076 0 r
F
.34213 .41304 m .34216 .41306 L .34137 .41422 L F
.34045 .41558 m .34215 .41308 L .34022 .41545 L 1 1 0 r
F
.34216 .41306 m .34365 .41374 L .34045 .41558 L 0 .076 0 r
F
.34049 .4156 m .34215 .41308 L .34045 .41558 L 1 1 0 r
F
.34049 .4156 m .34216 .41306 L .34215 .41308 L F
.34049 .4156 m .3406 .4155 L .34052 .41562 L 0 .076 0 r
F
.34053 .41553 m .3406 .4155 L .34049 .4156 L F
.34052 .41562 m .34357 .41379 L .34216 .41641 L F
.34357 .41379 m .34365 .41374 L .34216 .41641 L F
.3406 .4155 m .34365 .41374 L .34052 .41562 L F
.34022 .41545 m .34197 .41286 L .33569 .40797 L 1 1 0 r
F
.34022 .41545 m .33522 .40832 L .33301 .40983 L F
.34216 .41306 m .34193 .41293 L .34022 .41545 L F
.3407 .4191 m .34216 .41641 L .33295 .40977 L F
.34071 .4191 m .34216 .41641 L .3407 .4191 L F
.34071 .4191 m .33295 .40977 L .33274 .4099 L F
.34216 .41641 m .33522 .40832 L .33295 .40977 L F
.33522 .40832 m .33509 .40817 L .33295 .40977 L F
.33571 .408 m .33569 .40797 L .33522 .40832 L F
.3363 .40958 m .33685 .40989 L .33582 .40819 L F
.33685 .40989 m .34365 .41374 L .33582 .40819 L F
.33582 .40819 m .34365 .41374 L .33577 .40803 L F
.33573 .40805 m .33577 .40803 L .33571 .40798 L F
.3363 .40958 m .33577 .40803 L .33573 .40805 L F
.33855 .40627 m .33856 .40626 L .33853 .40625 L F
.35492 .41304 m .34756 .40542 L .34575 .40788 L F
.35492 .41304 m .35662 .41043 L .34758 .40538 L F
.21809 .33375 m .22135 .32782 L .34758 .40538 L .538 .073 0 r
F
.34756 .40542 m .34758 .40538 L .34758 .40538 L 1 1 0 r
F
.34756 .40542 m .34758 .40538 L .34846 .40592 L .538 .073 0 r
F
.21809 .33375 m .34758 .40538 L .34756 .40542 L F
.34756 .40542 m .34758 .40538 L .34744 .40531 L 1 1 0 r
F
.35492 .41304 m .34758 .40538 L .34756 .40542 L F
.34579 .40791 m .34834 .40601 L .3468 .4085 L .538 .073 0 r
F
.34575 .40788 m .34586 .4078 L .34579 .40791 L F
.34586 .4078 m .34846 .40592 L .34579 .40791 L F
.21809 .33375 m .34756 .40542 L .34575 .40788 L F
.34756 .40542 m .34846 .40592 L .34575 .40788 L F
.34575 .40788 m .34744 .40531 L .34558 .40779 L 1 1 0 r
F
.34756 .40542 m .34744 .40531 L .34575 .40788 L F
.34023 .40517 m .34122 .4044 L .34023 .40516 L F
.34376 .41031 m .34126 .4045 L .34023 .40517 L F
.34126 .4045 m .34122 .4044 L .34023 .40517 L F
.34376 .41031 m .34558 .40779 L .3413 .40446 L F
.34126 .40449 m .3413 .40446 L .34122 .4044 L F
.34376 .41031 m .3413 .40446 L .34126 .40449 L F
.33848 .4062 m .337 .4013 L .33531 .40389 L F
.33852 .40617 m .337 .4013 L .33848 .4062 L F
.33861 .4063 m .33858 .40614 L .33848 .4062 L F
.34023 .40516 m .337 .4013 L .33852 .40617 L F
.34023 .40516 m .33858 .40614 L .33861 .4063 L F
.34023 .40516 m .33852 .40617 L .33855 .40625 L F
.34023 .40516 m .34122 .4044 L .337 .4013 L F
.35662 .41043 m .34943 .40295 L .34758 .40538 L F
.35662 .41043 m .35835 .40786 L .34945 .40292 L F
.22135 .32782 m .22469 .32195 L .34945 .40292 L .54 .073 0 r
F
.34943 .40295 m .34945 .40292 L .34945 .40292 L 1 1 0 r
F
.34943 .40295 m .34945 .40292 L .35017 .40338 L .54 .073 0 r
F
.35835 .40786 m .35134 .40052 L .35078 .40123 L 1 1 0 r
F
.22469 .32195 m .35134 .40052 L .34945 .40292 L .541 .073 0 r
F
.35835 .40786 m .3507 .40116 L .34945 .40292 L 1 1 0 r
F
.35835 .40786 m .36011 .40532 L .35136 .4005 L F
.3802 .41525 m .25562 .32842 L .25265 .33439 L .545 .156 0 r
F
.25054 .33299 m .22638 .31495 L .22288 .32078 L 1 1 0 r
F
.25054 .33299 m .25359 .32699 L .22638 .31495 L F
.25265 .33439 m .22812 .31613 L .22469 .32195 L F
.25265 .33439 m .25562 .32842 L .22812 .31613 L F
.22469 .32195 m .22812 .31613 L .35136 .4005 L .541 .073 0 r
F
.35134 .40052 m .35136 .4005 L .35136 .4005 L 1 1 0 r
F
.35134 .40052 m .35136 .4005 L .35193 .40089 L .541 .073 0 r
F
.36011 .40532 m .35329 .39813 L .35243 .39919 L 1 1 0 r
F
.22812 .31613 m .35329 .39813 L .35136 .4005 L .543 .074 0 r
F
.36011 .40532 m .35236 .39913 L .35136 .4005 L 1 1 0 r
F
.36011 .40532 m .3619 .40281 L .35331 .39811 L F
.38032 .41501 m .25562 .32842 L .3802 .41525 L .545 .156 0 r
F
.25359 .32699 m .22996 .30918 L .22638 .31495 L 1 1 0 r
F
.25359 .32699 m .2567 .32103 L .22996 .30918 L F
.25562 .32842 m .23164 .31037 L .22812 .31613 L F
.25562 .32842 m .25867 .3225 L .23164 .31037 L F
.22812 .31613 m .23164 .31037 L .35331 .39811 L .543 .074 0 r
F
.35329 .39813 m .35331 .39811 L .35331 .39811 L 1 1 0 r
F
.35329 .39813 m .35331 .39811 L .35375 .39843 L .543 .074 0 r
F
.3619 .40281 m .35528 .39579 L .35414 .39713 L 1 1 0 r
F
.23164 .31037 m .35528 .39579 L .35331 .39811 L .545 .075 0 r
F
.3619 .40281 m .35409 .39709 L .35331 .39811 L 1 1 0 r
F
.3619 .40281 m .36372 .40035 L .35529 .39577 L F
.2567 .32103 m .23361 .30346 L .22996 .30918 L F
.2567 .32103 m .25987 .31512 L .23361 .30346 L F
.25867 .3225 m .23524 .30468 L .23164 .31037 L F
.25867 .3225 m .26179 .31663 L .23524 .30468 L F
.38299 .40965 m .26179 .31663 L .25867 .3225 L .537 .151 0 r
F
.38313 .40969 m .38301 .40962 L .38299 .40965 L 1 1 0 r
F
.38394 .4099 m .38324 .40951 L .38313 .40969 L F
.38258 .41271 m .38313 .40969 L .38171 .41222 L F
.38784 .41305 m .38312 .40944 L .38299 .40965 L .537 .151 0 r
F
.38312 .40944 m .26179 .31663 L .38299 .40965 L F
.38301 .40962 m .38301 .40962 L .38299 .40965 L 1 1 0 r
F
.23164 .31037 m .23524 .30468 L .35529 .39577 L .545 .075 0 r
F
.35528 .39579 m .35529 .39577 L .35529 .39577 L 1 1 0 r
F
.35528 .39579 m .35529 .39577 L .35563 .39603 L .545 .075 0 r
F
.36372 .40035 m .3573 .39348 L .35593 .39505 L 1 1 0 r
F
.23524 .30468 m .3573 .39348 L .35529 .39577 L .547 .076 0 r
F
.36372 .40035 m .35589 .39501 L .35529 .39577 L 1 1 0 r
F
.36372 .40035 m .36558 .39791 L .35731 .39347 L F
.25987 .31512 m .23733 .2978 L .23361 .30346 L F
.26179 .31663 m .23894 .29906 L .23524 .30468 L F
.23524 .30468 m .23894 .29906 L .35731 .39347 L .547 .076 0 r
F
.3573 .39348 m .35731 .39347 L .35731 .39347 L 1 1 0 r
F
.3573 .39348 m .35731 .39347 L .35756 .39367 L .547 .076 0 r
F
.36558 .39791 m .35936 .39123 L .35779 .39295 L 1 1 0 r
F
.25987 .31512 m .2631 .30926 L .23733 .2978 L F
.26179 .31663 m .26499 .31081 L .23894 .29906 L F
.23894 .29906 m .35936 .39123 L .35731 .39347 L .549 .077 0 r
F
.36558 .39791 m .35776 .39293 L .35731 .39347 L 1 1 0 r
F
.36558 .39791 m .36746 .39552 L .35937 .39122 L F
.2631 .30926 m .24112 .29221 L .23733 .2978 L F
.26499 .31081 m .24273 .29352 L .23894 .29906 L F
.23894 .29906 m .24273 .29352 L .35937 .39122 L .549 .077 0 r
F
.35936 .39123 m .35937 .39122 L .35937 .39122 L 1 1 0 r
F
.35936 .39123 m .35937 .39122 L .35956 .39137 L .549 .077 0 r
F
.36746 .39552 m .36145 .38901 L .35973 .39083 L 1 1 0 r
F
.24273 .29352 m .36145 .38901 L .35937 .39122 L .551 .079 0 r
F
.36746 .39552 m .3597 .39082 L .35937 .39122 L 1 1 0 r
F
.36746 .39552 m .36937 .39316 L .36146 .38901 L F
.2631 .30926 m .26639 .30345 L .24112 .29221 L F
.26639 .30345 m .24498 .28668 L .24112 .29221 L F
.26499 .31081 m .26826 .30506 L .24273 .29352 L F
.26826 .30506 m .24661 .28807 L .24273 .29352 L F
.24273 .29352 m .24661 .28807 L .36146 .38901 L .551 .079 0 r
F
.36145 .38901 m .36146 .38901 L .36146 .38901 L 1 1 0 r
F
.36145 .38901 m .36146 .38901 L .36161 .38914 L .551 .079 0 r
F
.36937 .39316 m .36357 .38685 L .36175 .38871 L 1 1 0 r
F
.24661 .28807 m .36357 .38685 L .36146 .38901 L .553 .08 0 r
F
.36937 .39316 m .36173 .3887 L .36146 .38901 L 1 1 0 r
F
.28887 .31123 m .26975 .29769 L .26639 .30345 L F
.29488 .31331 m .28966 .31006 L .28887 .31123 L F
.28966 .31006 m .26975 .29769 L .28887 .31123 L F
.29644 .31478 m .27159 .29936 L .26826 .30506 L F
.26639 .30345 m .26975 .29769 L .24498 .28668 L F
.26975 .29769 m .24892 .28122 L .24498 .28668 L F
.28993 .30862 m .29281 .30247 L .26316 .29172 L F
.29281 .30247 m .26661 .28575 L .26316 .29172 L F
.26975 .29769 m .27316 .29198 L .24892 .28122 L F
.26826 .30506 m .27159 .29936 L .24661 .28807 L F
.27316 .29198 m .25292 .27582 L .24892 .28122 L F
.27159 .29936 m .25059 .28271 L .24661 .28807 L F
.29488 .31331 m .29772 .30736 L .26975 .29769 L F
.29772 .30736 m .27316 .29198 L .26975 .29769 L F
.27159 .29936 m .27501 .29373 L .25059 .28271 L F
.27501 .29373 m .25467 .27746 L .25059 .28271 L F
.24892 .28122 m .25292 .27582 L .23281 .26425 L F
.25059 .28271 m .25467 .27746 L .23304 .26446 L F
.25059 .28271 m .23304 .26446 L .36356 .38682 L F
.3694 .39313 m .3713 .39085 L .3636 .38687 L F
.36358 .38684 m .36356 .38682 L .36372 .38697 L F
.25059 .28271 m .36356 .38682 L .36357 .38683 L F
.36331 .38642 m .23304 .26446 L .35696 .37775 L 0 .035 0 r
F
.36354 .38679 m .36571 .38471 L .36331 .38642 L 1 1 0 r
F
.36372 .38697 m .36356 .38682 L .36331 .38642 L 0 .035 0 r
F
.36356 .38682 m .23304 .26446 L .36331 .38642 L F
.36331 .38642 m .36571 .38471 L .35961 .38012 L 1 1 0 r
F
.36354 .3868 m .36354 .38679 L .36331 .38642 L F
.25059 .28271 m .36357 .38683 L .36358 .38684 L F
.36356 .38683 m .36356 .38682 L .36354 .3868 L F
.36356 .38682 m .36571 .38471 L .36354 .3868 L F
.3636 .38687 m .3713 .39085 L .36358 .38684 L F
.36937 .39316 m .3694 .39313 L .3636 .38687 L F
.24661 .28807 m .25059 .28271 L .36358 .38684 L .553 .08 0 r
F
.36357 .38685 m .36358 .38684 L .36358 .38684 L 1 1 0 r
F
.36357 .38685 m .36358 .38684 L .36372 .38697 L .553 .08 0 r
F
.3713 .39085 m .36571 .38471 L .36383 .38656 L 1 1 0 r
F
.36358 .38684 m .36357 .38683 L .36358 .38684 L F
.36358 .38684 m .36383 .38656 L .36356 .38683 L F
.3713 .39085 m .36383 .38656 L .36358 .38684 L F
.36357 .38685 m .36358 .38684 L .36357 .38685 L .553 .08 0 r
F
.24661 .28807 m .36358 .38684 L .36357 .38685 L F
.36357 .38685 m .36358 .38684 L .36356 .38683 L 1 1 0 r
F
.36937 .39316 m .36358 .38684 L .36357 .38685 L F
.36151 .38905 m .36372 .38697 L .36161 .38914 L .553 .08 0 r
F
.36207 .38845 m .36372 .38697 L .36151 .38905 L F
.36357 .38685 m .36372 .38697 L .36146 .38901 L F
.36175 .38871 m .36356 .38683 L .36173 .3887 L 1 1 0 r
F
.36357 .38685 m .36356 .38683 L .36175 .38871 L F
.36092 .38822 m .36315 .38652 L .35471 .37986 L F
.24273 .29352 m .36146 .38901 L .36145 .38901 L .551 .079 0 r
F
.36098 .38865 m .35471 .37986 L .35251 .38204 L 1 1 0 r
F
.36098 .38865 m .35471 .37986 L .36098 .38865 L F
.36115 .38853 m .35471 .37986 L .36099 .38866 L F
.36746 .39552 m .36146 .38901 L .36145 .38901 L F
.35942 .39126 m .36161 .38914 L .35956 .39137 L .551 .079 0 r
F
.35937 .39122 m .35994 .39069 L .35942 .39126 L F
.35994 .39069 m .36161 .38914 L .35942 .39126 L F
.36145 .38901 m .36161 .38914 L .35937 .39122 L F
.35973 .39083 m .36143 .38899 L .3597 .39082 L 1 1 0 r
F
.36145 .38901 m .36143 .38899 L .35973 .39083 L F
.35937 .39122 m .3597 .39082 L .35934 .3912 L F
.35956 .39137 m .36161 .38914 L .36114 .38878 L F
.23894 .29906 m .35937 .39122 L .35936 .39123 L .549 .077 0 r
F
.35874 .39074 m .35251 .38204 L .35037 .38428 L 1 1 0 r
F
.35874 .39074 m .35251 .38204 L .35874 .39074 L F
.35877 .39077 m .35875 .39074 L .35874 .39074 L F
.35897 .3906 m .35251 .38204 L .35874 .39074 L F
.35897 .3906 m .35875 .39074 L .35877 .39077 L F
.35897 .3906 m .35874 .39074 L .35876 .39076 L F
.35897 .3906 m .36098 .38865 L .35251 .38204 L F
.35897 .3906 m .35499 .3841 L .35875 .39074 L F
.36558 .39791 m .35937 .39122 L .35936 .39123 L F
.35736 .39351 m .35956 .39137 L .35756 .39367 L .549 .077 0 r
F
.35731 .39347 m .35778 .39304 L .35736 .39351 L F
.35778 .39304 m .35956 .39137 L .35736 .39351 L F
.35936 .39123 m .35956 .39137 L .35731 .39347 L F
.35779 .39295 m .35934 .3912 L .35776 .39293 L 1 1 0 r
F
.35936 .39123 m .35934 .3912 L .35779 .39295 L F
.23524 .30468 m .35731 .39347 L .3573 .39348 L .547 .076 0 r
F
.35731 .39347 m .35776 .39293 L .35727 .39345 L 1 1 0 r
F
.35644 .39281 m .35037 .38428 L .3483 .38658 L F
.35644 .39281 m .35037 .38428 L .35644 .39281 L F
.35647 .39284 m .35645 .3928 L .35644 .39281 L F
.35675 .39261 m .35037 .38428 L .35644 .39281 L F
.35675 .39261 m .35645 .3928 L .35647 .39284 L F
.35675 .39261 m .35644 .39281 L .35646 .39283 L F
.35675 .39261 m .35874 .39074 L .35037 .38428 L F
.35675 .39261 m .35273 .38616 L .35645 .3928 L F
.35644 .39281 m .35273 .38616 L .35051 .38827 L F
.35645 .3928 m .35273 .38616 L .35644 .39281 L F
.35646 .39283 m .35644 .39281 L .35644 .39281 L F
.35727 .39345 m .35675 .39261 L .35647 .39284 L F
.35756 .39367 m .35675 .39261 L .35646 .39283 L F
.35727 .39345 m .35934 .3912 L .359 .39094 L F
.35839 .39139 m .359 .39094 L .35874 .39074 L F
.35727 .39345 m .359 .39094 L .35839 .39139 L F
.35675 .39261 m .35874 .39074 L .35273 .38616 L F
.35727 .39345 m .35874 .39074 L .35675 .39261 L F
.35675 .39261 m .35889 .39086 L .35874 .39074 L F
.35756 .39367 m .35956 .39137 L .35889 .39086 L F
.35756 .39367 m .35889 .39086 L .35675 .39261 L F
.35874 .39074 m .35499 .3841 L .35273 .38616 L F
.35875 .39074 m .35499 .3841 L .35874 .39074 L F
.35876 .39076 m .35874 .39074 L .35874 .39074 L F
.35934 .3912 m .35897 .3906 L .35877 .39077 L F
.35936 .39123 m .35937 .39122 L .35936 .39123 L .549 .077 0 r
F
.35936 .39123 m .35937 .39122 L .35934 .3912 L 1 1 0 r
F
.35956 .39137 m .35897 .3906 L .35876 .39076 L F
.35934 .3912 m .36143 .38899 L .36125 .38886 L F
.36045 .38946 m .36125 .38886 L .36098 .38865 L F
.35934 .3912 m .36125 .38886 L .36045 .38946 L F
.35897 .3906 m .36098 .38865 L .35499 .3841 L F
.35934 .3912 m .36098 .38865 L .35897 .3906 L F
.35897 .3906 m .36114 .38878 L .36098 .38865 L F
.35956 .39137 m .36114 .38878 L .35897 .3906 L F
.36098 .38865 m .35728 .38209 L .35499 .3841 L F
.36143 .38899 m .36115 .38853 L .36098 .38865 L F
.36115 .38853 m .36315 .38652 L .36092 .38822 L F
.36115 .38853 m .35728 .38209 L .36098 .38865 L F
.36099 .38866 m .36098 .38865 L .36098 .38865 L F
.36145 .38901 m .36146 .38901 L .36145 .38901 L .551 .079 0 r
F
.36145 .38901 m .36146 .38901 L .36143 .38899 L 1 1 0 r
F
.36161 .38914 m .36115 .38853 L .36099 .38866 L F
.36143 .38899 m .36356 .38683 L .36344 .38674 L F
.36248 .38749 m .36344 .38674 L .36315 .38652 L F
.36143 .38899 m .36344 .38674 L .36248 .38749 L F
.36115 .38853 m .36315 .38652 L .35728 .38209 L F
.36143 .38899 m .36315 .38652 L .36115 .38853 L F
.36146 .38901 m .36207 .38845 L .36151 .38905 L .553 .08 0 r
F
.36146 .38901 m .36173 .3887 L .36143 .38899 L 1 1 0 r
F
.36161 .38914 m .36315 .38652 L .36115 .38853 L F
.36161 .38914 m .36372 .38697 L .36315 .38652 L F
.36315 .38652 m .35696 .37775 L .35471 .37986 L 0 .035 0 r
F
.36356 .38683 m .36354 .3868 L .36317 .38652 L 1 1 0 r
F
.36356 .38683 m .36317 .38652 L .36315 .38652 L F
.36331 .38642 m .35696 .37775 L .36315 .38652 L 0 .035 0 r
F
.36354 .3868 m .35961 .38012 L .35838 .38116 L 1 1 0 r
F
.36372 .38697 m .36331 .38642 L .36315 .38652 L 0 .035 0 r
F
.36315 .38652 m .36317 .38652 L .35728 .38209 L 1 1 0 r
F
.36354 .3868 m .35838 .38116 L .35728 .38209 L F
.3573 .39348 m .35731 .39347 L .3573 .39348 L .547 .076 0 r
F
.3573 .39348 m .35731 .39347 L .35727 .39345 L 1 1 0 r
F
.36372 .40035 m .35731 .39347 L .3573 .39348 L F
.35534 .39581 m .35756 .39367 L .35563 .39603 L .547 .076 0 r
F
.35529 .39577 m .35565 .39544 L .35534 .39581 L F
.35565 .39544 m .35756 .39367 L .35534 .39581 L F
.3573 .39348 m .35756 .39367 L .35529 .39577 L F
.35593 .39505 m .35727 .39345 L .35589 .39501 L 1 1 0 r
F
.3573 .39348 m .35727 .39345 L .35593 .39505 L F
.23164 .31037 m .35529 .39577 L .35528 .39579 L .545 .075 0 r
F
.35529 .39577 m .35589 .39501 L .35524 .39574 L 1 1 0 r
F
.35528 .39579 m .35529 .39577 L .35528 .39579 L .545 .075 0 r
F
.35528 .39579 m .35529 .39577 L .35524 .39574 L 1 1 0 r
F
.3619 .40281 m .35529 .39577 L .35528 .39579 L F
.35335 .39815 m .35537 .39627 L .35375 .39843 L .545 .075 0 r
F
.35358 .39786 m .35563 .39603 L .35335 .39815 L F
.35528 .39579 m .35563 .39603 L .35331 .39811 L F
.22812 .31613 m .35331 .39811 L .35329 .39813 L .543 .074 0 r
F
.35331 .39811 m .35409 .39709 L .35324 .39808 L 1 1 0 r
F
.35329 .39813 m .35331 .39811 L .35329 .39813 L .543 .074 0 r
F
.35329 .39813 m .35331 .39811 L .35324 .39808 L 1 1 0 r
F
.36011 .40532 m .35331 .39811 L .35329 .39813 L F
.35141 .40053 m .35355 .39861 L .35193 .40089 L .543 .074 0 r
F
.35355 .39861 m .35375 .39843 L .35193 .40089 L F
.35158 .40031 m .35375 .39843 L .35141 .40053 L F
.35329 .39813 m .35375 .39843 L .35136 .4005 L F
.22469 .32195 m .35136 .4005 L .35134 .40052 L .541 .073 0 r
F
.35136 .4005 m .35236 .39913 L .35127 .40045 L 1 1 0 r
F
.35134 .40052 m .35136 .4005 L .35134 .40052 L .541 .073 0 r
F
.35134 .40052 m .35136 .4005 L .35127 .40045 L 1 1 0 r
F
.35835 .40786 m .35136 .4005 L .35134 .40052 L F
.34949 .40295 m .35177 .40103 L .35017 .40338 L .541 .073 0 r
F
.35177 .40103 m .35193 .40089 L .35017 .40338 L F
.34962 .40278 m .35193 .40089 L .34949 .40295 L F
.35134 .40052 m .35193 .40089 L .34945 .40292 L F
.22135 .32782 m .34945 .40292 L .34943 .40295 L .54 .073 0 r
F
.34945 .40292 m .3507 .40116 L .34934 .40286 L 1 1 0 r
F
.34943 .40295 m .34945 .40292 L .34943 .40295 L .54 .073 0 r
F
.34943 .40295 m .34945 .40292 L .34934 .40286 L 1 1 0 r
F
.35662 .41043 m .34945 .40292 L .34943 .40295 L F
.34762 .40541 m .35003 .40349 L .34846 .40592 L .54 .073 0 r
F
.35003 .40349 m .35017 .40338 L .34846 .40592 L F
.34758 .40538 m .34772 .40528 L .34762 .40541 L F
.34772 .40528 m .35017 .40338 L .34762 .40541 L F
.32536 .39173 m .34938 .40302 L .34758 .40538 L F
.34938 .40302 m .35017 .40338 L .34758 .40538 L F
.29844 .37304 m .35017 .40338 L .32536 .39173 L F
.34758 .40538 m .34934 .40286 L .34744 .40531 L 1 1 0 r
F
.34943 .40295 m .34934 .40286 L .34758 .40538 L F
.34834 .40601 m .34846 .40592 L .3468 .4085 L .538 .073 0 r
F
.34558 .40779 m .34395 .40269 L .34269 .40352 L 1 1 0 r
F
.34395 .40269 m .34391 .40257 L .34269 .40352 L F
.34198 .40395 m .34265 .40347 L .34184 .40403 L F
.34269 .40352 m .34391 .40257 L .33874 .39875 L F
.34265 .40347 m .33874 .39875 L .34124 .40439 L F
.34134 .40449 m .3413 .40435 L .34122 .4044 L F
.34269 .40352 m .3413 .40435 L .34134 .40449 L F
.34184 .40403 m .34124 .40439 L .34126 .40443 L F
.34265 .40347 m .34124 .40439 L .34184 .40403 L F
.34122 .4044 m .33874 .39875 L .337 .4013 L F
.34122 .4044 m .33938 .40021 L .33798 .40188 L F
.34124 .40439 m .33874 .39875 L .34122 .4044 L F
.34391 .40257 m .34055 .39624 L .33874 .39875 L F
.34268 .40351 m .34391 .40257 L .33997 .39951 L F
.34269 .40352 m .34391 .40257 L .34268 .40351 L F
.34394 .40255 m .34055 .39624 L .34391 .40257 L F
.3451 .40182 m .34055 .39624 L .34397 .40261 L F
.34744 .40531 m .34934 .40286 L .34668 .4008 L F
.34658 .40087 m .34668 .4008 L .34655 .40069 L F
.34744 .40531 m .34668 .4008 L .34658 .40087 L F
.34744 .40531 m .34655 .40069 L .34512 .40184 L F
.34744 .40531 m .34512 .40184 L .34391 .40257 L F
.34846 .40592 m .34512 .40184 L .34397 .40261 L F
.34512 .40184 m .3451 .40182 L .34399 .40259 L F
.34512 .40184 m .34399 .40259 L .34397 .40261 L F
.34655 .40069 m .3424 .39376 L .34055 .39624 L F
.34657 .40068 m .3424 .39376 L .34655 .40069 L F
.34663 .40076 m .34659 .40067 L .34655 .40069 L F
.34752 .4001 m .3424 .39376 L .34657 .40068 L F
.34752 .4001 m .34659 .40067 L .34663 .40076 L F
.34752 .4001 m .34657 .40068 L .3466 .40073 L F
.34752 .4001 m .34912 .39878 L .3424 .39376 L F
.34912 .39878 m .34431 .39132 L .3424 .39376 L F
.3475 .40007 m .34912 .39878 L .34407 .39488 L F
.34752 .4001 m .34912 .39878 L .3475 .40007 L F
.34915 .39876 m .34431 .39132 L .34912 .39878 L F
.34991 .39835 m .34431 .39132 L .34921 .39885 L F
.35243 .39919 m .35324 .39808 L .35236 .39913 L F
.35329 .39813 m .35324 .39808 L .35243 .39919 L F
.35127 .40045 m .35324 .39808 L .35163 .39683 L F
.35193 .40088 m .35375 .39843 L .35163 .39683 L F
.34988 .39831 m .35163 .39683 L .34431 .39132 L F
.35127 .40045 m .35163 .39683 L .34988 .39831 L F
.35193 .40088 m .35163 .39683 L .34988 .39831 L F
.35163 .39683 m .34627 .38893 L .34431 .39132 L F
.35331 .39811 m .35358 .39786 L .35335 .39815 L .545 .075 0 r
F
.35216 .3964 m .34627 .38893 L .35163 .39683 L 1 1 0 r
F
.35537 .39627 m .35563 .39603 L .35375 .39843 L .545 .075 0 r
F
.35414 .39713 m .35524 .39574 L .35409 .39709 L 1 1 0 r
F
.35528 .39579 m .35524 .39574 L .35414 .39713 L F
.35324 .39808 m .35524 .39574 L .35428 .395 L F
.35397 .39523 m .35428 .395 L .35407 .39484 L F
.35324 .39808 m .35428 .395 L .35397 .39523 L F
.35324 .39808 m .35221 .39647 L .35163 .39683 L F
.35166 .39686 m .35221 .39647 L .35163 .39683 L F
.35324 .39808 m .35407 .39484 L .35221 .39647 L F
.35375 .39843 m .35221 .39647 L .35166 .39686 L F
.35375 .39843 m .35563 .39603 L .35407 .39484 L F
.35221 .39647 m .35407 .39484 L .34627 .38893 L F
.35375 .39843 m .35407 .39484 L .35221 .39647 L F
.35407 .39484 m .3483 .38658 L .34627 .38893 L F
.35446 .39452 m .3483 .38658 L .35407 .39484 L F
.35524 .39574 m .35727 .39345 L .35644 .39281 L F
.35563 .39603 m .35756 .39367 L .35644 .39281 L F
.3545 .39457 m .35644 .39281 L .3483 .38658 L F
.35524 .39574 m .35644 .39281 L .3545 .39457 L F
.35563 .39603 m .35644 .39281 L .3545 .39457 L F
.3545 .39457 m .35644 .39281 L .35051 .38827 L F
.35407 .39484 m .35051 .38827 L .34833 .39043 L F
.35524 .39574 m .3545 .39457 L .35407 .39484 L F
.3545 .39457 m .35446 .39452 L .35407 .39484 L F
.3545 .39457 m .35051 .38827 L .35407 .39484 L F
.35563 .39603 m .3545 .39457 L .35407 .39484 L F
.35216 .3964 m .35407 .39484 L .34833 .39043 L F
.35221 .39647 m .35407 .39484 L .35216 .3964 L F
.35163 .39683 m .34833 .39043 L .34618 .39263 L F
.35221 .39647 m .35216 .3964 L .35163 .39683 L F
.35221 .39647 m .34833 .39043 L .35163 .39683 L F
.34985 .39826 m .35163 .39683 L .34618 .39263 L F
.34988 .39831 m .35163 .39683 L .34985 .39826 L F
.34912 .39878 m .34618 .39263 L .34407 .39488 L F
.35127 .40045 m .34988 .39831 L .34912 .39878 L F
.34915 .39876 m .34915 .39876 L .34912 .39878 L F
.34988 .39831 m .34618 .39263 L .34912 .39878 L F
.34921 .39885 m .34915 .39876 L .34912 .39878 L F
.35136 .4005 m .35158 .40031 L .35141 .40053 L .543 .074 0 r
F
.35193 .40089 m .34991 .39835 L .34921 .39885 L 1 1 0 r
F
.34698 .40043 m .34407 .39488 L .34659 .40067 L F
.34752 .4001 m .3475 .40007 L .34698 .40043 L F
.3475 .40007 m .34407 .39488 L .34698 .40043 L F
.34655 .40069 m .34407 .39488 L .342 .39717 L F
.34659 .40067 m .34407 .39488 L .34655 .40069 L F
.3466 .40073 m .34657 .40068 L .34655 .40069 L F
.34934 .40286 m .35127 .40045 L .34928 .39891 L F
.34934 .40286 m .34928 .39891 L .34924 .39893 L F
.34934 .40286 m .34924 .39888 L .34913 .39896 L F
.34934 .40286 m .34912 .39878 L .34752 .4001 L F
.34934 .40286 m .34752 .4001 L .34663 .40076 L F
.34945 .40292 m .34962 .40278 L .34949 .40295 L .541 .073 0 r
F
.35017 .40338 m .34752 .4001 L .3466 .40073 L 1 1 0 r
F
.34924 .39893 m .34928 .39891 L .34924 .39888 L F
.34913 .39896 m .34924 .39888 L .34912 .39878 L F
.34845 .40591 m .35017 .40338 L .3466 .40073 L F
.34657 .40075 m .3466 .40073 L .34655 .40069 L F
.34845 .40591 m .3466 .40073 L .34657 .40075 L F
.34752 .4001 m .34921 .39885 L .34912 .39878 L F
.35078 .40123 m .35127 .40045 L .3507 .40116 L F
.35134 .40052 m .35127 .40045 L .35078 .40123 L F
.35016 .40338 m .35193 .40089 L .34921 .39885 L F
.35016 .40338 m .34921 .39885 L .34752 .4001 L F
.34512 .40184 m .34655 .40069 L .34055 .39624 L F
.34845 .40591 m .34655 .40069 L .34512 .40184 L F
.34512 .40184 m .34655 .40069 L .342 .39717 L F
.34391 .40257 m .342 .39717 L .33997 .39951 L F
.34394 .40255 m .34394 .40255 L .34391 .40257 L F
.34512 .40184 m .342 .39717 L .34391 .40257 L F
.34397 .40261 m .34394 .40255 L .34391 .40257 L F
.34252 .40363 m .33997 .39951 L .3413 .40435 L F
.34269 .40352 m .34265 .40347 L .34129 .40445 L F
.34269 .40352 m .34268 .40351 L .34252 .40363 L F
.34268 .40351 m .33997 .39951 L .34252 .40363 L F
.34122 .4044 m .33997 .39951 L .33938 .40021 L F
.3413 .40435 m .33997 .39951 L .34122 .4044 L F
.34129 .40445 m .34198 .40395 L .34126 .40443 L F
.34198 .40395 m .34184 .40403 L .34126 .40443 L F
.34558 .40779 m .34744 .40531 L .34401 .40264 L F
.34395 .40268 m .34401 .40264 L .34391 .40257 L F
.34558 .40779 m .34401 .40264 L .34395 .40268 L F
.34558 .40779 m .34269 .40352 L .34134 .40449 L F
.3467 .40857 m .3468 .4085 L .3452 .4111 L .536 .073 0 r
F
.34572 .40793 m .34575 .40788 L .3468 .4085 L F
.34572 .40793 m .34575 .40788 L .34558 .40779 L 1 1 0 r
F
.3452 .4111 m .3468 .4085 L .34129 .40445 L F
.34128 .40445 m .34129 .40445 L .34126 .40443 L F
.3452 .4111 m .34129 .40445 L .34128 .40445 L F
.3468 .4085 m .34269 .40352 L .34129 .40445 L F
.34269 .40352 m .34397 .40261 L .34391 .40257 L F
.3468 .40849 m .34846 .40592 L .34397 .40261 L F
.3468 .40849 m .34397 .40261 L .34269 .40352 L F
.3468 .4085 m .34846 .40592 L .3468 .40849 L F
.34846 .40592 m .35017 .40338 L .34845 .40591 L F
.35017 .40338 m .35193 .40089 L .35016 .40338 L F
.35193 .40089 m .35375 .39843 L .35193 .40088 L F
.34023 .40516 m .34122 .4044 L .33798 .40188 L F
.34023 .40516 m .34122 .4044 L .34023 .40516 L F
.34126 .40443 m .34124 .40439 L .34122 .4044 L F
.34018 .40519 m .33798 .40188 L .33858 .40614 L F
.34023 .40516 m .34023 .40516 L .34018 .40519 L F
.34023 .40516 m .33798 .40188 L .34018 .40519 L F
.33848 .4062 m .33798 .40188 L .33603 .4043 L F
.33858 .40614 m .33798 .40188 L .33848 .4062 L F
.33855 .40625 m .33852 .40617 L .33848 .4062 L F
.34376 .41031 m .34023 .40516 L .33861 .4063 L F
.3452 .4111 m .34023 .40516 L .33855 .40625 L F
.34365 .41374 m .3452 .4111 L .33855 .40625 L F
.33774 .40676 m .33853 .40625 L .33848 .4062 L F
.33852 .40627 m .33855 .40625 L .33848 .4062 L F
.34365 .41374 m .33855 .40625 L .33852 .40627 L F
.34023 .40516 m .34126 .40443 L .34122 .4044 L F
.3452 .4111 m .34126 .40443 L .34023 .40516 L F
.3452 .4111 m .3468 .4085 L .3452 .4111 L F
.33774 .40676 m .33848 .4062 L .33531 .40389 L F
.34365 .41374 m .33848 .4062 L .33774 .40676 L F
.33774 .40676 m .33848 .4062 L .33603 .4043 L F
.33577 .40803 m .33774 .40676 L .33569 .40797 L F
.34365 .41374 m .33774 .40676 L .33577 .40803 L F
.33774 .40676 m .33531 .40389 L .33569 .40797 L F
.33569 .40797 m .33603 .4043 L .33412 .40675 L F
.33774 .40676 m .33603 .4043 L .33569 .40797 L F
.33522 .40832 m .33412 .40675 L .33311 .40957 L F
.33287 .40971 m .33412 .40675 L .33225 .40923 L F
.33311 .40957 m .33412 .40675 L .33287 .40971 L F
.33287 .40972 m .33287 .40971 L .33287 .40971 L F
.33208 .40914 m .33367 .4065 L .32513 .39836 L F
.33024 .41135 m .33225 .40923 L .32619 .40245 L F
.33043 .41176 m .33115 .41076 L .33024 .41135 L F
.33115 .41076 m .33225 .40923 L .33024 .41135 L F
.33054 .41181 m .33115 .41076 L .33024 .41135 L F
.33012 .41141 m .32619 .40245 L .32429 .40489 L F
.33043 .41176 m .33024 .41135 L .33012 .41141 L F
.33012 .41141 m .33021 .4113 L .33008 .41138 L F
.33024 .41135 m .33021 .4113 L .33012 .41141 L F
.33024 .41135 m .32619 .40245 L .33012 .41141 L F
.33054 .41181 m .33024 .41135 L .33012 .41141 L F
.32747 .413 m .32429 .40489 L .32244 .40736 L F
.32756 .4131 m .32751 .41298 L .32747 .413 L F
.32751 .41298 m .32429 .40489 L .32747 .413 L F
.32864 .41431 m .32796 .41283 L .32756 .4131 L F
.32796 .41283 m .32429 .40489 L .32756 .4131 L F
.32796 .41283 m .32814 .41271 L .32795 .41282 L F
.32864 .41431 m .32814 .41271 L .32796 .41283 L F
.33015 .41173 m .33032 .41164 L .33025 .41155 L F
.32795 .41282 m .33025 .41155 L .32429 .40489 L F
.32906 .4145 m .33054 .41181 L .33012 .41141 L F
.32906 .4145 m .33012 .41141 L .32796 .41283 L F
.32868 .41436 m .33132 .41622 L .32906 .4145 L 0 .107 0 r
F
.32759 .41395 m .33123 .41639 L .32868 .41436 L F
.32868 .41436 m .33684 .42072 L .32869 .41435 L 1 1 0 r
F
.32868 .41436 m .32869 .41435 L .32864 .41431 L F
.20032 .37026 m .33718 .42092 L .33713 .42101 L .529 .072 0 r
F
.32757 .41394 m .33679 .42081 L .32759 .41395 L 0 .107 0 r
F
.17238 .35509 m .33678 .42081 L .32757 .41394 L F
.33678 .42081 m .33679 .42081 L .32757 .41394 L F
.20032 .37026 m .33713 .42101 L .17238 .35509 L .529 .072 0 r
F
.33709 .42099 m .33678 .42081 L .17238 .35509 L F
.33713 .42101 m .33678 .42081 L .33709 .42099 L F
.33713 .42101 m .33684 .42072 L .33558 .42361 L 1 1 0 r
F
.33713 .42101 m .33679 .42081 L .33678 .42081 L .529 .072 0 r
F
.3368 .42082 m .33684 .42072 L .33678 .42081 L 1 1 0 r
F
.33678 .42081 m .33684 .42072 L .32868 .41436 L F
.33713 .42101 m .33718 .42092 L .33684 .42072 L F
.33679 .42081 m .3368 .42082 L .32759 .41395 L 0 .107 0 r
F
.3368 .42082 m .33931 .42182 L .33125 .4164 L F
.3368 .42082 m .33125 .4164 L .32759 .41395 L F
.32868 .41436 m .32868 .41436 L .3277 .4158 L F
.3277 .4158 m .3277 .4158 L .32693 .41694 L F
.32868 .41436 m .3277 .4158 L .3277 .4158 L F
.26361 .40135 m .2315 .38358 L .22919 .38987 L 1 1 0 r
F
.37047 .44208 m .3576 .43454 L .35632 .43746 L F
.22919 .38987 m .2195 .37852 L .21752 .38284 L 1 .896 0 r
F
.21752 .38284 m .2195 .37852 L .19754 .36912 L 1 1 0 r
F
.21661 .38467 m .19754 .36912 L .19471 .37535 L F
.21752 .38284 m .21741 .38277 L .21661 .38467 L 1 .896 0 r
F
.21752 .38284 m .19754 .36912 L .21661 .38467 L 1 1 0 r
F
.21378 .39085 m .19471 .37535 L .19197 .38161 L F
.21469 .38894 m .21458 .38887 L .21378 .39085 L 1 .892 0 r
F
.21469 .38894 m .19471 .37535 L .21378 .39085 L 1 1 0 r
F
.211 .39705 m .19197 .38161 L .1893 .38791 L F
.21192 .39507 m .2118 .395 L .211 .39705 L 1 .888 0 r
F
.21192 .39507 m .19197 .38161 L .211 .39705 L 1 1 0 r
F
.21907 .40781 m .20928 .40126 L .20827 .40328 L F
.20827 .40328 m .18068 .38508 L .17816 .39146 L 1 .883 0 r
F
.20928 .40126 m .2092 .40121 L .20827 .40328 L 1 1 0 r
F
.22273 .40886 m .2092 .40121 L .20827 .40328 L 1 .883 0 r
F
.2092 .40121 m .18068 .38508 L .20827 .40328 L F
.2092 .40121 m .1893 .38791 L .20827 .40328 L 1 1 0 r
F
.20827 .40328 m .2077 .40282 L .18671 .39424 L F
.20442 .40016 m .1893 .38791 L .18671 .39424 L F
.20831 .40329 m .22273 .40886 L .20831 .40329 L 1 .878 0 r
F
.2227 .40894 m .2227 .40894 L .2227 .40894 L 0 .101 0 r
F
.2227 .40894 m .21907 .40781 L .20827 .40328 L F
.22073 .41523 m .2227 .40894 L .20831 .40329 L 1 .878 0 r
F
.2227 .40894 m .22273 .40886 L .20831 .40329 L F
.18671 .39424 m .1893 .38791 L .1612 .37277 L 1 1 0 r
F
.18671 .39424 m .1612 .37277 L .1583 .37901 L F
.20827 .40328 m .17816 .39146 L .17809 .39163 L 1 .883 0 r
F
.20631 .40725 m .20827 .40328 L .17809 .39163 L 1 .878 0 r
F
.22073 .41523 m .17809 .39163 L .17559 .3982 L F
.1751 .39807 m .17763 .39149 L .14752 .37552 L 1 1 0 r
F
.17559 .3982 m .17809 .39163 L .14788 .37563 L F
.1842 .4006 m .18671 .39424 L .1583 .37901 L F
.16888 .38627 m .19017 .39529 L .16098 .37988 L F
.19047 .3955 m .20537 .40186 L .18671 .39424 L 0 .101 0 r
F
.2227 .40894 m .2227 .40894 L .18671 .39424 L F
.2227 .40894 m .20827 .40328 L .18671 .39424 L F
.35153 .44931 m .2227 .40894 L .20537 .40186 L F
.35153 .44931 m .20537 .40186 L .19047 .3955 L F
.20641 .4073 m .20831 .40329 L .20827 .40328 L 1 .878 0 r
F
.20641 .4073 m .20827 .40328 L .20631 .40725 L F
.22073 .41523 m .20831 .40329 L .20641 .4073 L F
.18823 .40177 m .18671 .39424 L .1842 .4006 L 0 .101 0 r
F
.35153 .44931 m .19042 .39548 L .18823 .40177 L F
.19042 .39548 m .18671 .39424 L .18823 .40177 L F
.19236 .40306 m .35153 .44931 L .18823 .40177 L .689 .282 0 r
F
.21881 .42161 m .35085 .44951 L .18821 .40184 L .112 .131 0 r
F
.35085 .44951 m .35141 .44963 L .18821 .40184 L F
.18634 .40826 m .18818 .40191 L .18602 .40813 L F
.18742 .40411 m .18821 .40184 L .1833 .40296 L .689 .282 0 r
F
.18818 .40191 m .18722 .40468 L .18602 .40813 L .112 .131 0 r
F
.21881 .42161 m .18821 .40184 L .18634 .40826 L F
.18608 .40794 m .1833 .40296 L .18177 .40698 L .689 .282 0 r
F
.18821 .40184 m .18818 .40191 L .18634 .40826 L .112 .131 0 r
F
.18742 .40411 m .1833 .40296 L .18608 .40794 L .689 .282 0 r
F
.18821 .40184 m .1842 .4006 L .18417 .40066 L F
.18821 .40184 m .18417 .40066 L .1833 .40296 L F
.18821 .40184 m .18823 .40177 L .1842 .4006 L F
.1882 .40184 m .18785 .40161 L .18604 .40805 L .112 .131 0 r
F
.18722 .40468 m .18604 .40805 L .18602 .40813 L F
.1882 .40184 m .18604 .40805 L .18722 .40468 L F
.36045 .45218 m .35085 .44951 L .21881 .42161 L 1 .982 0 r
F
.35042 .45232 m .26263 .425 L .18608 .40794 L .689 .282 0 r
F
.1864 .40837 m .21881 .42161 L .18601 .40812 L 1 1 0 r
F
.18682 .40865 m .19524 .41206 L .1864 .40837 L F
.19524 .41206 m .21881 .42161 L .1864 .40837 L F
.18599 .4082 m .18601 .40812 L .18177 .40698 L .692 .282 0 r
F
.18599 .4082 m .18601 .40812 L .18599 .4082 L 1 1 0 r
F
.21697 .42801 m .18601 .40812 L .18599 .4082 L F
.18601 .40812 m .18607 .40794 L .18177 .40698 L .689 .282 0 r
F
.18602 .40813 m .18785 .40161 L .18561 .40796 L .112 .131 0 r
F
.36264 .45945 m .36348 .45678 L .21881 .42161 L .585 .169 0 r
F
.34934 .45535 m .35042 .45232 L .18601 .40812 L .692 .282 0 r
F
.34934 .45535 m .18601 .40812 L .18599 .4082 L F
.35042 .45232 m .18608 .40794 L .18601 .40812 L .689 .282 0 r
F
.35042 .45232 m .35141 .44963 L .26263 .425 L F
.26263 .425 m .18742 .40411 L .18608 .40794 L F
.18818 .40191 m .1882 .40184 L .18722 .40468 L .112 .131 0 r
F
.26263 .425 m .18821 .40184 L .18742 .40411 L .689 .282 0 r
F
.26263 .425 m .21675 .41068 L .213 .40956 L F
.21675 .41068 m .18823 .40177 L .213 .40956 L F
.213 .40956 m .18823 .40177 L .18821 .40184 L F
.26263 .425 m .33323 .44431 L .19236 .40306 L F
.35141 .44963 m .35153 .44931 L .26263 .425 L F
.1751 .39807 m .14752 .37552 L .1447 .38205 L 1 1 0 r
F
.17317 .4048 m .17559 .3982 L .14508 .38216 L F
.17317 .4048 m .14508 .38216 L .14238 .38872 L F
.17559 .3982 m .14788 .37563 L .14508 .38216 L F
.18177 .40698 m .1842 .4006 L .15548 .3853 L F
.18177 .40698 m .15548 .3853 L .15275 .39161 L F
.1842 .4006 m .1583 .37901 L .15548 .3853 L F
.18561 .40796 m .18785 .40161 L .15836 .38617 L F
.18561 .40796 m .15836 .38617 L .15584 .39248 L F
.15608 .39266 m .18561 .40796 L .15584 .39248 L F
.21697 .42801 m .18599 .4082 L .18346 .41433 L F
.18599 .4082 m .18561 .40796 L .18559 .40803 L F
.18599 .4082 m .18595 .40819 L .18559 .40804 L .692 .282 0 r
F
.18595 .40819 m .18177 .40698 L .18559 .40803 L F
.18595 .40819 m .18559 .40803 L .18559 .40803 L F
.18599 .4082 m .18559 .40803 L .18346 .41433 L 1 1 0 r
F
.18599 .4082 m .18559 .40804 L .18559 .40803 L .692 .282 0 r
F
.33608 .44943 m .18559 .40803 L .18558 .40803 L 0 .121 0 r
F
.15608 .39266 m .18558 .40803 L .15275 .39161 L F
.185 .40773 m .18561 .40796 L .15608 .39266 L 1 1 0 r
F
.18599 .4082 m .18601 .40812 L .18561 .40796 L F
.18601 .40812 m .18608 .40794 L .18607 .40794 L .689 .282 0 r
F
.33608 .44943 m .18558 .40803 L .15608 .39266 L 0 .121 0 r
F
.18558 .40803 m .18177 .40698 L .1576 .39418 L F
.18559 .40803 m .18561 .40796 L .185 .40773 L 1 1 0 r
F
.18559 .40803 m .18559 .40803 L .18558 .40803 L 0 .121 0 r
F
.18559 .40803 m .18177 .40698 L .18558 .40803 L F
.18559 .40803 m .185 .40773 L .18408 .40738 L 1 1 0 r
F
.18559 .40803 m .1576 .39418 L .15275 .39161 L 0 .121 0 r
F
.18408 .40738 m .185 .40773 L .15608 .39266 L 1 1 0 r
F
.18555 .40815 m .18559 .40803 L .18408 .40738 L F
.18346 .41433 m .18555 .40815 L .15608 .39266 L F
.18821 .40184 m .35852 .45114 L .18785 .40161 L .112 .131 0 r
F
.33323 .44431 m .35153 .44931 L .19236 .40306 L .689 .282 0 r
F
.35141 .44963 m .35852 .45114 L .18821 .40184 L .112 .131 0 r
F
.35852 .45114 m .19017 .39529 L .18785 .40161 L .685 .265 0 r
F
.35268 .44632 m .35386 .44335 L .35271 .44284 L 1 1 0 r
F
.35268 .44632 m .35271 .44284 L .35263 .44301 L F
.35152 .44546 m .35263 .44281 L .32355 .43303 L .683 .265 0 r
F
.34807 .44424 m .32355 .43303 L .19258 .38899 L F
.35152 .44546 m .32355 .43303 L .34807 .44424 L F
.35268 .44632 m .35263 .44281 L .35262 .44284 L 1 1 0 r
F
.35268 .44632 m .35262 .44283 L .35152 .44546 L F
.35139 .44575 m .19258 .38899 L .19017 .39529 L .683 .265 0 r
F
.35268 .44632 m .35152 .44546 L .35139 .44575 L 1 1 0 r
F
.35152 .44546 m .19258 .38899 L .35139 .44575 L .683 .265 0 r
F
.35152 .44546 m .35152 .44546 L .35139 .44575 L 1 1 0 r
F
.35139 .44575 m .35138 .44575 L .35139 .44575 L .683 .265 0 r
F
.35138 .44575 m .19258 .38899 L .35139 .44575 L F
.35905 .44926 m .3514 .44576 L .35139 .44575 L .306 0 0 r
F
.35028 .4484 m .35139 .44575 L .35139 .44575 L .685 .265 0 r
F
.35023 .44838 m .35139 .44575 L .19017 .39529 L F
.35028 .4484 m .35139 .44575 L .35023 .44838 L F
.35852 .45114 m .35907 .44926 L .35139 .44576 L F
.35852 .45114 m .35139 .44575 L .35028 .4484 L F
.359 .44923 m .35139 .44575 L .33988 .44067 L .306 0 0 r
F
.35905 .44926 m .35139 .44575 L .359 .44923 L F
.35263 .44281 m .19507 .38272 L .19258 .38899 L .682 .265 0 r
F
.35277 .44253 m .19507 .38272 L .35263 .44281 L F
.35386 .44335 m .35277 .44253 L .35263 .44281 L 1 1 0 r
F
.35277 .44253 m .35263 .44281 L .35264 .44281 L .682 .265 0 r
F
.35391 .43988 m .19765 .37647 L .19507 .38272 L .68 .265 0 r
F
.35404 .43962 m .19765 .37647 L .35391 .43988 L F
.35507 .44039 m .35404 .43962 L .35391 .43988 L 1 1 0 r
F
.35404 .43962 m .35391 .43988 L .35391 .43988 L .68 .265 0 r
F
.35521 .43698 m .20032 .37026 L .19765 .37647 L .678 .264 0 r
F
.35534 .43672 m .20032 .37026 L .35521 .43698 L F
.35522 .43698 m .35521 .43697 L .35521 .43698 L 1 1 0 r
F
.35534 .43672 m .35655 .43409 L .20032 .37026 L .678 .264 0 r
F
.35534 .43672 m .35534 .43672 L .35522 .43698 L 1 1 0 r
F
.35534 .43672 m .34546 .4293 L .35521 .43697 L F
.35534 .43672 m .35521 .43697 L .35522 .43698 L F
.35507 .44039 m .35632 .43746 L .3553 .43702 L F
.35507 .44039 m .3553 .43702 L .3552 .43722 L F
.35632 .43746 m .3576 .43454 L .35664 .43413 L F
.35632 .43746 m .35664 .43413 L .35653 .43435 L F
.35632 .43746 m .35655 .43409 L .35534 .43672 L F
.38476 .45224 m .36942 .44512 L .36839 .44819 L F
.40237 .45875 m .38476 .45224 L .38396 .45543 L 1 .998 0 r
F
.38396 .45543 m .38476 .45224 L .36839 .44819 L 1 1 0 r
F
.39167 .4545 m .37609 .44744 L .37535 .45037 L 1 .964 0 r
F
.36597 .44409 m .35632 .43746 L .35507 .44039 L .45 0 0 r
F
.37609 .44744 m .3665 .44208 L .36597 .44409 L 1 1 0 r
F
.37535 .45037 m .37609 .44744 L .36598 .44409 L F
.37535 .45037 m .36598 .44409 L .36578 .44506 L F
.40181 .46206 m .38396 .45543 L .38319 .45863 L 1 .989 0 r
F
.40181 .46206 m .40237 .45875 L .38396 .45543 L F
.38319 .45863 m .38396 .45543 L .36739 .45126 L 1 1 0 r
F
.38396 .45543 m .36839 .44819 L .36739 .45126 L F
.39113 .45749 m .39167 .4545 L .37535 .45037 L 1 .953 0 r
F
.39113 .45749 m .37535 .45037 L .37464 .4533 L F
.40126 .46538 m .40181 .46206 L .38319 .45863 L 1 .98 0 r
F
.39062 .46047 m .39113 .45749 L .37464 .4533 L 1 .943 0 r
F
.36528 .44704 m .35507 .44039 L .35386 .44335 L .895 .563 0 r
F
.36529 .44702 m .35507 .44039 L .36528 .44704 L F
.37535 .45037 m .36578 .44506 L .36528 .44704 L 1 1 0 r
F
.36578 .44506 m .35507 .44039 L .36535 .44706 L .895 .563 0 r
F
.38472 .45332 m .38551 .45071 L .36597 .44409 L F
.36578 .44506 m .36597 .44409 L .35507 .44039 L F
.36578 .44506 m .36598 .44409 L .36597 .44409 L 1 1 0 r
F
.38472 .45332 m .36597 .44409 L .36578 .44506 L .895 .563 0 r
F
.36578 .44506 m .36597 .44409 L .36115 .44249 L 1 1 0 r
F
.36528 .44704 m .36115 .44249 L .36023 .44537 L F
.36578 .44506 m .36115 .44249 L .36528 .44704 L F
.36535 .44706 m .36529 .44702 L .36528 .44704 L .895 .563 0 r
F
.36464 .45 m .35386 .44335 L .35268 .44632 L .897 .56 0 r
F
.36465 .44998 m .35386 .44335 L .36464 .45 L F
.37464 .4533 m .3651 .44805 L .36464 .45 L 1 1 0 r
F
.3651 .44805 m .3651 .44805 L .36464 .45 L F
.37464 .4533 m .37535 .45037 L .36529 .44704 L F
.37464 .4533 m .36529 .44704 L .36529 .44704 L F
.3651 .44805 m .36528 .44704 L .3651 .44805 L F
.37464 .4533 m .3653 .44705 L .3651 .44805 L F
.3653 .44705 m .36528 .44704 L .3651 .44805 L F
.38319 .45863 m .36739 .45126 L .36642 .45436 L F
.39062 .46047 m .37464 .4533 L .37396 .45624 L 1 .943 0 r
F
.36441 .45102 m .36464 .45 L .35268 .44632 L .899 .558 0 r
F
.37396 .45624 m .37441 .45431 L .36788 .45216 L 1 .991 0 r
F
.37396 .45624 m .36464 .45 L .36446 .45104 L F
.34748 .44411 m .35907 .44926 L .33988 .44067 L .306 0 0 r
F
.37054 .45437 m .36311 .45106 L .35852 .45114 L 1 .991 0 r
F
.36446 .45104 m .35907 .44926 L .35852 .45114 L F
.36916 .45391 m .35907 .44926 L .34748 .44411 L .306 0 0 r
F
.37396 .45624 m .37054 .45437 L .35852 .45114 L 1 .991 0 r
F
.37054 .45437 m .36446 .45104 L .36311 .45106 L F
.36446 .45104 m .35268 .44632 L .35907 .44926 L .899 .558 0 r
F
.36446 .45104 m .35936 .44825 L .35907 .44926 L 1 .991 0 r
F
.36446 .45104 m .35907 .44926 L .35908 .44927 L .899 .558 0 r
F
.3832 .45854 m .36446 .45104 L .36916 .45391 L F
.36446 .45104 m .35908 .44927 L .36916 .45391 L F
.36788 .45216 m .37464 .4533 L .36464 .45 L 1 .991 0 r
F
.37441 .45431 m .37464 .4533 L .36788 .45216 L F
.36446 .45104 m .36464 .45 L .36441 .45102 L .899 .558 0 r
F
.36446 .45104 m .36464 .45 L .35936 .44825 L 1 .991 0 r
F
.3832 .45854 m .36464 .45 L .36446 .45104 L .899 .558 0 r
F
.3832 .45854 m .38395 .45593 L .36471 .45002 L F
.36471 .45003 m .36471 .45002 L .36464 .45 L F
.3832 .45854 m .36471 .45002 L .36471 .45003 L F
.3651 .44805 m .35386 .44335 L .36471 .45002 L .897 .56 0 r
F
.3651 .44805 m .36528 .44704 L .35386 .44335 L F
.36464 .45 m .36023 .44537 L .35936 .44825 L 1 1 0 r
F
.3651 .44805 m .36023 .44537 L .36464 .45 L F
.36471 .45002 m .36465 .44998 L .36464 .45 L .897 .56 0 r
F
.38395 .45593 m .3651 .44805 L .36471 .45002 L F
.36529 .44704 m .36529 .44704 L .36528 .44704 L 1 1 0 r
F
.3651 .44805 m .36528 .44704 L .36023 .44537 L F
.36514 .44806 m .36535 .44706 L .36528 .44704 L .897 .56 0 r
F
.36514 .44806 m .36528 .44704 L .3651 .44805 L F
.38395 .45593 m .38472 .45332 L .36535 .44706 L F
.38395 .45593 m .36535 .44706 L .36514 .44806 L F
.38472 .45332 m .36578 .44506 L .36535 .44706 L .895 .563 0 r
F
.38551 .45071 m .3665 .44208 L .36597 .44409 L .45 0 0 r
F
.3665 .44208 m .35632 .43746 L .36597 .44409 L F
.36597 .44409 m .36211 .43962 L .36115 .44249 L 1 1 0 r
F
.3665 .44208 m .36211 .43962 L .36597 .44409 L F
.36115 .44249 m .36211 .43962 L .35521 .43698 L .68 .265 0 r
F
.35395 .43958 m .35521 .43698 L .19765 .37647 L F
.3552 .43722 m .3553 .43702 L .35521 .43698 L 1 1 0 r
F
.35404 .43962 m .35521 .43698 L .35395 .43958 L .68 .265 0 r
F
.35404 .43962 m .35521 .43698 L .35396 .43956 L 1 1 0 r
F
.35507 .44039 m .35521 .43698 L .35404 .43962 L F
.36115 .44249 m .35521 .43698 L .35404 .43962 L .68 .265 0 r
F
.35534 .43672 m .35521 .43698 L .35522 .43698 L .678 .264 0 r
F
.35521 .43698 m .34546 .4293 L .34401 .43211 L 1 1 0 r
F
.35521 .43697 m .34546 .4293 L .35521 .43698 L F
.35391 .43988 m .34401 .43211 L .3426 .43494 L F
.35404 .43962 m .34401 .43211 L .35391 .43988 L F
.35386 .44335 m .35507 .44039 L .35399 .43992 L F
.3539 .44011 m .35399 .43992 L .35391 .43988 L F
.35386 .44335 m .35399 .43992 L .3539 .44011 L F
.36023 .44537 m .36115 .44249 L .35391 .43988 L .682 .265 0 r
F
.35277 .44253 m .35391 .43988 L .19507 .38272 L F
.35386 .44335 m .35391 .43988 L .35277 .44253 L 1 1 0 r
F
.36023 .44537 m .35391 .43988 L .35277 .44253 L .682 .265 0 r
F
.35277 .44253 m .35391 .43988 L .35269 .44248 L 1 1 0 r
F
.35263 .44281 m .3426 .43494 L .34122 .4378 L F
.35277 .44253 m .3426 .43494 L .35263 .44281 L F
.35139 .44575 m .34122 .4378 L .33988 .44067 L F
.35152 .44546 m .34122 .4378 L .35139 .44575 L F
.35139 .44576 m .35936 .44825 L .35139 .44575 L .685 .265 0 r
F
.35907 .44926 m .35905 .44926 L .35905 .44925 L .306 0 0 r
F
.35905 .44926 m .35268 .44632 L .3514 .44576 L F
.35907 .44926 m .35936 .44825 L .35139 .44576 L .685 .265 0 r
F
.35907 .44926 m .35905 .44925 L .33988 .44067 L .306 0 0 r
F
.35262 .44284 m .35263 .44281 L .35262 .44283 L 1 1 0 r
F
.35936 .44825 m .36023 .44537 L .35263 .44281 L .683 .265 0 r
F
.35263 .44301 m .35271 .44284 L .35263 .44281 L 1 1 0 r
F
.35936 .44825 m .35263 .44281 L .35152 .44546 L .683 .265 0 r
F
.35152 .44546 m .35262 .44283 L .35145 .44541 L 1 1 0 r
F
.18785 .40161 m .19015 .39536 L .16888 .38627 L F
.19015 .39536 m .19017 .39529 L .16888 .38627 L F
.1893 .38791 m .19197 .38161 L .1642 .36656 L F
.1893 .38791 m .1642 .36656 L .1612 .37277 L F
.19017 .39529 m .19258 .38899 L .16369 .37363 L F
.19017 .39529 m .16369 .37363 L .16098 .37988 L F
.18785 .40161 m .16098 .37988 L .15836 .38617 L F
.1447 .38205 m .14752 .37552 L .1219 .35792 L F
.14752 .37552 m .12508 .35149 L .1219 .35792 L F
.14508 .38216 m .14788 .37563 L .12208 .35798 L F
.14508 .38216 m .12208 .35798 L .11902 .36445 L F
.14238 .38872 m .14508 .38216 L .11902 .36445 L F
.14788 .37563 m .12523 .35155 L .12208 .35798 L F
.15548 .3853 m .1583 .37901 L .13433 .36228 L F
.15548 .3853 m .13433 .36228 L .13124 .36848 L F
.15275 .39161 m .15548 .3853 L .13124 .36848 L F
.15275 .39161 m .13124 .36848 L .12824 .37472 L F
.1583 .37901 m .13752 .35613 L .13433 .36228 L F
.15836 .38617 m .16098 .37988 L .13573 .36277 L F
.15836 .38617 m .13573 .36277 L .13286 .36901 L F
.15584 .39248 m .15836 .38617 L .13286 .36901 L F
.15584 .39248 m .133 .36915 L .13009 .37529 L F
.133 .36915 m .13286 .36901 L .13123 .37269 L F
.133 .36915 m .13123 .37269 L .13009 .37529 L F
.11902 .36445 m .12208 .35798 L .11513 .34423 L 1 .783 0 r
F
.11902 .36445 m .11513 .34423 L .11512 .34424 L F
.11902 .36445 m .11512 .34422 L .1151 .34425 L F
.13009 .37529 m .13123 .37269 L .13001 .37518 L 1 1 0 r
F
.13 .37521 m .31229 .4229 L .31075 .42558 L .74 .254 0 r
F
.12824 .37472 m .12999 .37518 L .12998 .3752 L F
.12999 .37518 m .13001 .37518 L .12998 .3752 L F
.13001 .37518 m .31229 .4229 L .13 .37521 L F
.13001 .37518 m .13 .37521 L .12998 .3752 L F
.13019 .37539 m .15584 .39248 L .13009 .37529 L 1 1 0 r
F
.18346 .41433 m .15608 .39266 L .15341 .39881 L F
.15608 .39266 m .15584 .39248 L .15582 .39253 L F
.15608 .39266 m .15604 .39265 L .15582 .39253 L 0 .121 0 r
F
.15604 .39265 m .15275 .39161 L .15582 .39253 L F
.15604 .39265 m .15582 .39253 L .15582 .39253 L F
.15608 .39266 m .15582 .39253 L .15341 .39881 L 1 1 0 r
F
.15608 .39266 m .15582 .39253 L .15582 .39253 L 0 .121 0 r
F
.13019 .37539 m .15275 .39161 L .12824 .37472 L .065 .128 0 r
F
.15545 .39228 m .15584 .39248 L .13019 .37539 L 1 1 0 r
F
.18821 .40184 m .1882 .40184 L .18818 .40191 L .112 .131 0 r
F
.32491 .44289 m .15582 .39253 L .13019 .37539 L .065 .128 0 r
F
.15582 .39253 m .15275 .39161 L .13019 .37539 L F
.15481 .39196 m .15545 .39228 L .13019 .37539 L 1 1 0 r
F
.15578 .39262 m .15582 .39253 L .15481 .39196 L F
.15582 .39253 m .15584 .39248 L .15481 .39196 L F
.15341 .39881 m .15578 .39262 L .13019 .37539 L F
.15341 .39881 m .13019 .37539 L .12741 .3816 L F
.13019 .37539 m .13009 .37529 L .13007 .37531 L F
.13019 .37539 m .13017 .37539 L .13019 .37539 L .065 .128 0 r
F
.13019 .37539 m .13007 .37531 L .12741 .3816 L 1 1 0 r
F
.31592 .43582 m .13007 .37531 L .31075 .42558 L .286 .384 0 r
F
.13007 .37531 m .12824 .37472 L .13 .37521 L F
.13004 .37527 m .13009 .37529 L .13 .37521 L 1 1 0 r
F
.13009 .37529 m .13001 .37518 L .13 .37521 L F
.13007 .37531 m .13 .37521 L .31075 .42558 L .286 .384 0 r
F
.12998 .37524 m .13004 .37527 L .13 .37521 L 1 1 0 r
F
.3107 .43111 m .31592 .43582 L .30926 .4283 L F
.32305 .44225 m .13019 .37539 L .31592 .43582 L .065 .128 0 r
F
.13019 .37539 m .13019 .37539 L .31592 .43582 L F
.13017 .37539 m .13007 .37531 L .31592 .43582 L F
.31453 .43863 m .31592 .43582 L .3107 .43111 L 1 1 0 r
F
.32491 .44289 m .32305 .44225 L .31592 .43582 L .065 .128 0 r
F
.13017 .37539 m .12824 .37472 L .13007 .37531 L F
.12741 .3816 m .13007 .37531 L .12998 .37524 L 1 1 0 r
F
.13007 .37531 m .13009 .37529 L .12998 .37524 L F
.12998 .3752 m .13 .37521 L .13 .37521 L .74 .254 0 r
F
.12824 .37472 m .13124 .36848 L .13278 .36894 L F
.13001 .37518 m .13286 .36901 L .13278 .36894 L 1 1 0 r
F
.13123 .37269 m .13286 .36901 L .13001 .37518 L F
.19197 .38161 m .19471 .37535 L .16728 .3604 L F
.19197 .38161 m .16728 .3604 L .1642 .36656 L F
.19258 .38899 m .19507 .38272 L .16649 .36742 L F
.19258 .38899 m .16649 .36742 L .16369 .37363 L F
.16098 .37988 m .16369 .37363 L .13869 .35656 L F
.16098 .37988 m .13869 .35656 L .13573 .36277 L F
.19471 .37535 m .17045 .35428 L .16728 .3604 L F
.19507 .38272 m .19765 .37647 L .16939 .36123 L F
.19507 .38272 m .16939 .36123 L .16649 .36742 L F
.16369 .37363 m .16649 .36742 L .32369 .42228 L .643 .164 0 r
F
.19765 .37647 m .20032 .37026 L .17238 .35509 L 1 1 0 r
F
.19765 .37647 m .17238 .35509 L .16939 .36123 L F
.33206 .42884 m .33361 .42611 L .32531 .4196 L F
.33206 .42884 m .32531 .4196 L .32529 .41964 L F
.33206 .42884 m .32529 .41964 L .32376 .42234 L F
.16939 .36123 m .32692 .41697 L .32532 .41959 L .645 .164 0 r
F
.17238 .35509 m .32868 .41436 L .32693 .41694 L 0 .107 0 r
F
.33361 .42611 m .33521 .4234 L .32698 .41696 L 1 1 0 r
F
.32692 .41697 m .32696 .41698 L .32531 .4196 L .645 .164 0 r
F
.33361 .42611 m .32696 .41698 L .32531 .4196 L 1 1 0 r
F
.16939 .36123 m .17238 .35509 L .32698 .41696 L .645 .164 0 r
F
.32868 .41436 m .32716 .41668 L .32693 .41694 L 0 .107 0 r
F
.32698 .41696 m .32868 .41436 L .3269 .4169 L 1 1 0 r
F
.33521 .4234 m .32868 .41436 L .32698 .41696 L F
.32868 .41436 m .32722 .41661 L .32716 .41668 L 0 .107 0 r
F
.32696 .41698 m .32698 .41696 L .32762 .41722 L .645 .164 0 r
F
.16939 .36123 m .32698 .41696 L .32696 .41698 L F
.32696 .41698 m .32698 .41696 L .32696 .41698 L 1 1 0 r
F
.33361 .42611 m .32698 .41696 L .32696 .41698 L F
.32696 .41698 m .32762 .41722 L .32535 .41956 L .645 .164 0 r
F
.32696 .41698 m .32535 .41956 L .32531 .4196 L F
.32531 .4196 m .3269 .4169 L .3252 .41952 L 1 1 0 r
F
.32696 .41698 m .3269 .4169 L .32531 .4196 L F
.32531 .4196 m .32532 .41959 L .32531 .4196 L .645 .164 0 r
F
.16939 .36123 m .32532 .41959 L .32531 .4196 L F
.32529 .41964 m .32531 .4196 L .3252 .41952 L 1 1 0 r
F
.16649 .36742 m .32531 .4196 L .32529 .41964 L .644 .164 0 r
F
.32529 .41964 m .32531 .4196 L .32529 .41964 L 1 1 0 r
F
.32532 .41959 m .32532 .41959 L .32531 .4196 L .645 .164 0 r
F
.3237 .42228 m .32624 .41995 L .32491 .4227 L .644 .164 0 r
F
.32376 .42234 m .32527 .41968 L .32369 .42228 L 1 1 0 r
F
.16649 .36742 m .32523 .41962 L .32369 .42228 L .644 .164 0 r
F
.32523 .41962 m .32529 .41964 L .32369 .42228 L F
.16649 .36742 m .16939 .36123 L .32531 .4196 L F
.16369 .37363 m .32369 .42228 L .32366 .42233 L .643 .164 0 r
F
.16369 .37363 m .32366 .42233 L .13869 .35656 L F
.32366 .42232 m .32369 .42228 L .32355 .42217 L 1 1 0 r
F
.32366 .42233 m .32369 .42228 L .32491 .4227 L .643 .164 0 r
F
.32366 .42233 m .32491 .4227 L .32352 .42221 L F
.33055 .4316 m .32366 .42233 L .32193 .42484 L 1 1 0 r
F
.32366 .42233 m .32355 .42217 L .32352 .42221 L F
.32364 .42232 m .32352 .42221 L .13869 .35656 L .643 .164 0 r
F
.32366 .42233 m .32352 .42221 L .32364 .42232 L F
.13869 .35656 m .32352 .42221 L .31618 .41457 L .116 .129 0 r
F
.32327 .42193 m .32355 .42217 L .31975 .4179 L 1 1 0 r
F
.32527 .41968 m .32529 .41964 L .32369 .42228 L F
.32369 .42228 m .32529 .41964 L .3237 .42228 L .644 .164 0 r
F
.32529 .41964 m .32529 .41964 L .32376 .42234 L 1 1 0 r
F
.32529 .41964 m .32624 .41995 L .3237 .42228 L .644 .164 0 r
F
.32529 .41964 m .32523 .41956 L .32381 .42206 L 1 1 0 r
F
.32529 .41964 m .32381 .42206 L .32369 .42228 L F
.32369 .42228 m .3252 .41952 L .32355 .42217 L F
.32523 .41956 m .3252 .41952 L .32369 .42228 L F
.31972 .41788 m .31755 .41182 L .31618 .41457 L F
.32355 .42217 m .3252 .41952 L .32243 .4164 L F
.32355 .42217 m .32243 .4164 L .32236 .41644 L F
.32112 .41711 m .32233 .4163 L .32231 .41628 L F
.32112 .41711 m .32231 .41628 L .31755 .41182 L F
.31975 .4179 m .32112 .41711 L .31972 .41788 L F
.31985 .41801 m .31982 .41786 L .31975 .4179 L F
.32355 .42217 m .32112 .41711 L .31985 .41801 L F
.32112 .41711 m .31755 .41182 L .31972 .41788 L F
.32112 .41711 m .32111 .41709 L .31985 .41801 L F
.32231 .41628 m .31897 .40909 L .31755 .41182 L F
.32111 .41709 m .31887 .41242 L .31983 .41794 L F
.32111 .41709 m .31983 .41794 L .31985 .41801 L F
.32233 .4163 m .32232 .41627 L .32231 .41628 L F
.32232 .41627 m .31897 .40909 L .32231 .41628 L F
.32355 .42217 m .32233 .4163 L .32112 .41711 L F
.32491 .4227 m .32112 .41711 L .31975 .4179 L F
.31975 .4179 m .31887 .41242 L .31716 .41499 L F
.31982 .41786 m .31887 .41242 L .31975 .4179 L F
.32112 .41711 m .32233 .4163 L .32111 .41709 L F
.32236 .41644 m .32243 .4164 L .32233 .4163 L F
.32529 .41964 m .32531 .4196 L .32624 .41995 L .644 .164 0 r
F
.32531 .4196 m .32752 .41732 L .32624 .41995 L .645 .164 0 r
F
.32752 .41732 m .32762 .41722 L .32624 .41995 L F
.3252 .41952 m .3269 .4169 L .32505 .41483 L 1 1 0 r
F
.3249 .41466 m .32043 .40638 L .31897 .40909 L F
.32336 .41565 m .31897 .40909 L .32233 .4163 L F
.3234 .41571 m .32505 .41483 L .32493 .41469 L F
.3252 .41952 m .32505 .41483 L .3234 .41571 L F
.32696 .41698 m .32698 .41696 L .3269 .4169 L F
.32868 .41436 m .32863 .41432 L .3269 .4169 L F
.32565 .41424 m .32043 .40638 L .32493 .41469 L F
.32493 .41469 m .32564 .41421 L .32492 .41467 L F
.3269 .4169 m .32568 .41428 L .32493 .41469 L F
.32693 .41694 m .32893 .41465 L .32762 .41722 L 0 .107 0 r
F
.33065 .4171 m .33678 .42081 L .32868 .41436 L 1 1 0 r
F
.32897 .4146 m .32899 .41458 L .32868 .41436 L 0 .107 0 r
F
.33123 .41639 m .32899 .41458 L .32897 .4146 L F
.33123 .41639 m .33931 .42182 L .32899 .41458 L F
.32893 .41465 m .32906 .4145 L .32762 .41722 L F
.3269 .4169 m .32864 .41431 L .32753 .41306 L 1 1 0 r
F
.3269 .4169 m .32753 .41306 L .32568 .41428 L F
.32868 .41436 m .32864 .41431 L .32863 .41432 L F
.32868 .41436 m .32906 .4145 L .32722 .41661 L 0 .107 0 r
F
.32762 .41722 m .32906 .4145 L .32732 .4132 L 1 1 0 r
F
.32568 .41428 m .32732 .4132 L .32258 .40961 L F
.32762 .41722 m .32732 .4132 L .32568 .41428 L F
.32568 .41428 m .32753 .41306 L .32244 .40736 L F
.32624 .41994 m .32762 .41722 L .32493 .41469 L F
.32624 .41995 m .32762 .41722 L .32624 .41994 L F
.32762 .41722 m .32568 .41428 L .32493 .41469 L F
.32568 .41428 m .32565 .41424 L .32493 .41469 L F
.32568 .41428 m .32567 .41426 L .32493 .41469 L F
.32567 .41426 m .32564 .41421 L .32493 .41469 L F
.32491 .4147 m .32493 .41469 L .3249 .41466 L F
.32624 .41995 m .32493 .41469 L .32491 .4147 L F
.3234 .41571 m .3249 .41466 L .31897 .40909 L F
.32624 .41995 m .3249 .41466 L .3234 .41571 L F
.32241 .41639 m .32337 .41566 L .32236 .41633 L F
.3252 .41952 m .3234 .41571 L .32241 .41639 L F
.3234 .41571 m .32337 .41566 L .32241 .41639 L F
.32236 .41633 m .32064 .40987 L .31887 .41242 L F
.3234 .41571 m .32336 .41565 L .32259 .41614 L F
.3234 .41571 m .32259 .41614 L .32233 .4163 L F
.32337 .41566 m .32064 .40987 L .32236 .41633 L F
.32493 .41469 m .32491 .41466 L .3249 .41466 L F
.32491 .41466 m .32043 .40638 L .3249 .41466 L F
.32337 .41566 m .32493 .41469 L .32064 .40987 L F
.3234 .41571 m .32493 .41469 L .32337 .41566 L F
.32624 .41995 m .3234 .41571 L .32233 .4163 L F
.3249 .4227 m .32624 .41995 L .32233 .4163 L F
.32491 .4227 m .32624 .41995 L .3249 .4227 L F
.32491 .4227 m .32233 .4163 L .32112 .41711 L F
.32111 .41709 m .32233 .4163 L .31887 .41242 L F
.32352 .42221 m .32491 .4227 L .31975 .4179 L .116 .129 0 r
F
.32352 .42221 m .31975 .4179 L .31618 .41457 L F
.31851 .41778 m .32327 .42193 L .31716 .41499 L 1 1 0 r
F
.32327 .42193 m .31975 .4179 L .31716 .41499 L F
.32193 .42484 m .32352 .42221 L .31851 .41778 L F
.32352 .42221 m .32355 .42217 L .31851 .41778 L F
.32366 .42233 m .32352 .42221 L .32193 .42484 L F
.32366 .42233 m .32352 .42221 L .32352 .42221 L .643 .164 0 r
F
.32381 .42244 m .33206 .42884 L .32369 .42228 L 1 1 0 r
F
.33055 .4316 m .33201 .42894 L .32381 .42244 L F
.33201 .42894 m .33206 .42884 L .32381 .42244 L F
.33055 .4316 m .32369 .42228 L .32366 .42232 L F
.13286 .36901 m .13573 .36277 L .31358 .42012 L .74 .255 0 r
F
.12508 .35149 m .10826 .32622 L .10474 .33252 L 1 1 0 r
F
.12208 .35798 m .12523 .35155 L .11826 .33797 L 1 .796 0 r
F
.12208 .35798 m .11826 .33797 L .11508 .34413 L F
.12523 .35155 m .12154 .33186 L .11826 .33797 L .561 .813 0 r
F
.13433 .36228 m .13752 .35613 L .11869 .33815 L 1 1 0 r
F
.13573 .36277 m .13869 .35656 L .31485 .41734 L .74 .255 0 r
F
.13433 .36228 m .11869 .33815 L .11527 .34421 L 1 1 0 r
F
.13124 .36848 m .13433 .36228 L .11527 .34421 L F
.13573 .36277 m .31485 .41734 L .31358 .42012 L .74 .255 0 r
F
.13286 .36901 m .31358 .42012 L .25175 .39872 L F
.13752 .35613 m .12222 .33215 L .11869 .33815 L 1 1 0 r
F
.13869 .35656 m .31618 .41457 L .31485 .41734 L .116 .129 0 r
F
.13124 .36848 m .11527 .34421 L .25175 .39872 L 1 1 0 r
F
.13124 .36848 m .25175 .39872 L .13278 .36894 L F
.13278 .36894 m .25175 .39872 L .112 .35033 L .74 .255 0 r
F
.13286 .36901 m .25175 .39872 L .13278 .36894 L F
.13278 .36894 m .25175 .39872 L .31229 .4229 L 1 1 0 r
F
.13001 .37518 m .13278 .36894 L .31229 .4229 L .74 .254 0 r
F
.12824 .37472 m .13278 .36894 L .13001 .37518 L F
.13001 .37518 m .13278 .36894 L .11204 .35037 L 1 1 0 r
F
.12715 .38123 m .13 .37521 L .10903 .35657 L F
.12741 .3816 m .13 .37521 L .12715 .38123 L F
.13 .37521 m .11204 .35038 L .10903 .35657 L F
.13001 .37518 m .11204 .35038 L .13 .37521 L F
.11204 .35038 m .112 .35033 L .11086 .35272 L F
.11204 .35038 m .11086 .35272 L .10903 .35657 L F
.11512 .34424 m .11513 .34423 L .11512 .34422 L 1 .783 0 r
F
.1151 .34425 m .11512 .34422 L .11508 .34413 L F
.11204 .35038 m .11204 .35037 L .112 .35033 L 1 1 0 r
F
.13001 .37518 m .11204 .35037 L .11204 .35038 L F
.13 .37521 m .31229 .4229 L .13 .37521 L .74 .254 0 r
F
.318 .43852 m .32491 .44289 L .31592 .43582 L 1 1 0 r
F
.33436 .44888 m .15608 .39266 L .32491 .44289 L 0 .121 0 r
F
.15608 .39266 m .15582 .39253 L .32491 .44289 L F
.3236 .44577 m .32491 .44289 L .318 .43852 L 1 1 0 r
F
.33608 .44943 m .33436 .44888 L .32491 .44289 L 0 .121 0 r
F
.32761 .44546 m .33608 .44943 L .32491 .44289 L 1 1 0 r
F
.34775 .45489 m .18599 .4082 L .33608 .44943 L .692 .282 0 r
F
.18599 .4082 m .18559 .40803 L .33608 .44943 L F
.33489 .45238 m .33608 .44943 L .32761 .44546 L 1 1 0 r
F
.34934 .45535 m .34775 .45489 L .33608 .44943 L .692 .282 0 r
F
.21697 .42801 m .21809 .42412 L .18682 .40865 L 1 1 0 r
F
.21809 .42412 m .21881 .42161 L .18682 .40865 L F
.35936 .44825 m .35152 .44546 L .35139 .44575 L .683 .265 0 r
F
.35145 .44541 m .35263 .44281 L .34122 .4378 L 1 1 0 r
F
.36023 .44537 m .35277 .44253 L .35264 .44281 L .682 .265 0 r
F
.35269 .44248 m .35391 .43988 L .3426 .43494 L 1 1 0 r
F
.36115 .44249 m .35404 .43962 L .35391 .43988 L .68 .265 0 r
F
.35396 .43956 m .35521 .43698 L .34401 .43211 L 1 1 0 r
F
.35632 .43746 m .35534 .43672 L .35522 .43698 L F
.36211 .43962 m .35534 .43672 L .35522 .43698 L .678 .264 0 r
F
.35653 .43435 m .35664 .43413 L .35655 .43409 L 1 1 0 r
F
.35534 .43672 m .35655 .43409 L .34546 .4293 L F
.35534 .43672 m .3566 .43411 L .35655 .43409 L .678 .264 0 r
F
.36211 .43962 m .3631 .43677 L .3566 .43411 L F
.36211 .43962 m .3566 .43411 L .35534 .43672 L F
.33521 .4234 m .33678 .42081 L .33065 .4171 L 1 1 0 r
F
.33558 .42361 m .3368 .42082 L .33521 .4234 L F
.3368 .42082 m .33678 .42081 L .33521 .4234 L F
.32492 .41467 m .32244 .40736 L .32064 .40987 L F
.32564 .41421 m .32244 .40736 L .32492 .41467 L F
.32906 .4145 m .32796 .41283 L .32752 .41306 L F
.3273 .41318 m .32906 .4145 L .32752 .41306 L F
.33132 .41622 m .33931 .42182 L .32906 .4145 L 0 .107 0 r
F
.33713 .42101 m .33718 .42092 L .33931 .42182 L .529 .072 0 r
F
.33713 .42101 m .33718 .42092 L .33713 .42101 L 1 1 0 r
F
.33713 .42101 m .33931 .42182 L .33679 .42081 L .529 .072 0 r
F
.34546 .4293 m .34687 .42668 L .33747 .42121 L 1 1 0 r
F
.34687 .42668 m .34695 .42652 L .33747 .42121 L F
.34546 .4293 m .33713 .42101 L .33558 .42361 L F
.34216 .41306 m .3422 .413 L .34197 .41286 L F
.33522 .40832 m .33571 .40798 L .33569 .40797 L F
.33522 .40832 m .33569 .40797 L .33412 .40675 L F
.3363 .40958 m .33571 .40798 L .33522 .40832 L F
.34216 .41306 m .34197 .41286 L .34193 .41293 L F
.34216 .41641 m .34365 .41374 L .3363 .40958 L F
.35075 .41777 m .35495 .42007 L .34365 .41374 L 0 .076 0 r
F
.34365 .41374 m .3452 .4111 L .34365 .41374 L 1 1 0 r
F
.36233 .42257 m .36155 .42214 L .35174 .41822 L .665 .26 0 r
F
.36233 .42257 m .35171 .41821 L .35177 .41824 L F
.36233 .42257 m .35326 .41568 L .35171 .41821 L 1 1 0 r
F
.36233 .42257 m .35177 .41824 L .35495 .42007 L .665 .26 0 r
F
.35495 .42007 m .35171 .41821 L .3452 .4111 L 0 .076 0 r
F
.35171 .41821 m .35169 .41818 L .3452 .4111 L F
.36751 .42548 m .36233 .42257 L .35508 .42011 L .665 .26 0 r
F
.36751 .42548 m .35508 .42011 L .35509 .42013 L F
.36635 .42828 m .36751 .42548 L .35495 .42007 L 1 1 0 r
F
.3536 .42279 m .36579 .42602 L .35726 .42086 L .016 .124 0 r
F
.36579 .42602 m .36707 .42636 L .35726 .42086 L F
.35495 .42007 m .3452 .4111 L .34365 .41374 L 0 .076 0 r
F
.35096 .41705 m .35726 .42086 L .34921 .41486 L 1 1 0 r
F
.3536 .42279 m .35587 .42159 L .35593 .42324 L .016 .124 0 r
F
.35587 .42159 m .35726 .42086 L .35635 .4225 L F
.35587 .42159 m .35635 .4225 L .35593 .42324 L F
.35509 .42013 m .35508 .42011 L .35495 .42007 L .665 .26 0 r
F
.35593 .42324 m .35726 .42086 L .35096 .41705 L 1 1 0 r
F
.36223 .4225 m .3637 .42 L .35326 .41568 L F
.36872 .42271 m .36381 .41981 L .3637 .42 L .662 .258 0 r
F
.36371 .41974 m .36521 .41725 L .35492 .41304 L 1 1 0 r
F
.36997 .41995 m .36533 .41708 L .36522 .41726 L .659 .257 0 r
F
.37126 .41722 m .36687 .41437 L .36676 .41454 L .533 0 0 r
F
.22135 .32782 m .29844 .37304 L .32536 .39173 L .54 .073 0 r
F
.36602 .41424 m .35835 .40786 L .35662 .41043 L 1 1 0 r
F
.36706 .41451 m .35835 .40786 L .36602 .41424 L F
.37898 .41785 m .37847 .41751 L .36766 .41467 L .549 .158 0 r
F
.37885 .41809 m .378 .41757 L .36757 .41464 L 1 1 0 r
F
.37898 .41785 m .369 .41212 L .37885 .41809 L F
.37898 .41785 m .36757 .41464 L .36764 .41469 L .549 .158 0 r
F
.378 .41757 m .369 .41212 L .36757 .41464 L 1 1 0 r
F
.36687 .41437 m .369 .41212 L .35835 .40786 L F
.36747 .41482 m .36757 .41464 L .36687 .41437 L F
.36687 .41437 m .36757 .41464 L .36682 .41434 L .533 0 0 r
F
.36757 .41464 m .36756 .41464 L .36682 .41434 L F
.36757 .41464 m .369 .41212 L .36687 .41437 L 1 1 0 r
F
.37126 .41722 m .36757 .41464 L .36687 .41437 L .533 0 0 r
F
.36926 .41534 m .36757 .41464 L .36747 .41482 L 1 1 0 r
F
.37885 .41809 m .36757 .41464 L .36926 .41534 L F
.37994 .4184 m .37898 .41785 L .37885 .41809 L F
.3802 .41525 m .37056 .40944 L .369 .41212 L F
.38125 .41554 m .38033 .41502 L .3802 .41525 L F
.38552 .41862 m .38033 .41502 L .3802 .41525 L .545 .156 0 r
F
.38033 .41502 m .38032 .41501 L .3802 .41525 L F
.38033 .41502 m .38032 .41501 L .3802 .41525 L 1 1 0 r
F
.38032 .41501 m .37056 .40944 L .3802 .41525 L F
.38441 .42144 m .38552 .41862 L .3802 .41525 L .549 .158 0 r
F
.38019 .41527 m .3802 .41525 L .38016 .41522 L F
.38441 .42144 m .3802 .41525 L .38019 .41527 L F
.3784 .41909 m .37885 .41809 L .36926 .41534 L 1 1 0 r
F
.37944 .41952 m .37885 .41809 L .3784 .41909 L F
.38441 .42144 m .37898 .41785 L .37126 .41722 L .549 .158 0 r
F
.37898 .41785 m .36764 .41469 L .37126 .41722 L F
.37898 .41785 m .3802 .41525 L .37886 .41778 L 1 1 0 r
F
.37886 .41778 m .3802 .41525 L .369 .41212 L F
.38552 .41862 m .38155 .4125 L .38033 .41502 L .545 .156 0 r
F
.38155 .4125 m .38146 .41236 L .38033 .41502 L F
.38033 .41502 m .38158 .41244 L .38021 .41495 L 1 1 0 r
F
.38158 .41244 m .38146 .41235 L .38146 .41236 L .541 .153 0 r
F
.3817 .41221 m .37215 .40679 L .38158 .41244 L 1 1 0 r
F
.38552 .41862 m .38666 .41582 L .38158 .41244 L .545 .156 0 r
F
.38155 .4125 m .38158 .41244 L .38146 .41236 L F
.38552 .41862 m .38158 .41244 L .38155 .4125 L F
.38298 .40965 m .37376 .40418 L .37215 .40679 L 1 1 0 r
F
.38299 .40965 m .38298 .40965 L .38298 .40965 L F
.38298 .40965 m .37376 .40418 L .38298 .40965 L F
.38301 .40962 m .37376 .40418 L .38299 .40965 L F
.38171 .41222 m .38299 .40965 L .37215 .40679 L F
.38171 .41222 m .38307 .40971 L .38299 .40965 L .541 .153 0 r
F
.39508 .41801 m .39615 .415 L .38258 .41271 L 1 1 0 r
F
.38666 .41582 m .38784 .41305 L .38307 .40971 L .541 .153 0 r
F
.38666 .41582 m .38307 .40971 L .38171 .41222 L F
.38171 .41222 m .38158 .41244 L .38159 .41244 L F
.38158 .41244 m .37215 .40679 L .37056 .40944 L 1 1 0 r
F
.38324 .40951 m .37376 .40418 L .38313 .40969 L F
.38159 .41244 m .38158 .41244 L .38158 .41244 L .541 .153 0 r
F
.38021 .41495 m .38158 .41244 L .37056 .40944 L 1 1 0 r
F
.38666 .41582 m .38171 .41222 L .38159 .41244 L .541 .153 0 r
F
.38784 .41305 m .38438 .40696 L .38312 .40944 L .537 .151 0 r
F
.38438 .40696 m .38429 .4068 L .38312 .40944 L F
.38312 .40944 m .38441 .40689 L .38299 .40937 L 1 1 0 r
F
.38441 .40689 m .38429 .4068 L .38429 .4068 L .533 .148 0 r
F
.38453 .40669 m .37541 .40159 L .38441 .40689 L 1 1 0 r
F
.38784 .41305 m .38905 .41031 L .38441 .40689 L .537 .151 0 r
F
.38438 .40696 m .38441 .40689 L .38429 .4068 L F
.38784 .41305 m .38441 .40689 L .38438 .40696 L F
.38586 .40416 m .37708 .39905 L .37541 .40159 L 1 1 0 r
F
.38586 .40416 m .38586 .40416 L .38586 .40416 L F
.38586 .40416 m .37708 .39905 L .38586 .40416 L F
.38589 .40413 m .37708 .39905 L .38586 .40416 L F
.38454 .40669 m .38586 .40416 L .37541 .40159 L F
.38454 .40669 m .38595 .40423 L .38586 .40416 L .533 .148 0 r
F
.38905 .41031 m .3903 .40759 L .38595 .40423 L F
.38905 .41031 m .38595 .40423 L .38454 .40669 L F
.38454 .40669 m .38441 .40689 L .38442 .4069 L F
.38441 .40689 m .37541 .40159 L .37376 .40418 L 1 1 0 r
F
.38672 .40438 m .38612 .40404 L .38602 .4042 L F
.38442 .4069 m .38441 .40689 L .38441 .40689 L .533 .148 0 r
F
.38299 .40937 m .38441 .40689 L .37376 .40418 L 1 1 0 r
F
.38905 .41031 m .38454 .40669 L .38442 .4069 L .533 .148 0 r
F
.3903 .40759 m .38684 .40417 L .38597 .40395 L .705 .034 0 r
F
.39951 .40609 m .3984 .40566 L .39828 .40593 L 1 1 0 r
F
.3984 .40566 m .39947 .40304 L .39839 .40565 L .4 .07 0 r
F
.40336 .41008 m .39955 .4032 L .3984 .40566 L F
.39955 .4032 m .39947 .40304 L .3984 .40566 L F
.39947 .40304 m .39944 .40299 L .39919 .40362 L F
.39947 .40304 m .39919 .40362 L .39839 .40565 L F
.39948 .40302 m .38961 .39897 L .39947 .40302 L 1 1 0 r
F
.3996 .40276 m .38961 .39897 L .39948 .40302 L F
.3996 .40276 m .39948 .40302 L .39949 .40303 L F
.40336 .41008 m .40438 .40722 L .39947 .40302 L .4 .07 0 r
F
.39947 .40304 m .39947 .40302 L .39944 .40299 L F
.39948 .40307 m .39949 .40303 L .39947 .40302 L 1 1 0 r
F
.40336 .41008 m .39947 .40302 L .39947 .40304 L .4 .07 0 r
F
.39789 .40692 m .39828 .40593 L .38885 .40466 L 1 1 0 r
F
.39907 .40722 m .39828 .40593 L .39789 .40692 L F
.40336 .41008 m .3984 .40566 L .3903 .40759 L .4 .07 0 r
F
.3984 .40566 m .38693 .40426 L .3903 .40759 L F
.3984 .40566 m .39947 .40302 L .39826 .40561 L 1 1 0 r
F
.39961 .40277 m .39948 .40302 L .39949 .40303 L .395 .069 0 r
F
.39947 .40302 m .38961 .39897 L .38816 .40166 L 1 1 0 r
F
.40067 .40317 m .39961 .40277 L .39949 .40303 L F
.39961 .40277 m .4007 .40017 L .3996 .40276 L .395 .069 0 r
F
.40438 .40722 m .40078 .40033 L .39961 .40277 L F
.40078 .40033 m .4007 .40017 L .39961 .40277 L F
.4007 .40017 m .40067 .40011 L .40042 .40072 L F
.4007 .40017 m .40042 .40072 L .3996 .40276 L F
.40071 .40014 m .40071 .40014 L .40071 .40015 L 1 1 0 r
F
.40071 .40014 m .39109 .39631 L .40071 .40015 L F
.40083 .39989 m .39109 .39631 L .40071 .40014 L F
.40083 .39989 m .40071 .40014 L .40072 .40015 L F
.40438 .40722 m .40542 .40439 L .40071 .40015 L .395 .069 0 r
F
.4007 .40017 m .40071 .40015 L .40067 .40011 L F
.40071 .40019 m .40072 .40015 L .40071 .40015 L 1 1 0 r
F
.40438 .40722 m .40071 .40015 L .4007 .40017 L .395 .069 0 r
F
.39826 .40561 m .39947 .40302 L .38816 .40166 L 1 1 0 r
F
.39949 .40303 m .39948 .40302 L .39947 .40302 L .395 .069 0 r
F
.40438 .40722 m .39961 .40277 L .39949 .40303 L F
.39961 .40277 m .40071 .40015 L .39947 .40271 L 1 1 0 r
F
.40085 .3999 m .40071 .40015 L .40072 .40016 L .391 .069 0 r
F
.40071 .40015 m .39109 .39631 L .38961 .39897 L 1 1 0 r
F
.40185 .40027 m .40085 .3999 L .40072 .40015 L F
.40085 .3999 m .40189 .39732 L .40083 .39989 L .391 .069 0 r
F
.40542 .40439 m .402 .39755 L .40085 .3999 L F
.402 .39755 m .40189 .39732 L .40085 .3999 L F
.40189 .39732 m .4018 .39715 L .40083 .39989 L F
.39947 .40271 m .40071 .40015 L .38961 .39897 L 1 1 0 r
F
.40072 .40016 m .40071 .40015 L .40071 .40015 L .391 .069 0 r
F
.40542 .40439 m .40085 .3999 L .40072 .40016 L F
.40542 .40439 m .40649 .40158 L .40195 .39729 L F
.40191 .39737 m .40195 .39729 L .4018 .39715 L F
.40542 .40439 m .40195 .39729 L .40191 .39737 L F
.40195 .39729 m .39259 .39369 L .39109 .39631 L 1 1 0 r
F
.40197 .39729 m .40196 .39729 L .40195 .39729 L F
.40649 .40158 m .40209 .39705 L .40195 .39729 L .386 .068 0 r
F
.40209 .39705 m .40208 .39704 L .40195 .39729 L F
.40196 .39729 m .40196 .39729 L .40195 .39729 L 1 1 0 r
F
.40196 .39729 m .39259 .39369 L .40195 .39729 L F
.40085 .3999 m .40195 .39729 L .4007 .39985 L F
.40209 .39705 m .40322 .39446 L .39259 .39369 L F
.40305 .39739 m .40322 .39446 L .40209 .39705 L F
.40329 .39467 m .40321 .39449 L .40209 .39705 L .386 .068 0 r
F
.40649 .40158 m .40329 .39467 L .40209 .39705 L F
.40195 .39729 m .40181 .39714 L .4018 .39715 L F
.40209 .39705 m .39259 .39369 L .40197 .39729 L 1 1 0 r
F
.40322 .39446 m .39411 .3911 L .39259 .39369 L F
.40339 .39448 m .40324 .39442 L .40322 .39446 L F
.40324 .39442 m .39411 .3911 L .40322 .39446 L F
.40649 .40158 m .40759 .39879 L .40322 .39446 L .386 .068 0 r
F
.40649 .40158 m .40322 .39446 L .40321 .39448 L F
.40336 .39423 m .40334 .39422 L .40324 .39442 L 1 1 0 r
F
.40334 .39422 m .39411 .3911 L .40323 .39442 L F
.40334 .39422 m .40323 .39442 L .40324 .39442 L F
.40336 .39423 m .40324 .39442 L .40339 .39448 L F
.40323 .39448 m .40329 .39434 L .40322 .39446 L .382 .068 0 r
F
.40759 .39879 m .40336 .39423 L .40323 .39448 L F
.40336 .39423 m .40335 .39422 L .40323 .39448 L F
.4007 .39985 m .40195 .39729 L .39109 .39631 L 1 1 0 r
F
.40551 .39172 m .40479 .39148 L .40468 .39167 L F
.40479 .39148 m .39565 .38854 L .40468 .39167 L F
.40464 .39144 m .40511 .39088 L .39565 .38854 L F
.40511 .39088 m .40677 .38892 L .40616 .3889 L F
.40511 .39088 m .40616 .3889 L .39565 .38854 L F
.40551 .39172 m .40562 .39146 L .40464 .39144 L F
.40464 .39144 m .40561 .39144 L .40462 .39141 L .91 .064 0 r
F
.40492 .39144 m .40561 .39144 L .40464 .39144 L F
.40562 .39146 m .40561 .39144 L .40465 .39144 L F
.40562 .39146 m .40677 .38892 L .40464 .39144 L 1 1 0 r
F
.40465 .39144 m .40492 .39144 L .40464 .39144 L .91 .064 0 r
F
.41795 .39177 m .40811 .39151 L .40551 .39172 L 1 1 0 r
F
.40871 .39603 m .40562 .39146 L .40465 .39144 L .91 .064 0 r
F
.41784 .3877 m .40804 .38615 L .40677 .38892 L 1 1 0 r
F
.41798 .3874 m .4188 .38457 L .41796 .38737 L .286 .05 0 r
F
.4192 .38755 m .41798 .3874 L .41786 .3877 L 1 1 0 r
F
.4192 .38755 m .41885 .38461 L .41884 .38466 L F
.4192 .38755 m .41883 .38461 L .41798 .3874 L F
.42231 .39308 m .41896 .38496 L .41798 .3874 L .286 .05 0 r
F
.41896 .38496 m .4188 .38457 L .41798 .3874 L F
.41786 .3877 m .41791 .38754 L .41784 .3877 L 1 1 0 r
F
.41798 .3874 m .41796 .38739 L .41786 .3877 L F
.42231 .39308 m .41798 .3874 L .41784 .3877 L .286 .05 0 r
F
.41798 .3874 m .41796 .38737 L .41784 .3877 L F
.41791 .38754 m .41796 .38739 L .41784 .3877 L 1 1 0 r
F
.41784 .3877 m .41764 .38744 L .41763 .38746 L .286 .05 0 r
F
.41796 .38739 m .40804 .38615 L .41784 .3877 L 1 1 0 r
F
.41984 .38153 m .41926 .38019 L .41908 .38053 L .279 .049 0 r
F
.41996 .38121 m .41926 .38019 L .41984 .38153 L F
.41997 .38124 m .41065 .38069 L .41985 .38153 L 1 1 0 r
F
.41984 .38153 m .41065 .38069 L .40934 .3834 L F
.41985 .38153 m .41065 .38069 L .41984 .38153 L F
.41985 .38158 m .41986 .38153 L .41984 .38153 L F
.42318 .39009 m .42406 .38711 L .41984 .38153 L .282 .05 0 r
F
.42318 .39009 m .41984 .38153 L .41983 .38156 L F
.41884 .38466 m .41885 .38461 L .41883 .38461 L 1 1 0 r
F
.41883 .38464 m .41883 .38461 L .41883 .38463 L .286 .05 0 r
F
.41798 .3874 m .41883 .38461 L .40804 .38615 L 1 1 0 r
F
.42231 .39308 m .41883 .38461 L .41883 .38464 L .286 .05 0 r
F
.42318 .39009 m .41898 .38431 L .41883 .38461 L .282 .05 0 r
F
.41898 .38431 m .41896 .38431 L .41896 .38434 L 1 1 0 r
F
.41896 .38431 m .40934 .3834 L .41885 .38457 L F
.41883 .38461 m .40934 .3834 L .40804 .38615 L F
.41883 .38463 m .41883 .38461 L .4188 .38457 L .286 .05 0 r
F
.41885 .38457 m .40934 .3834 L .41883 .38461 L 1 1 0 r
F
.42231 .39308 m .42318 .39009 L .41883 .38461 L .286 .05 0 r
F
.41659 .39173 m .41687 .3908 L .40811 .39151 L 1 1 0 r
F
.41795 .39177 m .41687 .3908 L .41659 .39173 L F
.42147 .39609 m .41699 .39049 L .40871 .39603 L .29 .051 0 r
F
.41699 .39049 m .40576 .39167 L .40871 .39603 L F
.41699 .39049 m .41784 .3877 L .41685 .39047 L 1 1 0 r
F
.41685 .39047 m .41784 .3877 L .40677 .38892 L F
.41999 .38124 m .42085 .37849 L .41996 .38121 L .279 .049 0 r
F
.42406 .38711 m .42099 .37886 L .41999 .38124 L F
.42099 .37886 m .42085 .37849 L .41999 .38124 L F
.42085 .37849 m .42083 .37842 L .42069 .37886 L F
.42085 .37849 m .42069 .37886 L .41996 .38121 L F
.41926 .38019 m .34654 .27539 L .41908 .38053 L F
.42086 .37847 m .41198 .378 L .41065 .38069 L 1 1 0 r
F
.42086 .37847 m .34915 .26965 L .34654 .27539 L .275 .048 0 r
F
.42088 .37846 m .42087 .37846 L .42086 .37847 L 1 1 0 r
F
.42496 .38414 m .42101 .37818 L .42086 .37847 L .275 .048 0 r
F
.42101 .37818 m .34915 .26965 L .42086 .37847 L F
.42087 .37846 m .42087 .37846 L .42086 .37847 L 1 1 0 r
F
.42087 .37846 m .41198 .378 L .42086 .37847 L F
.42085 .37849 m .42086 .37847 L .42083 .37842 L .279 .049 0 r
F
.42086 .37849 m .42086 .37847 L .42085 .37849 L F
.42101 .37818 m .42099 .37818 L .42088 .37846 L 1 1 0 r
F
.42099 .37818 m .41198 .378 L .42087 .37846 L F
.42099 .37818 m .42087 .37846 L .42088 .37846 L F
.4219 .37541 m .41333 .37535 L .41198 .378 L F
.42204 .37513 m .4229 .37231 L .42202 .37509 L .271 .048 0 r
F
.42308 .3751 m .42204 .37513 L .42192 .3754 L 1 1 0 r
F
.42308 .3751 m .42408 .372 L .42294 .37236 L F
.42293 .37239 m .4229 .37231 L .42204 .37513 L .271 .048 0 r
F
.4219 .37541 m .35179 .26397 L .34915 .26965 L F
.42192 .3754 m .42197 .37526 L .4219 .37541 L 1 1 0 r
F
.42204 .37513 m .42202 .37513 L .42192 .3754 L F
.42587 .38119 m .42204 .37513 L .4219 .37541 L .271 .048 0 r
F
.42204 .37513 m .35179 .26397 L .4219 .37541 L F
.42197 .37526 m .42202 .37513 L .4219 .37541 L 1 1 0 r
F
.42204 .37513 m .42294 .37236 L .41333 .37535 L F
.42308 .3751 m .42294 .37236 L .42204 .37513 L F
.42307 .37282 m .42293 .37239 L .42204 .37513 L .271 .048 0 r
F
.42587 .38119 m .42307 .37282 L .42204 .37513 L F
.42189 .37543 m .4219 .37541 L .42186 .37536 L .275 .048 0 r
F
.42202 .37513 m .41333 .37535 L .4219 .37541 L 1 1 0 r
F
.40254 .2966 m .40387 .29049 L .37305 .28654 L 1 .988 0 r
F
.40387 .29049 m .37501 .28059 L .37305 .28654 L 1 .994 0 r
F
.40403 .29053 m .40404 .2905 L .40364 .28984 L .103 .015 0 r
F
.40387 .29049 m .40523 .28442 L .37501 .28059 L 1 .994 0 r
F
.40523 .28442 m .37701 .27467 L .37501 .28059 L 1 .999 0 r
F
.40538 .28446 m .40539 .28443 L .40501 .28377 L .107 .016 0 r
F
.40523 .28442 m .40661 .27838 L .37701 .27467 L 1 .999 0 r
F
.40661 .27838 m .37904 .2688 L .37701 .27467 L 1 1 0 r
F
.40676 .27842 m .40677 .27839 L .4064 .27773 L .113 .016 0 r
F
.40661 .27838 m .40801 .27238 L .37904 .2688 L 1 1 0 r
F
.42308 .37208 m .38109 .26297 L .35447 .25833 L 1 .107 0 r
F
.42345 .3722 m .42308 .37208 L .42308 .37209 L 1 1 0 r
F
.42309 .37209 m .42309 .37208 L .42308 .37208 L 1 .107 0 r
F
.42309 .37208 m .38109 .26297 L .42308 .37208 L F
.42408 .372 m .42419 .37166 L .42308 .37208 L 1 1 0 r
F
.42416 .37159 m .38109 .26297 L .42309 .37209 L 1 .107 0 r
F
.40012 .30892 m .40123 .30274 L .39993 .30891 L 1 .934 0 r
F
.40139 .30278 m .40123 .30274 L .40012 .30892 L F
.421 .33932 m .39332 .29379 L .42419 .37166 L .163 .027 0 r
F
.4346 .36599 m .43333 .36638 L .42419 .37166 L 1 1 0 r
F
.42775 .36991 m .42419 .37166 L .42408 .372 L F
.4346 .36599 m .42419 .37166 L .42775 .36991 L F
.43408 .36932 m .43448 .3668 L .42408 .372 L F
.4361 .36599 m .42775 .36991 L .42408 .372 L F
.42569 .37079 m .42419 .37166 L .42681 .37825 L .163 .027 0 r
F
.421 .33932 m .42419 .37166 L .42569 .37079 L F
.43625 .36505 m .43472 .36558 L .4346 .36599 L 1 1 0 r
F
.43472 .36558 m .43333 .36638 L .4346 .36599 L F
.43564 .3689 m .4361 .36599 L .43448 .3668 L F
.43564 .3689 m .43448 .3668 L .43408 .36932 L F
.43878 .37334 m .43472 .36558 L .42681 .37825 L .163 .027 0 r
F
.43472 .36558 m .421 .33932 L .42569 .37079 L F
.43472 .36558 m .42569 .37079 L .42681 .37825 L F
.43472 .36558 m .42509 .36891 L .43333 .36638 L 1 1 0 r
F
.43333 .36638 m .42509 .36891 L .42419 .37166 L F
.42308 .37208 m .42509 .36891 L .41469 .37272 L F
.42362 .3719 m .42416 .37159 L .4232 .37204 L 1 .107 0 r
F
.42419 .37166 m .42509 .36891 L .42308 .37208 L 1 1 0 r
F
.42416 .36925 m .41607 .37013 L .41469 .37272 L F
.42509 .36891 m .42429 .36902 L .42416 .36925 L F
.42429 .36902 m .41607 .37013 L .42416 .36925 L F
.42294 .37236 m .42271 .37198 L .4227 .37199 L 1 .107 0 r
F
.42345 .3722 m .42306 .37209 L .42294 .37236 L 1 1 0 r
F
.42681 .37825 m .42308 .37208 L .42294 .37236 L 1 .107 0 r
F
.42308 .37209 m .42308 .37208 L .42306 .37209 L 1 1 0 r
F
.42293 .37238 m .42294 .37236 L .4229 .37231 L .271 .048 0 r
F
.42294 .37236 m .42306 .37209 L .41333 .37535 L 1 1 0 r
F
.42587 .38119 m .42681 .37825 L .42294 .37236 L .271 .048 0 r
F
.42587 .38119 m .42294 .37236 L .42293 .37238 L F
.4219 .37546 m .42192 .3754 L .4219 .37541 L 1 1 0 r
F
.42101 .37818 m .4219 .37541 L .41198 .378 L F
.42496 .38414 m .42587 .38119 L .4219 .37541 L .275 .048 0 r
F
.42496 .38414 m .4219 .37541 L .42189 .37543 L F
.42087 .37851 m .42088 .37846 L .42086 .37847 L 1 1 0 r
F
.41999 .38124 m .42086 .37847 L .41065 .38069 L F
.42406 .38711 m .42496 .38414 L .42086 .37847 L .279 .049 0 r
F
.42406 .38711 m .42086 .37847 L .42086 .37849 L F
.41883 .3843 m .41984 .38153 L .40934 .3834 L 1 1 0 r
F
.42408 .372 m .42353 .37205 L .42345 .3722 L F
.42353 .37205 m .42308 .37208 L .42345 .3722 L F
.42308 .37208 m .41469 .37272 L .41334 .37532 L F
.42308 .37208 m .41334 .37532 L .41333 .37535 L F
.42314 .37218 m .42362 .3719 L .42309 .37209 L 1 .107 0 r
F
.42362 .3719 m .4232 .37204 L .42309 .37209 L F
.42681 .37825 m .42419 .37166 L .42314 .37218 L F
.42419 .37166 m .42416 .37159 L .42314 .37218 L F
.43625 .36505 m .43687 .36113 L .43526 .3622 L 1 1 0 r
F
.4014 .30275 m .40254 .2966 L .40123 .30274 L 1 .939 0 r
F
.43468 .3655 m .4352 .36214 L .4349 .36159 L .163 .027 0 r
F
.43369 .3636 m .43453 .3609 L .38109 .26297 L F
.40272 .29663 m .404 .29048 L .40271 .29661 L .103 .015 0 r
F
.40403 .29053 m .404 .29048 L .40272 .29663 L F
.40271 .29661 m .40387 .29049 L .40254 .2966 L 1 .945 0 r
F
.40403 .29053 m .40387 .29049 L .40271 .29661 L F
.43534 .36169 m .43586 .35828 L .43515 .35691 L .161 .027 0 r
F
.4343 .35961 m .43515 .35691 L .38318 .25718 L F
.43534 .36169 m .43515 .35691 L .4343 .35961 L F
.43524 .36221 m .38318 .25718 L .38109 .26297 L F
.43526 .3622 m .43524 .3622 L .43524 .36221 L 1 1 0 r
F
.43687 .36113 m .43538 .36178 L .43526 .3622 L F
.43525 .36224 m .43526 .3622 L .43524 .36221 L F
.43936 .36976 m .43538 .36178 L .43524 .36221 L .161 .027 0 r
F
.43538 .36178 m .38318 .25718 L .43524 .36221 L F
.43407 .36433 m .4349 .36159 L .43453 .3609 L .163 .027 0 r
F
.43407 .36433 m .43453 .3609 L .43369 .3636 L F
.43468 .3655 m .4349 .36159 L .43407 .36433 L F
.43625 .36505 m .43524 .36221 L .43472 .36558 L 1 1 0 r
F
.43878 .37334 m .43523 .36223 L .43468 .3655 L .163 .027 0 r
F
.43523 .36223 m .4352 .36214 L .43514 .36255 L F
.43523 .36223 m .43514 .36255 L .43468 .3655 L F
.43524 .3622 m .42612 .36583 L .43524 .36221 L 1 1 0 r
F
.43524 .36221 m .42612 .36583 L .42509 .36891 L F
.43471 .35608 m .3853 .25143 L .38318 .25718 L .159 .026 0 r
F
.43476 .35594 m .3853 .25143 L .43471 .35608 L F
.40403 .29053 m .40404 .2905 L .40387 .29049 L 1 .945 0 r
F
.40404 .2905 m .40523 .28442 L .40387 .29049 L 1 .95 0 r
F
.43604 .35793 m .43444 .35457 L .4359 .35835 L .159 .026 0 r
F
.43444 .35457 m .3853 .25143 L .4343 .35498 L F
.43444 .35457 m .4343 .35498 L .4359 .35835 L F
.43531 .35191 m .38744 .24573 L .3853 .25143 L .158 .026 0 r
F
.4367 .354 m .4355 .35135 L .43656 .35443 L F
.43592 .35834 m .43604 .35793 L .4359 .35835 L 1 1 0 r
F
.43748 .35715 m .43604 .35793 L .43592 .35834 L F
.43687 .36113 m .43748 .35715 L .43592 .35834 L F
.43538 .36178 m .43586 .35828 L .43534 .36169 L .161 .027 0 r
F
.4354 .36178 m .43592 .35834 L .4359 .35835 L 1 1 0 r
F
.4354 .36178 m .4359 .35835 L .43538 .36178 L F
.43687 .36113 m .43592 .35834 L .4354 .36178 L F
.43936 .36976 m .43589 .35839 L .43538 .36178 L .161 .027 0 r
F
.43589 .35839 m .43586 .35828 L .43538 .36178 L F
.43538 .36178 m .4359 .35835 L .42612 .36583 L 1 1 0 r
F
.43599 .35782 m .43531 .35191 L .43444 .35457 L .159 .026 0 r
F
.43748 .35715 m .4381 .35307 L .43657 .35442 L 1 1 0 r
F
.43657 .35442 m .4367 .354 L .43656 .35443 L 1 .955 0 r
F
.4381 .35307 m .4367 .354 L .43657 .35442 L F
.4367 .354 m .43718 .35034 L .43665 .35388 L .158 .026 0 r
F
.4381 .35307 m .43871 .34889 L .43723 .35041 L 1 .955 0 r
F
.40676 .27842 m .40676 .27839 L .40661 .27838 L F
.4054 .28445 m .40673 .27837 L .40539 .28443 L .113 .016 0 r
F
.40676 .27842 m .40673 .27837 L .4054 .28445 L F
.40677 .27839 m .40687 .27796 L .40676 .27839 L 1 .96 0 r
F
.40676 .27839 m .40801 .27238 L .40661 .27838 L F
.40539 .28443 m .40661 .27838 L .40523 .28442 L 1 .955 0 r
F
.40676 .27842 m .40661 .27838 L .40539 .28443 L F
.4361 .34706 m .43699 .34436 L .38961 .24008 L .157 .026 0 r
F
.43665 .35388 m .43718 .35034 L .43537 .34654 L .158 .026 0 r
F
.4345 .34915 m .43537 .34654 L .38744 .24573 L F
.43665 .35388 m .43537 .34654 L .4345 .34915 L F
.40404 .2905 m .40409 .29027 L .40404 .2905 L 1 .95 0 r
F
.43444 .35457 m .43531 .35191 L .3853 .25143 L .159 .026 0 r
F
.4355 .35135 m .38744 .24573 L .43531 .35191 L .158 .026 0 r
F
.44175 .33595 m .4411 .33304 L .44005 .33939 L .147 .019 0 r
F
.4411 .33304 m .41838 .23148 L .43942 .33626 L F
.4411 .33304 m .43942 .33626 L .44005 .33939 L F
.43723 .35045 m .43723 .35041 L .43722 .35042 L 1 .955 0 r
F
.4381 .35307 m .43723 .35041 L .43723 .35045 L F
.43638 .34866 m .38961 .24008 L .38744 .24573 L .157 .026 0 r
F
.43737 .34999 m .43656 .34813 L .43722 .35042 L F
.43722 .35042 m .43732 .35002 L .43718 .35046 L 1 .897 0 r
F
.43737 .34999 m .43784 .34623 L .43731 .34986 L .157 .026 0 r
F
.43871 .34889 m .43737 .34999 L .43723 .35041 L 1 .897 0 r
F
.43871 .34889 m .43933 .3446 L .43789 .34631 L F
.40818 .27242 m .40954 .2664 L .40816 .27239 L .126 .018 0 r
F
.40957 .26646 m .40954 .2664 L .40818 .27242 L F
.40816 .27239 m .40943 .26642 L .40801 .27238 L 1 .965 0 r
F
.40957 .26646 m .40943 .26642 L .40816 .27239 L F
.43705 .33869 m .39404 .22891 L .39181 .23447 L 1 .238 0 r
F
.43712 .3385 m .39404 .22891 L .43705 .33869 L F
.43671 .33665 m .43611 .33513 L .43667 .33675 L F
.43611 .33513 m .43596 .33556 L .43853 .3421 L F
.43762 .34489 m .43849 .34201 L .39181 .23447 L .157 .025 0 r
F
.43797 .34573 m .43844 .34239 L .43762 .34489 L F
.43844 .34239 m .43849 .34201 L .43762 .34489 L F
.41247 .25465 m .41248 .25462 L .41233 .25461 L 1 .976 0 r
F
.40957 .26646 m .40958 .26643 L .40943 .26642 L 1 .965 0 r
F
.41395 .2488 m .41381 .24876 L .41381 .24879 L 1 .981 0 r
F
.41395 .2488 m .41381 .24879 L .41247 .25462 L F
.41248 .25462 m .41272 .25364 L .41247 .25462 L F
.41247 .25462 m .41381 .24876 L .41233 .25461 L F
.41102 .2605 m .41233 .25461 L .41087 .26049 L 1 .976 0 r
F
.41247 .25465 m .41233 .25461 L .41102 .2605 L F
.40958 .26643 m .40974 .26575 L .40958 .26643 L 1 .97 0 r
F
.40958 .26643 m .41087 .26049 L .40943 .26642 L F
.43869 .34165 m .41838 .23148 L .39404 .22891 L 1 .238 0 r
F
.43901 .34126 m .43869 .34165 L .4389 .3416 L 1 .746 0 r
F
.43869 .34165 m .43868 .34166 L .4389 .3416 L F
.43881 .3417 m .43873 .3418 L .4388 .34174 L F
.43873 .3418 m .43872 .34183 L .4388 .34174 L F
.4389 .3416 m .43881 .3417 L .4388 .34174 L F
.43994 .34015 m .43901 .34126 L .4389 .3416 L F
.44526 .32998 m .44005 .33939 L .43994 .34015 L 1 .78 0 r
F
.44981 .32126 m .44005 .33939 L .44526 .32998 L F
.45026 .32106 m .44981 .32126 L .43994 .34015 L F
.45145 .33081 m .43933 .3446 L .45143 .33092 L 1 .854 0 r
F
.45201 .32408 m .45223 .3174 L .45002 .32149 L 1 .819 0 r
F
.44982 .32699 m .45002 .32149 L .43994 .34015 L F
.45201 .32408 m .45002 .32149 L .44982 .32699 L F
.45014 .32064 m .44981 .32126 L .45013 .32078 L 1 .78 0 r
F
.45014 .32064 m .45013 .32078 L .45182 .31816 L F
.45223 .3174 m .45245 .31035 L .45033 .31484 L F
.4503 .31577 m .45033 .31484 L .45024 .31551 L .147 .019 0 r
F
.45006 .32041 m .45024 .31551 L .44971 .31942 L F
.45223 .3174 m .45033 .31484 L .45014 .32064 L 1 .78 0 r
F
.45511 .3398 m .45201 .32408 L .45511 .3399 L 0 0 0 r
F
.45612 .33873 m .45523 .33677 L .45509 .34031 L 1 .846 0 r
F
.45532 .341 m .45201 .32408 L .45179 .33042 L 0 0 0 r
F
.45182 .31816 m .45032 .32048 L .45026 .32106 L 1 .78 0 r
F
.45014 .32064 m .45024 .31551 L .45006 .32041 L .147 .019 0 r
F
.45032 .32048 m .45013 .32078 L .45026 .32106 L 1 .78 0 r
F
.45201 .32408 m .45164 .32457 L .45163 .3247 L 1 .819 0 r
F
.45179 .33042 m .45201 .32408 L .43933 .3446 L 1 .854 0 r
F
.45383 .33099 m .45064 .31722 L .45014 .32064 L .147 .019 0 r
F
.45064 .31722 m .45024 .31551 L .45014 .32064 L F
.45013 .32078 m .44981 .32126 L .45007 .32114 L 1 .78 0 r
F
.45013 .32078 m .45007 .32114 L .45026 .32106 L F
.44971 .31942 m .45033 .31484 L .44989 .31369 L .147 .019 0 r
F
.44897 .31733 m .4495 .31268 L .44919 .31186 L F
.4487 .31657 m .44919 .31186 L .41838 .23148 L F
.44897 .31733 m .44919 .31186 L .4487 .31657 L F
.45271 .28792 m .4513 .29179 L .45269 .28813 L 1 .599 0 r
F
.45122 .29272 m .45102 .2921 L .45102 .29217 L .234 .034 0 r
F
.45 .29804 m .42311 .21458 L .42151 .22017 L .209 .03 0 r
F
.45049 .29939 m .45 .29788 L .45 .29804 L F
.45 .29788 m .42311 .21458 L .45 .29804 L F
.45097 .27306 m .42801 .1981 L .42636 .20355 L .283 .043 0 r
F
.45098 .2728 m .42801 .1981 L .45097 .27306 L F
.45166 .2749 m .42801 .1981 L .45166 .275 L F
.45087 .28253 m .42636 .20355 L .42473 .20904 L .259 .039 0 r
F
.45087 .28228 m .42636 .20355 L .45087 .28253 L F
.45161 .2836 m .42636 .20355 L .45155 .28447 L F
.45161 .28354 m .45161 .28353 L .45161 .2836 L F
.45161 .28353 m .42636 .20355 L .45161 .2836 L F
.45545 .27997 m .45543 .27959 L .45477 .27585 L 0 0 0 r
F
.45477 .27602 m .45477 .27585 L .4536 .26922 L F
.45545 .27997 m .45477 .27585 L .45477 .27602 L F
.45583 .28266 m .4536 .26922 L .45558 .28986 L F
.45237 .26564 m .45394 .25714 L .452 .26444 L 1 .359 0 r
F
.45396 .25751 m .45394 .25714 L .45237 .26564 L F
.45388 .25993 m .45396 .25748 L .45237 .26564 L 1 .444 0 r
F
.4548 .27069 m .45394 .25714 L .4545 .2725 L 1 .359 0 r
F
.45233 .26658 m .42968 .1927 L .42801 .1981 L F
.45233 .26645 m .42968 .1927 L .45233 .26658 L F
.45388 .25993 m .45237 .26564 L .45233 .26658 L 1 .444 0 r
F
.4536 .26922 m .45388 .25993 L .45233 .26658 L 1 .496 0 r
F
.45166 .275 m .45098 .2728 L .45097 .27306 L .283 .043 0 r
F
.45192 .27575 m .45166 .2749 L .45166 .275 L F
.45334 .27821 m .4536 .26922 L .45192 .27575 L 1 .548 0 r
F
.45161 .28354 m .45164 .28288 L .42636 .20355 L .259 .039 0 r
F
.45334 .27821 m .45192 .27575 L .45161 .28354 L 1 .548 0 r
F
.45167 .28299 m .45198 .2759 L .42636 .20355 L .259 .039 0 r
F
.45155 .28447 m .45087 .28228 L .45087 .28253 L F
.4505 .29929 m .45001 .29777 L .45049 .29939 L .209 .03 0 r
F
.45001 .29777 m .42311 .21458 L .45 .29788 L F
.45001 .29777 m .45 .29788 L .45049 .29939 L F
.45232 .26549 m .45218 .26503 L .45233 .26643 L 1 .359 0 r
F
.45595 .21191 m .45652 .20258 L .45333 .21812 L .985 .298 0 r
F
.45118 .26183 m .42968 .1927 L .45115 .26259 L 1 .359 0 r
F
.45382 .25515 m .44993 .19349 L .452 .26444 L F
.45304 .22392 m .45333 .21812 L .44895 .23941 L .985 .298 0 r
F
.44883 .24127 m .44895 .23941 L .44712 .2483 L F
.45304 .22392 m .44895 .23941 L .44883 .24127 L F
.44751 .24678 m .44712 .2483 L .44711 .24844 L F
.45304 .22392 m .44752 .24666 L .44751 .24678 L F
.44752 .24666 m .44712 .2483 L .44751 .24678 L F
.45218 .26503 m .45215 .26586 L .45233 .26643 L 1 .359 0 r
F
.45237 .25889 m .45158 .26104 L .45151 .26289 L 1 .395 0 r
F
.4542 .25041 m .45241 .25767 L .45237 .25889 L F
.45241 .25767 m .45158 .26104 L .45237 .25889 L F
.45197 .27481 m .42801 .1981 L .45192 .27575 L .283 .043 0 r
F
.45083 .29918 m .45057 .29839 L .45083 .30033 L .209 .03 0 r
F
.45029 .29753 m .42311 .21458 L .45026 .29854 L F
.4555 .32232 m .45245 .31035 L .45533 .32823 L 0 0 0 r
F
.45548 .32223 m .45269 .31128 L .45549 .32227 L F
.45547 .31482 m .45542 .3142 L .45266 .30292 L F
.45245 .31035 m .45266 .30292 L .45088 .30724 L 1 .739 0 r
F
.45222 .30398 m .45149 .30551 L .45146 .30584 L 1 .695 0 r
F
.45091 .30051 m .4509 .30052 L .4509 .30052 L 1 .649 0 r
F
.45095 .30016 m .45093 .3002 L .45091 .30051 L F
.45026 .30576 m .4509 .30052 L .42151 .22017 L .187 .026 0 r
F
.45157 .29836 m .45101 .29969 L .45154 .29878 L 1 .649 0 r
F
.44959 .31165 m .45018 .30673 L .41994 .2258 L .165 .022 0 r
F
.4509 .30052 m .45083 .29918 L .45083 .30033 L .209 .03 0 r
F
.45096 .29983 m .45083 .29918 L .4509 .30052 L F
.45098 .29964 m .45083 .29918 L .45096 .29983 L F
.45057 .29839 m .4505 .29929 L .45083 .30033 L F
.45247 .29608 m .45127 .29895 L .45244 .29628 L 1 .649 0 r
F
.45083 .30033 m .4505 .29929 L .45049 .29939 L .209 .03 0 r
F
.45127 .29895 m .45126 .29912 L .45244 .29628 L 1 .649 0 r
F
.45546 .3069 m .45541 .3063 L .45288 .29508 L 0 0 0 r
F
.45554 .31468 m .45288 .29508 L .45266 .30292 L F
.45554 .3146 m .45288 .29508 L .45554 .31468 L F
.45567 .30785 m .45288 .29508 L .45557 .3148 L F
.45244 .29628 m .45157 .29836 L .45154 .29878 L 1 .649 0 r
F
.45288 .29508 m .45247 .29608 L .45244 .29628 L F
.45288 .29508 m .4531 .28684 L .45122 .29272 L F
.45057 .29839 m .45122 .29272 L .42311 .21458 L .209 .03 0 r
F
.45098 .29964 m .45122 .29272 L .45057 .29839 L F
.45101 .29271 m .45097 .2932 L .45125 .29246 L 1 .599 0 r
F
.45128 .29215 m .45125 .29246 L .45163 .29144 L F
.45101 .29271 m .45125 .29246 L .45128 .29215 L F
.44955 .30506 m .42151 .22017 L .41994 .2258 L .187 .026 0 r
F
.44982 .30576 m .44956 .30498 L .44955 .30506 L F
.44956 .30498 m .42151 .22017 L .44955 .30506 L F
.44983 .30566 m .42151 .22017 L .44982 .30576 L F
.45019 .30661 m .44983 .30554 L .45018 .30673 L F
.44983 .30554 m .42151 .22017 L .44983 .30566 L F
.44983 .30554 m .44983 .30566 L .45018 .30673 L F
.45101 .29271 m .4508 .29328 L .45097 .2932 L 1 .599 0 r
F
.45062 .30776 m .4502 .30649 L .45061 .30788 L .187 .026 0 r
F
.4502 .30649 m .42151 .22017 L .45019 .30661 L F
.4502 .30649 m .45019 .30661 L .45061 .30788 L F
.45097 .29981 m .45073 .30036 L .45093 .3002 L 1 .649 0 r
F
.45245 .31035 m .45088 .30724 L .45088 .30825 L 1 .739 0 r
F
.45116 .30845 m .45078 .3073 L .45109 .30917 L .187 .026 0 r
F
.45072 .30711 m .45071 .30712 L .45067 .30744 L 1 .695 0 r
F
.45071 .30712 m .45068 .30719 L .45067 .30746 L F
.45069 .30704 m .45026 .30576 L .45062 .30776 L .187 .026 0 r
F
.45026 .30576 m .42151 .22017 L .4502 .30649 L F
.45026 .30576 m .4502 .30649 L .45062 .30776 L F
.45093 .3002 m .4507 .30074 L .4509 .30052 L 1 .649 0 r
F
.45197 .27481 m .45233 .26658 L .42801 .1981 L .283 .043 0 r
F
.45288 .29508 m .45122 .29272 L .45098 .29964 L 1 .649 0 r
F
.4513 .29179 m .45128 .29198 L .45269 .28813 L 1 .599 0 r
F
.45269 .28813 m .45167 .2909 L .45163 .29144 L F
.4531 .28684 m .45271 .28792 L .45269 .28813 L F
.4531 .28684 m .45334 .27821 L .45155 .28447 L F
.45129 .29182 m .45155 .28447 L .42473 .20904 L .234 .034 0 r
F
.45079 .29155 m .45067 .29116 L .45067 .2912 L F
.45102 .29217 m .4508 .29147 L .45079 .29155 L F
.45129 .29182 m .45155 .28447 L .44292 .31473 L 1 .599 0 r
F
.4531 .28684 m .45155 .28447 L .45129 .29182 L F
.45129 .29182 m .452 .28572 L .45155 .28447 L .234 .034 0 r
F
.45453 .30195 m .45469 .29329 L .452 .28572 L F
.45167 .2909 m .45127 .29199 L .45163 .29144 L 1 .599 0 r
F
.45127 .29199 m .45126 .2922 L .45163 .29144 L F
.45163 .29144 m .4506 .2942 L .45055 .2948 L F
.45018 .30673 m .44983 .30566 L .44982 .30576 L .187 .026 0 r
F
.45061 .30788 m .45019 .30661 L .45018 .30673 L F
.44998 .31277 m .45061 .30788 L .45018 .30673 L .165 .022 0 r
F
.44998 .31277 m .45018 .30673 L .44959 .31165 L F
.45266 .30292 m .45288 .29508 L .4509 .30052 L 1 .695 0 r
F
.45069 .30704 m .4509 .30052 L .45026 .30576 L .187 .026 0 r
F
.45069 .30704 m .4509 .30052 L .44176 .3257 L 1 .695 0 r
F
.45266 .30292 m .4509 .30052 L .45069 .30704 L F
.45224 .30379 m .45095 .30651 L .45222 .30398 L F
.45095 .30651 m .45069 .30704 L .45094 .30654 L F
.45095 .30651 m .45094 .30654 L .45222 .30398 L F
.45069 .30704 m .45067 .30721 L .45222 .30398 L F
.45149 .30551 m .45072 .30711 L .45146 .30584 L F
.45072 .30711 m .45067 .30744 L .45146 .30584 L F
.45281 .31176 m .45281 .31173 L .45269 .31128 L 0 0 0 r
F
.4527 .31133 m .45269 .31128 L .45245 .31035 L F
.45245 .31035 m .45061 .30788 L .45041 .31402 L 1 .739 0 r
F
.45146 .30584 m .45065 .30749 L .45061 .30788 L 1 .695 0 r
F
.45245 .31035 m .45204 .3111 L .45202 .31127 L 1 .739 0 r
F
.4542 .3175 m .4509 .30052 L .45069 .30704 L .187 .026 0 r
F
.45453 .30195 m .452 .28572 L .45129 .29182 L .234 .034 0 r
F
.4513 .29179 m .45129 .29182 L .45128 .29198 L 1 .599 0 r
F
.45129 .29182 m .45102 .29254 L .45126 .29201 L F
.45129 .29182 m .45126 .29201 L .45128 .29198 L F
.45197 .27481 m .45233 .26658 L .44402 .30218 L 1 .496 0 r
F
.45203 .27461 m .45233 .26658 L .45197 .27481 L F
.4536 .26922 m .45233 .26658 L .45237 .27344 L F
.45485 .28401 m .45501 .27415 L .45233 .26658 L .283 .043 0 r
F
.45237 .27344 m .45233 .26752 L .45203 .27461 L 1 .496 0 r
F
.45233 .26752 m .45233 .26658 L .45203 .27461 L F
.45334 .27821 m .45198 .28242 L .45193 .28314 L 1 .548 0 r
F
.45485 .28401 m .45233 .26658 L .45197 .27481 L .283 .043 0 r
F
.45255 .23382 m .45279 .22795 L .4465 .25981 L .993 .301 0 r
F
.45595 .21191 m .447 .24892 L .4465 .25981 L .985 .298 0 r
F
.45652 .20258 m .44753 .23727 L .447 .24892 L .989 .314 0 r
F
.45595 .21191 m .45333 .21812 L .45304 .22392 L .985 .298 0 r
F
.47061 .18684 m .45715 .19349 L .45652 .20258 L 1 1 0 r
F
.45543 .22143 m .45595 .21191 L .45279 .22795 L .993 .301 0 r
F
.45543 .22143 m .45279 .22795 L .45255 .23382 L F
.4465 .25981 m .447 .24892 L .44684 .25295 L 0 0 0 r
F
.45211 .24346 m .4523 .23754 L .44605 .26972 L 1 .32 0 r
F
.45211 .24346 m .44605 .26972 L .44605 .26973 L F
.45211 .24346 m .44604 .26977 L .44604 .26979 L F
.44603 .26986 m .4465 .25981 L .44625 .26435 L .73 .149 0 r
F
.44494 .29333 m .44505 .28746 L .44455 .29514 L 1 .395 0 r
F
.45161 .28354 m .45192 .27575 L .44348 .30869 L 1 .548 0 r
F
.45218 .26503 m .45118 .26183 L .45215 .26586 L 1 .359 0 r
F
.45118 .26183 m .45115 .26259 L .45215 .26586 L F
.4517 .26814 m .45174 .26181 L .44455 .29514 L 1 .444 0 r
F
.44419 .31026 m .44348 .30869 L .44292 .31473 L 1 .548 0 r
F
.45652 .20258 m .45715 .19349 L .44953 .22817 L .989 .314 0 r
F
.45652 .20258 m .44953 .22817 L .44943 .22954 L F
.4494 .23007 m .44818 .23429 L .44813 .23495 L F
.45652 .20258 m .44943 .22954 L .4494 .23007 L F
.44943 .22954 m .44818 .23429 L .4494 .23007 L F
.45437 .16259 m .45535 .15745 L .43955 .15615 L .964 1 0 r
F
.4534 .16778 m .45437 .16259 L .43773 .16118 L .969 1 0 r
F
.45437 .16259 m .43955 .15615 L .43773 .16118 L .964 1 0 r
F
.45438 .16266 m .45536 .15753 L .43956 .15626 L .966 1 0 r
F
.45535 .15745 m .44138 .15118 L .43955 .15615 L .96 1 0 r
F
.45536 .15753 m .44139 .15129 L .43956 .15626 L .962 1 0 r
F
.4534 .16778 m .43773 .16118 L .43593 .16627 L .969 1 0 r
F
.45438 .16266 m .43956 .15626 L .43774 .16129 L .966 1 0 r
F
.45554 .16118 m .44181 .15585 L .44001 .16089 L 1 1 0 r
F
.45535 .15745 m .45634 .15238 L .44138 .15118 L .96 1 0 r
F
.45536 .15753 m .45634 .15245 L .44139 .15129 L .962 1 0 r
F
.45554 .16118 m .45651 .15601 L .44181 .15585 L 1 1 0 r
F
.45244 .17304 m .43593 .16627 L .43414 .17142 L .974 1 0 r
F
.45244 .17304 m .4534 .16778 L .43593 .16627 L F
.45341 .16786 m .43774 .16129 L .43594 .16639 L .971 1 0 r
F
.45341 .16786 m .45438 .16266 L .43774 .16129 L F
.45458 .16639 m .44001 .16089 L .43824 .16597 L 1 1 0 r
F
.45458 .16639 m .45554 .16118 L .44001 .16089 L F
.45555 .16141 m .44184 .15627 L .44006 .16133 L F
.45555 .16141 m .45652 .15624 L .44184 .15627 L F
.45149 .17835 m .45244 .17304 L .43414 .17142 L .979 1 0 r
F
.45244 .17312 m .45341 .16786 L .43594 .16639 L .976 1 0 r
F
.45363 .17165 m .45458 .16639 L .43824 .16597 L 1 1 0 r
F
.45459 .16664 m .45555 .16141 L .44006 .16133 L F
.45634 .15238 m .44323 .14628 L .44138 .15118 L .955 1 0 r
F
.45634 .15238 m .45734 .14737 L .44323 .14628 L F
.45634 .15245 m .44324 .14639 L .44139 .15129 L .957 1 0 r
F
.45634 .15245 m .45734 .14744 L .44324 .14639 L F
.45651 .15601 m .44361 .15086 L .44181 .15585 L 1 1 0 r
F
.45651 .15601 m .45749 .1509 L .44361 .15086 L F
.45652 .15624 m .44365 .15125 L .44184 .15627 L F
.45652 .15624 m .45749 .1511 L .44365 .15125 L F
.47173 .14769 m .45834 .14243 L .45734 .14737 L .931 1 0 r
F
.47173 .14772 m .45834 .14249 L .45734 .14744 L .933 1 0 r
F
.47173 .15052 m .45847 .14583 L .45749 .1509 L .976 1 0 r
F
.47173 .14769 m .47186 .14268 L .45834 .14243 L .931 1 0 r
F
.47173 .14772 m .47186 .14272 L .45834 .14249 L .933 1 0 r
F
.47173 .15052 m .47186 .1454 L .45847 .14583 L .976 1 0 r
F
.47173 .15063 m .45848 .14602 L .45749 .1511 L .981 1 0 r
F
.47173 .15063 m .47186 .1455 L .45848 .14602 L F
.45734 .14737 m .44509 .14145 L .44323 .14628 L .95 1 0 r
F
.45734 .14744 m .4451 .14155 L .44324 .14639 L .952 1 0 r
F
.45749 .1509 m .44544 .14592 L .44361 .15086 L 1 1 0 r
F
.45734 .14737 m .45834 .14243 L .44509 .14145 L .95 1 0 r
F
.45734 .14744 m .45834 .14249 L .4451 .14155 L .952 1 0 r
F
.45749 .1509 m .45847 .14583 L .44544 .14592 L 1 1 0 r
F
.45749 .1511 m .44547 .14629 L .44365 .15125 L F
.45749 .1511 m .45848 .14602 L .44547 .14629 L F
.47186 .14268 m .46437 .13961 L .45834 .14243 L .927 1 0 r
F
.46437 .13961 m .45935 .13754 L .45862 .1411 L F
.46437 .13961 m .45862 .1411 L .45834 .14243 L F
.47186 .14268 m .47199 .13775 L .45935 .13754 L F
.47199 .13775 m .46467 .13458 L .45935 .13754 L .923 1 0 r
F
.46467 .13458 m .46037 .13272 L .45967 .13602 L F
.46467 .13458 m .45967 .13602 L .45935 .13754 L F
.47199 .13775 m .47213 .13287 L .46037 .13272 L F
.47213 .13287 m .46502 .12961 L .46037 .13272 L .92 1 0 r
F
.46502 .12961 m .4614 .12796 L .46074 .131 L F
.46502 .12961 m .46074 .131 L .46037 .13272 L F
.47213 .13287 m .47226 .12805 L .4614 .12796 L F
.47226 .12805 m .46543 .12472 L .4614 .12796 L .916 1 0 r
F
.46543 .12472 m .46243 .12326 L .46182 .12605 L F
.46543 .12472 m .46182 .12605 L .4614 .12796 L F
.47226 .12805 m .47239 .12329 L .46243 .12326 L F
.47239 .12329 m .4659 .11989 L .46243 .12326 L .913 1 0 r
F
.4659 .11989 m .46348 .11861 L .4629 .12118 L F
.4659 .11989 m .4629 .12118 L .46243 .12326 L F
.47239 .12329 m .47252 .11859 L .46348 .11861 L F
.47252 .11859 m .46644 .11512 L .46348 .11861 L .911 1 0 r
F
.46644 .11512 m .46453 .11403 L .46399 .11638 L F
.46644 .11512 m .46399 .11638 L .46348 .11861 L F
.47252 .11859 m .47266 .11395 L .46453 .11403 L F
.47266 .11395 m .46705 .11041 L .46453 .11403 L .91 1 0 r
F
.46705 .11041 m .46558 .10949 L .46508 .11165 L F
.46705 .11041 m .46508 .11165 L .46453 .11403 L F
.47266 .11395 m .47279 .10936 L .46558 .10949 L F
.47279 .10936 m .46772 .10576 L .46558 .10949 L .911 1 0 r
F
.46772 .10576 m .46665 .105 L .46617 .10702 L F
.46772 .10576 m .46617 .10702 L .46558 .10949 L F
.47279 .10936 m .47293 .10481 L .46665 .105 L F
.47293 .10481 m .46771 .09974 L .46665 .105 L .813 .952 0 r
F
.46872 .10496 m .46773 .10061 L .46665 .10502 L .915 1 0 r
F
.46773 .10061 m .46773 .10061 L .46773 .10061 L F
.46773 .10061 m .46773 .10061 L .46665 .10502 L F
.46773 .10061 m .4677 .10061 L .46665 .10502 L F
.46856 .10946 m .46665 .10502 L .46558 .10952 L .912 1 0 r
F
.47086 .10801 m .46665 .10502 L .46856 .10946 L F
.47279 .10937 m .47293 .10482 L .46665 .10502 L F
.46558 .10949 m .46665 .105 L .46047 .10378 L .819 .948 0 r
F
.46558 .10952 m .46665 .10502 L .46611 .10492 L .82 .948 0 r
F
.46558 .10949 m .46047 .10378 L .45853 .10936 L .819 .948 0 r
F
.46543 .10935 m .46611 .10492 L .46047 .1038 L .82 .948 0 r
F
.46558 .10952 m .46611 .10492 L .46543 .10935 L F
.46453 .11403 m .46508 .11165 L .45853 .10936 L .931 1 0 r
F
.46508 .11165 m .46558 .10949 L .46541 .10949 L F
.46508 .11165 m .46541 .10949 L .45853 .10936 L F
.46665 .105 m .46771 .09974 L .46246 .09956 L .971 1 0 r
F
.46771 .09974 m .46447 .09538 L .46246 .09956 L .901 1 0 r
F
.46413 .09989 m .46447 .0954 L .46246 .09958 L .971 1 0 r
F
.46762 .10054 m .46654 .09869 L .46413 .09989 L F
.46762 .10054 m .46752 .10028 L .46742 .10054 L .95 1 0 r
F
.46772 .10054 m .46765 .10045 L .46762 .10054 L F
.46765 .10045 m .46654 .09869 L .46762 .10054 L .971 1 0 r
F
.46765 .10045 m .46752 .10028 L .46762 .10054 L .95 1 0 r
F
.46772 .10056 m .46765 .10045 L .46762 .10054 L .971 1 0 r
F
.46654 .09869 m .46447 .0954 L .46413 .09989 L F
.46584 .10484 m .46302 .10044 L .46047 .10378 L F
.46302 .10044 m .46246 .09956 L .46175 .10107 L F
.46302 .10044 m .46175 .10107 L .46047 .10378 L F
.46665 .105 m .46606 .10424 L .46584 .10484 L F
.46606 .10424 m .46246 .09956 L .46584 .10484 L F
.46573 .10484 m .46246 .09958 L .46047 .1038 L .821 .955 0 r
F
.46665 .10502 m .46598 .10416 L .46573 .10484 L F
.46598 .10416 m .46246 .09958 L .46573 .10484 L F
.46665 .10502 m .4677 .10061 L .46246 .09958 L F
.4677 .10061 m .46772 .10054 L .46762 .10054 L 1 1 0 r
F
.4677 .10061 m .46772 .10056 L .46762 .10054 L .821 .955 0 r
F
.4677 .10061 m .46762 .10054 L .46246 .09958 L F
.4677 .10061 m .46762 .10054 L .46744 .10054 L 1 1 0 r
F
.46733 .10055 m .46449 .09634 L .46249 .10066 L .95 1 0 r
F
.46742 .10054 m .46736 .10046 L .46733 .10055 L F
.46736 .10046 m .46449 .09634 L .46733 .10055 L F
.46752 .10028 m .46449 .09634 L .46742 .10054 L F
.46667 .10675 m .4677 .10061 L .46249 .10066 L 1 1 0 r
F
.4677 .10061 m .46744 .10054 L .46249 .10066 L F
.47293 .10482 m .47092 .10318 L .46872 .10496 L .915 1 0 r
F
.4678 .10062 m .46772 .10054 L .4677 .10061 L .806 .924 0 r
F
.47092 .10318 m .4678 .10062 L .46872 .10496 L .915 1 0 r
F
.4678 .10062 m .46772 .10056 L .46775 .10073 L F
.4678 .10062 m .46775 .10073 L .46872 .10496 L F
.48003 .10889 m .47293 .10481 L .47279 .10936 L .889 1 0 r
F
.48083 .11348 m .47279 .10936 L .47266 .11395 L F
.48083 .11348 m .48003 .10889 L .47279 .10936 L F
.48003 .1089 m .47293 .10482 L .47279 .10937 L .89 1 0 r
F
.48003 .10889 m .47924 .10436 L .47293 .10481 L .889 1 0 r
F
.48003 .1089 m .47924 .10437 L .47293 .10482 L .89 1 0 r
F
.47293 .10481 m .47306 .10031 L .46771 .09974 L .813 .952 0 r
F
.47924 .10436 m .47306 .10031 L .47293 .10481 L .889 1 0 r
F
.47293 .10482 m .47306 .10032 L .46782 .10055 L .915 1 0 r
F
.4678 .10062 m .46782 .10055 L .46772 .10054 L .806 .924 0 r
F
.4678 .10062 m .46782 .10055 L .46772 .10056 L .915 1 0 r
F
.47293 .10482 m .46782 .10055 L .4678 .10062 L F
.4678 .10062 m .46783 .10055 L .46782 .10055 L .806 .924 0 r
F
.47924 .10437 m .47306 .10032 L .47293 .10482 L .89 1 0 r
F
.47292 .10607 m .47306 .10133 L .46783 .10055 L .806 .924 0 r
F
.47292 .10607 m .46783 .10055 L .4678 .10062 L F
.47292 .10607 m .4678 .10062 L .46667 .10675 L F
.4678 .10062 m .4677 .10061 L .46667 .10675 L F
.46773 .10061 m .46772 .10056 L .4677 .10061 L .915 1 0 r
F
.47279 .10937 m .47086 .10801 L .46856 .10946 L .912 1 0 r
F
.46859 .11401 m .46558 .10952 L .46453 .11406 L F
.47266 .11397 m .47087 .11284 L .46859 .11401 L F
.47087 .11284 m .46558 .10952 L .46859 .11401 L F
.46881 .11863 m .46453 .11406 L .46348 .11866 L .913 1 0 r
F
.47252 .11861 m .47094 .11771 L .46881 .11863 L F
.47094 .11771 m .46453 .11406 L .46881 .11863 L F
.46922 .12331 m .46348 .11866 L .46244 .1233 L .915 1 0 r
F
.47239 .12332 m .47107 .12263 L .46922 .12331 L F
.47107 .12263 m .46348 .11866 L .46922 .12331 L F
.46981 .12806 m .46244 .1233 L .4614 .12801 L .918 1 0 r
F
.47226 .12808 m .47126 .12759 L .46981 .12806 L F
.47126 .12759 m .46244 .1233 L .46981 .12806 L F
.47055 .13288 m .4614 .12801 L .46037 .13277 L .921 1 0 r
F
.47213 .1329 m .47149 .13261 L .47055 .13288 L F
.47149 .13261 m .4614 .12801 L .47055 .13288 L F
.47144 .13777 m .46037 .13277 L .45935 .1376 L .925 1 0 r
F
.47199 .13778 m .47178 .13768 L .47144 .13777 L F
.47178 .13768 m .46037 .13277 L .47144 .13777 L F
.47186 .14272 m .45935 .1376 L .45834 .14249 L .929 1 0 r
F
.47186 .1454 m .45947 .14081 L .45847 .14583 L .974 1 0 r
F
.47186 .1455 m .45947 .14098 L .45848 .14602 L .979 1 0 r
F
.46188 .14487 m .45432 .15385 L .45294 .16441 L 1 .868 0 r
F
.45427 .15729 m .45423 .16095 L .45424 .15778 L 0 0 0 r
F
.45192 .24428 m .44603 .26986 L .45188 .24683 L 1 .32 0 r
F
.45543 .22143 m .4465 .25981 L .44603 .26986 L .993 .301 0 r
F
.45742 .19895 m .4499 .24178 L .44939 .25624 L .895 .184 0 r
F
.4499 .24178 m .44974 .2427 L .44949 .25257 L F
.4499 .24178 m .44949 .25257 L .44939 .25624 L F
.45054 .18372 m .45149 .17835 L .43238 .17664 L .983 1 0 r
F
.45149 .17835 m .43414 .17142 L .43238 .17664 L .979 1 0 r
F
.45149 .17843 m .45244 .17312 L .43416 .17155 L .981 1 0 r
F
.45244 .17312 m .43594 .16639 L .43416 .17155 L .976 1 0 r
F
.45268 .17695 m .45363 .17165 L .43648 .17111 L 1 1 0 r
F
.45363 .17165 m .43824 .16597 L .43648 .17111 L F
.45364 .17191 m .45459 .16664 L .43829 .16644 L F
.45459 .16664 m .44006 .16133 L .43829 .16644 L F
.45715 .19349 m .44812 .22504 L .44753 .23727 L 1 .35 0 r
F
.45715 .19349 m .45783 .18468 L .44886 .22197 L F
.4488 .22268 m .44886 .22197 L .44812 .22504 L F
.45715 .19349 m .44886 .22197 L .4488 .22268 L F
.44961 .18915 m .45054 .18372 L .43062 .18192 L .988 1 0 r
F
.44961 .18924 m .45055 .18381 L .43064 .18205 L .99 1 0 r
F
.44991 .19317 m .45082 .18771 L .43129 .18681 L 1 1 0 r
F
.44993 .19349 m .45084 .18802 L .43137 .18735 L F
.45054 .18372 m .43238 .17664 L .43062 .18192 L .983 1 0 r
F
.45055 .18381 m .43239 .17677 L .43064 .18205 L .985 1 0 r
F
.45082 .18771 m .433 .18153 L .43129 .18681 L 1 1 0 r
F
.45055 .18381 m .45149 .17843 L .43239 .17677 L .985 1 0 r
F
.45082 .18771 m .45175 .18231 L .433 .18153 L 1 1 0 r
F
.45084 .18802 m .43307 .18205 L .43137 .18735 L F
.45084 .18802 m .45177 .1826 L .43307 .18205 L F
.45933 .1679 m .45059 .18753 L .44963 .19987 L 1 .577 0 r
F
.47184 .15786 m .46014 .15995 L .45933 .1679 L 1 1 0 r
F
.45856 .17614 m .44963 .19987 L .44882 .21247 L 1 .485 0 r
F
.45856 .17614 m .45933 .1679 L .44963 .19987 L F
.45933 .1679 m .46014 .15995 L .45059 .18753 L 1 .577 0 r
F
.46022 .16201 m .45221 .18363 L .45134 .19802 L 1 .439 0 r
F
.45202 .1867 m .45221 .1842 L .45221 .18489 L 0 0 0 r
F
.45272 .26676 m .45237 .26564 L .45267 .26756 L 1 .359 0 r
F
.45237 .26564 m .45237 .26656 L .45267 .26756 L F
.45237 .26564 m .45396 .25748 L .45237 .26545 L 1 .444 0 r
F
.4545 .2725 m .45396 .25751 L .45237 .26564 L 1 .359 0 r
F
.4507 .30074 m .44638 .31089 L .45067 .30105 L 1 .649 0 r
F
.44638 .31089 m .44637 .31103 L .45067 .30105 L F
.45057 .29839 m .45029 .29753 L .4505 .29929 L .209 .03 0 r
F
.45029 .29753 m .45026 .29854 L .4505 .29929 L F
.45075 .3002 m .45072 .29427 L .44234 .32038 L 1 .649 0 r
F
.45073 .30036 m .44744 .30822 L .4507 .30074 L F
.44744 .30822 m .44234 .32038 L .44743 .30842 L F
.44744 .30822 m .44743 .30842 L .4507 .30074 L F
.44939 .25624 m .44974 .2427 L .4496 .25082 L 0 0 0 r
F
.45075 .3002 m .44234 .32038 L .45073 .30036 L 1 .649 0 r
F
.4509 .30052 m .44234 .32038 L .44176 .3257 L F
.4509 .30052 m .44234 .32038 L .4509 .30052 L F
.44799 .30566 m .44748 .30469 L .44716 .31047 L 1 .34 0 r
F
.4508 .29328 m .44292 .31473 L .45076 .29376 L 1 .599 0 r
F
.45081 .29312 m .44292 .31473 L .4508 .29328 L F
.45161 .28354 m .45167 .28299 L .45164 .28288 L .259 .039 0 r
F
.45167 .28299 m .45233 .27689 L .45198 .2759 L F
.4559 .26172 m .45553 .24788 L .45516 .25678 L .996 .305 0 r
F
.45598 .25121 m .45553 .24788 L .4559 .26172 L F
.45553 .24788 m .45456 .24076 L .45516 .25678 L F
.45542 .25299 m .45569 .24198 L .45464 .24944 L .997 .271 0 r
F
.4542 .27187 m .45272 .26676 L .45267 .26756 L 1 .359 0 r
F
.45484 .27366 m .45421 .27162 L .4542 .27187 L F
.45421 .27162 m .45272 .26676 L .4542 .27187 L F
.45484 .27361 m .45272 .26676 L .45484 .27366 L F
.45497 .274 m .45272 .26676 L .45497 .27402 L F
.45064 .28767 m .44587 .30166 L .44565 .30516 L 1 .548 0 r
F
.44972 .24996 m .45003 .24434 L .44999 .25157 L 0 0 0 r
F
.45489 .26333 m .4542 .25041 L .45396 .25748 L F
.45517 .25701 m .4542 .25041 L .45489 .26333 L F
.45233 .27689 m .45197 .27481 L .45192 .27575 L .283 .043 0 r
F
.45238 .27611 m .45197 .27481 L .45233 .27689 L F
.45192 .27575 m .45085 .27867 L .45075 .28031 L 1 .496 0 r
F
.45197 .27481 m .45085 .27867 L .45192 .27575 L F
.45074 .28624 m .44435 .30599 L .45064 .28767 L 1 .548 0 r
F
.44435 .30599 m .44348 .30869 L .44434 .30615 L F
.44435 .30599 m .44434 .30615 L .45064 .28767 L F
.44637 .26341 m .44674 .25569 L .44633 .2662 L 0 0 0 r
F
.44565 .30516 m .44437 .30607 L .44419 .31026 L 1 .548 0 r
F
.44587 .30166 m .44437 .30607 L .44565 .30516 L F
.45117 .26443 m .44527 .28664 L .44496 .29321 L 1 .395 0 r
F
.45118 .26429 m .44523 .28681 L .45117 .26443 L F
.44523 .28681 m .44505 .28746 L .44522 .28682 L F
.44523 .28681 m .44522 .28682 L .45117 .26443 L F
.44693 .25221 m .44737 .24338 L .44729 .2463 L 0 0 0 r
F
.4515 .2558 m .44555 .27906 L .4452 .28492 L 1 .353 0 r
F
.44507 .28736 m .4452 .28492 L .44505 .28746 L F
.4515 .2558 m .4452 .28492 L .44507 .28736 L F
.44753 .23727 m .44812 .22504 L .44801 .23153 L 0 0 0 r
F
.44813 .23495 m .44818 .23429 L .44753 .23727 L .989 .314 0 r
F
.45151 .25561 m .44555 .27906 L .4515 .2558 L 1 .353 0 r
F
.4514 .26177 m .44507 .28738 L .45133 .26357 L 1 .395 0 r
F
.44507 .28738 m .44505 .28746 L .44507 .28739 L F
.44507 .28738 m .44507 .28739 L .45133 .26357 L F
.44748 .24165 m .44801 .23153 L .44794 .23608 L 0 0 0 r
F
.45133 .26357 m .44505 .28746 L .45132 .26375 L 1 .395 0 r
F
.45158 .26104 m .45167 .25496 L .44505 .28746 L F
.45173 .25278 m .44555 .27906 L .45167 .25496 L 1 .353 0 r
F
.45173 .25278 m .45188 .24683 L .44555 .27906 L F
.45188 .24683 m .44603 .26986 L .44555 .27906 L 1 .32 0 r
F
.44392 .30696 m .44402 .30218 L .44348 .30869 L 1 .496 0 r
F
.44688 .25446 m .44729 .2463 L .44708 .25462 L 0 0 0 r
F
.45075 .28031 m .44451 .30059 L .44422 .30578 L 1 .496 0 r
F
.45085 .27867 m .44402 .30218 L .45075 .28031 L F
.45089 .27274 m .44455 .29514 L .44402 .30218 L 1 .444 0 r
F
.45099 .27084 m .44455 .29514 L .45089 .27274 L F
.44674 .26061 m .44708 .25462 L .44582 .30301 L 0 0 0 r
F
.44688 .25446 m .44708 .25462 L .44674 .26061 L F
.44422 .30578 m .44427 .30136 L .44392 .30696 L 1 .496 0 r
F
.44451 .30059 m .44427 .30136 L .44422 .30578 L F
.44427 .30136 m .44402 .30218 L .44392 .30696 L F
.44745 .24485 m .44794 .23608 L .44778 .24582 L 0 0 0 r
F
.44737 .25219 m .44778 .24582 L .44691 .29773 L F
.44745 .24485 m .44778 .24582 L .44737 .25219 L F
.44748 .24165 m .44794 .23608 L .44745 .24485 L F
.44753 .23727 m .44801 .23153 L .44748 .24165 L F
.44693 .25221 m .44729 .2463 L .44688 .25446 L F
.44608 .27114 m .44633 .2662 L .44472 .30779 L F
.44637 .26341 m .44633 .2662 L .44608 .27114 L F
.45055 .2948 m .44292 .31473 L .44234 .32038 L 1 .599 0 r
F
.4506 .2942 m .44292 .31473 L .45055 .2948 L F
.44826 .29957 m .44815 .29592 L .4479 .30191 L .997 .271 0 r
F
.44993 .19349 m .43137 .18735 L .42968 .1927 L 1 1 0 r
F
.45149 .17843 m .43416 .17155 L .43239 .17677 L .981 1 0 r
F
.45175 .18231 m .43473 .17629 L .433 .18153 L 1 1 0 r
F
.45175 .18231 m .45268 .17695 L .43473 .17629 L F
.45177 .1826 m .43479 .1768 L .43307 .18205 L F
.45177 .1826 m .4527 .17724 L .43479 .1768 L F
.45268 .17695 m .43648 .17111 L .43473 .17629 L F
.4527 .17724 m .43653 .17159 L .43479 .1768 L F
.4527 .17724 m .45364 .17191 L .43653 .17159 L F
.45364 .17191 m .43829 .16644 L .43653 .17159 L F
.44138 .15118 m .44323 .14628 L .42964 .14446 L .971 1 0 r
F
.43955 .15615 m .44138 .15118 L .42696 .14919 L .976 1 0 r
F
.44138 .15118 m .42964 .14446 L .42696 .14919 L .971 1 0 r
F
.44139 .15129 m .44324 .14639 L .42966 .14463 L .974 1 0 r
F
.43773 .16118 m .43955 .15615 L .42431 .15399 L .982 1 0 r
F
.43955 .15615 m .42696 .14919 L .42431 .15399 L .976 1 0 r
F
.43956 .15626 m .44139 .15129 L .42698 .14936 L .979 1 0 r
F
.44139 .15129 m .42966 .14463 L .42698 .14936 L .974 1 0 r
F
.44181 .15585 m .44361 .15086 L .43042 .15077 L 1 1 0 r
F
.43773 .16118 m .42431 .15399 L .42168 .15886 L .982 1 0 r
F
.43956 .15626 m .42698 .14936 L .42433 .15417 L .979 1 0 r
F
.43593 .16627 m .43773 .16118 L .42168 .15886 L .987 1 0 r
F
.43774 .16129 m .43956 .15626 L .42433 .15417 L .984 1 0 r
F
.44001 .16089 m .44181 .15585 L .42781 .15553 L 1 1 0 r
F
.44181 .15585 m .43042 .15077 L .42781 .15553 L F
.44184 .15627 m .44365 .15125 L .43051 .15152 L F
.44323 .14628 m .43233 .1398 L .42964 .14446 L .966 1 0 r
F
.44323 .14628 m .44509 .14145 L .43233 .1398 L F
.44324 .14639 m .43235 .13996 L .42966 .14463 L .968 1 0 r
F
.44324 .14639 m .4451 .14155 L .43235 .13996 L F
.44361 .15086 m .43305 .14606 L .43042 .15077 L 1 1 0 r
F
.44361 .15086 m .44544 .14592 L .43305 .14606 L F
.44365 .15125 m .43313 .14678 L .43051 .15152 L F
.44365 .15125 m .44547 .14629 L .43313 .14678 L F
.44509 .14145 m .43505 .13521 L .43233 .1398 L .961 1 0 r
F
.44509 .14145 m .44697 .13668 L .43505 .13521 L F
.4451 .14155 m .43506 .13536 L .43235 .13996 L .963 1 0 r
F
.45834 .14243 m .44697 .13668 L .44509 .14145 L .946 1 0 r
F
.4451 .14155 m .44697 .13677 L .43506 .13536 L .963 1 0 r
F
.44544 .14592 m .4357 .1414 L .43305 .14606 L 1 1 0 r
F
.45834 .14249 m .44697 .13677 L .4451 .14155 L .948 1 0 r
F
.44544 .14592 m .44728 .14103 L .4357 .1414 L 1 1 0 r
F
.44547 .14629 m .43577 .14208 L .43313 .14678 L F
.45847 .14583 m .44728 .14103 L .44544 .14592 L F
.44547 .14629 m .4473 .14136 L .43577 .14208 L F
.44697 .13668 m .43779 .13069 L .43505 .13521 L .956 1 0 r
F
.44697 .13668 m .44886 .13197 L .43779 .13069 L F
.44697 .13677 m .4378 .13084 L .43506 .13536 L .959 1 0 r
F
.45834 .14243 m .45935 .13754 L .44697 .13668 L .946 1 0 r
F
.44849 .13678 m .44886 .13197 L .44697 .13668 L .941 1 0 r
F
.45935 .13754 m .45425 .13483 L .44849 .13678 L F
.45425 .13483 m .44886 .13197 L .44849 .13678 L F
.45935 .13754 m .46037 .13272 L .44886 .13197 L F
.4497 .13203 m .45077 .12733 L .44886 .13197 L .937 1 0 r
F
.46037 .13272 m .45527 .12986 L .4497 .13203 L F
.45527 .12986 m .45077 .12733 L .4497 .13203 L F
.46037 .13272 m .4614 .12796 L .45077 .12733 L F
.45109 .12735 m .45269 .12275 L .45077 .12733 L .934 1 0 r
F
.4614 .12796 m .45638 .12496 L .45109 .12735 L F
.45638 .12496 m .45269 .12275 L .45109 .12735 L F
.4614 .12796 m .46243 .12326 L .45269 .12275 L F
.46243 .12326 m .45757 .12013 L .45269 .12275 L .932 1 0 r
F
.45757 .12013 m .45462 .11824 L .45269 .12275 L F
.45757 .12013 m .45269 .12275 L .45269 .12275 L F
.46243 .12326 m .46348 .11861 L .45462 .11824 L F
.46348 .11861 m .45886 .11538 L .45462 .11824 L .93 1 0 r
F
.45886 .11538 m .45657 .11377 L .45469 .11807 L F
.45886 .11538 m .45469 .11807 L .45462 .11824 L F
.46348 .11861 m .46453 .11403 L .45657 .11377 L F
.46453 .11403 m .45853 .10936 L .45657 .11377 L .931 1 0 r
F
.46107 .11396 m .45853 .10942 L .45657 .11384 L .933 1 0 r
F
.46453 .11406 m .46289 .11279 L .46107 .11396 L F
.46289 .11279 m .45853 .10942 L .46107 .11396 L F
.46056 .11854 m .45657 .11384 L .45462 .11831 L F
.46348 .11866 m .46212 .11771 L .46056 .11854 L F
.46212 .11771 m .45657 .11384 L .46056 .11854 L F
.46027 .1232 m .45462 .11831 L .45269 .12283 L .934 1 0 r
F
.46244 .1233 m .46144 .12267 L .46027 .1232 L F
.46144 .12267 m .45462 .11831 L .46027 .1232 L F
.46019 .12794 m .45269 .12283 L .45077 .12742 L .936 1 0 r
F
.4614 .12801 m .46085 .12768 L .46019 .12794 L F
.46085 .12768 m .45269 .12283 L .46019 .12794 L F
.46032 .13277 m .45077 .12742 L .44887 .13206 L .94 1 0 r
F
.46037 .13277 m .46035 .13276 L .46032 .13277 L F
.46035 .13276 m .45077 .12742 L .46032 .13277 L F
.44697 .13677 m .44887 .13206 L .4378 .13084 L .959 1 0 r
F
.44728 .14103 m .43837 .13679 L .4357 .1414 L 1 1 0 r
F
.45834 .14249 m .45935 .1376 L .44697 .13677 L .948 1 0 r
F
.45935 .1376 m .44887 .13206 L .44697 .13677 L .943 1 0 r
F
.44728 .14103 m .44913 .13617 L .43837 .13679 L 1 1 0 r
F
.4473 .14136 m .43843 .13742 L .43577 .14208 L F
.45847 .14583 m .45947 .14081 L .44728 .14103 L F
.45947 .14081 m .44913 .13617 L .44728 .14103 L F
.4473 .14136 m .44915 .13648 L .43843 .13742 L F
.44201 .13118 m .44054 .12624 L .43779 .13069 L .952 1 0 r
F
.44886 .13197 m .44542 .1296 L .44201 .13118 L F
.44542 .1296 m .44054 .12624 L .44201 .13118 L F
.44886 .13197 m .45077 .12733 L .44054 .12624 L F
.44379 .12659 m .44332 .12186 L .44054 .12624 L .949 1 0 r
F
.45077 .12733 m .44725 .12474 L .44379 .12659 L F
.44725 .12474 m .44332 .12186 L .44379 .12659 L F
.45077 .12733 m .45269 .12275 L .44332 .12186 L F
.45269 .12275 m .44612 .11755 L .44332 .12186 L .947 1 0 r
F
.4511 .12269 m .44612 .11767 L .44333 .12199 L .95 1 0 r
F
.45269 .12283 m .45194 .12224 L .4511 .12269 L F
.45194 .12224 m .44612 .11767 L .4511 .12269 L F
.45027 .12736 m .44333 .12199 L .44056 .12638 L .952 1 0 r
F
.45077 .12742 m .45053 .12724 L .45027 .12736 L F
.45053 .12724 m .44333 .12199 L .45027 .12736 L F
.44887 .13206 m .44056 .12638 L .4378 .13084 L .955 1 0 r
F
.44887 .13206 m .45077 .12742 L .44056 .12638 L F
.44913 .13617 m .44106 .13222 L .43837 .13679 L 1 1 0 r
F
.45935 .1376 m .46037 .13277 L .44887 .13206 L .943 1 0 r
F
.44913 .13617 m .451 .13135 L .44106 .13222 L 1 1 0 r
F
.44915 .13648 m .44112 .1328 L .43843 .13742 L F
.47186 .14272 m .47199 .13778 L .45935 .1376 L .929 1 0 r
F
.45947 .14081 m .46047 .13583 L .44913 .13617 L 1 1 0 r
F
.46047 .13583 m .451 .13135 L .44913 .13617 L F
.44915 .13648 m .45102 .13163 L .44112 .1328 L F
.44956 .13148 m .44378 .12768 L .44106 .13222 L F
.451 .13135 m .44995 .13082 L .44956 .13148 L F
.44995 .13082 m .44378 .12768 L .44956 .13148 L F
.45077 .12742 m .45269 .12283 L .44333 .12199 L .952 1 0 r
F
.46037 .13277 m .4614 .12801 L .45077 .12742 L .94 1 0 r
F
.451 .13135 m .45289 .12657 L .44378 .12768 L 1 1 0 r
F
.45289 .12657 m .44651 .12317 L .44378 .12768 L F
.45221 .12693 m .44654 .12365 L .44382 .12821 L F
.4529 .12682 m .45241 .12657 L .45221 .12693 L F
.45241 .12657 m .44654 .12365 L .45221 .12693 L F
.45102 .13163 m .44382 .12821 L .44112 .1328 L F
.44054 .12624 m .44332 .12186 L .44289 .12181 L .957 1 0 r
F
.44042 .12613 m .44289 .12181 L .43451 .12072 L F
.44054 .12624 m .44289 .12181 L .44042 .12613 L F
.44332 .12186 m .44612 .11755 L .43789 .1141 L .838 .932 0 r
F
.44333 .12199 m .44612 .11767 L .44542 .11737 L .838 .93 0 r
F
.44332 .12186 m .43789 .1141 L .43451 .12072 L .838 .932 0 r
F
.44303 .12156 m .44542 .11737 L .43789 .11418 L .838 .93 0 r
F
.44333 .12199 m .44542 .11737 L .44303 .12156 L F
.43779 .13069 m .44054 .12624 L .43092 .12481 L .961 1 0 r
F
.44054 .12624 m .43451 .12072 L .43092 .12481 L .957 1 0 r
F
.44056 .12638 m .44333 .12199 L .43453 .12095 L .962 1 0 r
F
.43505 .13521 m .43779 .13069 L .42735 .12898 L .966 1 0 r
F
.43233 .1398 m .43505 .13521 L .4238 .13324 L .971 1 0 r
F
.43505 .13521 m .42735 .12898 L .4238 .13324 L .966 1 0 r
F
.43506 .13536 m .4378 .13084 L .42738 .12922 L .97 1 0 r
F
.43309 .12992 m .43092 .12481 L .42735 .12898 L .961 1 0 r
F
.43779 .13069 m .4355 .12873 L .43309 .12992 L F
.4355 .12873 m .43092 .12481 L .43309 .12992 L F
.44034 .12635 m .43453 .12095 L .43094 .12504 L .962 1 0 r
F
.44056 .12638 m .44046 .12629 L .44034 .12635 L F
.44046 .12629 m .43453 .12095 L .44034 .12635 L F
.4378 .13084 m .43094 .12504 L .42738 .12922 L .965 1 0 r
F
.4378 .13084 m .44056 .12638 L .43094 .12504 L F
.44106 .13222 m .44378 .12768 L .44335 .12784 L 1 1 0 r
F
.44078 .13215 m .44335 .12784 L .43555 .13087 L F
.44106 .13222 m .44335 .12784 L .44078 .13215 L F
.44333 .12199 m .43789 .11418 L .43453 .12095 L .838 .93 0 r
F
.44378 .12768 m .44651 .12317 L .43813 .11672 L .725 .718 0 r
F
.44382 .12821 m .44654 .12365 L .44608 .12328 L .719 .702 0 r
F
.44378 .12768 m .43828 .11703 L .43555 .13087 L .725 .718 0 r
F
.43828 .11703 m .43813 .11672 L .43808 .117 L F
.43828 .11703 m .43808 .117 L .43555 .13087 L F
.42602 .11595 m .43041 .11223 L .42599 .11594 L 1 1 0 r
F
.43451 .12072 m .43059 .1126 L .42602 .11595 L F
.43059 .1126 m .43041 .11223 L .42602 .11595 L F
.43451 .12072 m .43789 .1141 L .43041 .11223 L F
.43789 .1141 m .4359 .11053 L .43041 .11223 L .909 1 0 r
F
.4359 .11053 m .43485 .10864 L .43057 .1121 L F
.4359 .11053 m .43057 .1121 L .43041 .11223 L F
.43789 .1141 m .44155 .11015 L .43485 .10864 L F
.44155 .11015 m .43995 .10657 L .43485 .10864 L .899 1 0 r
F
.43995 .10657 m .43932 .10517 L .43559 .10807 L F
.43995 .10657 m .43559 .10807 L .43485 .10864 L F
.44155 .11015 m .44524 .1063 L .43932 .10517 L F
.44524 .1063 m .44381 .10185 L .43932 .10517 L .889 1 0 r
F
.44215 .10581 m .44382 .10198 L .43933 .1053 L .891 1 0 r
F
.44882 .11143 m .44619 .10767 L .44155 .11015 L .909 1 0 r
F
.44619 .10767 m .44524 .1063 L .44245 .10921 L F
.44619 .10767 m .44245 .10921 L .44155 .11015 L F
.44882 .11143 m .45167 .10729 L .44524 .1063 L F
.45167 .10729 m .44895 .10253 L .44524 .1063 L .907 1 0 r
F
.44824 .10682 m .44895 .1026 L .44524 .10637 L .909 1 0 r
F
.45657 .11377 m .45167 .10729 L .44882 .11143 L .824 .94 0 r
F
.45167 .10734 m .45077 .10578 L .44824 .10682 L .909 1 0 r
F
.45077 .10578 m .44895 .1026 L .44824 .10682 L F
.44524 .10637 m .44477 .10491 L .44215 .10581 L .891 1 0 r
F
.44477 .10491 m .44382 .10198 L .44215 .10581 L F
.4389 .10965 m .43933 .1053 L .43486 .10877 L .901 1 0 r
F
.44612 .11755 m .44172 .11042 L .43789 .1141 L 1 1 0 r
F
.44172 .11042 m .44155 .11015 L .43862 .11332 L F
.44172 .11042 m .43862 .11332 L .43789 .1141 L F
.44612 .11755 m .44882 .11143 L .44155 .11015 L F
.44187 .11029 m .44524 .10637 L .44156 .11023 L .911 1 0 r
F
.45462 .11824 m .44882 .11143 L .44612 .11755 L .831 .94 0 r
F
.44882 .11148 m .44557 .10683 L .44187 .11029 L .911 1 0 r
F
.44557 .10683 m .44524 .10637 L .44187 .11029 L F
.44156 .11023 m .44102 .10903 L .4389 .10965 L .901 1 0 r
F
.44102 .10903 m .43933 .1053 L .4389 .10965 L F
.4308 .11245 m .43486 .10877 L .43042 .11236 L .91 1 0 r
F
.43789 .11418 m .43515 .10927 L .4308 .11245 L F
.43515 .10927 m .43486 .10877 L .4308 .11245 L F
.43092 .12481 m .42599 .11594 L .4216 .11975 L .844 .92 0 r
F
.43092 .12481 m .43451 .12072 L .42599 .11594 L F
.43288 .12 m .43042 .11236 L .42601 .11607 L 1 1 0 r
F
.43453 .12095 m .4338 .1194 L .43288 .12 L F
.4338 .1194 m .43042 .11236 L .43288 .12 L F
.43453 .12095 m .43789 .11418 L .43042 .11236 L F
.43639 .1144 m .43525 .11273 L .43262 .11623 L .925 1 0 r
F
.43806 .11663 m .43525 .11273 L .43795 .11671 L F
.44473 .11708 m .44156 .11023 L .43789 .11418 L 1 1 0 r
F
.44612 .11767 m .44538 .11646 L .44473 .11708 L F
.44538 .11646 m .44156 .11023 L .44473 .11708 L F
.45269 .12275 m .45269 .12275 L .44612 .11755 L .947 1 0 r
F
.45269 .12275 m .45462 .11824 L .45431 .11821 L F
.45269 .12275 m .45431 .11821 L .44612 .11755 L F
.45462 .11824 m .45657 .11377 L .44882 .11143 L .831 .94 0 r
F
.45462 .11831 m .45657 .11384 L .45593 .11364 L .831 .939 0 r
F
.45438 .11801 m .45593 .11364 L .44882 .11148 L F
.45462 .11831 m .45593 .11364 L .45438 .11801 L F
.45462 .11831 m .44882 .11148 L .44612 .11767 L F
.44612 .11767 m .44882 .11148 L .44156 .11023 L 1 1 0 r
F
.44664 .11058 m .44543 .10899 L .44342 .11293 L .956 1 0 r
F
.44882 .11317 m .44543 .10899 L .4487 .11329 L F
.44882 .11148 m .45167 .10734 L .44524 .10637 L .911 1 0 r
F
.45657 .11384 m .45167 .10734 L .44882 .11148 L .824 .939 0 r
F
.44893 .1133 m .45176 .10911 L .44543 .10899 L .956 1 0 r
F
.45176 .10911 m .44911 .10526 L .44543 .10899 L .96 1 0 r
F
.44855 .1092 m .44912 .10545 L .44544 .10919 L .964 1 0 r
F
.4567 .11709 m .45176 .10911 L .44893 .1133 L .772 .83 0 r
F
.45177 .10921 m .45067 .10766 L .44855 .1092 L .964 1 0 r
F
.45067 .10766 m .44912 .10545 L .44855 .1092 L F
.44342 .11293 m .44543 .10899 L .44177 .11281 L .956 1 0 r
F
.4487 .11329 m .44664 .11058 L .44342 .11293 L F
.44893 .1133 m .44882 .11317 L .4487 .11329 L F
.43789 .11418 m .44156 .11023 L .43486 .10877 L .91 1 0 r
F
.43813 .11672 m .44177 .11281 L .43525 .11273 L .925 1 0 r
F
.43603 .11274 m .4397 .10959 L .43525 .11273 L .893 1 0 r
F
.44177 .11281 m .44037 .11064 L .43603 .11274 L F
.44037 .11064 m .4397 .10959 L .43603 .11274 L F
.44156 .11023 m .44524 .10637 L .43933 .1053 L .901 1 0 r
F
.44177 .11281 m .44543 .10899 L .4397 .10959 L .893 1 0 r
F
.44543 .10899 m .44417 .10674 L .43992 .10946 L .797 .855 0 r
F
.44021 .10954 m .43992 .10946 L .4397 .10959 L F
.44543 .10899 m .43992 .10946 L .44021 .10954 L F
.43913 .11307 m .43973 .11002 L .43529 .11314 L .885 1 0 r
F
.43262 .11623 m .43525 .11273 L .43084 .11607 L .925 1 0 r
F
.43795 .11671 m .43639 .1144 L .43262 .11623 L F
.42735 .12898 m .43092 .12481 L .4216 .11975 L .86 .932 0 r
F
.43094 .12504 m .43453 .12095 L .42601 .11607 L .842 .914 0 r
F
.43555 .13087 m .43813 .11672 L .43084 .11607 L 1 .97 0 r
F
.43815 .11694 m .43529 .11314 L .43128 .11618 L .926 1 0 r
F
.43813 .11672 m .43806 .11663 L .43795 .11671 L .925 1 0 r
F
.43828 .11685 m .44177 .11281 L .43813 .11672 L 1 1 0 r
F
.44651 .12317 m .44192 .11316 L .43828 .11685 L F
.44192 .11316 m .44177 .11281 L .43828 .11685 L F
.45269 .12283 m .45462 .11831 L .44612 .11767 L .95 1 0 r
F
.44651 .12317 m .44893 .1133 L .44177 .11281 L 1 1 0 r
F
.44205 .11303 m .44544 .10919 L .44178 .11302 L .961 1 0 r
F
.45479 .12182 m .44893 .1133 L .44651 .12317 L .768 .82 0 r
F
.44894 .11341 m .44563 .10941 L .44205 .11303 L .961 1 0 r
F
.44563 .10941 m .44544 .10919 L .44205 .11303 L F
.43815 .11694 m .44178 .11302 L .43529 .11314 L .926 1 0 r
F
.43525 .11273 m .4397 .10959 L .43488 .11267 L .444 .201 0 r
F
.43529 .11314 m .43973 .11002 L .435 .11386 L 0 0 0 r
F
.43485 .10864 m .43932 .10517 L .43404 .10413 L .856 1 0 r
F
.43485 .10864 m .43404 .10413 L .42885 .10703 L F
.43486 .10877 m .43933 .1053 L .43406 .10435 L .853 1 0 r
F
.43932 .10517 m .43902 .09871 L .43404 .10413 L .811 .932 0 r
F
.43932 .10517 m .44381 .10185 L .43902 .09871 L F
.43933 .1053 m .43903 .0988 L .43406 .10435 L .81 .929 0 r
F
.43933 .1053 m .44382 .10198 L .43903 .0988 L F
.4397 .10959 m .43926 .10151 L .43488 .11267 L .697 .718 0 r
F
.4397 .10959 m .44417 .10674 L .43926 .10151 L F
.43973 .11002 m .4397 .10939 L .435 .11386 L .689 .701 0 r
F
.4397 .10939 m .43928 .10176 L .43688 .10855 L F
.42735 .12898 m .4216 .11975 L .41775 .12701 L .86 .932 0 r
F
.42696 .14919 m .41679 .14199 L .41332 .14649 L .983 1 0 r
F
.42696 .14919 m .42964 .14446 L .41679 .14199 L F
.42431 .15399 m .41332 .14649 L .40989 .15107 L .989 1 0 r
F
.42431 .15399 m .42696 .14919 L .41332 .14649 L F
.42698 .14936 m .41683 .14224 L .41337 .14675 L .986 1 0 r
F
.42698 .14936 m .42966 .14463 L .41683 .14224 L F
.42964 .14446 m .42028 .13757 L .41679 .14199 L .977 1 0 r
F
.42964 .14446 m .43233 .1398 L .42028 .13757 L F
.42966 .14463 m .42032 .13782 L .41683 .14224 L .98 1 0 r
F
.42966 .14463 m .43235 .13996 L .42032 .13782 L F
.43233 .1398 m .4238 .13324 L .42028 .13757 L .971 1 0 r
F
.43235 .13996 m .42384 .13348 L .42032 .13782 L .975 1 0 r
F
.43235 .13996 m .43506 .13536 L .42384 .13348 L F
.43506 .13536 m .42738 .12922 L .42384 .13348 L .97 1 0 r
F
.42028 .13757 m .4238 .13324 L .41344 .13089 L .973 1 0 r
F
.41679 .14199 m .42028 .13757 L .40917 .13489 L .98 1 0 r
F
.42028 .13757 m .41344 .13089 L .40917 .13489 L .973 1 0 r
F
.42032 .13782 m .42384 .13348 L .41351 .13129 L .977 1 0 r
F
.4238 .13324 m .41775 .12701 L .41344 .13089 L .965 1 0 r
F
.4238 .13324 m .42735 .12898 L .41775 .12701 L F
.42384 .13348 m .41781 .1274 L .41351 .13129 L .969 1 0 r
F
.42384 .13348 m .42738 .12922 L .41871 .12757 L F
.41838 .12798 m .41871 .12757 L .41781 .1274 L F
.42384 .13348 m .41871 .12757 L .41838 .12798 L F
.43094 .12504 m .42929 .12203 L .42253 .12285 L .842 .914 0 r
F
.42929 .12203 m .42601 .11607 L .42253 .12285 L F
.41775 .12701 m .4216 .11975 L .41346 .11684 L 1 1 0 r
F
.41511 .11743 m .41856 .11342 L .41346 .11684 L .917 1 0 r
F
.4216 .11975 m .42011 .11666 L .41511 .11743 L F
.42011 .11666 m .41856 .11342 L .41511 .11743 L F
.4216 .11975 m .42599 .11594 L .41856 .11342 L F
.41925 .11366 m .42369 .11014 L .41856 .11342 L .902 1 0 r
F
.42599 .11594 m .42468 .11264 L .41925 .11366 L F
.42468 .11264 m .42369 .11014 L .41925 .11366 L F
.42599 .11594 m .43041 .11223 L .42369 .11014 L F
.43041 .11223 m .42939 .10884 L .42369 .11014 L .883 1 0 r
F
.42939 .10884 m .42885 .10703 L .42392 .11 L F
.42939 .10884 m .42392 .11 L .42369 .11014 L F
.43041 .11223 m .43485 .10864 L .42885 .10703 L F
.43253 .10817 m .43406 .10435 L .42887 .10724 L .853 1 0 r
F
.43486 .10877 m .43467 .10772 L .43253 .10817 L F
.43467 .10772 m .43406 .10435 L .43253 .10817 L F
.42878 .11187 m .42887 .10724 L .42371 .11035 L .883 1 0 r
F
.43042 .11236 m .43019 .1116 L .42878 .11187 L F
.43019 .1116 m .42887 .10724 L .42878 .11187 L F
.42534 .11585 m .42371 .11035 L .41859 .11362 L .903 1 0 r
F
.42601 .11607 m .42589 .11577 L .42534 .11585 L F
.42589 .11577 m .42371 .11035 L .42534 .11585 L F
.41775 .12701 m .41346 .11684 L .40839 .12038 L 1 1 0 r
F
.42017 .12213 m .41859 .11362 L .41349 .11704 L F
.42148 .12312 m .42106 .12175 L .42017 .12213 L F
.42106 .12175 m .41859 .11362 L .42017 .12213 L F
.42153 .1231 m .41859 .11362 L .42148 .12312 L F
.41332 .14649 m .41679 .14199 L .40493 .13898 L .988 1 0 r
F
.41679 .14199 m .40917 .13489 L .40493 .13898 L .98 1 0 r
F
.41683 .14224 m .42032 .13782 L .40924 .13528 L .984 1 0 r
F
.42032 .13782 m .41351 .13129 L .40924 .13528 L .977 1 0 r
F
.42168 .15886 m .42431 .15399 L .40989 .15107 L .995 1 0 r
F
.42433 .15417 m .42698 .14936 L .41337 .14675 L .992 1 0 r
F
.4217 .14709 m .42513 .14291 L .41635 .14839 L .748 .531 0 r
F
.41871 .12757 m .42233 .12383 L .41827 .12749 L .962 1 0 r
F
.42738 .12922 m .42234 .12384 L .41871 .12757 L F
.42234 .12384 m .42233 .12383 L .41871 .12757 L F
.42738 .12922 m .43094 .12504 L .42247 .12368 L F
.42246 .12409 m .42247 .12368 L .42212 .12327 L .667 .58 0 r
F
.42233 .12383 m .42247 .12368 L .42214 .12363 L .962 1 0 r
F
.42234 .12384 m .42212 .12327 L .42211 .12329 L .667 .58 0 r
F
.42738 .12922 m .42247 .12368 L .42234 .12384 L .962 1 0 r
F
.42858 .13881 m .42235 .12382 L .42234 .12384 L .667 .58 0 r
F
.42235 .12382 m .42212 .12327 L .42234 .12384 L F
.42234 .12384 m .42247 .12368 L .42233 .12383 L .962 1 0 r
F
.43094 .12504 m .42253 .12285 L .42253 .12295 L .842 .914 0 r
F
.43094 .12504 m .42249 .12295 L .42247 .12368 L F
.43206 .1348 m .42645 .11958 L .42621 .11978 L .643 .548 0 r
F
.42286 .12327 m .42621 .11978 L .42253 .12285 L F
.43206 .1348 m .42621 .11978 L .42286 .12327 L F
.42858 .13881 m .43206 .1348 L .42248 .12369 L .667 .58 0 r
F
.42248 .1237 m .42248 .12369 L .42247 .12368 L F
.42858 .13881 m .42248 .12369 L .42248 .1237 L F
.42513 .14291 m .42061 .14584 L .41635 .14839 L .656 .222 0 r
F
.42858 .13881 m .42234 .12384 L .42061 .14584 L .667 .58 0 r
F
.42234 .12384 m .42208 .12323 L .42205 .1237 L F
.41827 .12749 m .42225 .1238 L .41781 .1274 L .962 1 0 r
F
.42225 .1238 m .42225 .1238 L .41781 .1274 L F
.42233 .12383 m .42228 .12378 L .41827 .12749 L F
.42228 .12378 m .42205 .1237 L .41781 .1274 L F
.42234 .12384 m .42205 .1237 L .42061 .14584 L .667 .58 0 r
F
.42225 .1238 m .42228 .12378 L .42225 .1238 L .962 1 0 r
F
.42248 .12369 m .42253 .12285 L .42247 .12368 L .643 .548 0 r
F
.43206 .1348 m .4229 .12331 L .42248 .12369 L F
.4229 .12331 m .42253 .12285 L .42248 .12369 L F
.41344 .13089 m .41775 .12701 L .40839 .12038 L .869 .921 0 r
F
.40917 .13489 m .41344 .13089 L .40419 .12839 L .957 1 0 r
F
.41344 .13089 m .40839 .12038 L .40419 .12839 L .869 .921 0 r
F
.40948 .12592 m .41781 .1274 L .40961 .12577 L .94 1 0 r
F
.41351 .13129 m .41525 .12971 L .40948 .12592 L F
.41525 .12971 m .41781 .1274 L .40948 .12592 L F
.40989 .15107 m .41332 .14649 L .40071 .14317 L .996 1 0 r
F
.41332 .14649 m .40493 .13898 L .40071 .14317 L .988 1 0 r
F
.41337 .14675 m .41683 .14224 L .405 .13937 L .992 1 0 r
F
.41683 .14224 m .40924 .13528 L .405 .13937 L .984 1 0 r
F
.40493 .13898 m .40917 .13489 L .39921 .13192 L .97 1 0 r
F
.40917 .13489 m .40419 .12839 L .39921 .13192 L .957 1 0 r
F
.40924 .13528 m .41351 .13129 L .40432 .12905 L .958 1 0 r
F
.40565 .12938 m .40927 .12577 L .40432 .12905 L .94 1 0 r
F
.40927 .12577 m .40925 .12577 L .40432 .12905 L F
.41351 .13129 m .40948 .12592 L .40565 .12938 L F
.40948 .12592 m .40933 .12572 L .40565 .12938 L F
.41392 .17388 m .41648 .16881 L .39974 .16524 L 1 1 0 r
F
.43062 .18192 m .41392 .17388 L .41139 .17902 L F
.43062 .18192 m .43238 .17664 L .41392 .17388 L F
.43238 .17664 m .41648 .16881 L .41392 .17388 L .998 1 0 r
F
.41139 .17902 m .41392 .17388 L .39642 .17012 L 1 1 0 r
F
.41392 .17388 m .39974 .16524 L .39642 .17012 L F
.41396 .17407 m .41652 .16899 L .3998 .16551 L F
.41648 .16881 m .40309 .16044 L .39974 .16524 L F
.41648 .16881 m .41907 .1638 L .40309 .16044 L F
.41652 .16899 m .40315 .16071 L .3998 .16551 L F
.43238 .17664 m .43414 .17142 L .41648 .16881 L .998 1 0 r
F
.43414 .17142 m .41907 .1638 L .41648 .16881 L .993 1 0 r
F
.41652 .16899 m .4191 .16398 L .40315 .16071 L 1 1 0 r
F
.41907 .1638 m .40648 .15572 L .40309 .16044 L F
.41907 .1638 m .42168 .15886 L .40648 .15572 L F
.4191 .16398 m .40653 .15598 L .40315 .16071 L F
.43414 .17142 m .43593 .16627 L .41907 .1638 L .993 1 0 r
F
.43593 .16627 m .42168 .15886 L .41907 .1638 L .987 1 0 r
F
.4191 .16398 m .4217 .15904 L .40653 .15598 L 1 1 0 r
F
.42889 .18726 m .43062 .18192 L .41139 .17902 L F
.43064 .18205 m .43239 .17677 L .41396 .17407 L F
.43239 .17677 m .41652 .16899 L .41396 .17407 L F
.43239 .17677 m .43416 .17155 L .41652 .16899 L F
.41139 .17902 m .39642 .17012 L .39313 .17506 L F
.41396 .17407 m .3998 .16551 L .39648 .17039 L F
.41759 .17511 m .42012 .17013 L .40496 .16917 L F
.42168 .15886 m .40989 .15107 L .40648 .15572 L .995 1 0 r
F
.4217 .15904 m .40993 .15133 L .40653 .15598 L .998 1 0 r
F
.4217 .15904 m .42433 .15417 L .40993 .15133 L F
.43416 .17155 m .4191 .16398 L .41652 .16899 L .995 1 0 r
F
.42012 .17013 m .40825 .1646 L .40496 .16917 L 1 1 0 r
F
.43416 .17155 m .43594 .16639 L .4191 .16398 L .995 1 0 r
F
.42012 .17013 m .42266 .16521 L .40825 .1646 L 1 1 0 r
F
.43473 .17629 m .42012 .17013 L .41759 .17511 L F
.42889 .18726 m .41139 .17902 L .40887 .18422 L F
.43064 .18205 m .41396 .17407 L .41142 .1792 L F
.40887 .18422 m .39313 .17506 L .38986 .18007 L F
.40887 .18422 m .41139 .17902 L .39313 .17506 L F
.41142 .1792 m .39648 .17039 L .3932 .17533 L F
.41142 .1792 m .41396 .17407 L .39648 .17039 L F
.41759 .17511 m .40496 .16917 L .40169 .17381 L F
.42026 .17101 m .40858 .16626 L .40531 .17084 L F
.43473 .17629 m .43648 .17111 L .42012 .17013 L F
.43648 .17111 m .42266 .16521 L .42012 .17013 L F
.42026 .17101 m .42279 .16606 L .40858 .16626 L F
.42433 .15417 m .41337 .14675 L .40993 .15133 L .992 1 0 r
F
.43594 .16639 m .4217 .15904 L .4191 .16398 L .99 1 0 r
F
.42266 .16521 m .41158 .1601 L .40825 .1646 L 1 1 0 r
F
.42279 .16606 m .41188 .16174 L .40858 .16626 L F
.40648 .15572 m .40989 .15107 L .39653 .14745 L F
.40309 .16044 m .40648 .15572 L .39238 .15182 L F
.40648 .15572 m .39653 .14745 L .39238 .15182 L F
.40653 .15598 m .40993 .15133 L .39662 .14784 L F
.40989 .15107 m .40071 .14317 L .39653 .14745 L .996 1 0 r
F
.40993 .15133 m .40079 .14356 L .39662 .14784 L .999 1 0 r
F
.40993 .15133 m .41337 .14675 L .40079 .14356 L F
.39974 .16524 m .40309 .16044 L .38827 .15628 L 1 1 0 r
F
.39642 .17012 m .39974 .16524 L .38419 .16082 L F
.39974 .16524 m .38827 .15628 L .38419 .16082 L F
.3998 .16551 m .40315 .16071 L .38837 .15667 L F
.40825 .1646 m .41158 .1601 L .39968 .16146 L F
.39313 .17506 m .39642 .17012 L .38015 .16544 L F
.39642 .17012 m .38419 .16082 L .38015 .16544 L F
.39648 .17039 m .3998 .16551 L .3843 .16121 L F
.3998 .16551 m .38837 .15667 L .3843 .16121 L F
.40496 .16917 m .40825 .1646 L .39561 .16523 L F
.40825 .1646 m .39968 .16146 L .39561 .16523 L F
.40858 .16626 m .41188 .16174 L .40052 .16517 L F
.41337 .14675 m .405 .13937 L .40079 .14356 L .992 1 0 r
F
.40309 .16044 m .39238 .15182 L .38827 .15628 L 1 1 0 r
F
.40315 .16071 m .39248 .15221 L .38837 .15667 L F
.40315 .16071 m .40653 .15598 L .39248 .15221 L F
.41158 .1601 m .40379 .15787 L .39968 .16146 L F
.41158 .1601 m .41493 .15569 L .40379 .15787 L F
.41188 .16174 m .4046 .1617 L .40052 .16517 L .95 .932 0 r
F
.43594 .16639 m .43774 .16129 L .4217 .15904 L .99 1 0 r
F
.42266 .16521 m .42522 .16034 L .41158 .1601 L 1 1 0 r
F
.43774 .16129 m .42433 .15417 L .4217 .15904 L .984 1 0 r
F
.42522 .16034 m .41493 .15569 L .41158 .1601 L 1 1 0 r
F
.41188 .16174 m .41521 .1573 L .4046 .1617 L .95 .932 0 r
F
.40653 .15598 m .39662 .14784 L .39248 .15221 L 1 1 0 r
F
.40996 .15666 m .40794 .15446 L .40379 .15787 L .976 1 0 r
F
.41493 .15569 m .41215 .1552 L .40996 .15666 L F
.41215 .1552 m .40794 .15446 L .40996 .15666 L F
.41493 .15569 m .4183 .15135 L .40794 .15446 L F
.42522 .16034 m .42781 .15553 L .41493 .15569 L 1 1 0 r
F
.42781 .15553 m .4183 .15135 L .41493 .15569 L F
.41521 .1573 m .41856 .15293 L .40872 .15844 L .839 .709 0 r
F
.4183 .15135 m .41212 .15129 L .40794 .15446 L .887 .851 0 r
F
.4183 .15135 m .4217 .14709 L .41212 .15129 L F
.41856 .15293 m .41287 .15544 L .40872 .15844 L .735 .369 0 r
F
.4217 .14709 m .41635 .14839 L .41212 .15129 L .748 .531 0 r
F
.38986 .18007 m .39313 .17506 L .37614 .17014 L 1 1 0 r
F
.39313 .17506 m .38015 .16544 L .37614 .17014 L F
.3932 .17533 m .39648 .17039 L .38026 .16583 L F
.39648 .17039 m .3843 .16121 L .38026 .16583 L F
.40169 .17381 m .40496 .16917 L .39157 .16914 L F
.40496 .16917 m .39561 .16523 L .39157 .16914 L F
.40531 .17084 m .40858 .16626 L .39647 .16883 L F
.40858 .16626 m .40052 .16517 L .39647 .16883 L F
.41521 .1573 m .40872 .15844 L .4046 .1617 L .839 .709 0 r
F
.42717 .19266 m .40887 .18422 L .40639 .18948 L 1 1 0 r
F
.42717 .19266 m .42889 .18726 L .40887 .18422 L F
.40639 .18948 m .40887 .18422 L .38986 .18007 L F
.40891 .18441 m .41142 .1792 L .3932 .17533 L F
.42548 .19811 m .42717 .19266 L .40639 .18948 L F
.42719 .19279 m .42891 .18739 L .40891 .18441 L F
.42891 .18739 m .41142 .1792 L .40891 .18441 L F
.42891 .18739 m .43064 .18205 L .41142 .1792 L F
.40639 .18948 m .38986 .18007 L .38664 .18516 L F
.40891 .18441 m .3932 .17533 L .38994 .18035 L F
.41262 .18523 m .4151 .18014 L .39845 .17852 L F
.4151 .18014 m .40169 .17381 L .39845 .17852 L F
.4151 .18014 m .41759 .17511 L .40169 .17381 L F
.43129 .18681 m .4151 .18014 L .41262 .18523 L F
.42548 .19811 m .40639 .18948 L .40392 .1948 L F
.42719 .19279 m .40891 .18441 L .40643 .18967 L F
.40392 .1948 m .40639 .18948 L .38664 .18516 L F
.40643 .18967 m .40891 .18441 L .38994 .18035 L F
.41262 .18523 m .39845 .17852 L .39524 .1833 L F
.41527 .18107 m .40207 .1755 L .39886 .18023 L F
.43129 .18681 m .433 .18153 L .4151 .18014 L F
.433 .18153 m .41759 .17511 L .4151 .18014 L F
.41527 .18107 m .41775 .17601 L .40207 .1755 L F
.41775 .17601 m .40531 .17084 L .40207 .1755 L F
.433 .18153 m .43473 .17629 L .41759 .17511 L F
.41775 .17601 m .42026 .17101 L .40531 .17084 L F
.38664 .18516 m .38986 .18007 L .37217 .17491 L F
.38986 .18007 m .37614 .17014 L .37217 .17491 L F
.38994 .18035 m .3932 .17533 L .37626 .17053 L F
.3932 .17533 m .38026 .16583 L .37626 .17053 L F
.39845 .17852 m .40169 .17381 L .38757 .17318 L F
.40169 .17381 m .39157 .16914 L .38757 .17318 L F
.40207 .1755 m .40531 .17084 L .39247 .17266 L F
.40531 .17084 m .39647 .16883 L .39247 .17266 L F
.4046 .1617 m .40872 .15844 L .40419 .17994 L .132 0 0 r
F
.42379 .20363 m .42548 .19811 L .40392 .1948 L 1 1 0 r
F
.4255 .19825 m .42719 .19279 L .40643 .18967 L F
.4296 .19215 m .41262 .18523 L .41017 .19038 L F
.4296 .19215 m .43129 .18681 L .41262 .18523 L F
.41017 .19038 m .41262 .18523 L .39524 .1833 L F
.41281 .18618 m .41527 .18107 L .39886 .18023 L F
.40872 .15844 m .40904 .16568 L .40419 .17994 L .218 .001 0 r
F
.40904 .16568 m .40984 .18321 L .40902 .18274 L F
.40904 .16568 m .40902 .18274 L .40419 .17994 L F
.42379 .20363 m .40392 .1948 L .40149 .20019 L 1 1 0 r
F
.42213 .20919 m .40149 .20019 L .39908 .20563 L F
.42213 .20919 m .42379 .20363 L .40149 .20019 L F
.42382 .20376 m .40397 .195 L .40154 .20038 L F
.42382 .20376 m .4255 .19825 L .40397 .195 L F
.4255 .19825 m .40643 .18967 L .40397 .195 L F
.42049 .21481 m .42213 .20919 L .39908 .20563 L F
.42216 .20933 m .42382 .20376 L .40154 .20038 L F
.42462 .20845 m .42627 .20296 L .40535 .20083 L F
.42627 .20296 m .40775 .19558 L .40535 .20083 L F
.42627 .20296 m .42792 .19753 L .40775 .19558 L F
.42049 .21481 m .39908 .20563 L .3967 .21113 L F
.42216 .20933 m .40154 .20038 L .39913 .20582 L F
.42462 .20845 m .40535 .20083 L .40297 .20614 L F
.42636 .20355 m .40797 .19656 L .40558 .20182 L F
.42636 .20355 m .42801 .1981 L .40797 .19656 L F
.42792 .19753 m .41017 .19038 L .40775 .19558 L F
.42801 .1981 m .41038 .19134 L .40797 .19656 L F
.40149 .20019 m .40392 .1948 L .38344 .1903 L F
.40392 .1948 m .38664 .18516 L .38344 .1903 L F
.40397 .195 m .40643 .18967 L .38671 .18543 L F
.40775 .19558 m .41017 .19038 L .39206 .18816 L F
.40149 .20019 m .38344 .1903 L .38028 .19552 L F
.40397 .195 m .38671 .18543 L .38352 .19058 L F
.39908 .20563 m .40149 .20019 L .38028 .19552 L F
.40154 .20038 m .40397 .195 L .38352 .19058 L F
.40535 .20083 m .40775 .19558 L .38891 .19308 L F
.40775 .19558 m .39206 .18816 L .38891 .19308 L F
.40797 .19656 m .41038 .19134 L .39253 .18989 L F
.40643 .18967 m .38994 .18035 L .38671 .18543 L F
.41017 .19038 m .39524 .1833 L .39206 .18816 L F
.41038 .19134 m .39568 .18503 L .39253 .18989 L F
.42792 .19753 m .4296 .19215 L .41017 .19038 L F
.41038 .19134 m .41281 .18618 L .39568 .18503 L F
.41281 .18618 m .39886 .18023 L .39568 .18503 L F
.39653 .14745 m .40071 .14317 L .38936 .13937 L .993 1 0 r
F
.39238 .15182 m .39653 .14745 L .38449 .14328 L 1 1 0 r
F
.39653 .14745 m .38936 .13937 L .38449 .14328 L .993 1 0 r
F
.39662 .14784 m .40079 .14356 L .3895 .13998 L .996 1 0 r
F
.40071 .14317 m .39427 .13558 L .38936 .13937 L .982 1 0 r
F
.40071 .14317 m .40493 .13898 L .39427 .13558 L F
.40079 .14356 m .3944 .1362 L .3895 .13998 L .985 1 0 r
F
.40079 .14356 m .405 .13937 L .3944 .1362 L F
.40493 .13898 m .39921 .13192 L .39427 .13558 L .97 1 0 r
F
.405 .13937 m .39934 .13256 L .3944 .1362 L .973 1 0 r
F
.39968 .16146 m .40379 .15787 L .39593 .16669 L 0 0 0 r
F
.38344 .1903 m .38664 .18516 L .36824 .17976 L 1 1 0 r
F
.38664 .18516 m .37217 .17491 L .36824 .17976 L F
.38671 .18543 m .38994 .18035 L .3723 .1753 L F
.38994 .18035 m .37626 .17053 L .3723 .1753 L F
.39524 .1833 m .39845 .17852 L .3836 .17735 L F
.39845 .17852 m .38757 .17318 L .3836 .17735 L F
.39886 .18023 m .40207 .1755 L .38851 .17664 L F
.40207 .1755 m .39247 .17266 L .38851 .17664 L F
.40052 .16517 m .4046 .1617 L .39878 .17854 L .008 0 0 r
F
.38344 .1903 m .36824 .17976 L .36434 .18469 L 1 1 0 r
F
.38671 .18543 m .3723 .1753 L .36837 .18016 L F
.39524 .1833 m .3836 .17735 L .37967 .18163 L F
.39886 .18023 m .38851 .17664 L .38458 .18075 L F
.39647 .16883 m .40052 .16517 L .39355 .17844 L 0 0 0 r
F
.40052 .16517 m .39878 .17854 L .39355 .17844 L .008 0 0 r
F
.40379 .15787 m .40114 .16629 L .39593 .16669 L 0 0 0 r
F
.40379 .15787 m .40794 .15446 L .40136 .1659 L F
.40123 .166 m .40136 .1659 L .40114 .16629 L F
.40379 .15787 m .40136 .1659 L .40123 .166 L F
.43648 .17111 m .43824 .16597 L .42266 .16521 L 1 1 0 r
F
.43824 .16597 m .42522 .16034 L .42266 .16521 L F
.42279 .16606 m .42534 .16116 L .41188 .16174 L F
.42534 .16116 m .41521 .1573 L .41188 .16174 L F
.40872 .15844 m .41287 .15544 L .40998 .18195 L .218 .001 0 r
F
.40978 .18198 m .40998 .18195 L .40984 .18321 L F
.40872 .15844 m .40998 .18195 L .40978 .18198 L F
.42801 .1981 m .42968 .1927 L .41038 .19134 L 1 1 0 r
F
.42968 .1927 m .41281 .18618 L .41038 .19134 L F
.42968 .1927 m .43137 .18735 L .41281 .18618 L F
.43137 .18735 m .41527 .18107 L .41281 .18618 L F
.43137 .18735 m .43307 .18205 L .41527 .18107 L F
.43307 .18205 m .41775 .17601 L .41527 .18107 L F
.43307 .18205 m .43479 .1768 L .41775 .17601 L F
.43479 .1768 m .42026 .17101 L .41775 .17601 L F
.43824 .16597 m .44001 .16089 L .42522 .16034 L F
.44001 .16089 m .42781 .15553 L .42522 .16034 L F
.42534 .16116 m .42792 .15632 L .41521 .1573 L F
.42792 .15632 m .41856 .15293 L .41521 .1573 L F
.42781 .15553 m .43042 .15077 L .4183 .15135 L F
.43042 .15077 m .4217 .14709 L .4183 .15135 L F
.41856 .15293 m .42194 .14864 L .41287 .15544 L .735 .369 0 r
F
.41707 .15276 m .42158 .19327 L .41891 .19145 L .316 .035 0 r
F
.41821 .19018 m .41891 .19145 L .41824 .19099 L F
.41707 .15276 m .41891 .19145 L .41821 .19018 L F
.44437 .30607 m .44348 .30869 L .44419 .31026 L 1 .548 0 r
F
.43994 .34015 m .44005 .33939 L .43869 .34165 L 1 .746 0 r
F
.4401 .33965 m .44005 .33939 L .43869 .34165 L 1 .238 0 r
F
.44005 .33939 m .41838 .23148 L .43869 .34165 L F
.43869 .34165 m .43671 .33665 L .43853 .3421 L F
.43671 .33665 m .43667 .33675 L .43853 .3421 L F
.43853 .3421 m .43712 .3385 L .43705 .33869 L F
.43656 .34813 m .38961 .24008 L .43638 .34866 L .157 .026 0 r
F
.43788 .34634 m .43789 .34631 L .43788 .34632 L 1 .897 0 r
F
.43871 .34889 m .43789 .34631 L .43788 .34634 L F
.43816 .34598 m .43791 .34622 L .43788 .34632 L 1 .827 0 r
F
.43812 .34609 m .43803 .34587 L .43803 .34667 L .157 .025 0 r
F
.43803 .34587 m .39181 .23447 L .43788 .3463 L F
.43802 .34589 m .43791 .34622 L .43816 .34598 L 1 .827 0 r
F
.43803 .34587 m .43788 .3463 L .43803 .34667 L .157 .025 0 r
F
.43829 .34562 m .43803 .34587 L .43816 .34598 L 1 .827 0 r
F
.43803 .34587 m .43802 .34589 L .43802 .34589 L F
.43803 .34587 m .43849 .34201 L .43797 .34573 L .157 .025 0 r
F
.43803 .34587 m .43802 .34589 L .43816 .34598 L 1 .827 0 r
F
.43933 .3446 m .43829 .34562 L .43816 .34598 L F
.43933 .3446 m .43994 .34015 L .43853 .3421 L F
.43853 .34215 m .43849 .34201 L .43803 .34587 L .157 .025 0 r
F
.43788 .34632 m .39181 .23447 L .38961 .24008 L F
.43788 .3463 m .39181 .23447 L .43788 .34632 L F
.43698 .3491 m .43784 .34623 L .43699 .34436 L .157 .026 0 r
F
.43698 .3491 m .43699 .34436 L .4361 .34706 L F
.43803 .34587 m .43853 .3421 L .43032 .35345 L 1 .827 0 r
F
.43933 .3446 m .43853 .3421 L .43803 .34587 L F
.43884 .34337 m .43853 .34215 L .43803 .34587 L .157 .025 0 r
F
.44176 .35486 m .43884 .34337 L .43803 .34587 L F
.43803 .34587 m .43802 .34589 L .43802 .34589 L 1 .827 0 r
F
.43791 .34622 m .43791 .34622 L .43788 .34632 L F
.43803 .34667 m .43788 .3463 L .43788 .34632 L .157 .025 0 r
F
.44176 .35486 m .43812 .34609 L .43803 .34667 L F
.43869 .34165 m .4388 .34128 L .4314 .35033 L 1 .746 0 r
F
.4388 .34128 m .44055 .33555 L .43934 .3375 L F
.4388 .34128 m .43934 .3375 L .4314 .35033 L F
.44005 .33939 m .44055 .33555 L .43869 .34165 L F
.44234 .32038 m .44292 .31473 L .43638 .33566 L 1 .342 0 r
F
.44292 .31473 m .44251 .31604 L .44251 .31602 L .934 .238 0 r
F
.44251 .31604 m .44213 .31729 L .44251 .31602 L F
.44251 .31602 m .44213 .31729 L .44198 .31772 L F
.44198 .31772 m .43689 .33429 L .43578 .33759 L F
.44213 .31729 m .43689 .33429 L .44198 .31772 L F
.44292 .31473 m .44348 .30869 L .43725 .33287 L F
.43717 .33337 m .43725 .33287 L .43689 .33429 L F
.44292 .31473 m .43725 .33287 L .43717 .33337 L F
.43725 .33287 m .43801 .33092 L .43689 .33429 L .902 .187 0 r
F
.44348 .30869 m .43821 .33011 L .43725 .33287 L F
.43821 .33011 m .43801 .33092 L .43725 .33287 L F
.44348 .30869 m .44402 .30218 L .43828 .3296 L F
.44348 .30869 m .43828 .3296 L .43821 .33011 L F
.43821 .33011 m .43828 .3296 L .43801 .33092 L F
.43828 .3296 m .43913 .32746 L .43801 .33092 L .875 .18 0 r
F
.44402 .30218 m .43925 .32682 L .43828 .3296 L F
.43925 .32682 m .43913 .32746 L .43828 .3296 L F
.4423 .31099 m .44294 .3047 L .43932 .32631 L F
.44402 .30218 m .44294 .3047 L .4423 .31099 L F
.44402 .30218 m .44455 .29514 L .44294 .3047 L F
.44402 .30218 m .43932 .32631 L .43929 .32652 L F
.44402 .30218 m .43924 .32678 L .43918 .32718 L F
.43918 .32718 m .43924 .32678 L .43913 .32746 L F
.43924 .32678 m .44025 .3239 L .43913 .32746 L .844 .173 0 r
F
.43929 .32652 m .43932 .32631 L .43924 .32678 L .875 .18 0 r
F
.44455 .29514 m .44025 .3239 L .43924 .32678 L .844 .173 0 r
F
.44455 .29514 m .44505 .28746 L .4422 .30909 L F
.44225 .31032 m .4422 .30909 L .44055 .32159 L F
.44455 .29514 m .4422 .30909 L .44225 .31032 L F
.44047 .32244 m .44055 .32159 L .44025 .3239 L F
.44455 .29514 m .44055 .32159 L .44047 .32244 L F
.44467 .29036 m .44137 .32019 L .44025 .3239 L .81 .166 0 r
F
.4449 .28882 m .44137 .32019 L .44467 .29036 L F
.44505 .28746 m .4449 .28882 L .44467 .29036 L F
.44505 .28746 m .44555 .27906 L .44158 .31815 L F
.4415 .31903 m .44158 .31815 L .44137 .32019 L F
.44505 .28746 m .44158 .31815 L .4415 .31903 L F
.44469 .28745 m .44249 .3163 L .44137 .32019 L .772 .158 0 r
F
.44477 .28697 m .44249 .3163 L .44469 .28745 L F
.44496 .28514 m .44249 .3163 L .44487 .28571 L F
.44529 .28213 m .44249 .3163 L .44505 .28392 L F
.44555 .27906 m .44529 .28213 L .44505 .28392 L F
.44487 .28571 m .44477 .28697 L .44469 .28745 L F
.44505 .28392 m .44496 .28514 L .44487 .28571 L F
.44555 .27906 m .44603 .26986 L .44262 .31469 L F
.44555 .27906 m .44262 .31469 L .44255 .31561 L F
.44603 .26986 m .44541 .28068 L .44503 .28301 L .73 .149 0 r
F
.44541 .28068 m .44361 .31219 L .44503 .28301 L F
.44555 .27816 m .44576 .27337 L .44361 .31219 L F
.44591 .27181 m .44625 .26435 L .44576 .27337 L F
.44591 .27181 m .44576 .27337 L .44555 .27816 L F
.44496 .29321 m .44497 .29255 L .44494 .29333 L 1 .395 0 r
F
.44497 .29255 m .44505 .28746 L .44494 .29333 L F
.44527 .28664 m .44505 .28746 L .44496 .29321 L F
.4461 .26711 m .44472 .30779 L .44361 .31219 L 0 0 0 r
F
.44603 .26986 m .44625 .26435 L .44591 .27181 L .73 .149 0 r
F
.44605 .26973 m .44605 .26972 L .44604 .26977 L 1 .32 0 r
F
.44604 .26979 m .44604 .26977 L .44603 .26986 L F
.44618 .26637 m .44472 .30779 L .4461 .26711 L 0 0 0 r
F
.44631 .26383 m .44472 .30779 L .44624 .26466 L F
.44646 .26107 m .44472 .30779 L .44636 .26246 L F
.44255 .31561 m .44262 .31469 L .44249 .3163 L .772 .158 0 r
F
.44503 .28301 m .44361 .31219 L .44249 .3163 L .73 .149 0 r
F
.44638 .31089 m .44234 .32038 L .44637 .31103 L 1 .649 0 r
F
.45068 .30719 m .44176 .3257 L .45065 .30749 L 1 .695 0 r
F
.45069 .30704 m .44176 .3257 L .45067 .30721 L F
.45041 .31402 m .45061 .30788 L .44998 .31277 L .165 .022 0 r
F
.44931 .3183 m .44989 .31369 L .4495 .31268 L .147 .019 0 r
F
.44931 .3183 m .4495 .31268 L .44897 .31733 L F
.44971 .31942 m .44989 .31369 L .44931 .3183 L F
.44919 .31186 m .44894 .31113 L .44894 .31121 L .165 .022 0 r
F
.45041 .31402 m .45061 .30788 L .44116 .33074 L 1 .739 0 r
F
.4504 .30839 m .44176 .3257 L .44116 .33074 L 1 .695 0 r
F
.45045 .3079 m .44176 .3257 L .4504 .30839 L F
.44971 .31942 m .44897 .31733 L .44175 .33595 L .147 .019 0 r
F
.45014 .32064 m .44971 .31942 L .44888 .32299 L F
.44971 .31942 m .44006 .33947 L .44236 .35092 L F
.45014 .32064 m .45033 .31484 L .44055 .33555 L 1 .78 0 r
F
.45041 .31402 m .44116 .33074 L .45039 .31418 L 1 .739 0 r
F
.4504 .31417 m .44116 .33074 L .45038 .31439 L F
.45014 .32064 m .44055 .33555 L .44981 .32126 L 1 .78 0 r
F
.45033 .31484 m .44116 .33074 L .44055 .33555 L 1 .739 0 r
F
.45038 .31439 m .44116 .33074 L .45033 .31484 L F
.44175 .33595 m .44005 .33939 L .44055 .33846 L .147 .019 0 r
F
.44981 .32126 m .44055 .33555 L .44005 .33939 L 1 .78 0 r
F
.45233 .33207 m .45223 .33173 L .45234 .33209 L 0 0 0 r
F
.45223 .33173 m .45212 .3314 L .45223 .33175 L F
.45212 .33142 m .45212 .3314 L .45202 .33111 L F
.45202 .33112 m .45202 .33111 L .45194 .33085 L F
.45194 .33087 m .45187 .33064 L .45187 .33065 L F
.45194 .33086 m .45187 .33064 L .45194 .33087 L F
.45194 .33086 m .45194 .33085 L .45187 .33064 L F
.45187 .33065 m .45187 .33064 L .45182 .33049 L F
.45182 .3305 m .45182 .33049 L .45179 .33042 L F
.45179 .33042 m .45145 .33081 L .45143 .33092 L 1 .854 0 r
F
.45383 .33099 m .45014 .32064 L .44236 .35092 L .147 .019 0 r
F
.45014 .32064 m .44888 .32299 L .44236 .35092 L F
.43479 .1768 m .43653 .17159 L .42026 .17101 L 1 1 0 r
F
.43653 .17159 m .42279 .16606 L .42026 .17101 L F
.43653 .17159 m .43829 .16644 L .42279 .16606 L F
.43829 .16644 m .42534 .16116 L .42279 .16606 L F
.43829 .16644 m .44006 .16133 L .42534 .16116 L F
.44006 .16133 m .42792 .15632 L .42534 .16116 L F
.42792 .15632 m .43051 .15152 L .41856 .15293 L F
.43042 .15077 m .43305 .14606 L .4217 .14709 L F
.43051 .15152 m .42194 .14864 L .41856 .15293 L F
.43051 .15152 m .43313 .14678 L .42194 .14864 L F
.43305 .14606 m .42513 .14291 L .4217 .14709 L F
.43313 .14678 m .42534 .14443 L .42194 .14864 L F
.42118 .14921 m .41827 .15172 L .41287 .15544 L .636 .215 0 r
F
.41827 .15172 m .41707 .15276 L .41662 .15305 L F
.41827 .15172 m .41662 .15305 L .41287 .15544 L F
.42194 .14864 m .42158 .14895 L .42118 .14921 L F
.42158 .14895 m .41707 .15276 L .42118 .14921 L F
.42194 .14864 m .42534 .14443 L .41707 .15276 L F
.4172 .15264 m .42132 .1505 L .41707 .15276 L 0 0 0 r
F
.42534 .14443 m .42132 .1505 L .4172 .15264 L F
.447 .24892 m .44582 .30301 L .44472 .30779 L F
.44838 .29458 m .44815 .29592 L .44826 .29957 L .997 .271 0 r
F
.4479 .30191 m .4479 .29738 L .44744 .30492 L F
.44815 .29592 m .4479 .29738 L .4479 .30191 L F
.45471 .25721 m .4479 .29738 L .45469 .25777 L F
.45237 .26564 m .45232 .26549 L .45237 .26656 L 1 .359 0 r
F
.45232 .26549 m .45233 .26643 L .45237 .26656 L F
.45633 .26488 m .4563 .26436 L .45543 .25858 L 0 0 0 r
F
.45533 .25809 m .45533 .25789 L .4542 .25041 L F
.45237 .26564 m .45237 .26545 L .45221 .26622 L 1 .444 0 r
F
.45394 .25714 m .45373 .2556 L .452 .26444 L 1 .359 0 r
F
.45221 .26622 m .4542 .25041 L .45174 .26181 L 1 .444 0 r
F
.45221 .26622 m .45174 .26181 L .4517 .26814 L F
.45394 .25714 m .45382 .25515 L .45373 .2556 L 1 .359 0 r
F
.45396 .25748 m .4542 .25041 L .45221 .26622 L 1 .444 0 r
F
.45195 .26819 m .45099 .27084 L .45089 .27274 L F
.45233 .26658 m .45197 .26771 L .45195 .26819 L F
.45197 .26771 m .45099 .27084 L .45195 .26819 L F
.45237 .26564 m .45099 .27084 L .45233 .26658 L F
.45422 .25244 m .44856 .28741 L .44818 .29541 L .944 .208 0 r
F
.45514 .2459 m .45416 .25207 L .45422 .25244 L F
.45416 .25207 m .44856 .28741 L .45422 .25244 L F
.4435 .12759 m .44608 .12328 L .43815 .11694 L .719 .702 0 r
F
.44178 .11302 m .44115 .11209 L .43913 .11307 L .885 1 0 r
F
.43837 .13679 m .44106 .13222 L .43206 .1348 L 1 1 0 r
F
.44106 .13222 m .43555 .13087 L .43206 .1348 L F
.44112 .1328 m .44382 .12821 L .4357 .13227 L F
.44382 .12821 m .43815 .11694 L .4357 .13227 L .719 .702 0 r
F
.44528 .12264 m .44178 .11302 L .43815 .11694 L 1 1 0 r
F
.44654 .12365 m .44584 .12208 L .44528 .12264 L F
.44584 .12208 m .44178 .11302 L .44528 .12264 L F
.4614 .12801 m .46244 .1233 L .45269 .12283 L .936 1 0 r
F
.45957 .12617 m .45479 .12182 L .45289 .12657 L 1 1 0 r
F
.4625 .126 m .46031 .12481 L .45957 .12617 L F
.46031 .12481 m .45479 .12182 L .45957 .12617 L F
.46244 .1233 m .46348 .11866 L .45462 .11831 L .934 1 0 r
F
.47226 .12808 m .47239 .12332 L .46244 .1233 L .918 1 0 r
F
.4625 .126 m .46353 .12114 L .45479 .12182 L 1 1 0 r
F
.4602 .1214 m .4567 .11709 L .45479 .12182 L F
.46353 .12114 m .46106 .11968 L .4602 .1214 L F
.46106 .11968 m .4567 .11709 L .4602 .1214 L F
.46348 .11866 m .46453 .11406 L .45657 .11384 L .933 1 0 r
F
.47239 .12332 m .47252 .11861 L .46348 .11866 L .915 1 0 r
F
.46353 .12114 m .46457 .11632 L .4567 .11709 L 1 1 0 r
F
.46457 .11632 m .45863 .11238 L .4567 .11709 L F
.46259 .11662 m .45864 .11253 L .45671 .11728 L F
.46457 .1164 m .46316 .11548 L .46259 .11662 L F
.46316 .11548 m .45864 .11253 L .46259 .11662 L F
.4622 .12137 m .45671 .11728 L .4548 .12204 L F
.46353 .12124 m .46257 .12068 L .4622 .12137 L F
.46257 .12068 m .45671 .11728 L .4622 .12137 L F
.45289 .12657 m .45479 .12182 L .45447 .12187 L F
.45266 .12645 m .45447 .12187 L .44651 .12317 L F
.45289 .12657 m .45447 .12187 L .45266 .12645 L F
.45479 .12182 m .4567 .11709 L .44893 .1133 L .768 .82 0 r
F
.4548 .12204 m .45671 .11728 L .45635 .1171 L .767 .814 0 r
F
.45455 .12167 m .45635 .1171 L .44894 .11341 L F
.4548 .12204 m .45635 .1171 L .45455 .12167 L F
.4548 .12204 m .44894 .11341 L .44654 .12365 L F
.44654 .12365 m .44894 .11341 L .44178 .11302 L 1 1 0 r
F
.44899 .11886 m .44764 .11922 L .4459 .121 L .788 .459 0 r
F
.44914 .11871 m .44617 .11961 L .44899 .11886 L F
.45671 .11728 m .45177 .10921 L .44894 .11341 L .772 .826 0 r
F
.44926 .11868 m .45203 .11418 L .44617 .11961 L .788 .459 0 r
F
.44382 .12821 m .44608 .12328 L .4435 .12759 L .719 .702 0 r
F
.45513 .24553 m .44832 .2889 L .45514 .2459 L .944 .208 0 r
F
.45267 .26756 m .45233 .26645 L .45233 .26658 L 1 .359 0 r
F
.45248 .27035 m .45245 .26502 L .4479 .29738 L .997 .271 0 r
F
.45471 .25721 m .45245 .26502 L .45248 .27035 L F
.45471 .25721 m .45464 .24944 L .45245 .26502 L F
.45388 .26303 m .44838 .29458 L .44826 .29957 L F
.45384 .26273 m .44838 .29458 L .45388 .26303 L F
.45481 .26481 m .45469 .25777 L .45439 .25968 L 1 .34 0 r
F
.45383 .28113 m .45238 .27611 L .45233 .27689 L .283 .043 0 r
F
.45474 .28372 m .45384 .28082 L .45383 .28113 L F
.45384 .28082 m .45238 .27611 L .45383 .28113 L F
.45474 .28368 m .45385 .2808 L .45474 .28372 L F
.45385 .2808 m .45238 .27611 L .45384 .28082 L F
.45385 .2808 m .45384 .28082 L .45474 .28372 L F
.4548 .26591 m .45451 .26744 L .4548 .26612 L 1 .34 0 r
F
.44823 .30072 m .44744 .30492 L .44823 .30075 L F
.45469 .29329 m .45485 .28401 L .45233 .27689 L .259 .039 0 r
F
.45193 .28314 m .45161 .28354 L .45155 .28447 L 1 .548 0 r
F
.45198 .28242 m .45161 .28354 L .45193 .28314 L F
.45469 .29329 m .45233 .27689 L .45161 .28354 L .259 .039 0 r
F
.45149 .28469 m .45074 .28624 L .45064 .28767 L 1 .548 0 r
F
.45161 .28354 m .45074 .28624 L .45149 .28469 L F
.45449 .26653 m .45439 .25968 L .44744 .30492 L 1 .34 0 r
F
.44818 .29541 m .44832 .2889 L .4479 .29738 L .944 .208 0 r
F
.44856 .28741 m .44832 .2889 L .44818 .29541 L F
.44814 .30122 m .44748 .30469 L .44799 .30566 L 1 .34 0 r
F
.44716 .31047 m .44744 .30492 L .44695 .31169 L F
.44748 .30469 m .44744 .30492 L .44716 .31047 L F
.4548 .26591 m .45476 .26509 L .44744 .30492 L F
.45132 .26375 m .45118 .26429 L .45117 .26443 L 1 .395 0 r
F
.45158 .26104 m .4514 .26177 L .45151 .26289 L F
.4514 .26177 m .45133 .26357 L .45151 .26289 L F
.45151 .26289 m .45133 .26357 L .45132 .26375 L F
.4542 .25041 m .45456 .24076 L .45167 .25496 L F
.4542 .25041 m .45167 .25496 L .45158 .26104 L F
.45456 .24076 m .45173 .25278 L .45167 .25496 L 1 .353 0 r
F
.45456 .24076 m .45497 .23107 L .45188 .24683 L F
.45456 .24076 m .45188 .24683 L .45173 .25278 L F
.45602 .23091 m .44871 .27932 L .44832 .2889 L .915 .182 0 r
F
.45569 .24198 m .45602 .23091 L .44832 .2889 L .944 .208 0 r
F
.45485 .28401 m .45474 .28368 L .45474 .28372 L .283 .043 0 r
F
.45497 .27402 m .45484 .27361 L .45484 .27366 L 1 .359 0 r
F
.45501 .27415 m .45497 .274 L .45497 .27402 L F
.4507 .30074 m .45067 .30105 L .4509 .30052 L 1 .649 0 r
F
.45068 .30719 m .45065 .30749 L .45067 .30746 L 1 .695 0 r
F
.45078 .3073 m .45069 .30704 L .45078 .30824 L .187 .026 0 r
F
.45071 .30712 m .45067 .30746 L .45067 .30744 L 1 .695 0 r
F
.45088 .30825 m .45088 .30724 L .45061 .30788 L 1 .739 0 r
F
.45069 .30704 m .45062 .30776 L .45078 .30824 L .187 .026 0 r
F
.45078 .3073 m .45078 .30824 L .45109 .30917 L F
.45098 .29964 m .45122 .29272 L .45072 .29427 L 1 .649 0 r
F
.45098 .29964 m .45072 .29427 L .45075 .3002 L F
.45073 .30036 m .4507 .30074 L .45093 .3002 L F
.4508 .29328 m .45076 .29376 L .45097 .2932 L 1 .599 0 r
F
.45098 .29964 m .45169 .29403 L .45122 .29272 L .209 .03 0 r
F
.45437 .31001 m .45453 .30195 L .45169 .29403 L F
.45127 .29895 m .45098 .29964 L .45126 .29912 L 1 .649 0 r
F
.45098 .29964 m .45097 .29973 L .45126 .29912 L F
.45101 .29969 m .45096 .30013 L .45154 .29878 L F
.45154 .29878 m .45095 .30016 L .45091 .30051 L F
.45266 .30292 m .45224 .30379 L .45222 .30398 L 1 .695 0 r
F
.45437 .31001 m .45169 .29403 L .45098 .29964 L .209 .03 0 r
F
.45098 .29964 m .45075 .3002 L .45097 .29973 L 1 .649 0 r
F
.45102 .29254 m .45081 .29312 L .45101 .29271 L 1 .599 0 r
F
.45081 .29312 m .4508 .29328 L .45101 .29271 L F
.45075 .3002 m .45073 .30036 L .45126 .29912 L 1 .649 0 r
F
.45169 .29403 m .45129 .29182 L .45122 .29272 L .234 .034 0 r
F
.45453 .30195 m .45175 .29327 L .45169 .29403 L F
.45175 .29327 m .45129 .29182 L .45169 .29403 L F
.45145 .30109 m .45098 .29964 L .45138 .30183 L .209 .03 0 r
F
.45101 .29969 m .45097 .29981 L .45096 .30013 L 1 .649 0 r
F
.45098 .29964 m .45096 .29983 L .45138 .30183 L .209 .03 0 r
F
.45097 .29981 m .45093 .3002 L .45096 .30013 L 1 .649 0 r
F
.45093 .3002 m .4509 .30052 L .45091 .30051 L F
.45138 .30183 m .45096 .29983 L .4509 .30052 L .209 .03 0 r
F
.45437 .31001 m .45145 .30109 L .45138 .30183 L F
.4542 .3175 m .45437 .31001 L .45138 .30183 L .187 .026 0 r
F
.45129 .30252 m .45138 .30183 L .4509 .30052 L F
.4542 .3175 m .45138 .30183 L .45129 .30252 L F
.45102 .29254 m .45101 .29271 L .45128 .29198 L 1 .599 0 r
F
.45501 .27415 m .4548 .27069 L .4545 .2725 L 1 .359 0 r
F
.45064 .31722 m .45033 .31484 L .4503 .31577 L .147 .019 0 r
F
.45383 .33099 m .45072 .31664 L .45064 .31722 L F
.45072 .31664 m .45033 .31484 L .45064 .31722 L F
.45517 .34099 m .45509 .34031 L .45342 .34288 L 1 .851 0 r
F
.47062 .38937 m .45516 .34093 L .45516 .34095 L 0 0 0 r
F
.45611 .29265 m .4561 .29258 L .45582 .2911 L F
.47091 .37496 m .45596 .30096 L .45596 .30099 L F
.45596 .30096 m .45573 .29983 L .45596 .30099 L F
.45606 .3215 m .4555 .32232 L .45609 .32186 L 1 .839 0 r
F
.4556 .31494 m .4556 .31493 L .45555 .31472 L 0 0 0 r
F
.47086 .37734 m .45604 .30918 L .45607 .30967 L F
.45604 .30918 m .45563 .3073 L .45607 .30967 L F
.45582 .31589 m .4556 .31494 L .4556 .31497 L F
.47081 .37973 m .45581 .31586 L .45582 .31589 L F
.45581 .31586 m .4556 .31494 L .45582 .31589 L F
.45522 .33443 m .45445 .33182 L .45471 .33529 L 1 .842 0 r
F
.45528 .33432 m .45523 .33415 L .45522 .33443 L F
.45523 .33415 m .45519 .33404 L .45522 .33443 L F
.45574 .33356 m .45532 .333 L .45528 .33432 L F
.4554 .3289 m .45519 .32816 L .45522 .33443 L 0 0 0 r
F
.45532 .333 m .45445 .33182 L .45528 .33432 L 1 .842 0 r
F
.45626 .33267 m .4554 .3289 L .45574 .33356 L F
.4554 .3289 m .45383 .33099 L .45574 .33356 L F
.47071 .38453 m .4554 .3289 L .45522 .33443 L 0 0 0 r
F
.45519 .33404 m .45445 .33182 L .45522 .33443 L 1 .842 0 r
F
.45529 .33511 m .45511 .3399 L .45532 .341 L 0 0 0 r
F
.45523 .33677 m .45476 .33575 L .45509 .34031 L 1 .846 0 r
F
.45529 .33511 m .45522 .33491 L .45522 .33519 L F
.47067 .38694 m .45529 .33511 L .45532 .341 L 0 0 0 r
F
.45522 .33519 m .45471 .33529 L .45476 .33575 L 1 .846 0 r
F
.45522 .33491 m .45471 .33529 L .45522 .33519 L F
.45519 .32813 m .45259 .31866 L .45259 .31869 L 0 0 0 r
F
.45519 .32809 m .45259 .31866 L .45519 .32813 L F
.45519 .32809 m .45513 .32753 L .45259 .31866 L F
.45476 .33575 m .45471 .33529 L .45363 .33711 L 1 .846 0 r
F
.47062 .38937 m .47067 .38694 L .45532 .341 L 0 0 0 r
F
.47062 .38937 m .45532 .341 L .4554 .34166 L F
.4589 .31012 m .45839 .31092 L .45913 .31434 L 1 .838 0 r
F
.45857 .31545 m .45786 .31176 L .45814 .31632 L F
.471 .37019 m .47105 .3678 L .4561 .28335 L 0 0 0 r
F
.4561 .28339 m .4561 .28335 L .45595 .28253 L F
.471 .37019 m .4561 .28335 L .4561 .28339 L F
.47096 .37257 m .45611 .29267 L .45614 .2932 L F
.45611 .29267 m .45584 .29122 L .45614 .2932 L F
.45783 .32049 m .45726 .32094 L .45801 .32332 L 1 .839 0 r
F
.45596 .30096 m .4558 .29983 L .45584 .30037 L 0 0 0 r
F
.47091 .37496 m .45593 .30043 L .45596 .30096 L F
.45593 .30043 m .4558 .29983 L .45596 .30096 L F
.4556 .31494 m .45555 .31472 L .4556 .31497 L F
.4564 .32627 m .4555 .32232 L .45586 .32726 L 1 .839 0 r
F
.4555 .32232 m .45495 .32313 L .45586 .32726 L F
.47076 .38212 m .4555 .32232 L .45533 .32823 L 0 0 0 r
F
.45542 .32525 m .45495 .32313 L .45533 .32823 L 1 .839 0 r
F
.4555 .32232 m .45548 .32223 L .45549 .32227 L 0 0 0 r
F
.45556 .32254 m .4555 .32229 L .4555 .32232 L F
.4555 .32229 m .45548 .32223 L .4555 .32232 L F
.47076 .38212 m .45555 .3225 L .45556 .32254 L F
.45555 .3225 m .45548 .32223 L .45556 .32254 L F
.45546 .32912 m .4554 .32888 L .4554 .32891 L F
.47071 .38453 m .45546 .32909 L .45546 .32912 L F
.45546 .32909 m .4554 .32888 L .45546 .32912 L F
.45509 .34031 m .45363 .33711 L .45342 .34288 L 1 .846 0 r
F
.45476 .33575 m .45363 .33711 L .45509 .34031 L F
.47062 .38937 m .45514 .3409 L .45514 .3409 L 0 0 0 r
F
.45471 .33529 m .45383 .33099 L .45363 .33711 L 1 .842 0 r
F
.45445 .33182 m .45383 .33099 L .45471 .33529 L F
.4554 .3289 m .45533 .32823 L .45383 .33099 L F
.45533 .32823 m .45402 .32448 L .45383 .33099 L 1 .839 0 r
F
.45495 .32313 m .45402 .32448 L .45533 .32823 L F
.45491 .32272 m .4542 .3175 L .45402 .32448 L 1 .838 0 r
F
.45544 .32167 m .4546 .31882 L .45491 .32272 L F
.4546 .31882 m .4542 .3175 L .45491 .32272 L F
.45259 .31869 m .45238 .31792 L .4526 .31872 L 0 0 0 r
F
.45259 .31869 m .45259 .31866 L .45238 .31792 L F
.45579 .31801 m .45514 .3178 L .45598 .32059 L 1 .838 0 r
F
.45514 .3178 m .4542 .3175 L .45526 .31934 L F
.45514 .3178 m .45526 .31934 L .45598 .32059 L F
.45598 .32059 m .45526 .31934 L .45544 .32167 L F
.45526 .31934 m .4542 .3175 L .45544 .32167 L F
.45658 .32007 m .45653 .31951 L .45544 .32167 L 1 .839 0 r
F
.47081 .37973 m .45559 .31532 L .45544 .32167 L 0 0 0 r
F
.45559 .31532 m .45502 .31621 L .45554 .31743 L 1 .838 0 r
F
.45502 .31621 m .4542 .3175 L .45514 .3178 L F
.45555 .31475 m .45554 .31468 L .45554 .31471 L 0 0 0 r
F
.45555 .31472 m .45554 .31468 L .45555 .31475 L F
.45555 .31472 m .45555 .31472 L .45554 .31468 L F
.45584 .30037 m .45569 .29928 L .45573 .29983 L F
.4558 .29983 m .45569 .29928 L .45584 .30037 L F
.45573 .29986 m .45573 .29983 L .45573 .29986 L F
.45595 .28253 m .45595 .28253 L .45594 .28243 L F
.471 .37019 m .45595 .28253 L .45595 .28253 L F
.45773 .31003 m .45684 .3059 L .45719 .31117 L 1 .838 0 r
F
.45684 .3059 m .45626 .30687 L .45719 .31117 L F
.45588 .29178 m .45582 .29112 L .45586 .29168 L 0 0 0 r
F
.45584 .29122 m .45582 .29112 L .45588 .29178 L F
.45572 .29943 m .45572 .29943 L .45569 .29928 L F
.47091 .37496 m .45572 .29943 L .45572 .29943 L F
.45665 .31234 m .45567 .30785 L .45609 .31351 L 1 .838 0 r
F
.45567 .30785 m .45556 .30699 L .45561 .30757 L 0 0 0 r
F
.45567 .30785 m .45568 .3071 L .45562 .30723 L 1 .838 0 r
F
.45563 .3073 m .45563 .30729 L .45567 .30785 L 0 0 0 r
F
.45563 .30729 m .45556 .30699 L .45567 .30785 L F
.45567 .30785 m .45562 .30723 L .45437 .31001 L 1 .838 0 r
F
.45556 .30699 m .45541 .3063 L .45561 .30757 L 0 0 0 r
F
.45556 .30699 m .45556 .30695 L .45541 .3063 L F
.45611 .3138 m .45609 .31351 L .45554 .31468 L 1 .838 0 r
F
.45559 .31532 m .45554 .31468 L .4542 .3175 L F
.45554 .31471 m .45554 .31468 L .45542 .3142 L 0 0 0 r
F
.4555 .32232 m .45544 .32167 L .45402 .32448 L 1 .839 0 r
F
.45551 .32231 m .45547 .32176 L .45544 .32167 L 0 0 0 r
F
.45551 .32231 m .45544 .32167 L .45549 .32225 L F
.47076 .38212 m .47081 .37973 L .45547 .32176 L F
.47076 .38212 m .45547 .32176 L .45551 .32231 L F
.45499 .31584 m .45437 .31001 L .4542 .3175 L 1 .838 0 r
F
.45554 .31468 m .45459 .31086 L .45499 .31584 L F
.45459 .31086 m .45437 .31001 L .45499 .31584 L F
.45567 .30785 m .45437 .31001 L .45554 .31468 L F
.45557 .3148 m .45554 .3146 L .45554 .31468 L 0 0 0 r
F
.47086 .37734 m .45567 .30785 L .45557 .3148 L F
.45562 .30723 m .45453 .30195 L .45437 .31001 L 1 .841 0 r
F
.45562 .30723 m .45573 .29986 L .45558 .30706 L 0 0 0 r
F
.45573 .29986 m .45453 .30195 L .45562 .30723 L 1 .841 0 r
F
.47091 .37496 m .45573 .29986 L .45562 .30723 L 0 0 0 r
F
.46158 .32369 m .4613 .32103 L .4614 .32399 L 1 .842 0 r
F
.4613 .32103 m .46063 .32193 L .4614 .32399 L F
.47096 .37257 m .45586 .29168 L .45572 .2994 L 0 0 0 r
F
.45586 .29168 m .4558 .29139 L .45575 .29684 L F
.45586 .29168 m .45575 .29684 L .45572 .2994 L F
.45569 .29934 m .45559 .29951 L .45569 .29937 L 1 .841 0 r
F
.45586 .29168 m .45575 .29074 L .45579 .29133 L 0 0 0 r
F
.45582 .29112 m .45575 .29074 L .45586 .29168 L F
.45582 .29112 m .45582 .2911 L .45575 .29074 L F
.47096 .37257 m .45582 .2911 L .45582 .29112 L F
.45558 .30013 m .45559 .29951 L .45453 .30195 L 1 .841 0 r
F
.45569 .29928 m .45568 .29154 L .45559 .29951 L 1 .848 0 r
F
.45579 .29133 m .45568 .29154 L .45569 .29928 L F
.45572 .2994 m .45569 .29919 L .45569 .29928 L 0 0 0 r
F
.45559 .29951 m .45469 .29329 L .45453 .30195 L 1 .848 0 r
F
.45568 .29154 m .45469 .29329 L .45559 .29951 L F
.45584 .28224 m .4558 .28166 L .45543 .27959 L 0 0 0 r
F
.45584 .28224 m .45543 .27959 L .45545 .27997 L F
.45597 .28298 m .4558 .28166 L .45584 .28224 L F
.471 .37019 m .45594 .28243 L .45597 .28298 L F
.45581 .29066 m .45575 .2824 L .45569 .29094 L 1 .859 0 r
F
.45569 .29094 m .45485 .28401 L .45469 .29329 L F
.45575 .2824 m .45485 .28401 L .45569 .29094 L F
.4559 .27261 m .45588 .27216 L .45501 .27415 L 1 .875 0 r
F
.45647 .28113 m .45586 .28163 L .45584 .28224 L 1 .859 0 r
F
.45645 .28069 m .45586 .28163 L .45647 .28113 L F
.45238 .31795 m .45238 .31792 L .45223 .3174 L 0 0 0 r
F
.45584 .28224 m .45586 .28163 L .45485 .28401 L 1 .859 0 r
F
.45582 .28174 m .45501 .27415 L .45485 .28401 L 1 .875 0 r
F
.45589 .27408 m .45585 .27382 L .45582 .28174 L 0 0 0 r
F
.4559 .27261 m .45501 .27415 L .45582 .28174 L 1 .875 0 r
F
.45752 .28705 m .4575 .2867 L .45693 .28802 L 1 .848 0 r
F
.4616 .31439 m .45589 .27408 L .45582 .28174 L 0 0 0 r
F
.45321 .28912 m .45161 .28354 L .45155 .28447 L .259 .039 0 r
F
.45469 .29329 m .45323 .28867 L .45321 .28912 L F
.45323 .28867 m .45161 .28354 L .45321 .28912 L F
.45155 .28447 m .45161 .28354 L .45149 .28469 L 1 .548 0 r
F
.45421 .26954 m .44814 .30122 L .44799 .30566 L 1 .34 0 r
F
.45448 .26793 m .45422 .26933 L .45421 .26954 L F
.45422 .26933 m .44814 .30122 L .45421 .26954 L F
.45127 .29199 m .45101 .29271 L .45126 .2922 L 1 .599 0 r
F
.45041 .31402 m .45109 .30917 L .45061 .30788 L .165 .022 0 r
F
.45402 .32448 m .4542 .3175 L .45109 .30917 L F
.45045 .31396 m .45041 .31402 L .45043 .31412 L 1 .739 0 r
F
.45141 .31236 m .4504 .31417 L .45138 .31261 L F
.4504 .31417 m .45038 .31439 L .45138 .31261 L F
.45223 .3174 m .45184 .31801 L .45182 .31816 L 1 .78 0 r
F
.45402 .32448 m .45109 .30917 L .45041 .31402 L .165 .022 0 r
F
.45041 .31402 m .45039 .31418 L .45043 .31412 L 1 .739 0 r
F
.45061 .30788 m .45045 .3079 L .4504 .30839 L 1 .695 0 r
F
.45065 .30749 m .45045 .3079 L .45061 .30788 L F
.45109 .30917 m .45062 .30776 L .45061 .30788 L .187 .026 0 r
F
.4542 .3175 m .45116 .30845 L .45109 .30917 L F
.45383 .33099 m .45402 .32448 L .45033 .31484 L .147 .019 0 r
F
.45088 .31537 m .45041 .31402 L .4508 .31607 L .165 .022 0 r
F
.45041 .31402 m .45036 .31453 L .4508 .31607 L F
.4508 .31607 m .45036 .31453 L .45033 .31484 L F
.45402 .32448 m .45088 .31537 L .4508 .31607 L F
.45363 .33711 m .45383 .33099 L .44236 .35092 L 1 .843 0 r
F
.46241 .36692 m .4552 .26376 L .44695 .31169 L 1 .376 0 r
F
.44943 .22954 m .44953 .22817 L .44818 .23429 L .989 .314 0 r
F
.45783 .18468 m .44882 .21247 L .44812 .22504 L 1 .408 0 r
F
.44812 .22504 m .44882 .21247 L .44824 .26671 L 0 0 0 r
F
.44236 .35092 m .4401 .33965 L .43919 .34094 L 1 .238 0 r
F
.44589 .32348 m .44643 .31784 L .44048 .33831 L 1 .347 0 r
F
.44589 .32348 m .44048 .33831 L .44046 .33845 L F
.44589 .32348 m .44036 .33871 L .44034 .33883 L F
.44589 .32348 m .44018 .33932 L .44016 .33943 L F
.44006 .33977 m .44012 .33956 L .44001 .3399 L F
.44055 .33846 m .44005 .33939 L .44006 .33947 L .147 .019 0 r
F
.44012 .33956 m .44108 .33674 L .44001 .3399 L .941 .24 0 r
F
.44046 .33845 m .44048 .33831 L .44036 .33871 L 1 .347 0 r
F
.44034 .33883 m .44036 .33871 L .44027 .33904 L F
.44024 .33916 m .44027 .33904 L .44018 .33932 L F
.44016 .33943 m .44018 .33932 L .44012 .33956 L F
.44643 .31784 m .44108 .33674 L .44012 .33956 L .941 .24 0 r
F
.44643 .31784 m .44695 .31169 L .44157 .33466 L F
.44148 .33534 m .44157 .33466 L .44108 .33674 L F
.44643 .31784 m .44157 .33466 L .44148 .33534 L F
.44635 .31427 m .44216 .33349 L .44108 .33674 L .905 .185 0 r
F
.44669 .31288 m .44216 .33349 L .44635 .31427 L F
.44695 .31169 m .44669 .31288 L .44635 .31427 L F
.44695 .31169 m .44744 .30492 L .44253 .33146 L F
.44245 .33215 m .44253 .33146 L .44216 .33349 L F
.44695 .31169 m .44253 .33146 L .44245 .33215 L F
.44661 .3094 m .44324 .33013 L .44216 .33349 L .878 .178 0 r
F
.44698 .30771 m .44324 .33013 L .44661 .3094 L F
.44744 .30492 m .44698 .30771 L .44661 .3094 L F
.44744 .30492 m .4479 .29738 L .44351 .32822 L F
.44343 .32894 m .44351 .32822 L .44324 .33013 L F
.44744 .30492 m .44351 .32822 L .44343 .32894 L F
.44691 .30431 m .44431 .32663 L .44324 .33013 L .848 .171 0 r
F
.4473 .30231 m .44431 .32663 L .44691 .30431 L F
.4479 .29738 m .4473 .30231 L .44691 .30431 L F
.4479 .29738 m .44832 .2889 L .44449 .32493 L F
.44443 .32568 m .44449 .32493 L .44431 .32663 L F
.4479 .29738 m .44449 .32493 L .44443 .32568 L F
.44726 .29895 m .44539 .32296 L .44431 .32663 L .813 .163 0 r
F
.44832 .2889 m .44766 .29663 L .44726 .29895 L F
.44766 .29663 m .44539 .32296 L .44726 .29895 L F
.44832 .2889 m .44765 .29328 L .44623 .31197 L F
.44832 .2889 m .44871 .27932 L .44765 .29328 L F
.44612 .31438 m .44623 .31197 L .44549 .3216 L F
.44832 .2889 m .44623 .31197 L .44612 .31438 L F
.44544 .32238 m .44549 .3216 L .44539 .32296 L F
.44832 .2889 m .44549 .3216 L .44544 .32238 L F
.45363 .33711 m .44236 .35092 L .44176 .35486 L 1 .843 0 r
F
.45342 .34288 m .45363 .33711 L .44176 .35486 L 1 .88 0 r
F
.46241 .36692 m .44695 .31169 L .44643 .31784 L 1 .376 0 r
F
.45342 .34288 m .44341 .35317 L .44288 .35648 L 1 .88 0 r
F
.44286 .35723 m .45342 .34288 L .44288 .35648 L 1 .912 0 r
F
.45321 .34834 m .45339 .34372 L .44286 .35723 L F
.45339 .34372 m .45342 .34288 L .44286 .35723 L F
.45889 .3895 m .45339 .34372 L .44286 .35723 L 1 .172 0 r
F
.46204 .36916 m .44643 .31784 L .44589 .32348 L 0 0 0 r
F
.46204 .36916 m .46241 .36692 L .44643 .31784 L F
.44765 .29328 m .44647 .31906 L .44539 .32296 L .773 .155 0 r
F
.44871 .27932 m .44807 .29062 L .44765 .29328 L F
.44807 .29062 m .44647 .31906 L .44765 .29328 L F
.44589 .32348 m .44027 .33904 L .44024 .33916 L 1 .347 0 r
F
.44589 .32348 m .44012 .33956 L .44006 .33977 L F
.44871 .27932 m .44906 .26846 L .44692 .31027 L .773 .155 0 r
F
.44683 .31264 m .44692 .31027 L .44647 .31906 L F
.44871 .27932 m .44692 .31027 L .44683 .31264 L F
.44822 .28479 m .44753 .31486 L .44647 .31906 L .725 .145 0 r
F
.44836 .28207 m .44831 .28414 L .44822 .28479 L F
.44831 .28414 m .44753 .31486 L .44822 .28479 L F
.44851 .27912 m .44845 .28129 L .44836 .28207 L F
.44845 .28129 m .44753 .31486 L .44836 .28207 L F
.44867 .27603 m .44861 .27818 L .44851 .27912 L F
.44861 .27818 m .44753 .31486 L .44851 .27912 L F
.44883 .273 m .44877 .2749 L .44867 .27603 L F
.44877 .2749 m .44753 .31486 L .44867 .27603 L F
.44802 .2717 m .44824 .26671 L .44797 .2918 L 0 0 0 r
F
.44812 .22504 m .44824 .26671 L .44802 .2717 L F
.44906 .26846 m .44899 .27066 L .44883 .273 L .725 .145 0 r
F
.44899 .27066 m .44753 .31486 L .44883 .273 L F
.45783 .18468 m .45856 .17614 L .44882 .21247 L 1 .408 0 r
F
.44882 .21247 m .44963 .19987 L .44929 .24662 L 0 0 0 r
F
.44906 .26846 m .44939 .25624 L .44895 .27027 L .725 .145 0 r
F
.44906 .26846 m .44895 .27027 L .44882 .27577 L F
.45451 .26744 m .44823 .30072 L .45449 .26771 L 1 .34 0 r
F
.44823 .30072 m .44823 .30075 L .45449 .26771 L F
.45449 .26771 m .44814 .30122 L .45448 .26793 L F
.44881 .27854 m .44906 .26846 L .44871 .27932 L .903 .181 0 r
F
.45167 .25496 m .45151 .25561 L .4515 .2558 L 1 .353 0 r
F
.45497 .23107 m .45543 .22143 L .4523 .23754 L 1 .32 0 r
F
.45497 .23107 m .4523 .23754 L .45211 .24346 L F
.45497 .23107 m .45192 .24428 L .45188 .24683 L F
.45641 .21997 m .44908 .26832 L .44881 .27854 L .903 .181 0 r
F
.44908 .26832 m .44906 .26846 L .44881 .27854 L F
.45688 .20928 m .45742 .19895 L .44985 .25295 L .895 .182 0 r
F
.44982 .25358 m .44985 .25295 L .44939 .25624 L F
.45688 .20928 m .44985 .25295 L .44982 .25358 L F
.47061 .18684 m .47057 .18678 L .47058 .1868 L .427 .219 0 r
F
.47055 .18644 m .45715 .19349 L .47061 .18684 L 1 1 0 r
F
.47082 .17941 m .45783 .18468 L .45715 .19349 L F
.47055 .18644 m .47011 .18014 L .45715 .19349 L F
.45742 .19895 m .45803 .18905 L .45035 .23877 L .895 .184 0 r
F
.45029 .23953 m .45035 .23877 L .44974 .2427 L F
.45742 .19895 m .45035 .23877 L .45029 .23953 L F
.45688 .20928 m .44939 .25624 L .44906 .26846 L .895 .182 0 r
F
.461 .15227 m .45294 .16441 L .45169 .17566 L 1 .775 0 r
F
.47186 .1454 m .47199 .14033 L .45947 .14081 L .974 1 0 r
F
.47186 .1455 m .47199 .14041 L .45947 .14098 L .979 1 0 r
F
.4721 .14474 m .46188 .14487 L .461 .15227 L 1 1 0 r
F
.461 .15227 m .46188 .14487 L .45294 .16441 L 1 .775 0 r
F
.46191 .14603 m .45453 .15794 L .45328 .17023 L 1 .715 0 r
F
.45455 .16216 m .45456 .16479 L .45452 .16283 L 0 0 0 r
F
.45641 .21997 m .45688 .20928 L .4494 .26586 L .903 .181 0 r
F
.45641 .21997 m .4494 .26586 L .44938 .26633 L F
.45641 .21997 m .44908 .26829 L .44908 .26832 L F
.45803 .18905 m .45014 .22814 L .44974 .2427 L .903 .188 0 r
F
.47082 .17941 m .47079 .17935 L .47079 .17937 L .451 .264 0 r
F
.47076 .17904 m .45783 .18468 L .47082 .17941 L 1 1 0 r
F
.47102 .17216 m .45856 .17614 L .45783 .18468 L F
.47076 .17904 m .47033 .17282 L .45783 .18468 L F
.45803 .18905 m .4587 .1796 L .45089 .22387 L .903 .188 0 r
F
.45083 .22472 m .45089 .22387 L .45014 .22814 L F
.45803 .18905 m .45089 .22387 L .45083 .22472 L F
.46014 .15995 m .45169 .17566 L .45059 .18753 L 1 .676 0 r
F
.46014 .15995 m .461 .15227 L .45169 .17566 L F
.47197 .15122 m .461 .15227 L .46014 .15995 L 1 1 0 r
F
.46105 .15383 m .45328 .17023 L .45221 .18363 L 1 .578 0 r
F
.48629 .16564 m .48565 .15926 L .47173 .15063 L .518 .452 0 r
F
.48565 .15926 m .48499 .15301 L .47186 .1455 L .543 .494 0 r
F
.47197 .15122 m .4721 .14474 L .461 .15227 L 1 1 0 r
F
.46105 .15383 m .46191 .14603 L .45328 .17023 L 1 .578 0 r
F
.45456 .16479 m .45459 .17451 L .45453 .1654 L 0 0 0 r
F
.45602 .23091 m .45641 .21997 L .44871 .27932 L .915 .182 0 r
F
.4587 .1796 m .45066 .21304 L .45014 .22814 L .918 .216 0 r
F
.47097 .17183 m .45856 .17614 L .47102 .17216 L 1 1 0 r
F
.4587 .1796 m .45943 .17059 L .45124 .21022 L .918 .216 0 r
F
.45119 .21081 m .45124 .21022 L .45066 .21304 L F
.4587 .1796 m .45124 .21022 L .45119 .21081 L F
.45943 .17059 m .45134 .19802 L .45066 .21304 L .97 .314 0 r
F
.45943 .17059 m .46022 .16201 L .45196 .19549 L F
.45191 .19608 m .45196 .19549 L .45134 .19802 L F
.45943 .17059 m .45196 .19549 L .45191 .19608 L F
.47184 .15786 m .47197 .15122 L .46014 .15995 L 1 1 0 r
F
.46022 .16201 m .46105 .15383 L .45222 .18359 L 1 .439 0 r
F
.45222 .1836 m .45222 .18359 L .45221 .18363 L F
.46022 .16201 m .45222 .18359 L .45222 .1836 L F
.45469 .25777 m .45384 .26273 L .45388 .26303 L .997 .271 0 r
F
.44939 .25679 m .4496 .25082 L .44957 .25246 L 0 0 0 r
F
.44937 .25883 m .44957 .25246 L .44932 .26719 L F
.44939 .25679 m .44957 .25246 L .44937 .25883 L F
.44942 .25565 m .4496 .25082 L .44939 .25679 L F
.44938 .26633 m .4494 .26586 L .44908 .26829 L .903 .181 0 r
F
.44908 .26832 m .44908 .26829 L .44906 .26846 L F
.44916 .27183 m .44932 .26719 L .44859 .31027 L 0 0 0 r
F
.449 .2829 m .44904 .28009 L .449 .28499 L F
.44882 .27577 m .44892 .27126 L .44879 .2753 L .725 .145 0 r
F
.44882 .27577 m .44895 .27027 L .44892 .27126 L F
.4487 .27953 m .44879 .2753 L .44753 .31486 L F
.44882 .27577 m .44879 .2753 L .4487 .27953 L F
.44939 .25624 m .44859 .31027 L .44753 .31486 L 0 0 0 r
F
.44893 .25623 m .44904 .28009 L .449 .2829 L F
.44893 .25623 m .44929 .24662 L .44904 .28009 L F
.44882 .21247 m .44929 .24662 L .44893 .25623 L F
.45202 .18698 m .45221 .18489 L .45253 .27788 L F
.45252 .27808 m .45253 .27788 L .45256 .28416 L F
.45202 .18698 m .45253 .27788 L .45252 .27808 L F
.44971 .25821 m .44999 .25157 L .44963 .30516 L F
.44972 .24996 m .44999 .25157 L .44971 .25821 L F
.44939 .25624 m .4496 .25082 L .44939 .25639 L F
.45018 .23387 m .45066 .22641 L .45065 .24844 L F
.45033 .25424 m .45065 .24844 L .45065 .29932 L F
.45018 .23387 m .45065 .24844 L .45033 .25424 L F
.45134 .19802 m .45179 .19051 L .45256 .28416 L F
.45179 .19051 m .45203 .18765 L .45256 .28416 L F
.45014 .22814 m .45066 .21304 L .45066 .22641 L F
.45014 .22814 m .45066 .22641 L .45018 .23387 L F
.44974 .2427 m .45014 .22814 L .45003 .24434 L F
.44974 .2427 m .45003 .24434 L .44972 .24996 L F
.45221 .18363 m .45328 .17023 L .45341 .27373 L F
.45221 .18363 m .45341 .27373 L .45256 .28416 L F
.45134 .19802 m .45256 .28416 L .45163 .29247 L F
.45283 .17345 m .45264 .24065 L .45182 .25544 L F
.44006 .16133 m .44184 .15627 L .42792 .15632 L 1 1 0 r
F
.44184 .15627 m .43051 .15152 L .42792 .15632 L F
.4357 .1414 m .43837 .13679 L .42858 .13881 L F
.43688 .1371 m .43206 .1348 L .42858 .13881 L F
.43837 .13679 m .43743 .13649 L .43688 .1371 L F
.43743 .13649 m .43206 .1348 L .43688 .1371 L F
.4406 .133 m .4357 .13227 L .43222 .13624 L F
.44112 .1328 m .44081 .13277 L .4406 .133 L F
.44081 .13277 m .4357 .13227 L .4406 .133 L F
.43843 .13742 m .44112 .1328 L .43222 .13624 L F
.45066 .21304 m .45134 .19802 L .45161 .28641 L 0 0 0 r
F
.45157 .28735 m .45161 .28641 L .45163 .29247 L F
.45066 .21304 m .45161 .28641 L .45157 .28735 L F
.45066 .21304 m .45163 .29247 L .45065 .29932 L F
.45169 .17566 m .45182 .25544 L .45094 .26732 L F
.45202 .1867 m .45221 .18489 L .45202 .18698 L F
.45179 .19051 m .45202 .1867 L .45203 .18765 L F
.45202 .1867 m .45221 .18363 L .45221 .1842 L F
.45169 .17566 m .45294 .16441 L .45182 .25544 L F
.45059 .18753 m .45169 .17566 L .45113 .24358 L F
.4508 .23635 m .45113 .24358 L .45094 .26732 L F
.45059 .18753 m .45113 .24358 L .4508 .23635 L F
.45014 .22814 m .45065 .29932 L .44963 .30516 L F
.45059 .18753 m .45094 .26732 L .44999 .27698 L F
.44963 .19987 m .45059 .18753 L .45033 .22645 L F
.44969 .21175 m .45033 .22645 L .44999 .27698 L F
.44963 .19987 m .45033 .22645 L .44969 .21175 L F
.44939 .25639 m .44942 .25565 L .44939 .25679 L F
.44939 .25639 m .44932 .26719 L .44916 .27183 L F
.44974 .2427 m .44963 .30516 L .44859 .31027 L F
.44963 .19987 m .44999 .27698 L .449 .28499 L F
.44882 .21247 m .449 .28499 L .44797 .2918 L F
.44812 .22504 m .44797 .2918 L .44691 .29773 L F
.45329 .17494 m .45403 .24633 L .45341 .27373 L F
.45403 .24633 m .45407 .26205 L .45341 .27373 L F
.45182 .25544 m .45264 .24065 L .45294 .25208 L F
.45341 .27373 m .45417 .26021 L .45512 .32146 L F
.45341 .27373 m .45512 .32146 L .45353 .3232 L F
.45256 .28416 m .45341 .27373 L .45349 .30736 L F
.45319 .30973 m .45349 .30736 L .45352 .32191 L F
.45319 .30973 m .45352 .32191 L .4535 .32216 L F
.44624 .26466 m .44618 .26637 L .4461 .26711 L F
.44636 .26246 m .44631 .26383 L .44624 .26466 L F
.43305 .14606 m .4357 .1414 L .42513 .14291 L 1 1 0 r
F
.43313 .14678 m .43577 .14208 L .42534 .14443 L F
.4357 .1414 m .42858 .13881 L .42513 .14291 L F
.43577 .14208 m .42877 .1403 L .42534 .14443 L F
.44753 .23727 m .44691 .29773 L .44582 .30301 L 0 0 0 r
F
.45256 .28416 m .45349 .30736 L .45319 .30973 L F
.45194 .32497 m .45353 .3232 L .45194 .32498 L F
.45256 .28416 m .45353 .3232 L .45194 .32497 L F
.45353 .3232 m .45512 .32146 L .45512 .32143 L .281 .044 0 r
F
.45163 .29247 m .45256 .28416 L .45209 .31479 L 0 0 0 r
F
.45094 .26732 m .45182 .25544 L .45287 .31041 L F
.45272 .31124 m .45287 .31041 L .45303 .31882 L F
.45094 .26732 m .45287 .31041 L .45272 .31124 L F
.45188 .31602 m .45209 .31479 L .45196 .32377 L F
.45163 .29247 m .45209 .31479 L .45188 .31602 L F
.45196 .32378 m .45196 .32377 L .45196 .32383 L F
.45163 .29247 m .45196 .32377 L .45196 .32378 L F
.45163 .29247 m .45196 .32383 L .45193 .32405 L F
.45193 .32406 m .45194 .32497 L .45194 .32497 L F
.45163 .29247 m .45193 .32405 L .45193 .32406 L F
.45193 .32405 m .45194 .32497 L .45193 .32406 L F
.45163 .29247 m .45194 .32498 L .45036 .32679 L F
.45137 .32045 m .45303 .31882 L .45137 .32046 L F
.45065 .29932 m .45163 .29247 L .45058 .32086 L F
.45044 .3215 m .45058 .32086 L .4504 .32571 L F
.45065 .29932 m .45058 .32086 L .45044 .3215 L F
.44999 .27698 m .45094 .26732 L .45135 .31732 L F
.45128 .31762 m .45135 .31732 L .45137 .32046 L F
.44999 .27698 m .45135 .31732 L .45128 .31762 L F
.45094 .26732 m .45303 .31882 L .45137 .32045 L F
.45137 .32046 m .45247 .31938 L .45186 .31548 L .281 .045 0 r
F
.45051 .31385 m .4504 .32571 L .4504 .32572 L 0 0 0 r
F
.45065 .29932 m .45051 .31386 L .45051 .31385 L F
.45051 .31386 m .4504 .32571 L .45051 .31385 L F
.45037 .32593 m .4504 .32576 L .45037 .32597 L F
.45065 .29932 m .4504 .32572 L .45037 .32593 L F
.4504 .32572 m .4504 .32576 L .45037 .32593 L F
.45247 .31938 m .45274 .31704 L .45215 .31338 L .281 .045 0 r
F
.45182 .25544 m .45469 .31723 L .45303 .31882 L 0 0 0 r
F
.45283 .3085 m .45312 .30644 L .45274 .30383 L .279 .044 0 r
F
.4465 .25981 m .44646 .26107 L .44636 .26246 L 0 0 0 r
F
.44645 .26133 m .44684 .25295 L .44674 .25569 L F
.44645 .26133 m .44674 .25569 L .44637 .26341 L F
.4465 .25981 m .44684 .25295 L .44645 .26133 L F
.447 .24892 m .44753 .23727 L .44737 .24338 L F
.44711 .24844 m .44712 .2483 L .447 .24892 L .985 .298 0 r
F
.447 .24892 m .44737 .24338 L .44693 .25221 L 0 0 0 r
F
.43577 .14208 m .43843 .13742 L .42877 .1403 L 1 1 0 r
F
.43843 .13742 m .43222 .13624 L .42877 .1403 L F
.44963 .30516 m .45065 .29932 L .44885 .32767 L 0 0 0 r
F
.44882 .32787 m .44885 .32767 L .44879 .32864 L F
.44963 .30516 m .44885 .32767 L .44882 .32787 L F
.45186 .31548 m .45215 .31338 L .45172 .3107 L .281 .045 0 r
F
.45065 .29932 m .45036 .32679 L .44879 .32864 L 0 0 0 r
F
.44972 .32214 m .45137 .32046 L .44972 .32215 L F
.44999 .27698 m .45137 .32046 L .44972 .32214 L F
.42193 .14967 m .42557 .14882 L .42132 .1505 L F
.42557 .14882 m .42557 .14883 L .42132 .1505 L F
.42877 .1403 m .42566 .1487 L .42193 .14967 L F
.42566 .1487 m .42557 .14883 L .42557 .14887 L .281 .045 0 r
F
.46169 .37141 m .44589 .32348 L .44532 .32871 L 0 0 0 r
F
.46169 .37141 m .46204 .36916 L .44589 .32348 L F
.44472 .30779 m .44582 .30301 L .44321 .32939 L F
.44236 .35092 m .43919 .34094 L .43873 .34176 L 1 .238 0 r
F
.43868 .34166 m .43858 .34198 L .4389 .3416 L 1 .746 0 r
F
.43873 .3418 m .43858 .34197 L .43872 .34183 L F
.43858 .34197 m .43858 .34197 L .43872 .34183 L F
.43858 .34198 m .43857 .34201 L .43872 .34183 L F
.43852 .34213 m .43853 .3421 L .43849 .34201 L .157 .025 0 r
F
.4388 .34174 m .43851 .34207 L .43847 .34219 L 1 .746 0 r
F
.44236 .35092 m .43869 .34165 L .43853 .3421 L 1 .238 0 r
F
.44532 .32871 m .44589 .32348 L .43895 .343 L 1 .458 0 r
F
.44589 .32348 m .44001 .3399 L .43895 .343 L 1 .347 0 r
F
.44176 .35486 m .44236 .35092 L .43853 .3421 L .157 .025 0 r
F
.44176 .35486 m .43853 .3421 L .43852 .34213 L F
.43847 .34219 m .4314 .35033 L .43032 .35345 L 1 .746 0 r
F
.43851 .34207 m .4314 .35033 L .43847 .34219 L F
.43895 .343 m .44001 .3399 L .43372 .34914 L .904 .407 0 r
F
.44001 .3399 m .43517 .34694 L .43372 .34914 L .858 .242 0 r
F
.43873 .34176 m .43919 .34094 L .43869 .34165 L 1 .238 0 r
F
.43869 .34165 m .43868 .34166 L .43868 .34166 L 1 .746 0 r
F
.43868 .34166 m .4314 .35033 L .43858 .34198 L F
.43858 .34197 m .43858 .34198 L .43858 .34197 L F
.43858 .34198 m .4314 .35033 L .43857 .34201 L F
.44001 .3399 m .44108 .33674 L .43517 .34694 L .858 .242 0 r
F
.43524 .34683 m .43664 .34477 L .43517 .34694 L .818 .207 0 r
F
.44108 .33674 m .43664 .34477 L .43524 .34683 L F
.44108 .33674 m .44216 .33349 L .43664 .34477 L F
.43669 .34465 m .43812 .34262 L .43664 .34477 L .77 .195 0 r
F
.44216 .33349 m .43812 .34262 L .43669 .34465 L F
.44216 .33349 m .44324 .33013 L .43812 .34262 L F
.43816 .34251 m .43961 .34052 L .43812 .34262 L .714 .182 0 r
F
.44324 .33013 m .43961 .34052 L .43816 .34251 L F
.43787 .34636 m .43784 .34623 L .43737 .34999 L .157 .026 0 r
F
.43778 .34662 m .43784 .34623 L .43698 .3491 L F
.43802 .34589 m .43032 .35345 L .43791 .34622 L 1 .827 0 r
F
.44532 .32871 m .43895 .343 L .43789 .34604 L 1 .458 0 r
F
.44324 .33013 m .44431 .32663 L .43961 .34052 L .714 .182 0 r
F
.44431 .32663 m .44111 .33844 L .43961 .34052 L 0 0 0 r
F
.43961 .34052 m .44111 .33844 L .44105 .33851 L .59 .198 0 r
F
.43915 .33782 m .43248 .34719 L .4314 .35033 L 1 .655 0 r
F
.43664 .34477 m .43805 .34269 L .43296 .34772 L .723 .224 0 r
F
.43796 .34278 m .43475 .34607 L .43314 .34754 L .663 .213 0 r
F
.43793 .34282 m .43475 .34607 L .43796 .34278 L F
.43812 .34262 m .43793 .34282 L .43796 .34278 L F
.43812 .34262 m .43947 .34069 L .43749 .34326 L F
.43961 .34052 m .43655 .34449 L .43491 .34589 L .59 .198 0 r
F
.43961 .34052 m .44105 .33851 L .43679 .34417 L F
.43685 .3441 m .43679 .34417 L .43655 .34449 L F
.43961 .34052 m .43679 .34417 L .43685 .3441 L F
.43812 .34262 m .43961 .34052 L .43954 .34059 L .663 .213 0 r
F
.43664 .34477 m .43812 .34262 L .43805 .34269 L .723 .224 0 r
F
.43669 .3443 m .43836 .34297 L .43655 .34449 L 0 0 0 r
F
.44111 .33844 m .43836 .34297 L .43669 .3443 L F
.44475 .33361 m .44532 .32871 L .43789 .34604 L 1 .568 0 r
F
.44262 .33641 m .44019 .34154 L .43836 .34297 L 0 0 0 r
F
.43836 .34297 m .44019 .34154 L .44004 .34164 L .464 .201 0 r
F
.44111 .33844 m .44262 .33641 L .43836 .34297 L 0 0 0 r
F
.43836 .34297 m .44004 .34164 L .43634 .34435 L .464 .201 0 r
F
.43655 .34449 m .43836 .34297 L .4382 .34308 L .544 .215 0 r
F
.43655 .34449 m .4382 .34308 L .43427 .34555 L F
.43491 .34589 m .43655 .34449 L .43475 .34607 L .59 .198 0 r
F
.43475 .34607 m .43655 .34449 L .43637 .34458 L .612 .226 0 r
F
.43974 .33343 m .43357 .34403 L .43248 .34719 L 1 .555 0 r
F
.4393 .33736 m .43248 .34719 L .43915 .33782 L 1 .655 0 r
F
.44055 .33555 m .44116 .33074 L .43248 .34719 L F
.43248 .34719 m .43357 .34403 L .42613 .35287 L 1 .586 0 r
F
.43475 .34607 m .43637 .34458 L .43221 .34682 L .612 .226 0 r
F
.43314 .34754 m .43475 .34607 L .43296 .34772 L .663 .213 0 r
F
.44431 .32663 m .44539 .32296 L .44262 .33297 L 0 0 0 r
F
.44231 .33402 m .44262 .33297 L .44111 .33844 L F
.44431 .32663 m .44262 .33297 L .44231 .33402 L F
.44539 .32296 m .44262 .33641 L .44111 .33844 L F
.44539 .32296 m .44647 .31906 L .44262 .33641 L F
.44582 .30301 m .44691 .29773 L .445 .32499 L F
.44647 .31906 m .44415 .33441 L .44262 .33641 L F
.44492 .32528 m .445 .32499 L .44483 .32751 L F
.44582 .30301 m .445 .32499 L .44492 .32528 L F
.44582 .30301 m .44483 .32751 L .44321 .32939 L F
.44647 .31906 m .44753 .31486 L .44494 .32982 L F
.44473 .33055 m .44494 .32982 L .44415 .33441 L F
.44647 .31906 m .44494 .32982 L .44473 .33055 L F
.46098 .37593 m .44475 .33361 L .44416 .33823 L .007 .01 0 r
F
.46133 .37366 m .44532 .32871 L .44475 .33361 L 0 .005 0 r
F
.46098 .37593 m .46133 .37366 L .44475 .33361 L .007 .01 0 r
F
.46133 .37366 m .46169 .37141 L .44532 .32871 L 0 .005 0 r
F
.44753 .31486 m .44568 .33245 L .44415 .33441 L 0 0 0 r
F
.44691 .29773 m .44797 .2918 L .44651 .32443 L F
.44647 .32456 m .44651 .32443 L .44645 .32568 L F
.44691 .29773 m .44651 .32443 L .44647 .32456 L F
.44753 .31486 m .44859 .31027 L .4466 .32543 L F
.44632 .32645 m .4466 .32543 L .44568 .33245 L F
.44753 .31486 m .4466 .32543 L .44632 .32645 L F
.44859 .31027 m .44723 .33052 L .44568 .33245 L F
.44859 .31027 m .44963 .30516 L .44818 .32054 L F
.44963 .30516 m .44879 .32864 L .44723 .33052 L F
.449 .28499 m .44999 .27698 L .44977 .31473 L F
.44959 .31538 m .44977 .31473 L .44972 .32215 L F
.449 .28499 m .44977 .31473 L .44959 .31538 L F
.44783 .3218 m .44818 .32054 L .44732 .32965 L F
.44859 .31027 m .44818 .32054 L .44783 .3218 L F
.44728 .32984 m .44732 .32965 L .44723 .33052 L F
.44859 .31027 m .44732 .32965 L .44728 .32984 L F
.45126 .31969 m .45186 .31548 L .45107 .31049 L .281 .045 0 r
F
.44797 .2918 m .449 .28499 L .44818 .31989 L 0 0 0 r
F
.44797 .2918 m .44818 .31989 L .44807 .32027 L F
.42566 .1487 m .43222 .13624 L .42571 .14865 L F
.44691 .29773 m .44664 .31397 L .44608 .30955 L F
.44664 .31397 m .44645 .32568 L .44608 .30955 L F
.44608 .30955 m .44645 .32568 L .44483 .32751 L F
.44797 .2918 m .44808 .32389 L .44645 .32568 L F
.43722 .35042 m .43656 .34813 L .43638 .34866 L .157 .026 0 r
F
.43731 .34986 m .43778 .34662 L .43698 .3491 L F
.43656 .35443 m .4355 .35135 L .43531 .35191 L .158 .026 0 r
F
.43737 .34999 m .43788 .34632 L .42925 .35656 L 1 .897 0 r
F
.43871 .34889 m .43788 .34632 L .43737 .34999 L F
.43816 .34746 m .43787 .34636 L .43737 .34999 L .157 .026 0 r
F
.44115 .3587 m .44176 .35486 L .43788 .34632 L F
.44115 .3587 m .43788 .34632 L .43787 .34635 L F
.44416 .33823 m .44475 .33361 L .43683 .34904 L 1 .673 0 r
F
.43788 .34632 m .43032 .35345 L .42925 .35656 L 1 .827 0 r
F
.43787 .34635 m .43788 .34632 L .43784 .34623 L .157 .026 0 r
F
.43791 .34622 m .43032 .35345 L .43788 .34632 L 1 .827 0 r
F
.44475 .33361 m .43789 .34604 L .43683 .34904 L 1 .568 0 r
F
.44415 .33441 m .44568 .33245 L .44202 .34018 L 0 0 0 r
F
.44115 .3587 m .43816 .34746 L .43737 .34999 L .157 .026 0 r
F
.43737 .34999 m .43732 .35002 L .43722 .35042 L 1 .897 0 r
F
.43723 .35041 m .43737 .34999 L .43722 .35042 L F
.44115 .3587 m .43737 .34999 L .43722 .35042 L .157 .026 0 r
F
.43721 .35046 m .43718 .35034 L .4367 .354 L .158 .026 0 r
F
.4381 .35307 m .43722 .35042 L .4367 .354 L 1 .955 0 r
F
.44055 .36245 m .44115 .3587 L .43718 .35034 L .158 .026 0 r
F
.43639 .35522 m .43531 .35191 L .43599 .35782 L .159 .026 0 r
F
.4367 .354 m .43722 .35042 L .4372 .35044 L 1 .955 0 r
F
.43748 .35715 m .43656 .35443 L .43604 .35793 L 1 1 0 r
F
.43648 .3555 m .43661 .35454 L .43531 .35191 L .159 .026 0 r
F
.43669 .35401 m .4372 .35044 L .4282 .35965 L 1 .955 0 r
F
.4367 .354 m .4372 .35044 L .43669 .35401 L F
.43663 .35598 m .4369 .35511 L .43661 .35454 L .159 .026 0 r
F
.43663 .35598 m .43661 .35454 L .43648 .3555 L F
.43718 .35046 m .42925 .35656 L .4282 .35965 L 1 .897 0 r
F
.43732 .35002 m .42925 .35656 L .43718 .35046 L F
.44356 .34263 m .44416 .33823 L .43579 .352 L 1 .768 0 r
F
.44416 .33823 m .43683 .34904 L .43579 .352 L 1 .673 0 r
F
.44568 .33245 m .44386 .33889 L .44202 .34018 L 0 0 0 r
F
.44568 .33245 m .44723 .33052 L .44395 .33868 L F
.44391 .33874 m .44395 .33868 L .44386 .33889 L F
.44568 .33245 m .44395 .33868 L .44391 .33874 L F
.46063 .37821 m .44416 .33823 L .44356 .34263 L .029 .014 0 r
F
.46063 .37821 m .46098 .37593 L .44416 .33823 L F
.44723 .33052 m .44571 .3377 L .44386 .33889 L 0 0 0 r
F
.44645 .32568 m .44808 .32389 L .4453 .33539 L F
.44645 .32568 m .4453 .33539 L .4453 .33539 L F
.41886 .22049 m .42049 .21481 L .3967 .21113 L 1 1 0 r
F
.42051 .21495 m .42216 .20933 L .39913 .20582 L F
.423 .21398 m .42462 .20845 L .40297 .20614 L F
.41726 .22622 m .41886 .22049 L .39434 .21669 L F
.41886 .22049 m .3967 .21113 L .39434 .21669 L F
.41889 .22063 m .42051 .21495 L .39675 .21132 L F
.42051 .21495 m .39913 .20582 L .39675 .21132 L F
.4214 .21955 m .423 .21398 L .40062 .2115 L F
.423 .21398 m .40297 .20614 L .40062 .2115 L F
.42311 .21458 m .42473 .20904 L .40322 .20714 L F
.42473 .20904 m .40558 .20182 L .40322 .20714 L F
.42473 .20904 m .42636 .20355 L .40558 .20182 L F
.42335 .20443 m .42243 .19786 L .42234 .1977 L .375 .062 0 r
F
.42277 .20125 m .42234 .1977 L .422 .19707 L F
.42335 .20443 m .42234 .1977 L .42277 .20125 L F
.41707 .15276 m .42132 .1505 L .42225 .19694 L .316 .035 0 r
F
.4453 .33539 m .4453 .33539 L .4453 .3354 L 0 0 0 r
F
.44234 .32038 m .43638 .33566 L .43628 .33627 L 1 .342 0 r
F
.44234 .32038 m .44148 .32264 L .44134 .32306 L F
.44176 .3257 m .44234 .32038 L .43467 .34083 L 1 .449 0 r
F
.44134 .32306 m .43578 .33759 L .43467 .34083 L 1 .342 0 r
F
.44148 .32264 m .43578 .33759 L .44134 .32306 L F
.44067 .32814 m .43467 .34083 L .43357 .34403 L 1 .449 0 r
F
.44081 .32772 m .43467 .34083 L .44067 .32814 L F
.44116 .33074 m .44176 .3257 L .43357 .34403 L 1 .555 0 r
F
.44137 .32019 m .44249 .3163 L .43842 .33529 L 0 0 0 r
F
.44176 .3257 m .44081 .32772 L .44067 .32814 L 1 .449 0 r
F
.44116 .33074 m .43991 .33293 L .43974 .33343 L 1 .555 0 r
F
.43991 .33293 m .43357 .34403 L .43974 .33343 L F
.44249 .3163 m .44 .33328 L .43842 .33529 L 0 0 0 r
F
.44249 .3163 m .44361 .31219 L .44 .33328 L F
.44361 .31219 m .4416 .33131 L .44 .33328 L F
.44361 .31219 m .44472 .30779 L .4416 .33131 L F
.44472 .30779 m .44321 .32939 L .4416 .33131 L F
.44055 .33555 m .4393 .33736 L .43915 .33782 L 1 .655 0 r
F
.4416 .33131 m .44321 .32939 L .43956 .33877 L 0 0 0 r
F
.44321 .32939 m .44147 .33755 L .43956 .33877 L F
.44321 .32939 m .44483 .32751 L .44147 .33755 L F
.44262 .33641 m .44415 .33441 L .44019 .34154 L F
.44415 .33441 m .44202 .34018 L .44019 .34154 L F
.44483 .32751 m .44338 .33643 L .44147 .33755 L F
.44483 .32751 m .44645 .32568 L .44339 .3364 L F
.44339 .33641 m .44339 .3364 L .44338 .33643 L F
.44483 .32751 m .44339 .3364 L .44339 .33641 L F
.44645 .32568 m .4453 .3354 L .44338 .33643 L F
.44723 .33052 m .44879 .32864 L .44572 .33767 L F
.44572 .33768 m .44572 .33767 L .44571 .3377 L F
.44723 .33052 m .44572 .33767 L .44572 .33768 L F
.45194 .32498 m .4513 .3347 L .44944 .33559 L .023 0 0 r
F
.44944 .33559 m .4513 .3347 L .45061 .33099 L .377 .063 0 r
F
.44808 .32389 m .44788 .32637 L .44772 .3254 L .012 0 0 r
F
.44879 .32864 m .44757 .33659 L .44571 .3377 L 0 0 0 r
F
.44788 .32637 m .44722 .33447 L .44772 .3254 L .012 0 0 r
F
.44772 .3254 m .44722 .33447 L .4453 .3354 L F
.44808 .32389 m .44972 .32215 L .4473 .33405 L F
.44725 .33412 m .4473 .33405 L .44722 .33447 L F
.44808 .32389 m .4473 .33405 L .44725 .33412 L F
.44879 .32864 m .45036 .32679 L .44757 .33659 L 0 0 0 r
F
.45036 .32679 m .44944 .33559 L .44757 .33659 L F
.44972 .32215 m .44914 .33364 L .44722 .33447 L .054 0 0 r
F
.42566 .1487 m .42557 .14887 L .44905 .33293 L .281 .045 0 r
F
.44905 .33294 m .44905 .33293 L .44914 .33364 L F
.42566 .1487 m .44905 .33293 L .44905 .33294 L F
.44807 .32027 m .44818 .31989 L .44808 .32389 L 0 0 0 r
F
.44972 .32215 m .45111 .32074 L .44914 .33364 L .054 0 0 r
F
.45111 .32074 m .45137 .32046 L .45118 .32159 L F
.4504 .32572 m .4504 .32571 L .4504 .32576 L 0 0 0 r
F
.45037 .32597 m .4504 .32576 L .45036 .32679 L F
.45111 .32074 m .45118 .32159 L .44914 .33364 L .054 0 0 r
F
.449 .28499 m .44972 .32215 L .44808 .32389 L 0 0 0 r
F
.45137 .32046 m .42566 .1487 L .44914 .33364 L .281 .045 0 r
F
.44914 .33364 m .42557 .14883 L .42468 .18723 L 1 .664 0 r
F
.44914 .33364 m .42798 .20694 L .42243 .19786 L F
.45036 .32679 m .45194 .32498 L .44951 .33527 L 0 0 0 r
F
.44946 .33533 m .44951 .33527 L .44944 .33559 L F
.45036 .32679 m .44951 .33527 L .44946 .33533 L F
.45105 .33332 m .4506 .33008 L .45047 .33023 L 1 .672 0 r
F
.4513 .3347 m .45109 .33327 L .45105 .33332 L F
.45109 .33327 m .4506 .33008 L .45105 .33332 L F
.45047 .33023 m .43677 .23984 L .42937 .2166 L F
.4506 .33008 m .43677 .23984 L .45047 .33023 L F
.44903 .33316 m .45061 .33099 L .42937 .2166 L .377 .063 0 r
F
.44944 .33559 m .45061 .33099 L .44903 .33316 L F
.44676 .33194 m .42268 .19923 L .42335 .20443 L .375 .062 0 r
F
.44719 .33429 m .44676 .33194 L .44676 .33194 L F
.44676 .33194 m .42268 .19923 L .44676 .33194 L F
.44338 .33643 m .4453 .3354 L .44254 .33939 L 0 0 0 r
F
.44238 .33947 m .44254 .33939 L .44228 .33977 L F
.44338 .33643 m .44254 .33939 L .44238 .33947 L F
.41728 .22635 m .41889 .22063 L .3944 .21688 L 1 1 0 r
F
.41889 .22063 m .39675 .21132 L .3944 .21688 L F
.41824 .23085 m .41981 .22518 L .396 .22238 L F
.41838 .23148 m .3963 .22339 L .39404 .22891 L F
.41838 .23148 m .41994 .2258 L .3963 .22339 L F
.41981 .22518 m .3983 .21691 L .396 .22238 L F
.41981 .22518 m .4214 .21955 L .3983 .21691 L F
.41994 .2258 m .39858 .21793 L .3963 .22339 L F
.41994 .2258 m .42151 .22017 L .39858 .21793 L F
.4214 .21955 m .40062 .2115 L .3983 .21691 L F
.42151 .22017 m .40089 .21251 L .39858 .21793 L F
.42151 .22017 m .42311 .21458 L .40089 .21251 L F
.42311 .21458 m .40322 .20714 L .40089 .21251 L F
.43611 .33513 m .39404 .22891 L .43596 .33556 L 1 .238 0 r
F
.43467 .34083 m .43578 .33759 L .42913 .34824 L .866 .28 0 r
F
.42921 .34811 m .43065 .34599 L .42913 .34824 L .83 .21 0 r
F
.43578 .33759 m .43065 .34599 L .42921 .34811 L F
.43578 .33759 m .43689 .33429 L .43065 .34599 L F
.43072 .34585 m .43218 .34377 L .43065 .34599 L .786 .2 0 r
F
.43689 .33429 m .43218 .34377 L .43072 .34585 L F
.43689 .33429 m .43801 .33092 L .43566 .33677 L F
.43801 .33092 m .43372 .34159 L .43224 .34364 L .736 .188 0 r
F
.43628 .33627 m .43638 .33566 L .43578 .33759 L 1 .342 0 r
F
.43801 .33092 m .43913 .32746 L .43372 .34159 L .736 .188 0 r
F
.43913 .32746 m .43528 .33945 L .43372 .34159 L .681 .175 0 r
F
.43372 .34159 m .43528 .33945 L .43521 .33953 L .604 .201 0 r
F
.43224 .34364 m .43372 .34159 L .43218 .34377 L .736 .188 0 r
F
.43065 .34599 m .43209 .34386 L .42643 .34936 L .722 .224 0 r
F
.43199 .34395 m .42828 .34764 L .4266 .3492 L .668 .214 0 r
F
.43194 .344 m .42828 .34764 L .43199 .34395 L F
.43218 .34377 m .43194 .344 L .43199 .34395 L F
.43218 .34377 m .4336 .34174 L .43095 .34499 L F
.43372 .34159 m .43014 .34599 L .42843 .34748 L .604 .201 0 r
F
.43372 .34159 m .43521 .33953 L .43038 .34567 L F
.43045 .3456 m .43038 .34567 L .43014 .34599 L F
.43372 .34159 m .43038 .34567 L .43045 .3456 L F
.43218 .34377 m .43372 .34159 L .43364 .34168 L .668 .214 0 r
F
.43065 .34599 m .43218 .34377 L .43209 .34386 L .722 .224 0 r
F
.43027 .34582 m .432 .3444 L .43014 .34599 L 0 0 0 r
F
.43528 .33945 m .432 .3444 L .43027 .34582 L F
.43357 .34403 m .43467 .34083 L .42763 .35054 L .921 .436 0 r
F
.43467 .34083 m .42913 .34824 L .42763 .35054 L .866 .28 0 r
F
.43684 .33735 m .43388 .34288 L .432 .3444 L 0 0 0 r
F
.432 .3444 m .43388 .34288 L .43374 .34298 L .493 .206 0 r
F
.43528 .33945 m .43684 .33735 L .432 .3444 L 0 0 0 r
F
.43014 .34599 m .43185 .34449 L .42735 .34724 L .559 .217 0 r
F
.42758 .3471 m .42947 .34596 L .42735 .34724 L .493 .206 0 r
F
.432 .3444 m .42947 .34596 L .42758 .3471 L F
.432 .3444 m .43374 .34298 L .42947 .34596 L F
.42968 .34581 m .4316 .34474 L .42947 .34596 L 0 0 0 r
F
.43388 .34288 m .4316 .34474 L .42968 .34581 L F
.43178 .34459 m .43373 .3436 L .4316 .34474 L F
.43577 .34143 m .43373 .3436 L .43178 .34459 L F
.43766 .34006 m .43586 .34252 L .43373 .3436 L F
.43373 .3436 m .43586 .34252 L .43568 .34259 L .378 .199 0 r
F
.43388 .34288 m .43577 .34143 L .4316 .34474 L 0 0 0 r
F
.43577 .34143 m .43766 .34006 L .43373 .3436 L F
.43373 .3436 m .43568 .34259 L .43247 .34383 L .378 .199 0 r
F
.4316 .34474 m .43373 .3436 L .43353 .34366 L .442 .209 0 r
F
.4316 .34474 m .43353 .34366 L .43014 .34477 L F
.42947 .34596 m .4316 .34474 L .43138 .3448 L .5 .217 0 r
F
.42947 .34596 m .43138 .3448 L .42781 .34577 L F
.43014 .34599 m .432 .3444 L .43185 .34449 L .559 .217 0 r
F
.42843 .34748 m .43014 .34599 L .42828 .34764 L .604 .201 0 r
F
.42828 .34764 m .43014 .34599 L .42997 .34608 L .615 .226 0 r
F
.42828 .34764 m .42997 .34608 L .42524 .3486 L F
.4266 .3492 m .42828 .34764 L .42643 .34936 L .668 .214 0 r
F
.43913 .32746 m .44025 .3239 L .43528 .33945 L .681 .175 0 r
F
.44025 .3239 m .43684 .33735 L .43528 .33945 L 0 0 0 r
F
.44025 .3239 m .44137 .32019 L .43684 .33735 L F
.44137 .32019 m .43842 .33529 L .43684 .33735 L F
.44 .33328 m .4416 .33131 L .43766 .34006 L F
.4416 .33131 m .43956 .33877 L .43766 .34006 L F
.44147 .33755 m .44338 .33643 L .44015 .3406 L F
.44014 .3406 m .44015 .3406 L .44014 .34061 L F
.44147 .33755 m .44015 .3406 L .44014 .3406 L F
.44202 .34018 m .44386 .33889 L .44049 .34217 L F
.44386 .33889 m .44258 .34119 L .44049 .34217 L F
.44386 .33889 m .44571 .3377 L .44258 .34119 L F
.44258 .34119 m .44258 .34119 L .44258 .34119 L F
.44386 .33889 m .44258 .34119 L .44258 .34119 L F
.44757 .33659 m .44676 .3395 L .44467 .3403 L F
.44467 .3403 m .44676 .3395 L .4465 .33849 L .534 .154 0 r
F
.4453 .3354 m .44442 .33902 L .44228 .33977 L .055 0 0 r
F
.44228 .33977 m .44442 .33902 L .44417 .33799 L .519 .12 0 r
F
.40984 .18321 m .41583 .18935 L .42808 .27266 L .553 .072 0 r
F
.41583 .18935 m .42525 .25795 L .42634 .26083 L .279 .056 0 r
F
.42701 .26539 m .42525 .25795 L .42808 .27266 L F
.42903 .27396 m .4312 .27369 L .42525 .25795 L 1 .513 0 r
F
.44216 .32949 m .43209 .2781 L .42903 .27396 L F
.44248 .3295 m .43209 .2781 L .44216 .32949 L F
.44432 .33851 m .4312 .27369 L .4443 .33852 L F
.4453 .3354 m .44722 .33447 L .44461 .33872 L .055 0 0 r
F
.44448 .33877 m .44461 .33872 L .44442 .33902 L F
.4453 .3354 m .44461 .33872 L .44448 .33877 L F
.44722 .33447 m .422 .19707 L .44399 .33629 L .375 .062 0 r
F
.44461 .33872 m .44399 .33629 L .44442 .33902 L F
.44722 .33447 m .44399 .33629 L .44461 .33872 L F
.44571 .3377 m .44757 .33659 L .44467 .3403 L 0 0 0 r
F
.44636 .33797 m .4449 .3296 L .4442 .32957 L 1 .353 0 r
F
.44676 .3395 m .44646 .33792 L .44636 .33797 L F
.44646 .33792 m .4449 .3296 L .44636 .33797 L F
.42301 .20347 m .42205 .20028 L .44442 .33902 L .375 .062 0 r
F
.422 .19707 m .42204 .19981 L .42301 .20347 L F
.42204 .19981 m .42205 .20028 L .42301 .20347 L F
.42158 .19327 m .422 .19707 L .42186 .19915 L .316 .035 0 r
F
.42158 .19327 m .42186 .19915 L .41583 .18935 L F
.422 .19707 m .41812 .17592 L .42186 .19915 L .375 .062 0 r
F
.422 .19707 m .42186 .19915 L .42205 .20028 L F
.422 .19707 m .42231 .19987 L .42186 .19915 L .316 .035 0 r
F
.41707 .15276 m .41824 .19099 L .41591 .18717 L F
.42186 .19915 m .41812 .17592 L .42033 .19248 L 1 .513 0 r
F
.41709 .18117 m .42008 .19189 L .41717 .18067 L .279 .056 0 r
F
.42008 .19189 m .42072 .19418 L .42018 .19212 L F
.42008 .19189 m .42018 .19212 L .41717 .18067 L F
.42072 .19418 m .42033 .19248 L .41717 .18067 L F
.41591 .18717 m .41824 .19099 L .41583 .18935 L .316 .035 0 r
F
.41583 .18935 m .42186 .19915 L .41709 .18117 L .279 .056 0 r
F
.42186 .19915 m .42231 .19987 L .42057 .19364 L F
.42027 .19315 m .42057 .19364 L .41709 .18117 L F
.42186 .19915 m .42057 .19364 L .42027 .19315 L F
.41707 .15276 m .42196 .19448 L .422 .19707 L .316 .035 0 r
F
.42132 .1505 m .42022 .17955 L .42058 .18017 L .46 .227 0 r
F
.42053 .18212 m .42022 .17955 L .42053 .18219 L F
.42196 .19448 m .42225 .19694 L .422 .19707 L .316 .035 0 r
F
.42225 .19694 m .42022 .17955 L .41812 .17592 L 1 .664 0 r
F
.42132 .1505 m .42053 .18248 L .42225 .19694 L .46 .227 0 r
F
.42232 .19689 m .42468 .18723 L .42022 .17955 L 1 .664 0 r
F
.42272 .19651 m .42468 .18723 L .42232 .19689 L F
.42243 .19786 m .42022 .17955 L .42225 .19694 L F
.42053 .18219 m .42022 .17955 L .42053 .18248 L .46 .227 0 r
F
.422 .19707 m .42243 .19786 L .41812 .17592 L .375 .062 0 r
F
.422 .19707 m .42225 .19694 L .42201 .19717 L .316 .035 0 r
F
.42201 .19717 m .42225 .19694 L .42231 .19987 L F
.42225 .19694 m .42053 .18248 L .42231 .19987 L .46 .227 0 r
F
.42231 .19987 m .42053 .18248 L .42037 .18173 L 1 .714 0 r
F
.41812 .17592 m .42022 .17955 L .42049 .18356 L .576 .092 0 r
F
.42231 .19987 m .42037 .18173 L .42115 .19364 L 1 .714 0 r
F
.42243 .19786 m .42272 .19651 L .42232 .19689 L 1 .664 0 r
F
.42798 .20694 m .42468 .18723 L .42243 .19786 L F
.42231 .19987 m .42115 .19364 L .4207 .19385 L 1 .714 0 r
F
.42115 .19364 m .4268 .20387 L .42138 .19497 L .576 .092 0 r
F
.41812 .17592 m .42331 .19265 L .42115 .19364 L F
.42331 .19265 m .4268 .20387 L .42115 .19364 L F
.41812 .17592 m .42115 .19364 L .42033 .19248 L F
.40794 .15446 m .41212 .15129 L .40651 .16716 L .054 0 0 r
F
.41287 .15544 m .41583 .18935 L .40984 .18321 L .277 .021 0 r
F
.41212 .15129 m .41213 .16996 L .40651 .16716 L .183 0 0 r
F
.41287 .15544 m .41707 .15276 L .41583 .18935 L .277 .021 0 r
F
.41212 .15129 m .41635 .14839 L .41213 .16996 L .183 0 0 r
F
.41635 .14839 m .40948 .12592 L .41137 .15727 L .554 .37 0 r
F
.41522 .15418 m .41137 .15727 L .41213 .16996 L F
.41635 .14839 m .41137 .15727 L .41522 .15418 L F
.405 .13937 m .40924 .13528 L .39934 .13256 L .973 1 0 r
F
.40924 .13528 m .40432 .12905 L .39934 .13256 L .958 1 0 r
F
.39921 .13192 m .40419 .12839 L .39498 .11997 L .878 .907 0 r
F
.39427 .13558 m .39921 .13192 L .39064 .12894 L .93 1 0 r
F
.39921 .13192 m .39498 .11997 L .39064 .12894 L .878 .907 0 r
F
.39934 .13256 m .40432 .12905 L .39672 .12729 L .877 1 0 r
F
.39661 .1274 m .39671 .12729 L .39628 .12608 L .379 .114 0 r
F
.4046 .1617 m .40419 .17994 L .39878 .17854 L .132 0 0 r
F
.40794 .15446 m .40651 .16716 L .40114 .16629 L .054 0 0 r
F
.38936 .13937 m .39427 .13558 L .38504 .13201 L .954 1 0 r
F
.39427 .13558 m .39064 .12894 L .38504 .13201 L .93 1 0 r
F
.3944 .1362 m .39934 .13256 L .39089 .13002 L .92 1 0 r
F
.39281 .1306 m .39661 .1274 L .39089 .13002 L .877 1 0 r
F
.39934 .13256 m .39661 .1274 L .39281 .1306 L F
.39934 .13256 m .39672 .12729 L .39661 .1274 L F
.40545 .16291 m .39672 .12731 L .39661 .1274 L .379 .114 0 r
F
.39672 .12731 m .39672 .12729 L .39661 .1274 L F
.39908 .20563 m .38028 .19552 L .37714 .20079 L 1 1 0 r
F
.40154 .20038 m .38352 .19058 L .38036 .19579 L F
.3967 .21113 m .39908 .20563 L .37714 .20079 L F
.39913 .20582 m .40154 .20038 L .38036 .19579 L F
.40297 .20614 m .40535 .20083 L .38579 .19806 L F
.40535 .20083 m .38891 .19308 L .38579 .19806 L F
.40558 .20182 m .40797 .19656 L .38941 .19481 L F
.40797 .19656 m .39253 .18989 L .38941 .19481 L F
.3967 .21113 m .37714 .20079 L .37405 .20613 L F
.39913 .20582 m .38036 .19579 L .37724 .20106 L F
.39434 .21669 m .3967 .21113 L .37405 .20613 L F
.39675 .21132 m .39913 .20582 L .37724 .20106 L F
.40062 .2115 m .40297 .20614 L .38271 .20311 L F
.40297 .20614 m .38579 .19806 L .38271 .20311 L F
.40322 .20714 m .40558 .20182 L .38632 .1998 L F
.40558 .20182 m .38941 .19481 L .38632 .1998 L F
.39878 .17854 m .40419 .17994 L .41539 .25421 L .508 .065 0 r
F
.41535 .25419 m .41539 .25421 L .41546 .25469 L F
.39878 .17854 m .41539 .25421 L .41535 .25419 L F
.40984 .18321 m .42523 .26106 L .42397 .26573 L .553 .072 0 r
F
.42172 .26141 m .42397 .26573 L .42295 .26953 L F
.40984 .18321 m .42397 .26573 L .42172 .26141 L F
.42523 .26106 m .42748 .27246 L .42826 .2806 L F
.44338 .33643 m .44228 .33977 L .44014 .34061 L 0 0 0 r
F
.44228 .33977 m .42748 .27246 L .43079 .29148 L .519 .12 0 r
F
.43684 .33735 m .43842 .33529 L .43388 .34288 L 0 0 0 r
F
.43842 .33529 m .43577 .34143 L .43388 .34288 L F
.43842 .33529 m .44 .33328 L .43577 .34143 L F
.44 .33328 m .43766 .34006 L .43577 .34143 L F
.43766 .34006 m .43956 .33877 L .43586 .34252 L F
.43956 .33877 m .438 .34153 L .43586 .34252 L F
.43956 .33877 m .44147 .33755 L .438 .34153 L F
.44147 .33755 m .44014 .34061 L .438 .34153 L F
.438 .34153 m .43936 .34094 L .43714 .34215 L F
.43936 .34094 m .44014 .34061 L .43886 .34127 L F
.43936 .34094 m .43886 .34127 L .43714 .34215 L F
.43516 .32219 m .4301 .29173 L .43369 .31565 L 1 .187 0 r
F
.4301 .29173 m .43043 .29462 L .43369 .31565 L F
.44014 .34061 m .43947 .34141 L .43714 .34215 L 0 0 0 r
F
.43947 .34141 m .43574 .32118 L .43516 .32219 L 1 .187 0 r
F
.43574 .32118 m .42826 .2806 L .43516 .32219 L F
.43586 .34252 m .438 .34153 L .43481 .34296 L .309 .186 0 r
F
.43705 .34169 m .43339 .32136 L .43387 .3252 L .902 .15 0 r
F
.43705 .34169 m .43329 .32221 L .43511 .34113 L F
.43705 .34169 m .43365 .31921 L .43339 .32136 L F
.43947 .34141 m .43191 .30772 L .43705 .34169 L 1 .187 0 r
F
.438 .34153 m .43714 .34215 L .43481 .34296 L 0 0 0 r
F
.43481 .34296 m .43714 .34215 L .43456 .34235 L .377 .202 0 r
F
.43714 .34215 m .43705 .34169 L .43456 .34235 L .326 .195 0 r
F
.43456 .34235 m .43705 .34169 L .43517 .34115 L .445 .422 0 r
F
.43504 .34129 m .43517 .34115 L .43511 .34113 L F
.43456 .34235 m .43517 .34115 L .43504 .34129 L F
.43552 .34177 m .43409 .32553 L .43525 .34166 L 1 .193 0 r
F
.4371 .34165 m .43409 .32553 L .43552 .34177 L F
.4356 .34068 m .43433 .32897 L .43574 .34028 L 0 0 0 r
F
.43525 .34166 m .43521 .34111 L .4356 .34068 L F
.43521 .34111 m .43433 .32897 L .4356 .34068 L F
.43725 .34247 m .4371 .34165 L .43552 .34177 L 1 .193 0 r
F
.4371 .34165 m .43479 .32281 L .43409 .32553 L F
.43714 .34215 m .43824 .3418 L .43705 .34169 L .326 .195 0 r
F
.43722 .34232 m .43714 .34166 L .4371 .34165 L 1 .193 0 r
F
.43714 .34166 m .43479 .32281 L .4371 .34165 L F
.43824 .3418 m .4392 .3415 L .43724 .34167 L .326 .195 0 r
F
.43824 .3418 m .43724 .34167 L .43705 .34169 L F
.4392 .3415 m .43947 .34141 L .43782 .3416 L F
.43723 .34232 m .43715 .34166 L .43722 .34232 L 1 .193 0 r
F
.43387 .3252 m .43339 .32136 L .43329 .32221 L .902 .15 0 r
F
.43511 .34113 m .43329 .32221 L .43268 .32462 L .935 .162 0 r
F
.43329 .32221 m .43367 .323 L .43295 .32496 L 1 .107 0 r
F
.43715 .34166 m .43449 .32037 L .43714 .34166 L 1 .193 0 r
F
.43449 .32037 m .43448 .32038 L .43714 .34166 L F
.43574 .34028 m .43409 .32553 L .43623 .33891 L 0 0 0 r
F
.43433 .32897 m .43409 .32553 L .43574 .34028 L F
.43479 .32281 m .4341 .31732 L .43409 .32401 L 1 .193 0 r
F
.43479 .32281 m .43409 .32401 L .43409 .32553 L F
.43449 .32037 m .4341 .31732 L .43448 .32038 L F
.44014 .34061 m .44228 .33977 L .43963 .34132 L 0 0 0 r
F
.43951 .34136 m .43963 .34132 L .43947 .34141 L F
.44014 .34061 m .43963 .34132 L .43951 .34136 L F
.44207 .3399 m .43079 .29148 L .43926 .34016 L .519 .12 0 r
F
.43963 .34132 m .43926 .34016 L .43947 .34141 L F
.44207 .3399 m .43926 .34016 L .43963 .34132 L F
.44228 .33977 m .43079 .29148 L .44207 .3399 L F
.42748 .27246 m .42826 .2806 L .42916 .28551 L F
.43166 .29649 m .42916 .28551 L .43947 .34141 L F
.42748 .27246 m .42916 .28551 L .43166 .29649 L F
.42748 .27246 m .42968 .28357 L .42826 .2806 L .553 .072 0 r
F
.42523 .26106 m .42826 .2806 L .42295 .26953 L F
.42748 .27246 m .42296 .2519 L .42826 .2806 L .519 .12 0 r
F
.40419 .17994 m .42266 .26811 L .41546 .25469 L .529 .069 0 r
F
.42266 .26811 m .42295 .26953 L .42284 .26932 L F
.42266 .26811 m .42284 .26932 L .41546 .25469 L F
.39206 .18816 m .39524 .1833 L .37967 .18163 L 1 1 0 r
F
.39568 .18503 m .39886 .18023 L .38458 .18075 L F
.38827 .15628 m .39238 .15182 L .37965 .14729 L F
.38419 .16082 m .38827 .15628 L .37486 .15141 L F
.38827 .15628 m .37965 .14729 L .37486 .15141 L F
.38837 .15667 m .39248 .15221 L .37981 .14787 L F
.39238 .15182 m .38449 .14328 L .37965 .14729 L F
.39248 .15221 m .38464 .14387 L .37981 .14787 L F
.39248 .15221 m .39662 .14784 L .38464 .14387 L F
.39662 .14784 m .3895 .13998 L .38464 .14387 L .996 1 0 r
F
.39157 .16914 m .39561 .16523 L .38587 .16985 L .689 .434 0 r
F
.39247 .17266 m .39647 .16883 L .38846 .17928 L 0 0 0 r
F
.39561 .16523 m .39085 .16795 L .38587 .16985 L .562 .214 0 r
F
.39561 .16523 m .39968 .16146 L .39085 .16795 L F
.39647 .16883 m .39355 .17844 L .38846 .17928 L 0 0 0 r
F
.39968 .16146 m .39593 .16669 L .39085 .16795 L F
.38449 .14328 m .38936 .13937 L .37949 .13528 L .973 1 0 r
F
.37965 .14729 m .38449 .14328 L .37399 .1387 L .989 1 0 r
F
.38449 .14328 m .37949 .13528 L .37399 .1387 L .973 1 0 r
F
.38464 .14387 m .3895 .13998 L .37975 .13625 L .97 1 0 r
F
.38936 .13937 m .38504 .13201 L .37949 .13528 L .954 1 0 r
F
.3895 .13998 m .3853 .13304 L .37975 .13625 L .949 1 0 r
F
.3895 .13998 m .3944 .1362 L .3853 .13304 L F
.3944 .1362 m .39089 .13002 L .3853 .13304 L .92 1 0 r
F
.38028 .19552 m .38344 .1903 L .36434 .18469 L 1 1 0 r
F
.38352 .19058 m .38671 .18543 L .36837 .18016 L F
.38028 .19552 m .36434 .18469 L .36049 .18968 L F
.38352 .19058 m .36837 .18016 L .36448 .18508 L F
.38891 .19308 m .39206 .18816 L .37578 .18602 L F
.39206 .18816 m .37967 .18163 L .37578 .18602 L F
.39253 .18989 m .39568 .18503 L .3807 .18498 L F
.39568 .18503 m .38458 .18075 L .3807 .18498 L F
.38757 .17318 m .39157 .16914 L .38097 .17224 L .816 .794 0 r
F
.38458 .18075 m .38851 .17664 L .37864 .183 L .669 .229 0 r
F
.38851 .17664 m .3835 .18085 L .37864 .183 L .538 .204 0 r
F
.38851 .17664 m .39247 .17266 L .3835 .18085 L F
.39157 .16914 m .38587 .16985 L .38097 .17224 L .689 .434 0 r
F
.39247 .17266 m .38846 .17928 L .3835 .18085 L 0 0 0 r
F
.39201 .2223 m .39434 .21669 L .37099 .21153 L 1 1 0 r
F
.39434 .21669 m .37405 .20613 L .37099 .21153 L F
.3944 .21688 m .39675 .21132 L .37414 .2064 L F
.39675 .21132 m .37724 .20106 L .37414 .2064 L F
.38971 .22796 m .39201 .2223 L .36796 .21699 L F
.39201 .2223 m .37099 .21153 L .36796 .21699 L F
.39207 .22249 m .3944 .21688 L .37109 .2118 L F
.3944 .21688 m .37414 .2064 L .37109 .2118 L F
.396 .22238 m .3983 .21691 L .37663 .2134 L F
.38971 .22796 m .36796 .21699 L .36497 .2225 L F
.39207 .22249 m .37109 .2118 L .36806 .21725 L F
.38744 .23368 m .38971 .22796 L .36497 .2225 L F
.38977 .22816 m .39207 .22249 L .36806 .21725 L F
.39373 .22789 m .396 .22238 L .37364 .21864 L F
.396 .22238 m .37663 .2134 L .37364 .21864 L F
.3963 .22339 m .39858 .21793 L .37724 .21511 L F
.3983 .21691 m .37965 .20823 L .37663 .2134 L F
.3983 .21691 m .40062 .2115 L .37965 .20823 L F
.39858 .21793 m .38023 .20995 L .37724 .21511 L F
.39858 .21793 m .40089 .21251 L .38023 .20995 L F
.40062 .2115 m .38271 .20311 L .37965 .20823 L F
.40089 .21251 m .38326 .20484 L .38023 .20995 L F
.40089 .21251 m .40322 .20714 L .38326 .20484 L F
.40322 .20714 m .38632 .1998 L .38326 .20484 L F
.37714 .20079 m .38028 .19552 L .36049 .18968 L F
.38036 .19579 m .38352 .19058 L .36448 .18508 L F
.37714 .20079 m .36049 .18968 L .35667 .19475 L F
.38036 .19579 m .36448 .18508 L .36063 .19007 L F
.38579 .19806 m .38891 .19308 L .37192 .19051 L F
.38891 .19308 m .37578 .18602 L .37192 .19051 L F
.38941 .19481 m .39253 .18989 L .37685 .18933 L F
.39253 .18989 m .3807 .18498 L .37685 .18933 L F
.38846 .17928 m .39355 .17844 L .39921 .22718 L .445 .052 0 r
F
.39355 .17844 m .40743 .24017 L .39921 .22718 L .482 .06 0 r
F
.39355 .17844 m .39878 .17854 L .40743 .24017 L F
.39085 .16795 m .39593 .16669 L .39669 .19983 L .397 .04 0 r
F
.38504 .13201 m .39064 .12894 L .38371 .12634 L .814 1 0 r
F
.3853 .13304 m .39089 .13002 L .38418 .12826 L .745 .928 0 r
F
.39878 .17854 m .41546 .25469 L .40743 .24017 L .508 .065 0 r
F
.39593 .16669 m .40494 .21227 L .39669 .19983 L .46 .054 0 r
F
.39593 .16669 m .40114 .16629 L .40494 .21227 L F
.39064 .12894 m .38793 .11553 L .38371 .12634 L 1 1 0 r
F
.39064 .12894 m .39498 .11997 L .38793 .11553 L F
.39089 .13002 m .38801 .1159 L .38418 .12826 L .849 .82 0 r
F
.40114 .16629 m .41262 .22375 L .40494 .21227 L .499 .063 0 r
F
.41262 .22375 m .41388 .23005 L .41344 .22917 L F
.41262 .22375 m .41344 .22917 L .40494 .21227 L F
.37949 .13528 m .38504 .13201 L .3775 .1286 L .879 1 0 r
F
.37399 .1387 m .37949 .13528 L .37136 .13116 L .92 1 0 r
F
.37949 .13528 m .3775 .1286 L .37136 .13116 L .879 1 0 r
F
.37975 .13625 m .3853 .13304 L .37799 .13044 L .832 1 0 r
F
.38504 .13201 m .38371 .12634 L .3775 .1286 L .814 1 0 r
F
.3853 .13304 m .38418 .12826 L .37799 .13044 L .745 .928 0 r
F
.3775 .1286 m .378 .12842 L .37866 .12461 L .551 .656 0 r
F
.378 .12842 m .38371 .12634 L .37962 .12494 L F
.378 .12842 m .37962 .12494 L .37866 .12461 L F
.38371 .12634 m .38793 .11553 L .38232 .1108 L 1 1 0 r
F
.38371 .12634 m .38232 .1108 L .37866 .12461 L F
.38418 .12826 m .38241 .11115 L .37938 .12736 L F
.38144 .12105 m .38241 .11115 L .38179 .11998 L 0 0 0 r
F
.37938 .12736 m .37997 .12418 L .38144 .12105 L F
.37997 .12418 m .38241 .11115 L .38144 .12105 L F
.37799 .13044 m .38418 .12826 L .37938 .12736 L .485 .41 0 r
F
.38418 .12826 m .38801 .1159 L .38241 .11115 L 1 1 0 r
F
.39921 .22718 m .40743 .24017 L .42056 .30289 L .792 .228 0 r
F
.40743 .24017 m .42546 .30826 L .42056 .30289 L .833 .258 0 r
F
.40743 .24017 m .41546 .25469 L .42546 .30826 L F
.39669 .19983 m .40494 .21227 L .41971 .28669 L .755 .211 0 r
F
.41546 .25469 m .4299 .3128 L .42546 .30826 L .873 .285 0 r
F
.41546 .25469 m .42295 .26953 L .4299 .3128 L F
.40494 .21227 m .42632 .29836 L .41971 .28669 L .811 .258 0 r
F
.40494 .21227 m .41388 .23005 L .42632 .29836 L F
.42546 .30826 m .4299 .3128 L .43052 .32355 L .958 .209 0 r
F
.41971 .28669 m .42632 .29836 L .42899 .31725 L 1 .37 0 r
F
.42385 .30056 m .42899 .31725 L .42913 .31819 L F
.41971 .28669 m .42899 .31725 L .42385 .30056 L F
.39661 .1274 m .39648 .12727 L .39089 .13002 L .877 1 0 r
F
.39089 .13002 m .39648 .12727 L .39551 .12589 L .849 .82 0 r
F
.3902 .12666 m .39551 .12589 L .38801 .1159 L F
.39089 .13002 m .39551 .12589 L .3902 .12666 L F
.40419 .17994 m .40984 .18321 L .42295 .26953 L .529 .069 0 r
F
.40114 .16629 m .40571 .16703 L .41388 .23005 L .499 .063 0 r
F
.40571 .16703 m .40651 .16716 L .40968 .19423 L F
.40571 .16703 m .40968 .19423 L .41388 .23005 L F
.42295 .26953 m .41659 .24155 L .4299 .3128 L .394 .07 0 r
F
.41388 .23005 m .39648 .12727 L .38999 .12454 L 1 .615 0 r
F
.40968 .19423 m .409 .20123 L .41388 .23005 L .379 .114 0 r
F
.40902 .18853 m .40901 .19593 L .40968 .19423 L F
.40901 .19593 m .409 .20123 L .40968 .19423 L F
.41388 .23005 m .40073 .17199 L .42632 .29836 L 1 .615 0 r
F
.40073 .17199 m .39111 .12947 L .41253 .23237 L F
.39111 .12947 m .39045 .12659 L .39106 .12948 L F
.39111 .12947 m .39106 .12948 L .41253 .23237 L F
.38631 .1274 m .38999 .12454 L .38564 .12457 L 1 .457 0 r
F
.42632 .29836 m .39043 .12663 L .38631 .1274 L F
.39043 .12663 m .38999 .12454 L .38631 .1274 L F
.39045 .12659 m .39043 .12663 L .41253 .23237 L 1 .615 0 r
F
.40073 .17199 m .41253 .23237 L .42632 .29836 L F
.4299 .3128 m .3911 .1296 L .38634 .12746 L 1 .452 0 r
F
.3911 .1296 m .39048 .12667 L .38834 .12708 L F
.3911 .1296 m .38834 .12708 L .38634 .12746 L F
.39039 .12669 m .38869 .12921 L .38634 .12746 L .424 .003 0 r
F
.42632 .29836 m .38564 .12457 L .42913 .31819 L 1 .457 0 r
F
.42007 .27098 m .38634 .12746 L .42185 .2801 L 1 .452 0 r
F
.43004 .31532 m .38634 .12746 L .43052 .32355 L F
.42916 .30964 m .42007 .27098 L .43004 .31532 L F
.42007 .27098 m .42185 .2801 L .43004 .31532 L F
.4299 .3128 m .42916 .30964 L .43004 .31532 L F
.4308 .32311 m .38634 .12746 L .43188 .32143 L 0 0 0 r
F
.42941 .31858 m .38634 .12746 L .4308 .32311 L F
.42304 .29267 m .38564 .12457 L .38263 .12338 L 1 .209 0 r
F
.4223 .28777 m .38564 .12457 L .42304 .29267 L F
.41659 .24155 m .40723 .20037 L .42055 .26868 L .394 .07 0 r
F
.40723 .20037 m .40648 .20224 L .42055 .26868 L F
.41659 .24155 m .42055 .26868 L .4299 .3128 L F
.4392 .3415 m .43782 .3416 L .43722 .34167 L .326 .195 0 r
F
.43724 .34167 m .43722 .34167 L .43705 .34169 L F
.4392 .3415 m .43722 .34167 L .43724 .34167 L F
.43654 .3442 m .43841 .34323 L .43634 .34435 L 0 0 0 r
F
.44019 .34154 m .43841 .34323 L .43654 .3442 L F
.44202 .34018 m .44049 .34217 L .43841 .34323 L F
.43841 .34323 m .44049 .34217 L .44029 .34224 L .397 .202 0 r
F
.44019 .34154 m .44202 .34018 L .43841 .34323 L 0 0 0 r
F
.43841 .34323 m .44029 .34224 L .43742 .34329 L .397 .202 0 r
F
.43971 .34242 m .4341 .31732 L .43725 .34247 L .674 .323 0 r
F
.44049 .34217 m .44258 .34119 L .43971 .34242 L .322 .189 0 r
F
.44258 .34119 m .442 .34164 L .43971 .34242 L 0 0 0 r
F
.43971 .34242 m .442 .34164 L .4341 .31732 L .674 .323 0 r
F
.4341 .31732 m .4379 .32917 L .43409 .32553 L .987 .216 0 r
F
.44164 .34055 m .43805 .32163 L .4341 .31732 L 1 .207 0 r
F
.43365 .31921 m .43191 .30772 L .43329 .32221 L .902 .15 0 r
F
.42443 .26374 m .42605 .26986 L .42487 .26472 L .394 .07 0 r
F
.42569 .26812 m .42296 .2519 L .4251 .26525 L 1 .187 0 r
F
.42605 .26986 m .4251 .26525 L .42368 .25956 L .394 .07 0 r
F
.42826 .2806 m .42296 .2519 L .42569 .26812 L 1 .187 0 r
F
.42826 .2806 m .42968 .28357 L .42605 .26986 L .394 .07 0 r
F
.42826 .2806 m .42605 .26986 L .4236 .26062 L F
.42826 .2806 m .42569 .26812 L .42577 .26857 L 1 .187 0 r
F
.42295 .26953 m .42826 .2806 L .4236 .26062 L .394 .07 0 r
F
.42852 .28233 m .42577 .26857 L .43369 .31565 L 1 .187 0 r
F
.42826 .2806 m .42577 .26857 L .42852 .28233 L F
.40651 .16716 m .39661 .1274 L .409 .20123 L .379 .114 0 r
F
.39661 .1274 m .39648 .12727 L .409 .20123 L F
.40651 .16716 m .409 .20123 L .40902 .18853 L F
.4251 .26525 m .39296 .12645 L .41891 .24047 L 1 .609 0 r
F
.42296 .2519 m .42614 .26654 L .4251 .26525 L .936 .352 0 r
F
.42968 .28357 m .42552 .26577 L .4251 .26525 L 1 .609 0 r
F
.42748 .27246 m .42851 .27443 L .42808 .27266 L .519 .12 0 r
F
.42732 .27164 m .42808 .27266 L .42748 .27246 L .553 .072 0 r
F
.40984 .18321 m .42808 .27266 L .42732 .27164 L F
.42748 .27246 m .42808 .27266 L .42296 .2519 L .519 .12 0 r
F
.44228 .33977 m .42851 .27443 L .42748 .27246 L F
.42748 .27246 m .42808 .27266 L .42968 .28357 L .553 .072 0 r
F
.42808 .27266 m .42525 .25795 L .42296 .2519 L 1 .513 0 r
F
.43209 .2781 m .4312 .27369 L .42903 .27396 L F
.42968 .27918 m .42525 .25795 L .42808 .27266 L F
.42808 .27266 m .42525 .25795 L .42968 .28357 L .279 .056 0 r
F
.42968 .28357 m .42525 .25795 L .42614 .26654 L 1 .609 0 r
F
.4443 .33852 m .42525 .25795 L .42968 .27918 L 1 .513 0 r
F
.42527 .25817 m .4312 .27369 L .43131 .27459 L .936 .352 0 r
F
.42296 .2519 m .42525 .25795 L .42527 .25817 L F
.42525 .25795 m .4312 .27369 L .42527 .25817 L F
.42296 .2519 m .43131 .27459 L .42614 .26654 L F
.40419 .12839 m .40065 .11673 L .39498 .11997 L 1 1 0 r
F
.39498 .11997 m .40065 .11673 L .39415 .11279 L .902 1 0 r
F
.3969 .12572 m .4007 .11701 L .39808 .11546 L 1 1 0 r
F
.40432 .12905 m .4007 .11701 L .39716 .12569 L .847 .859 0 r
F
.40432 .12905 m .39716 .12569 L .39672 .12729 L F
.41213 .16996 m .40197 .12352 L .39716 .12569 L 1 .759 0 r
F
.39672 .12729 m .39716 .12569 L .39628 .12608 L F
.41213 .16996 m .39716 .12569 L .39672 .12729 L F
.39672 .12729 m .39716 .12569 L .39653 .12725 L .847 .859 0 r
F
.3968 .12658 m .39716 .12569 L .3969 .12572 L 1 1 0 r
F
.39716 .12569 m .4007 .11701 L .3969 .12572 L F
.39628 .12608 m .39716 .12569 L .39629 .1258 L .53 .469 0 r
F
.39653 .12725 m .3968 .12658 L .39666 .12586 L 1 1 0 r
F
.39629 .1258 m .39666 .12586 L .39423 .1132 L F
.39653 .12725 m .39666 .12586 L .39629 .1258 L F
.39666 .12586 m .39808 .11546 L .39423 .1132 L F
.3968 .12658 m .39688 .12589 L .39666 .12586 L F
.39688 .12589 m .39808 .11546 L .39666 .12586 L F
.39648 .12727 m .39628 .12608 L .39551 .12589 L 1 .615 0 r
F
.39498 .11997 m .39415 .11279 L .38793 .11553 L .902 1 0 r
F
.39551 .12589 m .39423 .1132 L .38801 .1159 L 1 1 0 r
F
.39628 .12608 m .39629 .1258 L .39551 .12589 L .53 .469 0 r
F
.39661 .1274 m .39628 .12608 L .39648 .12727 L .379 .114 0 r
F
.39653 .12725 m .39629 .1258 L .39551 .12589 L 1 1 0 r
F
.39629 .1258 m .39423 .1132 L .39551 .12589 L F
.39629 .1258 m .39629 .12578 L .39551 .12589 L .53 .469 0 r
F
.39629 .12578 m .39638 .12342 L .39558 .12569 L F
.39623 .12579 m .39558 .12569 L .39551 .12589 L F
.39629 .12578 m .39558 .12569 L .39623 .12579 L F
.3933 .12535 m .39638 .12342 L .38999 .12454 L F
.39551 .12589 m .39558 .12569 L .3933 .12535 L F
.39558 .12569 m .39638 .12342 L .3933 .12535 L F
.39629 .1258 m .40197 .12352 L .39638 .12342 L F
.39716 .12569 m .40197 .12352 L .39629 .1258 L F
.40545 .16291 m .40872 .16053 L .39672 .12729 L .379 .114 0 r
F
.42614 .26654 m .42525 .25795 L .39694 .12609 L 1 .609 0 r
F
.42576 .26595 m .42091 .24138 L .42045 .24204 L F
.42968 .28357 m .42614 .26654 L .42576 .26595 L F
.42614 .26654 m .42091 .24138 L .42576 .26595 L F
.44218 .33928 m .44417 .33799 L .42851 .27443 L .519 .12 0 r
F
.42614 .26654 m .43131 .27459 L .43667 .31506 L .936 .352 0 r
F
.42968 .28357 m .42045 .24204 L .42332 .25637 L 1 .609 0 r
F
.42614 .26654 m .42658 .26857 L .4251 .26525 L .936 .352 0 r
F
.42552 .26577 m .42332 .25637 L .4251 .26525 L 1 .609 0 r
F
.42332 .25637 m .39296 .12645 L .4251 .26525 L F
.42605 .26986 m .42968 .28357 L .4251 .26525 L .394 .07 0 r
F
.42577 .26857 m .42569 .26812 L .4251 .26525 L 1 .187 0 r
F
.43369 .31565 m .42577 .26857 L .43191 .30772 L F
.42577 .26857 m .4251 .26525 L .43191 .30772 L F
.4301 .29173 m .42826 .2806 L .43043 .29462 L F
.4251 .26525 m .43667 .31506 L .43191 .30772 L .936 .352 0 r
F
.42658 .26857 m .43667 .31506 L .4251 .26525 L F
.4236 .26062 m .42443 .26374 L .42368 .25956 L .394 .07 0 r
F
.42443 .26374 m .42487 .26472 L .42368 .25956 L F
.42332 .25637 m .42045 .24204 L .42009 .24254 L 1 .609 0 r
F
.4341 .31732 m .43805 .32163 L .4379 .32917 L .987 .216 0 r
F
.43191 .30772 m .43721 .32607 L .43357 .32249 L 1 .33 0 r
F
.4341 .31773 m .43502 .32139 L .43409 .3214 L .815 .332 0 r
F
.43191 .30772 m .43357 .32249 L .43329 .32221 L 1 .33 0 r
F
.4341 .31773 m .43409 .3214 L .43188 .32143 L .815 .332 0 r
F
.38634 .12746 m .4341 .31773 L .43188 .32143 L F
.40723 .20037 m .39048 .12667 L .40648 .20224 L .394 .07 0 r
F
.41891 .24047 m .39296 .12645 L .39048 .12667 L 1 .609 0 r
F
.42017 .2573 m .42368 .25956 L .39048 .12667 L .394 .07 0 r
F
.42295 .26953 m .42368 .25956 L .42017 .2573 L F
.43191 .30772 m .43667 .31506 L .43721 .32607 L 1 .33 0 r
F
.38634 .12746 m .39454 .13358 L .43502 .32139 L .815 .332 0 r
F
.38545 .12449 m .38812 .12949 L .38263 .12338 L .814 .069 0 r
F
.38554 .12453 m .38556 .12457 L .38545 .12449 L F
.38556 .12457 m .38812 .12949 L .38545 .12449 L F
.38564 .12457 m .38569 .12467 L .38554 .12453 L F
.38569 .12467 m .38812 .12949 L .38554 .12453 L F
.38812 .12949 m .39355 .14025 L .38659 .1295 L F
.38812 .12949 m .38659 .1295 L .38263 .12338 L F
.39048 .12667 m .39454 .13358 L .38869 .12921 L .424 .003 0 r
F
.39048 .12667 m .38869 .12921 L .39039 .12669 L F
.39045 .12659 m .38999 .12454 L .39043 .12663 L 1 .615 0 r
F
.39648 .12727 m .39551 .12589 L .38999 .12454 L F
.39648 .12727 m .39653 .12725 L .39551 .12589 L .849 .82 0 r
F
.43052 .32355 m .42941 .31858 L .4308 .32311 L 0 0 0 r
F
.42913 .31819 m .4223 .28777 L .42304 .29267 L 1 .209 0 r
F
.39661 .1274 m .39653 .12725 L .39648 .12727 L .877 1 0 r
F
.39661 .1274 m .39672 .12729 L .39653 .12725 L F
.42009 .24254 m .39694 .12609 L .39296 .12645 L 1 .609 0 r
F
.42091 .24138 m .39694 .12609 L .42009 .24254 L F
.442 .34164 m .44177 .3405 L .44164 .34055 L 1 .207 0 r
F
.44177 .3405 m .43805 .32163 L .44164 .34055 L F
.43409 .32553 m .43887 .3382 L .43623 .33891 L .992 .264 0 r
F
.43409 .32553 m .4379 .32917 L .43887 .3382 L F
.43367 .323 m .43695 .32983 L .43303 .32505 L 1 .107 0 r
F
.43367 .323 m .43303 .32505 L .43295 .32496 L F
.43715 .34166 m .43714 .34166 L .43722 .34232 L 1 .193 0 r
F
.43329 .32221 m .43295 .32496 L .43268 .32462 L 1 .107 0 r
F
.43725 .34247 m .43723 .34232 L .43722 .34232 L 1 .193 0 r
F
.40419 .12839 m .40839 .12038 L .40065 .11673 L 1 1 0 r
F
.40356 .12652 m .40842 .12491 L .4007 .11701 L .847 .859 0 r
F
.40925 .12577 m .4085 .12488 L .4007 .11701 L F
.40839 .12038 m .40635 .11363 L .40065 .11673 L .912 1 0 r
F
.40816 .12311 m .4064 .11393 L .40699 .12336 L 1 1 0 r
F
.40908 .12471 m .4064 .11393 L .4085 .12488 L F
.40948 .12592 m .40961 .12577 L .40921 .12503 L .554 .37 0 r
F
.41781 .1274 m .41634 .12387 L .40964 .12563 L .845 .891 0 r
F
.41781 .1274 m .40964 .12563 L .40961 .12577 L F
.41634 .12387 m .41349 .11704 L .40985 .12462 L F
.40961 .12577 m .40985 .12462 L .40921 .12503 L 1 .877 0 r
F
.40961 .12577 m .40985 .12462 L .40961 .12577 L F
.40839 .12038 m .41346 .11684 L .40635 .11363 L .912 1 0 r
F
.40908 .12471 m .40985 .12462 L .4064 .11393 L 1 1 0 r
F
.40985 .12462 m .41349 .11704 L .41161 .11621 L F
.40985 .12462 m .41161 .11621 L .4064 .11393 L F
.40908 .12471 m .41426 .12185 L .40772 .12135 L .736 .901 0 r
F
.40908 .12471 m .40909 .12471 L .40908 .12471 L F
.40909 .12471 m .41426 .12185 L .40908 .12471 L F
.40921 .12503 m .40985 .12462 L .40908 .12471 L F
.40948 .12592 m .40921 .12503 L .40925 .12577 L .554 .37 0 r
F
.40933 .12572 m .40985 .12462 L .40908 .12471 L 1 1 0 r
F
.41634 .12387 m .40985 .12462 L .40933 .12572 L .845 .891 0 r
F
.42061 .14584 m .41426 .12185 L .40985 .12462 L 1 .877 0 r
F
.42061 .14584 m .40985 .12462 L .40961 .12577 L F
.40961 .12577 m .40964 .12563 L .40933 .12572 L .845 .891 0 r
F
.40985 .12462 m .41426 .12185 L .40908 .12471 L .736 .901 0 r
F
.41412 .12184 m .4138 .1207 L .40852 .12142 L .572 .481 0 r
F
.41425 .12181 m .41354 .11976 L .41412 .12184 L F
.41781 .1274 m .42205 .1237 L .41349 .11704 L .845 .891 0 r
F
.42205 .1237 m .42208 .12323 L .42148 .12312 L 1 .877 0 r
F
.42205 .1237 m .42214 .12363 L .42148 .12312 L .845 .891 0 r
F
.42205 .1237 m .42148 .12312 L .41349 .11704 L F
.42205 .1237 m .42148 .12312 L .41902 .12269 L 1 .877 0 r
F
.41724 .12238 m .41935 .11891 L .41426 .12185 L .883 1 0 r
F
.42148 .12312 m .42058 .12135 L .41724 .12238 L F
.42058 .12135 m .41935 .11891 L .41724 .12238 L F
.42189 .12292 m .42162 .12215 L .42155 .12318 L 1 1 0 r
F
.42162 .12215 m .41859 .11362 L .42128 .12229 L F
.42162 .12215 m .42128 .12229 L .42155 .12318 L F
.42189 .12292 m .42601 .11607 L .41859 .11362 L F
.42189 .12293 m .42191 .12292 L .42191 .12292 L .883 1 0 r
F
.42208 .12323 m .42253 .12285 L .42189 .12293 L F
.42211 .12329 m .42212 .12327 L .42208 .12323 L .667 .58 0 r
F
.42214 .12363 m .42253 .12285 L .42189 .12292 L 1 1 0 r
F
.42253 .12285 m .42601 .11607 L .42189 .12292 L F
.42191 .12292 m .42645 .11958 L .4263 .11957 L .883 1 0 r
F
.42191 .12292 m .42645 .11958 L .42191 .12292 L F
.42084 .11905 m .42448 .11628 L .41935 .11891 L .81 .973 0 r
F
.4263 .11957 m .42529 .11774 L .42084 .11905 L F
.42529 .11774 m .42448 .11628 L .42084 .11905 L F
.42641 .11952 m .42448 .11628 L .4263 .11957 L F
.42645 .11958 m .43084 .11607 L .42448 .11628 L F
.42601 .11607 m .43042 .11236 L .42371 .11035 L .903 1 0 r
F
.42455 .11627 m .42965 .11409 L .42448 .11628 L .647 .636 0 r
F
.43084 .11607 m .43005 .11476 L .42455 .11627 L F
.43005 .11476 m .42965 .11409 L .42455 .11627 L F
.42664 .11982 m .43084 .11607 L .42645 .11958 L 1 .97 0 r
F
.43101 .11661 m .43084 .11607 L .42664 .11982 L F
.43084 .11607 m .43525 .11273 L .42965 .11409 L .647 .636 0 r
F
.43088 .11648 m .43406 .11407 L .42976 .11507 L .615 .431 0 r
F
.43429 .1139 m .43529 .11314 L .43288 .11399 L F
.42889 .11668 m .42927 .11598 L .42459 .11713 L F
.42927 .11598 m .42976 .11507 L .42578 .11665 L F
.42927 .11598 m .42578 .11665 L .42459 .11713 L F
.42189 .12292 m .41935 .11891 L .42148 .12312 L .883 1 0 r
F
.42189 .12292 m .4263 .11957 L .41935 .11891 L F
.42518 .11993 m .42459 .11713 L .41946 .11969 L .773 .898 0 r
F
.42189 .12293 m .4263 .11957 L .42189 .12292 L .883 1 0 r
F
.42253 .12285 m .42645 .11958 L .42189 .12293 L F
.42877 .1403 m .43179 .13675 L .42566 .1487 L 0 0 0 r
F
.43179 .13675 m .43222 .13624 L .42566 .1487 L F
.42534 .14443 m .42877 .1403 L .42132 .1505 L F
.42566 .1487 m .42569 .14867 L .42492 .14376 L .281 .045 0 r
F
.42566 .1487 m .42562 .14881 L .42557 .14882 L 0 0 0 r
F
.42566 .1487 m .42557 .14882 L .42193 .14967 L F
.42566 .1487 m .42492 .14376 L .42557 .14883 L .281 .045 0 r
F
.4257 .14869 m .42571 .14869 L .42529 .14607 L F
.42571 .14869 m .42571 .14869 L .42571 .14865 L F
.42571 .14869 m .42571 .14865 L .42529 .14607 L F
.42858 .13881 m .42247 .12368 L .42246 .12409 L .667 .58 0 r
F
.42513 .14291 m .42858 .13881 L .42061 .14584 L .656 .222 0 r
F
.42572 .14887 m .42529 .14607 L .42528 .14605 L .281 .045 0 r
F
.42572 .14882 m .42529 .14607 L .42572 .14887 L F
.43222 .13624 m .4277 .1234 L .42575 .14569 L .625 .509 0 r
F
.42571 .14865 m .42578 .14349 L .42492 .14376 L .279 .044 0 r
F
.42574 .14623 m .42575 .14569 L .4257 .1463 L .625 .509 0 r
F
.43222 .13624 m .42575 .14569 L .42574 .14623 L F
.4277 .1234 m .42578 .14349 L .4257 .1463 L F
.43222 .13624 m .4257 .1463 L .42571 .14865 L F
.42572 .14875 m .42578 .14349 L .42571 .14865 L .279 .044 0 r
F
.45303 .31882 m .42929 .14235 L .42578 .14349 L F
.45303 .31882 m .42578 .14349 L .42572 .14875 L F
.42528 .14605 m .42529 .14607 L .42492 .14376 L .281 .045 0 r
F
.42492 .14376 m .42578 .14349 L .42534 .14751 L .345 .045 0 r
F
.4257 .1463 m .42578 .14349 L .42542 .11994 L 1 .846 0 r
F
.42578 .14349 m .4265 .11998 L .42605 .11996 L F
.42578 .14349 m .42605 .11996 L .42542 .11994 L F
.42562 .14881 m .42555 .14566 L .42534 .14751 L F
.42061 .14584 m .42205 .1237 L .41426 .12185 L 1 .877 0 r
F
.42205 .1237 m .41902 .12269 L .41426 .12185 L F
.42228 .12378 m .42214 .12363 L .42205 .1237 L .962 1 0 r
F
.42208 .12323 m .42189 .12292 L .42148 .12312 L .883 1 0 r
F
.42155 .12318 m .42153 .1231 L .42148 .12312 L 1 1 0 r
F
.42214 .12363 m .42189 .12292 L .42155 .12318 L F
.42247 .12368 m .42253 .12285 L .42208 .12323 L .643 .548 0 r
F
.42253 .12295 m .42253 .12285 L .42249 .12295 L .842 .914 0 r
F
.42247 .12368 m .42249 .12295 L .42214 .12363 L F
.4257 .1463 m .42542 .11994 L .41946 .11969 L 1 .846 0 r
F
.42557 .14883 m .42492 .14376 L .4249 .14714 L 1 .664 0 r
F
.42132 .1505 m .42557 .14883 L .42539 .14839 L .46 .227 0 r
F
.42132 .1505 m .42543 .14837 L .4249 .14714 L F
.41889 .14074 m .4249 .14714 L .41437 .12258 L F
.41635 .14839 m .42061 .14584 L .40962 .12579 L .554 .37 0 r
F
.42132 .1505 m .4249 .14714 L .41889 .14074 L .46 .227 0 r
F
.42492 .14376 m .42534 .14751 L .4249 .14714 L .345 .045 0 r
F
.42534 .14751 m .41946 .11969 L .42514 .14771 L 1 .846 0 r
F
.42534 .14751 m .42536 .14763 L .4249 .14714 L .345 .045 0 r
F
.42557 .14883 m .42546 .14857 L .4255 .14893 L 1 .664 0 r
F
.42518 .14945 m .4249 .14714 L .42489 .1499 L F
.42514 .14771 m .42506 .14727 L .4249 .14714 L 1 .846 0 r
F
.42562 .14881 m .42534 .14751 L .42514 .14771 L F
.42557 .14883 m .42489 .1499 L .42468 .18723 L 1 .664 0 r
F
.42539 .14839 m .42562 .14881 L .42543 .14837 L .46 .227 0 r
F
.42557 .14882 m .42562 .14881 L .42557 .14883 L 0 0 0 r
F
.42557 .14883 m .42562 .14881 L .42539 .14839 L .46 .227 0 r
F
.42536 .14763 m .43208 .20727 L .4249 .14714 L .345 .045 0 r
F
.4249 .14714 m .43208 .20727 L .42468 .18723 L F
.4249 .14714 m .41946 .11969 L .41437 .12258 L 1 .846 0 r
F
.42506 .14727 m .41946 .11969 L .4249 .14714 L F
.42534 .14751 m .42578 .14349 L .4254 .14746 L .345 .045 0 r
F
.42534 .14751 m .4254 .14746 L .42537 .14777 L F
.42562 .14881 m .4257 .1463 L .42555 .14566 L 1 .846 0 r
F
.42534 .14751 m .42555 .14566 L .41946 .11969 L F
.45186 .31548 m .42572 .14882 L .42572 .14887 L .281 .045 0 r
F
.42566 .1487 m .42571 .14865 L .42562 .14881 L 0 0 0 r
F
.42571 .14865 m .4257 .1463 L .42562 .14881 L .625 .509 0 r
F
.4504 .31394 m .45107 .31049 L .42569 .14867 L .281 .045 0 r
F
.4504 .31394 m .42569 .14867 L .42566 .1487 L F
.4514 .31259 m .45147 .31222 L .42571 .14869 L F
.45147 .31222 m .45172 .3107 L .44905 .29404 L F
.45147 .31222 m .44905 .29404 L .42571 .14869 L F
.4514 .31259 m .42571 .14869 L .4257 .14869 L F
.4513 .3347 m .43224 .16771 L .4357 .22282 L 1 .672 0 r
F
.43224 .16771 m .42998 .14795 L .43045 .15426 L F
.43224 .16771 m .43045 .15426 L .43677 .23984 L F
.45283 .3085 m .45274 .30383 L .42955 .14414 L .279 .044 0 r
F
.45283 .3085 m .42955 .14414 L .42954 .14412 L F
.45269 .3095 m .45283 .3085 L .42929 .14235 L F
.45276 .31684 m .42978 .14586 L .42975 .1458 L F
.45276 .31684 m .42978 .14586 L .45276 .31684 L F
.45276 .31684 m .45319 .31309 L .42978 .14586 L F
.42974 .14548 m .43372 .14196 L .42929 .14235 L 1 .67 0 r
F
.45469 .31723 m .43444 .14798 L .42974 .14548 L F
.43444 .14798 m .43372 .14196 L .42974 .14548 L F
.43444 .14798 m .43907 .12703 L .43372 .14196 L F
.45469 .31723 m .43918 .12836 L .43444 .14798 L F
.43918 .12836 m .43907 .12703 L .43444 .14798 L F
.45388 .31801 m .45469 .31723 L .45424 .31412 L .279 .044 0 r
F
.45403 .30305 m .45426 .30122 L .45469 .31723 L 0 0 0 r
F
.45229 .26561 m .45294 .25208 L .45426 .30122 L F
.45229 .26561 m .45426 .30122 L .45403 .30305 L F
.45377 .29206 m .43918 .12839 L .4542 .31126 L .415 .065 0 r
F
.44784 .20399 m .43918 .12839 L .45377 .29206 L F
.45264 .24065 m .43921 .12818 L .43918 .12839 L F
.43921 .12818 m .43907 .12703 L .43918 .12836 L F
.43921 .12818 m .43918 .12836 L .43918 .12839 L F
.45264 .24065 m .43918 .12839 L .45278 .24711 L F
.45416 .29758 m .4542 .31126 L .45469 .31723 L F
.45182 .25544 m .45294 .25208 L .45229 .26561 L 0 0 0 r
F
.45264 .24065 m .4542 .31126 L .45416 .29758 L .415 .065 0 r
F
.45512 .32146 m .43919 .12837 L .43581 .14261 L 1 .672 0 r
F
.45512 .32146 m .43581 .14261 L .43449 .14886 L F
.43919 .12837 m .43902 .15041 L .43593 .14877 L .097 0 0 r
F
.43449 .14886 m .43581 .14261 L .43444 .14838 L 1 .672 0 r
F
.43914 .12859 m .43593 .14877 L .43452 .14802 L .097 0 0 r
F
.43919 .12837 m .43593 .14877 L .43914 .12859 L F
.45278 .24711 m .44784 .20399 L .45377 .29206 L .415 .065 0 r
F
.45332 .17464 m .45417 .26021 L .45329 .17494 L 0 0 0 r
F
.45335 .17749 m .45453 .15794 L .45417 .26021 L F
.45397 .17182 m .45344 .22247 L .45264 .24065 L F
.45291 .1724 m .45264 .24065 L .45283 .17345 L F
.45328 .17023 m .45332 .17464 L .45329 .17494 L F
.45328 .17023 m .45373 .16576 L .45335 .17749 L F
.45373 .16576 m .45453 .15794 L .45335 .17749 L F
.45294 .16441 m .45432 .15385 L .45264 .24065 L F
.45264 .24065 m .45344 .22247 L .43907 .12703 L .415 .065 0 r
F
.45304 .2502 m .45378 .23474 L .43919 .12837 L .38 .061 0 r
F
.43925 .12822 m .44261 .12327 L .43907 .12703 L 1 .668 0 r
F
.45344 .22247 m .44275 .12454 L .43925 .12822 L F
.44275 .12454 m .44261 .12327 L .43925 .12822 L F
.44275 .12454 m .44926 .11868 L .44261 .12327 L F
.45848 .14602 m .4473 .14136 L .44547 .14629 L 1 1 0 r
F
.45848 .14602 m .45947 .14098 L .4473 .14136 L F
.45947 .14098 m .44915 .13648 L .4473 .14136 L F
.47199 .14033 m .46047 .13583 L .45947 .14081 L .973 1 0 r
F
.45947 .14098 m .46048 .13598 L .44915 .13648 L 1 1 0 r
F
.46048 .13598 m .45102 .13163 L .44915 .13648 L F
.47199 .13778 m .47213 .1329 L .46037 .13277 L .925 1 0 r
F
.46047 .13583 m .46148 .13089 L .451 .13135 L 1 1 0 r
F
.45911 .131 m .45289 .12657 L .451 .13135 L F
.46148 .13089 m .4597 .13 L .45911 .131 L F
.4597 .13 m .45289 .12657 L .45911 .131 L F
.47213 .1329 m .47226 .12808 L .4614 .12801 L .921 1 0 r
F
.46148 .13089 m .4625 .126 L .45289 .12657 L 1 1 0 r
F
.46196 .12616 m .4548 .12204 L .4529 .12682 L F
.46251 .12612 m .46211 .12591 L .46196 .12616 L F
.46211 .12591 m .4548 .12204 L .46196 .12616 L F
.45102 .13163 m .4529 .12682 L .44382 .12821 L F
.4529 .12682 m .4548 .12204 L .44654 .12365 L F
.45344 .22247 m .44928 .11911 L .44275 .12454 L 1 .668 0 r
F
.44928 .11911 m .44926 .11868 L .44275 .12454 L F
.44278 .12451 m .44626 .12084 L .44272 .12456 L .761 .264 0 r
F
.45416 .16187 m .45406 .17081 L .45397 .17182 L 0 0 0 r
F
.45406 .17081 m .45344 .22247 L .45397 .17182 L F
.45423 .16095 m .45406 .1742 L .4542 .16138 L F
.45406 .1742 m .45344 .22247 L .45403 .17449 L F
.45406 .1742 m .45403 .17449 L .4542 .16138 L F
.45459 .17451 m .45477 .22472 L .45456 .17488 L F
.45477 .22472 m .45483 .24236 L .45476 .22533 L F
.45477 .22472 m .45476 .22533 L .45456 .17488 L F
.45459 .17451 m .45456 .17488 L .45453 .1654 L F
.45456 .16479 m .45453 .1654 L .45452 .16283 L F
.45447 .17661 m .45483 .24236 L .45417 .26021 L F
.45448 .17356 m .45449 .17624 L .45447 .17661 L F
.45449 .17624 m .45483 .24236 L .45447 .17661 L F
.45452 .16283 m .45455 .17227 L .45448 .17356 L F
.45455 .17227 m .45483 .24236 L .45448 .17356 L F
.45453 .15794 m .45455 .16216 L .45452 .16283 L F
.45423 .16095 m .4542 .16138 L .45424 .15778 L F
.45424 .15778 m .4542 .16138 L .45416 .16187 L F
.4542 .16138 m .45344 .22247 L .45416 .16187 L F
.45432 .15385 m .45427 .15729 L .45424 .15778 L F
.45294 .16441 m .45291 .1724 L .45283 .17345 L F
.47199 .14033 m .47212 .1353 L .46047 .13583 L .973 1 0 r
F
.46702 .13553 m .46148 .13089 L .46047 .13583 L F
.47212 .1353 m .46863 .13385 L .46702 .13553 L F
.46863 .13385 m .46148 .13089 L .46702 .13553 L F
.4846 .13938 m .48386 .13437 L .47213 .13287 L .782 .864 0 r
F
.4846 .13942 m .48386 .1344 L .47213 .1329 L F
.48386 .13437 m .47226 .12805 L .47213 .13287 L .779 .869 0 r
F
.48386 .1344 m .47226 .12808 L .47213 .1329 L F
.47212 .1353 m .47225 .13032 L .46148 .13089 L .973 1 0 r
F
.46662 .13062 m .4625 .126 L .46148 .13089 L .972 1 0 r
F
.47225 .13032 m .46844 .12863 L .46662 .13062 L F
.46844 .12863 m .4625 .126 L .46662 .13062 L F
.48386 .13437 m .4831 .12941 L .47226 .12805 L .779 .869 0 r
F
.48386 .1344 m .4831 .12943 L .47226 .12808 L F
.4831 .12941 m .47239 .12329 L .47226 .12805 L .972 .928 0 r
F
.4831 .12943 m .47239 .12332 L .47226 .12808 L .778 .874 0 r
F
.47225 .13032 m .47239 .12539 L .4625 .126 L .972 1 0 r
F
.46636 .12576 m .46353 .12114 L .4625 .126 L .973 1 0 r
F
.47239 .12539 m .46834 .12345 L .46636 .12576 L F
.46834 .12345 m .46353 .12114 L .46636 .12576 L F
.4831 .12941 m .48239 .12281 L .47239 .12329 L .972 .928 0 r
F
.4831 .12943 m .48234 .12454 L .47239 .12332 L .778 .874 0 r
F
.48234 .12454 m .48234 .12454 L .48223 .12451 L 1 .791 0 r
F
.48234 .12454 m .48234 .1245 L .48223 .12451 L F
.48239 .12281 m .47252 .11859 L .47239 .12329 L .894 1 0 r
F
.48223 .12449 m .47252 .11861 L .47244 .1217 L .777 .881 0 r
F
.48223 .12451 m .47244 .1217 L .47239 .12332 L F
.48234 .12452 m .47244 .1217 L .48223 .12451 L F
.48234 .12454 m .48223 .12451 L .47239 .12332 L .778 .874 0 r
F
.48223 .12451 m .47252 .1205 L .47239 .12539 L .936 1 0 r
F
.48234 .1245 m .48222 .12445 L .48223 .12451 L F
.48222 .12445 m .47252 .11861 L .48223 .12449 L .777 .881 0 r
F
.48222 .12445 m .47252 .1205 L .48223 .12451 L .936 1 0 r
F
.48234 .12452 m .48222 .12445 L .48223 .12449 L .777 .881 0 r
F
.48234 .12454 m .48234 .12452 L .48223 .12451 L .778 .874 0 r
F
.48292 .13488 m .48234 .12454 L .47239 .12539 L 1 .791 0 r
F
.48234 .12454 m .48223 .12451 L .47239 .12539 L F
.47239 .12539 m .47252 .1205 L .46353 .12114 L .973 1 0 r
F
.46626 .12095 m .46457 .11632 L .46353 .12114 L F
.47252 .1205 m .46836 .11831 L .46626 .12095 L F
.46836 .11831 m .46457 .11632 L .46626 .12095 L F
.47252 .11861 m .47266 .11397 L .46453 .11406 L .913 1 0 r
F
.48239 .12281 m .48161 .11811 L .47252 .11859 L .894 1 0 r
F
.48234 .1245 m .48157 .11963 L .48148 .11964 L .936 1 0 r
F
.48234 .12452 m .48157 .11965 L .48148 .11964 L .777 .881 0 r
F
.48164 .1241 m .48148 .11964 L .47252 .11861 L F
.48161 .11811 m .47384 .1145 L .47252 .11859 L .891 1 0 r
F
.47384 .1145 m .47266 .11395 L .47264 .11465 L F
.47384 .1145 m .47264 .11465 L .47252 .11859 L F
.49218 .1232 m .48161 .11811 L .48239 .12281 L .764 .878 0 r
F
.49383 .12803 m .48239 .12281 L .4831 .12941 L .764 .872 0 r
F
.49383 .12803 m .49218 .1232 L .48239 .12281 L F
.49383 .12803 m .49218 .1232 L .4824 .12451 L .907 .992 0 r
F
.48225 .12356 m .48157 .11963 L .48219 .12354 L .672 .744 0 r
F
.4824 .12451 m .48219 .12354 L .48234 .1245 L F
.49218 .1232 m .48162 .11967 L .4824 .12451 L .905 .997 0 r
F
.49198 .12667 m .48219 .12354 L .4824 .12451 L .672 .744 0 r
F
.4824 .12451 m .48157 .11965 L .48234 .12452 L .905 .997 0 r
F
.48162 .11967 m .48157 .11963 L .48225 .12356 L .672 .744 0 r
F
.48162 .11967 m .48157 .11965 L .4824 .12451 L .905 .997 0 r
F
.49198 .12667 m .48162 .11967 L .48225 .12356 L .672 .744 0 r
F
.49383 .12803 m .4824 .12451 L .48241 .12454 L .907 .992 0 r
F
.49547 .13292 m .4831 .12941 L .48386 .13437 L .907 .986 0 r
F
.49547 .13292 m .49383 .12803 L .4831 .12941 L F
.49547 .13292 m .49383 .12803 L .4831 .12943 L .909 .987 0 r
F
.49383 .12803 m .4824 .12454 L .4831 .12943 L .907 .992 0 r
F
.4824 .12454 m .48238 .12479 L .4831 .12943 L F
.49709 .13787 m .48386 .13437 L .4846 .13938 L .909 .981 0 r
F
.49869 .14287 m .4846 .13938 L .48535 .14445 L .911 .975 0 r
F
.50028 .14792 m .48535 .14445 L .48608 .14956 L .913 .97 0 r
F
.50186 .15303 m .48608 .14956 L .4868 .15473 L .914 .965 0 r
F
.50341 .15819 m .4868 .15473 L .48752 .15995 L .916 .96 0 r
F
.50496 .16341 m .48752 .15995 L .48823 .16522 L .918 .954 0 r
F
.50648 .16868 m .48823 .16522 L .48894 .17054 L .92 .949 0 r
F
.50799 .174 m .48894 .17054 L .48963 .17591 L .922 .944 0 r
F
.50949 .17937 m .48963 .17591 L .49032 .18132 L .924 .938 0 r
F
.51096 .1848 m .49032 .18132 L .491 .18679 L .926 .933 0 r
F
.51096 .1848 m .51096 .1848 L .51096 .1848 L F
.51096 .1848 m .49032 .18132 L .51096 .1848 L F
.51242 .19027 m .491 .18679 L .49167 .19231 L .927 .927 0 r
F
.51242 .19027 m .51242 .19027 L .51242 .19027 L .93 .929 0 r
F
.51242 .19027 m .51242 .19027 L .51242 .19027 L .927 .927 0 r
F
.51242 .19027 m .491 .18679 L .51242 .19027 L F
.51386 .1958 m .49167 .19231 L .49233 .19787 L .929 .921 0 r
F
.51387 .1958 m .51386 .1958 L .51386 .1958 L .932 .924 0 r
F
.51387 .1958 m .51386 .1958 L .51386 .1958 L .929 .921 0 r
F
.51386 .1958 m .49167 .19231 L .51386 .1958 L F
.51528 .20137 m .49233 .19787 L .49298 .20349 L .93 .916 0 r
F
.51529 .20137 m .51528 .20137 L .51528 .20137 L .933 .918 0 r
F
.51529 .20137 m .51528 .20137 L .51528 .20137 L .93 .916 0 r
F
.51528 .20137 m .49233 .19787 L .51528 .20137 L F
.51669 .20699 m .49298 .20349 L .49363 .20914 L .932 .91 0 r
F
.5167 .20699 m .51668 .20699 L .51669 .20699 L .935 .912 0 r
F
.5167 .20699 m .51668 .20699 L .51669 .20699 L .932 .91 0 r
F
.51668 .20699 m .49298 .20349 L .51669 .20699 L F
.51807 .21266 m .49363 .20914 L .49427 .21485 L .934 .904 0 r
F
.5181 .21266 m .51807 .21265 L .51807 .21266 L .936 .907 0 r
F
.5181 .21266 m .51807 .21265 L .51807 .21266 L .934 .904 0 r
F
.51807 .21265 m .49363 .20914 L .51807 .21266 L F
.51943 .21837 m .49427 .21485 L .4949 .22059 L .935 .899 0 r
F
.51947 .21837 m .51943 .21836 L .51943 .21837 L .938 .901 0 r
F
.51947 .21837 m .51943 .21836 L .51943 .21837 L .935 .899 0 r
F
.51943 .21836 m .49427 .21485 L .51943 .21837 L F
.52077 .22413 m .4949 .22059 L .49552 .22638 L .936 .893 0 r
F
.52083 .22413 m .52077 .22412 L .52077 .22413 L .939 .895 0 r
F
.52083 .22413 m .52077 .22412 L .52077 .22413 L .936 .893 0 r
F
.52077 .22412 m .4949 .22059 L .52077 .22413 L F
.52209 .22993 m .49552 .22638 L .49613 .23221 L .938 .887 0 r
F
.52217 .22993 m .52208 .22992 L .52209 .22993 L .941 .889 0 r
F
.52217 .22993 m .52208 .22992 L .52209 .22993 L .938 .887 0 r
F
.52208 .22992 m .49552 .22638 L .52209 .22993 L F
.52338 .23578 m .49613 .23221 L .49674 .23809 L .939 .881 0 r
F
.52465 .24167 m .49674 .23809 L .49733 .244 L .94 .875 0 r
F
.52589 .24759 m .49733 .244 L .49792 .24995 L .941 .869 0 r
F
.52734 .25354 m .52608 .24763 L .5259 .24765 L .945 .866 0 r
F
.52608 .24763 m .52607 .24758 L .52589 .24759 L F
.52708 .25351 m .52589 .24759 L .49792 .24995 L .942 .863 0 r
F
.52608 .24763 m .52589 .24759 L .49791 .25005 L .945 .866 0 r
F
.52734 .25354 m .52607 .24758 L .52589 .24759 L .942 .863 0 r
F
.52734 .25354 m .5259 .24765 L .52708 .25351 L .945 .866 0 r
F
.52734 .25354 m .52589 .24759 L .52708 .25351 L .942 .863 0 r
F
.52708 .25351 m .5259 .24765 L .49791 .25005 L .945 .866 0 r
F
.52589 .24759 m .49732 .24409 L .49791 .25005 L .944 .872 0 r
F
.52607 .24758 m .52588 .24755 L .52589 .24759 L F
.52588 .24755 m .52527 .24748 L .52589 .24759 L .941 .869 0 r
F
.52527 .24748 m .49733 .244 L .52589 .24759 L F
.52588 .24755 m .49732 .24409 L .52589 .24759 L .944 .872 0 r
F
.52607 .24758 m .52588 .24755 L .52589 .24759 L .941 .869 0 r
F
.52607 .24758 m .52479 .24165 L .52465 .24167 L .944 .872 0 r
F
.52607 .24758 m .52479 .24165 L .52465 .24167 L .941 .869 0 r
F
.52588 .24755 m .52465 .24167 L .49733 .244 L F
.52607 .24758 m .52465 .24167 L .52588 .24755 L .944 .872 0 r
F
.52607 .24758 m .52465 .24167 L .52588 .24755 L .941 .869 0 r
F
.52588 .24755 m .52465 .24167 L .49732 .24409 L .944 .872 0 r
F
.52465 .24167 m .49673 .23818 L .49732 .24409 L .943 .878 0 r
F
.52479 .24165 m .52464 .24163 L .52465 .24167 L F
.52465 .24166 m .49674 .23809 L .52465 .24167 L .94 .875 0 r
F
.52464 .24163 m .49674 .23809 L .52466 .24166 L F
.52464 .24163 m .49673 .23818 L .52465 .24167 L .943 .878 0 r
F
.52466 .24166 m .52465 .24166 L .52465 .24167 L .94 .875 0 r
F
.52479 .24165 m .52464 .24163 L .52466 .24166 L F
.52479 .24165 m .52349 .2358 L .52339 .23581 L .943 .878 0 r
F
.52349 .2358 m .52349 .23577 L .52338 .23578 L F
.52464 .24163 m .52338 .23578 L .49674 .23809 L .94 .875 0 r
F
.52349 .2358 m .52338 .23578 L .49673 .23818 L .943 .878 0 r
F
.52479 .24165 m .52349 .23577 L .52338 .23578 L .94 .875 0 r
F
.52479 .24165 m .52339 .23581 L .52459 .24143 L .943 .878 0 r
F
.52479 .24165 m .51993 .23611 L .52464 .24163 L F
.52479 .24165 m .52338 .23578 L .52464 .24163 L .94 .875 0 r
F
.52459 .24143 m .52339 .23581 L .51993 .23611 L .943 .878 0 r
F
.52464 .24163 m .51993 .23611 L .49673 .23818 L F
.52338 .23578 m .49612 .2323 L .49673 .23818 L .942 .884 0 r
F
.52349 .23577 m .52337 .23575 L .52338 .23578 L F
.52337 .23575 m .52277 .23568 L .52338 .23578 L .939 .881 0 r
F
.52277 .23568 m .49613 .23221 L .52338 .23578 L F
.52337 .23575 m .49612 .2323 L .52338 .23578 L .942 .884 0 r
F
.52349 .23577 m .52337 .23575 L .52338 .23578 L .939 .881 0 r
F
.52349 .23577 m .52217 .22993 L .52209 .22993 L .942 .884 0 r
F
.52349 .23577 m .52217 .22993 L .52209 .22993 L .939 .881 0 r
F
.52337 .23575 m .52209 .22993 L .49613 .23221 L F
.52349 .23577 m .52209 .22993 L .52337 .23575 L .942 .884 0 r
F
.52349 .23577 m .52209 .22993 L .52337 .23575 L .939 .881 0 r
F
.52337 .23575 m .52209 .22993 L .49612 .2323 L .942 .884 0 r
F
.52209 .22993 m .49551 .22647 L .49612 .2323 L .941 .889 0 r
F
.52208 .22992 m .49551 .22647 L .52209 .22993 L F
.52217 .22993 m .52083 .22413 L .52077 .22413 L F
.52217 .22993 m .52083 .22413 L .52077 .22413 L .938 .887 0 r
F
.52208 .22992 m .52077 .22413 L .49552 .22638 L F
.52217 .22993 m .52077 .22413 L .52208 .22992 L .941 .889 0 r
F
.52217 .22993 m .52077 .22413 L .52208 .22992 L .938 .887 0 r
F
.52208 .22992 m .52077 .22413 L .49551 .22647 L .941 .889 0 r
F
.52077 .22413 m .49489 .22068 L .49551 .22647 L .939 .895 0 r
F
.52077 .22412 m .49489 .22068 L .52077 .22413 L F
.52083 .22413 m .51947 .21837 L .51943 .21837 L F
.52083 .22413 m .51947 .21837 L .51943 .21837 L .936 .893 0 r
F
.52077 .22412 m .51943 .21837 L .4949 .22059 L F
.52083 .22413 m .51943 .21837 L .52077 .22412 L .939 .895 0 r
F
.52083 .22413 m .51943 .21837 L .52077 .22412 L .936 .893 0 r
F
.52077 .22412 m .51943 .21837 L .49489 .22068 L .939 .895 0 r
F
.51943 .21837 m .49426 .21493 L .49489 .22068 L .938 .901 0 r
F
.51943 .21836 m .49426 .21493 L .51943 .21837 L F
.51947 .21837 m .5181 .21266 L .51807 .21266 L F
.51947 .21837 m .5181 .21266 L .51807 .21266 L .935 .899 0 r
F
.51943 .21836 m .51807 .21266 L .49427 .21485 L F
.51947 .21837 m .51807 .21266 L .51943 .21836 L .938 .901 0 r
F
.51947 .21837 m .51807 .21266 L .51943 .21836 L .935 .899 0 r
F
.51943 .21836 m .51807 .21266 L .49426 .21493 L .938 .901 0 r
F
.51807 .21266 m .49362 .20922 L .49426 .21493 L .936 .907 0 r
F
.51807 .21265 m .49362 .20922 L .51807 .21266 L F
.5181 .21266 m .5167 .20699 L .51669 .20699 L F
.5181 .21266 m .5167 .20699 L .51669 .20699 L .934 .904 0 r
F
.51807 .21265 m .51669 .20699 L .49363 .20914 L F
.5181 .21266 m .51669 .20699 L .51807 .21265 L .936 .907 0 r
F
.5181 .21266 m .51669 .20699 L .51807 .21265 L .934 .904 0 r
F
.51807 .21265 m .51669 .20699 L .49362 .20922 L .936 .907 0 r
F
.51669 .20699 m .49298 .20356 L .49362 .20922 L .935 .912 0 r
F
.51668 .20699 m .49298 .20356 L .51669 .20699 L F
.5167 .20699 m .51529 .20137 L .51528 .20137 L F
.5167 .20699 m .51529 .20137 L .51528 .20137 L .932 .91 0 r
F
.51668 .20699 m .51528 .20137 L .49298 .20349 L F
.5167 .20699 m .51528 .20137 L .51668 .20699 L .935 .912 0 r
F
.5167 .20699 m .51528 .20137 L .51668 .20699 L .932 .91 0 r
F
.51668 .20699 m .51528 .20137 L .49298 .20356 L .935 .912 0 r
F
.51528 .20137 m .49232 .19795 L .49298 .20356 L .933 .918 0 r
F
.51528 .20137 m .49232 .19795 L .51528 .20137 L F
.51529 .20137 m .51387 .1958 L .51386 .1958 L F
.51529 .20137 m .51387 .1958 L .51386 .1958 L .93 .916 0 r
F
.51528 .20137 m .51386 .1958 L .49233 .19787 L F
.51529 .20137 m .51386 .1958 L .51528 .20137 L .933 .918 0 r
F
.51529 .20137 m .51386 .1958 L .51528 .20137 L .93 .916 0 r
F
.51528 .20137 m .51386 .1958 L .49232 .19795 L .933 .918 0 r
F
.51386 .1958 m .49166 .19238 L .49232 .19795 L .932 .924 0 r
F
.51386 .1958 m .49166 .19238 L .51386 .1958 L F
.51387 .1958 m .51242 .19027 L .51242 .19027 L F
.51387 .1958 m .51242 .19027 L .51242 .19027 L .929 .921 0 r
F
.51386 .1958 m .51242 .19027 L .49167 .19231 L F
.51387 .1958 m .51242 .19027 L .51386 .1958 L .932 .924 0 r
F
.51387 .1958 m .51242 .19027 L .51386 .1958 L .929 .921 0 r
F
.51386 .1958 m .51242 .19027 L .49166 .19238 L .932 .924 0 r
F
.51242 .19027 m .49099 .18686 L .49166 .19238 L .93 .929 0 r
F
.51242 .19027 m .49099 .18686 L .51242 .19027 L F
.51242 .19027 m .51096 .1848 L .51096 .1848 L F
.51242 .19027 m .51096 .1848 L .51096 .1848 L .927 .927 0 r
F
.51242 .19027 m .51096 .1848 L .491 .18679 L F
.51242 .19027 m .51096 .1848 L .51242 .19027 L .93 .929 0 r
F
.51242 .19027 m .51096 .1848 L .51242 .19027 L .927 .927 0 r
F
.51242 .19027 m .51096 .1848 L .49099 .18686 L .93 .929 0 r
F
.51096 .1848 m .49031 .18139 L .49099 .18686 L .928 .935 0 r
F
.51096 .1848 m .51096 .1848 L .51096 .1848 L F
.51096 .1848 m .49031 .18139 L .51096 .1848 L F
.51096 .1848 m .50949 .17937 L .50949 .17937 L F
.51096 .1848 m .50949 .17937 L .50949 .17937 L .926 .933 0 r
F
.51096 .1848 m .50949 .17937 L .49032 .18132 L F
.51096 .1848 m .50949 .17937 L .51096 .1848 L .928 .935 0 r
F
.51096 .1848 m .50949 .17937 L .51096 .1848 L .926 .933 0 r
F
.51096 .1848 m .50949 .17937 L .49031 .18139 L .928 .935 0 r
F
.50949 .17937 m .48963 .17597 L .49031 .18139 L .926 .94 0 r
F
.50949 .17937 m .50799 .174 L .50799 .174 L F
.50949 .17937 m .50799 .174 L .50799 .174 L .924 .938 0 r
F
.50948 .17937 m .50799 .174 L .48963 .17591 L F
.50949 .17937 m .50799 .174 L .50948 .17937 L .926 .94 0 r
F
.50949 .17937 m .50799 .174 L .50948 .17937 L .924 .938 0 r
F
.50948 .17937 m .50799 .174 L .48963 .17597 L .926 .94 0 r
F
.50799 .174 m .48893 .17059 L .48963 .17597 L .924 .946 0 r
F
.50799 .174 m .50648 .16868 L .50648 .16868 L F
.50799 .174 m .50648 .16868 L .50648 .16868 L .922 .944 0 r
F
.50799 .174 m .50648 .16868 L .48894 .17054 L F
.50799 .174 m .50648 .16868 L .50799 .174 L .924 .946 0 r
F
.50799 .174 m .50648 .16868 L .50799 .174 L .922 .944 0 r
F
.50799 .174 m .50648 .16868 L .48893 .17059 L .924 .946 0 r
F
.50648 .16868 m .48823 .16527 L .48893 .17059 L .923 .951 0 r
F
.50648 .16868 m .50496 .16341 L .50496 .16341 L F
.50648 .16868 m .50496 .16341 L .50496 .16341 L .92 .949 0 r
F
.50648 .16868 m .50496 .16341 L .48823 .16522 L F
.50648 .16868 m .50496 .16341 L .50648 .16868 L .923 .951 0 r
F
.50648 .16868 m .50496 .16341 L .50648 .16868 L .92 .949 0 r
F
.50648 .16868 m .50496 .16341 L .48823 .16527 L .923 .951 0 r
F
.50496 .16341 m .48752 .16 L .48823 .16527 L .921 .956 0 r
F
.50496 .16341 m .50341 .15819 L .50341 .15819 L F
.50496 .16341 m .50341 .15819 L .50341 .15819 L .918 .954 0 r
F
.50496 .16341 m .50341 .15819 L .48752 .15995 L F
.50496 .16341 m .50341 .15819 L .50496 .16341 L .921 .956 0 r
F
.50496 .16341 m .50341 .15819 L .50496 .16341 L .918 .954 0 r
F
.50496 .16341 m .50341 .15819 L .48752 .16 L .921 .956 0 r
F
.50341 .15819 m .4868 .15477 L .48752 .16 L .919 .962 0 r
F
.50341 .15819 m .50186 .15303 L .50186 .15303 L F
.50341 .15819 m .50186 .15303 L .50186 .15303 L .916 .96 0 r
F
.50341 .15819 m .50186 .15303 L .4868 .15473 L F
.50341 .15819 m .50186 .15303 L .50341 .15819 L .919 .962 0 r
F
.50341 .15819 m .50186 .15303 L .50341 .15819 L .916 .96 0 r
F
.50341 .15819 m .50186 .15303 L .4868 .15477 L .919 .962 0 r
F
.50186 .15303 m .48608 .1496 L .4868 .15477 L .917 .967 0 r
F
.50186 .15303 m .50028 .14792 L .50028 .14792 L F
.50186 .15303 m .50028 .14792 L .50028 .14792 L .914 .965 0 r
F
.50186 .15303 m .50028 .14792 L .48608 .14956 L F
.50186 .15303 m .50028 .14792 L .50186 .15303 L .917 .967 0 r
F
.50186 .15303 m .50028 .14792 L .50186 .15303 L .914 .965 0 r
F
.50186 .15303 m .50028 .14792 L .48608 .1496 L .917 .967 0 r
F
.50028 .14792 m .48534 .14448 L .48608 .1496 L .915 .972 0 r
F
.50028 .14792 m .49869 .14287 L .49869 .14287 L F
.50028 .14792 m .49869 .14287 L .49869 .14287 L .913 .97 0 r
F
.50028 .14792 m .49869 .14287 L .48535 .14445 L F
.50028 .14792 m .49869 .14287 L .50028 .14792 L .915 .972 0 r
F
.50028 .14792 m .49869 .14287 L .50028 .14792 L .913 .97 0 r
F
.50028 .14792 m .49869 .14287 L .48534 .14448 L .915 .972 0 r
F
.49869 .14287 m .4846 .13942 L .48534 .14448 L .913 .977 0 r
F
.49869 .14287 m .49709 .13787 L .49709 .13787 L F
.49869 .14287 m .49709 .13787 L .49709 .13787 L .911 .975 0 r
F
.49869 .14287 m .49709 .13787 L .4846 .13938 L F
.49869 .14287 m .49709 .13787 L .49869 .14287 L .913 .977 0 r
F
.49869 .14287 m .49709 .13787 L .49869 .14287 L .911 .975 0 r
F
.49869 .14287 m .49709 .13787 L .4846 .13942 L .913 .977 0 r
F
.49709 .13787 m .48386 .1344 L .4846 .13942 L .911 .982 0 r
F
.49709 .13787 m .49547 .13292 L .49547 .13292 L F
.49709 .13787 m .49547 .13292 L .48386 .13437 L .909 .981 0 r
F
.49709 .13787 m .49547 .13292 L .48386 .1344 L .911 .982 0 r
F
.49709 .13787 m .49547 .13292 L .49709 .13787 L F
.49709 .13787 m .49505 .13163 L .49709 .13787 L .909 .981 0 r
F
.49505 .13163 m .49547 .13292 L .49709 .13787 L F
.49547 .13292 m .4831 .12943 L .48386 .1344 L .909 .987 0 r
F
.49357 .13213 m .4824 .12454 L .48292 .13488 L .649 .711 0 r
F
.4824 .12454 m .48234 .1245 L .48234 .12454 L F
.4824 .12454 m .48234 .12454 L .48238 .12479 L .907 .992 0 r
F
.4824 .12454 m .48234 .12454 L .48292 .13488 L .649 .711 0 r
F
.4824 .12454 m .48234 .12452 L .48234 .12454 L .907 .992 0 r
F
.49357 .13213 m .49198 .12667 L .4824 .12451 L .649 .711 0 r
F
.4824 .12454 m .4824 .12451 L .48234 .1245 L F
.48241 .12454 m .4824 .12451 L .4824 .12454 L .907 .992 0 r
F
.49357 .13213 m .4824 .12451 L .4824 .12454 L .649 .711 0 r
F
.4824 .12454 m .4824 .12451 L .48234 .12452 L .907 .992 0 r
F
.49218 .1232 m .49052 .11842 L .48161 .11811 L .764 .878 0 r
F
.49218 .1232 m .49052 .11842 L .48163 .11965 L .905 .997 0 r
F
.48162 .11967 m .48163 .11965 L .48157 .11963 L .672 .744 0 r
F
.48162 .11967 m .48163 .11965 L .48157 .11965 L .905 .997 0 r
F
.49218 .1232 m .48163 .11965 L .48162 .11967 L F
.48165 .11969 m .48163 .11965 L .48162 .11967 L .672 .744 0 r
F
.49198 .12667 m .49037 .12131 L .48163 .11965 L F
.49198 .12667 m .48163 .11965 L .48165 .11969 L F
.48161 .11811 m .48083 .11348 L .47266 .11395 L .891 1 0 r
F
.49052 .11842 m .48083 .11348 L .48161 .11811 L .765 .886 0 r
F
.49052 .11842 m .48101 .11358 L .48156 .11953 L .766 .887 0 r
F
.49052 .11842 m .48156 .11953 L .48163 .11965 L F
.48101 .11358 m .48084 .1136 L .48157 .11965 L F
.48147 .11959 m .48083 .11348 L .47266 .11397 L .963 .957 0 r
F
.48157 .11963 m .48156 .11957 L .48147 .11959 L .935 1 0 r
F
.48157 .11965 m .48156 .11957 L .48147 .11959 L .963 .957 0 r
F
.48156 .11957 m .48083 .11348 L .48147 .11959 L F
.48148 .11959 m .48147 .11959 L .48148 .11964 L .935 1 0 r
F
.48148 .11964 m .47266 .11397 L .47252 .11861 L .963 .957 0 r
F
.48148 .11964 m .47266 .11397 L .48148 .11964 L F
.48147 .11959 m .47266 .11397 L .48148 .11964 L F
.48147 .11959 m .47272 .11568 L .48148 .11964 L .935 1 0 r
F
.47272 .11568 m .47272 .11568 L .48148 .11964 L F
.48157 .11963 m .48148 .11959 L .48148 .11964 L F
.48148 .11964 m .48148 .11964 L .48148 .11964 L .963 .957 0 r
F
.48157 .11965 m .48147 .11959 L .48148 .11964 L F
.48147 .11959 m .48079 .11482 L .48037 .11486 L .935 1 0 r
F
.48147 .11959 m .48037 .11486 L .47265 .11565 L F
.48156 .11957 m .48079 .11482 L .48147 .11959 L F
.49037 .12131 m .48079 .11482 L .48156 .11957 L .694 .777 0 r
F
.48163 .11965 m .48156 .11957 L .48157 .11963 L F
.48163 .11965 m .48156 .11953 L .48156 .11957 L .766 .887 0 r
F
.49037 .12131 m .48156 .11957 L .48163 .11965 L .694 .777 0 r
F
.48163 .11965 m .48156 .11957 L .48157 .11965 L .766 .887 0 r
F
.48148 .11964 m .4752 .11681 L .47252 .1205 L .935 1 0 r
F
.4752 .11681 m .47265 .11565 L .47257 .11872 L F
.4752 .11681 m .47257 .11872 L .47252 .1205 L F
.47272 .11568 m .47265 .11565 L .47272 .11568 L F
.48083 .11348 m .47279 .10937 L .47266 .11397 L .891 1 0 r
F
.48079 .11482 m .47471 .1118 L .47265 .11565 L .935 1 0 r
F
.47471 .1118 m .47279 .11084 L .47272 .11334 L F
.47471 .1118 m .47272 .11334 L .47265 .11565 L F
.48083 .11348 m .48003 .1089 L .47279 .10937 L .891 1 0 r
F
.48079 .11482 m .48001 .11006 L .47279 .11084 L .935 1 0 r
F
.48001 .11006 m .47431 .10685 L .47279 .11084 L .934 1 0 r
F
.47431 .10685 m .47292 .10607 L .47287 .10803 L F
.47431 .10685 m .47287 .10803 L .47279 .11084 L F
.48001 .11006 m .47922 .10534 L .47292 .10607 L F
.47922 .10534 m .47399 .10194 L .47292 .10607 L .935 1 0 r
F
.47399 .10194 m .47306 .10133 L .47302 .10281 L F
.47399 .10194 m .47302 .10281 L .47292 .10607 L F
.47924 .10436 m .47843 .09988 L .47306 .10031 L .889 1 0 r
F
.47924 .10437 m .47843 .09988 L .47306 .10032 L .89 1 0 r
F
.47922 .10534 m .47842 .10066 L .47306 .10133 L .935 1 0 r
F
.47843 .09988 m .4732 .09584 L .47306 .10031 L .892 1 0 r
F
.47843 .09988 m .4732 .09584 L .47306 .10032 L F
.47842 .10066 m .47319 .09662 L .47306 .10133 L .936 1 0 r
F
.47492 .10111 m .47319 .09664 L .47306 .10135 L .937 1 0 r
F
.47842 .10067 m .47682 .09943 L .47492 .10111 L F
.47682 .09943 m .47319 .09664 L .47492 .10111 L F
.47562 .10578 m .47306 .10135 L .47292 .1061 L .936 1 0 r
F
.47922 .10535 m .4775 .10423 L .47562 .10578 L F
.4775 .10423 m .47306 .10135 L .47562 .10578 L F
.47646 .11047 m .47292 .1061 L .47279 .11088 L F
.48001 .11007 m .47825 .10909 L .47646 .11047 L F
.47825 .10909 m .47292 .1061 L .47646 .11047 L F
.47742 .11519 m .47279 .11088 L .47265 .11569 L .937 1 0 r
F
.48079 .11484 m .47907 .11399 L .47742 .11519 L F
.47907 .11399 m .47279 .11088 L .47742 .11519 L F
.48222 .12445 m .48148 .11964 L .48164 .1241 L .777 .881 0 r
F
.48234 .1245 m .48148 .11964 L .48222 .12445 L .936 1 0 r
F
.48234 .12452 m .48148 .11964 L .48222 .12445 L .777 .881 0 r
F
.48222 .12445 m .48148 .11964 L .47252 .1205 L .936 1 0 r
F
.4822 .12913 m .48146 .1235 L .48137 .12352 L 1 1 0 r
F
.48202 .12905 m .48137 .12352 L .47252 .12055 L .671 .703 0 r
F
.48206 .12909 m .48137 .12352 L .48202 .12905 L F
.48292 .13488 m .47239 .12539 L .47225 .13032 L 1 .791 0 r
F
.48363 .14074 m .47225 .13032 L .47212 .1353 L .619 .622 0 r
F
.4836 .14072 m .48292 .13488 L .47225 .13032 L F
.48363 .14074 m .48354 .14005 L .4836 .14072 L F
.48354 .14005 m .48292 .13488 L .4836 .14072 L F
.49514 .13769 m .48292 .13488 L .48363 .14074 L 1 1 0 r
F
.49514 .13769 m .49357 .13213 L .48292 .13488 L F
.49514 .13769 m .49357 .13213 L .48309 .13494 L F
.4831 .13502 m .48309 .13494 L .48292 .13498 L F
.49514 .13769 m .48309 .13494 L .4831 .13502 L F
.48292 .13498 m .47239 .12545 L .47225 .13039 L .645 .662 0 r
F
.48249 .1346 m .48208 .12917 L .47239 .12545 L F
.48208 .12917 m .47252 .12055 L .47239 .12545 L .671 .703 0 r
F
.48432 .14672 m .48363 .14074 L .47212 .1353 L .594 .582 0 r
F
.48432 .14672 m .48432 .14668 L .48432 .14672 L F
.48432 .14668 m .48363 .14074 L .48432 .14672 L F
.49668 .14335 m .49668 .14335 L .48432 .14672 L 1 1 0 r
F
.49668 .14335 m .48363 .14074 L .48432 .14668 L F
.49668 .14335 m .48432 .14668 L .48432 .14672 L F
.49819 .1491 m .48432 .14672 L .485 .15281 L F
.49819 .1491 m .49668 .14335 L .49668 .14335 L F
.49819 .1491 m .49668 .14335 L .48432 .14672 L F
.49819 .1491 m .49668 .14335 L .49668 .14335 L F
.49819 .1491 m .49668 .14335 L .49819 .1491 L F
.49819 .1491 m .49668 .14335 L .48432 .14688 L F
.49967 .15496 m .485 .15281 L .48566 .15901 L 1 .997 0 r
F
.49967 .15496 m .49819 .1491 L .49819 .1491 L F
.49967 .15496 m .49819 .1491 L .485 .15281 L F
.49967 .15496 m .49819 .1491 L .49819 .1491 L 1 1 0 r
F
.49967 .15496 m .49819 .1491 L .49967 .15496 L 1 .997 0 r
F
.49967 .15496 m .49819 .1491 L .48499 .15301 L 1 1 0 r
F
.50113 .1609 m .48566 .15901 L .48631 .16532 L 1 .991 0 r
F
.50113 .1609 m .49967 .15496 L .49967 .15496 L F
.50113 .1609 m .49967 .15496 L .48566 .15901 L F
.50113 .1609 m .49967 .15496 L .49967 .15496 L 1 .998 0 r
F
.50113 .1609 m .49967 .15496 L .50113 .1609 L 1 .991 0 r
F
.50113 .1609 m .49967 .15496 L .48565 .15926 L 1 .998 0 r
F
.50255 .16695 m .48631 .16532 L .48693 .17175 L 1 .985 0 r
F
.50255 .16695 m .50113 .1609 L .50113 .1609 L F
.50255 .16695 m .50113 .1609 L .48631 .16532 L F
.50255 .16695 m .50113 .1609 L .50113 .1609 L 1 .993 0 r
F
.50255 .16695 m .50113 .1609 L .50255 .16695 L 1 .985 0 r
F
.50255 .16695 m .50113 .1609 L .48629 .16564 L 1 .993 0 r
F
.50393 .17309 m .48693 .17175 L .48754 .1783 L 1 .979 0 r
F
.50393 .17309 m .50255 .16695 L .50255 .16695 L F
.50393 .17309 m .50255 .16695 L .48693 .17175 L F
.50393 .17309 m .50255 .16695 L .50255 .16695 L 1 .988 0 r
F
.50393 .17309 m .50255 .16695 L .50393 .17309 L 1 .979 0 r
F
.50393 .17309 m .50255 .16695 L .48691 .17213 L 1 .988 0 r
F
.50529 .17933 m .48754 .1783 L .48812 .18496 L 1 .973 0 r
F
.50529 .17933 m .50393 .17309 L .50393 .17309 L F
.50529 .17933 m .50393 .17309 L .48754 .1783 L F
.50529 .17933 m .50393 .17309 L .50393 .17309 L 1 .983 0 r
F
.50529 .17933 m .50393 .17309 L .50529 .17933 L 1 .973 0 r
F
.50529 .17933 m .50393 .17309 L .48751 .17876 L 1 .983 0 r
F
.5066 .18566 m .48812 .18496 L .48869 .19173 L 1 .966 0 r
F
.5066 .18566 m .50529 .17933 L .50529 .17933 L F
.5066 .18566 m .50529 .17933 L .48812 .18496 L F
.5066 .18566 m .50529 .17933 L .50529 .17933 L 1 .978 0 r
F
.5066 .18566 m .50529 .17933 L .5066 .18566 L 1 .966 0 r
F
.5066 .18566 m .50529 .17933 L .48809 .18551 L 1 .978 0 r
F
.50788 .19209 m .48869 .19173 L .48923 .19863 L 1 .959 0 r
F
.50788 .19209 m .5066 .18566 L .50788 .19209 L 1 .972 0 r
F
.50788 .19209 m .5066 .18566 L .5066 .18566 L 1 .959 0 r
F
.50788 .19209 m .5066 .18566 L .48869 .19173 L F
.50788 .19209 m .5066 .18566 L .5066 .18566 L 1 .972 0 r
F
.50788 .19209 m .5066 .18566 L .50788 .19209 L 1 .959 0 r
F
.50788 .19209 m .5066 .18566 L .48865 .19239 L 1 .972 0 r
F
.50788 .19209 m .50788 .19209 L .50788 .19209 L F
.50911 .19861 m .48923 .19863 L .48974 .20563 L 1 .952 0 r
F
.50912 .19861 m .48923 .19863 L .50912 .19861 L F
.50912 .19861 m .50788 .19209 L .50912 .19861 L 1 .966 0 r
F
.50912 .19861 m .50788 .19209 L .50788 .19209 L 1 .952 0 r
F
.50912 .19861 m .50788 .19209 L .48923 .19863 L F
.50912 .19861 m .50788 .19209 L .50788 .19209 L 1 .966 0 r
F
.50912 .19861 m .50912 .19861 L .50912 .19861 L F
.50912 .19861 m .50788 .19209 L .50912 .19861 L 1 .952 0 r
F
.50912 .19861 m .50788 .19209 L .48918 .1994 L 1 .966 0 r
F
.50912 .19861 m .50912 .19861 L .50912 .19861 L 1 .952 0 r
F
.51031 .20523 m .48974 .20563 L .49023 .21275 L 1 .944 0 r
F
.51031 .20523 m .48974 .20563 L .51031 .20523 L F
.51031 .20522 m .48974 .20563 L .51031 .20523 L F
.51031 .20522 m .50912 .19861 L .51031 .20522 L 1 .96 0 r
F
.51031 .20522 m .50912 .19861 L .50912 .19861 L 1 .944 0 r
F
.51031 .20522 m .50912 .19861 L .48974 .20563 L F
.51031 .20522 m .50912 .19861 L .50912 .19861 L 1 .96 0 r
F
.51031 .20522 m .51031 .20522 L .51031 .20522 L F
.51031 .20522 m .50912 .19861 L .51031 .20522 L 1 .944 0 r
F
.51031 .20522 m .50912 .19861 L .48968 .20654 L 1 .96 0 r
F
.51031 .20523 m .51031 .20523 L .51031 .20523 L 1 .944 0 r
F
.51031 .20522 m .51031 .20522 L .51031 .20523 L 1 .96 0 r
F
.51031 .20522 m .51031 .20522 L .51031 .20523 L 1 .944 0 r
F
.51146 .21193 m .49023 .21275 L .4907 .21998 L 1 .936 0 r
F
.51146 .21193 m .49023 .21275 L .51146 .21193 L F
.51146 .21193 m .49023 .21275 L .51146 .21193 L F
.51146 .21193 m .51031 .20522 L .51146 .21193 L 1 .954 0 r
F
.51147 .21193 m .51031 .20522 L .51031 .20523 L 1 .936 0 r
F
.51146 .21193 m .51031 .20523 L .49023 .21275 L F
.51146 .21193 m .51031 .20522 L .51031 .20523 L 1 .954 0 r
F
.51147 .21193 m .51146 .21193 L .51146 .21193 L F
.51147 .21193 m .51031 .20523 L .51146 .21193 L 1 .936 0 r
F
.51146 .21193 m .51031 .20523 L .49016 .21382 L 1 .954 0 r
F
.51146 .21193 m .51146 .21193 L .51146 .21193 L 1 .936 0 r
F
.51147 .21193 m .51146 .21193 L .51146 .21193 L 1 .954 0 r
F
.51147 .21193 m .51146 .21193 L .51146 .21193 L 1 .936 0 r
F
.51255 .21873 m .4907 .21998 L .49113 .22732 L 1 .928 0 r
F
.51256 .21873 m .4907 .21998 L .51255 .21873 L F
.51257 .21873 m .51256 .21873 L .51256 .21873 L 1 .948 0 r
F
.51256 .21873 m .51256 .21873 L .51256 .21873 L 1 .928 0 r
F
.51256 .21873 m .4907 .21998 L .51256 .21873 L F
.51256 .21873 m .51256 .21873 L .51255 .21873 L F
.5136 .22562 m .49113 .22732 L .49154 .23476 L 1 .92 0 r
F
.51361 .22561 m .49113 .22732 L .5136 .22562 L F
.5146 .23259 m .49154 .23476 L .49191 .2423 L 1 .911 0 r
F
.5146 .23259 m .49154 .23476 L .5146 .23259 L F
.51463 .23258 m .51461 .23258 L .51461 .23259 L 1 .934 0 r
F
.51461 .23258 m .51461 .23258 L .51461 .23259 L 1 .911 0 r
F
.51461 .23258 m .49154 .23476 L .51461 .23259 L F
.51461 .23259 m .5146 .23259 L .5146 .23259 L F
.51553 .23965 m .49191 .2423 L .49225 .24992 L 1 .901 0 r
F
.51555 .23964 m .49191 .2423 L .51553 .23965 L F
.51641 .24679 m .49225 .24992 L .49256 .25762 L 1 .891 0 r
F
.51642 .24679 m .49225 .24992 L .51641 .24679 L F
.51647 .24677 m .51643 .24677 L .51643 .24678 L 1 .92 0 r
F
.51644 .24677 m .51643 .24677 L .51643 .24678 L 1 .891 0 r
F
.51643 .24677 m .49225 .24992 L .51643 .24678 L F
.51643 .24678 m .51642 .24679 L .51641 .24679 L F
.51723 .25401 m .49256 .25762 L .49284 .26537 L 1 .881 0 r
F
.51724 .25398 m .49256 .25762 L .51723 .25401 L F
.51797 .2613 m .49284 .26537 L .49308 .27316 L 1 .87 0 r
F
.51798 .26129 m .49284 .26537 L .51797 .2613 L F
.51807 .26124 m .518 .26126 L .51801 .26128 L 1 .903 0 r
F
.51801 .26126 m .518 .26126 L .51801 .26128 L 1 .87 0 r
F
.518 .26126 m .49284 .26537 L .51801 .26128 L F
.51801 .26128 m .51798 .26129 L .51797 .2613 L F
.51865 .26865 m .49308 .27316 L .49329 .28097 L 1 .859 0 r
F
.51868 .2686 m .49308 .27316 L .51865 .26865 L F
.51926 .27605 m .49329 .28097 L .49346 .28877 L 1 .847 0 r
F
.51927 .27603 m .49329 .28097 L .51926 .27605 L F
.51929 .27599 m .49329 .28097 L .51931 .27602 L F
.51941 .27577 m .51878 .26857 L .51929 .27599 L 1 .885 0 r
F
.52 .28337 m .51947 .27655 L .51935 .27662 L 1 .876 0 r
F
.51947 .27655 m .51942 .27595 L .51932 .27601 L F
.51983 .28342 m .51931 .27602 L .49346 .28877 L 1 .835 0 r
F
.51984 .28346 m .49346 .28877 L .49361 .29655 L F
.52 .28337 m .51983 .28342 L .51984 .28346 L 1 .876 0 r
F
.51999 .28339 m .51983 .28342 L .51984 .28346 L 1 .835 0 r
F
.51983 .28342 m .49346 .28877 L .51984 .28346 L F
.52051 .2908 m .52 .28337 L .51984 .28346 L 1 .866 0 r
F
.52031 .29093 m .49361 .29655 L .49373 .30425 L 1 .822 0 r
F
.52095 .29824 m .52051 .2908 L .52031 .29093 L 1 .856 0 r
F
.52069 .29841 m .49373 .30425 L .49382 .31187 L 1 .809 0 r
F
.52133 .30567 m .52095 .29824 L .52069 .29841 L 1 .845 0 r
F
.521 .30588 m .49382 .31187 L .49388 .31938 L 1 .796 0 r
F
.52164 .31307 m .52133 .30567 L .521 .30588 L 1 .835 0 r
F
.52122 .31333 m .49388 .31938 L .49393 .32674 L 1 .782 0 r
F
.52189 .32041 m .52164 .31307 L .52122 .31333 L 1 .824 0 r
F
.52137 .32074 m .49393 .32674 L .49396 .33393 L 1 .768 0 r
F
.52209 .32767 m .52189 .32041 L .52137 .32074 L 1 .814 0 r
F
.52144 .32808 m .49396 .33393 L .49398 .34095 L 1 .755 0 r
F
.52224 .33484 m .52209 .32767 L .52144 .32808 L 1 .804 0 r
F
.52224 .33484 m .52144 .32808 L .5214 .33515 L F
.52144 .33533 m .49398 .34095 L .49399 .34777 L 1 .741 0 r
F
.52234 .34189 m .52224 .33484 L .52144 .33533 L 1 .795 0 r
F
.52234 .34189 m .52144 .33533 L .52133 .34226 L F
.52136 .34246 m .49399 .34777 L .49399 .35439 L 1 .728 0 r
F
.52241 .34881 m .52234 .34189 L .52136 .34246 L 1 .786 0 r
F
.52241 .34881 m .52136 .34246 L .52119 .34923 L F
.52119 .34949 m .49399 .35439 L .49399 .36081 L 1 .716 0 r
F
.52123 .34947 m .52119 .34948 L .52119 .34949 L F
.52119 .34948 m .49399 .35439 L .52119 .34949 L F
.52119 .34923 m .52136 .34246 L .49399 .35439 L F
.52119 .34923 m .52136 .34246 L .52133 .34248 L 1 .786 0 r
F
.52119 .34923 m .49399 .35439 L .52123 .34947 L 1 .716 0 r
F
.52119 .34923 m .52133 .34248 L .49317 .35898 L 1 .786 0 r
F
.52244 .35557 m .52241 .34881 L .52123 .34947 L 1 .778 0 r
F
.52244 .35557 m .52123 .34947 L .52099 .35605 L F
.521 .35634 m .49399 .36081 L .49399 .36702 L 1 .704 0 r
F
.52103 .35633 m .521 .35634 L .521 .35634 L F
.521 .35634 m .49399 .36081 L .521 .35634 L F
.52099 .35605 m .52123 .34947 L .49399 .36081 L F
.52099 .35605 m .52123 .34947 L .5208 .34971 L 1 .778 0 r
F
.52099 .35605 m .49399 .36081 L .52103 .35633 L 1 .704 0 r
F
.52099 .35605 m .5208 .34971 L .49315 .3653 L 1 .778 0 r
F
.52245 .36217 m .52244 .35557 L .52103 .35633 L 1 .771 0 r
F
.52245 .36217 m .52103 .35633 L .52074 .36271 L F
.52077 .36303 m .49399 .36702 L .49399 .37304 L 1 .693 0 r
F
.52077 .36303 m .52077 .36303 L .52077 .36303 L F
.52077 .36303 m .49399 .36702 L .52077 .36303 L F
.52074 .36271 m .52103 .35633 L .49399 .36702 L F
.52074 .36271 m .52103 .35633 L .52028 .35674 L 1 .771 0 r
F
.52074 .36271 m .49399 .36702 L .52077 .36303 L 1 .693 0 r
F
.52074 .36271 m .52028 .35674 L .49312 .37138 L 1 .771 0 r
F
.52244 .3686 m .52245 .36217 L .52077 .36303 L 1 .765 0 r
F
.52244 .3686 m .52077 .36303 L .52045 .36919 L F
.52031 .36962 m .49399 .37304 L .49399 .37886 L 1 .683 0 r
F
.52031 .36958 m .49399 .37304 L .52031 .36962 L F
.52045 .36919 m .49399 .37304 L .52047 .36956 L F
.52045 .36919 m .52077 .36303 L .49399 .37304 L F
.51976 .36355 m .49312 .37138 L .49311 .37724 L 1 .771 0 r
F
.52077 .36303 m .51974 .36334 L .51976 .36355 L F
.51974 .36334 m .49312 .37138 L .51976 .36355 L F
.52047 .36956 m .52031 .36958 L .52031 .36962 L 1 .683 0 r
F
.52244 .3686 m .52045 .36919 L .52047 .36956 L 1 .765 0 r
F
.52242 .37486 m .52244 .3686 L .52047 .36956 L 1 .76 0 r
F
.52011 .37549 m .52047 .36956 L .49399 .37886 L 1 .674 0 r
F
.5197 .37605 m .49399 .37886 L .49399 .3845 L F
.5197 .37595 m .49399 .37886 L .5197 .37605 L F
.52011 .37549 m .49399 .37886 L .52013 .3759 L F
.52242 .37486 m .52011 .37549 L .52013 .37591 L 1 .76 0 r
F
.52239 .38093 m .52242 .37486 L .52013 .37591 L 1 .756 0 r
F
.51973 .3816 m .52013 .37591 L .49399 .3845 L 1 .665 0 r
F
.51912 .38227 m .49399 .3845 L .49399 .38996 L F
.51911 .38212 m .49399 .3845 L .51912 .38227 L F
.51973 .3816 m .49399 .3845 L .51975 .38206 L F
.52239 .38093 m .51973 .3816 L .51975 .38208 L 1 .756 0 r
F
.52236 .38683 m .52239 .38093 L .51975 .38208 L 1 .753 0 r
F
.52236 .38683 m .51975 .38208 L .52079 .3872 L F
.51856 .38828 m .49399 .38996 L .494 .39527 L 1 .658 0 r
F
.51855 .38812 m .49399 .38996 L .51856 .38828 L F
.51933 .38753 m .49399 .38996 L .51934 .38806 L F
.51933 .38753 m .51975 .38208 L .49399 .38996 L F
.5183 .3827 m .49309 .38834 L .49309 .39361 L 1 .756 0 r
F
.51975 .38208 m .51829 .38242 L .5183 .3827 L F
.51829 .38242 m .49309 .38834 L .5183 .3827 L F
.51934 .38806 m .51855 .38812 L .51856 .38828 L 1 .658 0 r
F
.52236 .38683 m .51933 .38753 L .51934 .38806 L 1 .753 0 r
F
.52233 .39256 m .52236 .38683 L .51934 .38806 L 1 .75 0 r
F
.5189 .39328 m .51934 .38806 L .494 .39527 L 1 .651 0 r
F
.51802 .39409 m .494 .39527 L .49401 .40042 L F
.51801 .39388 m .494 .39527 L .51802 .39409 L F
.5189 .39328 m .494 .39527 L .5189 .39383 L F
.52233 .39256 m .5189 .39328 L .5189 .39386 L 1 .75 0 r
F
.5223 .39812 m .52233 .39256 L .5189 .39386 L 1 .749 0 r
F
.5223 .39812 m .5189 .39386 L .51998 .39856 L F
.51749 .39971 m .49401 .40042 L .49403 .40543 L 1 .645 0 r
F
.51749 .39952 m .49401 .40042 L .51749 .39971 L F
.51844 .39885 m .49401 .40042 L .51843 .39949 L F
.51844 .39885 m .5189 .39386 L .49401 .40042 L F
.51738 .39443 m .49309 .39871 L .4931 .40365 L 1 .75 0 r
F
.5189 .39386 m .51738 .39414 L .51738 .39443 L F
.51738 .39414 m .49309 .39871 L .51738 .39443 L F
.51843 .39949 m .51749 .39952 L .51749 .39971 L 1 .645 0 r
F
.5223 .39812 m .51844 .39885 L .51843 .39949 L 1 .749 0 r
F
.52228 .40352 m .5223 .39812 L .51843 .39949 L 1 .748 0 r
F
.51797 .40425 m .51843 .39949 L .49403 .40543 L 1 .639 0 r
F
.51698 .40516 m .49403 .40543 L .49405 .41031 L F
.51698 .40493 m .49403 .40543 L .51698 .40516 L F
.51797 .40425 m .49403 .40543 L .51795 .40491 L F
.52228 .40352 m .51797 .40425 L .51795 .40494 L 1 .748 0 r
F
.52227 .40876 m .52228 .40352 L .51795 .40494 L 1 .747 0 r
F
.52227 .40876 m .51795 .40494 L .51898 .40926 L F
.51648 .41044 m .49405 .41031 L .49407 .41507 L 1 .634 0 r
F
.51648 .41024 m .49405 .41031 L .51648 .41044 L F
.51748 .40948 m .49405 .41031 L .51745 .41024 L F
.51748 .40948 m .51795 .40494 L .49405 .41031 L F
.49407 .41507 m .49405 .41031 L .46912 .41504 L 1 .749 0 r
F
.51649 .40543 m .49312 .40845 L .49314 .41312 L 1 .748 0 r
F
.51795 .40494 m .51649 .40515 L .51649 .40543 L F
.51649 .40515 m .49312 .40845 L .51649 .40543 L F
.51745 .41024 m .51648 .41024 L .51648 .41044 L 1 .634 0 r
F
.52227 .40876 m .51748 .40948 L .51745 .41024 L 1 .747 0 r
F
.52226 .41387 m .52227 .40876 L .51745 .41024 L 1 .748 0 r
F
.51697 .41456 m .51745 .41024 L .49407 .41507 L 1 .629 0 r
F
.51598 .41556 m .49407 .41507 L .49409 .41973 L F
.51598 .41533 m .49407 .41507 L .51598 .41556 L F
.51697 .41456 m .49407 .41507 L .51694 .41534 L F
.52226 .41387 m .51697 .41456 L .51693 .41538 L 1 .748 0 r
F
.52227 .41884 m .52226 .41387 L .51693 .41538 L F
.52227 .41884 m .51693 .41538 L .51783 .41934 L F
.51548 .42054 m .49409 .41973 L .49412 .42428 L 1 .624 0 r
F
.51549 .42036 m .49409 .41973 L .51548 .42054 L F
.51644 .4195 m .49409 .41973 L .5164 .42038 L F
.51644 .4195 m .51693 .41538 L .49409 .41973 L F
.49409 .41973 m .49407 .41507 L .46908 .41931 L 1 .745 0 r
F
.49409 .41973 m .46908 .41931 L .46904 .4235 L F
.49412 .42428 m .49409 .41973 L .46904 .4235 L 1 .74 0 r
F
.51559 .41577 m .49317 .41767 L .4932 .42212 L 1 .748 0 r
F
.51693 .41538 m .51559 .41551 L .51559 .41577 L F
.51559 .41551 m .49317 .41767 L .51559 .41577 L F
.5164 .42038 m .51549 .42036 L .51548 .42054 L 1 .624 0 r
F
.52227 .41884 m .51644 .4195 L .5164 .42038 L 1 .748 0 r
F
.52228 .42369 m .52227 .41884 L .5164 .42038 L 1 .749 0 r
F
.5159 .4243 m .5164 .42038 L .49412 .42428 L 1 .62 0 r
F
.51498 .42539 m .49412 .42428 L .49415 .42874 L F
.51499 .42517 m .49412 .42428 L .51498 .42539 L F
.5159 .4243 m .49412 .42428 L .51585 .4252 L F
.52228 .42369 m .5159 .4243 L .51585 .42525 L 1 .749 0 r
F
.52231 .42843 m .52228 .42369 L .51585 .42525 L 1 .75 0 r
F
.52231 .42843 m .51585 .42525 L .51658 .42888 L F
.51447 .43012 m .49415 .42874 L .49418 .43311 L 1 .615 0 r
F
.51447 .42995 m .49415 .42874 L .51447 .43012 L F
.51535 .42898 m .49415 .42874 L .51528 .43 L F
.51535 .42898 m .51585 .42525 L .49415 .42874 L F
.49415 .42874 m .49412 .42428 L .469 .42764 L 1 .736 0 r
F
.49415 .42874 m .469 .42764 L .46896 .43172 L F
.49418 .43311 m .49415 .42874 L .46896 .43172 L 1 .731 0 r
F
.51465 .42554 m .49324 .42647 L .49328 .43073 L 1 .749 0 r
F
.51585 .42525 m .51499 .42517 L .51498 .42539 L 1 .62 0 r
F
.51585 .42525 m .51466 .42532 L .51465 .42554 L 1 .749 0 r
F
.51466 .42532 m .49324 .42647 L .51465 .42554 L F
.51528 .43 m .51447 .42995 L .51447 .43012 L 1 .615 0 r
F
.52231 .42843 m .51535 .42898 L .51528 .43 L 1 .75 0 r
F
.52234 .43306 m .52231 .42843 L .51528 .43 L 1 .751 0 r
F
.51478 .43354 m .51528 .43 L .49418 .43311 L 1 .611 0 r
F
.51394 .43473 m .49418 .43311 L .49421 .4374 L F
.51395 .43452 m .49418 .43311 L .51394 .43473 L F
.51478 .43354 m .49418 .43311 L .51471 .43457 L F
.52234 .43306 m .51478 .43354 L .5147 .43463 L 1 .751 0 r
F
.52239 .4376 m .52234 .43306 L .5147 .43463 L 1 .752 0 r
F
.52239 .4376 m .5147 .43463 L .51526 .43794 L F
.5134 .43924 m .49421 .4374 L .49424 .44162 L 1 .607 0 r
F
.51341 .4391 m .49421 .4374 L .5134 .43924 L F
.51419 .438 m .49421 .4374 L .5141 .43916 L F
.51419 .438 m .5147 .43463 L .49421 .4374 L F
.49421 .4374 m .49418 .43311 L .46892 .43574 L 1 .726 0 r
F
.49421 .4374 m .46892 .43574 L .46888 .43972 L F
.49424 .44162 m .49421 .4374 L .46888 .43972 L 1 .72 0 r
F
.51367 .43484 m .49332 .43491 L .49336 .43901 L 1 .751 0 r
F
.5147 .43463 m .51395 .43452 L .51394 .43473 L 1 .611 0 r
F
.5147 .43463 m .51368 .43464 L .51367 .43484 L 1 .751 0 r
F
.51368 .43464 m .49332 .43491 L .51367 .43484 L F
.5141 .43916 m .51341 .4391 L .5134 .43924 L 1 .607 0 r
F
.52239 .4376 m .51419 .438 L .5141 .43916 L 1 .752 0 r
F
.52244 .44204 m .52239 .4376 L .5141 .43916 L 1 .754 0 r
F
.51359 .44235 m .5141 .43916 L .49424 .44162 L 1 .602 0 r
F
.51284 .44366 m .49424 .44162 L .49428 .44578 L F
.51286 .44346 m .49424 .44162 L .51284 .44366 L F
.51359 .44235 m .49424 .44162 L .51349 .44353 L F
.52244 .44204 m .51359 .44235 L .51348 .44359 L 1 .754 0 r
F
.52251 .44641 m .52244 .44204 L .51348 .44359 L 1 .755 0 r
F
.52251 .44641 m .51348 .44359 L .51386 .44659 L F
.51226 .44799 m .49428 .44578 L .49431 .44987 L 1 .598 0 r
F
.51227 .44786 m .49428 .44578 L .51226 .44799 L F
.51296 .44661 m .49428 .44578 L .51284 .44792 L F
.51296 .44661 m .51348 .44359 L .49428 .44578 L F
.49428 .44578 m .49424 .44162 L .46885 .44366 L 1 .714 0 r
F
.49428 .44578 m .46885 .44366 L .46881 .44755 L F
.49431 .44987 m .49428 .44578 L .46881 .44755 L 1 .709 0 r
F
.5126 .44374 m .49341 .44305 L .49346 .44703 L 1 .754 0 r
F
.51348 .44359 m .51286 .44346 L .51284 .44366 L 1 .602 0 r
F
.51348 .44359 m .51262 .44356 L .5126 .44374 L 1 .754 0 r
F
.51262 .44356 m .49341 .44305 L .5126 .44374 L F
.51284 .44792 m .51227 .44786 L .51226 .44799 L 1 .598 0 r
F
.52251 .44641 m .51296 .44661 L .51284 .44792 L 1 .755 0 r
F
.52258 .45071 m .52251 .44641 L .51284 .44792 L 1 .757 0 r
F
.51232 .45079 m .51284 .44792 L .49431 .44987 L 1 .593 0 r
F
.51166 .45223 m .49431 .44987 L .49434 .45391 L F
.51168 .45205 m .49431 .44987 L .51166 .45223 L F
.51232 .45079 m .49431 .44987 L .51218 .45212 L F
.52258 .45071 m .51232 .45079 L .51217 .45218 L 1 .757 0 r
F
.52266 .45493 m .52258 .45071 L .51217 .45218 L 1 .758 0 r
F
.52266 .45493 m .51217 .45218 L .5124 .45489 L F
.51103 .4564 m .49434 .45391 L .49438 .45789 L 1 .588 0 r
F
.51104 .4563 m .49434 .45391 L .51103 .4564 L F
.51166 .45489 m .49434 .45391 L .51149 .45636 L F
.51166 .45489 m .51217 .45218 L .49434 .45391 L F
.49434 .45391 m .49431 .44987 L .46877 .45141 L 1 .703 0 r
F
.49434 .45391 m .46877 .45141 L .46874 .45523 L F
.49438 .45789 m .49434 .45391 L .46874 .45523 L 1 .696 0 r
F
.51145 .45228 m .49351 .45095 L .49356 .45482 L 1 .757 0 r
F
.51217 .45218 m .51168 .45205 L .51166 .45223 L 1 .593 0 r
F
.51217 .45218 m .51146 .45213 L .51145 .45228 L 1 .757 0 r
F
.51146 .45213 m .49351 .45095 L .51145 .45228 L F
.51149 .45636 m .51104 .4563 L .51103 .4564 L 1 .588 0 r
F
.52266 .45493 m .51166 .45489 L .51149 .45636 L 1 .758 0 r
F
.52275 .4591 m .52266 .45493 L .51149 .45636 L 1 .76 0 r
F
.51097 .45892 m .51149 .45636 L .49438 .45789 L 1 .583 0 r
F
.51037 .4605 m .49438 .45789 L .49441 .46182 L F
.51039 .46034 m .49438 .45789 L .51037 .4605 L F
.51097 .45892 m .49438 .45789 L .51078 .46041 L F
.52275 .4591 m .51097 .45892 L .51077 .46047 L 1 .76 0 r
F
.52284 .46321 m .52275 .4591 L .51077 .46047 L 1 .761 0 r
F
.51025 .46287 m .51077 .46047 L .49441 .46182 L 1 .578 0 r
F
.50968 .46454 m .49441 .46182 L .49444 .46571 L F
.5097 .46439 m .49441 .46182 L .50968 .46454 L F
.51025 .46287 m .49441 .46182 L .51004 .46445 L F
.52284 .46321 m .51025 .46287 L .51003 .46451 L 1 .761 0 r
F
.52294 .46728 m .52284 .46321 L .51003 .46451 L 1 .762 0 r
F
.50951 .46677 m .51003 .46451 L .49444 .46571 L 1 .573 0 r
F
.50895 .46852 m .49444 .46571 L .49447 .46955 L F
.50897 .46838 m .49444 .46571 L .50895 .46852 L F
.50951 .46677 m .49444 .46571 L .50926 .46843 L F
.52294 .46728 m .50951 .46677 L .50925 .4685 L 1 .762 0 r
F
.52305 .4713 m .52294 .46728 L .50925 .4685 L 1 .764 0 r
F
.50874 .4706 m .50925 .4685 L .49447 .46955 L 1 .567 0 r
F
.50819 .47244 m .49447 .46955 L .49449 .47335 L F
.50821 .47231 m .49447 .46955 L .50819 .47244 L F
.50874 .4706 m .49447 .46955 L .50846 .47236 L F
.52305 .4713 m .50874 .4706 L .50845 .47243 L 1 .764 0 r
F
.52317 .47528 m .52305 .4713 L .50845 .47243 L 1 .765 0 r
F
.50794 .47439 m .50845 .47243 L .49449 .47335 L 1 .562 0 r
F
.50738 .47632 m .49449 .47335 L .49452 .47711 L F
.5074 .47619 m .49449 .47335 L .50738 .47632 L F
.50794 .47439 m .49449 .47335 L .50761 .47623 L F
.52317 .47528 m .50794 .47439 L .5076 .4763 L 1 .765 0 r
F
.52329 .47923 m .52317 .47528 L .5076 .4763 L 1 .767 0 r
F
.50711 .47811 m .5076 .4763 L .49452 .47711 L 1 .556 0 r
F
.50653 .48014 m .49452 .47711 L .49454 .48084 L F
.50656 .48002 m .49452 .47711 L .50653 .48014 L F
.50711 .47811 m .49452 .47711 L .50673 .48006 L F
.52329 .47923 m .5075 .47814 L .50672 .48013 L 1 .767 0 r
F
.5075 .47814 m .50711 .47811 L .50672 .48013 L F
.50607 .48178 m .50672 .48013 L .49454 .48084 L 1 .55 0 r
F
.52341 .48314 m .52329 .47923 L .50672 .48013 L 1 .768 0 r
F
.50623 .48179 m .50672 .48013 L .50607 .48178 L 1 .55 0 r
F
.49454 .48084 m .49452 .47711 L .46854 .47751 L 1 .656 0 r
F
.50623 .48179 m .50672 .48013 L .49395 .48083 L 1 .768 0 r
F
.52341 .48314 m .50672 .48013 L .50623 .48179 L F
.52161 .48305 m .50672 .48013 L .50623 .48179 L 1 .55 0 r
F
.52161 .48305 m .52161 .47927 L .50672 .48013 L F
.50711 .47811 m .50673 .48006 L .50696 .48012 L 1 .556 0 r
F
.50672 .48013 m .49389 .4772 L .49395 .48083 L 1 .767 0 r
F
.50696 .48012 m .50656 .48002 L .50653 .48014 L 1 .556 0 r
F
.50711 .47811 m .49389 .4772 L .50672 .48013 L 1 .767 0 r
F
.49452 .47711 m .49449 .47335 L .46857 .47386 L 1 .663 0 r
F
.49452 .47711 m .46857 .47386 L .46854 .47751 L F
.50723 .47633 m .49383 .47356 L .49389 .4772 L 1 .765 0 r
F
.5076 .4763 m .50725 .47623 L .50723 .47633 L F
.50725 .47623 m .49383 .47356 L .50723 .47633 L F
.52161 .47927 m .50711 .47811 L .50696 .48012 L 1 .556 0 r
F
.50711 .47811 m .5076 .4763 L .50723 .47633 L 1 .767 0 r
F
.50711 .47811 m .50723 .47633 L .49389 .4772 L F
.52329 .47923 m .5076 .4763 L .50711 .47811 L F
.52161 .47927 m .52161 .47544 L .5076 .4763 L 1 .556 0 r
F
.52161 .47927 m .5076 .4763 L .50711 .47811 L F
.50794 .47439 m .50761 .47623 L .50786 .47629 L 1 .562 0 r
F
.50786 .47629 m .5074 .47619 L .50738 .47632 L F
.50794 .47439 m .49383 .47356 L .5076 .4763 L 1 .765 0 r
F
.49449 .47335 m .49447 .46955 L .4686 .47019 L 1 .67 0 r
F
.49449 .47335 m .4686 .47019 L .46857 .47386 L F
.50803 .47246 m .49378 .46988 L .49383 .47356 L 1 .764 0 r
F
.50845 .47243 m .50804 .47236 L .50803 .47246 L F
.50804 .47236 m .49378 .46988 L .50803 .47246 L F
.52161 .47544 m .50794 .47439 L .50786 .47629 L 1 .562 0 r
F
.50794 .47439 m .50845 .47243 L .50803 .47246 L 1 .765 0 r
F
.50794 .47439 m .50803 .47246 L .49383 .47356 L F
.52317 .47528 m .50845 .47243 L .50794 .47439 L F
.52161 .47544 m .52161 .47156 L .50845 .47243 L 1 .562 0 r
F
.52161 .47544 m .50845 .47243 L .50794 .47439 L F
.50874 .4706 m .50846 .47236 L .50871 .47241 L 1 .567 0 r
F
.50871 .47241 m .50821 .47231 L .50819 .47244 L F
.50874 .4706 m .49378 .46988 L .50845 .47243 L 1 .764 0 r
F
.49447 .46955 m .49444 .46571 L .46864 .4665 L 1 .677 0 r
F
.49447 .46955 m .46864 .4665 L .4686 .47019 L F
.50878 .46854 m .49372 .46617 L .49378 .46988 L 1 .762 0 r
F
.50925 .4685 m .5088 .46843 L .50878 .46854 L F
.5088 .46843 m .49372 .46617 L .50878 .46854 L F
.52161 .47156 m .50874 .4706 L .50871 .47241 L 1 .567 0 r
F
.50874 .4706 m .50925 .4685 L .50878 .46854 L 1 .764 0 r
F
.50874 .4706 m .50878 .46854 L .49378 .46988 L F
.52305 .4713 m .50925 .4685 L .50874 .4706 L F
.52161 .47156 m .52161 .46762 L .50925 .4685 L 1 .567 0 r
F
.52161 .47156 m .50925 .4685 L .50874 .4706 L F
.50951 .46677 m .50926 .46843 L .50952 .46848 L 1 .573 0 r
F
.50952 .46848 m .50897 .46838 L .50895 .46852 L F
.50951 .46677 m .49372 .46617 L .50925 .4685 L 1 .762 0 r
F
.49444 .46571 m .49441 .46182 L .46867 .46277 L 1 .684 0 r
F
.49444 .46571 m .46867 .46277 L .46864 .4665 L F
.5095 .46457 m .49367 .46243 L .49372 .46617 L 1 .761 0 r
F
.51003 .46451 m .50951 .46445 L .5095 .46457 L F
.50951 .46445 m .49367 .46243 L .5095 .46457 L F
.52161 .46762 m .50951 .46677 L .50952 .46848 L 1 .573 0 r
F
.50951 .46677 m .51003 .46451 L .5095 .46457 L 1 .762 0 r
F
.50951 .46677 m .5095 .46457 L .49372 .46617 L F
.52294 .46728 m .51003 .46451 L .50951 .46677 L F
.52161 .46762 m .52161 .46363 L .51003 .46451 L 1 .573 0 r
F
.52161 .46762 m .51003 .46451 L .50951 .46677 L F
.51025 .46287 m .51004 .46445 L .5103 .46449 L 1 .578 0 r
F
.5103 .46449 m .5097 .46439 L .50968 .46454 L F
.51025 .46287 m .49367 .46243 L .51003 .46451 L 1 .761 0 r
F
.49441 .46182 m .49438 .45789 L .4687 .45902 L 1 .69 0 r
F
.49441 .46182 m .4687 .45902 L .46867 .46277 L F
.51018 .46054 m .49361 .45865 L .49367 .46243 L 1 .76 0 r
F
.51105 .46045 m .51039 .46034 L .51037 .4605 L 1 .583 0 r
F
.51077 .46047 m .5102 .46041 L .51018 .46054 L 1 .76 0 r
F
.5102 .46041 m .49361 .45865 L .51018 .46054 L F
.52161 .46363 m .51025 .46287 L .5103 .46449 L 1 .578 0 r
F
.51025 .46287 m .51077 .46047 L .51018 .46054 L 1 .761 0 r
F
.51025 .46287 m .51018 .46054 L .49367 .46243 L F
.52284 .46321 m .51077 .46047 L .51025 .46287 L F
.52161 .46363 m .52161 .45958 L .51077 .46047 L 1 .578 0 r
F
.52161 .46363 m .51077 .46047 L .51025 .46287 L F
.51097 .45892 m .51078 .46041 L .51105 .46045 L 1 .583 0 r
F
.51097 .45892 m .49361 .45865 L .51077 .46047 L 1 .76 0 r
F
.49438 .45789 m .46874 .45523 L .4687 .45902 L 1 .696 0 r
F
.51083 .45644 m .49356 .45482 L .49361 .45865 L 1 .758 0 r
F
.51106 .45641 m .51083 .45639 L .51083 .45644 L F
.51083 .45639 m .49356 .45482 L .51083 .45644 L F
.52161 .45958 m .51097 .45892 L .51105 .46045 L 1 .583 0 r
F
.51097 .45892 m .51149 .45636 L .51083 .45644 L 1 .76 0 r
F
.51097 .45892 m .51083 .45644 L .49361 .45865 L F
.52275 .4591 m .51149 .45636 L .51097 .45892 L F
.52161 .45958 m .52161 .45546 L .51149 .45636 L 1 .583 0 r
F
.52161 .45958 m .51149 .45636 L .51097 .45892 L F
.52161 .45546 m .51166 .45489 L .51149 .45636 L 1 .588 0 r
F
.51149 .45636 m .51166 .45489 L .51106 .45641 L 1 .758 0 r
F
.51166 .45489 m .49356 .45482 L .51106 .45641 L F
.52161 .45546 m .52162 .45127 L .51273 .45213 L 1 .588 0 r
F
.51265 .45234 m .51273 .45213 L .51217 .45218 L F
.52161 .45546 m .51273 .45213 L .51265 .45234 L F
.5124 .45489 m .51217 .45218 L .51166 .45489 L 1 .758 0 r
F
.52161 .45546 m .51217 .45218 L .51166 .45489 L 1 .588 0 r
F
.51166 .45489 m .51217 .45218 L .49356 .45482 L 1 .758 0 r
F
.51246 .45215 m .51217 .45212 L .51217 .45218 L 1 .593 0 r
F
.51217 .45212 m .51168 .45205 L .51217 .45218 L F
.51232 .45079 m .51218 .45212 L .51246 .45215 L F
.51232 .45079 m .49351 .45095 L .51217 .45218 L 1 .757 0 r
F
.49431 .44987 m .46881 .44755 L .46877 .45141 L 1 .709 0 r
F
.51204 .44805 m .49346 .44703 L .49351 .45095 L 1 .755 0 r
F
.51242 .44799 m .51205 .44797 L .51204 .44805 L F
.51205 .44797 m .49346 .44703 L .51204 .44805 L F
.52162 .45127 m .51232 .45079 L .51246 .45215 L 1 .593 0 r
F
.51232 .45079 m .51284 .44792 L .51204 .44805 L 1 .757 0 r
F
.51232 .45079 m .51204 .44805 L .49351 .45095 L F
.52258 .45071 m .51284 .44792 L .51232 .45079 L F
.52162 .45127 m .52163 .447 L .51284 .44792 L 1 .593 0 r
F
.52162 .45127 m .51284 .44792 L .51232 .45079 L F
.52163 .447 m .51296 .44661 L .51284 .44792 L 1 .598 0 r
F
.51284 .44792 m .51296 .44661 L .51242 .44799 L 1 .755 0 r
F
.51296 .44661 m .49346 .44703 L .51242 .44799 L F
.52163 .447 m .52164 .44265 L .51419 .4435 L 1 .598 0 r
F
.51406 .44383 m .51419 .4435 L .51348 .44359 L F
.52163 .447 m .51419 .4435 L .51406 .44383 L F
.51386 .44659 m .51348 .44359 L .51296 .44661 L 1 .755 0 r
F
.52163 .447 m .51348 .44359 L .51296 .44661 L 1 .598 0 r
F
.51296 .44661 m .51348 .44359 L .49346 .44703 L 1 .755 0 r
F
.51376 .44355 m .51347 .44352 L .51348 .44359 L 1 .602 0 r
F
.51347 .44352 m .51286 .44346 L .51348 .44359 L F
.51359 .44235 m .51349 .44353 L .51376 .44355 L F
.51359 .44235 m .49341 .44305 L .51348 .44359 L 1 .754 0 r
F
.49424 .44162 m .46888 .43972 L .46885 .44366 L 1 .72 0 r
F
.51314 .43934 m .49336 .43901 L .49341 .44305 L 1 .752 0 r
F
.5137 .43923 m .51315 .43923 L .51314 .43934 L F
.51315 .43923 m .49336 .43901 L .51314 .43934 L F
.52164 .44265 m .51359 .44235 L .51376 .44355 L 1 .602 0 r
F
.51359 .44235 m .5141 .43916 L .51314 .43934 L 1 .754 0 r
F
.51359 .44235 m .51314 .43934 L .49341 .44305 L F
.52244 .44204 m .5141 .43916 L .51359 .44235 L F
.52164 .44265 m .52165 .43822 L .5141 .43916 L 1 .602 0 r
F
.52164 .44265 m .5141 .43916 L .51359 .44235 L F
.52165 .43822 m .51419 .438 L .5141 .43916 L 1 .607 0 r
F
.5141 .43916 m .51419 .438 L .5137 .43923 L 1 .752 0 r
F
.51419 .438 m .49336 .43901 L .5137 .43923 L F
.52165 .43822 m .52167 .43369 L .51557 .43451 L 1 .607 0 r
F
.51539 .43498 m .51557 .43451 L .5147 .43463 L F
.52165 .43822 m .51557 .43451 L .51539 .43498 L F
.51526 .43794 m .5147 .43463 L .51419 .438 L 1 .752 0 r
F
.52165 .43822 m .5147 .43463 L .51419 .438 L 1 .607 0 r
F
.51419 .438 m .5147 .43463 L .49336 .43901 L 1 .752 0 r
F
.51497 .43459 m .51469 .43457 L .5147 .43463 L 1 .611 0 r
F
.51469 .43457 m .51395 .43452 L .5147 .43463 L F
.51478 .43354 m .51471 .43457 L .51497 .43459 L F
.51478 .43354 m .49332 .43491 L .5147 .43463 L 1 .751 0 r
F
.49418 .43311 m .46896 .43172 L .46892 .43574 L 1 .731 0 r
F
.51417 .43025 m .49328 .43073 L .49332 .43491 L 1 .75 0 r
F
.51491 .43008 m .51417 .4301 L .51417 .43025 L F
.51417 .4301 m .49328 .43073 L .51417 .43025 L F
.52167 .43369 m .51478 .43354 L .51497 .43459 L 1 .611 0 r
F
.51478 .43354 m .51528 .43 L .51417 .43025 L 1 .751 0 r
F
.51478 .43354 m .51417 .43025 L .49332 .43491 L F
.52234 .43306 m .51528 .43 L .51478 .43354 L F
.52167 .43369 m .5217 .42905 L .51528 .43 L 1 .611 0 r
F
.52167 .43369 m .51528 .43 L .51478 .43354 L F
.5217 .42905 m .51535 .42898 L .51528 .43 L 1 .615 0 r
F
.51528 .43 m .51535 .42898 L .51491 .43008 L 1 .75 0 r
F
.51535 .42898 m .49328 .43073 L .51491 .43008 L F
.5217 .42905 m .52173 .42431 L .51689 .42509 L 1 .615 0 r
F
.51662 .42576 m .51689 .42509 L .51585 .42525 L F
.5217 .42905 m .51689 .42509 L .51662 .42576 L F
.51658 .42888 m .51585 .42525 L .51535 .42898 L 1 .75 0 r
F
.5217 .42905 m .51585 .42525 L .51535 .42898 L 1 .615 0 r
F
.51535 .42898 m .51585 .42525 L .49328 .43073 L 1 .75 0 r
F
.5161 .42521 m .51584 .4252 L .51585 .42525 L 1 .62 0 r
F
.51584 .4252 m .51499 .42517 L .51585 .42525 L F
.5159 .4243 m .51585 .4252 L .5161 .42521 L F
.5159 .4243 m .49324 .42647 L .51585 .42525 L 1 .749 0 r
F
.49412 .42428 m .46904 .4235 L .469 .42764 L 1 .74 0 r
F
.51512 .42072 m .4932 .42212 L .49324 .42647 L 1 .748 0 r
F
.51607 .42047 m .51513 .42054 L .51512 .42072 L F
.51513 .42054 m .4932 .42212 L .51512 .42072 L F
.52173 .42431 m .5159 .4243 L .5161 .42521 L 1 .62 0 r
F
.5159 .4243 m .5164 .42038 L .51512 .42072 L 1 .749 0 r
F
.5159 .4243 m .51512 .42072 L .49324 .42647 L F
.52228 .42369 m .5164 .42038 L .5159 .4243 L F
.52173 .42431 m .52177 .41945 L .5164 .42038 L 1 .62 0 r
F
.52173 .42431 m .5164 .42038 L .5159 .4243 L F
.52177 .41945 m .51644 .4195 L .5164 .42038 L 1 .624 0 r
F
.5164 .42038 m .51644 .4195 L .51607 .42047 L 1 .748 0 r
F
.51644 .4195 m .4932 .42212 L .51607 .42047 L F
.52177 .41945 m .52182 .41445 L .51812 .41516 L 1 .624 0 r
F
.51776 .41608 m .51812 .41516 L .51693 .41538 L F
.52177 .41945 m .51812 .41516 L .51776 .41608 L F
.51783 .41934 m .51693 .41538 L .51644 .4195 L 1 .748 0 r
F
.52177 .41945 m .51693 .41538 L .51644 .4195 L 1 .624 0 r
F
.51644 .4195 m .51693 .41538 L .4932 .42212 L 1 .748 0 r
F
.51693 .41538 m .51598 .41533 L .51598 .41556 L 1 .629 0 r
F
.51715 .41534 m .51692 .41534 L .51693 .41538 L F
.51692 .41534 m .51598 .41533 L .51693 .41538 L F
.51697 .41456 m .51694 .41534 L .51715 .41534 L F
.51697 .41456 m .49317 .41767 L .51693 .41538 L 1 .748 0 r
F
.49407 .41507 m .46912 .41504 L .46908 .41931 L 1 .749 0 r
F
.51604 .41067 m .49314 .41312 L .49317 .41767 L 1 .747 0 r
F
.51717 .41032 m .51604 .41046 L .51604 .41067 L F
.51604 .41046 m .49314 .41312 L .51604 .41067 L F
.52182 .41445 m .51697 .41456 L .51715 .41534 L 1 .629 0 r
F
.51697 .41456 m .51745 .41024 L .51604 .41067 L 1 .748 0 r
F
.51697 .41456 m .51604 .41067 L .49317 .41767 L F
.52226 .41387 m .51745 .41024 L .51697 .41456 L F
.52182 .41445 m .52187 .40932 L .51745 .41024 L 1 .629 0 r
F
.52182 .41445 m .51745 .41024 L .51697 .41456 L F
.52187 .40932 m .51748 .40948 L .51745 .41024 L 1 .634 0 r
F
.51745 .41024 m .51748 .40948 L .51717 .41032 L 1 .747 0 r
F
.51748 .40948 m .49314 .41312 L .51717 .41032 L F
.52187 .40932 m .52193 .40405 L .51923 .40466 L 1 .634 0 r
F
.51879 .40587 m .51923 .40466 L .51795 .40494 L F
.52187 .40932 m .51923 .40466 L .51879 .40587 L F
.51898 .40926 m .51795 .40494 L .51748 .40948 L 1 .747 0 r
F
.52187 .40932 m .51795 .40494 L .51748 .40948 L 1 .634 0 r
F
.51748 .40948 m .51795 .40494 L .49314 .41312 L 1 .747 0 r
F
.51795 .40494 m .51698 .40493 L .51698 .40516 L 1 .639 0 r
F
.51813 .4049 m .51794 .40491 L .51795 .40494 L F
.51794 .40491 m .51698 .40493 L .51795 .40494 L F
.51797 .40425 m .51795 .40491 L .51813 .4049 L F
.51797 .40425 m .49312 .40845 L .51795 .40494 L 1 .748 0 r
F
.51693 .40002 m .4931 .40365 L .49312 .40845 L 1 .749 0 r
F
.51821 .39956 m .51693 .39977 L .51693 .40002 L F
.51693 .39977 m .4931 .40365 L .51693 .40002 L F
.52193 .40405 m .51797 .40425 L .51813 .4049 L 1 .639 0 r
F
.51797 .40425 m .51843 .39949 L .51693 .40002 L 1 .748 0 r
F
.51797 .40425 m .51693 .40002 L .49312 .40845 L F
.52228 .40352 m .51843 .39949 L .51797 .40425 L F
.52193 .40405 m .52199 .39862 L .51843 .39949 L 1 .639 0 r
F
.52193 .40405 m .51843 .39949 L .51797 .40425 L F
.52199 .39862 m .51844 .39885 L .51843 .39949 L 1 .645 0 r
F
.51843 .39949 m .51844 .39885 L .51821 .39956 L 1 .749 0 r
F
.51844 .39885 m .4931 .40365 L .51821 .39956 L F
.52199 .39862 m .52206 .39303 L .52016 .39353 L 1 .645 0 r
F
.51967 .39505 m .52016 .39353 L .5189 .39386 L F
.52199 .39862 m .52016 .39353 L .51967 .39505 L F
.51998 .39856 m .5189 .39386 L .51844 .39885 L 1 .749 0 r
F
.52199 .39862 m .5189 .39386 L .51844 .39885 L 1 .645 0 r
F
.51844 .39885 m .5189 .39386 L .4931 .40365 L 1 .749 0 r
F
.5189 .39386 m .51801 .39388 L .51802 .39409 L 1 .651 0 r
F
.51902 .39383 m .51889 .39383 L .5189 .39386 L F
.51889 .39383 m .51801 .39388 L .5189 .39386 L F
.5189 .39328 m .5189 .39383 L .51902 .39383 L F
.5189 .39328 m .49309 .39871 L .5189 .39386 L 1 .75 0 r
F
.51784 .38867 m .49309 .39361 L .49309 .39871 L 1 .753 0 r
F
.51918 .38812 m .51783 .38841 L .51784 .38867 L F
.51783 .38841 m .49309 .39361 L .51784 .38867 L F
.52206 .39303 m .5189 .39328 L .51902 .39383 L 1 .651 0 r
F
.5189 .39328 m .51934 .38806 L .51784 .38867 L 1 .75 0 r
F
.5189 .39328 m .51784 .38867 L .49309 .39871 L F
.52233 .39256 m .51934 .38806 L .5189 .39328 L F
.52206 .39303 m .52212 .38727 L .51934 .38806 L 1 .651 0 r
F
.52206 .39303 m .51934 .38806 L .5189 .39328 L F
.52212 .38727 m .51933 .38753 L .51934 .38806 L 1 .658 0 r
F
.51934 .38806 m .51933 .38753 L .51918 .38812 L 1 .753 0 r
F
.51933 .38753 m .49309 .39361 L .51918 .38812 L F
.52212 .38727 m .52219 .38133 L .52082 .38175 L 1 .658 0 r
F
.52038 .38346 m .52082 .38175 L .51975 .38208 L F
.52212 .38727 m .52082 .38175 L .52038 .38346 L F
.52079 .3872 m .51975 .38208 L .51933 .38753 L 1 .753 0 r
F
.52212 .38727 m .51975 .38208 L .51933 .38753 L 1 .658 0 r
F
.51933 .38753 m .51975 .38208 L .49309 .39361 L 1 .753 0 r
F
.51975 .38208 m .51911 .38212 L .51912 .38227 L 1 .665 0 r
F
.51982 .38205 m .51974 .38206 L .51975 .38208 L F
.51974 .38206 m .51911 .38212 L .51975 .38208 L F
.51973 .3816 m .51975 .38206 L .51982 .38205 L F
.51973 .3816 m .49309 .38834 L .51975 .38208 L 1 .756 0 r
F
.51878 .37653 m .49309 .38289 L .49309 .38834 L 1 .76 0 r
F
.52013 .37591 m .51876 .37626 L .51878 .37653 L F
.51876 .37626 m .49309 .38289 L .51878 .37653 L F
.52219 .38133 m .51973 .3816 L .51982 .38205 L 1 .665 0 r
F
.51973 .3816 m .52013 .37591 L .51878 .37653 L 1 .756 0 r
F
.51973 .3816 m .51878 .37653 L .49309 .38834 L F
.52239 .38093 m .52013 .37591 L .51973 .3816 L F
.52219 .38133 m .52225 .37521 L .52013 .37591 L 1 .665 0 r
F
.52219 .38133 m .52013 .37591 L .51973 .3816 L F
.52011 .37549 m .52013 .3759 L .52017 .3759 L 1 .674 0 r
F
.52017 .3759 m .5197 .37595 L .5197 .37605 L F
.52011 .37549 m .49309 .38289 L .52013 .37591 L 1 .76 0 r
F
.51926 .37015 m .49311 .37724 L .49309 .38289 L 1 .765 0 r
F
.5204 .36959 m .51925 .36992 L .51926 .37015 L F
.51925 .36992 m .49311 .37724 L .51926 .37015 L F
.52225 .37521 m .52011 .37549 L .52017 .3759 L 1 .674 0 r
F
.52011 .37549 m .52047 .36956 L .51926 .37015 L 1 .76 0 r
F
.52011 .37549 m .51926 .37015 L .49309 .38289 L F
.52242 .37486 m .52047 .36956 L .52011 .37549 L F
.52225 .37521 m .52229 .36892 L .52047 .36956 L 1 .674 0 r
F
.52225 .37521 m .52047 .36956 L .52011 .37549 L F
.52229 .36892 m .52045 .36919 L .52047 .36956 L 1 .683 0 r
F
.52047 .36956 m .52045 .36919 L .5204 .36959 L 1 .765 0 r
F
.52045 .36919 m .49311 .37724 L .5204 .36959 L F
.52229 .36892 m .52233 .36245 L .52111 .36291 L 1 .683 0 r
F
.521 .36392 m .52111 .36291 L .52077 .36303 L F
.52229 .36892 m .52111 .36291 L .521 .36392 L F
.52229 .36892 m .52077 .36303 L .52045 .36919 L F
.52045 .36919 m .52077 .36303 L .49311 .37724 L 1 .765 0 r
F
.52245 .36217 m .52074 .36271 L .52077 .36303 L 1 .771 0 r
F
.52074 .36271 m .49312 .37138 L .52077 .36303 L F
.52233 .36245 m .52074 .36271 L .52077 .36303 L 1 .693 0 r
F
.52233 .36245 m .52234 .35581 L .52103 .35633 L F
.52233 .36245 m .52103 .35633 L .52074 .36271 L F
.52103 .35633 m .49315 .3653 L .49312 .37138 L 1 .778 0 r
F
.52244 .35557 m .52099 .35605 L .52103 .35633 L F
.52099 .35605 m .49315 .3653 L .52103 .35633 L F
.52234 .35581 m .52099 .35605 L .52103 .35633 L 1 .704 0 r
F
.52234 .35581 m .52233 .34901 L .52123 .34947 L F
.52234 .35581 m .52123 .34947 L .52099 .35605 L F
.52123 .34947 m .49317 .35898 L .49315 .3653 L 1 .786 0 r
F
.52241 .34881 m .52119 .34923 L .52123 .34947 L F
.52119 .34923 m .49317 .35898 L .52123 .34947 L F
.52233 .34901 m .52119 .34923 L .52123 .34947 L 1 .716 0 r
F
.52233 .34901 m .52228 .34207 L .52136 .34246 L F
.52233 .34901 m .52136 .34246 L .52119 .34923 L F
.52136 .34246 m .4932 .35242 L .49317 .35898 L 1 .795 0 r
F
.52234 .34189 m .52133 .34226 L .52136 .34246 L F
.52133 .34226 m .49399 .34777 L .52136 .34246 L 1 .728 0 r
F
.52133 .34226 m .4932 .35242 L .52136 .34246 L 1 .795 0 r
F
.52228 .34207 m .52133 .34226 L .52136 .34246 L 1 .728 0 r
F
.52228 .34207 m .52219 .33499 L .52144 .33533 L F
.52133 .34226 m .52144 .33533 L .49399 .34777 L F
.52228 .34207 m .52144 .33533 L .52133 .34226 L F
.52133 .34226 m .52144 .33533 L .4932 .35242 L 1 .795 0 r
F
.52144 .33533 m .49323 .34562 L .4932 .35242 L 1 .804 0 r
F
.52224 .33484 m .5214 .33515 L .52144 .33533 L F
.5214 .33515 m .49398 .34095 L .52144 .33533 L 1 .741 0 r
F
.5214 .33515 m .49323 .34562 L .52144 .33533 L 1 .804 0 r
F
.52219 .33499 m .5214 .33515 L .52144 .33533 L 1 .741 0 r
F
.52219 .33499 m .52205 .32779 L .52144 .32808 L F
.5214 .33515 m .52144 .32808 L .49398 .34095 L F
.52219 .33499 m .52144 .32808 L .5214 .33515 L F
.5214 .33515 m .52144 .32808 L .49323 .34562 L 1 .804 0 r
F
.52144 .32808 m .49325 .33858 L .49323 .34562 L 1 .814 0 r
F
.52209 .32767 m .52141 .32793 L .52144 .32808 L F
.52141 .32793 m .49396 .33393 L .52144 .32808 L 1 .755 0 r
F
.52141 .32793 m .49325 .33858 L .52144 .32808 L 1 .814 0 r
F
.52205 .32779 m .52141 .32793 L .52144 .32808 L 1 .755 0 r
F
.52205 .32779 m .52186 .3205 L .52137 .32074 L F
.52141 .32793 m .52137 .32074 L .49396 .33393 L F
.52209 .32767 m .52137 .32074 L .52141 .32793 L 1 .814 0 r
F
.52205 .32779 m .52137 .32074 L .52141 .32793 L 1 .755 0 r
F
.52141 .32793 m .52137 .32074 L .49325 .33858 L 1 .814 0 r
F
.52137 .32074 m .49326 .33132 L .49325 .33858 L 1 .824 0 r
F
.52189 .32041 m .52134 .32062 L .52137 .32074 L F
.52134 .32062 m .49393 .32674 L .52137 .32074 L 1 .768 0 r
F
.52134 .32062 m .49326 .33132 L .52137 .32074 L 1 .824 0 r
F
.52186 .3205 m .52134 .32062 L .52137 .32074 L 1 .768 0 r
F
.52186 .3205 m .52162 .31314 L .52122 .31333 L F
.52134 .32062 m .52122 .31333 L .49393 .32674 L F
.52189 .32041 m .52122 .31333 L .52134 .32062 L 1 .824 0 r
F
.52186 .3205 m .52122 .31333 L .52134 .32062 L 1 .768 0 r
F
.52134 .32062 m .52122 .31333 L .49326 .33132 L 1 .824 0 r
F
.52122 .31333 m .49326 .32384 L .49326 .33132 L 1 .835 0 r
F
.52164 .31307 m .52119 .31324 L .52122 .31333 L F
.52119 .31324 m .49388 .31938 L .52122 .31333 L 1 .782 0 r
F
.52119 .31324 m .49326 .32384 L .52122 .31333 L 1 .835 0 r
F
.52162 .31314 m .52119 .31324 L .52122 .31333 L 1 .782 0 r
F
.52162 .31314 m .52131 .30573 L .521 .30588 L F
.52119 .31324 m .521 .30588 L .49388 .31938 L F
.52164 .31307 m .521 .30588 L .52119 .31324 L 1 .835 0 r
F
.52162 .31314 m .521 .30588 L .52119 .31324 L 1 .782 0 r
F
.52119 .31324 m .521 .30588 L .49326 .32384 L 1 .835 0 r
F
.521 .30588 m .49325 .31617 L .49326 .32384 L 1 .845 0 r
F
.52133 .30567 m .52097 .30581 L .521 .30588 L F
.52097 .30581 m .49382 .31187 L .521 .30588 L 1 .796 0 r
F
.52097 .30581 m .49325 .31617 L .521 .30588 L 1 .845 0 r
F
.52131 .30573 m .52097 .30581 L .521 .30588 L 1 .796 0 r
F
.52131 .30573 m .52094 .29829 L .52069 .29841 L F
.52097 .30581 m .52069 .29841 L .49382 .31187 L F
.52133 .30567 m .52069 .29841 L .52097 .30581 L 1 .845 0 r
F
.52131 .30573 m .52069 .29841 L .52097 .30581 L 1 .796 0 r
F
.52097 .30581 m .52069 .29841 L .49325 .31617 L 1 .845 0 r
F
.52069 .29841 m .49321 .30834 L .49325 .31617 L 1 .856 0 r
F
.52095 .29824 m .52067 .29835 L .52069 .29841 L F
.52067 .29835 m .49373 .30425 L .52069 .29841 L 1 .809 0 r
F
.52067 .29835 m .49321 .30834 L .52069 .29841 L 1 .856 0 r
F
.52094 .29829 m .52067 .29835 L .52069 .29841 L 1 .809 0 r
F
.52094 .29829 m .5205 .29083 L .52031 .29093 L F
.52067 .29835 m .52031 .29093 L .49373 .30425 L F
.52095 .29824 m .52031 .29093 L .52067 .29835 L 1 .856 0 r
F
.52094 .29829 m .52031 .29093 L .52067 .29835 L 1 .809 0 r
F
.52067 .29835 m .52031 .29093 L .49321 .30834 L 1 .856 0 r
F
.52031 .29093 m .49315 .30039 L .49321 .30834 L 1 .866 0 r
F
.52051 .2908 m .52029 .29088 L .52031 .29093 L F
.52029 .29088 m .49361 .29655 L .52031 .29093 L 1 .822 0 r
F
.52029 .29088 m .49315 .30039 L .52031 .29093 L 1 .866 0 r
F
.5205 .29083 m .52029 .29088 L .52031 .29093 L 1 .822 0 r
F
.5205 .29083 m .51999 .28339 L .51984 .28346 L F
.52029 .29088 m .51984 .28346 L .49361 .29655 L F
.52051 .2908 m .51984 .28346 L .52029 .29088 L 1 .866 0 r
F
.5205 .29083 m .51984 .28346 L .52029 .29088 L 1 .822 0 r
F
.52029 .29088 m .51984 .28346 L .49315 .30039 L 1 .866 0 r
F
.51984 .28346 m .49305 .29235 L .49315 .30039 L 1 .876 0 r
F
.51983 .28342 m .49305 .29235 L .51984 .28346 L F
.51947 .27655 m .51932 .27601 L .49305 .29235 L F
.51999 .28339 m .51942 .27597 L .51931 .27602 L 1 .835 0 r
F
.52 .28337 m .51935 .27662 L .51983 .28342 L 1 .876 0 r
F
.51999 .28339 m .51931 .27602 L .51983 .28342 L 1 .835 0 r
F
.51983 .28342 m .51935 .27662 L .49305 .29235 L 1 .876 0 r
F
.51929 .27599 m .51878 .26857 L .51869 .26863 L 1 .885 0 r
F
.51942 .27595 m .51941 .27577 L .51929 .27599 L F
.51942 .27597 m .51869 .26863 L .51928 .27585 L 1 .847 0 r
F
.51932 .27599 m .51928 .27585 L .51929 .27599 L F
.51942 .27597 m .51928 .27585 L .51932 .27599 L F
.51942 .27597 m .51878 .26859 L .51869 .26863 L F
.51929 .27599 m .51869 .26863 L .49329 .28097 L F
.51929 .27599 m .51869 .26863 L .49293 .28426 L 1 .885 0 r
F
.51931 .27602 m .51927 .27603 L .51926 .27605 L 1 .847 0 r
F
.51942 .27595 m .51929 .27599 L .51931 .27602 L 1 .885 0 r
F
.51942 .27597 m .51929 .27599 L .51931 .27602 L 1 .847 0 r
F
.51931 .27602 m .49293 .28426 L .49305 .29235 L 1 .885 0 r
F
.51929 .27599 m .49293 .28426 L .51931 .27602 L F
.51869 .26863 m .49277 .27616 L .49293 .28426 L 1 .895 0 r
F
.51878 .26857 m .51868 .2686 L .51869 .26863 L F
.51869 .26863 m .51868 .2686 L .51865 .26865 L 1 .859 0 r
F
.51868 .2686 m .49277 .27616 L .51869 .26863 L 1 .895 0 r
F
.51878 .26859 m .51868 .2686 L .51869 .26863 L 1 .859 0 r
F
.51878 .26857 m .51877 .26845 L .51868 .2686 L 1 .895 0 r
F
.51877 .26845 m .51801 .26128 L .51868 .2686 L F
.51878 .26857 m .51807 .26124 L .51801 .26128 L F
.51878 .26859 m .51807 .26125 L .49308 .27316 L 1 .859 0 r
F
.51868 .2686 m .51801 .26128 L .51535 .26957 L 1 .895 0 r
F
.51801 .26128 m .49257 .26807 L .49277 .27616 L 1 .903 0 r
F
.518 .26126 m .49257 .26807 L .51801 .26128 L F
.51806 .26116 m .5173 .25397 L .518 .26126 L F
.51807 .26125 m .5173 .25398 L .51725 .254 L 1 .87 0 r
F
.518 .26126 m .51725 .254 L .49284 .26537 L F
.518 .26126 m .5173 .25397 L .51725 .254 L 1 .903 0 r
F
.51807 .26124 m .51806 .26116 L .518 .26126 L F
.51807 .26125 m .51725 .254 L .518 .26126 L 1 .87 0 r
F
.518 .26126 m .51725 .254 L .49257 .26807 L 1 .903 0 r
F
.51807 .26125 m .51801 .26126 L .51801 .26128 L 1 .87 0 r
F
.51535 .26957 m .51801 .26128 L .49277 .27616 L 1 .895 0 r
F
.51725 .254 m .49234 .26003 L .49257 .26807 L 1 .912 0 r
F
.5173 .25397 m .51724 .25398 L .51725 .254 L F
.51725 .254 m .51724 .25398 L .51723 .25401 L 1 .881 0 r
F
.51724 .25398 m .49234 .26003 L .51725 .254 L 1 .912 0 r
F
.5173 .25398 m .51724 .25398 L .51725 .254 L 1 .881 0 r
F
.5173 .25397 m .51729 .25391 L .51724 .25398 L 1 .912 0 r
F
.51729 .25391 m .51643 .24678 L .51724 .25398 L F
.5173 .25397 m .51647 .24677 L .51643 .24678 L F
.5173 .25398 m .51647 .24677 L .49256 .25762 L 1 .881 0 r
F
.51724 .25398 m .51643 .24678 L .51364 .25486 L 1 .912 0 r
F
.51643 .24678 m .49206 .25206 L .49234 .26003 L 1 .92 0 r
F
.51643 .24677 m .49206 .25206 L .51643 .24678 L F
.51646 .24673 m .51558 .23963 L .51643 .24677 L F
.51647 .24677 m .51558 .23964 L .51555 .23965 L 1 .891 0 r
F
.51643 .24677 m .51555 .23965 L .49225 .24992 L F
.51643 .24677 m .51558 .23963 L .51555 .23965 L 1 .92 0 r
F
.51647 .24677 m .51646 .24673 L .51643 .24677 L F
.51647 .24677 m .51555 .23965 L .51643 .24677 L 1 .891 0 r
F
.51643 .24677 m .51555 .23965 L .49206 .25206 L 1 .92 0 r
F
.51647 .24677 m .51644 .24677 L .51643 .24678 L 1 .891 0 r
F
.51364 .25486 m .51643 .24678 L .49234 .26003 L 1 .912 0 r
F
.51555 .23965 m .49175 .24419 L .49206 .25206 L 1 .927 0 r
F
.51558 .23963 m .51555 .23964 L .51555 .23965 L F
.51555 .23965 m .51555 .23964 L .51553 .23965 L 1 .901 0 r
F
.51555 .23964 m .49175 .24419 L .51555 .23965 L 1 .927 0 r
F
.51558 .23964 m .51555 .23964 L .51555 .23965 L 1 .901 0 r
F
.51558 .23963 m .51557 .23961 L .51555 .23964 L 1 .927 0 r
F
.51557 .23961 m .51461 .23259 L .51555 .23964 L F
.51558 .23963 m .51463 .23258 L .51461 .23259 L F
.51558 .23964 m .51463 .23258 L .49191 .2423 L 1 .901 0 r
F
.51555 .23964 m .51461 .23259 L .5118 .24035 L 1 .927 0 r
F
.51461 .23259 m .4914 .23642 L .49175 .24419 L 1 .934 0 r
F
.51461 .23258 m .4914 .23642 L .51461 .23259 L F
.51463 .23256 m .51362 .22561 L .51461 .23258 L F
.51463 .23258 m .51362 .22561 L .51361 .22562 L 1 .911 0 r
F
.51461 .23258 m .51361 .22562 L .49154 .23476 L F
.51461 .23258 m .51362 .22561 L .51361 .22562 L 1 .934 0 r
F
.51463 .23258 m .51463 .23256 L .51461 .23258 L F
.51463 .23258 m .51361 .22562 L .51461 .23258 L 1 .911 0 r
F
.51461 .23258 m .51361 .22562 L .4914 .23642 L 1 .934 0 r
F
.51463 .23258 m .51461 .23258 L .51461 .23259 L 1 .911 0 r
F
.5118 .24035 m .51461 .23259 L .49175 .24419 L 1 .927 0 r
F
.51361 .22562 m .49102 .22876 L .4914 .23642 L 1 .941 0 r
F
.51362 .22561 m .51361 .22561 L .51361 .22562 L F
.51361 .22562 m .51361 .22561 L .5136 .22562 L 1 .92 0 r
F
.51361 .22561 m .49102 .22876 L .51361 .22562 L 1 .941 0 r
F
.51362 .22561 m .51361 .22561 L .51361 .22562 L 1 .92 0 r
F
.51362 .22561 m .51362 .2256 L .51361 .22561 L 1 .941 0 r
F
.51362 .2256 m .51256 .21873 L .51361 .22561 L F
.51362 .22561 m .51257 .21873 L .51256 .21873 L F
.51362 .22561 m .51257 .21873 L .49113 .22732 L 1 .92 0 r
F
.51361 .22561 m .51256 .21873 L .50986 .22613 L 1 .941 0 r
F
.51256 .21873 m .49061 .22123 L .49102 .22876 L 1 .948 0 r
F
.51256 .21873 m .49061 .22123 L .51256 .21873 L F
.51257 .21872 m .51147 .21193 L .51256 .21873 L F
.51257 .21873 m .51147 .21193 L .51146 .21193 L 1 .928 0 r
F
.51256 .21873 m .51146 .21193 L .4907 .21998 L F
.51256 .21873 m .51147 .21193 L .51146 .21193 L 1 .948 0 r
F
.51257 .21873 m .51257 .21872 L .51256 .21873 L F
.51257 .21873 m .51146 .21193 L .51256 .21873 L 1 .928 0 r
F
.51256 .21873 m .51146 .21193 L .49061 .22123 L 1 .948 0 r
F
.51257 .21873 m .51256 .21873 L .51256 .21873 L 1 .928 0 r
F
.50986 .22613 m .51256 .21873 L .49102 .22876 L 1 .941 0 r
F
.51146 .21193 m .49016 .21382 L .49061 .22123 L 1 .954 0 r
F
.51146 .21193 m .49016 .21382 L .51146 .21193 L F
.51031 .20523 m .48968 .20654 L .49016 .21382 L 1 .96 0 r
F
.51031 .20522 m .48968 .20654 L .51031 .20523 L F
.50912 .19861 m .48918 .1994 L .48968 .20654 L 1 .966 0 r
F
.50912 .19861 m .50912 .19861 L .50912 .19861 L F
.50912 .19861 m .48918 .1994 L .50912 .19861 L F
.50788 .19209 m .48865 .19239 L .48918 .1994 L 1 .972 0 r
F
.5066 .18566 m .48809 .18551 L .48865 .19239 L 1 .978 0 r
F
.50529 .17933 m .48751 .17876 L .48809 .18551 L 1 .983 0 r
F
.50393 .17309 m .48691 .17213 L .48751 .17876 L 1 .988 0 r
F
.50255 .16695 m .48629 .16564 L .48691 .17213 L 1 .993 0 r
F
.50113 .1609 m .48565 .15926 L .48629 .16564 L 1 .998 0 r
F
.49967 .15496 m .48499 .15301 L .48565 .15926 L 1 1 0 r
F
.49819 .1491 m .48432 .14688 L .48499 .15301 L F
.49668 .14335 m .48362 .14087 L .48432 .14688 L F
.49668 .14335 m .49514 .13769 L .48363 .14074 L F
.49668 .14335 m .49514 .13769 L .48383 .14082 L F
.48384 .14092 m .48383 .14082 L .48362 .14087 L F
.49668 .14335 m .48383 .14082 L .48384 .14092 L F
.48362 .14087 m .47225 .13039 L .47212 .13538 L .619 .62 0 r
F
.48362 .14087 m .48292 .13498 L .47225 .13039 L F
.48208 .12917 m .4725 .12617 L .47237 .13222 L 1 1 0 r
F
.4822 .12913 m .48206 .12909 L .48208 .12917 L F
.48208 .12917 m .48206 .12909 L .48208 .12917 L .671 .703 0 r
F
.48206 .12909 m .47252 .12055 L .48208 .12917 L F
.48206 .12909 m .4725 .12617 L .48208 .12917 L 1 1 0 r
F
.48219 .12921 m .48206 .12909 L .48208 .12917 L .671 .703 0 r
F
.48208 .1291 m .48118 .12358 L .48073 .12391 L 1 1 0 r
F
.48206 .12909 m .48073 .12391 L .47613 .12728 L F
.48208 .1291 m .48073 .12391 L .48206 .12909 L F
.4822 .12913 m .48199 .12803 L .48208 .1291 L F
.48199 .12803 m .48118 .12358 L .48208 .1291 L F
.48292 .13498 m .48219 .12921 L .48208 .12917 L .645 .662 0 r
F
.48292 .13498 m .48208 .12917 L .48249 .1346 L F
.48499 .15301 m .48432 .14688 L .47199 .14041 L .568 .536 0 r
F
.48432 .14688 m .48362 .14087 L .47212 .13538 L .594 .578 0 r
F
.48059 .19494 m .48219 .12921 L .47761 .20615 L .971 .424 0 r
F
.49514 .13769 m .48292 .13498 L .48362 .14087 L 1 1 0 r
F
.48304 .13495 m .48222 .12922 L .48292 .13498 L F
.49357 .13213 m .48223 .12922 L .48304 .13495 L F
.48223 .12922 m .48222 .12922 L .48304 .13495 L F
.49037 .12131 m .48719 .11917 L .48149 .12353 L .696 .779 0 r
F
.49037 .12131 m .48149 .12353 L .48149 .12353 L F
.48149 .12357 m .4815 .12354 L .48146 .1235 L .471 .193 0 r
F
.4815 .12354 m .48148 .12354 L .48148 .12355 L .696 .779 0 r
F
.49037 .12131 m .4815 .12353 L .4815 .12354 L F
.4815 .12354 m .48145 .12339 L .48146 .1235 L .52 .339 0 r
F
.4815 .12353 m .48148 .12354 L .4815 .12354 L .696 .779 0 r
F
.49357 .13213 m .49198 .12667 L .48223 .1292 L 1 1 0 r
F
.49357 .13213 m .48223 .1292 L .48223 .12922 L F
.49133 .16745 m .49077 .14754 L .48223 .1292 L .474 .098 0 r
F
.48222 .12922 m .48223 .1292 L .4822 .12913 L F
.48223 .1292 m .48191 .12697 L .48223 .1292 L .471 .193 0 r
F
.48193 .12702 m .48191 .12697 L .48223 .1292 L F
.48223 .1292 m .48191 .12697 L .4822 .12913 L F
.48222 .12922 m .4822 .12913 L .48219 .12921 L .474 .098 0 r
F
.48223 .1292 m .48146 .12355 L .48219 .12921 L 1 1 0 r
F
.49198 .12667 m .48587 .12486 L .48223 .1292 L F
.48587 .12486 m .48149 .12356 L .48223 .1292 L F
.49077 .14754 m .48194 .12704 L .48223 .1292 L .471 .193 0 r
F
.48194 .12704 m .48193 .12702 L .48223 .1292 L F
.48192 .12697 m .48146 .1235 L .48191 .12697 L F
.48273 .12887 m .4815 .12365 L .48192 .12697 L F
.4815 .12365 m .48146 .1235 L .48192 .12697 L F
.49198 .12667 m .49037 .12131 L .4815 .12354 L 1 1 0 r
F
.49198 .12667 m .4815 .12354 L .4815 .12355 L F
.49198 .12667 m .48148 .12355 L .48149 .12356 L F
.48719 .11917 m .48087 .11489 L .48145 .12338 L .696 .779 0 r
F
.48149 .12357 m .48146 .1235 L .48273 .12887 L .471 .193 0 r
F
.48719 .11917 m .48145 .12338 L .48146 .12355 L .696 .779 0 r
F
.48087 .11489 m .4808 .1149 L .48145 .12339 L F
.48146 .1235 m .48145 .12339 L .48135 .12345 L 1 1 0 r
F
.48145 .12339 m .48145 .12339 L .48146 .12355 L .696 .779 0 r
F
.48087 .11489 m .48145 .12339 L .48145 .12339 L F
.48137 .12352 m .47265 .11569 L .47252 .12055 L 1 .867 0 r
F
.48146 .1235 m .48136 .12346 L .48137 .12352 L 1 1 0 r
F
.48146 .12355 m .48135 .12345 L .48137 .12352 L 1 .867 0 r
F
.48135 .12345 m .47265 .11569 L .48137 .12352 L F
.48135 .12345 m .48079 .11484 L .47265 .11569 L F
.48146 .12355 m .48145 .12339 L .48135 .12345 L F
.48145 .12339 m .48079 .11484 L .48135 .12345 L F
.48135 .12345 m .48071 .11797 L .47996 .11818 L 1 1 0 r
F
.48135 .12345 m .47996 .11818 L .47264 .12027 L F
.48135 .12345 m .47996 .11818 L .48135 .12345 L F
.48145 .12339 m .48071 .11797 L .48135 .12345 L F
.48079 .11484 m .48001 .11007 L .47279 .11088 L .937 1 0 r
F
.48071 .11797 m .47277 .11451 L .47264 .12027 L 1 1 0 r
F
.48071 .11797 m .47995 .11256 L .47277 .11451 L F
.48087 .11489 m .48079 .11484 L .4808 .1149 L .696 .779 0 r
F
.49052 .11842 m .48884 .11369 L .48083 .11348 L .765 .886 0 r
F
.49052 .11842 m .48884 .11369 L .48083 .11348 L .766 .887 0 r
F
.49037 .12131 m .48873 .11605 L .48079 .11482 L .694 .777 0 r
F
.49037 .12131 m .48873 .11605 L .48079 .11484 L .696 .779 0 r
F
.48101 .11358 m .48083 .11348 L .48084 .1136 L .766 .887 0 r
F
.48884 .11369 m .48003 .10889 L .48083 .11348 L .767 .895 0 r
F
.48884 .11369 m .48003 .1089 L .48083 .11348 L .768 .896 0 r
F
.48873 .11605 m .48001 .11006 L .48079 .11482 L .717 .81 0 r
F
.48873 .11605 m .48001 .11007 L .48079 .11484 L .718 .811 0 r
F
.48833 .12437 m .47995 .11256 L .48071 .11797 L .593 .496 0 r
F
.48968 .1343 m .48833 .12437 L .48071 .11797 L .52 .339 0 r
F
.4808 .11809 m .47995 .11259 L .48071 .11801 L .596 .499 0 r
F
.48833 .12437 m .48039 .11321 L .4808 .11809 L F
.48039 .11321 m .47995 .11259 L .4808 .11809 L F
.48968 .1343 m .4808 .11814 L .48095 .11972 L .52 .339 0 r
F
.4808 .11814 m .48071 .11797 L .48091 .11947 L F
.4808 .11814 m .48091 .11947 L .48095 .11972 L F
.48148 .12344 m .48095 .11972 L .48145 .12339 L F
.48968 .1343 m .48095 .11972 L .48148 .12344 L F
.4815 .12355 m .4815 .12354 L .48148 .12355 L 1 1 0 r
F
.48149 .12356 m .48148 .12355 L .48146 .12355 L F
.48149 .12356 m .48146 .12355 L .48223 .1292 L F
.48222 .12922 m .48223 .1292 L .48222 .12922 L .474 .098 0 r
F
.48223 .12922 m .48223 .1292 L .48222 .12922 L 1 1 0 r
F
.49133 .16745 m .48223 .1292 L .48222 .12922 L .474 .098 0 r
F
.48222 .12922 m .48223 .1292 L .48219 .12921 L 1 1 0 r
F
.49077 .14754 m .48968 .1343 L .4815 .12354 L .471 .193 0 r
F
.49077 .14754 m .4815 .12354 L .48149 .12357 L F
.48968 .1343 m .48145 .12339 L .4815 .12354 L .52 .339 0 r
F
.48149 .12353 m .48149 .12353 L .48148 .12354 L .696 .779 0 r
F
.48148 .12355 m .48148 .12354 L .48146 .12355 L F
.49077 .14754 m .48149 .12357 L .48273 .12887 L .471 .193 0 r
F
.48222 .12922 m .48219 .12921 L .48292 .13498 L 1 1 0 r
F
.49133 .16745 m .48222 .12922 L .47962 .23448 L .474 .098 0 r
F
.48222 .12922 m .48219 .12921 L .47962 .23448 L F
.48222 .12922 m .48219 .12921 L .48219 .12921 L 1 1 0 r
F
.48542 .17673 m .49077 .14754 L .48051 .18444 L 1 .868 0 r
F
.49133 .16745 m .491 .15571 L .48542 .17673 L F
.491 .15571 m .49077 .14754 L .48542 .17673 L F
.47761 .20615 m .48219 .12921 L .47237 .13222 L .971 .424 0 r
F
.47962 .23448 m .48059 .19494 L .47761 .20615 L F
.48219 .12921 m .4822 .12913 L .48208 .12917 L F
.48219 .12921 m .48208 .12917 L .48208 .12917 L .645 .662 0 r
F
.48219 .12921 m .48208 .12917 L .47237 .13222 L .971 .424 0 r
F
.48219 .12921 m .48219 .12921 L .48208 .12917 L .645 .662 0 r
F
.48137 .12352 m .47264 .12027 L .4725 .12617 L 1 1 0 r
F
.48136 .12346 m .47264 .12027 L .48137 .12352 L F
.48219 .12921 m .48146 .12355 L .48137 .12352 L .671 .703 0 r
F
.4822 .12913 m .48137 .12352 L .48179 .12693 L 1 1 0 r
F
.48219 .12921 m .48137 .12352 L .48206 .12909 L .671 .703 0 r
F
.48179 .12693 m .48137 .12352 L .48118 .12358 L 1 1 0 r
F
.47613 .12728 m .48118 .12358 L .4725 .12617 L F
.47252 .1205 m .47265 .11565 L .46457 .11632 L .973 1 0 r
F
.46634 .11617 m .46561 .11152 L .46457 .11632 L .975 1 0 r
F
.47265 .11565 m .4685 .11322 L .46634 .11617 L F
.4685 .11322 m .46561 .11152 L .46634 .11617 L F
.47266 .11397 m .47279 .10937 L .46558 .10952 L .912 1 0 r
F
.47265 .11565 m .47279 .11084 L .46561 .11152 L .975 1 0 r
F
.46662 .11143 m .46667 .10675 L .46561 .11152 L .977 1 0 r
F
.47279 .11084 m .46877 .10815 L .46662 .11143 L F
.46877 .10815 m .46667 .10675 L .46662 .11143 L F
.47279 .11084 m .47292 .10607 L .46667 .10675 L F
.46989 .10644 m .46775 .10208 L .46667 .1068 L .984 1 0 r
F
.47292 .1061 m .47107 .10465 L .46989 .10644 L F
.4678 .10209 m .46773 .10199 L .46772 .10207 L .792 .844 0 r
F
.47107 .10465 m .4678 .10209 L .46989 .10644 L .984 1 0 r
F
.4678 .10209 m .46773 .10203 L .46778 .10214 L F
.4678 .10209 m .46778 .10214 L .46989 .10644 L F
.48001 .11007 m .47922 .10535 L .47292 .1061 L .936 1 0 r
F
.47279 .11088 m .47292 .1061 L .46667 .1068 L .981 1 0 r
F
.47292 .1061 m .47306 .10135 L .46783 .10202 L .984 1 0 r
F
.4678 .10209 m .46783 .10202 L .46773 .10199 L .792 .844 0 r
F
.4678 .10209 m .46783 .10202 L .46773 .10203 L .984 1 0 r
F
.47292 .1061 m .46783 .10202 L .4678 .10209 L F
.4678 .10209 m .46784 .10202 L .46783 .10202 L .792 .844 0 r
F
.47291 .10889 m .47305 .1034 L .46784 .10202 L F
.47291 .10889 m .46784 .10202 L .4678 .10209 L F
.47001 .11115 m .46667 .1068 L .46561 .11159 L .981 1 0 r
F
.47105 .10972 m .46667 .1068 L .47001 .11115 L F
.47265 .11569 m .47279 .11088 L .46561 .11159 L .979 1 0 r
F
.47291 .10889 m .4678 .10209 L .46673 .1115 L .792 .844 0 r
F
.4678 .10209 m .46772 .10207 L .46673 .1115 L F
.46775 .10208 m .46773 .10203 L .46772 .10207 L .984 1 0 r
F
.46775 .10208 m .46772 .10207 L .46667 .1068 L F
.47279 .11088 m .47105 .10972 L .47001 .11115 L .981 1 0 r
F
.47028 .1159 m .46561 .11159 L .46457 .1164 L .979 1 0 r
F
.47265 .11569 m .47115 .11482 L .47028 .1159 L F
.47115 .11482 m .46561 .11159 L .47028 .1159 L F
.47071 .12069 m .46457 .1164 L .46353 .12124 L .977 1 0 r
F
.47252 .12055 m .47135 .11994 L .47071 .12069 L F
.47135 .11994 m .46457 .1164 L .47071 .12069 L F
.47127 .12552 m .46353 .12124 L .46251 .12612 L F
.47239 .12545 m .47165 .1251 L .47127 .12552 L F
.47165 .1251 m .46353 .12124 L .47127 .12552 L F
.47194 .13041 m .46251 .12612 L .46149 .13103 L F
.47225 .13039 m .47204 .1303 L .47194 .13041 L F
.47204 .1303 m .46251 .12612 L .47194 .13041 L F
.46048 .13598 m .46149 .13103 L .45102 .13163 L 1 1 0 r
F
.46149 .13103 m .4529 .12682 L .45102 .13163 L F
.47199 .14041 m .46048 .13598 L .45947 .14098 L .978 1 0 r
F
.46188 .14487 m .46266 .13885 L .45432 .15385 L 1 .868 0 r
F
.46266 .13885 m .46244 .13906 L .45432 .15385 L F
.46268 .13862 m .4619 .13944 L .45432 .15385 L F
.46172 .13977 m .45582 .14397 L .45432 .15385 L 1 .95 0 r
F
.47199 .14041 m .47212 .13538 L .46048 .13598 L .978 1 0 r
F
.4721 .14474 m .47223 .1384 L .46188 .14487 L 1 1 0 r
F
.47223 .1384 m .4628 .13773 L .46188 .14487 L F
.46191 .14603 m .4627 .13958 L .45453 .15794 L 1 .715 0 r
F
.4627 .13958 m .46184 .14086 L .45453 .15794 L F
.46169 .14122 m .45591 .14708 L .45453 .15794 L 1 .84 0 r
F
.46184 .14086 m .45927 .14356 L .46169 .14122 L F
.45927 .14356 m .45591 .14708 L .46169 .14122 L F
.45432 .15385 m .45582 .14397 L .45574 .14635 L 0 0 0 r
F
.45694 .14581 m .45595 .14677 L .45591 .14708 L 1 .84 0 r
F
.46282 .13858 m .45591 .14708 L .46184 .14086 L F
.45453 .15794 m .45595 .14677 L .45483 .24236 L 0 0 0 r
F
.45429 .15591 m .45574 .14635 L .45344 .22247 L F
.45432 .15385 m .45574 .14635 L .45429 .15591 L F
.45862 .14188 m .45582 .14397 L .46172 .13977 L 1 .95 0 r
F
.4628 .13773 m .45582 .14397 L .4619 .13944 L F
.47212 .13538 m .46149 .13103 L .46048 .13598 L .977 1 0 r
F
.47212 .13538 m .47225 .13039 L .46149 .13103 L F
.4628 .13773 m .46375 .13083 L .45582 .14397 L 1 .95 0 r
F
.46375 .13083 m .45742 .13475 L .45646 .14028 L 1 1 0 r
F
.45613 .14346 m .45646 .14028 L .45582 .14397 L F
.46375 .13083 m .45646 .14028 L .45613 .14346 L F
.45357 .14811 m .44936 .11905 L .45063 .15118 L .567 .292 0 r
F
.45548 .14266 m .44936 .11905 L .45532 .16021 L F
.44936 .11905 m .44928 .11911 L .45344 .22247 L F
.46149 .13103 m .46251 .12612 L .4529 .12682 L 1 1 0 r
F
.45098 .12205 m .45203 .11418 L .44926 .11868 L .61 .367 0 r
F
.45742 .13475 m .45305 .11808 L .45098 .12205 L F
.45305 .11808 m .45203 .11418 L .45098 .12205 L F
.45657 .11377 m .45853 .10936 L .45167 .10729 L .824 .94 0 r
F
.45657 .11384 m .45853 .10942 L .45167 .10734 L .824 .939 0 r
F
.4567 .11709 m .45863 .11238 L .45176 .10911 L .772 .83 0 r
F
.45671 .11728 m .45864 .11253 L .45177 .10921 L .772 .826 0 r
F
.45761 .10909 m .45464 .10339 L .45167 .10729 L 1 1 0 r
F
.45798 .10853 m .45464 .10339 L .45761 .10909 L F
.45853 .10936 m .46047 .10378 L .45453 .10323 L F
.46047 .10378 m .45742 .09922 L .45453 .10323 L .907 1 0 r
F
.46047 .1038 m .45769 .09965 L .45473 .10329 L .909 1 0 r
F
.46558 .10952 m .46047 .1038 L .45853 .10942 L .82 .948 0 r
F
.45464 .10339 m .45453 .10323 L .45297 .10545 L 1 1 0 r
F
.45464 .10339 m .45297 .10545 L .45167 .10729 L F
.45743 .10908 m .45454 .10327 L .45167 .10734 L F
.45853 .10936 m .45798 .10853 L .45761 .10909 L F
.45853 .10942 m .45788 .10842 L .45743 .10908 L F
.45788 .10842 m .45454 .10327 L .45743 .10908 L F
.45853 .10942 m .46047 .1038 L .45454 .10327 L F
.4602 .105 m .45748 .10087 L .45461 .10497 L .965 1 0 r
F
.46036 .105 m .46028 .10488 L .4602 .105 L F
.46028 .10488 m .45748 .10087 L .4602 .105 L F
.4605 .105 m .46043 .1049 L .46036 .105 L F
.46043 .1049 m .45748 .10087 L .46036 .105 L F
.45473 .10329 m .45742 .09926 L .45454 .10327 L .909 1 0 r
F
.45769 .09965 m .45742 .09926 L .45473 .10329 L F
.45185 .10916 m .45461 .10497 L .45176 .10911 L 1 1 0 r
F
.45808 .11212 m .45472 .10517 L .45185 .10916 L F
.45828 .11174 m .45472 .10517 L .45808 .11212 L F
.46453 .11406 m .46558 .10952 L .45853 .10942 L .933 1 0 r
F
.46561 .11152 m .4605 .105 L .45863 .11238 L .797 .892 0 r
F
.46457 .11632 m .46561 .11152 L .46544 .11154 L 1 1 0 r
F
.46451 .11628 m .46544 .11154 L .45863 .11238 L F
.46457 .11632 m .46544 .11154 L .46451 .11628 L F
.46561 .11152 m .46667 .10675 L .4605 .105 L .797 .892 0 r
F
.46561 .11159 m .46667 .1068 L .46639 .10672 L .798 .891 0 r
F
.46547 .1114 m .46639 .10672 L .4605 .10504 L F
.46561 .11159 m .46639 .10672 L .46547 .1114 L F
.46561 .11159 m .4605 .10504 L .45864 .11253 L F
.45863 .11238 m .4605 .105 L .45461 .10497 L 1 1 0 r
F
.45472 .10517 m .45461 .10497 L .45185 .10916 L F
.45791 .11218 m .45462 .10506 L .45177 .10921 L F
.45863 .11238 m .45828 .11174 L .45808 .11212 L F
.45864 .11253 m .45818 .11167 L .45791 .11218 L F
.45818 .11167 m .45462 .10506 L .45791 .11218 L F
.45864 .11253 m .4605 .10504 L .45462 .10506 L F
.46022 .1078 m .45764 .10511 L .45482 .10967 L F
.46037 .10774 m .46029 .10766 L .46022 .1078 L F
.46029 .10766 m .45764 .10511 L .46022 .1078 L F
.46058 .10767 m .46046 .10757 L .46037 .10774 L F
.46046 .10757 m .45764 .10511 L .46037 .10774 L F
.4548 .10506 m .45748 .10095 L .45462 .10506 L .969 1 0 r
F
.4605 .10504 m .45762 .10114 L .4548 .10506 L F
.45762 .10114 m .45748 .10095 L .4548 .10506 L F
.46251 .12612 m .46353 .12124 L .4548 .12204 L 1 1 0 r
F
.46353 .12124 m .46457 .1164 L .45671 .11728 L F
.45222 .1145 m .45482 .10967 L .45203 .11418 L 1 .877 0 r
F
.45911 .12613 m .45491 .11002 L .45222 .1145 L F
.45491 .11002 m .45482 .10967 L .45222 .1145 L F
.46457 .1164 m .46561 .11159 L .45864 .11253 L 1 1 0 r
F
.45911 .12613 m .46058 .10767 L .45482 .10967 L 1 .877 0 r
F
.45497 .10993 m .45764 .10536 L .45484 .10998 L 1 1 0 r
F
.47252 .12055 m .47265 .11569 L .46457 .1164 L .977 1 0 r
F
.46571 .11773 m .46065 .10781 L .45911 .12613 L .734 .686 0 r
F
.46065 .10781 m .46058 .10767 L .46057 .10783 L F
.46065 .10781 m .46057 .10783 L .45911 .12613 L F
.46058 .10779 m .4577 .1054 L .45556 .10895 L 1 1 0 r
F
.46038 .10787 m .45556 .10895 L .45497 .10993 L F
.46058 .10779 m .45556 .10895 L .46038 .10787 L F
.4577 .1054 m .45764 .10536 L .45497 .10993 L F
.45742 .13475 m .45911 .12613 L .45203 .11418 L .61 .367 0 r
F
.45352 .11719 m .45484 .10998 L .45205 .11455 L 1 .867 0 r
F
.47225 .13039 m .47239 .12545 L .46251 .12612 L .977 1 0 r
F
.46472 .12417 m .45911 .12613 L .45837 .12991 L 1 1 0 r
F
.45788 .13408 m .45837 .12991 L .45742 .13475 L F
.46472 .12417 m .45837 .12991 L .45788 .13408 L F
.45876 .12661 m .45563 .11316 L .45352 .11719 L 1 .867 0 r
F
.45915 .12732 m .45883 .12602 L .45876 .12661 L F
.45883 .12602 m .45563 .11316 L .45876 .12661 L F
.45563 .11316 m .45484 .10998 L .45352 .11719 L F
.45582 .14397 m .45742 .13475 L .44926 .11868 L .567 .292 0 r
F
.45696 .13546 m .45205 .11455 L .44929 .1191 L .617 .355 0 r
F
.45749 .1366 m .45703 .13474 L .45696 .13546 L F
.45703 .13474 m .45205 .11455 L .45696 .13546 L F
.45595 .14677 m .45749 .1366 L .45729 .13617 L .576 .28 0 r
F
.45582 .14397 m .4556 .1474 L .45572 .14728 L .567 .292 0 r
F
.45582 .14397 m .45546 .14424 L .45546 .14514 L F
.45568 .1461 m .45546 .14514 L .45541 .15051 L F
.45582 .14397 m .45546 .14514 L .45568 .1461 L F
.45582 .14397 m .45548 .14266 L .45546 .14424 L F
.45578 .14609 m .45729 .13617 L .44929 .1191 L .576 .28 0 r
F
.45595 .14677 m .45729 .13617 L .45578 .14609 L F
.45532 .16021 m .45357 .14811 L .45344 .22247 L .567 .292 0 r
F
.45357 .14811 m .45063 .15118 L .45344 .22247 L F
.4557 .14573 m .45071 .15066 L .45076 .15178 L .576 .28 0 r
F
.45572 .14728 m .45541 .15051 L .45563 .15018 L .567 .292 0 r
F
.4556 .1474 m .45541 .15051 L .45572 .14728 L F
.45563 .15018 m .45541 .15051 L .45532 .16021 L F
.45568 .14702 m .45076 .15178 L .45483 .24236 L .576 .28 0 r
F
.4557 .14573 m .45076 .15178 L .45568 .14702 L F
.45595 .14677 m .4557 .14573 L .45568 .14702 L F
.45595 .14677 m .45568 .14702 L .45483 .24236 L F
.46282 .13858 m .45595 .14677 L .45694 .14581 L 1 .84 0 r
F
.4557 .14573 m .45531 .14413 L .45071 .15066 L .576 .28 0 r
F
.45531 .14413 m .44929 .1191 L .45056 .14736 L F
.45531 .14413 m .45056 .14736 L .45071 .15066 L F
.4619 .13944 m .45862 .14188 L .46172 .13977 L 1 .95 0 r
F
.4627 .13958 m .46282 .13858 L .46184 .14086 L 1 .715 0 r
F
.46266 .13885 m .46268 .13862 L .46244 .13906 L 1 .868 0 r
F
.46268 .13862 m .4628 .13773 L .4619 .13944 L F
.44936 .11905 m .44926 .11868 L .44928 .11911 L .567 .292 0 r
F
.44929 .1191 m .44629 .12082 L .44461 .12258 L .761 .264 0 r
F
.44925 .11913 m .44461 .12258 L .44278 .12451 L F
.44929 .1191 m .44461 .12258 L .44925 .11913 L F
.44629 .12082 m .44626 .12084 L .44278 .12451 L F
.45373 .23438 m .44272 .12456 L .43919 .12837 L 1 .659 0 r
F
.45403 .24633 m .45417 .26021 L .45407 .26205 L 0 0 0 r
F
.45417 .26021 m .43919 .12837 L .45512 .32146 L .38 .061 0 r
F
.43919 .12837 m .44184 .12551 L .43952 .14649 L .097 0 0 r
F
.43905 .14663 m .43952 .14649 L .43902 .151 L F
.43919 .12837 m .43952 .14649 L .43905 .14663 L F
.45376 .23404 m .44272 .12456 L .45373 .23438 L 1 .659 0 r
F
.45402 .2349 m .44272 .12456 L .45396 .23606 L F
.45466 .24076 m .44272 .12456 L .45465 .24104 L F
.45483 .24236 m .44929 .1191 L .44272 .12456 L F
.44365 .15746 m .44383 .15785 L .44365 .1576 L .165 .005 0 r
F
.44347 .15139 m .44383 .15785 L .44365 .15746 L F
.44626 .12084 m .44909 .17408 L .44442 .15968 L .21 .02 0 r
F
.44626 .12084 m .44442 .15968 L .44421 .15801 L F
.44626 .12084 m .44416 .15887 L .4439 .1568 L F
.44926 .11868 m .44914 .11871 L .44899 .11886 L .788 .459 0 r
F
.44929 .1191 m .45205 .11455 L .44626 .12084 L .761 .264 0 r
F
.44955 .11726 m .4498 .1172 L .44626 .12084 L .663 .206 0 r
F
.4498 .1172 m .44982 .11719 L .44974 .11728 L F
.4498 .1172 m .44974 .11728 L .44626 .12084 L F
.44894 .11341 m .45177 .10921 L .44544 .10919 L .961 1 0 r
F
.45116 .11499 m .44975 .11604 L .44617 .11961 L .707 .217 0 r
F
.45203 .11418 m .44975 .11604 L .45116 .11499 L F
.44543 .10899 m .44911 .10526 L .44854 .10543 L .797 .855 0 r
F
.44458 .10748 m .44854 .10543 L .44417 .10674 L F
.44543 .10899 m .44854 .10543 L .44458 .10748 L F
.45167 .10729 m .45297 .10545 L .44895 .10253 L .907 1 0 r
F
.45297 .10545 m .45453 .10323 L .45434 .1032 L F
.45297 .10545 m .45434 .1032 L .44895 .10253 L F
.45453 .10323 m .45742 .09922 L .45261 .0976 L .826 .971 0 r
F
.45454 .10327 m .45742 .09926 L .45686 .09907 L .827 .971 0 r
F
.45445 .10302 m .45686 .09907 L .45261 .09763 L F
.45454 .10327 m .45686 .09907 L .45445 .10302 L F
.45167 .10734 m .45454 .10327 L .44895 .1026 L .909 1 0 r
F
.44524 .1063 m .44895 .10253 L .44381 .10185 L .889 1 0 r
F
.44524 .10637 m .44895 .1026 L .44382 .10198 L .891 1 0 r
F
.45453 .10323 m .45261 .0976 L .44895 .10253 L .826 .971 0 r
F
.45454 .10327 m .45261 .09763 L .44895 .1026 L .827 .971 0 r
F
.45461 .10497 m .45267 .09885 L .44911 .10526 L .81 .929 0 r
F
.44895 .10253 m .44821 .09675 L .44381 .10185 L 1 1 0 r
F
.44895 .10253 m .45261 .0976 L .44821 .09675 L F
.44895 .1026 m .44822 .09681 L .44382 .10198 L F
.44895 .1026 m .45261 .09763 L .44822 .09681 L F
.44911 .10526 m .44833 .09871 L .44417 .10674 L F
.44911 .10526 m .45267 .09885 L .44833 .09871 L F
.44908 .10515 m .45268 .09892 L .44834 .09884 L F
.44912 .10545 m .44936 .10501 L .44908 .10515 L F
.44936 .10501 m .45268 .09892 L .44908 .10515 L F
.44544 .10919 m .44912 .10545 L .4442 .10719 L .768 .782 0 r
F
.44912 .10545 m .44834 .09884 L .4442 .10719 L 1 1 0 r
F
.44975 .11604 m .44871 .10477 L .44852 .11695 L F
.44871 .10477 m .44866 .10504 L .44852 .11695 L F
.45742 .09922 m .45637 .094 L .45261 .0976 L .984 1 0 r
F
.45742 .09926 m .45637 .09403 L .45261 .09763 L .986 1 0 r
F
.45261 .0976 m .45276 .09361 L .44843 .0966 L .855 1 0 r
F
.44872 .09685 m .44843 .0966 L .44821 .09675 L F
.45261 .0976 m .44843 .0966 L .44872 .09685 L F
.44381 .10185 m .44821 .09675 L .44487 .09607 L 1 1 0 r
F
.44426 .09615 m .44487 .09607 L .44427 .09595 L F
.44381 .10185 m .44487 .09607 L .44426 .09615 L F
.44381 .10185 m .44427 .09595 L .43902 .09871 L F
.43902 .09871 m .44427 .09595 L .44138 .09555 L .662 .859 0 r
F
.44073 .09575 m .44138 .09555 L .44088 .09548 L F
.43902 .09871 m .44138 .09555 L .44073 .09575 L F
.43902 .09871 m .44088 .09548 L .43498 .09739 L F
.43585 .09724 m .4409 .09568 L .43821 .09638 L .25 .181 0 r
F
.43404 .10413 m .43902 .09871 L .43498 .09739 L 1 1 0 r
F
.43499 .09756 m .43942 .09615 L .43585 .09724 L .25 .181 0 r
F
.43942 .09615 m .4409 .09568 L .43585 .09724 L F
.44031 .09667 m .44428 .09606 L .4409 .09568 L .644 .828 0 r
F
.43903 .0988 m .44404 .09618 L .44031 .09667 L F
.44404 .09618 m .44428 .09606 L .44031 .09667 L F
.44821 .09675 m .44945 .09178 L .44427 .09595 L .795 .961 0 r
F
.44821 .09675 m .45276 .09361 L .44945 .09178 L F
.44822 .09681 m .4483 .09648 L .44428 .09606 L F
.4483 .09648 m .44946 .09184 L .44609 .09458 L F
.4483 .09648 m .44609 .09458 L .44428 .09606 L F
.45261 .0976 m .45637 .094 L .45276 .09361 L .855 1 0 r
F
.45261 .09763 m .45277 .09367 L .44822 .09681 L .856 1 0 r
F
.45261 .09763 m .45637 .09403 L .45277 .09367 L F
.45267 .09885 m .45287 .09583 L .44853 .09858 L .814 .962 0 r
F
.4487 .09872 m .44853 .09858 L .44833 .09871 L F
.45267 .09885 m .44853 .09858 L .4487 .09872 L F
.44382 .10198 m .44822 .09681 L .44428 .09606 L 1 1 0 r
F
.44417 .10674 m .44833 .09871 L .44482 .09933 L F
.4445 .09959 m .44482 .09933 L .44451 .09938 L F
.44417 .10674 m .44482 .09933 L .4445 .09959 L F
.44382 .10198 m .44428 .09606 L .43903 .0988 L F
.44417 .10674 m .44451 .09938 L .43926 .10151 L F
.4442 .10719 m .44444 .10179 L .43928 .10176 L F
.44323 .10174 m .44426 .09979 L .43976 .10157 L F
.44444 .10179 m .43976 .10157 L .43928 .10176 L F
.44444 .10179 m .44453 .09968 L .44426 .09979 L F
.44444 .10179 m .44426 .09979 L .44323 .10174 L F
.44056 .10287 m .44453 .09968 L .44154 .10372 L .14 0 0 r
F
.43928 .10176 m .44428 .09978 L .44056 .10287 L F
.44428 .09978 m .44453 .09968 L .44056 .10287 L F
.43926 .10151 m .44451 .09938 L .44147 .10282 L .077 0 0 r
F
.4444 .0995 m .44685 .09458 L .44147 .10282 L .956 .905 0 r
F
.44451 .09938 m .44504 .09829 L .4444 .0995 L F
.44504 .09829 m .44685 .09458 L .4444 .0995 L F
.43973 .11002 m .4442 .10719 L .43928 .10176 L .689 .701 0 r
F
.43406 .10435 m .43903 .0988 L .43499 .09756 L 1 1 0 r
F
.43488 .11267 m .43926 .10151 L .43544 .10228 L F
.43529 .11314 m .43521 .11335 L .43288 .11399 L 0 0 0 r
F
.43521 .11335 m .43509 .11364 L .43288 .11399 L F
.43509 .11364 m .435 .11386 L .43479 .11387 L F
.43509 .11364 m .43479 .11387 L .43288 .11399 L F
.43347 .11395 m .435 .11386 L .43036 .11493 L F
.43042 .11236 m .43486 .10877 L .42887 .10724 L .883 1 0 r
F
.43525 .11273 m .43488 .11267 L .42965 .11409 L .444 .201 0 r
F
.43288 .11399 m .43347 .11395 L .42976 .11507 L 0 0 0 r
F
.43347 .11395 m .43036 .11493 L .42976 .11507 L F
.43088 .11648 m .43064 .11617 L .42889 .11668 L .615 .431 0 r
F
.43064 .11617 m .42976 .11507 L .42889 .11668 L F
.43555 .13087 m .43101 .11661 L .42664 .11982 L 1 .97 0 r
F
.43117 .1165 m .43128 .11618 L .43088 .11648 L .926 1 0 r
F
.43688 .11686 m .43156 .11621 L .43117 .1165 L F
.43156 .11621 m .43128 .11618 L .43117 .1165 L F
.43815 .11694 m .43128 .11618 L .43688 .11686 L F
.43206 .1348 m .43555 .13087 L .42645 .11958 L .643 .548 0 r
F
.4357 .13227 m .43815 .11694 L .43088 .11648 L 1 .953 0 r
F
.42645 .11958 m .42641 .11952 L .4263 .11957 L .81 .973 0 r
F
.4265 .11998 m .43088 .11648 L .42459 .11713 L .773 .898 0 r
F
.4357 .13227 m .43088 .11648 L .4265 .11998 L 1 .953 0 r
F
.43222 .13624 m .4357 .13227 L .4265 .11998 L .625 .509 0 r
F
.42976 .11507 m .435 .11386 L .43275 .13255 L .403 .041 0 r
F
.42965 .11409 m .43488 .11267 L .43209 .1266 L .371 .028 0 r
F
.43488 .11267 m .43543 .10245 L .43373 .11467 L 1 1 0 r
F
.43543 .10245 m .4354 .10259 L .43373 .11467 L F
.43488 .11267 m .43373 .11467 L .43462 .114 L F
.435 .11386 m .43511 .11356 L .43502 .11336 L F
.4368 .10876 m .43928 .10176 L .4355 .10285 L F
.44184 .12551 m .44272 .12456 L .44203 .12946 L .097 0 0 r
F
.44184 .12551 m .44203 .12946 L .43939 .14836 L F
.43931 .14838 m .43939 .14836 L .43902 .151 L F
.44184 .12551 m .43939 .14836 L .43931 .14838 L F
.44421 .15801 m .44442 .15968 L .44416 .15887 L .21 .02 0 r
F
.4439 .1568 m .44416 .15887 L .44383 .15785 L F
.44272 .12456 m .44383 .15785 L .44347 .15139 L .165 .005 0 r
F
.44203 .12946 m .44365 .1576 L .43902 .151 L F
.44272 .12456 m .44365 .1576 L .44203 .12946 L F
.44272 .12456 m .44626 .12084 L .44603 .12427 L F
.44288 .12801 m .44603 .12427 L .44409 .1539 L F
.44272 .12456 m .44603 .12427 L .44288 .12801 L F
.45205 .11455 m .4511 .11568 L .44955 .11726 L .663 .206 0 r
F
.45063 .11616 m .44982 .11719 L .44955 .11726 L F
.4511 .11568 m .44982 .11719 L .45063 .11616 L F
.44764 .11922 m .44617 .11961 L .4459 .121 L .788 .459 0 r
F
.44626 .12084 m .44982 .11719 L .44909 .17408 L .21 .02 0 r
F
.44617 .11961 m .44975 .11604 L .4497 .11728 L .194 .014 0 r
F
.449 .11998 m .4497 .11728 L .44959 .12006 L F
.44617 .11961 m .4497 .11728 L .449 .11998 L F
.44975 .11604 m .44852 .11695 L .4485 .11881 L 1 1 0 r
F
.44975 .11604 m .4485 .11881 L .4497 .11733 L F
.45176 .10911 m .45461 .10497 L .45443 .10498 L .96 1 0 r
F
.45172 .10905 m .45443 .10498 L .44911 .10526 L F
.45176 .10911 m .45443 .10498 L .45172 .10905 L F
.45461 .10497 m .45748 .10087 L .45267 .09885 L .81 .929 0 r
F
.45462 .10506 m .45748 .10095 L .4572 .10083 L .811 .928 0 r
F
.45454 .10481 m .4572 .10083 L .45268 .09892 L F
.45462 .10506 m .4572 .10083 L .45454 .10481 L F
.45177 .10921 m .45462 .10506 L .44912 .10545 L .964 1 0 r
F
.45203 .11418 m .45482 .10967 L .45467 .10986 L .707 .217 0 r
F
.45195 .11425 m .45467 .10986 L .44975 .11604 L F
.45203 .11418 m .45467 .10986 L .45195 .11425 L F
.45484 .10998 m .45764 .10536 L .45752 .10527 L .75 .76 0 r
F
.45462 .10506 m .45268 .09892 L .44912 .10545 L .811 .928 0 r
F
.45482 .10967 m .45281 .10162 L .44975 .11604 L .75 .766 0 r
F
.45482 .10967 m .45764 .10511 L .45281 .10162 L F
.45477 .10971 m .45752 .10527 L .45282 .10179 L .75 .76 0 r
F
.45484 .10998 m .45752 .10527 L .45477 .10971 L F
.44975 .11604 m .45281 .10162 L .44867 .10433 L 1 1 0 r
F
.45099 .11092 m .45282 .10179 L .44895 .10465 L F
.45012 .11567 m .45282 .10179 L .44979 .11692 L F
.45484 .10998 m .45282 .10179 L .44982 .11719 L .75 .76 0 r
F
.45268 .09892 m .45288 .09596 L .44834 .09884 L .808 .945 0 r
F
.45099 .11092 m .44895 .10465 L .4487 .10483 L 1 1 0 r
F
.45282 .10179 m .45324 .10338 L .4487 .10483 L 0 0 0 r
F
.45748 .10087 m .45642 .09528 L .45267 .09885 L 1 1 0 r
F
.45748 .10095 m .45642 .09534 L .45268 .09892 L F
.45553 .10359 m .45653 .09808 L .45281 .10162 L F
.45764 .10511 m .4566 .09854 L .45553 .10359 L F
.4566 .09854 m .45653 .09808 L .45553 .10359 L F
.46246 .09956 m .4603 .09444 L .45742 .09922 L .828 .981 0 r
F
.46047 .10378 m .46246 .09956 L .45742 .09922 L .907 1 0 r
F
.46246 .09958 m .4603 .09446 L .45742 .09926 L .828 .982 0 r
F
.46047 .1038 m .46246 .09958 L .45742 .09926 L .909 1 0 r
F
.46249 .10066 m .46032 .09527 L .45748 .10087 L .83 .967 0 r
F
.46634 .10627 m .46249 .10066 L .46625 .10663 L 1 1 0 r
F
.46366 .101 m .46449 .09637 L .46249 .1007 L F
.46764 .10201 m .4656 .09831 L .46366 .101 L F
.46764 .10201 m .46746 .10167 L .46736 .10206 L F
.46773 .10199 m .46766 .10191 L .46764 .10201 L F
.46766 .10191 m .4656 .09831 L .46764 .10201 L F
.46766 .10191 m .46746 .10167 L .46764 .10201 L F
.46773 .10203 m .46766 .10191 L .46764 .10201 L F
.4656 .09831 m .46449 .09637 L .46366 .101 L F
.46074 .10507 m .46249 .10066 L .4605 .105 L F
.46625 .10663 m .46315 .10171 L .46074 .10507 L F
.46315 .10171 m .46249 .10066 L .46074 .10507 L F
.46667 .10675 m .46634 .10627 L .46625 .10663 L F
.46614 .10665 m .46249 .1007 L .4605 .10504 L .813 .914 0 r
F
.46667 .1068 m .46625 .10619 L .46614 .10665 L F
.46625 .10619 m .46249 .1007 L .46614 .10665 L F
.46667 .1068 m .46772 .10207 L .46249 .1007 L F
.46772 .10207 m .46773 .10199 L .46764 .10201 L 1 .999 0 r
F
.46772 .10207 m .46773 .10203 L .46764 .10201 L .813 .914 0 r
F
.46772 .10207 m .46764 .10201 L .46249 .1007 L F
.46673 .1115 m .46772 .10207 L .46254 .10295 L 1 .999 0 r
F
.46772 .10207 m .46764 .10201 L .46254 .10295 L F
.46727 .10208 m .46452 .0982 L .46254 .10295 L 1 1 0 r
F
.46736 .10206 m .4673 .10197 L .46727 .10208 L F
.4673 .10197 m .46452 .0982 L .46727 .10208 L F
.46746 .10167 m .46452 .0982 L .46736 .10206 L F
.4605 .105 m .46249 .10066 L .46236 .10067 L .965 1 0 r
F
.46049 .10498 m .46236 .10067 L .45748 .10087 L F
.4605 .105 m .46236 .10067 L .46049 .10498 L F
.46246 .09956 m .46447 .09538 L .4603 .09444 L .828 .981 0 r
F
.46246 .09958 m .46447 .0954 L .4603 .09446 L .828 .982 0 r
F
.46249 .10066 m .46449 .09634 L .46032 .09527 L .83 .967 0 r
F
.46249 .1007 m .46449 .09637 L .46425 .09631 L .832 .968 0 r
F
.46242 .10053 m .46425 .09631 L .46032 .0953 L F
.46249 .1007 m .46425 .09631 L .46242 .10053 L F
.46249 .1007 m .46032 .0953 L .45748 .10095 L F
.4605 .10504 m .46249 .1007 L .45748 .10095 L .969 1 0 r
F
.46254 .10295 m .46036 .09679 L .45764 .10511 L .837 .927 0 r
F
.45742 .09922 m .4603 .09444 L .45637 .094 L .984 1 0 r
F
.45742 .09926 m .4603 .09446 L .45637 .09403 L .986 1 0 r
F
.45748 .10087 m .46032 .09527 L .45642 .09528 L 1 1 0 r
F
.45748 .10095 m .46032 .0953 L .45642 .09534 L F
.45764 .10511 m .46036 .09679 L .45653 .09808 L F
.4603 .09444 m .46013 .08977 L .45637 .094 L .826 1 0 r
F
.4603 .09446 m .46013 .08978 L .45637 .09403 L F
.46032 .09527 m .46015 .0905 L .45642 .09528 L .834 1 0 r
F
.46032 .0953 m .46015 .09053 L .45642 .09534 L .836 1 0 r
F
.46036 .09679 m .46019 .09179 L .45653 .09808 L .854 1 0 r
F
.46037 .09685 m .46019 .09185 L .45674 .09788 L .857 1 0 r
F
.45668 .09819 m .45674 .09788 L .45654 .09824 L F
.46037 .09685 m .45674 .09788 L .45668 .09819 L F
.45764 .10536 m .45654 .09824 L .45642 .09835 L 1 1 0 r
F
.45502 .10342 m .45642 .09835 L .45282 .10179 L F
.45764 .10536 m .45642 .09835 L .45502 .10342 L F
.45319 .10319 m .45654 .09824 L .45324 .10338 L 0 0 0 r
F
.45282 .10179 m .45642 .09835 L .45319 .10319 L F
.45642 .09835 m .45654 .09824 L .45319 .10319 L F
.45281 .10162 m .45653 .09808 L .45321 .10278 L F
.45637 .094 m .46013 .08977 L .45729 .08947 L .948 1 0 r
F
.45637 .09403 m .46013 .08978 L .45729 .0895 L .95 1 0 r
F
.45642 .09528 m .46015 .0905 L .45734 .09072 L 1 1 0 r
F
.45642 .09534 m .46015 .09053 L .45734 .09078 L F
.45647 .09817 m .45744 .09342 L .45321 .10278 L F
.45653 .09808 m .45663 .09758 L .45647 .09817 L F
.45663 .09758 m .45744 .09342 L .45647 .09817 L F
.45281 .10162 m .45321 .10278 L .4488 .10429 L 0 0 0 r
F
.44881 .10424 m .4488 .10429 L .44867 .10433 L F
.45281 .10162 m .4488 .10429 L .44881 .10424 L F
.44637 .12387 m .44959 .12006 L .44803 .15956 L .194 .014 0 r
F
.44617 .11961 m .44959 .12006 L .44637 .12387 L F
.4459 .121 m .44617 .11961 L .44261 .12327 L .788 .459 0 r
F
.44272 .12456 m .44409 .1539 L .4437 .15389 L .165 .005 0 r
F
.44261 .12327 m .44617 .11961 L .44307 .14689 L .131 0 0 r
F
.4429 .14333 m .44307 .14689 L .44297 .14779 L F
.44261 .12327 m .44307 .14689 L .4429 .14333 L F
.43452 .14802 m .43902 .151 L .43444 .14838 L .097 0 0 r
F
.43902 .15041 m .43902 .151 L .43452 .14802 L F
.43444 .14838 m .43902 .151 L .44062 .17199 L .371 .055 0 r
F
.45388 .31799 m .45424 .31412 L .45312 .30644 L .279 .044 0 r
F
.45388 .31799 m .45312 .30644 L .45269 .3095 L F
.45247 .31938 m .45303 .31882 L .45274 .31704 L .281 .045 0 r
F
.45303 .31882 m .45388 .31801 L .45319 .31309 L .279 .044 0 r
F
.45303 .31882 m .45319 .31309 L .45276 .31684 L F
.45278 .31762 m .45357 .31072 L .42998 .14795 L .281 .044 0 r
F
.45388 .31798 m .45424 .31412 L .45388 .31799 L .279 .044 0 r
F
.45512 .32146 m .43444 .14838 L .42998 .14795 L 1 .672 0 r
F
.43902 .151 m .45391 .30409 L .44947 .2878 L .379 .057 0 r
F
.43902 .151 m .44383 .15785 L .45391 .30409 L F
.43826 .14326 m .44297 .14779 L .45304 .29528 L .374 .056 0 r
F
.4439 .1619 m .44405 .16446 L .4474 .21506 L .164 .032 0 r
F
.44185 .12677 m .44297 .14779 L .43826 .14326 L .131 0 0 r
F
.44279 .1455 m .44335 .15745 L .4474 .21506 L .164 .032 0 r
F
.44297 .14779 m .4474 .21506 L .44773 .21746 L F
.44383 .15785 m .44324 .15054 L .44506 .1803 L .136 .025 0 r
F
.44617 .11961 m .44803 .15956 L .44386 .14985 L .194 .014 0 r
F
.44321 .14566 m .44386 .14985 L .44297 .14779 L F
.44617 .11961 m .44386 .14985 L .44321 .14566 L F
.44803 .15956 m .44867 .10433 L .44578 .1168 L 1 .835 0 r
F
.44803 .15956 m .44578 .1168 L .44578 .11684 L F
.44803 .15956 m .44578 .11681 L .4458 .11771 L F
.44297 .14779 m .44561 .15393 L .44554 .14467 L .164 .032 0 r
F
.44561 .15393 m .44803 .15956 L .44709 .15397 L F
.44561 .15393 m .44709 .15397 L .44554 .14467 L F
.44383 .15785 m .44802 .16681 L .44517 .1473 L .136 .025 0 r
F
.44419 .15863 m .44909 .17408 L .44802 .16681 L F
.44383 .15785 m .44416 .15887 L .44419 .15863 L F
.44416 .15887 m .44909 .17408 L .44419 .15863 L F
.4497 .11733 m .4485 .11881 L .44803 .15956 L 1 1 0 r
F
.44982 .11719 m .44878 .11853 L .44909 .17408 L F
.45417 .26021 m .45483 .24236 L .45378 .23474 L .38 .061 0 r
F
.45417 .26021 m .45378 .23474 L .45304 .2502 L F
.45451 .26744 m .45449 .26771 L .4548 .26612 L 1 .34 0 r
F
.4548 .26612 m .45449 .26771 L .45448 .26793 L F
.45481 .26481 m .45439 .25968 L .45449 .26653 L F
.44909 .17408 m .4487 .10483 L .44596 .1198 L 1 .819 0 r
F
.43907 .12708 m .44261 .12327 L .43826 .14326 L .036 0 0 r
F
.44261 .12327 m .44297 .14779 L .44185 .12677 L .131 0 0 r
F
.43908 .12701 m .44261 .12327 L .43907 .12708 L .036 0 0 r
F
.44452 .13857 m .44575 .11692 L .44021 .11275 L 1 .835 0 r
F
.44803 .15956 m .44674 .13549 L .44452 .13857 L F
.44674 .13549 m .44575 .11692 L .44452 .13857 L F
.44909 .17408 m .44596 .1198 L .44588 .11973 L 1 .819 0 r
F
.44279 .1455 m .44554 .14467 L .44025 .11296 L .164 .032 0 r
F
.44022 .11289 m .44025 .11296 L .44021 .11275 L F
.44279 .1455 m .44025 .11296 L .44022 .11289 L F
.44297 .14779 m .44554 .14467 L .44279 .1455 L F
.44554 .14984 m .4456 .14428 L .44035 .11438 L 1 .819 0 r
F
.4456 .14428 m .44588 .11973 L .44039 .11442 L F
.4456 .14428 m .44039 .11442 L .44035 .11438 L F
.4437 .15389 m .44409 .1539 L .44383 .15785 L .165 .005 0 r
F
.44302 .1477 m .44517 .1473 L .44035 .11438 L .136 .025 0 r
F
.44383 .15785 m .44517 .1473 L .44302 .1477 L F
.44035 .11438 m .44088 .11489 L .44477 .16263 L .505 .071 0 r
F
.44088 .11489 m .44551 .12899 L .44477 .16263 L F
.44909 .17408 m .44588 .11973 L .44554 .14984 L 1 .819 0 r
F
.44477 .16263 m .44569 .12953 L .45562 .28113 L .505 .071 0 r
F
.44572 .11958 m .44596 .1198 L .44477 .16263 L F
.44297 .14779 m .44308 .14996 L .44405 .16446 L .164 .032 0 r
F
.44297 .14779 m .44405 .16446 L .4439 .1619 L F
.44297 .14779 m .44279 .1455 L .44308 .14996 L F
.44279 .1455 m .44023 .11293 L .44255 .14606 L F
.44023 .11293 m .44021 .11275 L .44028 .1137 L F
.44023 .11293 m .44028 .1137 L .44307 .15348 L F
.44307 .15349 m .44307 .15348 L .44335 .15745 L F
.44023 .11293 m .44307 .15348 L .44307 .15349 L F
.44312 .15243 m .44255 .14606 L .44335 .15745 L F
.44279 .1455 m .44255 .14606 L .44312 .15243 L F
.44324 .15054 m .44035 .11438 L .44385 .16331 L .136 .025 0 r
F
.44324 .15054 m .44385 .16331 L .44506 .1803 L F
.44383 .15785 m .44506 .1803 L .44663 .20219 L F
.44773 .21746 m .44742 .2152 L .45304 .29528 L .164 .032 0 r
F
.44742 .2152 m .4474 .21506 L .44877 .23452 L F
.44742 .2152 m .44877 .23452 L .45304 .29528 L F
.45388 .31801 m .45388 .31798 L .45388 .31799 L .279 .044 0 r
F
.45312 .3202 m .45471 .31862 L .45357 .31072 L .281 .044 0 r
F
.45303 .31882 m .45276 .31684 L .45276 .31684 L .279 .044 0 r
F
.45312 .3202 m .45357 .31072 L .45278 .31762 L .281 .044 0 r
F
.45353 .3232 m .45512 .32143 L .45471 .31862 L F
.4535 .32216 m .45352 .32191 L .45353 .3232 L 0 0 0 r
F
.45353 .3232 m .45471 .31862 L .45312 .3202 L .281 .044 0 r
F
.43563 .15944 m .43722 .16343 L .44947 .2878 L .371 .055 0 r
F
.43722 .16343 m .44062 .17199 L .44628 .24602 L F
.43722 .16343 m .44628 .24602 L .44947 .2878 L F
.45126 .31969 m .45107 .31049 L .4504 .31394 L .281 .045 0 r
F
.45186 .31548 m .45172 .3107 L .4514 .31259 L F
.45247 .31938 m .45215 .31338 L .45186 .31548 L F
.45137 .32046 m .45186 .31548 L .45126 .31969 L F
.45193 .32405 m .45196 .32383 L .45194 .32497 L 0 0 0 r
F
.45194 .32497 m .45194 .32497 L .45194 .32498 L F
.45194 .32498 m .45353 .3232 L .4513 .3347 L .023 0 0 r
F
.45353 .3232 m .42998 .14795 L .4513 .3347 L .281 .044 0 r
F
.43444 .14838 m .44947 .2878 L .44373 .26559 L .371 .055 0 r
F
.44947 .2878 m .45391 .30409 L .45448 .32752 L .843 .292 0 r
F
.45441 .32738 m .45448 .32752 L .45449 .32799 L F
.44947 .2878 m .45448 .32752 L .45441 .32738 L F
.43104 .15697 m .43203 .15885 L .44373 .26559 L .364 .053 0 r
F
.43084 .14803 m .43444 .14838 L .4351 .15673 L F
.43084 .14803 m .4351 .15673 L .44373 .26559 L F
.43734 .24355 m .4357 .22282 L .43677 .23984 L 1 .672 0 r
F
.4513 .3347 m .4357 .22282 L .43734 .24355 L F
.42998 .14795 m .44373 .26559 L .43677 .23984 L .364 .053 0 r
F
.43372 .14196 m .44749 .27045 L .44013 .23763 L .367 .054 0 r
F
.44373 .26559 m .44947 .2878 L .45129 .31979 L .826 .285 0 r
F
.45086 .31918 m .45129 .31979 L .45154 .32426 L F
.44373 .26559 m .45129 .31979 L .45086 .31918 L F
.43677 .23984 m .44373 .26559 L .44829 .31952 L .776 .247 0 r
F
.44373 .26559 m .45154 .32426 L .44829 .31952 L .826 .285 0 r
F
.44829 .31952 m .45154 .32426 L .45092 .33205 L .91 .243 0 r
F
.44854 .31625 m .45115 .32118 L .45076 .33047 L .953 .309 0 r
F
.44759 .31444 m .45115 .32118 L .44755 .31437 L F
.44013 .23763 m .44749 .27045 L .45115 .32118 L .818 .289 0 r
F
.44947 .2878 m .45449 .32799 L .45154 .32426 L .843 .292 0 r
F
.44749 .27045 m .45429 .3262 L .454 .32574 L .868 .325 0 r
F
.4506 .31363 m .45107 .31528 L .45115 .32118 L F
.45107 .31528 m .45132 .32146 L .45115 .32118 L F
.45102 .32 m .45121 .32037 L .44166 .234 L .548 .132 0 r
F
.45107 .31528 m .454 .32574 L .45132 .32146 L .868 .325 0 r
F
.44749 .27045 m .454 .32574 L .4506 .31363 L F
.45121 .32037 m .45429 .3262 L .44535 .26094 L .548 .132 0 r
F
.45121 .32037 m .44535 .26094 L .44166 .234 L F
.44013 .23763 m .45115 .32118 L .44755 .31434 L .818 .289 0 r
F
.44854 .31625 m .45076 .33047 L .45075 .33078 L .953 .309 0 r
F
.45115 .32118 m .44166 .234 L .45075 .33078 L .548 .132 0 r
F
.45147 .3251 m .44528 .26394 L .45075 .32993 L .552 .141 0 r
F
.45147 .3252 m .45075 .32993 L .45092 .33205 L F
.45147 .3251 m .45075 .32993 L .45147 .3252 L F
.45091 .33141 m .44844 .30186 L .45057 .31758 L 0 0 0 r
F
.44844 .30186 m .44817 .29864 L .44926 .3072 L F
.44844 .30186 m .44926 .3072 L .45057 .31758 L F
.45115 .32118 m .45271 .32368 L .45102 .32 L .548 .132 0 r
F
.45271 .32368 m .45429 .3262 L .45102 .32 L F
.45137 .32263 m .44528 .26394 L .45147 .3251 L .552 .141 0 r
F
.44749 .27045 m .45037 .28335 L .45429 .3262 L .868 .325 0 r
F
.45037 .28335 m .45304 .29528 L .45383 .3149 L F
.45037 .28335 m .45383 .3149 L .45426 .32538 L F
.4539 .32191 m .45426 .32538 L .45429 .3262 L F
.45037 .28335 m .45426 .32538 L .4539 .32191 L F
.43826 .14326 m .45304 .29528 L .44952 .27952 L .374 .056 0 r
F
.44438 .22757 m .44952 .27952 L .44749 .27045 L F
.43444 .14838 m .44062 .17199 L .43563 .15944 L .371 .055 0 r
F
.43826 .14326 m .44952 .27952 L .44438 .22757 L .374 .056 0 r
F
.45407 .31041 m .45375 .30673 L .45449 .32799 L 1 .707 0 r
F
.45304 .29528 m .44326 .15619 L .44026 .1529 L 1 .732 0 r
F
.44326 .15619 m .44021 .11275 L .44025 .14096 L F
.44326 .15619 m .44025 .14096 L .44026 .1529 L F
.44711 .20535 m .44663 .20219 L .45342 .29711 L .136 .025 0 r
F
.45391 .30409 m .44419 .16802 L .44196 .17077 L 1 .707 0 r
F
.44419 .16802 m .44035 .11438 L .44142 .1518 L F
.44419 .16802 m .44142 .1518 L .44196 .17077 L F
.44142 .1518 m .44689 .21058 L .44196 .17077 L .505 .071 0 r
F
.44037 .11501 m .4434 .15943 L .44142 .1518 L F
.4434 .15943 m .44689 .21058 L .44142 .1518 L F
.44035 .11438 m .44689 .21058 L .44037 .11501 L F
.44021 .11338 m .44046 .11607 L .44026 .1529 L .503 .071 0 r
F
.44035 .11438 m .44709 .2122 L .44689 .21058 L .505 .071 0 r
F
.44046 .11607 m .44625 .20057 L .44026 .1529 L .503 .071 0 r
F
.4397 .10939 m .43688 .10855 L .435 .11386 L .689 .701 0 r
F
.43462 .114 m .43373 .11467 L .43209 .1266 L 1 1 0 r
F
.435 .11386 m .4355 .10285 L .43338 .12571 L F
.43244 .11534 m .43544 .10228 L .43288 .10632 L 1 .787 0 r
F
.43244 .11534 m .43288 .10632 L .43269 .10717 L F
.43209 .1266 m .43385 .11382 L .43244 .11534 L F
.43385 .11382 m .43544 .10228 L .43244 .11534 L F
.43316 .12916 m .43338 .12571 L .43275 .13255 L 1 1 0 r
F
.435 .11386 m .43338 .12571 L .43316 .12916 L F
.4277 .1234 m .4265 .11998 L .42578 .14349 L .625 .509 0 r
F
.4265 .11998 m .42624 .1196 L .42518 .11993 L .773 .898 0 r
F
.42624 .1196 m .42459 .11713 L .42518 .11993 L F
.42521 .12006 m .42976 .11507 L .42633 .12287 L .245 0 0 r
F
.42491 .117 m .42976 .11507 L .42521 .12006 L F
.42976 .11507 m .4304 .11879 L .42598 .12367 L .403 .041 0 r
F
.4304 .11879 m .43275 .13255 L .4284 .12685 L F
.4304 .11879 m .4284 .12685 L .42598 .12367 L F
.42879 .11543 m .42979 .11881 L .42557 .12043 L .371 .028 0 r
F
.42979 .11881 m .43209 .1266 L .42839 .1231 L F
.42583 .12295 m .42633 .12287 L .42598 .12367 L .245 0 0 r
F
.42521 .12006 m .42633 .12287 L .42583 .12295 L F
.42537 .14777 m .42929 .14235 L .43208 .20727 L .345 .045 0 r
F
.42578 .14349 m .42929 .14235 L .42537 .14777 L F
.42929 .14235 m .44013 .23763 L .43208 .20727 L .359 .051 0 r
F
.42132 .1505 m .41437 .12258 L .42022 .17955 L .46 .227 0 r
F
.44698 .33314 m .44861 .33096 L .42243 .19786 L .375 .062 0 r
F
.44719 .33429 m .42243 .19786 L .44719 .33429 L F
.44676 .3395 m .43809 .27825 L .44044 .30576 L 1 .353 0 r
F
.43809 .27825 m .43494 .25598 L .44044 .30576 L F
.44442 .33902 m .42186 .19915 L .4312 .27369 L 1 .513 0 r
F
.4442 .32957 m .44044 .30576 L .4355 .29582 L 1 .353 0 r
F
.4449 .3296 m .44044 .30576 L .4442 .32957 L F
.4443 .33852 m .44248 .3295 L .44216 .32949 L 1 .513 0 r
F
.44442 .33902 m .44432 .33851 L .4443 .33852 L F
.44571 .3377 m .44467 .3403 L .44258 .34119 L 0 0 0 r
F
.44457 .33982 m .4465 .33849 L .4355 .29582 L .534 .154 0 r
F
.44044 .30576 m .44491 .32781 L .44213 .32554 L .931 .296 0 r
F
.44044 .30576 m .44213 .32554 L .44164 .32514 L F
.43494 .25598 m .43609 .26775 L .44044 .30576 L 1 .353 0 r
F
.43389 .24856 m .43679 .27639 L .44044 .30576 L F
.44722 .33447 m .44719 .33429 L .44719 .33429 L .375 .062 0 r
F
.44722 .33447 m .44914 .33364 L .44861 .33096 L F
.44722 .33447 m .44861 .33096 L .44698 .33314 L F
.44757 .33659 m .44944 .33559 L .44676 .3395 L 0 0 0 r
F
.44944 .33559 m .42937 .2166 L .44676 .3395 L .377 .063 0 r
F
.43743 .28154 m .44464 .3135 L .44044 .30576 L .703 .188 0 r
F
.43494 .25598 m .43389 .24856 L .43609 .26775 L 1 .353 0 r
F
.43389 .24856 m .42937 .2166 L .43679 .27639 L F
.42937 .2166 m .44163 .29443 L .43743 .28154 L .703 .188 0 r
F
.44163 .29443 m .44464 .3135 L .43743 .28154 L F
.44044 .30576 m .44464 .3135 L .44491 .32781 L .931 .296 0 r
F
.4389 .2966 m .44325 .30485 L .4444 .32483 L .975 .364 0 r
F
.43793 .29161 m .43857 .2932 L .4389 .2966 L F
.43857 .2932 m .44325 .30485 L .4389 .2966 L F
.4355 .29582 m .44044 .30576 L .44164 .32514 L .934 .313 0 r
F
.43793 .29161 m .4389 .2966 L .44077 .32062 L .975 .364 0 r
F
.4389 .2966 m .4444 .32483 L .44149 .32146 L F
.4389 .2966 m .44149 .32146 L .44077 .32062 L F
.42937 .2166 m .43677 .23984 L .44464 .3135 L .703 .188 0 r
F
.42468 .18723 m .43208 .20727 L .44325 .30485 L .631 .137 0 r
F
.43677 .23984 m .44829 .31952 L .44464 .3135 L .776 .247 0 r
F
.43208 .20727 m .44755 .31434 L .44325 .30485 L .721 .21 0 r
F
.43208 .20727 m .44013 .23763 L .44755 .31434 L F
.41848 .14077 m .42938 .17622 L .4447 .29782 L .821 .326 0 r
F
.42979 .11881 m .42839 .1231 L .42584 .12068 L .371 .028 0 r
F
.42979 .11881 m .42584 .12068 L .42579 .12034 L F
.42579 .12034 m .42584 .12068 L .42557 .12043 L F
.42369 .11014 m .42885 .10703 L .42524 .10601 L .808 1 0 r
F
.42367 .10645 m .42524 .10601 L .42367 .10556 L F
.42369 .11014 m .42524 .10601 L .42367 .10645 L F
.42369 .11014 m .42367 .10556 L .41786 .108 L F
.41786 .108 m .42367 .10556 L .42063 .10489 L .583 .755 0 r
F
.41919 .10524 m .42063 .10489 L .41948 .10464 L F
.41786 .108 m .42063 .10489 L .41919 .10524 L F
.41209 .11071 m .41786 .108 L .41533 .10696 L .754 .979 0 r
F
.41278 .10738 m .41533 .10696 L .41306 .10603 L F
.41209 .11071 m .41533 .10696 L .41278 .10738 L F
.40635 .11363 m .41209 .11071 L .40671 .10797 L .829 1 0 r
F
.41209 .11071 m .41306 .10603 L .40671 .10797 L .754 .979 0 r
F
.40671 .10797 m .41306 .10603 L .40945 .1046 L .53 .673 0 r
F
.40671 .10797 m .40866 .10557 L .40256 .10539 L F
.40866 .10557 m .40945 .1046 L .40678 .1049 L F
.40866 .10557 m .40678 .1049 L .40256 .10539 L F
.40041 .11026 m .40256 .10539 L .39578 .10691 L .709 .941 0 r
F
.40041 .11026 m .40671 .10797 L .40256 .10539 L F
.39578 .10691 m .40256 .10539 L .39965 .10265 L .591 .828 0 r
F
.40256 .10539 m .40381 .10472 L .39965 .10265 L .384 .409 0 r
F
.40381 .10472 m .40433 .10404 L .40094 .10313 L .667 .881 0 r
F
.40433 .10404 m .40661 .10106 L .40035 .10262 L F
.40381 .10472 m .40013 .10268 L .39965 .10265 L .384 .409 0 r
F
.40433 .10404 m .40035 .10262 L .39967 .10279 L .667 .881 0 r
F
.40127 .10456 m .40381 .10472 L .39967 .10279 L F
.40256 .10539 m .40678 .1049 L .40526 .10481 L .384 .409 0 r
F
.40256 .10539 m .40863 .10409 L .40381 .10472 L F
.40271 .10616 m .40381 .10472 L .40127 .10456 L .667 .881 0 r
F
.40526 .10481 m .40945 .1046 L .40863 .10409 L .384 .409 0 r
F
.40678 .1049 m .40945 .1046 L .40526 .10481 L F
.40381 .10472 m .40863 .10409 L .40595 .10193 L .667 .881 0 r
F
.40381 .10472 m .40863 .10409 L .40695 .10304 L .384 .409 0 r
F
.40271 .10616 m .40863 .10409 L .40381 .10472 L .667 .881 0 r
F
.40271 .10616 m .4096 .10555 L .40863 .10409 L F
.40595 .10193 m .40863 .10409 L .40661 .10106 L F
.40863 .10409 m .41296 .09537 L .40661 .10106 L .714 .597 0 r
F
.4096 .10555 m .40979 .10497 L .40863 .10409 L F
.40945 .1046 m .40979 .10497 L .40863 .10409 L .628 .034 0 r
F
.41306 .10603 m .41427 .10572 L .40945 .1046 L .172 .169 0 r
F
.41427 .10572 m .41648 .10517 L .41046 .10468 L F
.41427 .10572 m .41046 .10468 L .40945 .1046 L F
.40881 .10423 m .41296 .09537 L .40863 .10409 L .714 .597 0 r
F
.40979 .10497 m .40994 .10453 L .40881 .10423 L F
.40994 .10453 m .41296 .09537 L .40881 .10423 L F
.41786 .108 m .41948 .10464 L .41306 .10603 L .583 .755 0 r
F
.41856 .11342 m .41786 .108 L .41209 .11071 L .859 1 0 r
F
.41856 .11342 m .42369 .11014 L .41786 .108 L F
.41791 .10833 m .41958 .10536 L .41315 .1066 L .549 .635 0 r
F
.41588 .10677 m .41958 .10536 L .41672 .10683 L .026 0 0 r
F
.4135 .10662 m .41567 .10617 L .41588 .10677 L F
.41567 .10617 m .41958 .10536 L .41588 .10677 L F
.41315 .1066 m .41533 .10618 L .4135 .10662 L F
.41533 .10618 m .41958 .10536 L .4135 .10662 L F
.41306 .10603 m .41584 .10543 L .41648 .10517 L .172 .169 0 r
F
.41584 .10543 m .41948 .10464 L .41677 .10512 L F
.41806 .10806 m .42372 .10593 L .41958 .10536 L .549 .635 0 r
F
.41791 .10833 m .41971 .10759 L .41806 .10806 L F
.41971 .10759 m .42372 .10593 L .41806 .10806 L F
.41859 .11362 m .42371 .11035 L .41791 .10833 L .854 1 0 r
F
.42371 .11035 m .42372 .10593 L .41791 .10833 L .797 1 0 r
F
.41948 .10464 m .42219 .0961 L .41648 .10517 L 1 1 0 r
F
.42367 .10556 m .42521 .09784 L .41948 .10464 L .779 .825 0 r
F
.41948 .10464 m .42521 .09784 L .42219 .0961 L 1 1 0 r
F
.41958 .10536 m .42224 .09648 L .41672 .10683 L F
.41672 .10683 m .41776 .10489 L .42226 .11075 L .324 .027 0 r
F
.42367 .10556 m .42953 .10354 L .42521 .09784 L .779 .825 0 r
F
.42372 .10593 m .42385 .10525 L .41958 .10536 L .772 .808 0 r
F
.42385 .10525 m .42524 .09807 L .42119 .10329 L F
.42385 .10525 m .42119 .10329 L .41958 .10536 L F
.42885 .10703 m .42953 .10354 L .42409 .10542 L .695 .888 0 r
F
.42467 .10584 m .42409 .10542 L .42367 .10556 L F
.42885 .10703 m .42409 .10542 L .42467 .10584 L F
.41958 .10536 m .42524 .09807 L .42224 .09648 L 1 1 0 r
F
.41776 .10489 m .42224 .09648 L .42225 .10388 L .324 .027 0 r
F
.41776 .10489 m .42225 .10388 L .42226 .11075 L F
.4164 .1052 m .41677 .10512 L .41648 .10517 L .172 .169 0 r
F
.41584 .10543 m .41677 .10512 L .4164 .1052 L F
.41648 .10517 m .42219 .0961 L .42007 .09426 L 1 1 0 r
F
.41648 .10517 m .41913 .09758 L .41658 .10513 L F
.41648 .10517 m .41658 .10513 L .41645 .10549 L F
.41561 .1051 m .41648 .10517 L .41637 .10574 L .628 .034 0 r
F
.41648 .10517 m .42007 .09426 L .41913 .09758 L 1 1 0 r
F
.41645 .10549 m .41913 .09758 L .41759 .10302 L F
.41637 .10574 m .42226 .11075 L .41759 .10302 L .324 .027 0 r
F
.41672 .10683 m .42196 .11054 L .41637 .10574 L F
.42196 .11054 m .42226 .11075 L .41637 .10574 L F
.41604 .10671 m .41672 .10683 L .41637 .10574 L .714 .597 0 r
F
.40786 .11432 m .41209 .11071 L .40635 .11363 L .889 1 0 r
F
.41346 .11684 m .4128 .11389 L .40786 .11432 L F
.4128 .11389 m .41209 .11071 L .40786 .11432 L F
.41346 .11684 m .41856 .11342 L .41209 .11071 L F
.4181 .11342 m .41791 .10833 L .41214 .11102 L .854 1 0 r
F
.41859 .11362 m .41856 .11338 L .4181 .11342 L F
.41856 .11338 m .41791 .10833 L .4181 .11342 L F
.41214 .11102 m .41791 .10833 L .41315 .1066 L .727 .948 0 r
F
.41315 .1066 m .41588 .10677 L .4096 .10555 L .026 0 0 r
F
.41588 .10677 m .41672 .10683 L .41604 .10671 L F
.4096 .10555 m .41604 .10671 L .41576 .10567 L .714 .597 0 r
F
.4096 .10555 m .41576 .10567 L .40979 .10497 L F
.41005 .10525 m .4104 .10563 L .408 .10403 L .628 .034 0 r
F
.41069 .10576 m .41063 .10573 L .4096 .10555 L .026 0 0 r
F
.4069 .10836 m .41258 .10676 L .4096 .10555 L .486 .525 0 r
F
.41258 .10676 m .41147 .1061 L .4096 .10555 L F
.40747 .10827 m .41315 .1066 L .4069 .10836 L F
.41214 .11102 m .41315 .1066 L .4068 .10847 L .727 .948 0 r
F
.4104 .10563 m .41533 .11098 L .40908 .10506 L .628 .034 0 r
F
.4104 .10563 m .40908 .10506 L .408 .10403 L F
.41588 .10677 m .41604 .10671 L .41063 .10573 L .026 0 0 r
F
.41588 .10677 m .41063 .10573 L .41069 .10576 L F
.41619 .10664 m .41624 .10777 L .41606 .10727 L 1 1 0 r
F
.41648 .10517 m .41635 .10657 L .41619 .10664 L F
.41635 .10657 m .41624 .10777 L .41619 .10664 L F
.41644 .10557 m .41759 .10302 L .41624 .10777 L F
.41645 .10549 m .41759 .10302 L .41644 .10557 L F
.41637 .10574 m .41759 .10302 L .41296 .09537 L .324 .027 0 r
F
.40945 .1046 m .41561 .1051 L .41637 .10574 L .628 .034 0 r
F
.40945 .1046 m .41637 .10574 L .40979 .10497 L F
.41604 .10671 m .41637 .10574 L .41296 .09537 L .714 .597 0 r
F
.41258 .10676 m .41315 .1066 L .41147 .1061 L .486 .525 0 r
F
.40979 .10497 m .41637 .10574 L .41533 .11098 L .628 .034 0 r
F
.40979 .10497 m .41576 .10567 L .41296 .09537 L .714 .597 0 r
F
.41606 .10727 m .41624 .10777 L .41533 .11098 L 1 1 0 r
F
.40979 .10497 m .40996 .10515 L .40863 .10409 L .628 .034 0 r
F
.40863 .10409 m .41005 .10525 L .40695 .10304 L F
.40996 .10515 m .41005 .10525 L .40863 .10409 L F
.40381 .10472 m .40695 .10304 L .40013 .10268 L .384 .409 0 r
F
.40381 .10472 m .40094 .10313 L .39967 .10279 L .667 .881 0 r
F
.41005 .10525 m .408 .10403 L .40695 .10304 L .628 .034 0 r
F
.4068 .10847 m .40747 .10827 L .4069 .10836 L .486 .525 0 r
F
.42371 .11035 m .42887 .10724 L .42372 .10593 L .797 1 0 r
F
.42448 .11628 m .42491 .11609 L .42557 .12043 L .147 0 0 r
F
.42491 .11609 m .42965 .11409 L .42557 .12043 L F
.42885 .10703 m .43404 .10413 L .42953 .10354 L .695 .888 0 r
F
.42887 .10724 m .42958 .10398 L .42372 .10593 L .664 .834 0 r
F
.42372 .10593 m .42958 .10398 L .42524 .09807 L .772 .808 0 r
F
.42608 .12091 m .42789 .12262 L .42599 .10429 L .368 .111 0 r
F
.42985 .1151 m .43209 .1266 L .42879 .11543 L .371 .028 0 r
F
.42789 .12262 m .43209 .1266 L .43087 .12215 L .368 .111 0 r
F
.42965 .11409 m .42985 .1151 L .42879 .11543 L .371 .028 0 r
F
.42789 .12262 m .43087 .12215 L .42609 .10467 L .368 .111 0 r
F
.42602 .10459 m .42609 .10467 L .42599 .10429 L F
.42789 .12262 m .42609 .10467 L .42602 .10459 L F
.4261 .10607 m .43275 .13255 L .42611 .10528 L .336 .072 0 r
F
.4284 .12685 m .43275 .13255 L .4261 .10607 L F
.42887 .10724 m .43406 .10435 L .42958 .10398 L .664 .834 0 r
F
.43209 .1266 m .43271 .10658 L .42599 .10429 L 1 .787 0 r
F
.43275 .13255 m .43284 .11706 L .43089 .11365 L 1 .74 0 r
F
.43284 .11706 m .43289 .10832 L .42648 .10544 L F
.43284 .11706 m .42648 .10544 L .42611 .10528 L F
.43275 .13255 m .43089 .11365 L .4294 .11878 L F
.43275 .13255 m .43338 .12571 L .43289 .10832 L F
.43338 .12571 m .4355 .10285 L .43303 .10804 L F
.43338 .12571 m .43303 .10804 L .43289 .10832 L F
.43518 .10351 m .43363 .11006 L .43289 .10832 L .617 .072 0 r
F
.4355 .10285 m .43998 .12314 L .43441 .11105 L F
.43493 .10502 m .43441 .11105 L .43375 .10961 L F
.4355 .10285 m .43441 .11105 L .43493 .10502 L F
.43928 .10176 m .43956 .102 L .4355 .10285 L .14 0 0 r
F
.44822 .09681 m .45277 .09367 L .44946 .09184 L .795 .961 0 r
F
.44833 .09871 m .44955 .09356 L .44451 .09938 L .748 .891 0 r
F
.44833 .09871 m .45287 .09583 L .44955 .09356 L F
.44834 .09884 m .44842 .09849 L .44453 .09968 L .747 .888 0 r
F
.44842 .09849 m .44672 .09706 L .44453 .09968 L F
.4442 .10719 m .44834 .09884 L .44453 .09968 L 1 1 0 r
F
.44451 .09938 m .44955 .09356 L .44685 .09458 L .956 .905 0 r
F
.44453 .09968 m .44687 .09486 L .44154 .10372 L .941 .853 0 r
F
.44711 .20535 m .45342 .29711 L .45339 .29647 L .136 .025 0 r
F
.44711 .20535 m .45387 .30348 L .45387 .30341 L F
.44383 .15785 m .44663 .20219 L .44711 .20535 L F
.44035 .11438 m .45256 .24764 L .44709 .2122 L .505 .071 0 r
F
.45256 .24764 m .45562 .28113 L .45443 .27148 L F
.45256 .24764 m .45443 .27148 L .44709 .2122 L F
.44927 .18422 m .44673 .1327 L .45562 .28113 L F
.44569 .12953 m .44658 .13225 L .44927 .18422 L F
.44658 .13225 m .44673 .1327 L .44927 .18422 L F
.4552 .26376 m .4548 .26591 L .4548 .26612 L 1 .34 0 r
F
.4552 .26376 m .45523 .26255 L .45476 .26509 L F
.4552 .26376 m .45476 .26509 L .4548 .26591 L F
.45173 .2162 m .45249 .22203 L .45562 .28113 L 0 0 0 r
F
.45249 .22203 m .45321 .22758 L .45409 .24712 L F
.45523 .26255 m .45469 .25777 L .45481 .26481 L 1 .34 0 r
F
.45249 .22203 m .45409 .24712 L .45562 .28113 L 0 0 0 r
F
.45396 .23606 m .45376 .23404 L .45373 .23438 L 1 .659 0 r
F
.45465 .24104 m .45402 .2349 L .45396 .23606 L F
.45483 .24236 m .45466 .24076 L .45465 .24104 L F
.45569 .24198 m .45513 .24553 L .45514 .2459 L .944 .208 0 r
F
.45543 .25879 m .45543 .25858 L .45533 .25789 L 0 0 0 r
F
.45543 .25879 m .45533 .25789 L .45533 .25809 L F
.45633 .26488 m .45543 .25858 L .45543 .25879 L F
.4554 .25313 m .45471 .25721 L .45469 .25777 L .997 .271 0 r
F
.45542 .25299 m .4554 .25312 L .4554 .25313 L F
.4554 .25312 m .45471 .25721 L .4554 .25313 L F
.45542 .25299 m .45464 .24944 L .45471 .25721 L F
.45523 .26255 m .45494 .25612 L .45469 .25777 L 1 .34 0 r
F
.45642 .26518 m .45631 .26444 L .45645 .26572 L 0 0 0 r
F
.45628 .27481 m .45608 .27342 L .4561 .2737 L F
.45626 .27454 m .45608 .27342 L .45628 .27481 L F
.47105 .3678 m .4711 .3654 L .45608 .27341 L F
.4711 .3654 m .45625 .26438 L .45613 .2711 L F
.45625 .26438 m .45597 .26248 L .45613 .2711 L F
.45597 .26248 m .45517 .25701 L .4559 .26967 L F
.47111 .36577 m .45573 .26714 L .45573 .26715 L F
.45573 .26714 m .45553 .26584 L .45573 .26715 L F
.45553 .26585 m .45523 .26396 L .45523 .26396 L F
.45553 .26584 m .45523 .26396 L .45553 .26585 L F
.45608 .27342 m .45606 .27325 L .4561 .2737 L F
.45608 .27342 m .45608 .27341 L .45606 .27325 L F
.47105 .3678 m .45608 .27341 L .45608 .27342 L F
.4711 .3654 m .47115 .36297 L .46207 .30265 L F
.4711 .3654 m .46207 .30265 L .46205 .30357 L F
.47111 .36577 m .47116 .36337 L .45552 .26576 L F
.45553 .26584 m .45552 .26576 L .45523 .26396 L F
.47111 .36577 m .45552 .26576 L .45553 .26584 L F
.45523 .26396 m .45523 .26396 L .4552 .26376 L F
.45614 .274 m .45607 .27351 L .45607 .27356 L F
.47105 .3678 m .45614 .27394 L .45614 .274 L F
.45614 .27394 m .45607 .27351 L .45614 .274 L F
.45631 .26444 m .4563 .26436 L .45634 .26498 L F
.46205 .30357 m .46207 .30265 L .45631 .26444 L F
.45631 .26444 m .45631 .26444 L .4563 .26436 L F
.46205 .30357 m .45631 .26444 L .45631 .26444 L F
.47105 .3678 m .45614 .274 L .45615 .27421 L F
.45614 .274 m .45607 .27356 L .45615 .27421 L F
.47115 .36297 m .45598 .25121 L .4559 .26172 L .996 .305 0 r
F
.45523 .26255 m .45542 .25299 L .45494 .25612 L 1 .34 0 r
F
.45608 .27376 m .4559 .27258 L .4559 .27261 L 0 0 0 r
F
.46213 .3 m .46215 .29903 L .45595 .25661 L F
.45596 .25675 m .45595 .25661 L .45542 .25299 L F
.47116 .36337 m .45595 .25661 L .45596 .25675 L F
.47105 .3678 m .45651 .27647 L .4616 .31439 L F
.47121 .36093 m .45569 .24198 L .45542 .25299 L F
.47116 .36337 m .45542 .25299 L .4552 .26376 L F
.471 .37019 m .46416 .33047 L .46622 .34526 L F
.47111 .36577 m .4552 .26376 L .46241 .36692 L F
.45562 .28113 m .45102 .17911 L .45823 .29062 L .184 .025 0 r
F
.45102 .17911 m .44805 .11341 L .45647 .26001 L F
.45102 .17911 m .45647 .26001 L .45823 .29062 L F
.45646 .24788 m .4563 .24651 L .4563 .24667 L 0 0 0 r
F
.45646 .24773 m .4563 .24651 L .45646 .24788 L F
.45652 .23505 m .4565 .23484 L .45653 .2352 L F
.45717 .22676 m .45717 .22666 L .45688 .22411 L F
.47131 .35591 m .45717 .22666 L .45717 .22676 L F
.45727 .2413 m .4567 .23644 L .4567 .2365 L F
.47126 .35845 m .45727 .24124 L .45727 .2413 L F
.45727 .24124 m .4567 .23644 L .45727 .2413 L F
.47126 .35845 m .47131 .35591 L .45764 .24416 L F
.45765 .24445 m .45764 .24416 L .4567 .23644 L F
.47126 .35845 m .45764 .24416 L .45765 .24445 L F
.4567 .2365 m .4567 .23644 L .4565 .23484 L F
.45688 .22415 m .45688 .22411 L .45678 .22319 L F
.47131 .35591 m .45688 .22411 L .45688 .22415 L F
.45651 .23499 m .4565 .23484 L .45602 .23091 L F
.45678 .22331 m .45678 .22319 L .45641 .21997 L F
.47131 .35591 m .45678 .22319 L .45678 .22331 L F
.47121 .36093 m .47126 .35845 L .4563 .24651 L F
.4563 .24667 m .4563 .24651 L .45569 .24198 L F
.47136 .35329 m .45688 .20928 L .45641 .21997 L F
.47131 .35591 m .45641 .21997 L .45602 .23091 L F
.47126 .35845 m .45602 .23091 L .45569 .24198 L F
.44805 .11341 m .45748 .21638 L .45823 .29062 L .578 .12 0 r
F
.45823 .29062 m .45748 .21638 L .4626 .32358 L .512 .075 0 r
F
.47116 .36337 m .47121 .36093 L .46215 .29903 L 0 0 0 r
F
.47116 .36337 m .46215 .29903 L .46213 .3 L F
.45748 .21638 m .46505 .31595 L .4627 .32552 L .633 .177 0 r
F
.45823 .29062 m .4627 .32552 L .46005 .32686 L .512 .075 0 r
F
.45897 .20005 m .45897 .19985 L .45848 .19427 L 0 0 0 r
F
.47146 .3476 m .45897 .19985 L .45897 .20005 L F
.45848 .19437 m .45848 .19427 L .45822 .19128 L F
.47146 .3476 m .45848 .19427 L .45848 .19437 L F
.45818 .20718 m .45785 .20354 L .45819 .20725 L F
.45789 .21925 m .45744 .21474 L .45744 .21484 L F
.47136 .35329 m .45788 .21916 L .45789 .21925 L F
.45788 .21916 m .45744 .21474 L .45789 .21925 L F
.47023 .21933 m .46966 .21819 L .46968 .21843 L .358 .074 0 r
F
.46973 .21851 m .46968 .21843 L .46968 .21843 L F
.47023 .21933 m .46968 .21843 L .46973 .21851 L F
.47019 .219 m .46965 .21792 L .47023 .21933 L F
.46965 .21792 m .46969 .21825 L .47023 .21933 L F
.46973 .21851 m .46882 .21866 L .46895 .21966 L 1 1 0 r
F
.46965 .21792 m .46882 .21866 L .46973 .21851 L F
.46965 .21792 m .46845 .2124 L .46882 .21866 L F
.46937 .21405 m .46845 .2124 L .46965 .21792 L F
.47091 .22041 m .47019 .219 L .47023 .21933 L .358 .074 0 r
F
.46996 .21032 m .46913 .21095 L .46919 .21138 L 1 1 0 r
F
.47147 .18017 m .47079 .17909 L .47082 .17941 L .451 .264 0 r
F
.47135 .18778 m .47058 .18649 L .47061 .18684 L .427 .219 0 r
F
.47124 .1956 m .47037 .19409 L .4704 .19448 L .404 .176 0 r
F
.47112 .20365 m .47015 .20188 L .47018 .2023 L .383 .135 0 r
F
.47101 .21192 m .46992 .20985 L .46996 .21032 L .371 .096 0 r
F
.47152 .34441 m .47171 .1739 L .4587 .1796 L 1 .402 0 r
F
.47164 .17278 m .47164 .17276 L .47159 .17161 L 0 0 0 r
F
.47164 .17278 m .47164 .17276 L .47159 .17278 L 1 1 0 r
F
.47164 .17276 m .4716 .17104 L .47159 .17278 L .518 .452 0 r
F
.47159 .17161 m .47097 .17183 L .47102 .17216 L 1 1 0 r
F
.471 .17187 m .47097 .17183 L .47102 .17216 L 1 .585 0 r
F
.47159 .17278 m .4716 .17104 L .47097 .17183 L F
.47159 .17278 m .471 .17187 L .47102 .17216 L F
.47171 .1739 m .47139 .16595 L .4587 .1796 L 1 .402 0 r
F
.45785 .2036 m .45762 .20109 L .45763 .20117 L 0 0 0 r
F
.45785 .20354 m .45762 .20109 L .45785 .2036 L F
.47136 .35329 m .47141 .35054 L .45747 .21501 L F
.47136 .35329 m .45747 .21501 L .45747 .21506 L F
.45822 .19135 m .45822 .19128 L .45803 .18905 L F
.47146 .3476 m .45822 .19128 L .45822 .19135 L F
.47141 .35054 m .47146 .3476 L .45785 .20346 L F
.45785 .20354 m .45785 .20346 L .45762 .20109 L F
.47141 .35054 m .45785 .20346 L .45785 .20354 L F
.47136 .35329 m .45748 .21516 L .45748 .21519 L F
.45763 .20117 m .45762 .20109 L .45742 .19895 L F
.47172 .1656 m .45943 .17059 L .4587 .1796 L 1 1 0 r
F
.47184 .15861 m .46022 .16201 L .45943 .17059 L F
.47146 .3476 m .45803 .18905 L .45742 .19895 L 0 0 0 r
F
.47141 .35054 m .45742 .19895 L .45688 .20928 L F
.47152 .34441 m .4587 .1796 L .45803 .18905 L 1 .402 0 r
F
.47223 .1384 m .47237 .13222 L .4628 .13773 L 1 1 0 r
F
.47237 .13222 m .46375 .13083 L .4628 .13773 L F
.46282 .13858 m .46376 .13144 L .45595 .14677 L 1 .84 0 r
F
.46375 .13083 m .46472 .12417 L .45742 .13475 L 1 1 0 r
F
.46376 .13144 m .45749 .1366 L .45595 .14677 L 1 .944 0 r
F
.47237 .13222 m .4725 .12617 L .46375 .13083 L 1 1 0 r
F
.4725 .12617 m .46472 .12417 L .46375 .13083 L F
.46376 .13144 m .46473 .1246 L .45749 .1366 L 1 .944 0 r
F
.46473 .1246 m .45915 .12732 L .45749 .1366 L 1 1 0 r
F
.45749 .1366 m .45915 .12732 L .45205 .11455 L .617 .355 0 r
F
.46058 .10767 m .46254 .10295 L .46243 .103 L 1 1 0 r
F
.4605 .1076 m .46243 .103 L .45764 .10511 L F
.46058 .10767 m .46243 .103 L .4605 .1076 L F
.46132 .10813 m .46254 .10295 L .46058 .10767 L 1 .999 0 r
F
.46673 .1115 m .46298 .10384 L .46132 .10813 L F
.46298 .10384 m .46254 .10295 L .46132 .10813 L F
.46317 .10335 m .46452 .09827 L .46254 .10304 L 1 1 0 r
F
.46777 .10559 m .46485 .099 L .46317 .10335 L F
.46485 .099 m .46452 .09827 L .46317 .10335 L F
.46254 .10295 m .46452 .0982 L .46036 .09679 L .837 .927 0 r
F
.46254 .10304 m .46452 .09827 L .46442 .09823 L .839 .927 0 r
F
.46248 .10287 m .46442 .09823 L .46037 .09685 L F
.46254 .10304 m .46442 .09823 L .46248 .10287 L F
.46571 .11773 m .46673 .1115 L .46058 .10767 L .734 .686 0 r
F
.46058 .10779 m .46254 .10304 L .45764 .10536 L 1 1 0 r
F
.47239 .12545 m .47252 .12055 L .46353 .12124 L .977 1 0 r
F
.46472 .12417 m .46571 .11773 L .46556 .11792 L 1 1 0 r
F
.46468 .12418 m .46556 .11792 L .45911 .12613 L F
.46472 .12417 m .46556 .11792 L .46468 .12418 L F
.47264 .12027 m .46571 .11773 L .46472 .12417 L F
.47264 .12027 m .47277 .11451 L .46571 .11773 L F
.47277 .11451 m .46673 .1115 L .46654 .11266 L F
.46654 .11735 m .46654 .11266 L .46571 .11773 L F
.47277 .11451 m .46654 .11266 L .46654 .11735 L F
.46654 .11157 m .46254 .10304 L .46058 .10779 L .792 .772 0 r
F
.46673 .11169 m .46654 .11129 L .46654 .11157 L F
.46654 .11129 m .46254 .10304 L .46654 .11157 L F
.46572 .11802 m .46673 .11169 L .46646 .11152 L .736 .681 0 r
F
.46558 .11775 m .46646 .11152 L .46058 .10779 L F
.46572 .11802 m .46646 .11152 L .46558 .11775 L F
.45915 .12732 m .46058 .10779 L .45484 .10998 L 1 .867 0 r
F
.46254 .10304 m .46037 .09685 L .45764 .10536 L .839 .927 0 r
F
.45764 .10536 m .46037 .09685 L .45654 .09824 L 1 1 0 r
F
.45748 .21638 m .45769 .10159 L .46495 .31301 L .633 .177 0 r
F
.46469 .3113 m .46495 .31301 L .46505 .31595 L F
.45748 .21638 m .46495 .31301 L .46469 .3113 L F
.46285 .32501 m .46505 .31595 L .46502 .31623 L 0 0 0 r
F
.46292 .3246 m .46505 .31595 L .46285 .32501 L F
.47221 .16761 m .47197 .15122 L .47184 .15786 L F
.47803 .32144 m .47242 .16377 L .47221 .16761 L F
.47242 .16377 m .47197 .15122 L .47221 .16761 L F
.47206 .15331 m .4721 .14474 L .47197 .15122 L .061 0 0 r
F
.47812 .30762 m .47222 .14781 L .47206 .15331 L F
.47222 .14781 m .4721 .14474 L .47206 .15331 L F
.47213 .1453 m .47223 .1384 L .4721 .14474 L .46 .061 0 r
F
.47856 .28219 m .47228 .13941 L .47213 .1453 L F
.47228 .13941 m .47223 .1384 L .47213 .1453 L F
.47225 .13861 m .47237 .13222 L .47223 .1384 L .971 .424 0 r
F
.47962 .23448 m .47241 .13275 L .47225 .13861 L F
.47241 .13275 m .47237 .13222 L .47225 .13861 L F
.47241 .13273 m .4725 .12637 L .47237 .13248 L .653 .199 0 r
F
.48051 .18444 m .47256 .12681 L .47241 .13273 L F
.47256 .12681 m .4725 .12637 L .47241 .13273 L F
.49077 .20088 m .49133 .16745 L .47962 .23448 L 1 .807 0 r
F
.49077 .20088 m .49133 .16745 L .49077 .20088 L 1 .814 0 r
F
.49077 .20088 m .49138 .16477 L .49077 .20088 L 1 .807 0 r
F
.49077 .20088 m .49077 .20088 L .47856 .28219 L F
.49077 .20088 m .47962 .23448 L .47943 .24274 L F
.49077 .20088 m .47943 .24274 L .47856 .28219 L F
.47931 .24464 m .47962 .23448 L .47788 .26671 L .46 .061 0 r
F
.47856 .28219 m .47918 .25416 L .47834 .27706 L F
.47918 .25416 m .47962 .23448 L .47834 .27706 L F
.47812 .30762 m .47856 .28219 L .4721 .14474 L .061 0 0 r
F
.48879 .24886 m .49077 .20088 L .49077 .20088 L 1 .748 0 r
F
.48879 .24886 m .49077 .20088 L .47856 .28219 L 1 .74 0 r
F
.48879 .24886 m .47856 .28219 L .47812 .30762 L F
.47803 .32144 m .47812 .30762 L .47197 .15122 L 0 0 0 r
F
.48699 .28799 m .48879 .24886 L .48879 .24886 L 1 .701 0 r
F
.48699 .28799 m .48879 .24886 L .48879 .24886 L 1 .693 0 r
F
.48699 .28799 m .48879 .24886 L .47812 .30762 L F
.48699 .28799 m .48879 .24886 L .48699 .28799 L 1 .701 0 r
F
.48699 .28799 m .48879 .24886 L .48699 .28799 L 1 .693 0 r
F
.48879 .24886 m .47845 .28528 L .47815 .30369 L 1 .748 0 r
F
.48232 .30543 m .47812 .30762 L .47803 .32144 L 1 .693 0 r
F
.47962 .30431 m .47812 .30762 L .48232 .30543 L F
.47901 .30405 m .47815 .30369 L .47805 .30943 L 1 .748 0 r
F
.48879 .24886 m .47815 .30369 L .47901 .30405 L F
.48699 .28799 m .47962 .30431 L .48232 .30543 L 1 .693 0 r
F
.4781 .33018 m .47803 .32144 L .47184 .15786 L 0 0 0 r
F
.48621 .3103 m .48699 .28799 L .48699 .28799 L 1 .704 0 r
F
.48621 .3103 m .48699 .28799 L .48699 .28799 L 1 .696 0 r
F
.48621 .3103 m .48699 .28799 L .47803 .32144 L F
.48621 .3103 m .48699 .28799 L .48621 .3103 L 1 .704 0 r
F
.48621 .3103 m .48699 .28799 L .48621 .3103 L 1 .696 0 r
F
.48699 .28799 m .47805 .30943 L .47801 .31819 L 1 .701 0 r
F
.48109 .32284 m .47803 .32144 L .4781 .33018 L 1 .696 0 r
F
.47915 .31991 m .47803 .32144 L .48109 .32284 L F
.47882 .31941 m .47801 .31819 L .47798 .32261 L 1 .701 0 r
F
.48699 .28799 m .47801 .31819 L .47882 .31941 L F
.48621 .3103 m .47915 .31991 L .48109 .32284 L 1 .696 0 r
F
.48604 .3234 m .48621 .3103 L .48621 .3103 L 1 .734 0 r
F
.48604 .3234 m .48621 .3103 L .48621 .3103 L 1 .726 0 r
F
.48604 .3234 m .48621 .3103 L .4781 .33018 L F
.48604 .3234 m .48621 .3103 L .48604 .3234 L 1 .734 0 r
F
.48604 .3234 m .48621 .3103 L .48604 .3234 L 1 .726 0 r
F
.48621 .3103 m .47798 .32261 L .47803 .32692 L 1 .704 0 r
F
.48104 .33177 m .4781 .33018 L .47825 .33644 L 1 .726 0 r
F
.47937 .32909 m .4781 .33018 L .48104 .33177 L F
.47903 .32855 m .47803 .32692 L .47806 .33102 L 1 .704 0 r
F
.48621 .3103 m .47803 .32692 L .47903 .32855 L F
.48604 .3234 m .47937 .32909 L .48104 .33177 L 1 .726 0 r
F
.48618 .33206 m .48604 .3234 L .48604 .3234 L 1 .775 0 r
F
.48618 .33206 m .48604 .3234 L .48604 .3234 L 1 .766 0 r
F
.48618 .33206 m .48604 .3234 L .47825 .33644 L F
.48618 .33206 m .48604 .3234 L .48618 .33206 L 1 .775 0 r
F
.48618 .33206 m .48604 .3234 L .48618 .33206 L 1 .766 0 r
F
.48604 .3234 m .47806 .33102 L .47811 .33289 L 1 .734 0 r
F
.48127 .33795 m .47825 .33644 L .47843 .34134 L 1 .766 0 r
F
.47979 .33558 m .47825 .33644 L .48127 .33795 L F
.47942 .33498 m .47811 .33289 L .47822 .33709 L 1 .734 0 r
F
.48604 .3234 m .47811 .33289 L .47942 .33498 L F
.48618 .33206 m .47979 .33558 L .48127 .33795 L 1 .766 0 r
F
.48647 .33843 m .48618 .33206 L .48618 .33206 L 1 .817 0 r
F
.48647 .33843 m .48618 .33206 L .48618 .33206 L 1 .808 0 r
F
.48647 .33843 m .48618 .33206 L .47843 .34134 L F
.48647 .33843 m .48618 .33206 L .48647 .33843 L 1 .817 0 r
F
.48647 .33843 m .48618 .33206 L .48647 .33843 L 1 .808 0 r
F
.48618 .33206 m .47822 .33709 L .47822 .33726 L 1 .775 0 r
F
.48161 .34278 m .47843 .34134 L .47865 .34545 L 1 .808 0 r
F
.48031 .34066 m .47843 .34134 L .48161 .34278 L F
.4799 .33999 m .47822 .33726 L .47841 .34187 L 1 .775 0 r
F
.48618 .33206 m .47822 .33726 L .4799 .33999 L F
.48647 .33843 m .48031 .34066 L .48161 .34278 L 1 .808 0 r
F
.48685 .34348 m .48647 .33843 L .48647 .33843 L 1 .854 0 r
F
.48685 .34348 m .48647 .33843 L .48647 .33843 L 1 .844 0 r
F
.48685 .34348 m .48647 .33843 L .47865 .34545 L F
.48685 .34348 m .48647 .33843 L .48685 .34348 L 1 .854 0 r
F
.48685 .34348 m .48647 .33843 L .48685 .34348 L 1 .844 0 r
F
.48202 .34684 m .47865 .34545 L .47887 .34904 L F
.48088 .34491 m .47865 .34545 L .48202 .34684 L F
.48044 .34416 m .47841 .34187 L .47862 .3459 L 1 .817 0 r
F
.48647 .33843 m .47896 .34164 L .48044 .34416 L F
.47896 .34164 m .47841 .34187 L .48044 .34416 L F
.48685 .34348 m .48088 .34491 L .48202 .34684 L 1 .844 0 r
F
.48247 .35042 m .47887 .34904 L .47911 .35229 L 1 .874 0 r
F
.48729 .34774 m .48149 .34863 L .48247 .35042 L F
.48149 .34863 m .47887 .34904 L .48247 .35042 L F
.48296 .35367 m .47911 .35229 L .47935 .35531 L 1 .895 0 r
F
.48776 .35147 m .48212 .35201 L .48296 .35367 L F
.48212 .35201 m .47911 .35229 L .48296 .35367 L F
.48346 .35669 m .47935 .35531 L .4796 .35817 L 1 .909 0 r
F
.48825 .35486 m .48277 .35514 L .48346 .35669 L F
.48277 .35514 m .47935 .35531 L .48346 .35669 L F
.47985 .36091 m .4796 .35817 L .47973 .35902 L .747 .135 0 r
F
.48398 .35956 m .4796 .35817 L .47985 .36091 L 1 .917 0 r
F
.48875 .358 m .48341 .3581 L .48398 .35956 L F
.48341 .3581 m .4796 .35817 L .48398 .35956 L F
.48451 .36232 m .47985 .36091 L .4801 .36357 L 1 .921 0 r
F
.48926 .36097 m .48407 .36094 L .48451 .36232 L F
.48407 .36094 m .47985 .36091 L .48451 .36232 L F
.48506 .36499 m .4801 .36357 L .48035 .36616 L 1 .922 0 r
F
.48978 .36381 m .48472 .36368 L .48506 .36499 L F
.48472 .36368 m .4801 .36357 L .48506 .36499 L F
.48561 .3676 m .48035 .36616 L .4806 .36872 L 1 .92 0 r
F
.4903 .36656 m .48536 .36636 L .48561 .3676 L F
.48536 .36636 m .48035 .36616 L .48561 .3676 L F
.48616 .37018 m .4806 .36872 L .48084 .37124 L 1 .916 0 r
F
.49082 .36925 m .486 .36899 L .48616 .37018 L F
.486 .36899 m .4806 .36872 L .48616 .37018 L F
.48109 .37373 m .48084 .37124 L .47096 .37257 L 1 .969 0 r
F
.48672 .37272 m .48084 .37124 L .48109 .37373 L 1 .912 0 r
F
.49134 .37188 m .48663 .37159 L .48672 .37272 L F
.48663 .37159 m .48084 .37124 L .48672 .37272 L F
.48134 .37622 m .48109 .37373 L .47091 .37496 L 1 .962 0 r
F
.49185 .37448 m .48109 .37373 L .48134 .37622 L 1 .907 0 r
F
.49188 .37447 m .49185 .37447 L .49185 .37448 L 1 .917 0 r
F
.49188 .37447 m .49185 .37447 L .49185 .37448 L 1 .907 0 r
F
.49185 .37447 m .48109 .37373 L .49185 .37448 L F
.48158 .3787 m .48134 .37622 L .47086 .37734 L 1 .954 0 r
F
.49236 .37705 m .48134 .37622 L .48158 .3787 L 1 .901 0 r
F
.4924 .37704 m .49236 .37704 L .49236 .37705 L 1 .911 0 r
F
.4924 .37704 m .49236 .37704 L .49236 .37705 L 1 .901 0 r
F
.49236 .37704 m .48134 .37622 L .49236 .37705 L F
.48182 .38117 m .48158 .3787 L .47081 .37973 L 1 .946 0 r
F
.49286 .3796 m .48158 .3787 L .48182 .38117 L .998 .895 0 r
F
.49292 .37959 m .49286 .37959 L .49286 .3796 L 1 .905 0 r
F
.49292 .37959 m .49286 .37959 L .49286 .3796 L .998 .895 0 r
F
.49286 .37959 m .48158 .3787 L .49286 .3796 L F
.48206 .38364 m .48182 .38117 L .47076 .38212 L 1 .939 0 r
F
.49335 .38214 m .48182 .38117 L .48206 .38364 L .992 .889 0 r
F
.49343 .38213 m .49335 .38213 L .49335 .38214 L 1 .899 0 r
F
.49343 .38213 m .49335 .38213 L .49335 .38214 L .992 .889 0 r
F
.49335 .38213 m .48182 .38117 L .49335 .38214 L F
.4823 .38611 m .48206 .38364 L .47071 .38453 L 1 .932 0 r
F
.49309 .38834 m .49309 .38289 L .46951 .39408 L 1 .814 0 r
F
.49384 .38468 m .48206 .38364 L .4823 .38611 L .986 .882 0 r
F
.49394 .38466 m .49384 .38466 L .49384 .38468 L .998 .892 0 r
F
.49394 .38466 m .49384 .38466 L .49384 .38468 L .986 .882 0 r
F
.49384 .38466 m .48206 .38364 L .49384 .38468 L F
.48253 .38859 m .4823 .38611 L .47067 .38694 L 1 .924 0 r
F
.49431 .38721 m .4823 .38611 L .48253 .38859 L .981 .876 0 r
F
.49444 .38719 m .49431 .38718 L .49431 .38721 L .993 .886 0 r
F
.49444 .38719 m .49431 .38718 L .49431 .38721 L .981 .876 0 r
F
.49431 .38718 m .4823 .38611 L .49431 .38721 L F
.49309 .38834 m .46951 .39408 L .46947 .39858 L 1 .814 0 r
F
.48276 .39108 m .48253 .38859 L .47062 .38937 L 1 .917 0 r
F
.49309 .39361 m .49309 .38834 L .46947 .39858 L 1 .814 0 r
F
.49478 .38974 m .48253 .38859 L .48276 .39108 L .977 .869 0 r
F
.49494 .38972 m .49477 .3897 L .49478 .38974 L .989 .879 0 r
F
.49494 .38972 m .49477 .3897 L .49478 .38974 L .977 .869 0 r
F
.49477 .3897 m .48253 .38859 L .49478 .38974 L F
.48299 .39357 m .48276 .39108 L .47057 .3918 L 1 .91 0 r
F
.49523 .39227 m .48276 .39108 L .48299 .39357 L .974 .863 0 r
F
.49543 .39225 m .49522 .39223 L .49523 .39227 L .985 .872 0 r
F
.49543 .39225 m .49522 .39223 L .49523 .39227 L .974 .863 0 r
F
.49522 .39223 m .48276 .39108 L .49523 .39227 L F
.49309 .39361 m .46947 .39858 L .46943 .40296 L 1 .814 0 r
F
.48321 .39607 m .48299 .39357 L .47053 .39425 L 1 .904 0 r
F
.49309 .39871 m .49309 .39361 L .46943 .40296 L 1 .815 0 r
F
.49567 .39481 m .48299 .39357 L .48321 .39607 L .971 .856 0 r
F
.49592 .39478 m .49566 .39476 L .49567 .39481 L .982 .865 0 r
F
.49592 .39478 m .49566 .39476 L .49567 .39481 L .971 .856 0 r
F
.49566 .39476 m .48299 .39357 L .49567 .39481 L F
.48343 .39858 m .48321 .39607 L .47048 .39671 L 1 .897 0 r
F
.49609 .39735 m .48321 .39607 L .48343 .39858 L .969 .85 0 r
F
.49309 .39871 m .46943 .40296 L .46939 .40725 L 1 .815 0 r
F
.48365 .40111 m .48343 .39858 L .47043 .39919 L 1 .89 0 r
F
.4931 .40365 m .49309 .39871 L .46939 .40725 L 1 .815 0 r
F
.4965 .3999 m .48343 .39858 L .48365 .40111 L .966 .843 0 r
F
.48387 .40364 m .48365 .40111 L .47039 .40168 L 1 .883 0 r
F
.49689 .40245 m .48365 .40111 L .48387 .40364 L .965 .837 0 r
F
.4931 .40365 m .46939 .40725 L .46935 .41144 L 1 .815 0 r
F
.48408 .40618 m .48387 .40364 L .47034 .40418 L 1 .877 0 r
F
.49312 .40845 m .4931 .40365 L .46935 .41144 L 1 .815 0 r
F
.49727 .40502 m .48387 .40364 L .48408 .40618 L .963 .83 0 r
F
.48429 .40873 m .48408 .40618 L .4703 .4067 L 1 .87 0 r
F
.49392 .40791 m .48408 .40618 L .48429 .40873 L .962 .823 0 r
F
.49763 .40759 m .49429 .40716 L .49392 .40791 L F
.49429 .40716 m .48408 .40618 L .49392 .40791 L F
.49312 .40845 m .46935 .41144 L .46932 .41555 L 1 .815 0 r
F
.49314 .41312 m .49312 .40845 L .46932 .41555 L F
.48449 .4113 m .48429 .40873 L .47025 .40922 L 1 .864 0 r
F
.49434 .41048 m .48429 .40873 L .48449 .4113 L .961 .817 0 r
F
.49797 .41018 m .49472 .40974 L .49434 .41048 L F
.49472 .40974 m .48429 .40873 L .49434 .41048 L F
.48469 .41387 m .48449 .4113 L .47021 .41176 L 1 .857 0 r
F
.49314 .41312 m .46932 .41555 L .46928 .41958 L 1 .815 0 r
F
.49317 .41767 m .49314 .41312 L .46928 .41958 L 1 .816 0 r
F
.49474 .41306 m .48449 .4113 L .48469 .41387 L .96 .81 0 r
F
.49829 .41277 m .49514 .41232 L .49474 .41306 L F
.49514 .41232 m .48449 .4113 L .49474 .41306 L F
.48489 .41646 m .48469 .41387 L .47017 .41432 L 1 .851 0 r
F
.49513 .41565 m .48469 .41387 L .48489 .41646 L .959 .803 0 r
F
.49858 .41538 m .49553 .41491 L .49513 .41565 L F
.49553 .41491 m .48469 .41387 L .49513 .41565 L F
.49317 .41767 m .46928 .41958 L .46924 .42355 L 1 .816 0 r
F
.48508 .41905 m .48489 .41646 L .47012 .41689 L 1 .844 0 r
F
.4932 .42212 m .49317 .41767 L .46924 .42355 L 1 .816 0 r
F
.49549 .41825 m .48489 .41646 L .48508 .41905 L .958 .797 0 r
F
.49886 .41799 m .4959 .41751 L .49549 .41825 L F
.4959 .41751 m .48489 .41646 L .49549 .41825 L F
.48527 .42166 m .48508 .41905 L .47008 .41946 L 1 .838 0 r
F
.49583 .42086 m .48508 .41905 L .48527 .42166 L .958 .79 0 r
F
.49911 .42061 m .49626 .42012 L .49583 .42086 L F
.49626 .42012 m .48508 .41905 L .49583 .42086 L F
.4932 .42212 m .46924 .42355 L .4692 .42746 L 1 .816 0 r
F
.49324 .42647 m .4932 .42212 L .4692 .42746 L 1 .815 0 r
F
.48546 .42428 m .48527 .42166 L .47004 .42205 L 1 .831 0 r
F
.49614 .42349 m .48527 .42166 L .48546 .42428 L .957 .783 0 r
F
.49935 .42325 m .49658 .42274 L .49614 .42349 L F
.49658 .42274 m .48527 .42166 L .49614 .42349 L F
.49324 .42647 m .4692 .42746 L .46917 .4313 L 1 .815 0 r
F
.48564 .4269 m .48546 .42428 L .47 .42466 L 1 .825 0 r
F
.49644 .42612 m .48546 .42428 L .48564 .4269 L .957 .777 0 r
F
.49955 .42589 m .49689 .42536 L .49644 .42612 L F
.49689 .42536 m .48546 .42428 L .49644 .42612 L F
.49328 .43073 m .49324 .42647 L .46917 .4313 L 1 .815 0 r
F
.48582 .42954 m .48564 .4269 L .46996 .42727 L 1 .818 0 r
F
.4967 .42876 m .48564 .4269 L .48582 .42954 L .956 .77 0 r
F
.49974 .42854 m .49717 .42799 L .4967 .42876 L F
.49717 .42799 m .48564 .4269 L .4967 .42876 L F
.49328 .43073 m .46917 .4313 L .46913 .4351 L 1 .815 0 r
F
.49332 .43491 m .49328 .43073 L .46913 .4351 L 1 .814 0 r
F
.48599 .43218 m .48582 .42954 L .46992 .42989 L 1 .812 0 r
F
.49694 .43141 m .48582 .42954 L .48599 .43218 L .956 .763 0 r
F
.49989 .43121 m .49742 .43063 L .49694 .43141 L F
.49742 .43063 m .48582 .42954 L .49694 .43141 L F
.48616 .43484 m .48599 .43218 L .46987 .43252 L 1 .805 0 r
F
.49715 .43407 m .48599 .43218 L .48616 .43484 L .955 .757 0 r
F
.50002 .43388 m .49765 .43327 L .49715 .43407 L F
.49765 .43327 m .48599 .43218 L .49715 .43407 L F
.49332 .43491 m .46913 .4351 L .4691 .43885 L 1 .814 0 r
F
.49336 .43901 m .49332 .43491 L .4691 .43885 L F
.48633 .4375 m .48616 .43484 L .46983 .43517 L 1 .799 0 r
F
.49734 .43675 m .48616 .43484 L .48633 .4375 L .955 .75 0 r
F
.50013 .43656 m .49785 .43592 L .49734 .43675 L F
.49785 .43592 m .48616 .43484 L .49734 .43675 L F
.49336 .43901 m .4691 .43885 L .46906 .44255 L 1 .814 0 r
F
.49341 .44305 m .49336 .43901 L .46906 .44255 L 1 .813 0 r
F
.48649 .44017 m .48633 .4375 L .4698 .43782 L 1 .792 0 r
F
.49749 .43943 m .48633 .4375 L .48649 .44017 L .955 .743 0 r
F
.5002 .43924 m .49802 .43858 L .49749 .43943 L F
.49802 .43858 m .48633 .4375 L .49749 .43943 L F
.48665 .44284 m .48649 .44017 L .46976 .44048 L 1 .786 0 r
F
.49762 .44211 m .48649 .44017 L .48665 .44284 L .954 .736 0 r
F
.50025 .44194 m .49817 .44124 L .49762 .44211 L F
.49817 .44124 m .48649 .44017 L .49762 .44211 L F
.49341 .44305 m .46906 .44255 L .46903 .44622 L 1 .813 0 r
F
.49346 .44703 m .49341 .44305 L .46903 .44622 L 1 .812 0 r
F
.4868 .44553 m .48665 .44284 L .46972 .44314 L 1 .779 0 r
F
.49771 .44481 m .48665 .44284 L .4868 .44553 L .954 .729 0 r
F
.50027 .44464 m .49828 .44391 L .49771 .44481 L F
.49828 .44391 m .48665 .44284 L .49771 .44481 L F
.49346 .44703 m .46903 .44622 L .46899 .44984 L 1 .812 0 r
F
.49351 .45095 m .49346 .44703 L .46899 .44984 L F
.48695 .44822 m .4868 .44553 L .46968 .44582 L 1 .772 0 r
F
.49777 .44751 m .4868 .44553 L .48695 .44822 L .954 .722 0 r
F
.50025 .44735 m .49837 .44658 L .49777 .44751 L F
.49837 .44658 m .4868 .44553 L .49777 .44751 L F
.49351 .45095 m .46899 .44984 L .46896 .45343 L 1 .812 0 r
F
.48709 .45091 m .48695 .44822 L .46964 .4485 L 1 .766 0 r
F
.4978 .45022 m .48695 .44822 L .48709 .45091 L .953 .715 0 r
F
.50021 .45007 m .49842 .44925 L .4978 .45022 L F
.49842 .44925 m .48695 .44822 L .4978 .45022 L F
.49356 .45482 m .49351 .45095 L .46896 .45343 L 1 .811 0 r
F
.48723 .45361 m .48709 .45091 L .46961 .45119 L 1 .759 0 r
F
.49779 .45294 m .48709 .45091 L .48723 .45361 L .953 .708 0 r
F
.50014 .45279 m .49844 .45193 L .49779 .45294 L F
.49844 .45193 m .48709 .45091 L .49779 .45294 L F
.49356 .45482 m .46896 .45343 L .46893 .45699 L 1 .811 0 r
F
.49361 .45865 m .49356 .45482 L .46893 .45699 L 1 .81 0 r
F
.48737 .45631 m .48723 .45361 L .46957 .45388 L 1 .752 0 r
F
.49774 .45566 m .48723 .45361 L .48737 .45631 L .952 .701 0 r
F
.50003 .45551 m .49843 .45461 L .49774 .45566 L F
.49843 .45461 m .48723 .45361 L .49774 .45566 L F
.49361 .45865 m .46893 .45699 L .46889 .46051 L 1 .81 0 r
F
.4875 .45902 m .48737 .45631 L .46953 .45658 L 1 .745 0 r
F
.49766 .45839 m .48737 .45631 L .4875 .45902 L .952 .694 0 r
F
.49988 .45825 m .49839 .45729 L .49766 .45839 L F
.49839 .45729 m .48737 .45631 L .49766 .45839 L F
.49367 .46243 m .49361 .45865 L .46889 .46051 L 1 .809 0 r
F
.48762 .46174 m .4875 .45902 L .4695 .45928 L 1 .739 0 r
F
.49755 .46112 m .4875 .45902 L .48762 .46174 L .952 .687 0 r
F
.49971 .46098 m .49831 .45997 L .49755 .46112 L F
.49831 .45997 m .4875 .45902 L .49755 .46112 L F
.49367 .46243 m .46889 .46051 L .46886 .464 L 1 .809 0 r
F
.49372 .46617 m .49367 .46243 L .46886 .464 L F
.48774 .46445 m .48762 .46174 L .46946 .46199 L 1 .732 0 r
F
.49739 .46385 m .48762 .46174 L .48774 .46445 L .951 .68 0 r
F
.49949 .46373 m .49819 .46266 L .49739 .46385 L F
.49819 .46266 m .48762 .46174 L .49739 .46385 L F
.49372 .46617 m .46886 .464 L .46883 .46747 L 1 .809 0 r
F
.48774 .46445 m .46946 .46199 L .46943 .4647 L 1 .732 0 r
F
.49378 .46988 m .49372 .46617 L .46883 .46747 L 1 .809 0 r
F
.48786 .46717 m .48774 .46445 L .46943 .4647 L 1 .725 0 r
F
.49719 .4666 m .48774 .46445 L .48786 .46717 L .951 .673 0 r
F
.49924 .46647 m .49804 .46534 L .49719 .4666 L F
.49804 .46534 m .48774 .46445 L .49719 .4666 L F
.48786 .46717 m .46943 .4647 L .4694 .46741 L 1 .725 0 r
F
.49378 .46988 m .46883 .46747 L .4688 .47091 L 1 .809 0 r
F
.48797 .46988 m .48786 .46717 L .4694 .46741 L 1 .718 0 r
F
.49695 .46934 m .48786 .46717 L .48797 .46988 L .95 .665 0 r
F
.49895 .46922 m .49785 .46803 L .49695 .46934 L F
.49785 .46803 m .48786 .46717 L .49695 .46934 L F
.48797 .46988 m .4694 .46741 L .46936 .47012 L 1 .718 0 r
F
.49383 .47356 m .49378 .46988 L .4688 .47091 L 1 .808 0 r
F
.48808 .4726 m .48797 .46988 L .46936 .47012 L 1 .711 0 r
F
.49667 .47209 m .48797 .46988 L .48808 .4726 L .949 .658 0 r
F
.49862 .47197 m .49762 .47071 L .49667 .47209 L F
.49762 .47071 m .48797 .46988 L .49667 .47209 L F
.49383 .47356 m .4688 .47091 L .46877 .47433 L 1 .808 0 r
F
.48808 .4726 m .46936 .47012 L .46933 .47284 L 1 .711 0 r
F
.49389 .4772 m .49383 .47356 L .46877 .47433 L 1 .808 0 r
F
.48819 .47532 m .48808 .4726 L .46933 .47284 L 1 .704 0 r
F
.49634 .47483 m .48808 .4726 L .48819 .47532 L .949 .651 0 r
F
.49824 .47472 m .49735 .47339 L .49634 .47483 L F
.49735 .47339 m .48808 .4726 L .49634 .47483 L F
.49389 .4772 m .46877 .47433 L .46874 .47772 L 1 .808 0 r
F
.48819 .47532 m .46933 .47284 L .4693 .47556 L 1 .704 0 r
F
.49395 .48083 m .49389 .4772 L .46874 .47772 L 1 .809 0 r
F
.48828 .47804 m .48819 .47532 L .4693 .47556 L 1 .697 0 r
F
.49596 .47759 m .48819 .47532 L .48828 .47804 L .948 .643 0 r
F
.49782 .47747 m .49704 .47607 L .49596 .47759 L F
.49704 .47607 m .48819 .47532 L .49596 .47759 L F
.49395 .48083 m .46874 .47772 L .46871 .48109 L 1 .809 0 r
F
.48828 .47804 m .4693 .47556 L .46927 .47827 L 1 .697 0 r
F
.48838 .48076 m .48828 .47804 L .46927 .47827 L 1 .69 0 r
F
.49782 .47747 m .48816 .47533 L .48826 .47805 L .959 .656 0 r
F
.50716 .47692 m .49796 .47615 L .49782 .47747 L F
.49796 .47615 m .49704 .47607 L .49782 .47747 L .948 .643 0 r
F
.49796 .47615 m .48816 .47533 L .49782 .47747 L .959 .656 0 r
F
.5071 .47692 m .49796 .47615 L .49782 .47747 L .948 .643 0 r
F
.50716 .47692 m .50693 .47419 L .49824 .47472 L .959 .656 0 r
F
.49815 .47519 m .49824 .47472 L .49634 .47483 L .948 .643 0 r
F
.49691 .47606 m .49634 .47483 L .48819 .47532 L F
.50716 .47692 m .49824 .47472 L .49796 .47615 L .959 .656 0 r
F
.5071 .47692 m .49634 .47483 L .49691 .47606 L .948 .643 0 r
F
.49796 .47615 m .49824 .47472 L .48816 .47533 L .959 .656 0 r
F
.5071 .47692 m .50688 .4742 L .49824 .47472 L .948 .643 0 r
F
.5071 .47692 m .49824 .47472 L .49815 .47519 L F
.50737 .47964 m .50716 .47692 L .49782 .47747 L .959 .649 0 r
F
.50737 .47964 m .49782 .47747 L .49781 .47754 L F
.49753 .47882 m .49782 .47747 L .48828 .47804 L .948 .636 0 r
F
.50737 .47964 m .49759 .47749 L .49824 .47888 L .959 .649 0 r
F
.48838 .48076 m .46927 .47827 L .46924 .48099 L 1 .69 0 r
F
.49735 .48023 m .48828 .47804 L .48838 .48076 L .948 .636 0 r
F
.50737 .47964 m .49753 .47882 L .49735 .48023 L .959 .649 0 r
F
.50732 .47964 m .49753 .47882 L .49735 .48023 L .948 .636 0 r
F
.49753 .47882 m .48828 .47804 L .49735 .48023 L F
.49735 .48023 m .49753 .47882 L .49711 .48024 L .959 .649 0 r
F
.49711 .48024 m .48826 .47805 L .48836 .48076 L F
.49753 .47882 m .48826 .47805 L .49711 .48024 L F
.50732 .47964 m .5071 .47692 L .49792 .47747 L .948 .636 0 r
F
.49792 .4775 m .49792 .47747 L .49782 .47747 L F
.50732 .47964 m .49792 .47747 L .49792 .4775 L F
.50732 .47964 m .49782 .47747 L .49753 .47882 L F
.49781 .47754 m .49782 .47747 L .49759 .47749 L .959 .649 0 r
F
.49824 .47888 m .49759 .47749 L .48826 .47805 L F
.498 .47474 m .48806 .47262 L .48816 .47533 L .96 .663 0 r
F
.49824 .47472 m .49804 .47468 L .498 .47474 L F
.49804 .47468 m .48806 .47262 L .498 .47474 L F
.50693 .47419 m .49835 .47348 L .49824 .47472 L F
.49835 .47348 m .49735 .47339 L .49824 .47472 L .949 .651 0 r
F
.49835 .47348 m .48806 .47262 L .49824 .47472 L .96 .663 0 r
F
.50688 .4742 m .49835 .47348 L .49824 .47472 L .949 .651 0 r
F
.50693 .47419 m .50669 .47147 L .49862 .47197 L .96 .663 0 r
F
.50693 .47419 m .49862 .47197 L .49835 .47348 L F
.50688 .4742 m .50664 .47148 L .49862 .47197 L .949 .651 0 r
F
.49835 .47348 m .49862 .47197 L .48808 .4726 L F
.50688 .4742 m .49862 .47197 L .49835 .47348 L F
.49835 .47348 m .49862 .47197 L .48806 .47262 L .96 .663 0 r
F
.49834 .47198 m .48795 .4699 L .48806 .47262 L .96 .67 0 r
F
.49862 .47197 m .49839 .47192 L .49834 .47198 L F
.49839 .47192 m .48795 .4699 L .49834 .47198 L F
.50669 .47147 m .4987 .4708 L .49862 .47197 L F
.4987 .4708 m .49762 .47071 L .49862 .47197 L .949 .658 0 r
F
.4987 .4708 m .48795 .4699 L .49862 .47197 L .96 .67 0 r
F
.50664 .47148 m .4987 .4708 L .49862 .47197 L .949 .658 0 r
F
.50669 .47147 m .50644 .46875 L .49895 .46922 L .96 .67 0 r
F
.50669 .47147 m .49895 .46922 L .4987 .4708 L F
.50664 .47148 m .5064 .46876 L .49895 .46922 L .949 .658 0 r
F
.4987 .4708 m .49895 .46922 L .48797 .46988 L F
.50664 .47148 m .49895 .46922 L .4987 .4708 L F
.4987 .4708 m .49895 .46922 L .48795 .4699 L .96 .67 0 r
F
.49865 .46924 m .48784 .46719 L .48795 .4699 L .961 .677 0 r
F
.49895 .46922 m .49869 .46917 L .49865 .46924 L F
.49869 .46917 m .48784 .46719 L .49865 .46924 L F
.50644 .46875 m .49901 .46813 L .49895 .46922 L F
.49901 .46813 m .49785 .46803 L .49895 .46922 L .95 .665 0 r
F
.49901 .46813 m .48784 .46719 L .49895 .46922 L .961 .677 0 r
F
.5064 .46876 m .49901 .46813 L .49895 .46922 L .95 .665 0 r
F
.50644 .46875 m .50618 .46603 L .49924 .46647 L .961 .677 0 r
F
.50644 .46875 m .49924 .46647 L .49901 .46813 L F
.5064 .46876 m .50615 .46605 L .49924 .46647 L .95 .665 0 r
F
.49901 .46813 m .49924 .46647 L .48786 .46717 L F
.5064 .46876 m .49924 .46647 L .49901 .46813 L F
.49901 .46813 m .49924 .46647 L .48784 .46719 L .961 .677 0 r
F
.49891 .46649 m .48772 .46448 L .48784 .46719 L .961 .684 0 r
F
.49924 .46647 m .49896 .46642 L .49891 .46649 L F
.49896 .46642 m .48772 .46448 L .49891 .46649 L F
.50618 .46603 m .49928 .46545 L .49924 .46647 L F
.49928 .46545 m .49804 .46534 L .49924 .46647 L .951 .673 0 r
F
.49928 .46545 m .48772 .46448 L .49924 .46647 L .961 .684 0 r
F
.50615 .46605 m .49928 .46545 L .49924 .46647 L .951 .673 0 r
F
.50618 .46603 m .50591 .46332 L .49949 .46373 L .961 .684 0 r
F
.50618 .46603 m .49949 .46373 L .49928 .46545 L F
.50615 .46605 m .50588 .46333 L .49949 .46373 L .951 .673 0 r
F
.49928 .46545 m .49949 .46373 L .48774 .46445 L F
.50615 .46605 m .49949 .46373 L .49928 .46545 L F
.49928 .46545 m .49949 .46373 L .48772 .46448 L .961 .684 0 r
F
.49912 .46375 m .4876 .46177 L .48772 .46448 L .961 .691 0 r
F
.49949 .46373 m .49918 .46367 L .49912 .46375 L F
.49918 .46367 m .4876 .46177 L .49912 .46375 L F
.50591 .46332 m .49951 .46277 L .49949 .46373 L F
.49951 .46277 m .49819 .46266 L .49949 .46373 L .951 .68 0 r
F
.49951 .46277 m .4876 .46177 L .49949 .46373 L .961 .691 0 r
F
.50588 .46333 m .49951 .46277 L .49949 .46373 L .951 .68 0 r
F
.48762 .46174 m .4695 .45928 L .46946 .46199 L 1 .739 0 r
F
.50591 .46332 m .50564 .4606 L .49971 .46098 L .961 .691 0 r
F
.50591 .46332 m .49971 .46098 L .49951 .46277 L F
.50588 .46333 m .50561 .46062 L .49971 .46098 L .951 .68 0 r
F
.49951 .46277 m .49971 .46098 L .48762 .46174 L F
.50588 .46333 m .49971 .46098 L .49951 .46277 L F
.49951 .46277 m .49971 .46098 L .4876 .46177 L .961 .691 0 r
F
.4993 .46101 m .48747 .45906 L .4876 .46177 L .962 .698 0 r
F
.49971 .46098 m .49936 .46093 L .4993 .46101 L F
.49936 .46093 m .48747 .45906 L .4993 .46101 L F
.50564 .4606 m .49971 .4601 L .49971 .46098 L F
.49971 .4601 m .49831 .45997 L .49971 .46098 L .952 .687 0 r
F
.49971 .4601 m .48747 .45906 L .49971 .46098 L .962 .698 0 r
F
.50561 .46062 m .49971 .4601 L .49971 .46098 L .952 .687 0 r
F
.4875 .45902 m .46953 .45658 L .4695 .45928 L 1 .745 0 r
F
.50564 .4606 m .50535 .45789 L .49988 .45825 L .962 .698 0 r
F
.50561 .46062 m .50532 .45791 L .49988 .45825 L .952 .687 0 r
F
.49971 .4601 m .49988 .45825 L .4875 .45902 L F
.50564 .4606 m .49988 .45825 L .49971 .4601 L .962 .698 0 r
F
.50561 .46062 m .49988 .45825 L .49971 .4601 L .952 .687 0 r
F
.49971 .4601 m .49988 .45825 L .48747 .45906 L .962 .698 0 r
F
.49944 .45828 m .48734 .45636 L .48747 .45906 L .962 .705 0 r
F
.49988 .45825 m .4995 .45819 L .49944 .45828 L F
.4995 .45819 m .48734 .45636 L .49944 .45828 L F
.50535 .45789 m .49988 .45742 L .49988 .45825 L F
.49988 .45742 m .49839 .45729 L .49988 .45825 L .952 .694 0 r
F
.49988 .45742 m .48734 .45636 L .49988 .45825 L .962 .705 0 r
F
.50532 .45791 m .49988 .45742 L .49988 .45825 L .952 .694 0 r
F
.48737 .45631 m .46957 .45388 L .46953 .45658 L 1 .752 0 r
F
.50535 .45789 m .50505 .45518 L .50003 .45551 L .962 .705 0 r
F
.50532 .45791 m .50503 .4552 L .50003 .45551 L .952 .694 0 r
F
.49988 .45742 m .50003 .45551 L .48737 .45631 L F
.50535 .45789 m .50003 .45551 L .49988 .45742 L .962 .705 0 r
F
.50532 .45791 m .50003 .45551 L .49988 .45742 L .952 .694 0 r
F
.49988 .45742 m .50003 .45551 L .48734 .45636 L .962 .705 0 r
F
.49954 .45555 m .4872 .45366 L .48734 .45636 L .962 .712 0 r
F
.50003 .45551 m .4996 .45545 L .49954 .45555 L F
.4996 .45545 m .4872 .45366 L .49954 .45555 L F
.50505 .45518 m .50001 .45475 L .50003 .45551 L F
.50001 .45475 m .49843 .45461 L .50003 .45551 L .952 .701 0 r
F
.50001 .45475 m .4872 .45366 L .50003 .45551 L .962 .712 0 r
F
.50503 .4552 m .50001 .45475 L .50003 .45551 L .952 .701 0 r
F
.48723 .45361 m .46961 .45119 L .46957 .45388 L 1 .759 0 r
F
.50505 .45518 m .50475 .45248 L .50014 .45279 L .962 .712 0 r
F
.50503 .4552 m .50473 .45249 L .50014 .45279 L .952 .701 0 r
F
.50001 .45475 m .50014 .45279 L .48723 .45361 L F
.50505 .45518 m .50014 .45279 L .50001 .45475 L .962 .712 0 r
F
.50503 .4552 m .50014 .45279 L .50001 .45475 L .952 .701 0 r
F
.50001 .45475 m .50014 .45279 L .4872 .45366 L .962 .712 0 r
F
.49961 .45282 m .48706 .45096 L .4872 .45366 L .963 .719 0 r
F
.50014 .45279 m .49967 .45272 L .49961 .45282 L F
.49967 .45272 m .48706 .45096 L .49961 .45282 L F
.50475 .45248 m .50012 .45208 L .50014 .45279 L F
.50012 .45208 m .49844 .45193 L .50014 .45279 L .953 .708 0 r
F
.50012 .45208 m .48706 .45096 L .50014 .45279 L .963 .719 0 r
F
.50473 .45249 m .50012 .45208 L .50014 .45279 L .953 .708 0 r
F
.48709 .45091 m .46964 .4485 L .46961 .45119 L 1 .766 0 r
F
.50475 .45248 m .50444 .44978 L .50021 .45007 L .963 .719 0 r
F
.50473 .45249 m .50442 .44979 L .50021 .45007 L .953 .708 0 r
F
.50012 .45208 m .50021 .45007 L .48709 .45091 L F
.50475 .45248 m .50021 .45007 L .50012 .45208 L .963 .719 0 r
F
.50473 .45249 m .50021 .45007 L .50012 .45208 L .953 .708 0 r
F
.50012 .45208 m .50021 .45007 L .48706 .45096 L .963 .719 0 r
F
.49963 .4501 m .48692 .44827 L .48706 .45096 L .963 .725 0 r
F
.50021 .45007 m .4997 .45 L .49963 .4501 L F
.4997 .45 m .48692 .44827 L .49963 .4501 L F
.50444 .44978 m .50019 .44941 L .50021 .45007 L F
.50019 .44941 m .49842 .44925 L .50021 .45007 L .953 .715 0 r
F
.50019 .44941 m .48692 .44827 L .50021 .45007 L .963 .725 0 r
F
.50442 .44979 m .50019 .44941 L .50021 .45007 L .953 .715 0 r
F
.48695 .44822 m .46968 .44582 L .46964 .4485 L 1 .772 0 r
F
.50444 .44978 m .50411 .44708 L .50025 .44735 L .963 .725 0 r
F
.50442 .44979 m .5041 .4471 L .50025 .44735 L .953 .715 0 r
F
.50019 .44941 m .50025 .44735 L .48695 .44822 L F
.50444 .44978 m .50025 .44735 L .50019 .44941 L .963 .725 0 r
F
.50442 .44979 m .50025 .44735 L .50019 .44941 L .953 .715 0 r
F
.50019 .44941 m .50025 .44735 L .48692 .44827 L .963 .725 0 r
F
.49963 .44739 m .48677 .44559 L .48692 .44827 L .963 .732 0 r
F
.50025 .44735 m .4997 .44728 L .49963 .44739 L F
.4997 .44728 m .48677 .44559 L .49963 .44739 L F
.50411 .44708 m .50023 .44675 L .50025 .44735 L F
.50023 .44675 m .49837 .44658 L .50025 .44735 L .954 .722 0 r
F
.50023 .44675 m .48677 .44559 L .50025 .44735 L .963 .732 0 r
F
.5041 .4471 m .50023 .44675 L .50025 .44735 L .954 .722 0 r
F
.4868 .44553 m .46972 .44314 L .46968 .44582 L 1 .779 0 r
F
.50411 .44708 m .50378 .44439 L .50027 .44464 L .963 .732 0 r
F
.5041 .4471 m .50377 .44441 L .50027 .44464 L .954 .722 0 r
F
.50023 .44675 m .50027 .44464 L .4868 .44553 L F
.50411 .44708 m .50027 .44464 L .50023 .44675 L .963 .732 0 r
F
.5041 .4471 m .50027 .44464 L .50023 .44675 L .954 .722 0 r
F
.50023 .44675 m .50027 .44464 L .48677 .44559 L .963 .732 0 r
F
.49959 .44469 m .48662 .44291 L .48677 .44559 L .964 .739 0 r
F
.50027 .44464 m .49967 .44456 L .49959 .44469 L F
.49967 .44456 m .48662 .44291 L .49959 .44469 L F
.50378 .44439 m .50024 .44409 L .50027 .44464 L F
.50024 .44409 m .49828 .44391 L .50027 .44464 L .954 .729 0 r
F
.50024 .44409 m .48662 .44291 L .50027 .44464 L .964 .739 0 r
F
.50377 .44441 m .50024 .44409 L .50027 .44464 L .954 .729 0 r
F
.48665 .44284 m .46976 .44048 L .46972 .44314 L 1 .786 0 r
F
.50378 .44439 m .50344 .44171 L .50025 .44194 L .964 .739 0 r
F
.50377 .44441 m .50343 .44173 L .50025 .44194 L .954 .729 0 r
F
.50024 .44409 m .50025 .44194 L .48665 .44284 L F
.50378 .44439 m .50025 .44194 L .50024 .44409 L .964 .739 0 r
F
.50377 .44441 m .50025 .44194 L .50024 .44409 L .954 .729 0 r
F
.50024 .44409 m .50025 .44194 L .48662 .44291 L .964 .739 0 r
F
.49951 .44199 m .48646 .44024 L .48662 .44291 L .964 .746 0 r
F
.50025 .44194 m .4996 .44186 L .49951 .44199 L F
.4996 .44186 m .48646 .44024 L .49951 .44199 L F
.50344 .44171 m .50022 .44143 L .50025 .44194 L F
.50022 .44143 m .49817 .44124 L .50025 .44194 L .954 .736 0 r
F
.50022 .44143 m .48646 .44024 L .50025 .44194 L .964 .746 0 r
F
.50343 .44173 m .50022 .44143 L .50025 .44194 L .954 .736 0 r
F
.48649 .44017 m .4698 .43782 L .46976 .44048 L 1 .792 0 r
F
.50344 .44171 m .50309 .43903 L .5002 .43924 L .964 .746 0 r
F
.50343 .44173 m .50308 .43905 L .5002 .43924 L .954 .736 0 r
F
.50022 .44143 m .5002 .43924 L .48649 .44017 L F
.50344 .44171 m .5002 .43924 L .50022 .44143 L .964 .746 0 r
F
.50343 .44173 m .5002 .43924 L .50022 .44143 L .954 .736 0 r
F
.50022 .44143 m .5002 .43924 L .48646 .44024 L .964 .746 0 r
F
.4994 .4393 m .4863 .43757 L .48646 .44024 L .964 .752 0 r
F
.5002 .43924 m .49949 .43916 L .4994 .4393 L F
.49949 .43916 m .4863 .43757 L .4994 .4393 L F
.50309 .43903 m .50017 .43878 L .5002 .43924 L F
.50017 .43878 m .49802 .43858 L .5002 .43924 L .955 .743 0 r
F
.50017 .43878 m .4863 .43757 L .5002 .43924 L .964 .752 0 r
F
.50308 .43905 m .50017 .43878 L .5002 .43924 L .955 .743 0 r
F
.48633 .4375 m .46983 .43517 L .4698 .43782 L 1 .799 0 r
F
.50309 .43903 m .50274 .43636 L .50013 .43656 L .964 .752 0 r
F
.50308 .43905 m .50272 .43638 L .50013 .43656 L .955 .743 0 r
F
.50017 .43878 m .50013 .43656 L .48633 .4375 L F
.50309 .43903 m .50013 .43656 L .50017 .43878 L .964 .752 0 r
F
.50308 .43905 m .50013 .43656 L .50017 .43878 L .955 .743 0 r
F
.50017 .43878 m .50013 .43656 L .4863 .43757 L .964 .752 0 r
F
.49926 .43662 m .48614 .43492 L .4863 .43757 L .964 .759 0 r
F
.50013 .43656 m .49936 .43647 L .49926 .43662 L F
.49936 .43647 m .48614 .43492 L .49926 .43662 L F
.50274 .43636 m .50009 .43613 L .50013 .43656 L F
.50009 .43613 m .49785 .43592 L .50013 .43656 L .955 .75 0 r
F
.50009 .43613 m .48614 .43492 L .50013 .43656 L .964 .759 0 r
F
.50272 .43638 m .50009 .43613 L .50013 .43656 L .955 .75 0 r
F
.48616 .43484 m .46987 .43252 L .46983 .43517 L 1 .805 0 r
F
.50274 .43636 m .50237 .4337 L .50002 .43388 L .964 .759 0 r
F
.50272 .43638 m .50236 .43371 L .50002 .43388 L .955 .75 0 r
F
.50009 .43613 m .50002 .43388 L .48616 .43484 L F
.50274 .43636 m .50002 .43388 L .50009 .43613 L .964 .759 0 r
F
.50272 .43638 m .50002 .43388 L .50009 .43613 L .955 .75 0 r
F
.50009 .43613 m .50002 .43388 L .48614 .43492 L .964 .759 0 r
F
.49909 .43395 m .48597 .43227 L .48614 .43492 L .965 .766 0 r
F
.50002 .43388 m .49919 .43378 L .49909 .43395 L F
.49919 .43378 m .48597 .43227 L .49909 .43395 L F
.50237 .4337 m .49999 .43349 L .50002 .43388 L F
.49999 .43349 m .49765 .43327 L .50002 .43388 L .955 .757 0 r
F
.49999 .43349 m .48597 .43227 L .50002 .43388 L .965 .766 0 r
F
.50236 .43371 m .49999 .43349 L .50002 .43388 L .955 .757 0 r
F
.48599 .43218 m .46992 .42989 L .46987 .43252 L 1 .812 0 r
F
.50237 .4337 m .50199 .43105 L .49989 .43121 L .965 .766 0 r
F
.50236 .43371 m .50199 .43106 L .49989 .43121 L .955 .757 0 r
F
.49999 .43349 m .49989 .43121 L .48599 .43218 L F
.50237 .4337 m .49989 .43121 L .49999 .43349 L .965 .766 0 r
F
.50236 .43371 m .49989 .43121 L .49999 .43349 L .955 .757 0 r
F
.49999 .43349 m .49989 .43121 L .48597 .43227 L .965 .766 0 r
F
.49888 .43128 m .48579 .42963 L .48597 .43227 L .965 .772 0 r
F
.49989 .43121 m .49899 .4311 L .49888 .43128 L F
.49899 .4311 m .48579 .42963 L .49888 .43128 L F
.50199 .43105 m .49986 .43086 L .49989 .43121 L F
.49986 .43086 m .49742 .43063 L .49989 .43121 L .956 .763 0 r
F
.49986 .43086 m .48579 .42963 L .49989 .43121 L .965 .772 0 r
F
.50199 .43106 m .49986 .43086 L .49989 .43121 L .956 .763 0 r
F
.48582 .42954 m .46996 .42727 L .46992 .42989 L 1 .818 0 r
F
.50199 .43105 m .50161 .4284 L .49974 .42854 L .965 .772 0 r
F
.50199 .43106 m .5016 .42841 L .49974 .42854 L .956 .763 0 r
F
.49986 .43086 m .49974 .42854 L .48582 .42954 L F
.50199 .43105 m .49974 .42854 L .49986 .43086 L .965 .772 0 r
F
.50199 .43106 m .49974 .42854 L .49986 .43086 L .956 .763 0 r
F
.49986 .43086 m .49974 .42854 L .48579 .42963 L .965 .772 0 r
F
.49865 .42863 m .48562 .427 L .48579 .42963 L .966 .779 0 r
F
.49974 .42854 m .49877 .42844 L .49865 .42863 L F
.49877 .42844 m .48562 .427 L .49865 .42863 L F
.50161 .4284 m .49971 .42823 L .49974 .42854 L F
.49971 .42823 m .49717 .42799 L .49974 .42854 L .956 .77 0 r
F
.49971 .42823 m .48562 .427 L .49974 .42854 L .966 .779 0 r
F
.5016 .42841 m .49971 .42823 L .49974 .42854 L .956 .77 0 r
F
.48564 .4269 m .47 .42466 L .46996 .42727 L 1 .825 0 r
F
.50161 .4284 m .50122 .42576 L .49955 .42589 L .966 .779 0 r
F
.5016 .42841 m .50121 .42577 L .49955 .42589 L .956 .77 0 r
F
.49971 .42823 m .49955 .42589 L .48564 .4269 L F
.50161 .4284 m .49955 .42589 L .49971 .42823 L .966 .779 0 r
F
.5016 .42841 m .49955 .42589 L .49971 .42823 L .956 .77 0 r
F
.49971 .42823 m .49955 .42589 L .48562 .427 L .966 .779 0 r
F
.49838 .42598 m .48543 .42437 L .48562 .427 L .966 .786 0 r
F
.49955 .42589 m .49851 .42578 L .49838 .42598 L F
.49851 .42578 m .48543 .42437 L .49838 .42598 L F
.50122 .42576 m .49953 .42561 L .49955 .42589 L F
.49953 .42561 m .49689 .42536 L .49955 .42589 L .957 .777 0 r
F
.49953 .42561 m .48543 .42437 L .49955 .42589 L .966 .786 0 r
F
.50121 .42577 m .49953 .42561 L .49955 .42589 L .957 .777 0 r
F
.48546 .42428 m .47004 .42205 L .47 .42466 L 1 .831 0 r
F
.50122 .42576 m .50082 .42313 L .49935 .42325 L .966 .786 0 r
F
.50121 .42577 m .50081 .42314 L .49935 .42325 L .957 .777 0 r
F
.49953 .42561 m .49935 .42325 L .48546 .42428 L F
.50122 .42576 m .49935 .42325 L .49953 .42561 L .966 .786 0 r
F
.50121 .42577 m .49935 .42325 L .49953 .42561 L .957 .777 0 r
F
.49953 .42561 m .49935 .42325 L .48543 .42437 L .966 .786 0 r
F
.49809 .42335 m .48525 .42176 L .48543 .42437 L .967 .792 0 r
F
.49935 .42325 m .49822 .42313 L .49809 .42335 L F
.49822 .42313 m .48525 .42176 L .49809 .42335 L F
.50082 .42313 m .49932 .423 L .49935 .42325 L F
.49932 .423 m .49658 .42274 L .49935 .42325 L .957 .783 0 r
F
.49932 .423 m .48525 .42176 L .49935 .42325 L .967 .792 0 r
F
.50081 .42314 m .49932 .423 L .49935 .42325 L .957 .783 0 r
F
.48527 .42166 m .47008 .41946 L .47004 .42205 L 1 .838 0 r
F
.50082 .42313 m .50041 .42051 L .49911 .42061 L .967 .792 0 r
F
.50081 .42314 m .50041 .42052 L .49911 .42061 L .957 .783 0 r
F
.49932 .423 m .49911 .42061 L .48527 .42166 L F
.50082 .42313 m .49911 .42061 L .49932 .423 L .967 .792 0 r
F
.50081 .42314 m .49911 .42061 L .49932 .423 L .957 .783 0 r
F
.49932 .423 m .49911 .42061 L .48525 .42176 L .967 .792 0 r
F
.49776 .42073 m .48506 .41916 L .48525 .42176 L .967 .799 0 r
F
.49911 .42061 m .4979 .42049 L .49776 .42073 L F
.4979 .42049 m .48506 .41916 L .49776 .42073 L F
.50041 .42051 m .49909 .42039 L .49911 .42061 L F
.49909 .42039 m .49626 .42012 L .49911 .42061 L .958 .79 0 r
F
.49909 .42039 m .48506 .41916 L .49911 .42061 L .967 .799 0 r
F
.50041 .42052 m .49909 .42039 L .49911 .42061 L .958 .79 0 r
F
.48508 .41905 m .47012 .41689 L .47008 .41946 L 1 .844 0 r
F
.50041 .42051 m .49999 .41789 L .49886 .41799 L .967 .799 0 r
F
.50041 .42052 m .49999 .4179 L .49886 .41799 L .958 .79 0 r
F
.49909 .42039 m .49886 .41799 L .48508 .41905 L F
.50041 .42051 m .49886 .41799 L .49909 .42039 L .967 .799 0 r
F
.50041 .42052 m .49886 .41799 L .49909 .42039 L .958 .79 0 r
F
.49909 .42039 m .49886 .41799 L .48506 .41916 L .967 .799 0 r
F
.49741 .41811 m .48487 .41657 L .48506 .41916 L .968 .806 0 r
F
.49886 .41799 m .49756 .41786 L .49741 .41811 L F
.49756 .41786 m .48487 .41657 L .49741 .41811 L F
.49999 .41789 m .49884 .41779 L .49886 .41799 L F
.49884 .41779 m .4959 .41751 L .49886 .41799 L .958 .797 0 r
F
.49884 .41779 m .48487 .41657 L .49886 .41799 L .968 .806 0 r
F
.49999 .4179 m .49884 .41779 L .49886 .41799 L .958 .797 0 r
F
.48489 .41646 m .47017 .41432 L .47012 .41689 L 1 .851 0 r
F
.49999 .41789 m .49957 .41529 L .49858 .41538 L .968 .806 0 r
F
.49999 .4179 m .49957 .4153 L .49858 .41538 L .958 .797 0 r
F
.49884 .41779 m .49858 .41538 L .48489 .41646 L F
.49999 .41789 m .49858 .41538 L .49884 .41779 L .968 .806 0 r
F
.49999 .4179 m .49858 .41538 L .49884 .41779 L .958 .797 0 r
F
.49884 .41779 m .49858 .41538 L .48487 .41657 L .968 .806 0 r
F
.49703 .41551 m .48467 .41398 L .48487 .41657 L .969 .812 0 r
F
.49858 .41538 m .49719 .41524 L .49703 .41551 L F
.49719 .41524 m .48467 .41398 L .49703 .41551 L F
.49957 .41529 m .49857 .4152 L .49858 .41538 L F
.49857 .4152 m .49553 .41491 L .49858 .41538 L .959 .803 0 r
F
.49857 .4152 m .48467 .41398 L .49858 .41538 L .969 .812 0 r
F
.49957 .4153 m .49857 .4152 L .49858 .41538 L .959 .803 0 r
F
.48469 .41387 m .47021 .41176 L .47017 .41432 L 1 .857 0 r
F
.49957 .41529 m .49914 .4127 L .49829 .41277 L .969 .812 0 r
F
.49957 .4153 m .49914 .4127 L .49829 .41277 L .959 .803 0 r
F
.49857 .4152 m .49829 .41277 L .48469 .41387 L F
.49957 .41529 m .49829 .41277 L .49857 .4152 L .969 .812 0 r
F
.49957 .4153 m .49829 .41277 L .49857 .4152 L .959 .803 0 r
F
.49857 .4152 m .49829 .41277 L .48467 .41398 L .969 .812 0 r
F
.49663 .41292 m .48447 .41141 L .48467 .41398 L .969 .819 0 r
F
.49829 .41277 m .49679 .41263 L .49663 .41292 L F
.49679 .41263 m .48447 .41141 L .49663 .41292 L F
.49914 .4127 m .49827 .41262 L .49829 .41277 L F
.49827 .41262 m .49514 .41232 L .49829 .41277 L .96 .81 0 r
F
.49827 .41262 m .48447 .41141 L .49829 .41277 L .969 .819 0 r
F
.49914 .4127 m .49827 .41262 L .49829 .41277 L .96 .81 0 r
F
.48449 .4113 m .47025 .40922 L .47021 .41176 L 1 .864 0 r
F
.49914 .4127 m .4987 .41011 L .49797 .41018 L .969 .819 0 r
F
.49914 .4127 m .4987 .41012 L .49797 .41018 L .96 .81 0 r
F
.49827 .41262 m .49797 .41018 L .48449 .4113 L F
.49914 .4127 m .49797 .41018 L .49827 .41262 L .969 .819 0 r
F
.49914 .4127 m .49797 .41018 L .49827 .41262 L .96 .81 0 r
F
.49827 .41262 m .49797 .41018 L .48447 .41141 L .969 .819 0 r
F
.49619 .41034 m .48427 .40885 L .48447 .41141 L .971 .825 0 r
F
.49797 .41018 m .49636 .41002 L .49619 .41034 L F
.49636 .41002 m .48427 .40885 L .49619 .41034 L F
.4987 .41011 m .49795 .41005 L .49797 .41018 L F
.49795 .41005 m .49472 .40974 L .49797 .41018 L .961 .817 0 r
F
.49795 .41005 m .48427 .40885 L .49797 .41018 L .971 .825 0 r
F
.4987 .41012 m .49795 .41005 L .49797 .41018 L .961 .817 0 r
F
.48429 .40873 m .4703 .4067 L .47025 .40922 L 1 .87 0 r
F
.4987 .41011 m .49825 .40754 L .49763 .40759 L .971 .825 0 r
F
.4987 .41012 m .49825 .40754 L .49763 .40759 L .961 .817 0 r
F
.49795 .41005 m .49763 .40759 L .48429 .40873 L F
.4987 .41011 m .49763 .40759 L .49795 .41005 L .971 .825 0 r
F
.4987 .41012 m .49763 .40759 L .49795 .41005 L .961 .817 0 r
F
.49795 .41005 m .49763 .40759 L .48427 .40885 L .971 .825 0 r
F
.49574 .40777 m .48406 .4063 L .48427 .40885 L .972 .832 0 r
F
.49763 .40759 m .49591 .40743 L .49574 .40777 L F
.49591 .40743 m .48406 .4063 L .49574 .40777 L F
.49825 .40754 m .49762 .40748 L .49763 .40759 L F
.49762 .40748 m .49429 .40716 L .49763 .40759 L .962 .823 0 r
F
.49762 .40748 m .48406 .4063 L .49763 .40759 L .972 .832 0 r
F
.49825 .40754 m .49762 .40748 L .49763 .40759 L .962 .823 0 r
F
.48408 .40618 m .47034 .40418 L .4703 .4067 L 1 .877 0 r
F
.49825 .40754 m .4978 .40497 L .49727 .40502 L .972 .832 0 r
F
.49825 .40754 m .4978 .40497 L .49727 .40502 L .962 .823 0 r
F
.49762 .40748 m .49727 .40502 L .48408 .40618 L F
.49825 .40754 m .49727 .40502 L .49762 .40748 L .972 .832 0 r
F
.49825 .40754 m .49727 .40502 L .49762 .40748 L .962 .823 0 r
F
.49762 .40748 m .49727 .40502 L .48406 .4063 L .972 .832 0 r
F
.49525 .40522 m .48385 .40377 L .48406 .4063 L .973 .839 0 r
F
.49727 .40502 m .49544 .40485 L .49525 .40522 L F
.49544 .40485 m .48385 .40377 L .49525 .40522 L F
.4978 .40497 m .49726 .40492 L .49727 .40502 L F
.49727 .405 m .48387 .40364 L .49727 .40502 L .963 .83 0 r
F
.49726 .40492 m .48387 .40364 L .49736 .40501 L F
.49726 .40492 m .48385 .40377 L .49727 .40502 L .973 .839 0 r
F
.49736 .40501 m .49727 .405 L .49727 .40502 L .963 .83 0 r
F
.4978 .40497 m .49726 .40492 L .49736 .40501 L F
.4978 .40497 m .49739 .40267 L .49693 .40271 L .973 .839 0 r
F
.49739 .40267 m .49734 .40241 L .49689 .40245 L F
.49726 .40492 m .49689 .40245 L .48387 .40364 L .963 .83 0 r
F
.49739 .40267 m .49689 .40245 L .48385 .40377 L .973 .839 0 r
F
.4978 .40497 m .49734 .40241 L .49689 .40245 L .963 .83 0 r
F
.4978 .40497 m .49693 .40271 L .4972 .40452 L .973 .839 0 r
F
.4978 .40497 m .49497 .40286 L .49726 .40492 L F
.4978 .40497 m .49689 .40245 L .49726 .40492 L .963 .83 0 r
F
.4972 .40452 m .49693 .40271 L .49497 .40286 L .973 .839 0 r
F
.49726 .40492 m .49497 .40286 L .48385 .40377 L F
.48387 .40364 m .47039 .40168 L .47034 .40418 L 1 .883 0 r
F
.49689 .40245 m .48363 .40124 L .48385 .40377 L .975 .845 0 r
F
.49734 .40241 m .49689 .40237 L .49689 .40245 L F
.49689 .40237 m .49665 .40235 L .49689 .40245 L .965 .837 0 r
F
.49665 .40235 m .48365 .40111 L .49689 .40245 L F
.49689 .40237 m .48363 .40124 L .49689 .40245 L .975 .845 0 r
F
.49734 .40241 m .49689 .40237 L .49689 .40245 L .965 .837 0 r
F
.48365 .40111 m .47043 .39919 L .47039 .40168 L 1 .89 0 r
F
.49734 .40241 m .49687 .39986 L .4965 .3999 L .975 .845 0 r
F
.49734 .40241 m .49687 .39986 L .4965 .3999 L .965 .837 0 r
F
.49689 .40237 m .4965 .3999 L .48365 .40111 L F
.49734 .40241 m .4965 .3999 L .49689 .40237 L .975 .845 0 r
F
.49734 .40241 m .4965 .3999 L .49689 .40237 L .965 .837 0 r
F
.49689 .40237 m .4965 .3999 L .48363 .40124 L .975 .845 0 r
F
.4965 .3999 m .48341 .39872 L .48363 .40124 L .977 .852 0 r
F
.49687 .39986 m .49649 .39983 L .4965 .3999 L F
.4965 .39988 m .48343 .39858 L .4965 .3999 L .966 .843 0 r
F
.49649 .39983 m .48341 .39872 L .4965 .3999 L .977 .852 0 r
F
.49658 .39989 m .4965 .39988 L .4965 .3999 L .966 .843 0 r
F
.49687 .39986 m .49649 .39983 L .49658 .39989 L F
.49649 .39983 m .48343 .39858 L .49658 .39989 L F
.49687 .39986 m .49643 .39748 L .49612 .39751 L .977 .852 0 r
F
.49643 .39748 m .4964 .39731 L .49609 .39735 L F
.49649 .39983 m .49609 .39735 L .48343 .39858 L .966 .843 0 r
F
.49643 .39748 m .49609 .39735 L .48341 .39872 L .977 .852 0 r
F
.49687 .39986 m .4964 .39732 L .49609 .39735 L .966 .843 0 r
F
.49687 .39986 m .49612 .39751 L .49645 .39956 L .977 .852 0 r
F
.49687 .39986 m .49382 .39773 L .49649 .39983 L F
.49687 .39986 m .49609 .39735 L .49649 .39983 L .966 .843 0 r
F
.49645 .39956 m .49612 .39751 L .49382 .39773 L .977 .852 0 r
F
.49649 .39983 m .49382 .39773 L .48341 .39872 L F
.48343 .39858 m .47048 .39671 L .47043 .39919 L 1 .897 0 r
F
.49609 .39735 m .48319 .39621 L .48341 .39872 L .979 .859 0 r
F
.4964 .39731 m .49609 .39729 L .49609 .39735 L F
.49609 .39729 m .49589 .39727 L .49609 .39735 L .969 .85 0 r
F
.49609 .39729 m .48319 .39621 L .49609 .39735 L .979 .859 0 r
F
.4964 .39732 m .49609 .39729 L .49609 .39735 L .969 .85 0 r
F
.49589 .39727 m .48321 .39607 L .49609 .39735 L F
.4964 .39731 m .49592 .39478 L .49567 .39481 L .979 .859 0 r
F
.4964 .39732 m .49592 .39478 L .49567 .39481 L .969 .85 0 r
F
.49609 .39729 m .49567 .39481 L .48321 .39607 L F
.4964 .39731 m .49567 .39481 L .49609 .39729 L .979 .859 0 r
F
.4964 .39732 m .49567 .39481 L .49609 .39729 L .969 .85 0 r
F
.49609 .39729 m .49567 .39481 L .48319 .39621 L .979 .859 0 r
F
.48321 .39607 m .47053 .39425 L .47048 .39671 L 1 .904 0 r
F
.49567 .39481 m .48297 .39372 L .48319 .39621 L .982 .865 0 r
F
.49566 .39476 m .48297 .39372 L .49567 .39481 L F
.49592 .39478 m .49543 .39225 L .49523 .39227 L F
.49592 .39478 m .49543 .39225 L .49523 .39227 L .971 .856 0 r
F
.49566 .39476 m .49523 .39227 L .48299 .39357 L F
.49592 .39478 m .49523 .39227 L .49566 .39476 L .982 .865 0 r
F
.49592 .39478 m .49523 .39227 L .49566 .39476 L .971 .856 0 r
F
.49566 .39476 m .49523 .39227 L .48297 .39372 L .982 .865 0 r
F
.48299 .39357 m .47057 .3918 L .47053 .39425 L 1 .91 0 r
F
.49523 .39227 m .48274 .39123 L .48297 .39372 L .985 .872 0 r
F
.49522 .39223 m .48274 .39123 L .49523 .39227 L F
.49543 .39225 m .49494 .38972 L .49478 .38974 L F
.49543 .39225 m .49494 .38972 L .49478 .38974 L .974 .863 0 r
F
.49522 .39223 m .49478 .38974 L .48276 .39108 L F
.49543 .39225 m .49478 .38974 L .49522 .39223 L .985 .872 0 r
F
.49543 .39225 m .49478 .38974 L .49522 .39223 L .974 .863 0 r
F
.49522 .39223 m .49478 .38974 L .48274 .39123 L .985 .872 0 r
F
.48276 .39108 m .47062 .38937 L .47057 .3918 L 1 .917 0 r
F
.49478 .38974 m .48251 .38875 L .48274 .39123 L .989 .879 0 r
F
.49477 .3897 m .48251 .38875 L .49478 .38974 L F
.49494 .38972 m .49444 .38719 L .49431 .38721 L F
.49494 .38972 m .49444 .38719 L .49431 .38721 L .977 .869 0 r
F
.49477 .3897 m .49431 .38721 L .48253 .38859 L F
.49494 .38972 m .49431 .38721 L .49477 .3897 L .989 .879 0 r
F
.49494 .38972 m .49431 .38721 L .49477 .3897 L .977 .869 0 r
F
.49477 .3897 m .49431 .38721 L .48251 .38875 L .989 .879 0 r
F
.48253 .38859 m .47067 .38694 L .47062 .38937 L 1 .924 0 r
F
.49431 .38721 m .48228 .38628 L .48251 .38875 L .993 .886 0 r
F
.49431 .38718 m .48228 .38628 L .49431 .38721 L F
.49444 .38719 m .49394 .38466 L .49384 .38468 L F
.49444 .38719 m .49394 .38466 L .49384 .38468 L .981 .876 0 r
F
.49431 .38718 m .49384 .38468 L .4823 .38611 L F
.49444 .38719 m .49384 .38468 L .49431 .38718 L .993 .886 0 r
F
.49444 .38719 m .49384 .38468 L .49431 .38718 L .981 .876 0 r
F
.49431 .38718 m .49384 .38468 L .48228 .38628 L .993 .886 0 r
F
.4823 .38611 m .47071 .38453 L .47067 .38694 L 1 .932 0 r
F
.49384 .38468 m .48204 .38381 L .48228 .38628 L .998 .892 0 r
F
.49384 .38466 m .48204 .38381 L .49384 .38468 L F
.49394 .38466 m .49343 .38213 L .49335 .38214 L F
.49394 .38466 m .49343 .38213 L .49335 .38214 L .986 .882 0 r
F
.49384 .38466 m .49335 .38214 L .48206 .38364 L F
.49394 .38466 m .49335 .38214 L .49384 .38466 L .998 .892 0 r
F
.49394 .38466 m .49335 .38214 L .49384 .38466 L .986 .882 0 r
F
.49384 .38466 m .49335 .38214 L .48204 .38381 L .998 .892 0 r
F
.48206 .38364 m .47076 .38212 L .47071 .38453 L 1 .939 0 r
F
.49335 .38214 m .4818 .38134 L .48204 .38381 L 1 .899 0 r
F
.49335 .38213 m .4818 .38134 L .49335 .38214 L F
.49343 .38213 m .49292 .37959 L .49286 .3796 L F
.49343 .38213 m .49292 .37959 L .49286 .3796 L .992 .889 0 r
F
.49335 .38213 m .49286 .3796 L .48182 .38117 L F
.49343 .38213 m .49286 .3796 L .49335 .38213 L 1 .899 0 r
F
.49343 .38213 m .49286 .3796 L .49335 .38213 L .992 .889 0 r
F
.49335 .38213 m .49286 .3796 L .4818 .38134 L 1 .899 0 r
F
.48182 .38117 m .47081 .37973 L .47076 .38212 L 1 .946 0 r
F
.49286 .3796 m .48156 .37888 L .4818 .38134 L 1 .905 0 r
F
.49286 .37959 m .48156 .37888 L .49286 .3796 L F
.49292 .37959 m .4924 .37704 L .49236 .37705 L F
.49292 .37959 m .4924 .37704 L .49236 .37705 L .998 .895 0 r
F
.49286 .37959 m .49236 .37705 L .48158 .3787 L F
.49292 .37959 m .49236 .37705 L .49286 .37959 L 1 .905 0 r
F
.49292 .37959 m .49236 .37705 L .49286 .37959 L .998 .895 0 r
F
.49286 .37959 m .49236 .37705 L .48156 .37888 L 1 .905 0 r
F
.48158 .3787 m .47086 .37734 L .47081 .37973 L 1 .954 0 r
F
.49236 .37705 m .48132 .37641 L .48156 .37888 L 1 .911 0 r
F
.49236 .37704 m .48132 .37641 L .49236 .37705 L F
.4924 .37704 m .49188 .37447 L .49185 .37448 L F
.4924 .37704 m .49188 .37447 L .49185 .37448 L 1 .901 0 r
F
.49236 .37704 m .49185 .37448 L .48134 .37622 L F
.4924 .37704 m .49185 .37448 L .49236 .37704 L 1 .911 0 r
F
.4924 .37704 m .49185 .37448 L .49236 .37704 L 1 .901 0 r
F
.49236 .37704 m .49185 .37448 L .48132 .37641 L 1 .911 0 r
F
.48134 .37622 m .47091 .37496 L .47086 .37734 L 1 .962 0 r
F
.49185 .37448 m .48107 .37393 L .48132 .37641 L 1 .917 0 r
F
.49185 .37447 m .48107 .37393 L .49185 .37448 L F
.49188 .37447 m .49136 .37188 L .49134 .37188 L F
.49188 .37447 m .49136 .37188 L .49134 .37188 L 1 .907 0 r
F
.49185 .37447 m .49134 .37188 L .48109 .37373 L F
.49188 .37447 m .49134 .37188 L .49185 .37447 L 1 .917 0 r
F
.49188 .37447 m .49134 .37188 L .49185 .37447 L 1 .907 0 r
F
.49185 .37447 m .49134 .37188 L .48107 .37393 L 1 .917 0 r
F
.48109 .37373 m .47096 .37257 L .47091 .37496 L 1 .969 0 r
F
.49134 .37188 m .48083 .37144 L .48107 .37393 L 1 .923 0 r
F
.49136 .37188 m .49134 .37188 L .49134 .37188 L F
.49134 .37188 m .48083 .37144 L .49134 .37188 L F
.49136 .37188 m .49134 .37188 L .49134 .37188 L 1 .912 0 r
F
.49134 .37188 m .48663 .37159 L .49134 .37188 L F
.49136 .37188 m .49084 .36924 L .49082 .36925 L 1 .923 0 r
F
.49136 .37188 m .49084 .36924 L .49082 .36925 L 1 .912 0 r
F
.49134 .37188 m .49082 .36925 L .48084 .37124 L F
.49136 .37188 m .49082 .36925 L .49134 .37188 L 1 .923 0 r
F
.49136 .37188 m .49082 .36925 L .49134 .37188 L 1 .912 0 r
F
.49134 .37188 m .49082 .36925 L .48083 .37144 L 1 .923 0 r
F
.48084 .37124 m .471 .37019 L .47096 .37257 L 1 .977 0 r
F
.48084 .37124 m .4806 .36872 L .471 .37019 L F
.48653 .37019 m .48058 .36894 L .48083 .37144 L 1 .927 0 r
F
.49082 .36925 m .48645 .36911 L .48653 .37019 L F
.48645 .36911 m .48058 .36894 L .48653 .37019 L F
.49084 .36924 m .49082 .36924 L .49082 .36925 L F
.49082 .36924 m .48058 .36894 L .49082 .36925 L F
.49084 .36924 m .49082 .36924 L .49082 .36925 L 1 .916 0 r
F
.49082 .36924 m .486 .36899 L .49082 .36925 L F
.49084 .36924 m .49031 .36656 L .4903 .36656 L 1 .927 0 r
F
.49084 .36924 m .49031 .36656 L .4903 .36656 L 1 .916 0 r
F
.49082 .36924 m .4903 .36656 L .4806 .36872 L F
.49084 .36924 m .4903 .36656 L .49082 .36924 L 1 .927 0 r
F
.49084 .36924 m .4903 .36656 L .49082 .36924 L 1 .916 0 r
F
.49082 .36924 m .4903 .36656 L .48058 .36894 L 1 .927 0 r
F
.4806 .36872 m .47105 .3678 L .471 .37019 L 1 .985 0 r
F
.4806 .36872 m .48035 .36616 L .47105 .3678 L F
.48582 .36766 m .48033 .3664 L .48058 .36894 L 1 .931 0 r
F
.4903 .36656 m .48566 .36649 L .48582 .36766 L F
.48566 .36649 m .48033 .3664 L .48582 .36766 L F
.49031 .36656 m .4903 .36656 L .4903 .36656 L F
.4903 .36656 m .48033 .3664 L .4903 .36656 L F
.49031 .36656 m .4903 .36656 L .4903 .36656 L 1 .92 0 r
F
.4903 .36656 m .48536 .36636 L .4903 .36656 L F
.49031 .36656 m .48979 .36381 L .48978 .36381 L 1 .931 0 r
F
.49031 .36656 m .48979 .36381 L .48978 .36381 L 1 .92 0 r
F
.4903 .36656 m .48978 .36381 L .48035 .36616 L F
.49031 .36656 m .48978 .36381 L .4903 .36656 L 1 .931 0 r
F
.49031 .36656 m .48978 .36381 L .4903 .36656 L 1 .92 0 r
F
.4903 .36656 m .48978 .36381 L .48033 .3664 L 1 .931 0 r
F
.48035 .36616 m .4711 .3654 L .47105 .3678 L 1 .993 0 r
F
.48035 .36616 m .4801 .36357 L .4711 .3654 L F
.48511 .36509 m .48008 .36382 L .48033 .3664 L 1 .933 0 r
F
.48978 .36381 m .48485 .36381 L .48511 .36509 L F
.48485 .36381 m .48008 .36382 L .48511 .36509 L F
.48979 .36381 m .48978 .36381 L .48978 .36381 L F
.48978 .36381 m .48008 .36382 L .48978 .36381 L F
.48979 .36381 m .48978 .36381 L .48978 .36381 L 1 .922 0 r
F
.48978 .36381 m .48472 .36368 L .48978 .36381 L F
.48979 .36381 m .48927 .36097 L .48926 .36097 L 1 .933 0 r
F
.48979 .36381 m .48927 .36097 L .48926 .36097 L 1 .922 0 r
F
.48978 .36381 m .48926 .36097 L .4801 .36357 L F
.48979 .36381 m .48926 .36097 L .48978 .36381 L 1 .933 0 r
F
.48979 .36381 m .48926 .36097 L .48978 .36381 L 1 .922 0 r
F
.48978 .36381 m .48926 .36097 L .48008 .36382 L 1 .933 0 r
F
.4801 .36357 m .47115 .36297 L .4711 .3654 L 1 .999 0 r
F
.4801 .36357 m .47985 .36091 L .47115 .36297 L F
.4844 .36248 m .47983 .36118 L .48008 .36382 L 1 .932 0 r
F
.48926 .36097 m .48403 .36108 L .4844 .36248 L F
.48403 .36108 m .47983 .36118 L .4844 .36248 L F
.48927 .36097 m .48926 .36097 L .48926 .36097 L F
.48926 .36097 m .47983 .36118 L .48926 .36097 L F
.48927 .36097 m .48926 .36097 L .48926 .36097 L 1 .921 0 r
F
.48926 .36097 m .48407 .36094 L .48926 .36097 L F
.48927 .36097 m .48875 .358 L .48875 .358 L 1 .932 0 r
F
.48927 .36097 m .48875 .358 L .48875 .358 L 1 .921 0 r
F
.48926 .36097 m .48875 .358 L .47985 .36091 L F
.48927 .36097 m .48875 .358 L .48926 .36097 L 1 .932 0 r
F
.48927 .36097 m .48875 .358 L .48926 .36097 L 1 .921 0 r
F
.48926 .36097 m .48875 .358 L .47983 .36118 L 1 .932 0 r
F
.4837 .3598 m .47958 .35846 L .47983 .36118 L 1 .928 0 r
F
.48875 .358 m .4832 .35828 L .4837 .3598 L F
.4832 .35828 m .47958 .35846 L .4837 .3598 L F
.48875 .358 m .48875 .358 L .48875 .358 L F
.48875 .358 m .47958 .35846 L .48875 .358 L F
.48875 .358 m .48875 .358 L .48875 .358 L 1 .917 0 r
F
.48875 .358 m .48341 .3581 L .48875 .358 L F
.48875 .358 m .48825 .35486 L .48825 .35486 L 1 .928 0 r
F
.48875 .358 m .48825 .35486 L .48825 .35486 L 1 .917 0 r
F
.48875 .358 m .48825 .35486 L .4796 .35817 L F
.48875 .358 m .48825 .35486 L .48875 .358 L 1 .928 0 r
F
.48875 .358 m .48825 .35486 L .48875 .358 L 1 .917 0 r
F
.48875 .358 m .48825 .35486 L .47958 .35846 L 1 .928 0 r
F
.483 .35704 m .47933 .35563 L .47958 .35846 L 1 .92 0 r
F
.48825 .35486 m .48236 .35537 L .483 .35704 L F
.48236 .35537 m .47933 .35563 L .483 .35704 L F
.48825 .35486 m .48825 .35486 L .48825 .35486 L F
.48825 .35486 m .47933 .35563 L .48825 .35486 L F
.48825 .35486 m .48825 .35486 L .48825 .35486 L 1 .909 0 r
F
.48825 .35486 m .48277 .35514 L .48825 .35486 L F
.48825 .35486 m .48776 .35147 L .48776 .35147 L 1 .92 0 r
F
.48825 .35486 m .48776 .35147 L .48776 .35147 L 1 .909 0 r
F
.48825 .35486 m .48776 .35147 L .47935 .35531 L F
.48825 .35486 m .48776 .35147 L .48825 .35486 L 1 .92 0 r
F
.48825 .35486 m .48776 .35147 L .48825 .35486 L 1 .909 0 r
F
.48825 .35486 m .48776 .35147 L .47933 .35563 L 1 .92 0 r
F
.48232 .35415 m .47909 .35264 L .47933 .35563 L 1 .905 0 r
F
.48776 .35147 m .4815 .35231 L .48232 .35415 L F
.4815 .35231 m .47909 .35264 L .48232 .35415 L F
.48776 .35147 m .48729 .34774 L .48729 .34774 L F
.48776 .35147 m .48729 .34774 L .48729 .34774 L 1 .895 0 r
F
.48776 .35147 m .48729 .34774 L .47911 .35229 L F
.48776 .35147 m .48729 .34774 L .48776 .35147 L 1 .905 0 r
F
.48776 .35147 m .48729 .34774 L .48776 .35147 L 1 .895 0 r
F
.48776 .35147 m .48729 .34774 L .47909 .35264 L 1 .905 0 r
F
.48167 .3511 m .47885 .34943 L .47909 .35264 L 1 .884 0 r
F
.48729 .34774 m .48065 .34907 L .48167 .3511 L F
.48065 .34907 m .47885 .34943 L .48167 .3511 L F
.48729 .34774 m .48685 .34348 L .48685 .34348 L F
.48729 .34774 m .48685 .34348 L .48685 .34348 L 1 .874 0 r
F
.48729 .34774 m .48685 .34348 L .47887 .34904 L F
.48729 .34774 m .48685 .34348 L .48729 .34774 L 1 .884 0 r
F
.48729 .34774 m .48685 .34348 L .48729 .34774 L 1 .874 0 r
F
.48729 .34774 m .48685 .34348 L .47885 .34943 L 1 .884 0 r
F
.48104 .3478 m .47862 .3459 L .47885 .34943 L 1 .854 0 r
F
.48685 .34348 m .4798 .34555 L .48104 .3478 L F
.4798 .34555 m .47862 .3459 L .48104 .3478 L F
.48685 .34348 m .48647 .33843 L .48044 .34416 L F
.48685 .34348 m .48044 .34416 L .47862 .3459 L F
.48647 .33843 m .48618 .33206 L .4799 .33999 L 1 .817 0 r
F
.48647 .33843 m .4799 .33999 L .47841 .34187 L F
.48618 .33206 m .48604 .3234 L .47942 .33498 L 1 .775 0 r
F
.48618 .33206 m .47942 .33498 L .47822 .33709 L F
.48604 .3234 m .48621 .3103 L .47903 .32855 L 1 .734 0 r
F
.48604 .3234 m .47903 .32855 L .47806 .33102 L F
.48621 .3103 m .48699 .28799 L .47882 .31941 L 1 .704 0 r
F
.48621 .3103 m .47882 .31941 L .47798 .32261 L F
.48699 .28799 m .48879 .24886 L .47901 .30405 L 1 .701 0 r
F
.48699 .28799 m .47901 .30405 L .47805 .30943 L F
.48879 .24886 m .49077 .20088 L .48231 .25887 L 1 .748 0 r
F
.48879 .24886 m .48231 .25887 L .47845 .28528 L F
.48879 .24886 m .49077 .20088 L .48879 .24886 L F
.48879 .24886 m .49077 .20088 L .49077 .20088 L 1 .74 0 r
F
.48879 .24886 m .49077 .20088 L .48879 .24886 L F
.49077 .20088 m .47947 .2388 L .47903 .25903 L 1 .814 0 r
F
.49077 .20088 m .47903 .25903 L .47845 .28528 L F
.49077 .20088 m .47983 .23667 L .47975 .23788 L F
.49077 .20088 m .49133 .16745 L .47983 .23667 L F
.47975 .23788 m .47983 .23667 L .47947 .2388 L F
.47788 .26671 m .47962 .23448 L .47223 .1384 L .46 .061 0 r
F
.47834 .27706 m .47931 .24464 L .47788 .26671 L F
.47983 .23667 m .48051 .18444 L .47947 .2388 L 1 .868 0 r
F
.49133 .16745 m .48183 .18236 L .47983 .23667 L F
.48183 .18236 m .48051 .18444 L .47983 .23667 L F
.47228 .13938 m .47237 .13248 L .47223 .13875 L .673 .166 0 r
F
.47947 .2388 m .47243 .13343 L .47228 .13938 L F
.47243 .13343 m .47237 .13248 L .47228 .13938 L F
.47222 .14775 m .47223 .13875 L .4721 .14519 L .431 .058 0 r
F
.47845 .28528 m .47238 .14221 L .47222 .14775 L F
.47238 .14221 m .47223 .13875 L .47222 .14775 L F
.47243 .16362 m .4721 .14519 L .47197 .15181 L .022 0 0 r
F
.47805 .30943 m .47263 .15981 L .47243 .16362 L F
.47263 .15981 m .4721 .14519 L .47243 .16362 L F
.47184 .15861 m .47197 .15181 L .46022 .16201 L 1 1 0 r
F
.47197 .15181 m .46105 .15383 L .46022 .16201 L F
.47197 .15181 m .4721 .14519 L .46105 .15383 L F
.4721 .14519 m .46191 .14603 L .46105 .15383 L F
.4721 .14519 m .47223 .13875 L .46191 .14603 L F
.47223 .13875 m .46282 .13858 L .46191 .14603 L F
.47223 .13875 m .47237 .13248 L .46282 .13858 L F
.47237 .13248 m .46376 .13144 L .46282 .13858 L F
.4725 .12617 m .47264 .12027 L .46472 .12417 L F
.46473 .1246 m .46572 .11802 L .45915 .12732 L F
.46572 .11802 m .46058 .10779 L .45915 .12732 L .736 .681 0 r
F
.47277 .11451 m .47291 .10889 L .46673 .1115 L 1 1 0 r
F
.46673 .11169 m .46777 .10559 L .46254 .10304 L .792 .772 0 r
F
.45769 .10159 m .46325 .09851 L .46503 .31373 L .495 .065 0 r
F
.46495 .31301 m .46503 .31373 L .46505 .31595 L F
.45769 .10159 m .46503 .31373 L .46495 .31301 L F
.47237 .13248 m .4725 .12637 L .46376 .13144 L 1 1 0 r
F
.4725 .12637 m .46473 .1246 L .46376 .13144 L F
.46505 .31595 m .46325 .09851 L .46801 .32818 L .685 .226 0 r
F
.46505 .31595 m .46801 .32818 L .46793 .32793 L F
.46502 .31623 m .46514 .3167 L .46542 .33254 L .687 .228 0 r
F
.46505 .31595 m .46793 .32793 L .46502 .31623 L .685 .226 0 r
F
.4651 .3143 m .46524 .31555 L .46542 .33254 L .687 .228 0 r
F
.46523 .31493 m .468 .3278 L .46732 .32906 L F
.46523 .31493 m .46732 .32906 L .46542 .33254 L F
.46285 .32501 m .46502 .31623 L .46515 .32149 L .682 .203 0 r
F
.46285 .32501 m .46515 .32149 L .46542 .33254 L F
.46281 .32491 m .46496 .31367 L .46502 .31623 L F
.46281 .32491 m .46502 .31623 L .46285 .32501 L F
.46285 .32501 m .46502 .31623 L .46484 .31827 L 0 0 0 r
F
.46263 .32438 m .46281 .32491 L .46281 .32501 L .682 .203 0 r
F
.4627 .32552 m .46292 .3246 L .46285 .32501 L 0 0 0 r
F
.46269 .32412 m .46496 .31367 L .46281 .32491 L .682 .203 0 r
F
.46285 .32501 m .46484 .31827 L .46275 .32502 L 0 0 0 r
F
.46285 .32501 m .46275 .32502 L .46267 .32528 L F
.46267 .32528 m .46275 .32502 L .46264 .32503 L F
.4627 .32552 m .46285 .32501 L .46267 .32528 L F
.46264 .32503 m .46281 .3252 L .46265 .32606 L .682 .203 0 r
F
.46263 .32438 m .46277 .32501 L .46264 .32503 L F
.46277 .32501 m .46281 .3252 L .46264 .32503 L F
.46277 .32501 m .46281 .32501 L .46281 .3252 L F
.46263 .32438 m .46281 .32501 L .46277 .32501 L F
.46178 .31837 m .4626 .32358 L .46263 .3242 L .512 .075 0 r
F
.46242 .32335 m .46263 .3242 L .4627 .32552 L F
.45823 .29062 m .4626 .32358 L .46178 .31837 L F
.46263 .32438 m .46269 .32412 L .46281 .32491 L .682 .203 0 r
F
.46178 .31837 m .46263 .3242 L .46242 .32335 L .512 .075 0 r
F
.46077 .32375 m .46263 .32438 L .46087 .32524 L .53 .09 0 r
F
.45822 .28597 m .46196 .31855 L .46077 .32375 L F
.46196 .31855 m .46263 .32438 L .46077 .32375 L F
.45805 .32561 m .4581 .31488 L .46005 .32686 L .29 .042 0 r
F
.4581 .31488 m .45823 .29062 L .45997 .32523 L F
.4581 .31488 m .45997 .32523 L .46005 .32686 L F
.45996 .32568 m .46013 .3261 L .46012 .3265 L .749 .217 0 r
F
.45996 .32568 m .46012 .3265 L .45999 .32708 L F
.45822 .28597 m .46087 .32524 L .45996 .32568 L .53 .09 0 r
F
.45996 .32568 m .46263 .32438 L .46264 .32503 L .749 .217 0 r
F
.46019 .32625 m .46159 .32584 L .4616 .32554 L .868 .489 0 r
F
.46159 .32584 m .4627 .32552 L .46267 .3253 L F
.45996 .32568 m .46264 .32503 L .46019 .32625 L .749 .217 0 r
F
.46159 .32584 m .46267 .3253 L .46189 .31843 L .868 .489 0 r
F
.46005 .32686 m .46129 .32623 L .46019 .32625 L F
.46129 .32623 m .4627 .32552 L .46019 .32625 L F
.46019 .32625 m .46264 .32503 L .46274 .33287 L .749 .217 0 r
F
.46019 .32625 m .4616 .32554 L .46189 .31843 L .868 .489 0 r
F
.46013 .32625 m .4614 .33315 L .46008 .33343 L .749 .217 0 r
F
.46013 .3261 m .46015 .32625 L .46013 .32625 L F
.46015 .32625 m .4614 .33315 L .46013 .32625 L F
.46017 .32632 m .46274 .33287 L .4614 .33315 L F
.46013 .3261 m .46019 .32625 L .46017 .32632 L F
.46019 .32625 m .46274 .33287 L .46017 .32632 L F
.46011 .32658 m .46019 .32625 L .46004 .3269 L .868 .489 0 r
F
.46019 .32625 m .46189 .31843 L .46015 .32641 L F
.46019 .32625 m .46015 .32641 L .46004 .3269 L F
.44196 .17077 m .45562 .28113 L .458 .32482 L 1 .519 0 r
F
.45792 .32439 m .458 .32482 L .45805 .32561 L F
.44196 .17077 m .458 .32482 L .45792 .32439 L F
.45304 .29528 m .44907 .2511 L .45429 .3262 L 1 .732 0 r
F
.44907 .2511 m .44757 .23433 L .44926 .25751 L F
.44907 .2511 m .44926 .25751 L .45429 .3262 L F
.44757 .23433 m .44822 .25081 L .45429 .3262 L F
.44099 .16108 m .44135 .16637 L .44539 .21631 L F
.44524 .21379 m .44539 .21631 L .45429 .3262 L F
.44099 .16108 m .44539 .21631 L .44524 .21379 L F
.44757 .23433 m .44099 .16108 L .44822 .25081 L F
.45375 .30673 m .44196 .17077 L .45303 .30964 L 1 .707 0 r
F
.45434 .32694 m .45433 .32657 L .44528 .26394 L 0 0 0 r
F
.45375 .30673 m .45303 .30964 L .45439 .3267 L 1 .707 0 r
F
.45447 .32748 m .45439 .3267 L .45449 .32799 L F
.45375 .30673 m .45439 .3267 L .45447 .32748 L F
.44099 .16108 m .44026 .1529 L .44135 .16637 L 1 .732 0 r
F
.45447 .32742 m .45249 .30263 L .45349 .30648 L 0 0 0 r
F
.45249 .30263 m .45292 .29975 L .45349 .30648 L F
.45447 .32742 m .45349 .30648 L .45403 .31599 L F
.45249 .30263 m .44196 .17077 L .45292 .29975 L F
.45436 .32643 m .44196 .17077 L .45447 .32742 L F
.45391 .30409 m .45261 .28952 L .45407 .31041 L 1 .707 0 r
F
.45261 .28952 m .44196 .17077 L .45407 .31041 L F
.45339 .29647 m .45342 .29711 L .45387 .30348 L .136 .025 0 r
F
.45387 .30341 m .45387 .30348 L .45391 .30409 L F
.44196 .17077 m .45805 .32561 L .45381 .31024 L 1 .519 0 r
F
.44026 .1529 m .45791 .32396 L .45694 .31988 L .975 .459 0 r
F
.45367 .30364 m .45694 .31988 L .45374 .30632 L F
.44026 .1529 m .45694 .31988 L .45273 .29896 L F
.45273 .29896 m .45367 .30364 L .45314 .30375 L F
.45367 .30364 m .45374 .30632 L .45314 .30375 L F
.4534 .30486 m .45754 .3224 L .45309 .2994 L .431 .071 0 r
F
.45307 .29927 m .45791 .32396 L .45462 .29415 L F
.45277 .28134 m .45462 .29415 L .45269 .27669 L F
.45307 .29927 m .45462 .29415 L .45277 .28134 L F
.45754 .3224 m .45791 .32396 L .45307 .29927 L F
.45381 .31024 m .45805 .32561 L .45464 .29634 L .432 .072 0 r
F
.45398 .29205 m .45464 .29634 L .454 .29082 L F
.45381 .31024 m .45464 .29634 L .45398 .29205 L F
.4539 .31224 m .45399 .29219 L .45455 .32464 L F
.45448 .32481 m .45455 .32464 L .45459 .32726 L F
.4539 .31224 m .45455 .32464 L .45448 .32481 L F
.45399 .29219 m .45403 .29323 L .45459 .32726 L F
.45429 .3262 m .44958 .26798 L .45324 .30579 L 0 0 0 r
F
.45429 .3262 m .45425 .32548 L .44166 .234 L F
.45324 .30579 m .44026 .1529 L .45314 .30375 L F
.44958 .26798 m .44026 .1529 L .45324 .30579 L F
.45425 .32548 m .45314 .30375 L .44936 .28077 L F
.43372 .14196 m .43826 .14326 L .44749 .27045 L .367 .054 0 r
F
.45425 .32548 m .44936 .28077 L .44166 .234 L 0 0 0 r
F
.45403 .31599 m .45349 .30648 L .45381 .31024 L F
.45433 .32657 m .45381 .31024 L .45327 .30729 L F
.45323 .317 m .45327 .30729 L .4502 .29061 L F
.45433 .32657 m .45327 .30729 L .45323 .317 L F
.45314 .30375 m .4534 .30486 L .45307 .29927 L .431 .071 0 r
F
.45314 .30375 m .45317 .30093 L .45329 .30329 L F
.45314 .30375 m .45306 .29882 L .45317 .30093 L F
.45433 .32657 m .4502 .29061 L .44528 .26394 L 0 0 0 r
F
.45449 .32799 m .45436 .32643 L .45447 .32742 L F
.45447 .3274 m .45381 .31024 L .45434 .32694 L F
.45154 .32426 m .45449 .32799 L .44528 .26394 L .552 .141 0 r
F
.45052 .29955 m .45459 .32726 L .45181 .32056 L 1 .629 0 r
F
.45052 .29955 m .45181 .32056 L .45057 .31758 L F
.45127 .31672 m .45401 .32453 L .45122 .31693 L 1 .534 0 r
F
.45401 .32453 m .45442 .32571 L .45397 .32446 L F
.45401 .32453 m .45397 .32446 L .45122 .31693 L F
.45442 .3261 m .45438 .32512 L .45459 .32726 L 1 .629 0 r
F
.45438 .32512 m .45361 .30959 L .45448 .3253 L F
.45438 .32512 m .45448 .3253 L .45459 .32726 L F
.45336 .30877 m .45361 .30959 L .45442 .3261 L F
.45154 .32426 m .45137 .32263 L .45147 .3251 L .552 .141 0 r
F
.45057 .31758 m .45399 .32893 L .45208 .33491 L 1 .436 0 r
F
.45057 .31758 m .45432 .32659 L .45425 .32928 L F
.45449 .32799 m .45447 .3274 L .45434 .32694 L 0 0 0 r
F
.45432 .32659 m .45459 .32726 L .45425 .32928 L 1 .436 0 r
F
.45361 .30959 m .45393 .3129 L .45459 .32726 L 1 .629 0 r
F
.45459 .32726 m .454 .29082 L .45738 .33362 L .38 .06 0 r
F
.45442 .32571 m .4546 .32451 L .45424 .32956 L .213 .03 0 r
F
.45425 .32928 m .45424 .32956 L .45422 .32984 L F
.45442 .32571 m .45424 .32956 L .45425 .32928 L F
.45057 .31758 m .45425 .32928 L .45399 .32893 L 1 .436 0 r
F
.45399 .32893 m .45442 .32571 L .45425 .32928 L 1 .534 0 r
F
.45399 .32893 m .45425 .32928 L .45422 .32984 L F
.45399 .32893 m .45425 .32928 L .4542 .3296 L 1 .436 0 r
F
.45399 .32893 m .4542 .3296 L .45416 .32968 L F
.44528 .26394 m .45052 .30038 L .45057 .31758 L 1 .629 0 r
F
.44817 .29864 m .44809 .29761 L .45028 .31457 L 0 0 0 r
F
.44809 .29761 m .44528 .26394 L .44998 .31157 L F
.44809 .29761 m .44998 .31157 L .45028 .31457 L F
.44817 .29864 m .45028 .31457 L .45057 .31758 L F
.45083 .33089 m .44528 .26394 L .45091 .33141 L F
.44755 .31437 m .44854 .31625 L .45075 .33078 L .953 .309 0 r
F
.45075 .33078 m .4483 .30468 L .45014 .31654 L 0 0 0 r
F
.45014 .31654 m .44166 .234 L .44999 .31307 L F
.4483 .30468 m .44166 .234 L .45014 .31654 L F
.44464 .3135 m .44829 .31952 L .448 .33009 L .922 .272 0 r
F
.44829 .31952 m .45092 .33205 L .448 .33009 L .91 .243 0 r
F
.44755 .31434 m .45075 .33078 L .44769 .32814 L .953 .309 0 r
F
.448 .33009 m .45092 .33205 L .45011 .33478 L .88 .07 0 r
F
.44769 .32814 m .45075 .33078 L .45003 .33385 L .945 .116 0 r
F
.44854 .33029 m .45003 .33385 L .44999 .33399 L F
.44769 .32814 m .45003 .33385 L .44854 .33029 L F
.45075 .33078 m .45072 .33012 L .45039 .33232 L 0 0 0 r
F
.45072 .33012 m .44999 .31307 L .45039 .33232 L F
.45092 .33205 m .45083 .33089 L .45091 .33141 L F
.45039 .33232 m .45012 .31938 L .45003 .33385 L F
.45092 .33205 m .45085 .32913 L .45011 .33478 L F
.45085 .32913 m .45057 .31758 L .45018 .3321 L F
.45085 .32913 m .45018 .3321 L .45011 .33478 L F
.45043 .3348 m .45053 .31905 L .45208 .33491 L .205 .025 0 r
F
.45013 .33409 m .45053 .31905 L .45043 .3348 L F
.45003 .33385 m .44999 .31307 L .44999 .33399 L 0 0 0 r
F
.45012 .31938 m .44999 .31307 L .45003 .33385 L F
.44999 .33399 m .44999 .31307 L .45059 .32366 L F
.44464 .3135 m .448 .33009 L .44491 .32781 L .922 .272 0 r
F
.44491 .32781 m .448 .33009 L .4472 .33348 L .905 .075 0 r
F
.448 .33009 m .45011 .33478 L .4472 .33348 L .88 .07 0 r
F
.44769 .32814 m .44999 .33399 L .44976 .33387 L .945 .116 0 r
F
.44325 .30485 m .44769 .32814 L .4444 .32483 L .968 .342 0 r
F
.44325 .30485 m .44755 .31434 L .44769 .32814 L F
.44164 .32514 m .44491 .32781 L .44422 .33221 L .927 .106 0 r
F
.44491 .32781 m .4472 .33348 L .44422 .33221 L .905 .075 0 r
F
.4444 .32483 m .44677 .33171 L .44394 .33069 L .978 .176 0 r
F
.44677 .33171 m .44703 .33246 L .44598 .33186 L F
.44677 .33171 m .44598 .33186 L .44394 .33069 L F
.44228 .33977 m .44417 .33799 L .44218 .33928 L .519 .12 0 r
F
.44258 .34119 m .44467 .3403 L .442 .34164 L 0 0 0 r
F
.44467 .3403 m .4355 .29582 L .442 .34164 L .534 .154 0 r
F
.44164 .32514 m .44422 .33221 L .44128 .33158 L .927 .106 0 r
F
.44128 .33158 m .44422 .33221 L .44329 .33231 L .262 0 0 r
F
.44394 .33069 m .44511 .33199 L .44326 .33216 L .685 .026 0 r
F
.44397 .33224 m .44485 .33204 L .44329 .33231 L .186 .217 0 r
F
.44485 .33204 m .44353 .33226 L .44329 .33231 L F
.44422 .33221 m .44459 .33212 L .44397 .33224 L F
.44459 .33212 m .44511 .33199 L .44397 .33224 L F
.44394 .33069 m .44598 .33186 L .44511 .33199 L .685 .026 0 r
F
.44511 .33199 m .44604 .33177 L .4449 .33203 L .186 .217 0 r
F
.44511 .33199 m .4449 .33203 L .44397 .33224 L F
.44511 .33199 m .44703 .33246 L .44674 .3328 L .685 .026 0 r
F
.44598 .33186 m .44703 .33246 L .44511 .33199 L F
.4444 .32483 m .44769 .32814 L .44703 .33246 L .978 .176 0 r
F
.44674 .3328 m .44727 .32128 L .44604 .33177 L .742 .406 0 r
F
.44732 .33055 m .44791 .33135 L .44703 .33246 L .945 .116 0 r
F
.44791 .33135 m .4473 .3326 L .44703 .33246 L F
.4472 .33279 m .4472 .33267 L .447 .33319 L .742 .406 0 r
F
.44703 .33246 m .4473 .3326 L .4472 .33267 L .783 .043 0 r
F
.4472 .33267 m .44727 .32128 L .44701 .33281 L .742 .406 0 r
F
.4472 .33267 m .44701 .33281 L .447 .33319 L F
.4473 .3326 m .44999 .33399 L .4472 .33267 L .783 .043 0 r
F
.44996 .33407 m .45003 .32911 L .44727 .32128 L .205 .025 0 r
F
.4472 .33267 m .44978 .33389 L .44976 .33397 L .783 .043 0 r
F
.4472 .33348 m .44992 .3347 L .44996 .33407 L .742 .406 0 r
F
.44992 .3347 m .45011 .33478 L .44996 .33407 L F
.44999 .33399 m .45008 .33257 L .45004 .33274 L 0 0 0 r
F
.44978 .33389 m .44999 .33399 L .44996 .33407 L .783 .043 0 r
F
.44791 .33135 m .44976 .33387 L .4473 .3326 L .945 .116 0 r
F
.44769 .32814 m .44976 .33387 L .44732 .33055 L F
.4472 .33267 m .44996 .33407 L .44727 .32128 L .742 .406 0 r
F
.4472 .33348 m .44996 .33407 L .4472 .33267 L F
.44978 .33389 m .44996 .33407 L .4494 .33535 L .783 .043 0 r
F
.44996 .33407 m .45004 .33274 L .44949 .33514 L 0 0 0 r
F
.44999 .33399 m .45004 .33274 L .44996 .33407 L F
.4472 .33267 m .44976 .33397 L .4494 .33535 L .783 .043 0 r
F
.44949 .33514 m .45003 .32952 L .4494 .33535 L 0 0 0 r
F
.45003 .32952 m .45059 .32366 L .45003 .32911 L F
.45003 .32952 m .45003 .32911 L .4494 .33535 L F
.45008 .33257 m .45059 .32366 L .44949 .33514 L F
.44996 .33407 m .45208 .33491 L .45003 .32911 L .205 .025 0 r
F
.44998 .33418 m .45011 .33422 L .44996 .33407 L F
.45011 .33422 m .45208 .33491 L .44996 .33407 L F
.44674 .3328 m .4494 .33535 L .4463 .33331 L .783 .043 0 r
F
.44703 .33246 m .4472 .33267 L .44674 .3328 L F
.447 .33319 m .44701 .33272 L .44674 .3328 L .742 .406 0 r
F
.4472 .33348 m .4472 .33279 L .447 .33319 L F
.4472 .33267 m .4494 .33535 L .44674 .3328 L .783 .043 0 r
F
.44701 .33272 m .44701 .33271 L .44674 .3328 L .742 .406 0 r
F
.44701 .33271 m .44727 .32128 L .44674 .3328 L F
.44422 .33221 m .4472 .33348 L .44604 .33177 L .186 .217 0 r
F
.44605 .33303 m .44674 .3328 L .4463 .33331 L .685 .026 0 r
F
.44511 .33199 m .44674 .3328 L .44605 .33303 L F
.44511 .33199 m .4463 .33331 L .44353 .33226 L F
.44511 .33199 m .44353 .33226 L .44326 .33216 L F
.44485 .33204 m .44604 .33177 L .44353 .33226 L .186 .217 0 r
F
.45011 .33478 m .45013 .33409 L .45043 .3348 L .205 .025 0 r
F
.45011 .33478 m .45044 .3348 L .44998 .33418 L F
.45044 .3348 m .45208 .33491 L .44998 .33418 L F
.45053 .31905 m .45057 .31758 L .45091 .3215 L F
.45053 .31905 m .45091 .3215 L .45208 .33491 L F
.44999 .31307 m .4504 .31468 L .45059 .32366 L 1 .534 0 r
F
.4504 .31468 m .45399 .32893 L .45189 .32568 L F
.4504 .31468 m .45189 .32568 L .45059 .32366 L F
.45399 .32893 m .45422 .32984 L .45415 .32972 L F
.45399 .32893 m .45415 .32972 L .45208 .33491 L 1 .436 0 r
F
.45399 .32893 m .45415 .32972 L .45059 .32366 L 1 .534 0 r
F
.45399 .32893 m .45416 .32968 L .45415 .32972 L 1 .436 0 r
F
.45211 .32144 m .45246 .3221 L .45399 .32893 L 1 .534 0 r
F
.45246 .3221 m .45442 .32571 L .45399 .32893 L F
.4504 .31468 m .45397 .32446 L .45211 .32144 L F
.45397 .32446 m .45442 .32571 L .45211 .32144 L F
.45052 .29955 m .45336 .30877 L .45436 .3251 L 1 .629 0 r
F
.45425 .32492 m .45436 .3251 L .45442 .3261 L F
.45052 .29955 m .45436 .3251 L .45425 .32492 L F
.45026 .29097 m .45381 .31024 L .45052 .29955 L F
.45327 .30604 m .45329 .30329 L .45442 .32571 L .431 .071 0 r
F
.45314 .30375 m .45329 .30329 L .45327 .30604 L F
.4546 .32451 m .45577 .31676 L .45496 .32363 L .213 .03 0 r
F
.45459 .32726 m .45738 .33362 L .45425 .32966 L .38 .06 0 r
F
.45425 .32928 m .45425 .32966 L .4542 .3296 L F
.45459 .32726 m .45425 .32966 L .45425 .32928 L F
.4546 .32451 m .45496 .32363 L .45425 .32966 L .213 .03 0 r
F
.45425 .32951 m .45425 .32966 L .45422 .32984 L F
.4546 .32451 m .45425 .32966 L .45425 .32951 L F
.45382 .30918 m .45398 .29205 L .4539 .31224 L .432 .072 0 r
F
.45398 .29205 m .454 .29082 L .45399 .29219 L F
.45398 .29205 m .45399 .29219 L .4539 .31224 L F
.45306 .29882 m .45277 .28134 L .4534 .29657 L .431 .071 0 r
F
.45277 .28134 m .45269 .27669 L .453 .28529 L F
.45277 .28134 m .453 .28529 L .4534 .29657 L F
.45381 .31024 m .45382 .30918 L .4539 .31224 L .432 .072 0 r
F
.4534 .30486 m .45309 .2994 L .45307 .29927 L .431 .071 0 r
F
.45361 .30959 m .45381 .31024 L .45393 .3129 L 1 .629 0 r
F
.45306 .29882 m .4534 .29657 L .45442 .32571 L .431 .071 0 r
F
.42974 .1209 m .43289 .10832 L .43382 .13842 L .751 .198 0 r
F
.42605 .11362 m .42722 .11613 L .4261 .10607 L .336 .072 0 r
F
.42598 .12367 m .42722 .11613 L .42605 .11362 L F
.42598 .12367 m .4284 .12685 L .42722 .11613 L F
.42598 .12317 m .42599 .12177 L .42609 .12334 L F
.42598 .12317 m .42609 .12334 L .42927 .17458 L F
.42598 .12367 m .42598 .12317 L .42927 .17458 L F
.42599 .12177 m .4261 .10673 L .42729 .13087 L F
.4261 .10673 m .42611 .10528 L .42628 .10911 L F
.4261 .10673 m .42628 .10911 L .42729 .13087 L F
.42599 .12177 m .42729 .13087 L .42938 .17622 L F
.42557 .12043 m .42598 .10462 L .42609 .1239 L .368 .111 0 r
F
.42598 .10462 m .42599 .10429 L .42599 .10493 L F
.42598 .10462 m .42599 .10493 L .42609 .1239 L F
.42598 .12367 m .42927 .17458 L .42927 .17455 L .336 .072 0 r
F
.42521 .12006 m .42598 .12367 L .42558 .12352 L .245 0 0 r
F
.41978 .12138 m .42023 .12155 L .42938 .17622 L .636 .12 0 r
F
.42023 .12155 m .42598 .12367 L .42938 .17622 L F
.426 .1274 m .42612 .1285 L .42612 .12938 L .368 .111 0 r
F
.42459 .11713 m .42492 .11871 L .41978 .12138 L .245 0 0 r
F
.42492 .11871 m .42521 .12006 L .42127 .12102 L F
.42492 .11871 m .42127 .12102 L .41978 .12138 L F
.41426 .12185 m .41425 .12181 L .41412 .12184 L .572 .481 0 r
F
.41635 .14839 m .40962 .12579 L .40962 .12579 L .554 .37 0 r
F
.41635 .14839 m .40961 .12577 L .40948 .12592 L F
.42053 .18248 m .41437 .12258 L .41282 .12264 L 1 .714 0 r
F
.41426 .12185 m .41935 .11891 L .41354 .11976 L .572 .481 0 r
F
.40699 .12336 m .4064 .11393 L .4007 .11701 L 1 1 0 r
F
.4085 .12488 m .40816 .12311 L .40699 .12336 L F
.40819 .12348 m .40772 .12135 L .40452 .12405 L .736 .901 0 r
F
.40907 .12469 m .40772 .12135 L .4085 .12488 L F
.40452 .12405 m .40772 .12135 L .40197 .12352 L F
.4085 .12488 m .40819 .12348 L .40452 .12405 L F
.40921 .12503 m .40908 .12471 L .4085 .12488 L F
.40925 .12577 m .40921 .12503 L .4085 .12488 L 1 .759 0 r
F
.40933 .12572 m .40908 .12471 L .4085 .12488 L 1 1 0 r
F
.40831 .12462 m .40798 .12283 L .4083 .12461 L 1 .714 0 r
F
.40432 .12905 m .40925 .12577 L .40842 .12491 L .847 .859 0 r
F
.40432 .12905 m .40842 .12491 L .40356 .12652 L F
.40925 .12577 m .4085 .12488 L .40519 .12419 L 1 .759 0 r
F
.40968 .13223 m .40925 .12577 L .40848 .12553 L F
.40968 .13223 m .40848 .12553 L .40197 .12352 L F
.41213 .16996 m .40968 .13223 L .40197 .12352 L F
.40925 .12577 m .40519 .12419 L .40197 .12352 L F
.40948 .12592 m .40925 .12577 L .41213 .16996 L .554 .37 0 r
F
.40831 .12462 m .4083 .12461 L .4207 .19385 L 1 .714 0 r
F
.42115 .19364 m .40831 .12462 L .4207 .19385 L F
.42033 .19248 m .40798 .12283 L .40222 .12481 L F
.4205 .19271 m .40798 .12283 L .42033 .19248 L F
.42115 .19364 m .42037 .18173 L .40798 .12283 L F
.40908 .12471 m .40907 .12469 L .4085 .12488 L .736 .901 0 r
F
.40925 .12577 m .40933 .12572 L .4085 .12488 L .847 .859 0 r
F
.40927 .12577 m .40933 .12572 L .40925 .12577 L .94 1 0 r
F
.40962 .12579 m .40962 .12579 L .40961 .12577 L .554 .37 0 r
F
.40948 .12592 m .40961 .12577 L .40933 .12572 L .94 1 0 r
F
.42053 .18248 m .41282 .12264 L .40798 .12283 L 1 .714 0 r
F
.40222 .12481 m .40798 .12283 L .40362 .12698 L .048 0 0 r
F
.40798 .12283 m .40906 .12595 L .40362 .12698 L .363 .001 0 r
F
.40906 .12595 m .41061 .1304 L .40553 .12791 L F
.40906 .12595 m .40553 .12791 L .40362 .12698 L F
.40651 .16716 m .41213 .16996 L .41028 .16485 L .379 .114 0 r
F
.40651 .16716 m .41028 .16485 L .40872 .16053 L F
.40651 .16716 m .40872 .16053 L .40545 .16291 L F
.41583 .18935 m .40222 .12481 L .42525 .25795 L .279 .056 0 r
F
.42525 .25795 m .40222 .12481 L .39767 .12591 L 1 .609 0 r
F
.41412 .18121 m .41717 .18067 L .40222 .12481 L .279 .056 0 r
F
.42525 .25795 m .39767 .12591 L .39694 .12609 L 1 .609 0 r
F
.39694 .12609 m .40362 .12698 L .40446 .14976 L .702 .071 0 r
F
.40362 .12698 m .41437 .1697 L .40446 .14976 L .762 .192 0 r
F
.40362 .12698 m .41061 .1304 L .41437 .1697 L F
.40176 .13 m .41037 .14788 L .40116 .13347 L .737 .099 0 r
F
.40222 .12481 m .40293 .12591 L .39694 .12609 L .048 0 0 r
F
.40293 .12591 m .40362 .12698 L .39984 .12647 L F
.40293 .12591 m .39984 .12647 L .39694 .12609 L F
.39048 .12667 m .39633 .12614 L .39454 .13358 L .424 .003 0 r
F
.39633 .12614 m .39694 .12609 L .39543 .13079 L F
.39633 .12614 m .39543 .13079 L .39454 .13358 L F
.39454 .13358 m .40446 .14976 L .43012 .28313 L .856 .357 0 r
F
.40446 .14976 m .42108 .21545 L .43012 .28313 L 1 .429 0 r
F
.41583 .18935 m .41717 .18067 L .41412 .18121 L .279 .056 0 r
F
.40446 .14976 m .41437 .1697 L .42108 .21545 L 1 .429 0 r
F
.40438 .15118 m .41997 .2096 L .41687 .21987 L .921 .375 0 r
F
.39694 .12609 m .40446 .14976 L .39758 .13855 L .702 .071 0 r
F
.40116 .13347 m .40651 .15515 L .40438 .15118 L .921 .375 0 r
F
.40651 .15515 m .41997 .2096 L .40438 .15118 L F
.39534 .13437 m .39758 .13855 L .39526 .13475 L .702 .071 0 r
F
.39694 .12609 m .39758 .13855 L .39534 .13437 L F
.39543 .13079 m .39526 .13475 L .39454 .13358 L F
.39694 .12609 m .39526 .13475 L .39543 .13079 L F
.39454 .13358 m .43012 .28313 L .43502 .32139 L .856 .357 0 r
F
.39484 .13387 m .39523 .13539 L .39359 .14038 L .841 .324 0 r
F
.39523 .13539 m .41687 .21987 L .39483 .14459 L F
.39523 .13539 m .39483 .14459 L .39359 .14038 L F
.39308 .12699 m .39484 .13387 L .39355 .14025 L F
.39484 .13387 m .39359 .14038 L .39355 .14025 L F
.39638 .12342 m .39799 .12681 L .39308 .12699 L .561 .035 0 r
F
.39799 .12681 m .40116 .13347 L .39382 .12758 L F
.39799 .12681 m .39382 .12758 L .39308 .12699 L F
.40292 .12336 m .40448 .12849 L .40176 .13 L .737 .099 0 r
F
.40448 .12849 m .41037 .14788 L .40176 .13 L F
.41377 .1226 m .4138 .12197 L .40798 .12283 L .484 .215 0 r
F
.4138 .12197 m .41382 .12152 L .41051 .12226 L F
.4138 .12197 m .41051 .12226 L .40798 .12283 L F
.40798 .12283 m .41382 .12152 L .41061 .1304 L .363 .001 0 r
F
.4042 .12282 m .40971 .12523 L .40292 .12336 L .223 0 0 r
F
.40772 .12135 m .40829 .12246 L .4042 .12282 L F
.40829 .12246 m .40971 .12523 L .4042 .12282 L F
.41437 .12258 m .41434 .12251 L .41377 .1226 L .484 .215 0 r
F
.41434 .12251 m .41382 .12152 L .41377 .1226 L F
.41437 .12258 m .41946 .11969 L .41382 .12152 L F
.41382 .12152 m .41978 .12138 L .41848 .14077 L .563 .056 0 r
F
.41978 .12138 m .42233 .13593 L .41848 .14077 L .636 .12 0 r
F
.42521 .12006 m .42558 .12352 L .41978 .12138 L .245 0 0 r
F
.42557 .12043 m .42609 .1239 L .42612 .1285 L .368 .111 0 r
F
.42557 .12043 m .42612 .1285 L .426 .1274 L F
.42565 .12456 m .42612 .12938 L .42622 .14893 L F
.42565 .12456 m .42622 .14893 L .42619 .15061 L F
.42557 .12043 m .42612 .12938 L .42565 .12456 L F
.42616 .13592 m .42602 .10943 L .42614 .13599 L 1 .606 0 r
F
.42602 .10943 m .42599 .10508 L .42614 .13599 L F
.41946 .11969 m .42459 .11713 L .41978 .12138 L 0 0 0 r
F
.41946 .11914 m .42557 .12043 L .42625 .15361 L .626 .075 0 r
F
.42614 .13599 m .42599 .10508 L .42545 .13879 L 1 .606 0 r
F
.42599 .10508 m .42598 .10495 L .42545 .13879 L F
.42927 .17455 m .42927 .17458 L .42938 .17622 L .336 .072 0 r
F
.42459 .11713 m .42491 .117 L .42521 .12006 L .245 0 0 r
F
.4228 .11723 m .42557 .12043 L .41946 .11914 L .147 0 0 r
F
.42448 .11628 m .42464 .11688 L .4228 .11723 L F
.42464 .11688 m .42557 .12043 L .4228 .11723 L F
.41935 .11891 m .42448 .11628 L .41946 .11914 L 0 0 0 r
F
.42513 .13301 m .42599 .10429 L .42383 .10885 L 1 .606 0 r
F
.42556 .13172 m .42599 .10429 L .42513 .13301 L F
.42619 .15061 m .42622 .14893 L .42625 .15361 L .368 .111 0 r
F
.42625 .15361 m .42616 .13592 L .42545 .13879 L 1 .606 0 r
F
.42938 .17622 m .42693 .12318 L .42427 .11279 L 1 .58 0 r
F
.42938 .17622 m .42643 .13962 L .43501 .20989 L F
.42427 .11279 m .42628 .10911 L .42418 .1116 L F
.42693 .12318 m .42628 .10911 L .42427 .11279 L F
.42643 .13962 m .42418 .1116 L .42657 .13332 L F
.42643 .13962 m .42657 .13332 L .43501 .20989 L F
.42938 .17622 m .43501 .20989 L .4447 .29782 L F
.42545 .13879 m .42556 .13172 L .42513 .13301 L 1 .606 0 r
F
.42625 .15361 m .42383 .10885 L .43431 .20696 L F
.42936 .17844 m .43431 .20696 L .44216 .28053 L F
.42233 .13593 m .42938 .17622 L .42846 .17326 L .636 .12 0 r
F
.42625 .15361 m .43431 .20696 L .42936 .17844 L 1 .606 0 r
F
.44216 .28053 m .42423 .1126 L .42349 .11999 L 1 .319 0 r
F
.42423 .1126 m .42383 .10885 L .42377 .11081 L F
.42423 .1126 m .42377 .11081 L .42349 .11999 L F
.42049 .18356 m .42468 .18723 L .4268 .20387 L .576 .092 0 r
F
.42022 .17955 m .42468 .18723 L .42049 .18356 L F
.42072 .19418 m .42231 .19987 L .42033 .19248 L .279 .056 0 r
F
.42268 .19923 m .42243 .19786 L .42335 .20443 L .375 .062 0 r
F
.42138 .19497 m .4268 .20387 L .43793 .29161 L .576 .092 0 r
F
.42468 .18723 m .44325 .30485 L .43793 .29161 L .631 .137 0 r
F
.41061 .1304 m .41848 .14077 L .43124 .2367 L .771 .269 0 r
F
.41848 .14077 m .4447 .29782 L .43124 .2367 L .821 .326 0 r
F
.4186 .14479 m .43015 .21131 L .42481 .19777 L .784 .294 0 r
F
.43015 .21131 m .44216 .28053 L .43847 .26291 L F
.42209 .13649 m .42764 .16849 L .41925 .14326 L .636 .12 0 r
F
.42764 .16849 m .42746 .16998 L .41925 .14326 L F
.42233 .13593 m .41925 .14326 L .41848 .14077 L F
.41908 .14365 m .44216 .28053 L .4186 .14479 L .784 .294 0 r
F
.42233 .13593 m .42846 .17326 L .42209 .13649 L .636 .12 0 r
F
.41881 .12258 m .42592 .15225 L .41707 .13173 L .626 .075 0 r
F
.42592 .15225 m .42625 .15361 L .42584 .15264 L F
.42592 .15225 m .42584 .15264 L .41707 .13173 L F
.41382 .12152 m .41448 .12425 L .41061 .1304 L .563 .056 0 r
F
.41448 .12425 m .41848 .14077 L .41133 .13135 L F
.41448 .12425 m .41133 .13135 L .41061 .1304 L F
.42115 .19364 m .42138 .19497 L .42033 .19248 L .576 .092 0 r
F
.4207 .19385 m .4205 .19271 L .42033 .19248 L 1 .714 0 r
F
.42188 .19954 m .42059 .1944 L .42223 .20665 L 1 .513 0 r
F
.42186 .19915 m .42059 .1944 L .42188 .19954 L F
.42186 .19915 m .42033 .19248 L .42059 .1944 L F
.42186 .19915 m .42223 .20665 L .4312 .27369 L F
.42033 .19248 m .43793 .29161 L .4312 .27369 L .576 .092 0 r
F
.42138 .19497 m .43793 .29161 L .42033 .19248 L F
.41061 .1304 m .42515 .20535 L .41437 .1697 L .771 .269 0 r
F
.42515 .20535 m .42426 .20897 L .41437 .1697 L F
.41437 .1697 m .41686 .17971 L .42108 .21545 L .735 .109 0 r
F
.41686 .17971 m .42347 .21214 L .42079 .2102 L 1 .485 0 r
F
.42347 .21214 m .43657 .2764 L .42204 .21793 L F
.41686 .17971 m .42153 .21587 L .42108 .21545 L .735 .109 0 r
F
.42347 .21214 m .42204 .21793 L .41997 .2096 L 1 .485 0 r
F
.42515 .20535 m .43124 .2367 L .42426 .20897 L .771 .269 0 r
F
.41286 .16389 m .41686 .17971 L .41997 .2096 L 1 .485 0 r
F
.41437 .1697 m .42426 .20897 L .41978 .19129 L .735 .109 0 r
F
.41437 .1697 m .42985 .23143 L .41686 .17971 L F
.41037 .14788 m .41686 .17971 L .41286 .16389 L 1 .485 0 r
F
.41978 .19129 m .43124 .2367 L .42985 .23143 L .735 .109 0 r
F
.42426 .20897 m .43124 .2367 L .41978 .19129 L F
.41686 .17971 m .42985 .23143 L .43079 .24802 L 1 .485 0 r
F
.41686 .17971 m .42985 .23143 L .42712 .22106 L .735 .109 0 r
F
.41037 .14788 m .42985 .23143 L .41686 .17971 L 1 .485 0 r
F
.41037 .14788 m .42481 .19777 L .42985 .23143 L F
.43079 .24802 m .42985 .23143 L .43657 .2764 L F
.42985 .23143 m .44679 .31814 L .43657 .2764 L 1 .641 0 r
F
.42481 .19777 m .42972 .22463 L .42985 .23143 L F
.43124 .2367 m .42972 .22463 L .42976 .22675 L .419 .071 0 r
F
.43124 .2367 m .42948 .22486 L .42985 .23143 L F
.42983 .2177 m .43847 .26291 L .42967 .22094 L .784 .294 0 r
F
.43015 .21131 m .43847 .26291 L .42983 .2177 L F
.43015 .21131 m .42967 .22094 L .42481 .19777 L F
.41817 .12011 m .41879 .1206 L .41382 .12152 L 0 0 0 r
F
.41879 .1206 m .41978 .12138 L .41521 .12149 L F
.41879 .1206 m .41521 .12149 L .41382 .12152 L F
.41173 .12235 m .41707 .13173 L .40971 .12523 L .486 .037 0 r
F
.4138 .1207 m .41354 .11976 L .40852 .12142 L .572 .481 0 r
F
.41354 .11976 m .41413 .12176 L .41173 .12235 L .486 .037 0 r
F
.41413 .12176 m .41707 .13173 L .41173 .12235 L F
.41349 .11704 m .41859 .11362 L .41214 .11102 L .887 1 0 r
F
.41935 .11891 m .41946 .11914 L .41354 .11976 L 0 0 0 r
F
.41946 .11969 m .41951 .11993 L .41817 .12011 L F
.41951 .11993 m .41978 .12138 L .41817 .12011 L F
.41354 .11976 m .41946 .11914 L .41707 .13173 L .486 .037 0 r
F
.42764 .16849 m .42846 .17326 L .42746 .16998 L .636 .12 0 r
F
.41707 .13173 m .42625 .15361 L .44216 .28053 L .784 .294 0 r
F
.43847 .26291 m .44216 .28053 L .44284 .286 L 1 .641 0 r
F
.44284 .286 m .44162 .27537 L .44205 .27899 L 1 .319 0 r
F
.4447 .29782 m .42418 .1116 L .44994 .3188 L .3 .049 0 r
F
.44284 .286 m .44658 .30538 L .44277 .28543 L F
.4447 .29782 m .44624 .30401 L .44284 .286 L F
.44624 .30401 m .44658 .30538 L .44284 .286 L F
.44365 .29306 m .4447 .29782 L .44284 .286 L .419 .071 0 r
F
.44216 .28053 m .44027 .26422 L .44162 .27537 L 1 .319 0 r
F
.44216 .28053 m .44162 .27537 L .44284 .286 L F
.44263 .28467 m .44275 .28526 L .41591 .1148 L .3 .049 0 r
F
.44275 .28526 m .44994 .3188 L .43953 .25643 L F
.44027 .26422 m .43098 .18438 L .43962 .25723 L 1 .319 0 r
F
.44027 .26422 m .43962 .25723 L .44018 .2622 L F
.43098 .18438 m .43123 .18584 L .44016 .26174 L F
.44658 .30538 m .44994 .3188 L .44275 .28526 L .3 .049 0 r
F
.44658 .30538 m .44275 .28526 L .44277 .28543 L F
.44205 .27899 m .44016 .26174 L .44679 .31814 L 1 .319 0 r
F
.44027 .26422 m .44018 .2622 L .44205 .27899 L F
.44018 .2622 m .44016 .26174 L .44205 .27899 L F
.44277 .28543 m .44275 .28526 L .44263 .28467 L .3 .049 0 r
F
.44275 .28526 m .43953 .25643 L .41591 .1148 L F
.44018 .2622 m .43962 .25723 L .44016 .26174 L 1 .319 0 r
F
.44284 .286 m .44205 .27899 L .44679 .31814 L F
.44284 .286 m .44277 .28543 L .44263 .28467 L .3 .049 0 r
F
.42481 .19777 m .43847 .26291 L .44284 .286 L 1 .641 0 r
F
.43124 .2367 m .44365 .29306 L .44178 .28105 L .419 .071 0 r
F
.43124 .2367 m .44178 .28105 L .42972 .22463 L F
.42481 .19777 m .42968 .22159 L .42972 .22463 L 1 .641 0 r
F
.42968 .22159 m .44284 .286 L .42972 .22463 L F
.42974 .22665 m .42955 .22332 L .42948 .22486 L .419 .071 0 r
F
.42976 .22675 m .42974 .22645 L .42974 .22665 L F
.42974 .22645 m .42955 .22332 L .42974 .22665 L F
.44365 .29306 m .44284 .286 L .41591 .1148 L F
.42972 .22463 m .44284 .286 L .44679 .31814 L 1 .641 0 r
F
.42972 .22463 m .44178 .28105 L .41591 .1148 L .419 .071 0 r
F
.42972 .22463 m .44679 .31814 L .42985 .23143 L 1 .641 0 r
F
.42972 .22463 m .42955 .22332 L .42976 .22675 L .419 .071 0 r
F
.42985 .23143 m .42948 .22486 L .42926 .2292 L F
.41686 .17971 m .42712 .22106 L .42153 .21587 L .735 .109 0 r
F
.41686 .17971 m .42079 .2102 L .41997 .2096 L 1 .485 0 r
F
.40998 .13441 m .42481 .19777 L .41037 .14788 L .769 .248 0 r
F
.40971 .12523 m .4111 .13188 L .40998 .13441 L F
.4111 .13188 m .42481 .19777 L .40998 .13441 L F
.40971 .12523 m .41707 .13173 L .42481 .19777 L F
.42518 .18857 m .42263 .16828 L .42438 .19513 L .419 .071 0 r
F
.41707 .13173 m .41908 .14365 L .4186 .14479 L .784 .294 0 r
F
.42263 .16828 m .41591 .1148 L .42192 .17176 L .419 .071 0 r
F
.42263 .16828 m .42192 .17176 L .42438 .19513 L F
.42926 .2292 m .42518 .18857 L .42712 .22106 L F
.42955 .22332 m .42518 .18857 L .42926 .2292 L F
.42518 .18857 m .42438 .19513 L .42712 .22106 L F
.41946 .11914 m .41999 .12183 L .41881 .12258 L .626 .075 0 r
F
.41999 .12183 m .42625 .15361 L .41881 .12258 L F
.42628 .10911 m .42611 .10528 L .42459 .11025 L 1 .58 0 r
F
.42628 .10911 m .42459 .11025 L .42418 .1116 L F
.42998 .14795 m .43084 .14803 L .43203 .15885 L .364 .053 0 r
F
.42998 .14795 m .43203 .15885 L .43104 .15697 L F
.42975 .1458 m .42978 .14586 L .42929 .14235 L .279 .044 0 r
F
.42948 .14404 m .43372 .14196 L .44013 .23763 L .359 .051 0 r
F
.42418 .1116 m .42692 .12792 L .44994 .3188 L .932 .416 0 r
F
.42846 .13744 m .42855 .13791 L .42853 .13785 L .873 .373 0 r
F
.44528 .26394 m .45026 .29097 L .45052 .29955 L 1 .629 0 r
F
.44166 .234 m .44942 .28113 L .44989 .29315 L 1 .647 0 r
F
.44528 .26394 m .45052 .29955 L .45052 .30038 L 1 .629 0 r
F
.44166 .234 m .44989 .29315 L .44999 .31307 L 1 .647 0 r
F
.42929 .14235 m .42934 .14235 L .42948 .14404 L .359 .051 0 r
F
.42954 .14412 m .42955 .14414 L .42929 .14235 L .279 .044 0 r
F
.42934 .14235 m .43372 .14196 L .42948 .14404 L .359 .051 0 r
F
.42692 .12792 m .44067 .21288 L .44994 .3188 L .932 .416 0 r
F
.43006 .14725 m .43112 .14578 L .44115 .21547 L .873 .373 0 r
F
.43907 .12703 m .43826 .14326 L .43372 .14196 L .036 0 0 r
F
.42692 .12792 m .43325 .13756 L .43669 .16952 L .932 .416 0 r
F
.43325 .13756 m .43382 .13842 L .43669 .16952 L F
.42444 .11232 m .43382 .13842 L .42692 .12792 L F
.42611 .10528 m .43382 .13842 L .43315 .13655 L .751 .198 0 r
F
.42614 .10647 m .43315 .13655 L .42649 .11804 L F
.42611 .10528 m .43315 .13655 L .42614 .10647 L F
.43497 .1065 m .43868 .11785 L .43457 .11009 L .605 .068 0 r
F
.43956 .102 m .43572 .10288 L .4355 .10285 L .14 0 0 r
F
.4355 .10285 m .43363 .11006 L .43518 .10351 L .617 .072 0 r
F
.43543 .10245 m .43544 .10228 L .4354 .10259 L 1 1 0 r
F
.44046 .11607 m .44102 .12206 L .44098 .12358 L .503 .071 0 r
F
.44102 .12206 m .45434 .26493 L .44098 .12358 L F
.44098 .12358 m .45434 .26493 L .44625 .20057 L F
.44021 .11275 m .44034 .1141 L .44021 .11338 L F
.44034 .1141 m .45434 .26493 L .44021 .11338 L F
.44088 .11489 m .44572 .11958 L .44551 .12899 L .505 .071 0 r
F
.44245 .10962 m .4442 .10719 L .43973 .11002 L .768 .782 0 r
F
.44115 .11209 m .43973 .11002 L .43913 .11307 L .885 1 0 r
F
.44178 .11302 m .44544 .10919 L .43973 .11002 L F
.44569 .12953 m .44596 .1198 L .44673 .1327 L .505 .071 0 r
F
.44021 .11275 m .44575 .11692 L .45434 .26493 L .503 .071 0 r
F
.4355 .10285 m .44001 .1035 L .44074 .12658 L .617 .072 0 r
F
.43544 .10228 m .43868 .11785 L .43497 .1065 L .605 .068 0 r
F
.43886 .10216 m .44127 .10368 L .43572 .10288 L .14 0 0 r
F
.43557 .10292 m .44034 .12099 L .43868 .11785 L .605 .068 0 r
F
.43561 .10291 m .44034 .12099 L .43557 .10292 L F
.43544 .10228 m .43561 .10291 L .43557 .10292 L F
.43515 .10274 m .43457 .11009 L .43298 .10709 L F
.43285 .10635 m .43298 .10709 L .43271 .10658 L F
.43515 .10274 m .43298 .10709 L .43285 .10635 L F
.43298 .10602 m .43387 .10876 L .43323 .10552 L .342 .071 0 r
F
.43301 .10714 m .43387 .10876 L .43298 .10602 L F
.43375 .10961 m .44087 .1272 L .43363 .11006 L .617 .072 0 r
F
.43998 .12314 m .44087 .1272 L .43375 .10961 L F
.43544 .10228 m .43457 .11009 L .43515 .10274 L .605 .068 0 r
F
.43387 .10876 m .44034 .12099 L .43323 .10552 L .342 .071 0 r
F
.43289 .10832 m .43477 .11275 L .4337 .10651 L .324 .064 0 r
F
.43289 .10832 m .43311 .10783 L .43382 .13842 L F
.43492 .10205 m .43508 .1026 L .43635 .09912 L .342 .071 0 r
F
.43956 .102 m .44154 .10372 L .44127 .10368 L .14 0 0 r
F
.43956 .102 m .44127 .10368 L .43886 .10216 L F
.43911 .10154 m .44147 .10282 L .43544 .10228 L .077 0 0 r
F
.44001 .1035 m .44154 .10372 L .44074 .12658 L .617 .072 0 r
F
.43544 .10228 m .44147 .10282 L .44034 .12099 L .605 .068 0 r
F
.43508 .1026 m .44034 .12099 L .43645 .09966 L .342 .071 0 r
F
.43508 .1026 m .43645 .09966 L .43635 .09912 L F
.43404 .10413 m .43498 .09739 L .42953 .10354 L 1 1 0 r
F
.43406 .10435 m .43499 .09756 L .42958 .10398 L F
.43323 .10552 m .43451 .10832 L .43492 .10205 L .342 .071 0 r
F
.43451 .10832 m .44034 .12099 L .43492 .10205 L F
.44074 .12658 m .44154 .10372 L .44087 .1272 L .617 .072 0 r
F
.43602 .10132 m .44087 .1272 L .43646 .10033 L .324 .064 0 r
F
.4337 .10651 m .43472 .10945 L .43602 .10132 L F
.43472 .10945 m .44087 .1272 L .43602 .10132 L F
.43477 .11275 m .44087 .1272 L .43472 .10945 L F
.43447 .11101 m .43472 .10945 L .4337 .10651 L F
.43477 .11275 m .43472 .10945 L .43447 .11101 L F
.43424 .11424 m .43646 .10033 L .43514 .11937 L F
.43311 .10783 m .43602 .10132 L .43424 .11424 L F
.43602 .10132 m .43646 .10033 L .43424 .11424 L F
.43311 .10783 m .43514 .11937 L .43382 .13842 L F
.43388 .11884 m .43628 .09971 L .43379 .11988 L 0 0 0 r
F
.43628 .09971 m .43635 .09912 L .43628 .09967 L F
.43628 .09971 m .43628 .09967 L .43379 .11988 L F
.43379 .11988 m .43628 .09967 L .43567 .10691 L F
.43628 .09967 m .43635 .09912 L .43633 .0994 L F
.43628 .09967 m .43633 .0994 L .43567 .10691 L F
.44034 .12098 m .43938 .11016 L .43635 .09912 L .41 .058 0 r
F
.44001 .12193 m .43972 .11491 L .43649 .10047 L .443 .063 0 r
F
.43696 .10338 m .43649 .10047 L .43646 .10033 L F
.44001 .12193 m .43649 .10047 L .43696 .10338 L F
.44026 .1529 m .45434 .26493 L .45791 .32396 L .975 .459 0 r
F
.45442 .32571 m .45269 .27669 L .45577 .31676 L .213 .03 0 r
F
.43646 .10033 m .43651 .10067 L .45569 .31592 L 1 .508 0 r
F
.43774 .11289 m .43916 .12643 L .43903 .12566 L .831 .355 0 r
F
.45399 .29219 m .454 .29082 L .45403 .29323 L .432 .072 0 r
F
.45649 .29678 m .45812 .31093 L .45805 .32482 L .184 .025 0 r
F
.45562 .28113 m .45805 .32482 L .45801 .32484 L F
.45619 .29566 m .4578 .31439 L .45791 .32396 L .205 .028 0 r
F
.45575 .28824 m .45659 .29891 L .45619 .29566 L F
.45659 .29891 m .4578 .31439 L .45619 .29566 L F
.45562 .28113 m .45823 .29062 L .45812 .31093 L .184 .025 0 r
F
.45562 .28113 m .45812 .31093 L .45649 .29678 L F
.45791 .32396 m .45742 .27899 L .45996 .32568 L .291 .043 0 r
F
.45791 .32396 m .45868 .32461 L .45523 .297 L F
.4543 .29124 m .45523 .297 L .45269 .27669 L F
.45791 .32396 m .45523 .297 L .4543 .29124 L F
.45868 .32461 m .45996 .32568 L .45975 .32426 L F
.45434 .26493 m .45466 .26639 L .4578 .31439 L .205 .028 0 r
F
.45466 .26639 m .45636 .28585 L .4578 .31439 L F
.45559 .27064 m .45768 .30347 L .4578 .31439 L F
.45434 .26493 m .4578 .31439 L .45575 .28824 L F
.45868 .32461 m .45975 .32426 L .45269 .27669 L .291 .043 0 r
F
.45801 .32484 m .45805 .32482 L .45805 .32561 L .184 .025 0 r
F
.45798 .32504 m .46005 .32686 L .45966 .32452 L .29 .042 0 r
F
.45797 .32491 m .45966 .32452 L .454 .29082 L F
.45798 .32504 m .45966 .32452 L .45797 .32491 L F
.4581 .32564 m .46005 .32686 L .45798 .32504 L F
.454 .29082 m .45966 .32452 L .45966 .32539 L 1 .514 0 r
F
.45772 .31534 m .45975 .32586 L .46008 .33343 L 1 .706 0 r
F
.45966 .32452 m .45974 .32524 L .45967 .32812 L 1 .514 0 r
F
.45993 .32682 m .45999 .32746 L .45975 .32586 L 1 .706 0 r
F
.45973 .32576 m .45998 .32709 L .45967 .32812 L 1 .514 0 r
F
.45975 .32506 m .45998 .32704 L .45973 .32576 L F
.45998 .32704 m .45998 .32709 L .45973 .32576 L F
.45975 .32586 m .45999 .32746 L .46008 .33343 L 1 .706 0 r
F
.45966 .32452 m .45975 .32506 L .45974 .32524 L 1 .514 0 r
F
.45965 .32356 m .45993 .32682 L .45975 .32586 L 1 .706 0 r
F
.45269 .27669 m .45965 .32356 L .45975 .32586 L F
.454 .29082 m .45966 .32539 L .45772 .31534 L 1 .514 0 r
F
.45269 .27669 m .45975 .32586 L .45772 .31534 L 1 .706 0 r
F
.45772 .31534 m .45966 .32539 L .45967 .32812 L 1 .514 0 r
F
.45975 .32506 m .46005 .32686 L .45999 .32708 L F
.45965 .32356 m .45996 .32568 L .45999 .32708 L 1 .706 0 r
F
.45993 .32682 m .45999 .32708 L .45999 .32746 L F
.45975 .32506 m .45999 .32708 L .45998 .32704 L 1 .514 0 r
F
.45965 .32356 m .45999 .32708 L .45993 .32682 L 1 .706 0 r
F
.45998 .32704 m .45999 .32708 L .45998 .32709 L 1 .514 0 r
F
.43907 .12703 m .43908 .12701 L .43907 .12708 L .036 0 0 r
F
.45805 .32561 m .4581 .32564 L .45798 .32504 L .29 .042 0 r
F
.454 .29082 m .45772 .31534 L .45738 .33362 L 1 .514 0 r
F
.45269 .27669 m .45772 .31534 L .45577 .31676 L 1 .706 0 r
F
.45772 .31534 m .46008 .33343 L .45907 .32955 L F
.45772 .31534 m .45907 .32955 L .45738 .33362 L 1 .514 0 r
F
.45772 .31534 m .45907 .32955 L .45577 .31676 L 1 .706 0 r
F
.45772 .31534 m .45967 .32812 L .45907 .32955 L 1 .514 0 r
F
.43651 .10067 m .45285 .2631 L .45569 .31592 L 1 .508 0 r
F
.43646 .10033 m .43649 .10047 L .43651 .10067 L F
.43648 .10041 m .43651 .10067 L .43632 .09942 L .831 .355 0 r
F
.43651 .10067 m .43916 .12643 L .43678 .10373 L F
.43382 .13842 m .43646 .10033 L .45569 .31592 L .765 .298 0 r
F
.43651 .10067 m .43678 .10373 L .43632 .09942 L .831 .355 0 r
F
.44544 .10919 m .44496 .10841 L .44245 .10962 L .768 .782 0 r
F
.44496 .10841 m .4442 .10719 L .44245 .10962 L F
.44154 .10372 m .44498 .10041 L .44131 .12433 L 0 0 0 r
F
.44154 .10372 m .44131 .12433 L .44096 .12417 L F
.44141 .10377 m .44368 .1052 L .44034 .12099 L F
.44453 .09968 m .44956 .09368 L .44687 .09486 L .941 .853 0 r
F
.44154 .10372 m .44687 .09486 L .44498 .10041 L 0 0 0 r
F
.44087 .1272 m .44498 .10041 L .44661 .14577 L .443 .063 0 r
F
.44034 .12099 m .44491 .09938 L .44513 .10911 L .41 .058 0 r
F
.44493 .13141 m .44513 .10911 L .44567 .13311 L F
.44034 .12099 m .44513 .10911 L .44493 .13141 L F
.44034 .12099 m .44193 .12459 L .43938 .11016 L F
.44045 .12326 m .43972 .11491 L .44001 .12193 L .443 .063 0 r
F
.44096 .12417 m .44131 .12433 L .44087 .1272 L 0 0 0 r
F
.44034 .12099 m .43938 .11016 L .44034 .12098 L .41 .058 0 r
F
.44087 .1272 m .44661 .14577 L .43972 .11491 L .443 .063 0 r
F
.44087 .1272 m .43972 .11491 L .44069 .12608 L F
.43649 .10047 m .44487 .13796 L .43651 .10067 L 1 .508 0 r
F
.44487 .13796 m .44661 .14577 L .44487 .13798 L F
.44487 .13796 m .44487 .13798 L .43651 .10067 L F
.44193 .12459 m .44567 .13311 L .44353 .12529 L .41 .058 0 r
F
.44193 .12459 m .44353 .12529 L .43938 .11016 L F
.4462 .14528 m .44661 .14577 L .44671 .14761 L 1 .508 0 r
F
.45466 .26639 m .45559 .27064 L .45636 .28585 L .205 .028 0 r
F
.45559 .27064 m .45742 .27899 L .45768 .30347 L F
.44069 .12608 m .44045 .12326 L .44001 .12193 L .443 .063 0 r
F
.44596 .1198 m .45213 .21158 L .45173 .2162 L 0 0 0 r
F
.45213 .21158 m .45321 .22758 L .45215 .21944 L F
.45213 .21158 m .45215 .21944 L .45173 .2162 L F
.44708 .13976 m .45182 .21271 L .45162 .21815 L F
.45182 .21271 m .45276 .22713 L .45182 .21971 L F
.45182 .21271 m .45182 .21971 L .45162 .21815 L F
.44589 .11926 m .44717 .13918 L .44708 .13976 L F
.44589 .11909 m .44717 .13918 L .44589 .11926 L F
.44717 .13918 m .45276 .22713 L .44708 .13976 L F
.44596 .1198 m .44805 .11341 L .45212 .20364 L F
.44596 .1198 m .45212 .20364 L .45118 .19753 L F
.44979 .11692 m .45099 .11092 L .4487 .10483 L 1 1 0 r
F
.44982 .11719 m .45012 .11567 L .44979 .11692 L F
.44982 .11719 m .4487 .10483 L .44878 .11853 L F
.4458 .11771 m .44578 .11681 L .44575 .11692 L 1 .835 0 r
F
.45118 .19753 m .45212 .20364 L .45321 .22758 L 0 0 0 r
F
.44864 .10517 m .44765 .11061 L .44596 .1198 L .504 .502 0 r
F
.44873 .104 m .45321 .10278 L .44982 .09829 L .518 .528 0 r
F
.44882 .10428 m .45321 .10278 L .44873 .104 L F
.4487 .10483 m .45324 .10338 L .44984 .09869 L .504 .502 0 r
F
.44596 .1198 m .44984 .09869 L .44805 .11341 L 0 0 0 r
F
.44575 .11692 m .44789 .11085 L .45276 .22713 L F
.45205 .11455 m .45484 .10998 L .44982 .11719 L .663 .206 0 r
F
.45267 .09885 m .45642 .09528 L .45287 .09583 L .814 .962 0 r
F
.45268 .09892 m .45642 .09534 L .45288 .09596 L .808 .945 0 r
F
.44834 .09884 m .45288 .09596 L .44956 .09368 L .747 .888 0 r
F
.45637 .094 m .45729 .08947 L .45276 .09361 L .948 1 0 r
F
.45637 .09403 m .45729 .0895 L .45277 .09367 L .95 1 0 r
F
.45642 .09528 m .45734 .09072 L .45287 .09583 L 1 1 0 r
F
.45642 .09534 m .45734 .09078 L .45288 .09596 L F
.45276 .09361 m .45471 .08826 L .44945 .09178 L .926 1 0 r
F
.45276 .09361 m .45729 .08947 L .45479 .08829 L F
.45467 .08836 m .45479 .08829 L .45471 .08826 L F
.45276 .09361 m .45479 .08829 L .45467 .08836 L F
.44945 .09178 m .45471 .08826 L .45266 .08801 L .817 1 0 r
F
.45235 .08818 m .45266 .08801 L .4525 .08799 L F
.44945 .09178 m .45266 .08801 L .45235 .08818 L F
.44945 .09178 m .4525 .08799 L .44663 .09123 L F
.44901 .08958 m .4525 .08799 L .45081 .08837 L .529 .27 0 r
F
.44663 .09123 m .45166 .08846 L .44901 .08958 L F
.45166 .08846 m .4525 .08799 L .44901 .08958 L F
.4492 .08958 m .45251 .08806 L .45071 .08855 L .511 .219 0 r
F
.44704 .09106 m .45182 .08843 L .4492 .08958 L F
.45182 .08843 m .45251 .08806 L .4492 .08958 L F
.44088 .09548 m .44663 .09123 L .44434 .09123 L .822 .903 0 r
F
.44663 .09123 m .4507 .0884 L .44434 .09123 L .529 .27 0 r
F
.44901 .08958 m .45081 .08837 L .45053 .08852 L F
.44427 .09595 m .44663 .09123 L .44088 .09548 L .953 1 0 r
F
.44427 .09595 m .44945 .09178 L .44663 .09123 L F
.44664 .09133 m .45071 .08855 L .44435 .09144 L .511 .219 0 r
F
.44435 .09144 m .44851 .08955 L .44485 .09142 L .271 0 0 r
F
.44088 .09548 m .44434 .09123 L .43817 .09595 L .822 .903 0 r
F
.43498 .09739 m .44088 .09548 L .43817 .09595 L .312 .192 0 r
F
.4409 .09568 m .44435 .09144 L .43821 .09638 L .808 .864 0 r
F
.4409 .09568 m .44664 .09133 L .44435 .09144 L F
.43821 .09638 m .44435 .09144 L .44272 .09328 L 0 0 0 r
F
.44528 .09115 m .44568 .09112 L .4437 .09182 L .238 0 0 r
F
.44664 .09133 m .45029 .0893 L .44704 .09106 L .511 .219 0 r
F
.45029 .0893 m .45251 .08806 L .44704 .09106 L F
.44428 .09606 m .44664 .09133 L .4409 .09568 L .956 1 0 r
F
.44428 .09606 m .44946 .09184 L .44664 .09133 L F
.44946 .09184 m .45251 .08806 L .44664 .09133 L .814 .998 0 r
F
.44485 .09142 m .45071 .08855 L .44946 .09124 L .271 0 0 r
F
.44435 .09144 m .44873 .09127 L .44272 .09328 L F
.44873 .09127 m .44946 .09124 L .44398 .0929 L F
.44873 .09127 m .44398 .0929 L .44272 .09328 L F
.45287 .09583 m .4535 .0937 L .45218 .09535 L 1 1 0 r
F
.45277 .09367 m .45729 .0895 L .45471 .08829 L .929 1 0 r
F
.4535 .0937 m .45476 .08945 L .45218 .09535 L 1 1 0 r
F
.45277 .09367 m .45471 .08829 L .44946 .09184 L .929 1 0 r
F
.45218 .09535 m .45476 .08945 L .44955 .09356 L 1 1 0 r
F
.45287 .09583 m .45734 .09072 L .45483 .08949 L F
.45473 .08957 m .45483 .08949 L .45476 .08945 L F
.45287 .09583 m .45483 .08949 L .45473 .08957 L F
.44955 .09356 m .45476 .08945 L .45261 .09032 L .642 .408 0 r
F
.4501 .09311 m .45476 .08952 L .45262 .09048 L .631 .337 0 r
F
.44956 .09368 m .45421 .08996 L .4501 .09311 L F
.45421 .08996 m .45476 .08952 L .4501 .09311 L F
.45288 .09596 m .45476 .08952 L .44956 .09368 L 1 1 0 r
F
.45288 .09596 m .45734 .09078 L .45476 .08952 L F
.45321 .10278 m .45487 .09199 L .45016 .09787 L F
.44989 .09838 m .45016 .09787 L .44982 .09829 L F
.45321 .10278 m .45016 .09787 L .44989 .09838 L F
.45321 .10278 m .45744 .09342 L .45492 .09202 L F
.45485 .09213 m .45492 .09202 L .45487 .09199 L F
.45321 .10278 m .45492 .09202 L .45485 .09213 L F
.45324 .10338 m .45488 .09215 L .45431 .09289 L F
.45324 .10338 m .45431 .09289 L .45018 .09915 L F
.45053 .09866 m .45488 .09215 L .45301 .09852 L .062 0 0 r
F
.45456 .09257 m .45488 .09215 L .45053 .09866 L F
.46013 .08977 m .46186 .08529 L .45729 .08947 L .875 1 0 r
F
.46013 .08978 m .46186 .08531 L .45729 .0895 L .876 1 0 r
F
.45653 .09808 m .46019 .09179 L .45744 .09342 L 1 1 0 r
F
.45324 .10338 m .45744 .09357 L .45488 .09215 L F
.45729 .08947 m .46186 .08529 L .46002 .08522 L .933 1 0 r
F
.45729 .0895 m .46186 .08531 L .46002 .08524 L .935 1 0 r
F
.45729 .08947 m .46002 .08522 L .45471 .08826 L .933 1 0 r
F
.45729 .0895 m .46002 .08524 L .45471 .08829 L .935 1 0 r
F
.45734 .09072 m .46005 .08625 L .45476 .08945 L .967 1 0 r
F
.4603 .09444 m .46322 .09059 L .46013 .08977 L .826 1 0 r
F
.4603 .09446 m .46322 .09061 L .46013 .08978 L F
.46322 .09059 m .46393 .08587 L .46013 .08977 L .967 1 0 r
F
.46322 .09061 m .46393 .08588 L .46013 .08978 L .968 1 0 r
F
.46013 .08977 m .46393 .08587 L .46186 .08529 L .875 1 0 r
F
.46013 .08978 m .46393 .08588 L .46186 .08531 L .876 1 0 r
F
.46015 .0905 m .46188 .08584 L .45734 .09072 L .913 1 0 r
F
.45986 .08656 m .46188 .08584 L .46005 .08625 L .967 1 0 r
F
.45734 .09072 m .45924 .08868 L .45986 .08656 L F
.45924 .08868 m .46188 .08584 L .45986 .08656 L F
.45471 .08826 m .46002 .08522 L .4584 .08448 L .818 1 0 r
F
.45471 .08829 m .46002 .08524 L .4584 .08451 L .819 1 0 r
F
.45476 .08945 m .46005 .08625 L .45844 .08567 L .831 1 0 r
F
.45476 .08952 m .45992 .08638 L .45844 .08574 L .832 1 0 r
F
.45992 .08638 m .46005 .08629 L .45995 .08626 L F
.45992 .08638 m .45995 .08626 L .45844 .08574 L F
.45734 .09078 m .46005 .08629 L .45476 .08952 L .968 1 0 r
F
.46015 .09053 m .46188 .08586 L .45734 .09078 L .915 1 0 r
F
.45734 .09078 m .46188 .08586 L .46005 .08629 L .968 1 0 r
F
.45744 .09342 m .46011 .08828 L .45487 .09199 L .861 .584 0 r
F
.46447 .09538 m .46322 .09059 L .4603 .09444 L .957 1 0 r
F
.46447 .0954 m .46322 .09061 L .4603 .09446 L .958 1 0 r
F
.46032 .09527 m .46324 .09135 L .46015 .0905 L .834 1 0 r
F
.46449 .09634 m .46324 .09135 L .46032 .09527 L 1 1 0 r
F
.46032 .0953 m .46324 .09137 L .46015 .09053 L .836 1 0 r
F
.46447 .09538 m .46648 .09073 L .46322 .09059 L .957 1 0 r
F
.46447 .0954 m .46648 .09074 L .46322 .09061 L .958 1 0 r
F
.46648 .09073 m .46615 .08603 L .46322 .09059 L .875 1 0 r
F
.46648 .09074 m .46615 .08603 L .46322 .09061 L F
.46322 .09059 m .46615 .08603 L .46393 .08587 L .967 1 0 r
F
.46322 .09061 m .46615 .08603 L .46393 .08588 L .968 1 0 r
F
.46324 .09135 m .46393 .08635 L .46015 .0905 L 1 1 0 r
F
.46324 .09137 m .46394 .08637 L .46015 .09053 L F
.46015 .0905 m .46393 .08635 L .46188 .08584 L .913 1 0 r
F
.46015 .09053 m .46394 .08637 L .46188 .08586 L .915 1 0 r
F
.46019 .09179 m .4619 .08672 L .45744 .09342 L .985 1 0 r
F
.45993 .08862 m .4619 .08672 L .46011 .08828 L .861 .584 0 r
F
.45744 .09342 m .45959 .09018 L .45993 .08862 L F
.45959 .09018 m .4619 .08672 L .45993 .08862 L F
.45487 .09199 m .46011 .08828 L .45852 .08819 L .828 .996 0 r
F
.45488 .09215 m .45996 .08849 L .45853 .08834 L .825 .982 0 r
F
.45996 .08849 m .46011 .08838 L .45998 .08838 L F
.45996 .08849 m .45998 .08838 L .45853 .08834 L F
.45744 .09357 m .46011 .08838 L .45488 .09215 L .851 .552 0 r
F
.45488 .09215 m .45853 .08834 L .45301 .09852 L .825 .982 0 r
F
.45484 .09209 m .45852 .08819 L .45298 .0978 L .828 .996 0 r
F
.45487 .09199 m .45497 .09189 L .45484 .09209 L F
.45497 .09189 m .45852 .08819 L .45484 .09209 L F
.45018 .09915 m .45431 .09289 L .44984 .09869 L 1 1 0 r
F
.44984 .09869 m .45456 .09257 L .45053 .09866 L .062 0 0 r
F
.45654 .09824 m .45744 .09357 L .45324 .10338 L 1 1 0 r
F
.45744 .21474 m .4573 .21339 L .45744 .21484 L 0 0 0 r
F
.45747 .21506 m .45747 .21501 L .4573 .21339 L F
.45748 .21519 m .45731 .21349 L .45731 .21353 L F
.45748 .21516 m .45731 .21349 L .45748 .21519 L F
.45301 .09852 m .45769 .10159 L .45769 .10323 L .373 .047 0 r
F
.45662 .19381 m .45697 .1644 L .45748 .21638 L F
.45697 .1644 m .45766 .10538 L .45751 .19848 L F
.45697 .1644 m .45751 .19848 L .45748 .21638 L F
.45799 .22909 m .46496 .31367 L .46263 .32438 L .656 .197 0 r
F
.45766 .10538 m .45768 .10575 L .45748 .21638 L .373 .047 0 r
F
.45731 .21353 m .45701 .21052 L .45701 .21056 L 0 0 0 r
F
.45731 .21349 m .45701 .21052 L .45731 .21353 L F
.45731 .21349 m .4573 .21339 L .45701 .21052 L F
.45701 .21056 m .45701 .21052 L .45688 .20928 L F
.44805 .11341 m .45301 .09852 L .45748 .21638 L .578 .12 0 r
F
.45617 .19159 m .45775 .21352 L .45799 .22909 L .656 .197 0 r
F
.45775 .21352 m .46496 .31367 L .45799 .22909 L F
.45301 .09852 m .45769 .10323 L .45662 .19381 L .373 .047 0 r
F
.46449 .09637 m .46324 .09137 L .46032 .0953 L 1 1 0 r
F
.46452 .0982 m .46327 .09268 L .46036 .09679 L F
.46452 .09827 m .46327 .09273 L .46037 .09685 L F
.46771 .09974 m .46879 .09543 L .46447 .09538 L .901 1 0 r
F
.47306 .10031 m .46879 .09543 L .46771 .09974 L .818 .963 0 r
F
.46765 .10045 m .46879 .09544 L .46447 .0954 L .971 1 0 r
F
.46772 .10054 m .46775 .10041 L .46765 .10045 L .95 1 0 r
F
.46772 .10056 m .46775 .10041 L .46765 .10045 L .971 1 0 r
F
.46775 .10041 m .46879 .09544 L .46765 .10045 L F
.47306 .10032 m .46879 .09544 L .46775 .10041 L .819 .963 0 r
F
.46782 .10055 m .46775 .10041 L .46772 .10054 L .822 .946 0 r
F
.46782 .10055 m .46775 .10041 L .46772 .10056 L .819 .963 0 r
F
.47306 .10032 m .46775 .10041 L .46782 .10055 L F
.47306 .10133 m .46879 .0961 L .46775 .10041 L .822 .946 0 r
F
.47306 .10133 m .46775 .10041 L .46782 .10055 L F
.46765 .10045 m .46879 .0961 L .46449 .09634 L .95 1 0 r
F
.46775 .10041 m .46879 .0961 L .46765 .10045 L F
.46879 .09543 m .46648 .09073 L .46447 .09538 L .832 .991 0 r
F
.46879 .09544 m .46648 .09074 L .46447 .0954 L F
.46449 .09634 m .46649 .09123 L .46324 .09135 L 1 1 0 r
F
.46449 .09637 m .46649 .09124 L .46324 .09137 L F
.46766 .10191 m .46879 .09612 L .46449 .09637 L F
.46773 .10199 m .46777 .10183 L .46766 .10191 L F
.46773 .10203 m .46777 .10183 L .46766 .10191 L F
.46777 .10183 m .46879 .09612 L .46766 .10191 L F
.47306 .10135 m .46879 .09612 L .46777 .10183 L .823 .947 0 r
F
.46783 .10202 m .46777 .10183 L .46773 .10199 L .833 .902 0 r
F
.46783 .10202 m .46777 .10183 L .46773 .10203 L .823 .947 0 r
F
.47306 .10135 m .46777 .10183 L .46783 .10202 L F
.47306 .10031 m .4732 .09584 L .46879 .09543 L .818 .963 0 r
F
.47306 .10032 m .4732 .09584 L .46879 .09544 L .819 .963 0 r
F
.47306 .10133 m .47319 .09662 L .46879 .0961 L .822 .946 0 r
F
.47306 .10135 m .47319 .09664 L .46879 .09612 L .823 .947 0 r
F
.47922 .10535 m .47842 .10067 L .47306 .10135 L .936 1 0 r
F
.47305 .1034 m .47319 .09805 L .4688 .09725 L .833 .902 0 r
F
.4732 .09584 m .46988 .09115 L .46879 .09543 L .932 1 0 r
F
.4732 .09584 m .46988 .09116 L .46879 .09544 L F
.47319 .09662 m .46988 .09167 L .46879 .0961 L .981 1 0 r
F
.47319 .09664 m .46988 .09168 L .46879 .09612 L .982 1 0 r
F
.47319 .09805 m .46988 .09249 L .4688 .09725 L 1 1 0 r
F
.46912 .09733 m .46988 .09251 L .4688 .09727 L F
.47319 .09807 m .47032 .09324 L .46912 .09733 L F
.47032 .09324 m .46988 .09251 L .46912 .09733 L F
.4678 .10184 m .4688 .09725 L .46777 .10183 L .833 .902 0 r
F
.47305 .1034 m .46904 .09759 L .4678 .10184 L F
.46904 .09759 m .4688 .09725 L .4678 .10184 L F
.47305 .1034 m .46777 .10183 L .46783 .10202 L F
.46879 .09543 m .46988 .09115 L .46648 .09073 L .832 .991 0 r
F
.46879 .09544 m .46988 .09116 L .46648 .09074 L F
.46879 .0961 m .46649 .09123 L .46449 .09634 L .845 .991 0 r
F
.46879 .0961 m .46988 .09167 L .46649 .09123 L F
.46879 .09612 m .46649 .09124 L .46449 .09637 L .846 .992 0 r
F
.46879 .09612 m .46988 .09168 L .46649 .09124 L F
.4688 .09725 m .46988 .09249 L .4665 .09201 L .869 .989 0 r
F
.4688 .09727 m .46988 .09251 L .46974 .09249 L .871 .99 0 r
F
.46875 .09715 m .46974 .09249 L .4665 .09203 L F
.4688 .09727 m .46974 .09249 L .46875 .09715 L F
.46766 .10191 m .46827 .09941 L .46452 .0982 L 1 1 0 r
F
.46827 .09941 m .4688 .09725 L .46873 .09726 L F
.46827 .09941 m .46873 .09726 L .46452 .0982 L F
.46777 .10183 m .4688 .09725 L .46766 .10191 L F
.46452 .0982 m .4665 .09201 L .46327 .09268 L F
.4688 .09725 m .4665 .09201 L .46452 .0982 L .869 .989 0 r
F
.46452 .09827 m .4665 .09203 L .46327 .09273 L 1 1 0 r
F
.46036 .09679 m .46327 .09268 L .46019 .09179 L .854 1 0 r
F
.46037 .09685 m .46327 .09273 L .46019 .09185 L .857 1 0 r
F
.46649 .09123 m .46616 .08633 L .46324 .09135 L .903 1 0 r
F
.46649 .09124 m .46616 .08634 L .46324 .09137 L .904 1 0 r
F
.4665 .09201 m .46616 .08676 L .46327 .09268 L .947 1 0 r
F
.4665 .09203 m .46616 .08677 L .46327 .09273 L .948 1 0 r
F
.46324 .09135 m .46616 .08633 L .46393 .08635 L 1 1 0 r
F
.46324 .09137 m .46616 .08634 L .46394 .08637 L F
.46327 .09268 m .46395 .0871 L .46019 .09179 L F
.46327 .09268 m .46616 .08676 L .46395 .0871 L F
.46327 .09273 m .46395 .08712 L .46019 .09185 L F
.46327 .09273 m .46616 .08677 L .46395 .08712 L F
.46019 .09179 m .46395 .0871 L .4619 .08672 L .985 1 0 r
F
.46019 .09185 m .46395 .08712 L .4619 .08675 L .989 1 0 r
F
.45769 .10159 m .46365 .08733 L .46325 .09851 L .495 .065 0 r
F
.4577 .10201 m .46323 .0974 L .46496 .31367 L .494 .064 0 r
F
.45654 .09824 m .46019 .09185 L .45744 .09357 L 1 1 0 r
F
.46019 .09185 m .4619 .08675 L .45744 .09357 L .989 1 0 r
F
.45744 .09357 m .4619 .08675 L .46011 .08838 L .851 .552 0 r
F
.45301 .09852 m .45853 .08834 L .45769 .10159 L .373 .047 0 r
F
.453 .0986 m .45736 .10014 L .45617 .19159 L .366 .044 0 r
F
.45736 .10014 m .45764 .10024 L .45758 .10421 L F
.45736 .10014 m .45758 .10421 L .45617 .19159 L F
.45298 .0978 m .45332 .09798 L .453 .0986 L F
.45332 .09798 m .45764 .10024 L .453 .0986 L F
.44984 .09869 m .45301 .09852 L .45296 .09868 L .062 0 0 r
F
.44888 .10663 m .45296 .09868 L .44805 .11341 L F
.44984 .09869 m .45296 .09868 L .44888 .10663 L F
.44982 .09829 m .45298 .0978 L .44789 .11085 L .033 0 0 r
F
.44982 .09829 m .45487 .09199 L .45298 .0978 L F
.44789 .11085 m .45298 .0978 L .45617 .19159 L .57 .11 0 r
F
.45105 .09495 m .45682 .10462 L .45671 .10532 L .604 .09 0 r
F
.44789 .11085 m .45617 .19159 L .45742 .27899 L .57 .11 0 r
F
.45742 .27899 m .45617 .19159 L .46263 .32438 L .53 .09 0 r
F
.45199 .13655 m .46476 .31626 L .46176 .31624 L .793 .324 0 r
F
.45184 .13022 m .45334 .12255 L .45197 .13568 L .604 .09 0 r
F
.45334 .12255 m .45226 .13384 L .45197 .13568 L F
.44575 .11692 m .44589 .11909 L .44589 .11926 L 0 0 0 r
F
.44578 .11684 m .44578 .1168 L .44578 .11681 L 1 .835 0 r
F
.44867 .10433 m .44982 .09829 L .44575 .11692 L .518 .528 0 r
F
.4487 .10483 m .44879 .10437 L .44765 .11061 L .504 .502 0 r
F
.44879 .10437 m .44984 .09869 L .4486 .10547 L F
.44879 .10437 m .4486 .10547 L .44765 .11061 L F
.44867 .10433 m .44882 .10428 L .44873 .104 L .518 .528 0 r
F
.4487 .10483 m .44765 .11061 L .44864 .10517 L .504 .502 0 r
F
.44871 .10477 m .44867 .10433 L .44866 .10504 L 1 1 0 r
F
.44575 .11692 m .44982 .09829 L .44789 .11085 L 0 0 0 r
F
.45434 .26493 m .44789 .11085 L .45742 .27899 L .205 .028 0 r
F
.44498 .10041 m .45082 .12991 L .44661 .14577 L .671 .178 0 r
F
.45082 .12991 m .45197 .13568 L .44737 .14435 L F
.45082 .12991 m .44737 .14435 L .44661 .14577 L F
.45742 .27899 m .45822 .28597 L .45996 .32568 L .53 .09 0 r
F
.45162 .21815 m .45276 .22713 L .45434 .26493 L 0 0 0 r
F
.44671 .14761 m .46176 .31624 L .45886 .31772 L .799 .328 0 r
F
.44671 .14752 m .46176 .31624 L .44671 .14761 L F
.44661 .14577 m .44669 .14471 L .44671 .14761 L .916 .492 0 r
F
.44651 .14481 m .4467 .14575 L .44668 .14722 L .799 .328 0 r
F
.4467 .14575 m .44685 .14651 L .44671 .14711 L F
.4467 .14575 m .44671 .14711 L .44668 .14722 L F
.44567 .13311 m .44669 .14471 L .44651 .14481 L F
.44661 .14577 m .44737 .14435 L .44669 .14471 L .916 .492 0 r
F
.44669 .14471 m .44685 .14651 L .44651 .14481 L .799 .328 0 r
F
.44842 .09849 m .44956 .09368 L .44672 .09706 L .747 .888 0 r
F
.44687 .09486 m .45051 .09494 L .44498 .10041 L .219 0 0 r
F
.45105 .09495 m .45671 .10532 L .45184 .13022 L .604 .09 0 r
F
.45298 .0978 m .45852 .08819 L .45764 .10024 L .366 .044 0 r
F
.44498 .10041 m .45105 .09495 L .45197 .13568 L .671 .178 0 r
F
.45105 .09495 m .4572 .08815 L .45682 .10462 L .604 .09 0 r
F
.45103 .09503 m .45674 .10259 L .45145 .12659 L .595 .076 0 r
F
.45476 .08945 m .45844 .08567 L .45261 .09032 L .831 1 0 r
F
.45476 .08952 m .45844 .08574 L .45262 .09048 L .832 1 0 r
F
.45262 .09048 m .4572 .08815 L .45695 .08843 L .053 0 0 r
F
.45149 .09371 m .45695 .08843 L .45105 .09495 L F
.45262 .09048 m .45695 .08843 L .45149 .09371 L F
.46393 .08587 m .46648 .08156 L .46186 .08529 L .915 1 0 r
F
.46393 .08588 m .46648 .08156 L .46186 .08531 L .916 1 0 r
F
.46615 .08603 m .46774 .08177 L .46393 .08587 L .888 1 0 r
F
.46615 .08603 m .46774 .08177 L .46393 .08588 L .889 1 0 r
F
.46393 .08587 m .46774 .08177 L .46648 .08156 L .915 1 0 r
F
.46393 .08588 m .46774 .08177 L .46648 .08156 L .916 1 0 r
F
.46393 .08635 m .46648 .08182 L .46188 .08584 L .958 1 0 r
F
.46394 .08637 m .46648 .08183 L .46188 .08586 L .96 1 0 r
F
.46648 .09073 m .46852 .08638 L .46615 .08603 L .875 1 0 r
F
.46648 .09074 m .46852 .08639 L .46615 .08603 L F
.46852 .08638 m .46912 .08195 L .46615 .08603 L .892 1 0 r
F
.46852 .08639 m .46912 .08195 L .46615 .08603 L .893 1 0 r
F
.46615 .08603 m .46912 .08195 L .46774 .08177 L .888 1 0 r
F
.46615 .08603 m .46912 .08195 L .46774 .08177 L .889 1 0 r
F
.46616 .08633 m .46775 .08196 L .46393 .08635 L .917 1 0 r
F
.46616 .08634 m .46775 .08197 L .46394 .08637 L .918 1 0 r
F
.46393 .08635 m .46775 .08196 L .46648 .08182 L .958 1 0 r
F
.46394 .08637 m .46775 .08197 L .46648 .08183 L .96 1 0 r
F
.46395 .0871 m .46649 .08218 L .4619 .08672 L 1 1 0 r
F
.46395 .08712 m .46649 .08219 L .4619 .08675 L F
.46186 .08529 m .46648 .08156 L .46534 .08134 L .88 1 0 r
F
.46186 .08531 m .46648 .08156 L .46534 .08135 L .881 1 0 r
F
.46188 .08584 m .46648 .08182 L .46535 .08171 L .913 1 0 r
F
.46188 .08586 m .46648 .08183 L .46535 .08173 L .915 1 0 r
F
.4619 .08672 m .46535 .08226 L .46011 .08828 L .96 1 0 r
F
.4619 .08672 m .46649 .08218 L .46535 .08226 L F
.4619 .08675 m .46535 .08227 L .46011 .08838 L .962 1 0 r
F
.4619 .08675 m .46649 .08219 L .46535 .08227 L F
.46186 .08529 m .46534 .08134 L .46002 .08522 L .88 1 0 r
F
.46186 .08531 m .46534 .08135 L .46002 .08524 L .881 1 0 r
F
.46188 .08584 m .46535 .08171 L .46005 .08625 L .913 1 0 r
F
.46188 .08586 m .46535 .08173 L .46005 .08629 L .915 1 0 r
F
.46011 .08828 m .46437 .08258 L .45852 .08819 L .993 .978 0 r
F
.46011 .08828 m .46535 .08226 L .46438 .08258 L F
.46436 .08261 m .46438 .08258 L .46437 .08258 L F
.46011 .08828 m .46438 .08258 L .46436 .08261 L F
.46011 .08838 m .46437 .08262 L .45853 .08834 L .996 .973 0 r
F
.46011 .08838 m .46535 .08227 L .46437 .08262 L F
.45899 .08825 m .46437 .08262 L .46365 .08733 L .369 .037 0 r
F
.45853 .08834 m .46397 .08301 L .45899 .08825 L F
.46397 .08301 m .46437 .08262 L .45899 .08825 L F
.45853 .08834 m .46365 .08733 L .45769 .10159 L F
.45852 .08819 m .46364 .08713 L .45764 .10024 L .366 .036 0 r
F
.45852 .08819 m .46437 .08258 L .46364 .08713 L F
.45764 .10024 m .45772 .1002 L .4577 .10201 L .494 .064 0 r
F
.45772 .1002 m .46323 .0974 L .4577 .10201 L F
.45764 .10024 m .46364 .08713 L .46323 .0974 L F
.45766 .10538 m .45769 .10323 L .45768 .10575 L .373 .047 0 r
F
.45617 .19159 m .45764 .10024 L .46496 .31367 L .656 .197 0 r
F
.4572 .08815 m .46297 .08547 L .45682 .10462 L .302 .001 0 r
F
.46002 .08522 m .46435 .08115 L .4584 .08448 L .896 1 0 r
F
.46002 .08522 m .46534 .08134 L .46435 .08115 L F
.46002 .08524 m .46336 .08209 L .4584 .08451 L .898 1 0 r
F
.46336 .08209 m .46435 .08116 L .45885 .08426 L F
.46336 .08209 m .45885 .08426 L .4584 .08451 L F
.4584 .08451 m .46435 .08116 L .46354 .0819 L 0 0 0 r
F
.4584 .08448 m .46435 .08115 L .46354 .08187 L F
.45837 .08449 m .46354 .08187 L .45709 .08495 L F
.4584 .08448 m .45853 .08441 L .45837 .08449 L F
.45853 .08441 m .46354 .08187 L .45837 .08449 L F
.46002 .08524 m .46534 .08135 L .46435 .08116 L .898 1 0 r
F
.46005 .08625 m .46436 .0817 L .45844 .08567 L .941 1 0 r
F
.46005 .08625 m .46535 .08171 L .46455 .0817 L F
.46398 .0821 m .46455 .0817 L .46437 .0817 L F
.46398 .0821 m .46437 .0817 L .46433 .08173 L F
.46005 .08625 m .46455 .0817 L .46398 .0821 L F
.46005 .08629 m .46401 .0821 L .45844 .08574 L .943 1 0 r
F
.46401 .0821 m .46436 .08172 L .45952 .085 L F
.46401 .0821 m .45952 .085 L .45844 .08574 L F
.46005 .08629 m .46535 .08173 L .46454 .08172 L F
.46447 .08177 m .46454 .08172 L .46452 .08172 L F
.46005 .08629 m .46454 .08172 L .46447 .08177 L F
.46401 .0821 m .46452 .08172 L .46403 .08207 L F
.46005 .08629 m .46447 .08177 L .46401 .0821 L F
.46447 .08177 m .46452 .08172 L .46401 .0821 L F
.45844 .08574 m .4596 .08523 L .45818 .08624 L .199 0 0 r
F
.45962 .08516 m .45973 .08511 L .45817 .08617 L .191 0 0 r
F
.4596 .08523 m .46357 .08349 L .45818 .08624 L .199 0 0 r
F
.45973 .08511 m .46357 .08342 L .45835 .08608 L .191 0 0 r
F
.45973 .08511 m .45835 .08608 L .45817 .08617 L F
.45818 .08624 m .46357 .08349 L .4572 .08815 L .199 0 0 r
F
.46403 .08207 m .46452 .08172 L .46436 .08172 L .943 1 0 r
F
.45948 .08528 m .46436 .08172 L .46357 .08349 L .199 0 0 r
F
.45262 .09048 m .45844 .08574 L .4572 .08815 L .053 0 0 r
F
.45813 .08623 m .46357 .08342 L .4572 .08795 L .191 0 0 r
F
.45817 .08617 m .45835 .08608 L .45813 .08623 L F
.45835 .08608 m .46357 .08342 L .45813 .08623 L F
.45841 .08572 m .45962 .08516 L .45817 .08617 L F
.45844 .08567 m .45858 .08561 L .45841 .08572 L F
.45844 .08574 m .46413 .08188 L .45948 .08528 L .199 0 0 r
F
.45858 .08561 m .45962 .08516 L .45841 .08572 L .191 0 0 r
F
.46413 .08188 m .46436 .08172 L .45948 .08528 L .199 0 0 r
F
.46433 .08173 m .46437 .0817 L .46436 .0817 L .941 1 0 r
F
.4572 .08815 m .46357 .08349 L .46297 .08547 L .302 .001 0 r
F
.45719 .0882 m .46297 .0853 L .45674 .10259 L .294 0 0 r
F
.4572 .08795 m .45768 .08773 L .45719 .0882 L F
.45768 .08773 m .46297 .0853 L .45719 .0882 L F
.45102 .09437 m .45133 .09481 L .45103 .09503 L .595 .076 0 r
F
.45133 .09481 m .45674 .10259 L .45103 .09503 L F
.45051 .09494 m .45105 .09495 L .45074 .09524 L .219 0 0 r
F
.44901 .09646 m .45074 .09524 L .44603 .09947 L F
.45051 .09494 m .45074 .09524 L .44901 .09646 L F
.45051 .09494 m .44603 .09947 L .44498 .10041 L F
.44497 .10054 m .45145 .12659 L .44673 .13192 L .661 .16 0 r
F
.44491 .09938 m .44514 .10036 L .44497 .10054 L F
.44514 .10036 m .45145 .12659 L .44497 .10054 L F
.44532 .11773 m .44673 .13192 L .44567 .13311 L F
.44491 .09938 m .44673 .13192 L .44532 .11773 L F
.44955 .09356 m .45261 .09032 L .44685 .09458 L .642 .408 0 r
F
.44956 .09368 m .45259 .09051 L .44687 .09486 L .631 .337 0 r
F
.45259 .09051 m .45262 .09048 L .45178 .09111 L F
.45259 .09051 m .45178 .09111 L .44687 .09486 L F
.44687 .09486 m .45178 .09111 L .45105 .09495 L .219 0 0 r
F
.45178 .09111 m .45262 .09048 L .4525 .09082 L F
.45178 .09111 m .4525 .09082 L .45105 .09495 L F
.44671 .09492 m .45102 .09437 L .44491 .09938 L .192 0 0 r
F
.44685 .09458 m .44719 .09456 L .44671 .09492 L F
.44719 .09456 m .45102 .09437 L .44671 .09492 L F
.44491 .09938 m .45102 .09437 L .45145 .12659 L .661 .16 0 r
F
.44669 .14471 m .45179 .13602 L .45174 .13546 L .916 .492 0 r
F
.44567 .13311 m .45145 .12659 L .45192 .13513 L .799 .328 0 r
F
.44567 .13311 m .45192 .13513 L .44669 .14471 L F
.44669 .14471 m .45174 .13546 L .44946 .1078 L .916 .492 0 r
F
.44737 .14435 m .45179 .13602 L .44669 .14471 L F
.45179 .13602 m .45191 .1358 L .45179 .13441 L F
.45179 .13602 m .45179 .13441 L .44946 .1078 L F
.45191 .1358 m .45197 .13568 L .45191 .13499 L F
.45191 .1358 m .45191 .13499 L .44946 .1078 L F
.44669 .14471 m .45192 .13513 L .46176 .31624 L .799 .328 0 r
F
.44685 .14651 m .46176 .31624 L .44668 .14722 L F
.44681 .20071 m .44671 .14761 L .45886 .31772 L .831 .355 0 r
F
.43651 .10067 m .44671 .14761 L .44681 .20071 L F
.44671 .14761 m .44736 .13825 L .44881 .18776 L .916 .492 0 r
F
.44736 .13825 m .44946 .1078 L .44907 .15557 L F
.44736 .13825 m .44907 .15557 L .44881 .18776 L F
.44669 .14471 m .44946 .1078 L .44671 .14761 L F
.44668 .14722 m .44671 .14752 L .44671 .14761 L .799 .328 0 r
F
.45334 .12255 m .45671 .10532 L .45226 .13384 L .604 .09 0 r
F
.45145 .12659 m .45674 .10259 L .45682 .10463 L .793 .324 0 r
F
.45205 .13512 m .45682 .10462 L .45682 .10463 L .836 .182 0 r
F
.45197 .13568 m .45226 .13384 L .45205 .13512 L F
.45226 .13384 m .45682 .10462 L .45205 .13512 L F
.45205 .13512 m .45682 .10463 L .46476 .31626 L .793 .324 0 r
F
.45145 .12659 m .45682 .10463 L .45205 .13512 L F
.45205 .13512 m .45682 .10463 L .45623 .10716 L .836 .182 0 r
F
.45195 .13575 m .45209 .1356 L .45199 .13655 L .793 .324 0 r
F
.45145 .12659 m .45205 .13512 L .45192 .13513 L F
.45192 .13513 m .45623 .10716 L .44946 .1078 L .836 .182 0 r
F
.45197 .13568 m .45205 .13512 L .45192 .13513 L F
.45205 .13512 m .45623 .10716 L .45192 .13513 L F
.45192 .13513 m .45205 .13512 L .45195 .13575 L .793 .324 0 r
F
.45205 .13512 m .45209 .1356 L .45195 .13575 L F
.45209 .1356 m .46476 .31626 L .45199 .13655 L F
.45682 .10462 m .45992 .14898 L .45985 .14823 L .793 .323 0 r
F
.45682 .10475 m .45687 .10534 L .46476 .31626 L .792 .322 0 r
F
.46496 .31367 m .46323 .0974 L .468 .3278 L .687 .228 0 r
F
.45687 .10534 m .46547 .22877 L .46476 .31626 L .792 .322 0 r
F
.45682 .10462 m .45985 .14823 L .45682 .10463 L .793 .323 0 r
F
.45682 .10462 m .46297 .08547 L .46589 .23429 L F
.45688 .10445 m .46555 .21918 L .45682 .10475 L .792 .322 0 r
F
.45682 .10463 m .45985 .14823 L .45623 .10716 L .793 .323 0 r
F
.45992 .14898 m .46059 .1586 L .46015 .15338 L F
.45992 .14898 m .46015 .15338 L .45623 .10716 L F
.46059 .1586 m .46589 .23429 L .46179 .18037 L F
.46059 .1586 m .46179 .18037 L .45623 .10716 L F
.45687 .10534 m .46555 .21918 L .46547 .22877 L .792 .322 0 r
F
.45674 .10259 m .45688 .10445 L .45682 .10475 L F
.44912 .10461 m .44929 .10491 L .44908 .10498 L .743 .177 0 r
F
.44912 .10461 m .44908 .10498 L .44259 .10729 L F
.44147 .10282 m .44491 .09938 L .44368 .1052 L 0 0 0 r
F
.44147 .10282 m .44368 .1052 L .44141 .10377 L F
.44147 .10282 m .44685 .09458 L .44491 .09938 L F
.44268 .09335 m .44912 .10461 L .44259 .10729 L .743 .177 0 r
F
.44268 .09276 m .44288 .09313 L .44268 .09326 L F
.44568 .09112 m .44434 .0917 L .4437 .09182 L .238 0 0 r
F
.4437 .09182 m .44622 .09137 L .44268 .09276 L F
.44622 .09137 m .44943 .0908 L .44397 .09238 L F
.44622 .09137 m .44397 .09238 L .44268 .09276 L F
.44434 .09123 m .44528 .09115 L .4437 .09182 L F
.44208 .09318 m .44434 .09123 L .44268 .09276 L 0 0 0 r
F
.43817 .09595 m .44146 .09343 L .44208 .09318 L F
.44146 .09343 m .44434 .09123 L .44208 .09318 L F
.43578 .09141 m .44268 .09276 L .43561 .09108 L F
.43817 .09595 m .44208 .09318 L .43578 .09141 L F
.44208 .09318 m .44268 .09276 L .43578 .09141 L F
.43165 .09636 m .43817 .09595 L .43561 .09108 L .701 .728 0 r
F
.43165 .09636 m .43561 .09108 L .42915 .09602 L F
.42915 .09602 m .43561 .09108 L .43407 .09021 L .935 .991 0 r
F
.43561 .09108 m .43573 .09135 L .43407 .09021 L .812 .215 0 r
F
.43563 .09133 m .43575 .09136 L .43573 .09135 L 0 .122 0 r
F
.43932 .10155 m .44147 .10282 L .43911 .10154 L .077 0 0 r
F
.43903 .0988 m .4409 .09568 L .43499 .09756 L .644 .828 0 r
F
.43498 .09739 m .43817 .09595 L .43205 .09633 L .312 .192 0 r
F
.43228 .09655 m .43205 .09633 L .43165 .09636 L F
.43498 .09739 m .43205 .09633 L .43228 .09655 L F
.42953 .10354 m .43165 .09636 L .42521 .09784 L 1 1 0 r
F
.42953 .10354 m .43498 .09739 L .43251 .09662 L F
.43155 .09671 m .43251 .09662 L .43165 .09636 L F
.42953 .10354 m .43251 .09662 L .43155 .09671 L F
.42669 .09716 m .43165 .09636 L .42915 .09602 L .358 .199 0 r
F
.42521 .09784 m .4267 .0975 L .42669 .09716 L F
.4267 .0975 m .43165 .09636 L .42669 .09716 L F
.42521 .09784 m .42915 .09602 L .42219 .0961 L F
.42269 .09609 m .42879 .09603 L .42796 .09596 L .037 .146 0 r
F
.42879 .09603 m .42915 .09602 L .42796 .09596 L F
.42238 .0961 m .42915 .09602 L .42269 .09609 L F
.42219 .0961 m .42796 .09596 L .4255 .096 L F
.42667 .09654 m .42922 .09658 L .42665 .09583 L .206 .17 0 r
F
.4255 .096 m .42796 .09596 L .42748 .09593 L .037 .146 0 r
F
.42714 .09597 m .42922 .09658 L .42796 .09596 L .206 .17 0 r
F
.42799 .09704 m .43021 .0968 L .42922 .09658 L .292 .19 0 r
F
.43021 .0968 m .43168 .09665 L .42922 .09658 L F
.42524 .09807 m .43128 .09674 L .42799 .09704 L F
.43128 .09674 m .43168 .09665 L .42799 .09704 L F
.43359 .12049 m .43635 .09912 L .43342 .12244 L 0 0 0 r
F
.43248 .10814 m .43289 .10832 L .42974 .1209 L .751 .198 0 r
F
.43271 .10741 m .43635 .09912 L .43265 .12779 L .342 .071 0 r
F
.43331 .10535 m .43635 .09912 L .43271 .10741 L F
.42958 .10398 m .43168 .09665 L .42524 .09807 L 1 1 0 r
F
.42958 .10398 m .43499 .09756 L .43168 .09665 L F
.42524 .09807 m .42922 .09658 L .42224 .09648 L .292 .19 0 r
F
.42922 .09658 m .43559 .10611 L .4279 .09628 L .608 .067 0 r
F
.42922 .09658 m .4279 .09628 L .42763 .09593 L F
.42714 .09597 m .42796 .09596 L .42745 .09571 L .206 .17 0 r
F
.42796 .09596 m .42757 .09586 L .42745 .09571 L .608 .067 0 r
F
.42915 .09602 m .43407 .09021 L .42757 .09586 L .935 .991 0 r
F
.42796 .09596 m .42757 .09586 L .42748 .09593 L F
.42915 .09602 m .42757 .09586 L .42796 .09596 L F
.42796 .09596 m .42763 .09593 L .42757 .09586 L .608 .067 0 r
F
.42922 .09658 m .42763 .09593 L .42796 .09596 L F
.4255 .096 m .42667 .09654 L .42665 .09583 L .206 .17 0 r
F
.42224 .09648 m .42422 .09651 L .4255 .096 L F
.42422 .09651 m .42667 .09654 L .4255 .096 L F
.42219 .0961 m .4255 .096 L .42007 .09426 L .037 .146 0 r
F
.42665 .09583 m .42714 .09597 L .42745 .09571 L .206 .17 0 r
F
.4255 .096 m .42745 .09571 L .42738 .09591 L F
.4255 .096 m .42748 .09593 L .42738 .09591 L .037 .146 0 r
F
.4255 .096 m .42738 .09591 L .42737 .09593 L .206 .17 0 r
F
.4255 .096 m .42738 .09591 L .42632 .09567 L .037 .146 0 r
F
.4255 .096 m .42632 .09567 L .42007 .09426 L F
.42224 .09648 m .4255 .096 L .42226 .11075 L .206 .17 0 r
F
.4255 .096 m .42737 .09593 L .42226 .11075 L F
.42219 .0961 m .42238 .0961 L .42269 .09609 L .037 .146 0 r
F
.43168 .09665 m .43197 .09626 L .42922 .09658 L .691 .707 0 r
F
.43197 .09626 m .43563 .09133 L .43089 .09521 L F
.43197 .09626 m .43089 .09521 L .42922 .09658 L F
.43499 .09756 m .43821 .09638 L .43168 .09665 L .25 .181 0 r
F
.43168 .09665 m .43821 .09638 L .43563 .09133 L .691 .707 0 r
F
.43821 .09638 m .44272 .09328 L .43563 .09133 L 0 0 0 r
F
.42922 .09658 m .43563 .09133 L .43559 .10611 L .608 .067 0 r
F
.43563 .09133 m .43573 .09135 L .43559 .10611 L 0 .122 0 r
F
.43573 .09135 m .44259 .10729 L .43855 .09921 L .812 .215 0 r
F
.43573 .09135 m .44219 .09314 L .44216 .09312 L 0 .122 0 r
F
.43561 .09108 m .44268 .09276 L .44268 .09326 L .812 .215 0 r
F
.43561 .09108 m .44268 .09326 L .43573 .09135 L F
.43573 .09135 m .44216 .09312 L .44144 .09249 L 0 .122 0 r
F
.43575 .09136 m .44219 .09314 L .43573 .09135 L F
.43573 .09135 m .44268 .09326 L .44259 .10729 L .812 .215 0 r
F
.43573 .09135 m .44144 .09249 L .43855 .09921 L 0 .122 0 r
F
.43651 .10067 m .437 .10284 L .43686 .10315 L 1 .508 0 r
F
.437 .10284 m .44295 .12941 L .43686 .10315 L F
.43686 .10315 m .44295 .12941 L .44212 .14037 L F
.44295 .12941 m .44661 .14577 L .44212 .14037 L F
.43635 .09912 m .44567 .13311 L .44671 .14761 L .831 .355 0 r
F
.43635 .09912 m .44671 .14761 L .43651 .10067 L F
.43916 .12643 m .44143 .14843 L .43875 .12912 L F
.43916 .12643 m .43875 .12912 L .43567 .10691 L F
.44143 .14843 m .45886 .31772 L .44191 .16364 L F
.44143 .14843 m .44191 .16364 L .43567 .10691 L F
.43651 .10067 m .44881 .18776 L .45285 .2631 L 1 .508 0 r
F
.43632 .09942 m .43774 .11289 L .43567 .10691 L .831 .355 0 r
F
.43635 .09912 m .43648 .10041 L .43632 .09942 L F
.43573 .09135 m .43855 .09921 L .43559 .10611 L 0 .122 0 r
F
.43573 .09135 m .43855 .09921 L .43415 .09038 L .812 .215 0 r
F
.43573 .09135 m .43415 .09038 L .43407 .09021 L F
.44219 .09314 m .44272 .09328 L .44237 .09306 L 0 .122 0 r
F
.44219 .09314 m .44237 .09306 L .44144 .09249 L F
.44851 .08955 m .45071 .08855 L .44485 .09142 L .271 0 0 r
F
.45053 .08852 m .45081 .08837 L .4507 .0884 L .529 .27 0 r
F
.44434 .09123 m .4507 .0884 L .44943 .0908 L .238 0 0 r
F
.44685 .09458 m .45261 .09032 L .45102 .09437 L .192 0 0 r
F
.44268 .09276 m .44943 .0908 L .44943 .09116 L .743 .177 0 r
F
.44272 .09328 m .44946 .09124 L .44943 .09116 L .923 .89 0 r
F
.44272 .09328 m .44943 .09116 L .44288 .09313 L F
.44288 .09313 m .44943 .09116 L .44929 .10491 L .743 .177 0 r
F
.44268 .09276 m .44943 .09116 L .44288 .09313 L F
.44568 .09112 m .44703 .091 L .44434 .0917 L .238 0 0 r
F
.44703 .091 m .44943 .0908 L .44622 .09137 L F
.44703 .091 m .44622 .09137 L .44434 .0917 L F
.44288 .09313 m .44338 .09265 L .44268 .09326 L .923 .89 0 r
F
.44338 .09265 m .44829 .08793 L .44326 .0927 L F
.44338 .09265 m .44326 .0927 L .44268 .09326 L F
.44288 .09313 m .44943 .09116 L .44829 .08793 L F
.44241 .09309 m .44829 .08793 L .44144 .09249 L F
.44268 .09326 m .44326 .0927 L .44241 .09309 L F
.44326 .0927 m .44829 .08793 L .44241 .09309 L F
.44272 .09328 m .44288 .09313 L .44268 .09326 L F
.44268 .09326 m .44295 .09325 L .44268 .09335 L .743 .177 0 r
F
.44288 .09313 m .44295 .09325 L .44268 .09326 L F
.44295 .09325 m .44929 .10491 L .44268 .09335 L F
.44994 .09124 m .45471 .08829 L .45251 .08806 L .814 .998 0 r
F
.44946 .09184 m .45402 .08876 L .44994 .09124 L F
.45402 .08876 m .45471 .08829 L .44994 .09124 L F
.44212 .14037 m .4462 .14528 L .44881 .18776 L 1 .508 0 r
F
.4462 .14528 m .44671 .14761 L .44881 .18776 L F
.43774 .11289 m .43903 .12566 L .43567 .10691 L .831 .355 0 r
F
.43265 .12779 m .43567 .10691 L .43828 .15858 L 0 0 0 r
F
.44357 .21757 m .45394 .30176 L .43684 .17096 L .765 .298 0 r
F
.44357 .21757 m .43684 .17096 L .43683 .17083 L F
.45394 .30176 m .45398 .30233 L .43683 .17084 L F
.43669 .16952 m .441 .21262 L .44115 .21547 L 0 0 0 r
F
.43683 .17084 m .43683 .17084 L .43679 .17058 L .765 .298 0 r
F
.45394 .30176 m .43683 .17084 L .43683 .17084 L F
.43235 .12714 m .43669 .16952 L .44115 .21547 L .873 .373 0 r
F
.45466 .30755 m .45469 .30821 L .43679 .17058 L .765 .298 0 r
F
.43112 .14578 m .43648 .16859 L .44115 .21547 L .873 .373 0 r
F
.43887 .19302 m .45469 .30821 L .44007 .20608 L .765 .298 0 r
F
.43679 .17058 m .44455 .23027 L .43887 .19302 L F
.44455 .23027 m .45469 .30821 L .43887 .19302 L F
.45469 .30821 m .45473 .30916 L .44007 .20608 L F
.43382 .13842 m .44357 .21757 L .43679 .17058 L F
.43669 .16952 m .44071 .20688 L .441 .21262 L 0 0 0 r
F
.43385 .13958 m .43828 .15858 L .44071 .20688 L F
.43265 .12779 m .43828 .15858 L .43385 .13958 L F
.43265 .12779 m .44071 .20688 L .43669 .16952 L F
.43112 .14578 m .43383 .14202 L .43648 .16859 L .873 .373 0 r
F
.42418 .1116 m .42444 .11232 L .42692 .12792 L .932 .416 0 r
F
.42602 .10557 m .42649 .11804 L .42444 .11232 L .751 .198 0 r
F
.42459 .11025 m .42444 .11232 L .42418 .1116 L F
.42602 .10557 m .42444 .11232 L .42459 .11025 L F
.42611 .10528 m .42649 .11804 L .42602 .10557 L F
.42383 .10885 m .43383 .14202 L .43006 .14725 L .873 .373 0 r
F
.42692 .12792 m .43669 .16952 L .44007 .20608 L .932 .416 0 r
F
.42442 .11252 m .42692 .12792 L .42432 .11394 L .873 .373 0 r
F
.42692 .12792 m .42855 .13791 L .42823 .13611 L F
.42692 .12792 m .42823 .13611 L .42432 .11394 L F
.42411 .11058 m .42442 .11252 L .42377 .11081 L F
.42442 .11252 m .42432 .11394 L .42377 .11081 L F
.42855 .13791 m .44115 .21547 L .42983 .15429 L F
.42855 .13791 m .42983 .15429 L .42349 .11999 L F
.42692 .12792 m .44007 .20608 L .44067 .21288 L .932 .416 0 r
F
.42377 .11081 m .42846 .13744 L .42349 .11999 L .873 .373 0 r
F
.42846 .13744 m .42853 .13785 L .42349 .11999 L F
.42383 .10885 m .42411 .11058 L .42377 .11081 L F
.42383 .10885 m .43235 .12714 L .43383 .14202 L F
.43235 .12714 m .43265 .12779 L .43669 .16952 L F
.43683 .17083 m .43684 .17096 L .43679 .17058 L .765 .298 0 r
F
.45394 .30176 m .45466 .30755 L .45398 .30233 L F
.45466 .30755 m .45569 .31592 L .45469 .30821 L F
.45469 .30821 m .45569 .31592 L .45473 .30916 L F
.44989 .29315 m .45314 .30375 L .45442 .32571 L 1 .647 0 r
F
.44942 .28113 m .45314 .30375 L .44989 .29315 L F
.44989 .29315 m .45442 .32571 L .45153 .31745 L F
.44989 .29315 m .45153 .31745 L .44999 .31307 L F
.45999 .32708 m .46189 .31843 L .45967 .32812 L .868 .489 0 r
F
.46004 .3269 m .46015 .32641 L .45999 .32708 L F
.46015 .32641 m .46189 .31843 L .45999 .32708 L F
.46005 .32686 m .46011 .32658 L .46004 .3269 L F
.45999 .32708 m .46012 .3265 L .46008 .33343 L .749 .217 0 r
F
.46264 .32503 m .46484 .31827 L .46189 .31843 L 0 0 0 r
F
.46275 .32502 m .46484 .31827 L .46264 .32503 L F
.46502 .31623 m .46793 .32793 L .46484 .31827 L .685 .226 0 r
F
.46496 .31367 m .4651 .3143 L .46514 .3167 L .687 .228 0 r
F
.46496 .31367 m .46514 .3167 L .46502 .31623 L F
.4651 .3143 m .46523 .31493 L .46524 .31555 L F
.46265 .32606 m .46281 .3252 L .46274 .33287 L .682 .203 0 r
F
.46281 .32491 m .46542 .33254 L .46477 .33262 L F
.46281 .32491 m .46477 .33262 L .46274 .33287 L F
.43342 .12244 m .43388 .11884 L .43379 .11988 L 0 0 0 r
F
.43265 .12779 m .43359 .12049 L .43342 .12244 L F
.43271 .10658 m .43301 .10714 L .43298 .10602 L .342 .071 0 r
F
.43269 .10717 m .43288 .10632 L .43271 .10658 L 1 .787 0 r
F
.43271 .10658 m .43331 .10535 L .43271 .10741 L .342 .071 0 r
F
.4294 .11878 m .43089 .11365 L .42611 .10528 L 1 .74 0 r
F
.42611 .10528 m .42709 .10572 L .42974 .1209 L .751 .198 0 r
F
.42709 .10572 m .43191 .1108 L .42974 .1209 L F
.42599 .10508 m .42599 .10429 L .42598 .10495 L 1 .606 0 r
F
.42592 .10443 m .4299 .11809 L .42383 .10885 L .746 .157 0 r
F
.42599 .10429 m .42614 .10482 L .42592 .10443 L F
.42614 .10482 m .4299 .11809 L .42592 .10443 L F
.42709 .10572 m .43248 .10814 L .43191 .1108 L .751 .198 0 r
F
.43098 .18438 m .42349 .11999 L .43123 .18584 L 1 .319 0 r
F
.4299 .11809 m .43265 .12779 L .42872 .11936 L .746 .157 0 r
F
.4299 .11809 m .42872 .11936 L .42383 .10885 L F
.45028 .31388 m .45127 .31672 L .4504 .31468 L 1 .534 0 r
F
.45127 .31672 m .45122 .31693 L .4504 .31468 L F
.44999 .31307 m .45028 .31388 L .4504 .31468 L F
.44755 .31434 m .44759 .31444 L .44755 .31437 L .953 .309 0 r
F
.43926 .10151 m .43932 .10155 L .43911 .10154 L .077 0 0 r
F
.40852 .12142 m .41354 .11976 L .40772 .12135 L .572 .481 0 r
F
.44467 .3403 m .4465 .33849 L .44457 .33982 L .534 .154 0 r
F
.43749 .35146 m .43721 .35046 L .4367 .354 L .158 .026 0 r
F
.44055 .36245 m .43749 .35146 L .4367 .354 L F
.43657 .35446 m .43657 .35442 L .43656 .35443 L 1 1 0 r
F
.43748 .35715 m .43657 .35442 L .43657 .35446 L F
.43604 .35793 m .43639 .35522 L .43599 .35782 L .159 .026 0 r
F
.43643 .35534 m .43639 .35522 L .43604 .35793 L F
.4359 .35835 m .43476 .35594 L .43471 .35608 L F
.43604 .35793 m .43656 .35443 L .42715 .36274 L 1 1 0 r
F
.43996 .36614 m .43643 .35534 L .43604 .35793 L .159 .026 0 r
F
.43996 .36614 m .44055 .36245 L .4369 .35511 L F
.43996 .36614 m .4369 .35511 L .43663 .35598 L F
.43656 .35443 m .43666 .35403 L .43652 .35446 L 1 .955 0 r
F
.4367 .354 m .43666 .35403 L .43656 .35443 L F
.44055 .36245 m .4367 .354 L .43656 .35443 L .158 .026 0 r
F
.43996 .36614 m .43604 .35793 L .4359 .35835 L .159 .026 0 r
F
.4359 .35835 m .43601 .35794 L .43588 .35837 L 1 1 0 r
F
.43604 .35793 m .43601 .35794 L .4359 .35835 L F
.43652 .35446 m .4282 .35965 L .42715 .36274 L 1 .955 0 r
F
.43666 .35403 m .4282 .35965 L .43652 .35446 L F
.43588 .35837 m .42715 .36274 L .42612 .36583 L 1 1 0 r
F
.43601 .35794 m .42715 .36274 L .43588 .35837 L F
.43523 .36223 m .43524 .36221 L .4352 .36214 L .163 .027 0 r
F
.43524 .36224 m .43524 .36221 L .43523 .36223 L F
.43538 .36178 m .43537 .36179 L .43526 .3622 L 1 1 0 r
F
.43537 .36179 m .42612 .36583 L .43524 .3622 L F
.43537 .36179 m .43524 .3622 L .43526 .3622 L F
.43936 .36976 m .43996 .36614 L .43622 .35897 L .161 .027 0 r
F
.43615 .35921 m .43622 .35897 L .43586 .35828 L F
.43936 .36976 m .43622 .35897 L .43615 .35921 L F
.43625 .36505 m .43526 .3622 L .43525 .36224 L 1 1 0 r
F
.43472 .36558 m .43524 .36221 L .42509 .36891 L F
.43548 .36299 m .43554 .36276 L .43524 .36221 L .163 .027 0 r
F
.43548 .36299 m .43524 .36221 L .43524 .36224 L F
.43878 .37334 m .43936 .36976 L .43554 .36276 L F
.43878 .37334 m .43554 .36276 L .43548 .36299 L F
.4014 .30275 m .40142 .30268 L .4014 .30275 L 1 .939 0 r
F
.421 .33932 m .38109 .26297 L .39332 .29379 L .163 .027 0 r
F
.44088 .37181 m .43936 .36976 L .43878 .37334 L 1 .981 0 r
F
.44126 .37236 m .44093 .37151 L .44088 .37181 L .109 .03 0 r
F
.45791 .3967 m .44138 .36877 L .44126 .37236 L F
.44135 .36809 m .43996 .36614 L .43936 .36976 L 1 .963 0 r
F
.44175 .36872 m .44141 .36777 L .44135 .36809 L .093 .027 0 r
F
.45823 .39428 m .44187 .365 L .44175 .36872 L F
.44183 .36432 m .44055 .36245 L .43996 .36614 L 1 .94 0 r
F
.44226 .36502 m .44189 .36397 L .44183 .36432 L .077 .023 0 r
F
.45856 .39188 m .44236 .36116 L .44226 .36502 L F
.44236 .36116 m .44232 .36048 L .4423 .3612 L 1 .94 0 r
F
.4423 .3612 m .44232 .36048 L .44055 .36245 L F
.44277 .36125 m .44234 .35995 L .44232 .36048 L 1 .172 0 r
F
.44286 .35723 m .44239 .36009 L .44277 .36125 L F
.44232 .36048 m .44115 .3587 L .44055 .36245 L 1 .912 0 r
F
.44288 .35648 m .44176 .35486 L .44115 .3587 L 1 .88 0 r
F
.44341 .35317 m .44176 .35486 L .44288 .35648 L F
.45889 .3895 m .44286 .35723 L .44277 .36125 L 1 .172 0 r
F
.44286 .35723 m .44288 .35648 L .44115 .3587 L 1 .912 0 r
F
.47171 .1739 m .47172 .1656 L .47139 .16595 L 1 .402 0 r
F
.33274 .29016 m .31265 .27832 L .30957 .28403 L 1 1 0 r
F
.33804 .29156 m .33338 .28913 L .33274 .29016 L F
.33338 .28913 m .31265 .27832 L .33274 .29016 L F
.24148 .35871 m .23243 .35267 L .21183 .34575 L 1 .91 0 r
F
.23243 .35267 m .21028 .34334 L .21183 .34575 L F
.23243 .35267 m .21281 .33857 L .21028 .34334 L 1 1 0 r
F
.21183 .34575 m .21028 .34334 L .18869 .325 L .798 .077 0 r
F
.20974 .34648 m .20894 .34589 L .20882 .3459 L 1 1 0 r
F
.22847 .3602 m .20894 .34589 L .20647 .35067 L F
.23887 .36488 m .21183 .34575 L .20894 .34589 L F
.23887 .36488 m .20894 .34589 L .20974 .34648 L F
.36348 .45678 m .35141 .44963 L .35042 .45232 L F
.37333 .45917 m .36045 .45218 L .353 .45057 L 1 .982 0 r
F
.37333 .45917 m .353 .45057 L .35309 .45063 L F
.36458 .46058 m .36536 .45789 L .36337 .45714 L 1 1 0 r
F
.36458 .46058 m .36337 .45714 L .36264 .45945 L F
.36536 .45789 m .36348 .45678 L .35042 .45232 L F
.37272 .4621 m .36348 .45678 L .36264 .45945 L .585 .169 0 r
F
.36264 .45945 m .36337 .45714 L .35042 .45232 L 1 1 0 r
F
.36249 .45986 m .35042 .45232 L .34934 .45535 L F
.36264 .45945 m .35042 .45232 L .36249 .45986 L F
.38103 .46827 m .38173 .46505 L .36458 .46058 L F
.37215 .46503 m .37272 .4621 L .36249 .45986 L .586 .168 0 r
F
.36168 .46253 m .36249 .45986 L .21697 .42801 L F
.3637 .46371 m .36253 .45997 L .36168 .46253 L 1 1 0 r
F
.36253 .45997 m .36249 .45986 L .36168 .46253 L F
.3637 .46371 m .36168 .46253 L .36153 .46296 L F
.36154 .46296 m .36168 .46253 L .36153 .46296 L .586 .168 0 r
F
.37215 .46503 m .36168 .46253 L .36154 .46296 L F
.37215 .46503 m .36249 .45986 L .36168 .46253 L F
.36168 .46253 m .36249 .45986 L .36163 .4625 L 1 1 0 r
F
.36163 .4625 m .36249 .45986 L .34934 .45535 L F
.36255 .45987 m .36249 .45986 L .36249 .45986 L .585 .169 0 r
F
.37272 .4621 m .36269 .45946 L .36255 .45987 L F
.36148 .46294 m .34934 .45535 L .34829 .45839 L 1 1 0 r
F
.36153 .46296 m .36148 .46292 L .36148 .46294 L F
.36148 .46292 m .34934 .45535 L .36148 .46294 L F
.36168 .46253 m .36167 .46253 L .36153 .46296 L .586 .168 0 r
F
.36168 .46253 m .34934 .45535 L .36153 .46296 L 1 1 0 r
F
.36075 .46562 m .36159 .46298 L .36153 .46296 L F
.36285 .46685 m .36159 .46298 L .36075 .46562 L F
.38036 .4715 m .38103 .46827 L .3637 .46371 L F
.37161 .46795 m .37215 .46503 L .36158 .46297 L .587 .167 0 r
F
.36075 .46562 m .36158 .46297 L .2152 .43442 L F
.37161 .46795 m .36158 .46297 L .36075 .46562 L F
.36074 .46562 m .2152 .43442 L .3606 .46606 L F
.36285 .46685 m .36075 .46562 L .36061 .46607 L 1 1 0 r
F
.35985 .46872 m .36065 .46608 L .3606 .46606 L F
.36204 .46999 m .36065 .46608 L .35985 .46872 L F
.37972 .47474 m .38036 .4715 L .36285 .46685 L F
.37111 .47087 m .37161 .46795 L .3606 .46606 L .588 .167 0 r
F
.35976 .46871 m .3606 .46606 L .21352 .44084 L F
.35983 .46872 m .21352 .44084 L .3597 .46918 L F
.36204 .46999 m .35985 .46872 L .35971 .46918 L 1 1 0 r
F
.37064 .47378 m .37111 .47087 L .3597 .46918 L .589 .166 0 r
F
.35889 .47182 m .3597 .46918 L .21191 .44727 L F
.35898 .47183 m .35975 .46919 L .3597 .46918 L 1 1 0 r
F
.36125 .47315 m .35975 .46919 L .35898 .47183 L F
.35896 .47183 m .21191 .44727 L .35883 .4723 L .589 .166 0 r
F
.36125 .47315 m .35898 .47183 L .35884 .4723 L 1 1 0 r
F
.35898 .47183 m .3597 .46918 L .35889 .47182 L .589 .166 0 r
F
.35888 .47213 m .35896 .47183 L .35883 .4723 L F
.35898 .47183 m .35883 .4723 L .35884 .4723 L 1 1 0 r
F
.35898 .47183 m .35896 .47183 L .35884 .4723 L .589 .166 0 r
F
.35898 .47183 m .34631 .46451 L .35883 .4723 L 1 1 0 r
F
.35884 .4723 m .35888 .47213 L .35883 .4723 L .589 .166 0 r
F
.3702 .47669 m .37064 .47378 L .35883 .4723 L .59 .165 0 r
F
.35805 .47494 m .35883 .4723 L .21039 .4537 L F
.35814 .47495 m .35883 .4723 L .35805 .47494 L F
.35813 .47495 m .35873 .47268 L .35883 .4723 L 1 1 0 r
F
.35873 .47268 m .35883 .4723 L .35883 .4723 L F
.35814 .47495 m .35883 .4723 L .35813 .47495 L F
.3605 .47632 m .35886 .47237 L .35814 .47495 L F
.35886 .47237 m .35883 .4723 L .35814 .47495 L F
.35812 .47495 m .21039 .4537 L .35799 .47543 L .59 .165 0 r
F
.35799 .47543 m .34537 .46759 L .34447 .47068 L 1 1 0 r
F
.3605 .47632 m .35814 .47495 L .35799 .47543 L F
.35804 .47526 m .35812 .47495 L .35799 .47543 L .59 .165 0 r
F
.35814 .47495 m .35812 .47495 L .358 .47543 L F
.35814 .47495 m .34537 .46759 L .35799 .47543 L 1 1 0 r
F
.358 .47543 m .35804 .47526 L .35799 .47543 L .59 .165 0 r
F
.3702 .47669 m .35814 .47495 L .358 .47543 L F
.3702 .47669 m .35883 .4723 L .35814 .47495 L F
.35883 .4723 m .34631 .46451 L .34537 .46759 L 1 1 0 r
F
.35884 .4723 m .35883 .4723 L .35883 .4723 L F
.35883 .4723 m .34631 .46451 L .35883 .4723 L F
.37064 .47378 m .35975 .4692 L .35898 .47183 L .589 .166 0 r
F
.35975 .4692 m .3597 .46918 L .35898 .47183 L F
.3597 .46918 m .34729 .46144 L .34631 .46451 L 1 1 0 r
F
.35971 .46918 m .3597 .46918 L .3597 .46918 L F
.3597 .46918 m .34729 .46144 L .3597 .46918 L F
.35985 .46872 m .3606 .46606 L .35976 .46871 L .588 .167 0 r
F
.35985 .46872 m .3597 .46918 L .35971 .46918 L 1 1 0 r
F
.35971 .46918 m .35976 .46901 L .3597 .46918 L .588 .167 0 r
F
.35976 .46901 m .35983 .46872 L .3597 .46918 L F
.35985 .46872 m .35983 .46872 L .35971 .46918 L F
.35985 .46872 m .34729 .46144 L .3597 .46918 L 1 1 0 r
F
.37111 .47087 m .36065 .46608 L .35985 .46872 L .588 .167 0 r
F
.36065 .46608 m .3606 .46606 L .35985 .46872 L F
.3606 .46606 m .34829 .45839 L .34729 .46144 L 1 1 0 r
F
.36061 .46607 m .3606 .46606 L .3606 .46606 L F
.36066 .4659 m .36074 .46562 L .3606 .46606 L .587 .167 0 r
F
.36075 .46562 m .36074 .46562 L .36066 .4659 L F
.36075 .46562 m .34829 .45839 L .3606 .46606 L 1 1 0 r
F
.36075 .46562 m .3606 .46606 L .36061 .46607 L F
.36075 .46562 m .36066 .4659 L .36061 .46606 L .587 .167 0 r
F
.36061 .46606 m .36066 .4659 L .3606 .46606 L F
.3606 .46606 m .34829 .45839 L .3606 .46606 L 1 1 0 r
F
.3607 .46559 m .36153 .46296 L .34829 .45839 L F
.36075 .46562 m .36153 .46296 L .3607 .46559 L F
.37161 .46795 m .36075 .46562 L .36061 .46606 L .587 .167 0 r
F
.3598 .4687 m .3606 .46606 L .34729 .46144 L 1 1 0 r
F
.35985 .46872 m .3606 .46606 L .3598 .4687 L F
.37111 .47087 m .35985 .46872 L .35971 .46918 L .588 .167 0 r
F
.35894 .47181 m .3597 .46918 L .34631 .46451 L 1 1 0 r
F
.35898 .47183 m .3597 .46918 L .35894 .47181 L F
.37064 .47378 m .35898 .47183 L .35884 .4723 L .589 .166 0 r
F
.3581 .47493 m .35883 .4723 L .34537 .46759 L 1 1 0 r
F
.35813 .47495 m .35883 .4723 L .3581 .47493 L F
.3698 .47958 m .3702 .47669 L .358 .47543 L .591 .163 0 r
F
.358 .47544 m .358 .47543 L .35799 .47543 L F
.3698 .47958 m .358 .47543 L .358 .47544 L F
.35732 .47808 m .35799 .47543 L .20894 .46013 L F
.35978 .47949 m .35799 .47543 L .35732 .47808 L 1 1 0 r
F
.3698 .47958 m .35799 .47543 L .35732 .47808 L .591 .163 0 r
F
.35732 .47808 m .35799 .47543 L .35729 .47806 L 1 1 0 r
F
.35704 .47899 m .35634 .47827 L .34361 .47378 L F
.35966 .48001 m .35712 .47868 L .35704 .47899 L F
.35712 .47868 m .35634 .47827 L .35704 .47899 L F
.35718 .47857 m .34447 .47068 L .34361 .47378 L F
.35978 .47949 m .35732 .47808 L .35718 .47857 L F
.35732 .47808 m .35731 .47807 L .35723 .47839 L .591 .163 0 r
F
.35731 .47807 m .35718 .47857 L .35719 .47857 L F
.35732 .47808 m .34447 .47068 L .35718 .47857 L 1 1 0 r
F
.35732 .47808 m .35723 .47839 L .35719 .47857 L .591 .163 0 r
F
.35909 .48267 m .35966 .48001 L .35707 .479 L 1 1 0 r
F
.35651 .48119 m .35707 .479 L .34361 .47378 L F
.35909 .48267 m .35707 .479 L .35651 .48119 L F
.35715 .4787 m .35718 .47857 L .35634 .47827 L F
.35966 .48001 m .35718 .47857 L .35715 .4787 L F
.35719 .47857 m .35718 .47857 L .35718 .47857 L .591 .163 0 r
F
.3698 .47958 m .35732 .47808 L .35719 .47857 L F
.35729 .47806 m .35799 .47543 L .34447 .47068 L 1 1 0 r
F
.35966 .48001 m .3698 .47958 L .35718 .47857 L .267 .354 0 r
F
.36041 .48039 m .35966 .48001 L .35959 .48001 L 1 .847 0 r
F
.37393 .48675 m .35966 .48001 L .36041 .48039 L F
.38734 .48695 m .35966 .48001 L .37393 .48675 L F
.37393 .48675 m .35966 .48001 L .35909 .48267 L 1 .966 0 r
F
.38711 .48982 m .38734 .48695 L .37394 .48675 L .467 .071 0 r
F
.37271 .49317 m .35843 .48585 L .3578 .48904 L 1 .949 0 r
F
.37284 .49254 m .35843 .48585 L .37271 .49317 L F
.37227 .49574 m .37271 .49317 L .24291 .4976 L .467 .07 0 r
F
.37209 .49639 m .24291 .4976 L .24212 .50397 L F
.37219 .49574 m .24291 .4976 L .37209 .49639 L F
.3716 .49959 m .3572 .49223 L .35664 .49542 L 1 .931 0 r
F
.3755 .50068 m .37172 .49894 L .3716 .49959 L F
.3755 .50068 m .37215 .49639 L .37172 .49894 L F
.3755 .50068 m .37594 .49744 L .37214 .49638 L F
.3755 .50068 m .37214 .49638 L .37214 .49639 L F
.38647 .50117 m .3866 .49836 L .3716 .49959 L .467 .07 0 r
F
.37436 .5104 m .37471 .50717 L .3706 .50601 L 1 .904 0 r
F
.37113 .50214 m .37113 .50213 L .24141 .51033 L .467 .07 0 r
F
.37113 .50213 m .37147 .49961 L .24141 .51033 L F
.37103 .50281 m .24141 .51033 L .24078 .51666 L F
.37509 .50393 m .3755 .50068 L .3716 .49959 L 1 .922 0 r
F
.37113 .50213 m .3716 .49959 L .37147 .49961 L .467 .07 0 r
F
.37121 .50213 m .37145 .50054 L .3712 .50213 L 1 .922 0 r
F
.3712 .50213 m .3716 .49959 L .37113 .50214 L .467 .07 0 r
F
.37145 .50054 m .37154 .49995 L .3712 .50213 L 1 .922 0 r
F
.37509 .50393 m .3716 .49959 L .37121 .50213 L F
.38647 .50117 m .3716 .49959 L .3712 .50213 L .467 .07 0 r
F
.37154 .49995 m .3716 .49959 L .3712 .50213 L 1 .922 0 r
F
.3716 .49959 m .37155 .4996 L .37155 .4996 L .467 .07 0 r
F
.3712 .50213 m .3716 .49959 L .35664 .49542 L 1 .922 0 r
F
.37113 .50214 m .24141 .51033 L .37103 .50281 L .467 .07 0 r
F
.37108 .5028 m .35664 .49542 L .35611 .49861 L 1 .922 0 r
F
.37509 .50393 m .3712 .50213 L .37108 .5028 L F
.37108 .5028 m .37113 .50214 L .37103 .50281 L .467 .07 0 r
F
.3711 .50271 m .37113 .50214 L .37108 .5028 L F
.3712 .50213 m .37113 .50214 L .3711 .5028 L F
.3712 .50213 m .35664 .49542 L .37108 .5028 L 1 .922 0 r
F
.3711 .5028 m .3711 .50271 L .37108 .5028 L .467 .07 0 r
F
.38647 .50117 m .3712 .50213 L .3711 .5028 L F
.37027 .50853 m .3706 .50601 L .3706 .50601 L 1 .904 0 r
F
.37026 .50852 m .3706 .50601 L .35561 .50181 L F
.37027 .50853 m .3706 .50601 L .37026 .50852 L F
.37436 .5104 m .3706 .50601 L .37027 .50853 L F
.37172 .49894 m .37172 .49894 L .3716 .49959 L 1 .931 0 r
F
.37165 .49934 m .3717 .49894 L .3716 .49959 L .467 .07 0 r
F
.37172 .49894 m .3717 .49894 L .37161 .49959 L F
.37172 .49894 m .3572 .49223 L .3716 .49959 L 1 .931 0 r
F
.37161 .49959 m .37165 .49934 L .3716 .49959 L .467 .07 0 r
F
.3866 .49836 m .37172 .49894 L .37161 .49959 L F
.37215 .49639 m .37214 .49639 L .37172 .49894 L 1 .931 0 r
F
.37214 .49639 m .37214 .49638 L .37172 .49894 L F
.37594 .49744 m .37272 .49318 L .37227 .49574 L 1 .94 0 r
F
.37214 .49638 m .3578 .48904 L .3572 .49223 L F
.37594 .49744 m .37227 .49574 L .37214 .49638 L F
.37214 .49638 m .37219 .49574 L .37209 .49639 L .467 .07 0 r
F
.37216 .49629 m .37219 .49574 L .37214 .49638 L F
.37227 .49574 m .37219 .49574 L .37215 .49638 L F
.37227 .49574 m .3578 .48904 L .37214 .49638 L 1 .94 0 r
F
.37215 .49638 m .37216 .49629 L .37214 .49638 L .467 .07 0 r
F
.3866 .49836 m .37215 .49638 L .37196 .49747 L F
.3866 .49836 m .37196 .49747 L .37172 .49894 L F
.37196 .49747 m .37215 .49638 L .37214 .49638 L F
.37214 .49639 m .37214 .49638 L .37214 .49638 L 1 .931 0 r
F
.37172 .49893 m .37214 .49638 L .3572 .49223 L F
.37226 .49574 m .37271 .49317 L .3578 .48904 L 1 .94 0 r
F
.37227 .49574 m .37271 .49317 L .37226 .49574 L F
.37272 .49317 m .37271 .49317 L .37271 .49317 L .467 .071 0 r
F
.38691 .49269 m .37284 .49254 L .37272 .49317 L F
.38674 .49553 m .38691 .49269 L .37272 .49317 L .467 .07 0 r
F
.37272 .49317 m .37272 .49317 L .37271 .49317 L F
.38674 .49553 m .37272 .49317 L .37272 .49317 L F
.37227 .49574 m .37272 .49317 L .37229 .49559 L 1 .94 0 r
F
.37272 .49318 m .37272 .49317 L .37227 .49574 L F
.38674 .49553 m .37271 .49317 L .37227 .49574 L .467 .07 0 r
F
.37227 .49574 m .37229 .49559 L .37227 .49574 L 1 .94 0 r
F
.38674 .49553 m .37227 .49574 L .37215 .49638 L .467 .07 0 r
F
.3866 .49836 m .38674 .49553 L .37215 .49638 L F
.37101 .50335 m .37035 .5026 L .35611 .49861 L 1 .913 0 r
F
.37501 .50462 m .37107 .50291 L .37101 .50335 L F
.37107 .50291 m .37035 .5026 L .37101 .50335 L F
.37072 .50533 m .37101 .50335 L .35611 .49861 L F
.37471 .50717 m .37101 .50335 L .37072 .50533 L F
.37501 .50462 m .38647 .50117 L .37108 .5028 L .373 .545 0 r
F
.37501 .50462 m .37108 .5028 L .37035 .5026 L 1 .913 0 r
F
.39039 .51306 m .39051 .51217 L .39069 .51061 L .344 .052 0 r
F
.39033 .51308 m .39069 .51061 L .39057 .51064 L F
.39033 .51308 m .39057 .51064 L .28253 .53251 L F
.39033 .51308 m .39057 .51064 L .39033 .51308 L F
.38968 .51948 m .38971 .51714 L .38952 .51952 L .342 .051 0 r
F
.39504 .52149 m .39525 .51823 L .38996 .51709 L 1 .828 0 r
F
.38996 .5171 m .38996 .51709 L .38994 .51708 L F
.39504 .52149 m .38996 .51709 L .38996 .5171 L F
.39504 .52149 m .38994 .51708 L .38994 .51709 L F
.39504 .52149 m .38993 .51708 L .38969 .51949 L F
.38952 .51952 m .38971 .51714 L .2822 .5448 L .342 .051 0 r
F
.39547 .51497 m .39566 .5125 L .39062 .51121 L 1 .847 0 r
F
.39547 .51497 m .39062 .51121 L .3904 .51306 L F
.39031 .51385 m .37471 .50717 L .37436 .5104 L F
.39547 .51497 m .39042 .51307 L .39031 .51385 L F
.39039 .51306 m .39069 .51061 L .39033 .51308 L .344 .052 0 r
F
.39062 .51121 m .39069 .51061 L .37471 .50717 L 1 .847 0 r
F
.39566 .5125 m .39069 .51061 L .39062 .51121 L F
.3904 .51306 m .39071 .51061 L .39051 .51217 L .344 .052 0 r
F
.3904 .51306 m .39051 .51217 L .39039 .51306 L F
.39566 .5125 m .39572 .5117 L .39069 .51061 L 1 .847 0 r
F
.39572 .5117 m .3908 .50985 L .39069 .51061 L 1 .856 0 r
F
.40582 .51028 m .39074 .51061 L .3904 .51306 L .344 .052 0 r
F
.39074 .51061 m .39071 .51061 L .3904 .51306 L F
.39042 .51307 m .3904 .51306 L .39031 .51385 L 1 .847 0 r
F
.3904 .51306 m .37471 .50717 L .3903 .51385 L F
.39031 .51385 m .39025 .51309 L .39018 .51388 L .344 .052 0 r
F
.40582 .51028 m .39038 .51307 L .39031 .51385 L F
.39038 .51307 m .39025 .51309 L .39031 .51385 L F
.38996 .51629 m .39031 .51385 L .28232 .53868 L .343 .051 0 r
F
.39003 .51628 m .39031 .51385 L .38996 .51629 L F
.39005 .51628 m .39019 .51502 L .39022 .5146 L 1 .837 0 r
F
.39005 .51628 m .39022 .5146 L .39011 .51556 L F
.39007 .51627 m .39031 .51385 L .39003 .51628 L .343 .051 0 r
F
.39011 .51556 m .39022 .5146 L .39027 .51384 L 1 .837 0 r
F
.39019 .51502 m .39033 .51386 L .39031 .51385 L F
.39019 .51502 m .39031 .51385 L .39027 .51384 L F
.3904 .51306 m .3903 .51385 L .39031 .51385 L 1 .847 0 r
F
.39525 .51823 m .39033 .51386 L .39005 .51628 L 1 .837 0 r
F
.39007 .51627 m .39036 .51384 L .39031 .51385 L .343 .051 0 r
F
.40587 .51298 m .40582 .51028 L .39036 .51384 L F
.40587 .51298 m .39036 .51384 L .39007 .51627 L F
.38958 .5203 m .37403 .51363 L .37373 .51686 L 1 .828 0 r
F
.39504 .52149 m .38969 .51949 L .38959 .5203 L F
.38959 .5203 m .3896 .5195 L .38954 .52031 L .342 .051 0 r
F
.38969 .51949 m .38968 .51948 L .38959 .5203 L 1 .828 0 r
F
.39525 .51823 m .39003 .51628 L .38994 .51708 L 1 .837 0 r
F
.40594 .51565 m .38968 .51948 L .38959 .5203 L .342 .051 0 r
F
.38968 .51948 m .3896 .5195 L .38959 .5203 L F
.38968 .51948 m .37403 .51363 L .38959 .5203 L 1 .828 0 r
F
.38959 .5203 m .38958 .5203 L .38958 .5203 L F
.38958 .5203 m .37403 .51363 L .38958 .5203 L F
.38944 .52271 m .38963 .52031 L .38959 .5203 L 1 .819 0 r
F
.38934 .52268 m .38943 .52182 L .38959 .5203 L .341 .05 0 r
F
.38928 .52269 m .38959 .5203 L .38936 .52037 L F
.38919 .52272 m .38936 .52037 L .28217 .55086 L F
.38928 .52269 m .38936 .52037 L .38919 .52272 L F
.39443 .5344 m .39455 .53119 L .38865 .5299 L 1 .79 0 r
F
.38944 .52271 m .38959 .5203 L .38935 .52268 L 1 .819 0 r
F
.38921 .52353 m .28217 .55086 L .28224 .55686 L .341 .05 0 r
F
.38913 .5259 m .38931 .52352 L .38926 .52351 L 1 .809 0 r
F
.38927 .5227 m .28217 .55086 L .38921 .52353 L .341 .05 0 r
F
.38905 .52682 m .38895 .52679 L .38902 .52739 L 1 .8 0 r
F
.38883 .52676 m .28224 .55686 L .28239 .56279 L .34 .05 0 r
F
.38895 .52672 m .38883 .52675 L .38883 .52676 L F
.38883 .52675 m .28224 .55686 L .38883 .52676 L F
.39433 .53759 m .39443 .5344 L .38851 .53311 L 1 .78 0 r
F
.38895 .52671 m .28224 .55686 L .38895 .52672 L .34 .05 0 r
F
.38901 .52587 m .28224 .55686 L .38895 .52671 L F
.39486 .52473 m .38968 .52032 L .3895 .52273 L 1 .819 0 r
F
.38926 .52351 m .37373 .51686 L .37345 .52008 L F
.39486 .52473 m .38936 .52268 L .38926 .52351 L F
.38926 .52351 m .38927 .5227 L .38921 .52353 L .341 .05 0 r
F
.38936 .52268 m .38935 .52268 L .38926 .52351 L 1 .819 0 r
F
.3895 .52273 m .38968 .52032 L .38963 .52031 L F
.3895 .52273 m .38963 .52031 L .38944 .52271 L F
.40603 .51829 m .38935 .52268 L .38926 .52351 L .341 .05 0 r
F
.38935 .52268 m .38932 .52268 L .38926 .52351 L F
.38932 .52268 m .38927 .5227 L .38926 .52351 L F
.38934 .52268 m .38959 .5203 L .38928 .52269 L F
.38935 .52268 m .37373 .51686 L .38926 .52351 L 1 .819 0 r
F
.38897 .52588 m .38914 .52447 L .28224 .55686 L .34 .05 0 r
F
.38914 .52447 m .38926 .52351 L .38922 .52353 L F
.38914 .52447 m .38922 .52353 L .28224 .55686 L F
.38815 .53625 m .37279 .52969 L .37263 .53288 L 1 .78 0 r
F
.39433 .53759 m .38823 .53536 L .38815 .53625 L F
.38823 .53536 m .37279 .52969 L .38815 .53625 L F
.38908 .52588 m .38926 .52351 L .38922 .5235 L 1 .809 0 r
F
.38908 .52588 m .38922 .5235 L .38903 .52586 L F
.38903 .52586 m .3893 .5235 L .38926 .52351 L .34 .05 0 r
F
.38903 .52586 m .38926 .52351 L .38897 .52588 L F
.40614 .5209 m .40603 .51829 L .3893 .5235 L F
.38913 .5259 m .38926 .52351 L .38908 .52588 L 1 .809 0 r
F
.38919 .52592 m .38936 .52354 L .38931 .52352 L F
.38919 .52592 m .38931 .52352 L .38913 .5259 L F
.3947 .52796 m .38936 .52354 L .38919 .52592 L F
.40614 .5209 m .3893 .5235 L .38903 .52586 L .34 .05 0 r
F
.38894 .52671 m .37345 .52008 L .37321 .52329 L 1 .809 0 r
F
.38895 .52672 m .38894 .52671 L .38894 .52671 L F
.38894 .52671 m .37345 .52008 L .38894 .52671 L F
.3947 .52796 m .38903 .52586 L .38895 .52672 L F
.38903 .52586 m .38901 .52587 L .38898 .52638 L .34 .05 0 r
F
.38901 .52587 m .38895 .52671 L .38897 .52671 L F
.38903 .52586 m .37345 .52008 L .38895 .52672 L 1 .809 0 r
F
.38903 .52586 m .38898 .52638 L .38897 .52671 L .34 .05 0 r
F
.38895 .52679 m .38895 .52672 L .38845 .52661 L 1 .8 0 r
F
.39466 .52885 m .38895 .52672 L .38895 .52679 L F
.3884 .53542 m .38851 .53311 L .37279 .52969 L 1 .78 0 r
F
.39433 .53759 m .38851 .53311 L .3884 .53542 L F
.38895 .52679 m .38845 .52661 L .38892 .52725 L 1 .8 0 r
F
.38895 .52679 m .38892 .52725 L .38902 .52739 L F
.38897 .52671 m .38895 .52671 L .38895 .52672 L .34 .05 0 r
F
.40614 .5209 m .38903 .52586 L .38897 .52671 L F
.38903 .52586 m .38922 .5235 L .37345 .52008 L 1 .809 0 r
F
.38891 .5291 m .38902 .52739 L .38896 .52738 L 1 .8 0 r
F
.38885 .52908 m .38896 .52738 L .37321 .52329 L F
.38891 .5291 m .38896 .52738 L .38885 .52908 L F
.38848 .5322 m .38865 .5299 L .37298 .5265 L 1 .79 0 r
F
.39443 .5344 m .38865 .5299 L .38848 .5322 L F
.38954 .52031 m .38947 .52033 L .38947 .52034 L .342 .051 0 r
F
.38935 .52268 m .38959 .5203 L .37373 .51686 L 1 .819 0 r
F
.38943 .52182 m .3896 .5203 L .38959 .5203 L .341 .05 0 r
F
.40603 .51829 m .40594 .51565 L .3896 .5203 L F
.40603 .51829 m .3896 .5203 L .38934 .52268 L F
.40594 .51565 m .38993 .51712 L .38968 .51948 L .342 .051 0 r
F
.38993 .51712 m .38971 .51714 L .38968 .51948 L F
.38995 .51712 m .38995 .51708 L .38994 .51708 L F
.38993 .51712 m .38994 .51708 L .38971 .51714 L F
.38995 .51712 m .38994 .51708 L .38993 .51712 L F
.38989 .51709 m .38982 .51711 L .38982 .51711 L .343 .051 0 r
F
.38968 .51948 m .38993 .51708 L .37403 .51363 L 1 .828 0 r
F
.38969 .51949 m .38983 .51803 L .38968 .51948 L F
.38983 .51803 m .38993 .51708 L .38968 .51948 L F
.38994 .51709 m .38994 .51708 L .38993 .51708 L F
.39051 .51217 m .39071 .51061 L .39069 .51061 L .344 .052 0 r
F
.3904 .51306 m .39062 .51121 L .37471 .50717 L 1 .847 0 r
F
.40579 .50756 m .37501 .50462 L .39069 .51061 L 1 .708 0 r
F
.39069 .51061 m .37501 .50462 L .37471 .50717 L 1 .856 0 r
F
.40582 .51028 m .40579 .50756 L .39071 .51061 L .344 .052 0 r
F
.38994 .51708 m .37436 .5104 L .37403 .51363 L 1 .837 0 r
F
.38994 .51708 m .38996 .51629 L .38989 .51709 L .343 .051 0 r
F
.38995 .51695 m .38996 .51629 L .38994 .51708 L F
.39003 .51628 m .38996 .51629 L .38995 .51708 L F
.39003 .51628 m .37436 .5104 L .38994 .51708 L 1 .837 0 r
F
.38995 .51708 m .38995 .51695 L .38994 .51708 L .343 .051 0 r
F
.40587 .51298 m .39003 .51628 L .38995 .51708 L F
.39003 .51628 m .39027 .51384 L .37436 .5104 L 1 .837 0 r
F
.39005 .51628 m .39027 .51384 L .39003 .51628 L F
.40594 .51565 m .40587 .51298 L .38995 .51708 L .342 .051 0 r
F
.40594 .51565 m .38995 .51708 L .38995 .51712 L F
.38889 .52736 m .38845 .52661 L .37321 .52329 L 1 .8 0 r
F
.38902 .52739 m .3889 .52723 L .38889 .52736 L F
.3889 .52723 m .38845 .52661 L .38889 .52736 L F
.39466 .52885 m .38905 .52682 L .38902 .52739 L F
.39455 .53119 m .38902 .52739 L .38891 .5291 L F
.39466 .52885 m .40614 .5209 L .38895 .52672 L .465 .718 0 r
F
.41087 .53612 m .41112 .5342 L .41115 .53387 L .211 .02 0 r
F
.41085 .53613 m .41115 .53387 L .32894 .57438 L F
.41087 .53612 m .41115 .53387 L .41085 .53613 L F
.41777 .53586 m .41126 .5339 L .41117 .53453 L 1 .728 0 r
F
.41126 .5339 m .41115 .53387 L .41117 .53453 L F
.41777 .53586 m .41778 .53494 L .41115 .53387 L F
.41778 .53494 m .41127 .53297 L .41115 .53387 L 1 .738 0 r
F
.42638 .52888 m .41116 .53386 L .41112 .5342 L .211 .02 0 r
F
.4109 .5361 m .41112 .5342 L .41087 .53612 L F
.41117 .53453 m .41115 .53387 L .41108 .53451 L 1 .728 0 r
F
.41772 .53815 m .41777 .53586 L .41151 .5346 L F
.41148 .53473 m .41151 .5346 L .41108 .53451 L F
.41772 .53815 m .41151 .5346 L .41148 .53473 L F
.41772 .53815 m .41108 .53451 L .4109 .5361 L F
.41767 .54136 m .41052 .53921 L .41041 .54019 L 1 .718 0 r
F
.41767 .54136 m .41772 .53815 L .41081 .53704 L F
.41767 .54136 m .41081 .53704 L .4108 .53707 L F
.41767 .54136 m .4108 .53707 L .41052 .53921 L F
.41049 .53923 m .41076 .53739 L .3302 .57929 L .201 .015 0 r
F
.41076 .53739 m .41081 .53704 L .3302 .57929 L F
.4108 .53707 m .41072 .53703 L .41052 .53921 L 1 .718 0 r
F
.41076 .53739 m .41081 .53704 L .41081 .53704 L .201 .015 0 r
F
.41081 .53704 m .39455 .53119 L .39443 .5344 L 1 .728 0 r
F
.41772 .53815 m .4109 .5361 L .41081 .53704 L F
.4109 .5361 m .41088 .53611 L .41081 .53704 L .211 .02 0 r
F
.4109 .5361 m .39455 .53119 L .41081 .53704 L 1 .728 0 r
F
.42638 .52888 m .4109 .5361 L .41081 .53704 L .211 .02 0 r
F
.42723 .53314 m .42672 .53113 L .41042 .54018 L .18 .006 0 r
F
.41001 .54229 m .41034 .54057 L .41016 .54067 L F
.40989 .54235 m .41016 .54067 L .33176 .58387 L F
.41001 .54229 m .41016 .54067 L .40989 .54235 L F
.41764 .54454 m .41054 .54021 L .41038 .54238 L 1 .708 0 r
F
.41034 .54057 m .41041 .54019 L .33176 .58387 L .18 .006 0 r
F
.41031 .54024 m .3302 .57929 L .33176 .58387 L .201 .015 0 r
F
.41031 .54024 m .3302 .57929 L .41031 .54024 L F
.40992 .5433 m .33176 .58387 L .33358 .5881 L .18 .006 0 r
F
.41764 .54454 m .41003 .54227 L .40992 .5433 L 1 .708 0 r
F
.41023 .54233 m .41041 .54019 L .41003 .54227 L F
.41038 .54238 m .41054 .54021 L .41041 .54019 L F
.41038 .54238 m .41041 .54019 L .41023 .54233 L F
.42723 .53314 m .41003 .54227 L .40992 .5433 L .18 .006 0 r
F
.41003 .54227 m .33176 .58387 L .40992 .5433 L F
.40992 .5433 m .41003 .54227 L .40984 .54329 L 1 .708 0 r
F
.40984 .54329 m .39433 .53759 L .39425 .54078 L F
.41003 .54227 m .41042 .54018 L .41001 .54229 L .18 .006 0 r
F
.41003 .54227 m .39433 .53759 L .40984 .54329 L 1 .708 0 r
F
.42723 .53314 m .41045 .54017 L .41003 .54227 L .18 .006 0 r
F
.41045 .54017 m .41042 .54018 L .41003 .54227 L F
.40928 .54515 m .3928 .55694 L .38469 .56067 L .526 .778 0 r
F
.41025 .54529 m .3928 .55694 L .40928 .54515 L F
.3928 .55694 m .34502 .58886 L .38122 .56314 L F
.3928 .55694 m .38122 .56314 L .38469 .56067 L F
.34502 .58886 m .3306 .59849 L .34026 .5887 L F
.40793 .54401 m .40579 .54264 L .39425 .54078 L 1 .698 0 r
F
.41003 .54451 m .40797 .5436 L .40793 .54401 L F
.40797 .5436 m .40579 .54264 L .40793 .54401 L F
.41008 .54396 m .40579 .54264 L .41003 .54451 L F
.32095 .59513 m .32094 .59514 L .32066 .60107 L .299 .188 0 r
F
.33978 .58738 m .32066 .60107 L .31789 .6008 L .526 .778 0 r
F
.34234 .58739 m .32066 .60107 L .33978 .58738 L F
.34019 .59209 m .33081 .59288 L .33113 .59814 L F
.42522 .53501 m .34234 .58739 L .33978 .58738 L F
.43765 .54074 m .44463 .54204 L .42944 .53426 L 1 1 0 r
F
.42941 .53473 m .42944 .53426 L .42723 .53314 L F
.43765 .54074 m .42944 .53426 L .42941 .53473 L F
.4289 .54013 m .42903 .53893 L .42928 .53755 L 0 0 0 r
F
.44434 .54563 m .44448 .54389 L .43765 .54074 L 1 1 0 r
F
.44448 .54389 m .44463 .54204 L .43765 .54074 L F
.42637 .53396 m .42723 .53314 L .40992 .5433 L 0 0 0 r
F
.42944 .53426 m .4279 .5325 L .42723 .53314 L 1 1 0 r
F
.42934 .53273 m .42831 .5321 L .42944 .53426 L F
.42831 .5321 m .42672 .53113 L .4279 .5325 L F
.42831 .5321 m .4279 .5325 L .42944 .53426 L F
.42636 .53397 m .40992 .5433 L .40987 .54333 L 0 0 0 r
F
.46807 .54244 m .44241 .53765 L .44238 .54087 L 1 .588 0 r
F
.46805 .54564 m .46807 .54244 L .44238 .54087 L 1 .578 0 r
F
.44463 .54204 m .42934 .53273 L .42944 .53426 L 1 1 0 r
F
.46809 .53922 m .44244 .53441 L .44241 .53765 L 1 .597 0 r
F
.46807 .54244 m .46809 .53922 L .44241 .53765 L 1 .588 0 r
F
.44463 .54204 m .44486 .53862 L .42858 .5319 L 1 1 0 r
F
.42831 .5321 m .42858 .5319 L .42672 .53113 L F
.44463 .54204 m .42858 .5319 L .42831 .5321 L F
.40878 .54509 m .40878 .54421 L .4087 .54419 L 1 .698 0 r
F
.40878 .54509 m .4087 .54419 L .40786 .54481 L F
.42361 .53563 m .40987 .54333 L .40786 .54481 L 0 0 0 r
F
.44486 .53862 m .42638 .52888 L .42672 .53113 L 1 .994 0 r
F
.44486 .53862 m .44504 .53534 L .42638 .52888 L F
.46811 .53598 m .44248 .53115 L .44244 .53441 L 1 .607 0 r
F
.46809 .53922 m .46811 .53598 L .44244 .53441 L 1 .597 0 r
F
.44504 .53534 m .42612 .52649 L .42638 .52888 L 1 .95 0 r
F
.42931 .53191 m .42837 .52926 L .42833 .53183 L 1 .638 0 r
F
.46815 .54092 m .44519 .53218 L .44504 .53534 L 1 .931 0 r
F
.43472 .53235 m .42988 .53151 L .42987 .53196 L 1 .638 0 r
F
.44504 .53534 m .44519 .53218 L .42612 .52649 L 1 .95 0 r
F
.44837 .53346 m .43485 .53203 L .43472 .53235 L 1 .638 0 r
F
.43485 .53203 m .42988 .53151 L .43472 .53235 L F
.44834 .53602 m .44837 .53346 L .43472 .53235 L 1 .629 0 r
F
.42683 .5337 m .42723 .53314 L .42637 .53396 L 0 0 0 r
F
.43442 .53311 m .43472 .53235 L .42931 .53191 L 1 .629 0 r
F
.43442 .53311 m .42931 .53191 L .42918 .53201 L F
.42753 .53335 m .42723 .53314 L .42833 .53264 L 1 1 0 r
F
.42753 .53335 m .42833 .53264 L .42858 .53274 L F
.42675 .53407 m .4253 .53505 L .42522 .53501 L .526 .778 0 r
F
.44295 .53511 m .42918 .53201 L .42832 .53263 L 1 .629 0 r
F
.44443 .5352 m .42918 .53201 L .44295 .53511 L F
.42684 .53401 m .42832 .53263 L .42653 .53393 L 1 .681 0 r
F
.42684 .53408 m .41025 .54529 L .40928 .54515 L .526 .778 0 r
F
.44295 .53511 m .42832 .53263 L .43279 .53446 L 1 .629 0 r
F
.46811 .54451 m .44504 .53534 L .44486 .53862 L 1 .944 0 r
F
.46811 .54451 m .46815 .54092 L .44504 .53534 L F
.44833 .53856 m .44834 .53602 L .43372 .53483 L 1 .62 0 r
F
.42941 .53473 m .42781 .53356 L .42885 .53286 L 1 1 0 r
F
.42941 .53473 m .42885 .53286 L .42985 .53326 L F
.44295 .53511 m .43279 .53446 L .43372 .53483 L 1 .629 0 r
F
.44434 .54563 m .42941 .53473 L .42992 .53331 L 1 1 0 r
F
.44434 .54563 m .42992 .53331 L .42997 .53333 L F
.44434 .54563 m .42993 .53329 L .43372 .53483 L F
.44399 .54943 m .44434 .54563 L .43383 .53494 L F
.43382 .53496 m .43383 .53494 L .43377 .53489 L F
.44399 .54943 m .43383 .53494 L .43382 .53496 L F
.44399 .54943 m .43377 .53489 L .43377 .5349 L F
.42724 .54996 m .42725 .54873 L .42848 .54195 L 0 0 0 r
F
.42845 .54247 m .42848 .54195 L .42903 .53893 L F
.42724 .54996 m .42848 .54195 L .42845 .54247 L F
.42724 .54996 m .42903 .53893 L .4289 .54013 L F
.42997 .53333 m .42992 .53331 L .42993 .53329 L 1 1 0 r
F
.43372 .53483 m .42993 .53329 L .43053 .5316 L F
.42956 .53625 m .42955 .53605 L .42982 .53453 L 0 0 0 r
F
.42956 .53625 m .42982 .53453 L .42982 .53473 L F
.42925 .53807 m .42928 .53755 L .42955 .53605 L F
.42925 .53807 m .42955 .53605 L .42956 .53625 L F
.4289 .54013 m .42928 .53755 L .42925 .53807 L F
.42724 .54996 m .42724 .54989 L .42724 .54996 L F
.42724 .54989 m .42725 .54873 L .42724 .54996 L F
.42725 .54876 m .41763 .5463 L .4283 .53417 L 1 .842 0 r
F
.42985 .53326 m .42885 .53286 L .43024 .53193 L 1 1 0 r
F
.42781 .53356 m .42753 .53335 L .43024 .53193 L F
.43024 .53193 m .42753 .53335 L .43029 .53174 L F
.42982 .53473 m .42982 .53453 L .42983 .53452 L 0 0 0 r
F
.42941 .53473 m .4303 .53171 L .43053 .5316 L 1 1 0 r
F
.43372 .53483 m .42985 .53326 L .42983 .53436 L 1 .629 0 r
F
.43372 .53483 m .4283 .53417 L .42983 .53452 L F
.43345 .53547 m .4335 .53535 L .42982 .53467 L 1 .62 0 r
F
.42725 .54876 m .4283 .53417 L .42983 .53452 L 1 .842 0 r
F
.42982 .53471 m .42982 .53467 L .42829 .53439 L 1 .62 0 r
F
.43345 .53547 m .42982 .53467 L .42982 .53471 L F
.42982 .53471 m .42983 .53452 L .42982 .53471 L 0 0 0 r
F
.42982 .53473 m .42983 .53452 L .42982 .53471 L F
.43018 .53474 m .42983 .53452 L .42829 .53439 L 1 .62 0 r
F
.4335 .53535 m .43115 .53482 L .43018 .53474 L F
.43115 .53482 m .42983 .53452 L .43018 .53474 L F
.42982 .53471 m .42983 .53452 L .4303 .53189 L 0 0 0 r
F
.42983 .53436 m .42974 .53426 L .4283 .53417 L 1 .629 0 r
F
.42974 .53426 m .42832 .53263 L .4283 .53417 L F
.42701 .53409 m .41763 .5463 L .41025 .54529 L .526 .778 0 r
F
.42985 .53326 m .42832 .53263 L .42983 .53436 L 1 .629 0 r
F
.4283 .53417 m .42832 .53263 L .42684 .53401 L 1 .681 0 r
F
.42709 .53404 m .4283 .53417 L .42701 .53409 L .526 .778 0 r
F
.4303 .53189 m .4283 .53417 L .42709 .53404 L F
.42827 .53417 m .41763 .5463 L .42701 .53409 L F
.4283 .53417 m .41763 .5463 L .42827 .53417 L F
.42725 .54876 m .41763 .5463 L .41762 .54771 L 1 .631 0 r
F
.42723 .54998 m .42982 .53471 L .41763 .54891 L 0 0 0 r
F
.42976 .53478 m .42829 .53459 L .41763 .54891 L F
.42982 .53471 m .42829 .53459 L .42976 .53478 L F
.42701 .53409 m .41025 .54529 L .42684 .53408 L .526 .778 0 r
F
.42684 .53408 m .4253 .53505 L .42675 .53407 L F
.42639 .53401 m .42417 .53521 L .42361 .53563 L 0 0 0 r
F
.4268 .53372 m .42417 .53521 L .42639 .53401 L F
.42637 .53396 m .40992 .5433 L .42636 .53397 L F
.4253 .53505 m .34234 .58739 L .42522 .53501 L .526 .778 0 r
F
.41053 .54657 m .40878 .54509 L .40875 .54629 L 1 .698 0 r
F
.41762 .54771 m .40968 .54535 L .41053 .54657 L F
.40968 .54535 m .40878 .54509 L .41053 .54657 L F
.41762 .55399 m .41761 .55086 L .41589 .55058 L 1 .678 0 r
F
.41565 .55231 m .41589 .55058 L .41311 .55014 L F
.41762 .55399 m .41589 .55058 L .41565 .55231 L F
.41546 .55364 m .33766 .59574 L .41546 .55364 L .459 .393 0 r
F
.41735 .55751 m .41764 .55674 L .33962 .59938 L .477 .382 0 r
F
.41764 .55674 m .41762 .55399 L .41546 .55364 L 1 .667 0 r
F
.41762 .55399 m .41551 .55337 L .41546 .55364 L 1 .678 0 r
F
.4135 .54718 m .41762 .54771 L .41352 .54705 L 1 .688 0 r
F
.41445 .54799 m .41762 .54771 L .41071 .54682 L F
.41076 .54688 m .41071 .54682 L .41043 .54679 L F
.41445 .54799 m .41071 .54682 L .41076 .54688 L F
.41043 .54679 m .4135 .54718 L .40986 .54646 L F
.4135 .54718 m .41352 .54705 L .40986 .54646 L F
.41761 .54893 m .40875 .54629 L .40815 .54669 L .57 .814 0 r
F
.41761 .54893 m .41762 .54771 L .4128 .54813 L 1 .688 0 r
F
.40878 .54509 m .40875 .5451 L .40877 .54627 L .526 .778 0 r
F
.41764 .55674 m .41546 .55364 L .33962 .59938 L .477 .382 0 r
F
.41546 .55364 m .33766 .59574 L .33962 .59938 L .459 .393 0 r
F
.41551 .55337 m .33766 .59574 L .41547 .55364 L F
.41533 .55346 m .41304 .55018 L .33766 .59574 L F
.41311 .55014 m .37162 .57256 L .3746 .57341 L .526 .676 0 r
F
.41511 .55636 m .41546 .55364 L .40876 .55258 L 1 .667 0 r
F
.40863 .54518 m .33081 .59288 L .40865 .54635 L .526 .778 0 r
F
.37009 .57212 m .33985 .5881 L .34019 .59209 L F
.33985 .5881 m .33081 .59288 L .34019 .59209 L F
.40856 .54641 m .36702 .57123 L .37009 .57212 L F
.40875 .54629 m .40856 .5464 L .40856 .54641 L F
.40856 .5464 m .36702 .57123 L .40856 .54641 L F
.42194 .55756 m .41763 .55676 L .41735 .55751 L 1 .939 0 r
F
.42895 .55975 m .41735 .55751 L .43981 .56255 L 1 .88 0 r
F
.41735 .55751 m .33962 .59938 L .34135 .60308 L .477 .382 0 r
F
.41504 .56409 m .41735 .55751 L .34135 .60308 L .506 .399 0 r
F
.41768 .56019 m .41764 .5571 L .4088 .55569 L 1 .657 0 r
F
.36702 .57123 m .33081 .59288 L .37009 .57212 L .526 .778 0 r
F
.40875 .54628 m .33081 .59288 L .40875 .54629 L F
.40751 .54625 m .35709 .57478 L .33559 .59203 L 0 0 0 r
F
.40772 .54612 m .40751 .54624 L .40751 .54625 L F
.40751 .54624 m .35709 .57478 L .40751 .54625 L F
.40885 .55763 m .4088 .55569 L .40695 .5554 L 1 .657 0 r
F
.40772 .54612 m .35709 .57478 L .40772 .54612 L 0 0 0 r
F
.40875 .54629 m .40784 .54501 L .40772 .54612 L 1 .698 0 r
F
.40786 .54481 m .33358 .5881 L .40772 .54612 L 0 0 0 r
F
.40878 .54509 m .39421 .54311 L .39419 .54395 L 1 .698 0 r
F
.40786 .54481 m .40772 .54612 L .40774 .54611 L 0 0 0 r
F
.40784 .54496 m .39425 .54078 L .39421 .54311 L 1 .698 0 r
F
.40878 .54509 m .40786 .54481 L .40784 .54496 L F
.40786 .54481 m .39425 .54078 L .40784 .54496 L F
.41311 .55014 m .33559 .59203 L .41311 .55014 L .526 .676 0 r
F
.41318 .54956 m .33559 .59203 L .41311 .55014 L F
.40875 .5451 m .40863 .54518 L .40875 .54628 L .526 .778 0 r
F
.40863 .54518 m .40865 .54635 L .40875 .54628 L F
.40875 .5451 m .40875 .54628 L .40877 .54627 L F
.4132 .54955 m .40772 .54612 L .33559 .59203 L .526 .676 0 r
F
.40972 .54853 m .40986 .54646 L .40875 .54629 L 1 .688 0 r
F
.41257 .54937 m .40986 .54646 L .40972 .54853 L F
.41761 .55086 m .41086 .54703 L .41257 .54937 L F
.41086 .54703 m .40986 .54646 L .41257 .54937 L F
.41762 .55399 m .41311 .55014 L .41325 .55032 L 1 .678 0 r
F
.41317 .55019 m .41311 .55014 L .41315 .55019 L .459 .393 0 r
F
.41761 .55086 m .4132 .54955 L .41311 .55014 L 1 .688 0 r
F
.41761 .55086 m .41761 .54893 L .4128 .54813 L F
.41978 .55104 m .41313 .55014 L .41317 .55019 L .459 .393 0 r
F
.41313 .55014 m .41311 .55014 L .41317 .55019 L F
.41762 .54771 m .41763 .5463 L .40878 .54509 L 1 .698 0 r
F
.41761 .54893 m .42829 .53459 L .40875 .54629 L .57 .814 0 r
F
.427 .53425 m .42829 .53439 L .42684 .5342 L 1 .671 0 r
F
.4283 .53417 m .4283 .53417 L .42827 .53417 L .526 .778 0 r
F
.42983 .53452 m .4283 .53417 L .4283 .53417 L 1 .842 0 r
F
.42983 .53452 m .4283 .53417 L .42829 .53439 L 1 .629 0 r
F
.42983 .53452 m .4283 .53417 L .4303 .53189 L 1 .842 0 r
F
.43349 .53552 m .43374 .53485 L .43348 .5355 L 1 1 0 r
F
.44399 .54943 m .43376 .53489 L .43349 .53552 L F
.43376 .53489 m .43374 .53485 L .43349 .53552 L F
.43374 .53485 m .43372 .53489 L .43348 .5355 L F
.43348 .5355 m .43374 .53485 L .43372 .53483 L F
.43348 .5355 m .43372 .53483 L .4337 .53487 L F
.43719 .53624 m .43345 .53547 L .44154 .53801 L 1 .62 0 r
F
.44399 .54943 m .43345 .53547 L .42252 .54445 L 1 1 0 r
F
.43345 .53547 m .42829 .53439 L .43194 .53539 L 1 .62 0 r
F
.42931 .53467 m .42829 .53439 L .42829 .53459 L F
.42982 .53471 m .4303 .53189 L .42829 .53459 L 0 0 0 r
F
.42982 .53471 m .42829 .53459 L .42829 .53459 L F
.4335 .53535 m .43372 .53483 L .42983 .53452 L 1 .62 0 r
F
.43312 .53574 m .42829 .5352 L .42252 .54445 L 1 1 0 r
F
.43345 .53547 m .42829 .5352 L .43312 .53574 L F
.42829 .53459 m .42684 .5342 L .40875 .54629 L .57 .814 0 r
F
.40875 .54629 m .40878 .54509 L .40784 .54501 L 1 .698 0 r
F
.42684 .5342 m .40878 .54509 L .40877 .54627 L .526 .778 0 r
F
.42692 .53402 m .42701 .53409 L .42684 .53408 L F
.4303 .53189 m .42709 .53404 L .42692 .53402 L F
.42709 .53404 m .42701 .53409 L .42692 .53402 L F
.42638 .52888 m .41112 .5342 L .4109 .5361 L .211 .02 0 r
F
.41173 .53081 m .41174 .53071 L .41155 .53068 L 1 .738 0 r
F
.42612 .52649 m .39466 .52885 L .41115 .53387 L 1 .517 0 r
F
.42638 .52888 m .42612 .52649 L .41117 .53386 L .211 .02 0 r
F
.42638 .52888 m .41117 .53386 L .41117 .53386 L F
.42682 .53371 m .42637 .53396 L .42636 .53397 L 0 0 0 r
F
.42683 .5337 m .42637 .53396 L .42682 .53371 L F
.42691 .53365 m .4283 .53264 L .42683 .5337 L F
.42832 .53263 m .42723 .53314 L .42683 .5337 L F
.4279 .5325 m .42672 .53113 L .42723 .53314 L 1 1 0 r
F
.42672 .53113 m .42638 .52888 L .41082 .53703 L .201 .015 0 r
F
.42672 .53113 m .41082 .53703 L .41082 .53703 L F
.41052 .53921 m .41081 .53704 L .41049 .53923 L F
.42672 .53113 m .41084 .53703 L .41052 .53921 L F
.41084 .53703 m .41081 .53704 L .41052 .53921 L F
.41043 .53995 m .41045 .53925 L .41041 .54019 L F
.41052 .53921 m .41045 .53925 L .41043 .54018 L F
.41052 .53921 m .39443 .5344 L .41038 .54017 L 1 .718 0 r
F
.41043 .54001 m .41043 .53995 L .41041 .54019 L .201 .015 0 r
F
.41052 .53921 m .41038 .54017 L .41041 .54019 L 1 .718 0 r
F
.42672 .53113 m .41052 .53921 L .41043 .54018 L .201 .015 0 r
F
.42653 .53393 m .42832 .53263 L .42005 .53122 L 1 .681 0 r
F
.42021 .53078 m .40653 .52857 L .40667 .5311 L .942 .409 0 r
F
.41108 .53451 m .41115 .53387 L .39455 .53119 L 1 .728 0 r
F
.41115 .53387 m .39466 .52885 L .39455 .53119 L 1 .738 0 r
F
.41583 .53278 m .40667 .5311 L .4068 .53361 L .307 0 0 r
F
.41583 .53278 m .40667 .5311 L .41583 .53278 L F
.4162 .53122 m .40667 .5311 L .41583 .53278 L F
.418 .53306 m .41597 .53222 L .41583 .53278 L 1 .681 0 r
F
.41972 .53214 m .4162 .53122 L .41933 .5332 L F
.4162 .53122 m .42021 .53078 L .40667 .5311 L .307 0 0 r
F
.41972 .53214 m .41635 .53058 L .4162 .53122 L 1 .681 0 r
F
.42832 .53263 m .42574 .5315 L .40895 .52932 L F
.4162 .53122 m .42022 .53078 L .42021 .53078 L .307 0 0 r
F
.41972 .53214 m .42005 .53122 L .41856 .53096 L 1 .681 0 r
F
.41743 .53109 m .41856 .53096 L .41635 .53058 L F
.41972 .53214 m .41856 .53096 L .41743 .53109 L F
.4162 .53122 m .40895 .52932 L .41453 .53141 L F
.4162 .53122 m .41453 .53141 L .41933 .5332 L F
.44837 .53346 m .43196 .53002 L .42988 .53151 L 1 .638 0 r
F
.43196 .53002 m .42837 .52926 L .42931 .53191 L F
.42833 .53183 m .42837 .52926 L .42121 .52833 L 1 .69 0 r
F
.46813 .53272 m .44253 .52787 L .44248 .53115 L 1 .616 0 r
F
.46811 .53598 m .46813 .53272 L .44248 .53115 L 1 .607 0 r
F
.46819 .5374 m .44531 .52908 L .44519 .53218 L 1 .918 0 r
F
.44519 .53218 m .44531 .52908 L .42592 .52401 L 1 .91 0 r
F
.44519 .53218 m .42592 .52401 L .42612 .52649 L F
.4484 .53089 m .42843 .52668 L .42837 .52926 L 1 .647 0 r
F
.46815 .54092 m .46819 .5374 L .44519 .53218 L 1 .931 0 r
F
.44837 .53346 m .4484 .53089 L .42837 .52926 L 1 .638 0 r
F
.42612 .52649 m .42592 .52401 L .40614 .5209 L 1 .517 0 r
F
.42121 .52833 m .4064 .52604 L .40653 .52857 L .946 .45 0 r
F
.42121 .52833 m .4064 .52604 L .42121 .52833 L F
.4216 .52747 m .4064 .52604 L .42121 .52833 L F
.4216 .52747 m .42231 .52588 L .42202 .52584 L 1 .699 0 r
F
.42837 .52926 m .42843 .52668 L .42231 .52588 L F
.42837 .52926 m .42231 .52588 L .4216 .52747 L F
.46815 .52943 m .44258 .52457 L .44253 .52787 L 1 .625 0 r
F
.46813 .53272 m .46815 .52943 L .44253 .52787 L 1 .616 0 r
F
.44253 .52787 m .44258 .52457 L .41817 .52191 L 1 .699 0 r
F
.46823 .53395 m .4454 .52604 L .44531 .52908 L 1 .905 0 r
F
.44258 .52457 m .41831 .51862 L .41817 .52191 L 1 .708 0 r
F
.44531 .52908 m .4454 .52604 L .42576 .52146 L 1 .876 0 r
F
.44531 .52908 m .42576 .52146 L .42592 .52401 L F
.44843 .52831 m .4285 .52408 L .42843 .52668 L 1 .656 0 r
F
.46819 .5374 m .46823 .53395 L .44531 .52908 L 1 .918 0 r
F
.4484 .53089 m .44843 .52831 L .42843 .52668 L 1 .647 0 r
F
.42592 .52401 m .42576 .52146 L .40603 .51829 L 1 .563 0 r
F
.42592 .52401 m .40603 .51829 L .40614 .5209 L F
.42843 .52668 m .4285 .52408 L .42278 .52333 L 1 .707 0 r
F
.42576 .52146 m .40594 .51565 L .40603 .51829 L 1 .598 0 r
F
.46817 .52612 m .44264 .52126 L .44258 .52457 L 1 .634 0 r
F
.46815 .52943 m .46817 .52612 L .44258 .52457 L 1 .625 0 r
F
.44258 .52457 m .44264 .52126 L .41831 .51862 L 1 .708 0 r
F
.46827 .53055 m .44548 .52304 L .4454 .52604 L 1 .892 0 r
F
.44264 .52126 m .41845 .51532 L .41831 .51862 L 1 .717 0 r
F
.4454 .52604 m .44548 .52304 L .42564 .51885 L 1 .849 0 r
F
.4454 .52604 m .42564 .51885 L .42576 .52146 L F
.44848 .52572 m .42858 .52147 L .4285 .52408 L 1 .664 0 r
F
.42576 .52146 m .42564 .51885 L .40594 .51565 L 1 .598 0 r
F
.42858 .52147 m .40943 .51633 L .4093 .51895 L 1 .725 0 r
F
.4285 .52408 m .42858 .52147 L .42333 .52079 L 1 .716 0 r
F
.42291 .52259 m .42333 .52079 L .4093 .51895 L F
.4285 .52408 m .42333 .52079 L .42291 .52259 L F
.42277 .52334 m .42278 .52333 L .42273 .52333 L 1 .707 0 r
F
.46823 .53395 m .46827 .53055 L .4454 .52604 L 1 .905 0 r
F
.44843 .52831 m .44848 .52572 L .4285 .52408 L 1 .656 0 r
F
.4285 .52408 m .4093 .51895 L .40927 .51973 L 1 .716 0 r
F
.40949 .51979 m .40927 .51973 L .40925 .51975 L 1 .685 0 r
F
.41951 .52336 m .40925 .51975 L .40626 .52348 L F
.42273 .52333 m .40951 .51982 L .41951 .52336 L F
.40951 .51982 m .40925 .51975 L .41951 .52336 L F
.40927 .51973 m .4093 .51895 L .4046 .51808 L 1 .766 0 r
F
.40626 .52348 m .40927 .51973 L .38621 .51763 L .772 .944 0 r
F
.40927 .51973 m .4046 .51808 L .4046 .51808 L 1 .766 0 r
F
.4046 .51808 m .38621 .51494 L .38621 .51763 L .972 .526 0 r
F
.40475 .51745 m .38621 .51494 L .4046 .51808 L F
.405 .51551 m .38622 .51222 L .38621 .51494 L .969 .53 0 r
F
.40515 .51491 m .38622 .51222 L .405 .51551 L F
.4093 .51895 m .40943 .51633 L .40527 .51556 L 1 .775 0 r
F
.40523 .51569 m .40527 .51556 L .405 .51551 L F
.4093 .51895 m .40527 .51556 L .40523 .51569 L F
.42564 .51885 m .40587 .51298 L .40594 .51565 L 1 .626 0 r
F
.44264 .52126 m .44271 .51793 L .41845 .51532 L 1 .717 0 r
F
.44548 .52304 m .42555 .51619 L .42564 .51885 L 1 .829 0 r
F
.44271 .51793 m .41861 .512 L .41845 .51532 L 1 .726 0 r
F
.42564 .51885 m .42555 .51619 L .40587 .51298 L 1 .626 0 r
F
.42868 .51885 m .40958 .5137 L .40943 .51633 L 1 .733 0 r
F
.42858 .52147 m .42868 .51885 L .40943 .51633 L 1 .725 0 r
F
.40542 .51293 m .38625 .50948 L .38622 .51222 L .965 .533 0 r
F
.42555 .51619 m .40582 .51028 L .40587 .51298 L 1 .65 0 r
F
.46819 .52279 m .44271 .51793 L .44264 .52126 L 1 .643 0 r
F
.44271 .51793 m .44278 .51458 L .41861 .512 L 1 .726 0 r
F
.44555 .52004 m .42548 .51348 L .42555 .51619 L 1 .813 0 r
F
.42555 .51619 m .42548 .51348 L .40582 .51028 L 1 .65 0 r
F
.42878 .51623 m .40975 .51106 L .40958 .5137 L 1 .741 0 r
F
.40958 .5137 m .40975 .51106 L .40614 .51039 L 1 .792 0 r
F
.40584 .51034 m .3863 .50673 L .38625 .50948 L .96 .536 0 r
F
.44278 .51458 m .41879 .50867 L .41861 .512 L 1 .735 0 r
F
.42548 .51348 m .40579 .50756 L .40582 .51028 L 1 .67 0 r
F
.46821 .51944 m .44278 .51458 L .44271 .51793 L 1 .652 0 r
F
.44562 .51706 m .42544 .51074 L .42548 .51348 L 1 .803 0 r
F
.42548 .51348 m .42544 .51074 L .40579 .50756 L 1 .67 0 r
F
.4289 .51359 m .40993 .50842 L .40975 .51106 L 1 .749 0 r
F
.40975 .51106 m .40993 .50842 L .40657 .5078 L 1 .8 0 r
F
.40626 .50774 m .38638 .50396 L .3863 .50673 L .956 .539 0 r
F
.42544 .51074 m .40579 .5048 L .40579 .50756 L 1 .689 0 r
F
.44287 .51122 m .41897 .50533 L .41879 .50867 L 1 .744 0 r
F
.44278 .51458 m .44287 .51122 L .41879 .50867 L 1 .735 0 r
F
.41879 .50867 m .41897 .50533 L .39657 .50184 L 1 .812 0 r
F
.46824 .51606 m .44287 .51122 L .44278 .51458 L 1 .661 0 r
F
.44567 .51408 m .42542 .50795 L .42544 .51074 L 1 .796 0 r
F
.42544 .51074 m .42542 .50795 L .40579 .5048 L 1 .689 0 r
F
.42903 .51094 m .41014 .50577 L .40993 .50842 L 1 .757 0 r
F
.40993 .50842 m .41014 .50577 L .40702 .50519 L 1 .808 0 r
F
.40579 .50756 m .40579 .5048 L .38647 .50117 L 1 .708 0 r
F
.41897 .50533 m .3969 .49854 L .39657 .50184 L 1 .821 0 r
F
.42542 .50795 m .40581 .50201 L .40579 .5048 L 1 .705 0 r
F
.40581 .50201 m .38674 .49553 L .3866 .49836 L 1 .738 0 r
F
.40579 .5048 m .40581 .50201 L .3866 .49836 L 1 .723 0 r
F
.46826 .51267 m .44295 .50784 L .44287 .51122 L 1 .669 0 r
F
.44295 .50784 m .41917 .50198 L .41897 .50533 L 1 .753 0 r
F
.44287 .51122 m .44295 .50784 L .41897 .50533 L 1 .744 0 r
F
.44573 .51108 m .42542 .50513 L .42542 .50795 L 1 .791 0 r
F
.41897 .50533 m .41917 .50198 L .3969 .49854 L 1 .821 0 r
F
.42542 .50795 m .42542 .50513 L .40581 .50201 L 1 .705 0 r
F
.42917 .50829 m .41036 .50311 L .41014 .50577 L 1 .765 0 r
F
.41917 .50198 m .39725 .49523 L .3969 .49854 L 1 .83 0 r
F
.42542 .50513 m .40586 .4992 L .40581 .50201 L 1 .72 0 r
F
.40581 .50201 m .40586 .4992 L .38674 .49553 L 1 .738 0 r
F
.41036 .50311 m .39264 .49709 L .39233 .49975 L 1 .823 0 r
F
.41014 .50577 m .41036 .50311 L .40711 .50251 L 1 .816 0 r
F
.40677 .50463 m .40711 .50251 L .39233 .49975 L F
.41014 .50577 m .40711 .50251 L .40677 .50463 L F
.40641 .50723 m .407 .50523 L .40668 .50517 L 1 .808 0 r
F
.40635 .50722 m .40668 .5052 L .38638 .50396 L .956 .539 0 r
F
.40668 .5052 m .40669 .50513 L .38638 .50396 L F
.40993 .50842 m .40702 .50519 L .40641 .50723 L 1 .808 0 r
F
.41092 .50797 m .40669 .50513 L .40668 .5052 L .956 .539 0 r
F
.40641 .50723 m .40668 .5052 L .40635 .50722 L F
.41092 .50797 m .40668 .5052 L .40641 .50723 L F
.40579 .5048 m .3866 .49836 L .38647 .50117 L 1 .723 0 r
F
.4036 .50495 m .39226 .50023 L .38638 .50396 L 1 .797 0 r
F
.40669 .50513 m .39256 .50033 L .4036 .50495 L F
.39256 .50033 m .39226 .50023 L .4036 .50495 L F
.41014 .50577 m .39233 .49975 L .39228 .50021 L 1 .816 0 r
F
.41109 .50538 m .39345 .49948 L .39228 .50021 L 1 .797 0 r
F
.39258 .50032 m .39228 .50021 L .39226 .50023 L F
.41014 .50577 m .39228 .50021 L .40669 .50513 L 1 .816 0 r
F
.41109 .50538 m .39228 .50021 L .39258 .50032 L 1 .797 0 r
F
.41109 .50538 m .39226 .50023 L .40669 .50513 L F
.40669 .50513 m .39228 .50021 L .39205 .5024 L 1 .816 0 r
F
.38638 .50396 m .39228 .50021 L .36801 .49675 L .613 .847 0 r
F
.39228 .50021 m .39233 .49975 L .38958 .49906 L 1 .866 0 r
F
.39228 .50021 m .38958 .49906 L .36801 .49675 L .613 .847 0 r
F
.39205 .5024 m .39228 .50021 L .38949 .49944 L 1 .866 0 r
F
.38958 .49906 m .36824 .49392 L .36801 .49675 L .998 .597 0 r
F
.38967 .49864 m .36824 .49392 L .38958 .49906 L F
.39001 .49644 m .36849 .49107 L .36824 .49392 L .994 .599 0 r
F
.39233 .49975 m .39264 .49709 L .39025 .4965 L 1 .874 0 r
F
.3902 .4967 m .39025 .4965 L .39001 .49644 L F
.39233 .49975 m .39025 .4965 L .3902 .4967 L F
.40586 .4992 m .38691 .49269 L .38674 .49553 L 1 .753 0 r
F
.44305 .50444 m .41939 .49862 L .41917 .50198 L 1 .762 0 r
F
.41939 .49862 m .39762 .49192 L .39725 .49523 L 1 .839 0 r
F
.41917 .50198 m .41939 .49862 L .39725 .49523 L 1 .83 0 r
F
.42544 .50228 m .40593 .49636 L .40586 .4992 L 1 .734 0 r
F
.44295 .50784 m .44305 .50444 L .41917 .50198 L 1 .753 0 r
F
.42542 .50513 m .42544 .50228 L .40586 .4992 L 1 .72 0 r
F
.40586 .4992 m .40593 .49636 L .38691 .49269 L 1 .753 0 r
F
.41059 .50045 m .39297 .49443 L .39264 .49709 L 1 .831 0 r
F
.41036 .50311 m .41059 .50045 L .39264 .49709 L 1 .823 0 r
F
.39264 .49709 m .39297 .49443 L .39048 .49381 L 1 .881 0 r
F
.39047 .49381 m .36877 .48822 L .36849 .49107 L .99 .601 0 r
F
.44315 .50103 m .41961 .49526 L .41939 .49862 L 1 .771 0 r
F
.44305 .50444 m .44315 .50103 L .41939 .49862 L 1 .762 0 r
F
.41939 .49862 m .41961 .49526 L .39762 .49192 L 1 .839 0 r
F
.42547 .4994 m .40602 .4935 L .40593 .49636 L 1 .748 0 r
F
.42544 .50228 m .42547 .4994 L .40593 .49636 L 1 .734 0 r
F
.41961 .49526 m .398 .48861 L .39762 .49192 L 1 .848 0 r
F
.40593 .49636 m .40602 .4935 L .38711 .48982 L 1 .767 0 r
F
.40593 .49636 m .38711 .48982 L .38691 .49269 L F
.41085 .49778 m .39332 .49177 L .39297 .49443 L 1 .838 0 r
F
.39297 .49443 m .39332 .49177 L .39119 .49123 L 1 .889 0 r
F
.39094 .49117 m .36908 .48535 L .36877 .48822 L .986 .603 0 r
F
.44326 .4976 m .41985 .49188 L .41961 .49526 L 1 .779 0 r
F
.44315 .50103 m .44326 .4976 L .41961 .49526 L 1 .771 0 r
F
.41961 .49526 m .41985 .49188 L .398 .48861 L 1 .848 0 r
F
.42553 .49649 m .40614 .49061 L .40602 .4935 L 1 .76 0 r
F
.42547 .4994 m .42553 .49649 L .40602 .4935 L 1 .748 0 r
F
.40602 .4935 m .40614 .49061 L .38734 .48695 L 1 .781 0 r
F
.40602 .4935 m .38734 .48695 L .38711 .48982 L F
.41112 .49511 m .3937 .4891 L .39332 .49177 L 1 .846 0 r
F
.39332 .49177 m .3937 .4891 L .39169 .4886 L 1 .896 0 r
F
.39143 .48854 m .36942 .48247 L .36908 .48535 L .981 .604 0 r
F
.41985 .49188 m .39841 .4853 L .398 .48861 L 1 .857 0 r
F
.398 .48861 m .39841 .4853 L .37851 .48121 L 1 .919 0 r
F
.44338 .49416 m .42011 .48849 L .41985 .49188 L 1 .788 0 r
F
.44326 .4976 m .44338 .49416 L .41985 .49188 L 1 .779 0 r
F
.41985 .49188 m .42011 .48849 L .39841 .4853 L 1 .857 0 r
F
.4256 .49356 m .40629 .4877 L .40614 .49061 L 1 .772 0 r
F
.42553 .49649 m .4256 .49356 L .40614 .49061 L 1 .76 0 r
F
.40614 .49061 m .40629 .4877 L .38759 .48405 L 1 .794 0 r
F
.40614 .49061 m .38759 .48405 L .38734 .48695 L F
.41141 .49243 m .39409 .48643 L .3937 .4891 L 1 .853 0 r
F
.3937 .4891 m .39409 .48643 L .3922 .48596 L 1 .904 0 r
F
.38734 .48695 m .38759 .48405 L .3698 .47958 L 1 .847 0 r
F
.39841 .4853 m .3791 .47797 L .37851 .48121 L 1 .927 0 r
F
.42011 .48849 m .39884 .48198 L .39841 .4853 L 1 .866 0 r
F
.39841 .4853 m .39884 .48198 L .3791 .47797 L 1 .927 0 r
F
.40629 .4877 m .38787 .48115 L .38759 .48405 L 1 .807 0 r
F
.38759 .48405 m .38787 .48115 L .3702 .47669 L 1 .858 0 r
F
.41172 .48976 m .39451 .48377 L .39409 .48643 L 1 .86 0 r
F
.39884 .48198 m .37972 .47474 L .3791 .47797 L 1 .936 0 r
F
.40646 .48478 m .38817 .47823 L .38787 .48115 L 1 .819 0 r
F
.40629 .4877 m .40646 .48478 L .38787 .48115 L 1 .807 0 r
F
.38787 .48115 m .38817 .47823 L .37064 .47378 L 1 .869 0 r
F
.38787 .48115 m .37064 .47378 L .3702 .47669 L F
.39451 .48377 m .37872 .47701 L .37818 .47966 L 1 .918 0 r
F
.39409 .48643 m .39451 .48377 L .39249 .48326 L 1 .911 0 r
F
.39202 .48555 m .39249 .48326 L .37818 .47966 L F
.39409 .48643 m .39249 .48326 L .39202 .48555 L F
.39154 .48819 m .39219 .486 L .39194 .48594 L 1 .904 0 r
F
.39148 .48817 m .39193 .48595 L .36942 .48247 L .981 .604 0 r
F
.39193 .48595 m .39194 .4859 L .36942 .48247 L F
.3937 .4891 m .3922 .48596 L .39154 .48819 L 1 .904 0 r
F
.39466 .489 m .39195 .4859 L .39193 .48595 L .981 .604 0 r
F
.39154 .48819 m .39193 .48595 L .39148 .48817 L F
.39466 .489 m .39193 .48595 L .39154 .48819 L F
.38759 .48405 m .3702 .47669 L .3698 .47958 L 1 .858 0 r
F
.39194 .4859 m .37809 .47998 L .36942 .48247 L 1 .898 0 r
F
.39194 .48594 m .39194 .4859 L .37767 .48232 L 1 .904 0 r
F
.39219 .486 m .39194 .4859 L .39194 .48594 L F
.39154 .48819 m .39194 .48594 L .37767 .48232 L F
.39193 .48595 m .39195 .4859 L .39194 .4859 L .981 .604 0 r
F
.39219 .486 m .3922 .48596 L .39194 .4859 L 1 .904 0 r
F
.41141 .49243 m .41172 .48976 L .39409 .48643 L 1 .853 0 r
F
.39409 .48643 m .37818 .47966 L .37812 .47997 L 1 .911 0 r
F
.37849 .48013 m .37812 .47997 L .37809 .47998 L 1 .898 0 r
F
.39409 .48643 m .37812 .47997 L .39194 .4859 L 1 .911 0 r
F
.39502 .48636 m .37809 .47998 L .39194 .4859 L 1 .898 0 r
F
.39194 .4859 m .37812 .47997 L .37767 .48232 L 1 .911 0 r
F
.39502 .48636 m .37917 .47967 L .37812 .47997 L 1 .898 0 r
F
.39502 .48636 m .37812 .47997 L .37849 .48013 L F
.39466 .489 m .39502 .48636 L .39195 .4859 L .981 .604 0 r
F
.39153 .48819 m .36942 .48247 L .39143 .48854 L F
.39143 .48854 m .37767 .48232 L .37719 .48497 L 1 .904 0 r
F
.3937 .4891 m .39154 .48819 L .39143 .48854 L F
.39145 .48849 m .39153 .48819 L .39143 .48854 L .981 .604 0 r
F
.39154 .48819 m .39153 .48819 L .39144 .48854 L F
.39154 .48819 m .37767 .48232 L .39143 .48854 L 1 .904 0 r
F
.39144 .48854 m .39145 .48849 L .39143 .48854 L .981 .604 0 r
F
.39466 .489 m .39154 .48819 L .39144 .48854 L F
.39105 .49081 m .39169 .4886 L .39143 .48854 L 1 .896 0 r
F
.39332 .49177 m .39169 .4886 L .39105 .49081 L F
.41112 .49511 m .41141 .49243 L .3937 .4891 L 1 .846 0 r
F
.39432 .49162 m .39466 .489 L .39144 .48854 L .986 .603 0 r
F
.39105 .49081 m .39144 .48854 L .36908 .48535 L F
.39432 .49162 m .39144 .48854 L .39105 .49081 L F
.39104 .49081 m .36908 .48535 L .39094 .49117 L F
.39058 .49343 m .39119 .49123 L .39094 .49117 L 1 .889 0 r
F
.39297 .49443 m .39119 .49123 L .39058 .49343 L F
.41085 .49778 m .41112 .49511 L .39332 .49177 L 1 .838 0 r
F
.39401 .49425 m .39432 .49162 L .39094 .49117 L .99 .601 0 r
F
.3905 .49341 m .39094 .49117 L .36877 .48822 L F
.39056 .49342 m .36877 .48822 L .39047 .49381 L F
.39297 .49443 m .39058 .49343 L .39051 .49382 L 1 .889 0 r
F
.41059 .50045 m .41085 .49778 L .39297 .49443 L 1 .831 0 r
F
.39372 .49686 m .39401 .49425 L .39047 .49381 L .994 .599 0 r
F
.39005 .49602 m .39047 .49381 L .36849 .49107 L F
.39012 .49604 m .39047 .49381 L .39005 .49602 L F
.39009 .49603 m .39037 .49443 L .39047 .49381 L 1 .881 0 r
F
.39037 .49443 m .39048 .49381 L .39047 .49381 L F
.39012 .49604 m .39048 .49381 L .39009 .49603 L F
.39264 .49709 m .39066 .49407 L .39012 .49604 L F
.39066 .49407 m .39048 .49381 L .39012 .49604 L F
.39011 .49604 m .36849 .49107 L .39001 .49644 L .994 .599 0 r
F
.39001 .49644 m .37631 .49028 L .37591 .49293 L 1 .881 0 r
F
.39264 .49709 m .39012 .49604 L .39001 .49644 L F
.39003 .49639 m .39011 .49604 L .39001 .49644 L .994 .599 0 r
F
.39012 .49604 m .39011 .49604 L .39001 .49644 L F
.39012 .49604 m .37631 .49028 L .39001 .49644 L 1 .881 0 r
F
.39001 .49644 m .39003 .49639 L .39001 .49644 L .994 .599 0 r
F
.39372 .49686 m .39012 .49604 L .39001 .49644 L F
.39372 .49686 m .39047 .49381 L .39012 .49604 L F
.39047 .49381 m .37673 .48762 L .37631 .49028 L 1 .889 0 r
F
.39051 .49382 m .39047 .4938 L .39047 .49381 L F
.39047 .4938 m .37673 .48762 L .39047 .49381 L F
.39058 .49343 m .39094 .49117 L .3905 .49341 L .99 .601 0 r
F
.39058 .49343 m .39047 .4938 L .39051 .49382 L 1 .889 0 r
F
.39047 .49381 m .39048 .49376 L .39047 .49381 L .99 .601 0 r
F
.39048 .49376 m .39056 .49342 L .39047 .49381 L F
.39058 .49343 m .39056 .49342 L .39047 .49381 L F
.39058 .49343 m .37673 .48762 L .39047 .4938 L 1 .889 0 r
F
.39401 .49425 m .39095 .49118 L .39058 .49343 L .99 .601 0 r
F
.39095 .49118 m .39094 .49117 L .39058 .49343 L F
.39094 .49117 m .37719 .48497 L .37673 .48762 L 1 .896 0 r
F
.39098 .49118 m .39094 .49117 L .39094 .49117 L F
.39094 .49117 m .37719 .48497 L .39094 .49117 L F
.39332 .49177 m .39105 .49081 L .39098 .49118 L F
.39105 .49081 m .39095 .49117 L .39098 .49118 L F
.39094 .49117 m .39096 .49113 L .39094 .49117 L .986 .603 0 r
F
.39096 .49113 m .39104 .49081 L .39094 .49117 L F
.39105 .49081 m .39104 .49081 L .39094 .49117 L F
.39105 .49081 m .37719 .48497 L .39095 .49117 L 1 .896 0 r
F
.39085 .49073 m .39143 .48854 L .37719 .48497 L F
.39105 .49081 m .39143 .48854 L .39085 .49073 L F
.39432 .49162 m .39105 .49081 L .39094 .49117 L .986 .603 0 r
F
.39038 .49335 m .39094 .49117 L .37673 .48762 L 1 .889 0 r
F
.39058 .49343 m .39094 .49117 L .39038 .49335 L F
.39401 .49425 m .39058 .49343 L .39047 .49381 L .99 .601 0 r
F
.38993 .49596 m .39047 .49381 L .37631 .49028 L 1 .881 0 r
F
.39009 .49603 m .39047 .49381 L .38993 .49596 L F
.39345 .49948 m .39372 .49686 L .39001 .49644 L .998 .597 0 r
F
.39001 .49644 m .39001 .49644 L .39001 .49644 L F
.39345 .49948 m .39001 .49644 L .39001 .49644 L F
.38969 .49865 m .39001 .49644 L .36824 .49392 L F
.39233 .49975 m .39001 .49644 L .38969 .49865 L 1 .874 0 r
F
.39345 .49948 m .39001 .49644 L .38969 .49865 L .998 .597 0 r
F
.38969 .49865 m .39001 .49644 L .3895 .49857 L 1 .874 0 r
F
.38958 .49906 m .37591 .49293 L .37553 .49557 L F
.39233 .49975 m .38969 .49865 L .38958 .49906 L F
.38969 .49865 m .38967 .49864 L .38959 .49902 L .998 .597 0 r
F
.38967 .49864 m .38958 .49906 L .38958 .49906 L F
.38969 .49865 m .37591 .49293 L .38958 .49906 L 1 .874 0 r
F
.38969 .49865 m .38959 .49902 L .38958 .49906 L .998 .597 0 r
F
.38949 .49944 m .38946 .49903 L .37553 .49557 L 1 .866 0 r
F
.39228 .50021 m .38957 .49908 L .38949 .49944 L F
.38957 .49908 m .38946 .49903 L .38949 .49944 L F
.38909 .50117 m .38949 .49944 L .37553 .49557 L F
.39205 .5024 m .38949 .49944 L .38909 .50117 L F
.39345 .49948 m .38969 .49865 L .38958 .49906 L .998 .597 0 r
F
.3895 .49857 m .39001 .49644 L .37591 .49293 L 1 .874 0 r
F
.39228 .50021 m .39345 .49948 L .38958 .49906 L .613 .847 0 r
F
.39228 .50021 m .38958 .49906 L .38946 .49903 L 1 .866 0 r
F
.40668 .50517 m .40669 .50513 L .39205 .5024 L 1 .808 0 r
F
.407 .50523 m .40669 .50513 L .40668 .50517 L F
.40641 .50723 m .40668 .50517 L .39205 .5024 L F
.40668 .5052 m .40669 .50513 L .40669 .50513 L .956 .539 0 r
F
.407 .50523 m .40702 .50519 L .40669 .50513 L 1 .808 0 r
F
.46824 .51606 m .46826 .51267 L .44287 .51122 L 1 .661 0 r
F
.44567 .51408 m .44573 .51108 L .42542 .50795 L 1 .796 0 r
F
.42903 .51094 m .42917 .50829 L .41014 .50577 L 1 .757 0 r
F
.41092 .50797 m .41109 .50538 L .40669 .50513 L .956 .539 0 r
F
.40639 .50723 m .38638 .50396 L .40626 .50774 L F
.40626 .50774 m .39205 .5024 L .39179 .50504 L 1 .808 0 r
F
.40993 .50842 m .40641 .50723 L .40626 .50774 L F
.40628 .50768 m .40639 .50723 L .40626 .50774 L .956 .539 0 r
F
.40641 .50723 m .40639 .50723 L .40626 .50774 L F
.40641 .50723 m .39205 .5024 L .40626 .50774 L 1 .808 0 r
F
.40626 .50774 m .40628 .50768 L .40626 .50774 L .956 .539 0 r
F
.41092 .50797 m .40641 .50723 L .40626 .50774 L F
.40599 .5098 m .40657 .5078 L .40626 .50774 L 1 .8 0 r
F
.40975 .51106 m .40657 .5078 L .40599 .5098 L F
.46821 .51944 m .46824 .51606 L .44278 .51458 L 1 .652 0 r
F
.44562 .51706 m .44567 .51408 L .42544 .51074 L 1 .803 0 r
F
.4289 .51359 m .42903 .51094 L .40993 .50842 L 1 .749 0 r
F
.41078 .51055 m .41092 .50797 L .40627 .50774 L .96 .536 0 r
F
.40599 .5098 m .40627 .50774 L .3863 .50673 L F
.41078 .51055 m .40627 .50774 L .40599 .5098 L F
.40597 .5098 m .3863 .50673 L .40584 .51034 L F
.40975 .51106 m .40599 .5098 L .40592 .51035 L 1 .8 0 r
F
.40558 .51236 m .40614 .51039 L .40584 .51034 L 1 .792 0 r
F
.40958 .5137 m .40614 .51039 L .40558 .51236 L F
.46819 .52279 m .46821 .51944 L .44271 .51793 L 1 .643 0 r
F
.44555 .52004 m .44562 .51706 L .42548 .51348 L 1 .813 0 r
F
.42878 .51623 m .4289 .51359 L .40975 .51106 L 1 .741 0 r
F
.41066 .51312 m .41078 .51055 L .40584 .51034 L .965 .533 0 r
F
.40551 .51235 m .40584 .51034 L .38625 .50948 L F
.40556 .51236 m .38625 .50948 L .40542 .51293 L F
.40958 .5137 m .40558 .51236 L .4055 .51294 L 1 .792 0 r
F
.40558 .51236 m .40584 .51034 L .40551 .51235 L .965 .533 0 r
F
.40543 .51287 m .40556 .51236 L .40542 .51293 L F
.40558 .51236 m .40556 .51236 L .40542 .51293 L F
.40558 .51236 m .39155 .50769 L .40542 .51291 L 1 .792 0 r
F
.40558 .51236 m .40542 .51291 L .4055 .51294 L F
.40542 .51293 m .40543 .51287 L .40542 .51293 L .965 .533 0 r
F
.40943 .51633 m .40958 .5137 L .40542 .51293 L 1 .783 0 r
F
.46817 .52612 m .46819 .52279 L .44264 .52126 L 1 .634 0 r
F
.44548 .52304 m .44555 .52004 L .42555 .51619 L 1 .829 0 r
F
.42868 .51885 m .42878 .51623 L .40958 .5137 L 1 .733 0 r
F
.41056 .51568 m .41066 .51312 L .40542 .51293 L .969 .53 0 r
F
.4051 .5149 m .40542 .51293 L .38622 .51222 L F
.40542 .51293 m .40542 .51293 L .40542 .51293 L 1 .783 0 r
F
.40943 .51633 m .40542 .51293 L .40542 .51293 L F
.40517 .51491 m .40542 .51293 L .4051 .5149 L .969 .53 0 r
F
.40517 .51491 m .40541 .51293 L .4051 .51489 L 1 .783 0 r
F
.40943 .51633 m .40566 .51314 L .40517 .51491 L F
.40566 .51314 m .40541 .51293 L .40517 .51491 L F
.405 .51551 m .39133 .51032 L .39114 .51295 L F
.40943 .51633 m .40517 .51491 L .405 .51551 L F
.40502 .51545 m .40515 .51491 L .405 .51551 L .969 .53 0 r
F
.40517 .51491 m .40515 .51491 L .40501 .51551 L F
.40517 .51491 m .39133 .51032 L .405 .51551 L 1 .783 0 r
F
.40501 .51551 m .40502 .51545 L .405 .51551 L .969 .53 0 r
F
.41056 .51568 m .40517 .51491 L .40501 .51551 L F
.41056 .51568 m .40542 .51293 L .40517 .51491 L F
.40542 .51293 m .39155 .50769 L .39133 .51032 L 1 .792 0 r
F
.4055 .51294 m .40542 .51291 L .40542 .51293 L F
.40542 .51291 m .39155 .50769 L .40542 .51293 L F
.41066 .51312 m .40584 .51034 L .40558 .51236 L .965 .533 0 r
F
.40584 .51034 m .40584 .51034 L .40558 .51236 L F
.40584 .51034 m .39179 .50504 L .39155 .50769 L 1 .8 0 r
F
.40592 .51035 m .40584 .51032 L .40584 .51034 L F
.40584 .51032 m .39179 .50504 L .40584 .51034 L F
.40599 .5098 m .40584 .51032 L .40592 .51035 L F
.40584 .51034 m .40585 .51028 L .40584 .51034 L .96 .536 0 r
F
.40585 .51028 m .40597 .5098 L .40584 .51034 L F
.40599 .5098 m .40597 .5098 L .40584 .51034 L F
.40599 .5098 m .39179 .50504 L .40584 .51032 L 1 .8 0 r
F
.40574 .50972 m .40626 .50774 L .39179 .50504 L F
.40599 .5098 m .40626 .50774 L .40574 .50972 L F
.41078 .51055 m .40599 .5098 L .40584 .51034 L .96 .536 0 r
F
.40534 .51228 m .40584 .51034 L .39155 .50769 L 1 .792 0 r
F
.40558 .51236 m .40584 .51034 L .40534 .51228 L F
.41066 .51312 m .40558 .51236 L .40542 .51293 L .965 .533 0 r
F
.40542 .51293 m .40542 .51293 L .40541 .51293 L 1 .783 0 r
F
.4051 .51489 m .40541 .51293 L .39133 .51032 L F
.41047 .51822 m .41056 .51568 L .40501 .51551 L .972 .526 0 r
F
.40501 .51551 m .40501 .51551 L .405 .51551 L F
.41047 .51822 m .40501 .51551 L .40501 .51551 L F
.40476 .51745 m .40493 .51551 L .38621 .51494 L F
.40927 .51973 m .4046 .51808 L .38621 .51763 L .772 .944 0 r
F
.40446 .52069 m .39097 .51557 L .39082 .51818 L 1 .766 0 r
F
.40918 .52156 m .40452 .52002 L .40446 .52069 L F
.40452 .52002 m .39097 .51557 L .40446 .52069 L F
.40477 .51745 m .405 .51551 L .40493 .51551 L .972 .526 0 r
F
.40477 .51745 m .40493 .51551 L .40476 .51745 L F
.4093 .51895 m .405 .51551 L .40477 .51745 L 1 .775 0 r
F
.41047 .51822 m .405 .51551 L .40477 .51745 L .972 .526 0 r
F
.40477 .51745 m .405 .51551 L .40456 .51738 L 1 .775 0 r
F
.4046 .51808 m .39114 .51295 L .39097 .51557 L F
.4093 .51895 m .40477 .51745 L .4046 .51808 L F
.40477 .51745 m .40475 .51745 L .40462 .51801 L .972 .526 0 r
F
.40475 .51745 m .4046 .51808 L .4046 .51808 L F
.40477 .51745 m .39114 .51295 L .4046 .51808 L 1 .775 0 r
F
.40477 .51745 m .40462 .51801 L .4046 .51808 L .972 .526 0 r
F
.40918 .52156 m .40927 .51973 L .40447 .51864 L 1 .766 0 r
F
.40418 .51991 m .40447 .51864 L .39097 .51557 L F
.40918 .52156 m .40447 .51864 L .40418 .51991 L F
.40447 .51864 m .4046 .51808 L .39097 .51557 L F
.40927 .51973 m .4046 .51808 L .40447 .51864 L F
.41047 .51822 m .40477 .51745 L .4046 .51808 L .972 .526 0 r
F
.40456 .51738 m .405 .51551 L .39114 .51295 L 1 .775 0 r
F
.40927 .51973 m .41047 .51822 L .4046 .51808 L .772 .944 0 r
F
.4285 .52408 m .40927 .51973 L .42273 .52333 L 1 .716 0 r
F
.4293 .52327 m .40925 .51975 L .42273 .52333 L 1 .685 0 r
F
.42273 .52333 m .40927 .51973 L .40918 .52156 L 1 .716 0 r
F
.4293 .52327 m .41047 .51822 L .40927 .51973 L 1 .685 0 r
F
.4293 .52327 m .40927 .51973 L .40949 .51979 L F
.42929 .52575 m .4293 .52327 L .42273 .52333 L .943 .467 0 r
F
.42232 .52506 m .42271 .52343 L .40626 .52348 L F
.42271 .52343 m .42273 .52333 L .40626 .52348 L F
.42226 .52504 m .42264 .52379 L .40918 .52156 L 1 .707 0 r
F
.42264 .52379 m .42277 .52334 L .42273 .52333 L F
.42264 .52379 m .42273 .52333 L .40918 .52156 L F
.42271 .52343 m .42273 .52333 L .42273 .52333 L .943 .467 0 r
F
.42273 .52333 m .42273 .52333 L .40918 .52156 L 1 .707 0 r
F
.42277 .52334 m .42273 .52333 L .42273 .52333 L F
.42239 .52507 m .42271 .52343 L .42232 .52506 L .943 .467 0 r
F
.42239 .52507 m .42278 .52333 L .42226 .52504 L 1 .707 0 r
F
.42843 .52668 m .42311 .52353 L .42239 .52507 L F
.42311 .52353 m .42278 .52333 L .42239 .52507 L F
.42202 .52584 m .40626 .52348 L .4064 .52604 L .943 .467 0 r
F
.42202 .52584 m .40626 .52348 L .42202 .52584 L F
.42236 .52507 m .40626 .52348 L .42203 .52584 L F
.42202 .52584 m .40918 .52156 L .40909 .52415 L 1 .707 0 r
F
.42843 .52668 m .42239 .52507 L .42202 .52584 L F
.42239 .52507 m .42236 .52507 L .42212 .52564 L .943 .467 0 r
F
.42239 .52507 m .40918 .52156 L .42202 .52584 L 1 .707 0 r
F
.42239 .52507 m .42212 .52564 L .42208 .52572 L .943 .467 0 r
F
.42929 .52575 m .42239 .52507 L .42203 .52584 L F
.42239 .52507 m .42208 .52572 L .42203 .52584 L F
.42929 .52575 m .42273 .52333 L .42271 .52343 L F
.42929 .52575 m .42271 .52343 L .42239 .52507 L F
.42932 .52819 m .42929 .52575 L .42202 .52584 L .946 .45 0 r
F
.42202 .52584 m .42202 .52584 L .42202 .52584 L F
.42932 .52819 m .42202 .52584 L .42202 .52584 L F
.4216 .52747 m .42202 .52584 L .4064 .52604 L F
.42932 .52819 m .42202 .52584 L .4216 .52747 L F
.4216 .52747 m .4216 .52747 L .42202 .52584 L 1 .699 0 r
F
.42135 .5274 m .42202 .52584 L .40909 .52415 L F
.4216 .52747 m .42202 .52584 L .42135 .5274 L F
.42203 .52584 m .42202 .52584 L .42202 .52584 L .943 .467 0 r
F
.4216 .52747 m .42135 .5274 L .42121 .52833 L 1 .699 0 r
F
.42135 .5274 m .40909 .52415 L .42098 .52825 L F
.42135 .5274 m .42098 .52825 L .42121 .52833 L F
.42121 .52833 m .40909 .52415 L .40901 .52674 L F
.42837 .52926 m .4216 .52747 L .42121 .52833 L F
.42121 .52833 m .42121 .52833 L .42121 .52833 L .946 .45 0 r
F
.42932 .52819 m .4216 .52747 L .42121 .52833 L F
.42939 .53057 m .42932 .52819 L .42121 .52833 L .942 .409 0 r
F
.42121 .52833 m .42121 .52833 L .42121 .52833 L F
.42939 .53057 m .42121 .52833 L .42121 .52833 L F
.42061 .5298 m .42121 .52833 L .40653 .52857 L F
.42833 .53183 m .42121 .52833 L .42121 .52833 L 1 .69 0 r
F
.42833 .53183 m .4212 .52833 L .42061 .5298 L F
.42939 .53057 m .42121 .52833 L .42061 .5298 L .942 .409 0 r
F
.42121 .52833 m .42121 .52833 L .4212 .52833 L 1 .69 0 r
F
.42061 .5298 m .4212 .52833 L .40901 .52674 L F
.42021 .53078 m .40653 .52857 L .42021 .53078 L .942 .409 0 r
F
.42058 .5298 m .40653 .52857 L .42022 .53078 L F
.42021 .53078 m .40901 .52674 L .40895 .52932 L 1 .69 0 r
F
.42833 .53183 m .42061 .5298 L .42021 .53078 L F
.42061 .5298 m .42058 .5298 L .42028 .53061 L .942 .409 0 r
F
.42061 .5298 m .40901 .52674 L .42021 .53078 L 1 .69 0 r
F
.42061 .5298 m .42028 .53061 L .42024 .53073 L .942 .409 0 r
F
.42939 .53057 m .42061 .5298 L .42022 .53078 L F
.42061 .5298 m .42024 .53073 L .42022 .53078 L F
.43069 .53141 m .42939 .53057 L .42022 .53078 L .307 0 0 r
F
.42653 .53393 m .42005 .53122 L .41972 .53214 L 1 .681 0 r
F
.43069 .53141 m .42022 .53078 L .4162 .53122 L .307 0 0 r
F
.4162 .53122 m .41583 .53278 L .41584 .53278 L F
.41933 .5332 m .41603 .53197 L .418 .53306 L 1 .681 0 r
F
.41603 .53197 m .40895 .52932 L .41597 .53222 L F
.41603 .53197 m .41597 .53222 L .418 .53306 L F
.41583 .53278 m .40895 .52932 L .4089 .53188 L F
.41597 .53222 m .40895 .52932 L .41583 .53278 L F
.41584 .53278 m .41583 .53278 L .41583 .53278 L .307 0 0 r
F
.42653 .53393 m .40786 .54481 L .42651 .53416 L 0 0 0 r
F
.42653 .53393 m .4268 .53372 L .42639 .53401 L F
.43053 .5316 m .42691 .53366 L .42653 .53393 L F
.42691 .53366 m .4268 .53372 L .42653 .53393 L F
.42648 .53397 m .41972 .53214 L .41933 .5332 L 1 .681 0 r
F
.42653 .53398 m .42648 .53397 L .42648 .53397 L F
.42648 .53397 m .41972 .53214 L .42648 .53397 L F
.42684 .53401 m .42653 .53393 L .42653 .53398 L F
.42653 .53393 m .41972 .53214 L .42653 .53398 L F
.42653 .53393 m .42653 .53393 L .42651 .53416 L 0 0 0 r
F
.42684 .53401 m .42684 .53408 L .42675 .53407 L .526 .778 0 r
F
.42684 .53401 m .40878 .54509 L .42684 .5342 L F
.42692 .53402 m .42684 .53408 L .42684 .53401 L F
.42829 .53439 m .42684 .53401 L .418 .53306 L 1 .681 0 r
F
.43053 .5316 m .42653 .53393 L .42651 .53416 L 0 0 0 r
F
.42832 .53263 m .42833 .53183 L .42574 .5315 L 1 .681 0 r
F
.43069 .53141 m .4162 .53122 L .41584 .53278 L .307 0 0 r
F
.4162 .53122 m .41635 .53058 L .40895 .52932 L 1 .681 0 r
F
.42022 .53078 m .42021 .53078 L .42021 .53078 L .942 .409 0 r
F
.4303 .53189 m .42692 .53402 L .42684 .53401 L .526 .778 0 r
F
.4303 .53189 m .42684 .53401 L .42684 .5342 L F
.42829 .5352 m .42651 .53416 L .40772 .54612 L .526 .676 0 r
F
.42651 .53416 m .40786 .54481 L .40774 .54611 L 0 0 0 r
F
.42173 .53447 m .42683 .53456 L .41867 .53331 L 1 .671 0 r
F
.42683 .53456 m .4272 .53457 L .42683 .53451 L F
.42683 .53456 m .42683 .53451 L .41867 .53331 L F
.42252 .54445 m .42829 .5352 L .40772 .54612 L .526 .676 0 r
F
.4272 .53457 m .42829 .53459 L .42693 .53441 L 1 .671 0 r
F
.42829 .5352 m .42829 .53459 L .42173 .53447 L F
.42829 .53439 m .4283 .53417 L .42684 .53401 L 1 .681 0 r
F
.42829 .53459 m .4303 .53189 L .42684 .5342 L .57 .814 0 r
F
.4265 .53419 m .427 .53425 L .42651 .53416 L 1 .671 0 r
F
.427 .53425 m .42684 .5342 L .42651 .53416 L F
.42829 .53459 m .42829 .53439 L .41867 .53331 L F
.42931 .53467 m .42829 .53459 L .42827 .53694 L 1 .62 0 r
F
.42829 .5352 m .43053 .5316 L .42651 .53416 L .526 .676 0 r
F
.4272 .53457 m .42693 .53441 L .41867 .53331 L 1 .671 0 r
F
.42417 .53521 m .40987 .54333 L .42361 .53563 L 0 0 0 r
F
.4109 .5361 m .41108 .53451 L .39455 .53119 L 1 .728 0 r
F
.42406 .53639 m .4068 .53361 L .40691 .53612 L .839 .916 0 r
F
.42406 .53639 m .4068 .53361 L .42406 .53639 L F
.41112 .5342 m .41116 .53386 L .41115 .53387 L .211 .02 0 r
F
.42428 .5359 m .4068 .53361 L .42406 .53639 L .839 .916 0 r
F
.41117 .53386 m .41117 .53386 L .41116 .53386 L .211 .02 0 r
F
.42827 .53694 m .42829 .5352 L .42478 .53481 L 1 .671 0 r
F
.42446 .5355 m .42478 .53481 L .42173 .53447 L F
.42827 .53694 m .42478 .53481 L .42446 .5355 L F
.44154 .53801 m .42931 .53467 L .42827 .53694 L 1 .62 0 r
F
.43345 .53547 m .43053 .5316 L .42829 .5352 L 1 1 0 r
F
.41867 .53331 m .4265 .53419 L .418 .53306 L 1 .671 0 r
F
.4265 .53419 m .42651 .53416 L .418 .53306 L F
.42225 .53515 m .41583 .53278 L .41234 .5331 L .839 .916 0 r
F
.41019 .53222 m .41601 .53284 L .4089 .53188 L 1 .671 0 r
F
.41601 .53284 m .418 .53306 L .41583 .53278 L F
.41601 .53284 m .41583 .53278 L .4089 .53188 L F
.42827 .53694 m .42271 .53484 L .42301 .53518 L F
.42827 .53694 m .41601 .53284 L .42428 .5359 L F
.42827 .53694 m .42428 .5359 L .42406 .53639 L F
.4325 .53774 m .43269 .5373 L .42827 .53694 L 1 .611 0 r
F
.43247 .53781 m .4325 .53774 L .42827 .53694 L F
.46807 .54819 m .44486 .53862 L .44463 .54204 L 1 .955 0 r
F
.44832 .54109 m .42827 .53694 L .42826 .53947 L 1 .611 0 r
F
.41082 .53703 m .41082 .53703 L .41081 .53704 L .201 .015 0 r
F
.41081 .53704 m .41077 .53706 L .41077 .53706 L .211 .02 0 r
F
.4108 .53707 m .41081 .53704 L .41072 .53703 L 1 .718 0 r
F
.41052 .53921 m .41072 .53703 L .39443 .5344 L F
.42635 .53922 m .40691 .53612 L .40702 .53863 L 1 .687 0 r
F
.42645 .539 m .40691 .53612 L .42636 .53922 L F
.4263 .53897 m .42412 .53646 L .40691 .53612 L F
.42412 .53646 m .42406 .53639 L .40691 .53612 L F
.42635 .53922 m .40888 .53443 L .40887 .53697 L 1 .662 0 r
F
.42826 .53947 m .42645 .539 L .42635 .53922 L F
.42826 .53947 m .42827 .53694 L .4274 .53683 L F
.42674 .53835 m .4274 .53683 L .42406 .53639 L F
.42826 .53947 m .4274 .53683 L .42674 .53835 L F
.42826 .53947 m .42471 .53687 L .42645 .539 L F
.42471 .53687 m .42406 .53639 L .42539 .53784 L F
.42471 .53687 m .42539 .53784 L .42645 .539 L F
.42825 .54201 m .42826 .54193 L .40702 .53863 L 1 .658 0 r
F
.4305 .54207 m .42826 .53947 L .42827 .54172 L 1 .601 0 r
F
.43172 .54226 m .42827 .54172 L .42825 .54201 L 1 .645 0 r
F
.46795 .55194 m .46795 .55194 L .46795 .55194 L 1 .559 0 r
F
.46795 .55194 m .46804 .54881 L .46795 .55194 L F
.46795 .55194 m .46807 .54819 L .44463 .54204 L 1 .964 0 r
F
.46794 .55195 m .44463 .54204 L .44434 .54563 L F
.46802 .55197 m .46795 .55194 L .46794 .55195 L F
.46795 .55195 m .46795 .55194 L .46794 .55195 L 1 .559 0 r
F
.46795 .55194 m .44463 .54204 L .46794 .55195 L 1 .964 0 r
F
.46794 .55195 m .46795 .55195 L .46794 .55195 L 1 .559 0 r
F
.44831 .5436 m .43148 .54013 L .43069 .54193 L 1 .601 0 r
F
.43172 .54226 m .43069 .54193 L .43059 .54217 L F
.44831 .5436 m .43069 .54193 L .43172 .54226 L F
.43528 .54343 m .43172 .54226 L .42825 .54201 L 1 .631 0 r
F
.46486 .55452 m .46794 .55195 L .44434 .54563 L 1 .97 0 r
F
.4483 .54864 m .44831 .54691 L .42815 .54468 L 1 .618 0 r
F
.44831 .54691 m .44832 .54674 L .44623 .54595 L F
.44831 .54691 m .44615 .54592 L .42815 .54468 L F
.46802 .55188 m .46804 .54881 L .46795 .55194 L 1 .559 0 r
F
.46802 .55187 m .46807 .54819 L .46795 .55194 L 1 .964 0 r
F
.46868 .54953 m .45037 .54642 L .4483 .54864 L 1 .565 0 r
F
.45037 .54642 m .44831 .54691 L .4483 .54864 L F
.46807 .54819 m .46811 .54451 L .44486 .53862 L 1 .955 0 r
F
.46868 .54953 m .46869 .54699 L .45068 .54617 L 1 .565 0 r
F
.45021 .54639 m .45068 .54617 L .44831 .54609 L 1 .528 0 r
F
.45021 .54639 m .45068 .54617 L .44832 .54607 L 1 .565 0 r
F
.46868 .54953 m .45068 .54617 L .45021 .54639 L F
.46869 .54699 m .46871 .54444 L .45929 .544 L 1 .576 0 r
F
.45697 .54497 m .45929 .544 L .45772 .54393 L F
.45617 .54483 m .45772 .54393 L .44831 .5436 L 1 .538 0 r
F
.45759 .544 m .45772 .54393 L .45764 .54392 L 1 .576 0 r
F
.45697 .54497 m .45772 .54393 L .45759 .544 L F
.46869 .54699 m .45929 .544 L .45697 .54497 L F
.46871 .54444 m .46872 .54189 L .46389 .54165 L 1 .586 0 r
F
.46258 .54159 m .44833 .53856 L .44832 .54109 L 1 .557 0 r
F
.46607 .53918 m .44834 .53602 L .44833 .53856 L 1 .566 0 r
F
.46625 .53888 m .44834 .53602 L .46607 .53918 L F
.4687 .53674 m .44837 .53346 L .44834 .53602 L 1 .576 0 r
F
.46876 .53674 m .46871 .53673 L .4687 .53674 L 1 .614 0 r
F
.46876 .53674 m .46871 .53673 L .4687 .53674 L 1 .576 0 r
F
.46871 .53673 m .44837 .53346 L .4687 .53674 L F
.46877 .53419 m .4484 .53089 L .44837 .53346 L 1 .585 0 r
F
.46871 .53673 m .46877 .53419 L .44837 .53346 L 1 .576 0 r
F
.46877 .53419 m .46879 .53162 L .4484 .53089 L 1 .585 0 r
F
.46871 .53673 m .46877 .53415 L .44852 .53312 L 1 .614 0 r
F
.46876 .53674 m .46876 .53668 L .46871 .53673 L F
.46876 .53668 m .46877 .53419 L .46871 .53673 L 1 .576 0 r
F
.46876 .53668 m .46877 .53415 L .46871 .53673 L 1 .614 0 r
F
.46876 .5367 m .46876 .53668 L .46871 .53673 L 1 .576 0 r
F
.46876 .53674 m .46876 .5367 L .46871 .53673 L F
.4687 .53674 m .44852 .53312 L .44847 .53571 L 1 .614 0 r
F
.46871 .53673 m .44852 .53312 L .4687 .53674 L F
.46874 .53932 m .46876 .53674 L .4687 .53674 L 1 .605 0 r
F
.46656 .53893 m .4687 .53674 L .44834 .53602 L 1 .566 0 r
F
.46656 .53893 m .4687 .53674 L .44847 .53571 L 1 .605 0 r
F
.46874 .53932 m .4687 .53674 L .46656 .53893 L F
.46656 .53893 m .46876 .53674 L .4687 .53674 L 1 .566 0 r
F
.46874 .53928 m .46875 .53783 L .46656 .53893 L F
.46875 .53783 m .46876 .53674 L .46656 .53893 L F
.46605 .53918 m .44847 .53571 L .44843 .53831 L 1 .605 0 r
F
.46607 .53918 m .46605 .53918 L .46605 .53918 L F
.46605 .53918 m .44847 .53571 L .46605 .53918 L F
.46874 .53932 m .46656 .53893 L .46607 .53918 L F
.46656 .53893 m .46625 .53888 L .46607 .53918 L 1 .566 0 r
F
.46656 .53893 m .44847 .53571 L .46607 .53918 L 1 .605 0 r
F
.46874 .53928 m .46656 .53893 L .46607 .53918 L 1 .566 0 r
F
.46872 .54189 m .46874 .53932 L .46607 .53918 L 1 .596 0 r
F
.46873 .5418 m .46874 .53928 L .46607 .53918 L 1 .557 0 r
F
.46393 .54104 m .46607 .53918 L .44833 .53856 L F
.46603 .53925 m .46607 .53918 L .46601 .53924 L 1 .596 0 r
F
.46872 .54189 m .46607 .53918 L .46603 .53925 L F
.46418 .54108 m .46595 .53918 L .46393 .54104 L F
.46872 .54189 m .46648 .53969 L .46418 .54108 L F
.46648 .53969 m .46595 .53918 L .46418 .54108 L F
.46165 .5428 m .46389 .54165 L .46258 .54159 L 1 .586 0 r
F
.46871 .54444 m .46389 .54165 L .46104 .54311 L F
.4631 .54091 m .44833 .53856 L .46258 .54159 L 1 .557 0 r
F
.46258 .54159 m .44843 .53831 L .44839 .5409 L 1 .596 0 r
F
.46872 .54189 m .46418 .54108 L .46258 .54159 L F
.46331 .54161 m .46322 .54133 L .46258 .54159 L 1 .557 0 r
F
.46322 .54133 m .4631 .54091 L .46258 .54159 L F
.46418 .54108 m .46393 .54104 L .46258 .54159 L 1 .596 0 r
F
.46393 .54104 m .4631 .54091 L .46331 .54161 L 1 .557 0 r
F
.46393 .54104 m .44843 .53831 L .46258 .54159 L 1 .596 0 r
F
.45886 .54275 m .46258 .54159 L .44832 .54109 L 1 .547 0 r
F
.46104 .54311 m .46165 .5428 L .46102 .54271 L 1 .586 0 r
F
.46058 .54303 m .46258 .54159 L .45886 .54275 L 1 .547 0 r
F
.46058 .54303 m .46102 .54271 L .44839 .5409 L 1 .586 0 r
F
.46104 .54311 m .46102 .54271 L .46058 .54303 L F
.46165 .5428 m .46258 .54159 L .44839 .5409 L F
.4609 .54308 m .46258 .54159 L .46058 .54303 L 1 .547 0 r
F
.4609 .54308 m .46331 .54161 L .46258 .54159 L F
.46871 .54431 m .46873 .5418 L .46331 .54161 L F
.46871 .54431 m .46331 .54161 L .4609 .54308 L F
.46873 .5418 m .46607 .53918 L .46393 .54104 L 1 .557 0 r
F
.46601 .53924 m .46607 .53918 L .46595 .53918 L 1 .596 0 r
F
.46393 .54104 m .46595 .53918 L .44843 .53831 L F
.46873 .5418 m .46393 .54104 L .46331 .54161 L 1 .557 0 r
F
.45772 .54393 m .44832 .54109 L .44831 .5436 L 1 .547 0 r
F
.46058 .54303 m .44832 .54109 L .45772 .54393 L F
.45772 .54393 m .44839 .5409 L .44835 .54349 L 1 .586 0 r
F
.46871 .54444 m .46058 .54303 L .45772 .54393 L F
.46058 .54303 m .44839 .5409 L .45772 .54393 L F
.46871 .54431 m .46058 .54303 L .45772 .54393 L 1 .547 0 r
F
.4687 .5468 m .46871 .54431 L .45933 .54398 L 1 .538 0 r
F
.45885 .54422 m .45933 .54398 L .45772 .54393 L F
.4687 .5468 m .45933 .54398 L .45885 .54422 L F
.45697 .54497 m .45764 .54392 L .45617 .54483 L 1 .576 0 r
F
.4687 .5468 m .45772 .54393 L .45617 .54483 L 1 .538 0 r
F
.45068 .54617 m .44831 .5436 L .44831 .54609 L F
.46869 .54699 m .45617 .54483 L .45068 .54617 L 1 .576 0 r
F
.45669 .54491 m .44831 .5436 L .4513 .5462 L 1 .538 0 r
F
.45068 .54617 m .44835 .54349 L .44832 .54607 L 1 .576 0 r
F
.45114 .54606 m .44831 .5436 L .45068 .54617 L 1 .538 0 r
F
.45617 .54483 m .44835 .54349 L .45068 .54617 L 1 .576 0 r
F
.4513 .5462 m .45114 .54606 L .45068 .54617 L 1 .538 0 r
F
.4687 .5468 m .45669 .54491 L .45563 .54516 L F
.45382 .54628 m .45563 .54516 L .4513 .5462 L F
.4687 .5468 m .45563 .54516 L .45382 .54628 L F
.45617 .54483 m .45764 .54392 L .44835 .54349 L 1 .576 0 r
F
.46869 .54927 m .4687 .5468 L .45382 .54628 L 1 .528 0 r
F
.45309 .54659 m .45382 .54628 L .45068 .54617 L F
.46869 .54927 m .45382 .54628 L .45309 .54659 L F
.46869 .54927 m .45068 .54617 L .45021 .54639 L F
.46869 .54927 m .45021 .54639 L .44832 .54857 L F
.45021 .54639 m .44831 .54609 L .44832 .54674 L F
.45037 .54642 m .45021 .54639 L .44831 .54691 L 1 .565 0 r
F
.45021 .54639 m .44832 .54674 L .44831 .54691 L F
.45021 .54639 m .44832 .54674 L .44832 .54857 L 1 .528 0 r
F
.45021 .54639 m .44832 .54607 L .44832 .54674 L 1 .565 0 r
F
.44831 .54609 m .44831 .5436 L .43953 .54289 L 1 .591 0 r
F
.44831 .54609 m .43953 .54289 L .44472 .54526 L F
.44831 .54609 m .43172 .54226 L .43494 .54313 L F
.44613 .54592 m .42825 .54201 L .42815 .54468 L 1 .631 0 r
F
.44599 .54588 m .42825 .54201 L .44613 .54592 L F
.43826 .54403 m .42825 .54201 L .44615 .54592 L F
.44613 .54592 m .42827 .54198 L .42828 .54448 L 1 .591 0 r
F
.44831 .54609 m .43826 .54403 L .44613 .54592 L F
.43826 .54403 m .42827 .54198 L .44613 .54592 L F
.44615 .54592 m .44599 .54588 L .44613 .54592 L 1 .631 0 r
F
.44832 .54607 m .43826 .54403 L .44615 .54592 L F
.43826 .54403 m .43172 .54226 L .43528 .54343 L F
.44831 .54609 m .43059 .54217 L .43058 .54219 L 1 .591 0 r
F
.43826 .54403 m .43058 .54219 L .43047 .54243 L F
.44831 .54609 m .43058 .54219 L .43826 .54403 L F
.44832 .54857 m .44832 .54674 L .42828 .54448 L 1 .581 0 r
F
.44832 .54674 m .44831 .54609 L .44613 .54592 L F
.44832 .54674 m .44613 .54592 L .42828 .54448 L F
.44623 .54595 m .44832 .54607 L .44615 .54592 L 1 .618 0 r
F
.44832 .54674 m .44832 .54607 L .44623 .54595 L F
.44472 .54526 m .43953 .54289 L .43172 .54226 L 1 .591 0 r
F
.43494 .54313 m .43172 .54226 L .43059 .54217 L F
.44832 .54607 m .43172 .54226 L .43826 .54403 L 1 .631 0 r
F
.44831 .5436 m .44832 .54109 L .43165 .53974 L 1 .601 0 r
F
.44831 .5436 m .43165 .53974 L .43148 .54013 L F
.44832 .54607 m .44835 .54349 L .43172 .54226 L 1 .631 0 r
F
.43148 .54013 m .42826 .53947 L .43059 .54217 L 1 .601 0 r
F
.43148 .54013 m .43165 .53974 L .42826 .53947 L F
.44835 .54349 m .4284 .53928 L .42827 .54172 L 1 .645 0 r
F
.44835 .54349 m .42827 .54172 L .43172 .54226 L F
.43059 .54217 m .4305 .54207 L .42827 .54172 L 1 .601 0 r
F
.42876 .54202 m .42827 .54172 L .42827 .54198 L F
.43059 .54217 m .42827 .54172 L .42876 .54202 L F
.42826 .54193 m .42827 .54172 L .42798 .54154 L 1 .658 0 r
F
.42826 .54193 m .42636 .53922 L .40702 .53863 L F
.42827 .54198 m .42827 .54172 L .40887 .53697 L 1 .652 0 r
F
.42827 .54172 m .42826 .53947 L .42635 .53922 L F
.42798 .54154 m .42801 .54138 L .42638 .53925 L 1 .658 0 r
F
.42827 .54172 m .4284 .53928 L .42798 .54154 L F
.42827 .54172 m .42635 .53922 L .40887 .53697 L 1 .652 0 r
F
.42638 .53925 m .4284 .53928 L .42636 .53922 L 1 .658 0 r
F
.42801 .54138 m .4284 .53928 L .42638 .53925 L F
.4284 .53928 m .42406 .53639 L .4263 .53897 L 1 .687 0 r
F
.42645 .539 m .40888 .53443 L .42635 .53922 L 1 .662 0 r
F
.4284 .53928 m .42645 .539 L .42636 .53922 L 1 .687 0 r
F
.42645 .539 m .42406 .53639 L .40888 .53443 L 1 .662 0 r
F
.42412 .53646 m .42406 .53639 L .42406 .53639 L 1 .687 0 r
F
.4284 .53928 m .42864 .53647 L .42406 .53639 L F
.42301 .53518 m .418 .53306 L .41601 .53284 L 1 .671 0 r
F
.42271 .53484 m .418 .53306 L .42301 .53518 L F
.42225 .53515 m .41234 .5331 L .42428 .5359 L .839 .916 0 r
F
.42428 .5359 m .41601 .53284 L .41019 .53222 L 1 .671 0 r
F
.42428 .5359 m .41234 .5331 L .42135 .53551 L .839 .916 0 r
F
.42864 .53647 m .42225 .53515 L .42428 .5359 L F
.42918 .53201 m .42833 .53183 L .42832 .53263 L 1 .629 0 r
F
.43053 .5316 m .42683 .5337 L .42682 .53371 L 0 0 0 r
F
.43029 .53174 m .42723 .53314 L .4303 .53171 L 1 1 0 r
F
.43053 .5316 m .42832 .53263 L .4283 .53264 L 0 0 0 r
F
.42858 .53274 m .42833 .53264 L .43029 .53174 L 1 1 0 r
F
.43053 .5316 m .4283 .53264 L .42691 .53365 L 0 0 0 r
F
.42918 .53201 m .42931 .53191 L .42833 .53183 L 1 .629 0 r
F
.43346 .53547 m .43372 .53483 L .43053 .5316 L 1 1 0 r
F
.42987 .53196 m .42988 .53151 L .42931 .53191 L 1 .638 0 r
F
.42864 .53647 m .43069 .53141 L .41583 .53278 L .839 .916 0 r
F
.42864 .53647 m .41583 .53278 L .42225 .53515 L F
.42135 .53551 m .41234 .5331 L .4068 .53361 L F
.42406 .53639 m .4089 .53188 L .40888 .53443 L 1 .671 0 r
F
.42428 .5359 m .4089 .53188 L .42406 .53639 L F
.42406 .53639 m .42406 .53639 L .42406 .53639 L .839 .916 0 r
F
.42864 .53647 m .42428 .5359 L .42406 .53639 L F
.43345 .53547 m .43194 .53539 L .43333 .53577 L 1 .62 0 r
F
.43345 .53547 m .43333 .53577 L .44154 .53801 L F
.43348 .5355 m .43371 .53485 L .43346 .53547 L 1 1 0 r
F
.43371 .53485 m .43372 .53483 L .43365 .535 L F
.43371 .53485 m .43365 .535 L .43346 .53547 L F
.40875 .54677 m .40875 .54629 L .40772 .54612 L 1 .688 0 r
F
.40972 .54853 m .40875 .54629 L .40876 .54825 L F
.40877 .54627 m .40875 .54628 L .40875 .54629 L .526 .778 0 r
F
.4128 .54813 m .41445 .54799 L .41043 .54679 L 1 .688 0 r
F
.42252 .54445 m .40772 .54612 L .4132 .54955 L .526 .676 0 r
F
.40876 .54825 m .40875 .54677 L .40772 .54612 L 1 .688 0 r
F
.41311 .55014 m .39419 .54395 L .39416 .5471 L F
.4132 .54955 m .41318 .54956 L .41315 .54991 L .526 .676 0 r
F
.41318 .54956 m .41311 .55014 L .41312 .55013 L F
.4132 .54955 m .39419 .54395 L .41311 .55014 L 1 .688 0 r
F
.4132 .54955 m .41315 .54991 L .41312 .55013 L .526 .676 0 r
F
.41282 .55258 m .40875 .54944 L .40846 .5513 L 1 .678 0 r
F
.41551 .55337 m .41304 .55018 L .41533 .55346 L .459 .393 0 r
F
.41762 .55399 m .41495 .55262 L .41551 .55337 L 1 .678 0 r
F
.41315 .55019 m .41304 .55018 L .41551 .55337 L .459 .393 0 r
F
.41762 .55399 m .4131 .5502 L .41467 .55247 L 1 .678 0 r
F
.44236 .55666 m .44235 .55355 L .41761 .55086 L 1 .611 0 r
F
.44236 .55666 m .41761 .55086 L .41762 .55399 L F
.41978 .55104 m .41315 .55019 L .41551 .55337 L .459 .393 0 r
F
.41551 .55337 m .41294 .55159 L .41282 .55258 L 1 .678 0 r
F
.41495 .55262 m .41294 .55159 L .41551 .55337 L F
.41294 .55159 m .40875 .54944 L .41282 .55258 L F
.40695 .5554 m .39414 .55024 L .39414 .55337 L 1 .667 0 r
F
.41764 .5571 m .40706 .55401 L .40695 .5554 L F
.40706 .55401 m .39414 .55024 L .40695 .5554 L F
.40772 .54612 m .40772 .54612 L .40772 .54612 L 0 0 0 r
F
.40772 .54612 m .40772 .54612 L .40772 .54612 L F
.40757 .54789 m .40772 .54612 L .39419 .54395 L 1 .688 0 r
F
.40876 .54825 m .40772 .54612 L .40757 .54789 L F
.40684 .55705 m .40695 .5554 L .39414 .55337 L 1 .657 0 r
F
.40885 .55763 m .40695 .5554 L .40684 .55705 L F
.41768 .56019 m .4088 .55569 L .40885 .55763 L F
.4088 .55452 m .40876 .55258 L .39414 .55024 L 1 .667 0 r
F
.41511 .55636 m .40876 .55258 L .4088 .55452 L F
.42723 .54998 m .41763 .54891 L .41761 .54893 L 0 0 0 r
F
.41978 .55104 m .42252 .54445 L .41312 .55013 L .459 .393 0 r
F
.41313 .55014 m .41312 .55013 L .41311 .55014 L F
.41978 .55104 m .41312 .55013 L .41313 .55014 L F
.41315 .55019 m .41311 .55014 L .41304 .55018 L F
.41325 .55032 m .41311 .55014 L .4131 .5502 L 1 .678 0 r
F
.41467 .55247 m .4131 .5502 L .41294 .55159 L F
.44238 .55976 m .44236 .55666 L .41762 .55399 L 1 .601 0 r
F
.44238 .55976 m .41762 .55399 L .41764 .55674 L F
.41772 .55676 m .41764 .55674 L .41763 .55676 L 1 .939 0 r
F
.42194 .55756 m .41764 .55674 L .41764 .5571 L 1 .601 0 r
F
.44238 .55976 m .41764 .55674 L .42194 .55756 L F
.4431 .55779 m .41978 .55104 L .41764 .55674 L 1 .939 0 r
F
.4431 .55779 m .41764 .55674 L .41772 .55676 L F
.41764 .55674 m .41978 .55104 L .41547 .55364 L .477 .382 0 r
F
.4158 .55412 m .41547 .55364 L .41546 .55364 L F
.41764 .55674 m .41547 .55364 L .4158 .55412 L F
.41764 .5571 m .41764 .55674 L .41546 .55364 L 1 .667 0 r
F
.41764 .5571 m .41546 .55364 L .41511 .55636 L F
.41546 .55364 m .39416 .5471 L .39414 .55024 L 1 .678 0 r
F
.41551 .55337 m .39416 .5471 L .41546 .55364 L F
.41547 .55364 m .41546 .55364 L .41546 .55364 L .459 .393 0 r
F
.41978 .55104 m .41551 .55337 L .41547 .55364 L F
.40772 .54612 m .40784 .54501 L .39419 .54395 L 1 .698 0 r
F
.40774 .54611 m .40772 .54612 L .40772 .54612 L 0 0 0 r
F
.43374 .53485 m .43374 .53485 L .43372 .53489 L 1 1 0 r
F
.44832 .54075 m .44154 .53801 L .43269 .5373 L 1 .611 0 r
F
.44832 .54075 m .43269 .5373 L .4325 .53774 L F
.43047 .54243 m .43059 .54217 L .42827 .54198 L 1 .591 0 r
F
.43377 .5349 m .43377 .53489 L .43374 .53485 L 1 1 0 r
F
.44832 .54109 m .44832 .54075 L .4325 .53774 L 1 .611 0 r
F
.44832 .54109 m .4325 .53774 L .43247 .53781 L F
.44832 .54075 m .44833 .53856 L .44154 .53801 L F
.44833 .53856 m .43719 .53624 L .44154 .53801 L 1 .62 0 r
F
.4337 .53487 m .43372 .53483 L .43372 .53483 L 1 1 0 r
F
.43719 .53624 m .43372 .53483 L .43345 .53547 L 1 .62 0 r
F
.44833 .53856 m .43372 .53483 L .43719 .53624 L F
.44834 .53602 m .44295 .53511 L .43372 .53483 L 1 .629 0 r
F
.44834 .53602 m .44443 .5352 L .44295 .53511 L F
.44834 .53602 m .43472 .53235 L .43442 .53311 L F
.32136 .58876 m .31791 .58788 L .32117 .59175 L 1 .701 0 r
F
.3151 .60252 m .31524 .59608 L .26772 .58842 L 1 .715 0 r
F
.31744 .60069 m .31765 .5943 L .2714 .58647 L 1 .739 0 r
F
.3151 .60252 m .26772 .58842 L .26748 .59494 L 1 .715 0 r
F
.31744 .60069 m .2714 .58647 L .27112 .5929 L 1 .739 0 r
F
.33559 .59203 m .29585 .58723 L .28436 .59134 L .827 .06 0 r
F
.29585 .58723 m .28383 .58578 L .28396 .58719 L F
.29585 .58723 m .28396 .58719 L .28436 .59134 L F
.35709 .57478 m .33358 .5881 L .33378 .58849 L 0 0 0 r
F
.35709 .57478 m .33378 .58849 L .33559 .59203 L F
.3746 .57341 m .33559 .59203 L .33766 .59574 L .526 .676 0 r
F
.37162 .57256 m .33559 .59203 L .3746 .57341 L F
.41312 .55013 m .41311 .55014 L .41311 .55014 L F
.41294 .55159 m .41311 .55014 L .40875 .54944 L 1 .678 0 r
F
.40846 .5513 m .40875 .54944 L .39416 .5471 L F
.41037 .54021 m .41031 .54024 L .41031 .54024 L .201 .015 0 r
F
.41003 .54227 m .41041 .54019 L .39433 .53759 L 1 .708 0 r
F
.41034 .54057 m .41042 .54018 L .41041 .54019 L .18 .006 0 r
F
.41041 .54019 m .39443 .5344 L .39433 .53759 L 1 .718 0 r
F
.41043 .54018 m .41043 .54001 L .41041 .54019 L .201 .015 0 r
F
.42252 .54445 m .4132 .54955 L .41312 .55013 L .526 .676 0 r
F
.4431 .55779 m .41763 .55676 L .42194 .55756 L 1 .939 0 r
F
.43778 .56169 m .43266 .55956 L .42014 .55737 L 1 .59 0 r
F
.43266 .55956 m .42991 .55842 L .42194 .55756 L F
.43266 .55956 m .42194 .55756 L .42014 .55737 L F
.42661 .55895 m .42014 .55737 L .42988 .55993 L F
.44735 .5627 m .44238 .55976 L .44566 .56302 L 1 .518 0 r
F
.45149 .56137 m .44238 .55976 L .44813 .56316 L F
.44256 .56238 m .4431 .55779 L .42194 .55756 L 1 .88 0 r
F
.44256 .56238 m .42194 .55756 L .42988 .55993 L F
.44241 .56362 m .44095 .56301 L .41504 .56409 L .956 .835 0 r
F
.44137 .56295 m .43981 .56255 L .44057 .56286 L 1 .579 0 r
F
.44095 .56301 m .43983 .56255 L .43981 .56255 L .956 .835 0 r
F
.44095 .56301 m .43981 .56255 L .41504 .56409 L F
.44057 .56286 m .43981 .56255 L .41768 .56019 L 1 .579 0 r
F
.43373 .56388 m .44093 .56301 L .41768 .56019 L F
.44093 .56301 m .44137 .56295 L .44057 .56286 L F
.44093 .56301 m .44057 .56286 L .41768 .56019 L F
.44137 .56295 m .4424 .56283 L .43981 .56255 L F
.43981 .56255 m .41764 .5571 L .41768 .56019 L 1 .59 0 r
F
.4424 .56283 m .42988 .55993 L .43981 .56255 L F
.43862 .56224 m .42895 .55975 L .43981 .56255 L 1 .88 0 r
F
.42988 .55993 m .42895 .55975 L .43983 .56255 L F
.42988 .55993 m .41764 .5571 L .43981 .56255 L 1 .59 0 r
F
.43983 .56255 m .43862 .56224 L .43981 .56255 L 1 .88 0 r
F
.44095 .56301 m .44256 .56238 L .43983 .56255 L .956 .835 0 r
F
.44241 .56362 m .44241 .56361 L .44095 .56301 L F
.44241 .56361 m .4424 .56283 L .43373 .56388 L 1 .579 0 r
F
.44241 .56361 m .44256 .56238 L .44095 .56301 L .956 .835 0 r
F
.42988 .55993 m .42014 .55737 L .41764 .5571 L 1 .59 0 r
F
.44256 .56238 m .42988 .55993 L .43983 .56255 L 1 .88 0 r
F
.44244 .56588 m .44241 .56361 L .43373 .56388 L 1 .579 0 r
F
.46796 .56732 m .44456 .56321 L .44244 .56588 L 1 .507 0 r
F
.44456 .56321 m .4424 .56283 L .44241 .56361 L F
.44458 .56322 m .44456 .56321 L .44241 .56362 L 1 .959 0 r
F
.44456 .56321 m .44241 .56361 L .44241 .56362 L F
.44456 .56321 m .44241 .56361 L .44244 .56588 L 1 .507 0 r
F
.44456 .56321 m .44256 .56238 L .44241 .56361 L 1 .959 0 r
F
.44813 .56316 m .44735 .5627 L .44566 .56302 L 1 .518 0 r
F
.46797 .5643 m .45149 .56137 L .44813 .56316 L F
.46797 .5643 m .45517 .5605 L .45149 .56137 L F
.45149 .56137 m .4431 .55779 L .44508 .56289 L 1 .967 0 r
F
.45149 .56137 m .44508 .56289 L .44512 .56298 L F
.44512 .56298 m .4431 .55779 L .44256 .56238 L F
.4471 .56365 m .44813 .56316 L .44512 .56298 L 1 .507 0 r
F
.4471 .56365 m .44512 .56298 L .44434 .56317 L F
.46796 .56732 m .46797 .5643 L .44813 .56316 L F
.46796 .56732 m .44813 .56316 L .4471 .56365 L F
.45497 .56049 m .4539 .56017 L .45346 .5604 L 1 .528 0 r
F
.46798 .56125 m .45688 .55926 L .45497 .56049 L F
.45774 .55942 m .45954 .55768 L .45688 .55926 L F
.46798 .56125 m .468 .55818 L .4602 .55772 L F
.46798 .56125 m .4602 .55772 L .45774 .55942 L F
.468 .55818 m .46415 .55488 L .46121 .55695 L 1 .539 0 r
F
.45685 .55925 m .45947 .55766 L .44358 .55348 L 1 .972 0 r
F
.46801 .55508 m .46794 .55195 L .46482 .5545 L 1 .549 0 r
F
.46793 .55196 m .46794 .55195 L .46794 .55195 L 1 .97 0 r
F
.46802 .55197 m .46802 .55188 L .46795 .55194 L 1 .964 0 r
F
.46802 .55195 m .46802 .55188 L .46795 .55194 L 1 .559 0 r
F
.46802 .55188 m .46802 .55187 L .46795 .55194 L 1 .964 0 r
F
.46802 .55195 m .46795 .55194 L .46794 .55195 L 1 .559 0 r
F
.46795 .55194 m .46795 .55194 L .46794 .55195 L F
.44358 .55348 m .44399 .54943 L .42827 .54579 L 1 1 0 r
F
.4282 .54689 m .42827 .54579 L .42252 .54445 L F
.44358 .55348 m .42827 .54579 L .4282 .54689 L F
.42769 .55185 m .42252 .54445 L .41978 .55104 L F
.44358 .55348 m .4282 .54689 L .42769 .55185 L F
.4282 .54689 m .42252 .54445 L .42769 .55185 L F
.40933 .54373 m .40992 .5433 L .40579 .54264 L 1 .698 0 r
F
.40786 .54481 m .4087 .54419 L .39425 .54078 L F
.41486 .62859 m .41499 .62213 L .36651 .61756 L 1 .685 0 r
F
.42341 .61364 m .40071 .61459 L .39907 .62205 L .84 .693 0 r
F
.4368 .60901 m .42355 .61105 L .42341 .61364 L F
.42355 .61105 m .40071 .61459 L .42341 .61364 L F
.41486 .62859 m .36651 .61756 L .3656 .62493 L 1 .685 0 r
F
.41474 .63503 m .41486 .62859 L .3656 .62493 L 1 .656 0 r
F
.42302 .62045 m .39907 .62205 L .39757 .62947 L .842 .683 0 r
F
.43602 .61584 m .42315 .618 L .42302 .62045 L F
.42315 .618 m .39907 .62205 L .42302 .62045 L F
.33559 .59203 m .33378 .58849 L .29585 .58723 L .827 .06 0 r
F
.33378 .58849 m .33358 .5881 L .29585 .58723 L F
.33113 .59814 m .31789 .60081 L .3177 .60711 L .526 .778 0 r
F
.33081 .59288 m .31789 .60081 L .33113 .59814 L F
.32095 .59513 m .32097 .5947 L .31765 .5943 L 1 .692 0 r
F
.32807 .58331 m .32918 .58278 L .32915 .58278 L .762 .062 0 r
F
.32717 .58375 m .32773 .58348 L .31821 .58144 L 1 .708 0 r
F
.31833 .58016 m .31827 .58015 L .31827 .58016 L 1 .419 0 r
F
.32915 .58278 m .31827 .58015 L .31821 .58144 L 1 .716 0 r
F
.31821 .58144 m .31827 .58015 L .27256 .56706 L 1 .764 0 r
F
.31827 .58015 m .2815 .5686 L .27256 .56706 L F
.5855 .36154 m .54588 .35987 L .54679 .36635 L .91 .715 0 r
F
.58688 .36801 m .5855 .36154 L .54679 .36635 L .91 .708 0 r
F
.5854 .36164 m .54588 .35988 L .54678 .36637 L .906 .711 0 r
F
.58677 .36812 m .5854 .36164 L .54678 .36637 L .906 .704 0 r
F
.63614 .40691 m .59429 .4073 L .59543 .41388 L .849 .608 0 r
F
.63762 .41348 m .63614 .40691 L .59543 .41388 L .848 .6 0 r
F
.61383 .59836 m .5648 .59646 L .56491 .60289 L .88 .45 0 r
F
.61383 .59836 m .61366 .5919 L .5648 .59646 L F
.6573 .53266 m .61047 .53302 L .61096 .53961 L .83 .465 0 r
F
.6573 .53266 m .65662 .52605 L .61047 .53302 L F
.56466 .62141 m .51498 .61765 L .51496 .62394 L .93 .471 0 r
F
.56466 .62141 m .56465 .61511 L .51498 .61765 L F
.63493 .4002 m .59326 .40064 L .59444 .40721 L .854 .62 0 r
F
.63648 .40676 m .63493 .4002 L .59444 .40721 L .853 .613 0 r
F
.65583 .52585 m .6095 .52627 L .61001 .53284 L .826 .464 0 r
F
.65583 .52585 m .65513 .51926 L .6095 .52627 L F
.63461 .40036 m .59312 .40074 L .59429 .4073 L .85 .615 0 r
F
.63614 .40691 m .63461 .40036 L .59429 .4073 L .849 .608 0 r
F
.65793 .53927 m .61096 .53961 L .61143 .54619 L .828 .457 0 r
F
.65793 .53927 m .6573 .53266 L .61096 .53961 L F
.51494 .6302 m .4648 .6244 L .46476 .63066 L .985 .518 0 r
F
.51494 .6302 m .51496 .62394 L .4648 .6244 L F
.65647 .53243 m .61001 .53284 L .61049 .53941 L .824 .456 0 r
F
.65647 .53243 m .65583 .52585 L .61001 .53284 L F
.63334 .39365 m .59205 .39409 L .59326 .40064 L .854 .628 0 r
F
.63493 .4002 m .63334 .39365 L .59326 .40064 L .854 .62 0 r
F
.56509 .6284 m .51509 .62438 L .51508 .6307 L .935 .476 0 r
F
.56509 .6284 m .56508 .62206 L .51509 .62438 L F
.61311 .59776 m .56447 .59604 L .56455 .60242 L .873 .438 0 r
F
.61311 .59776 m .61297 .59136 L .56447 .59604 L F
.5841 .35508 m .54495 .35341 L .54588 .35987 L .91 .721 0 r
F
.5855 .36154 m .5841 .35508 L .54588 .35987 L .91 .715 0 r
F
.584 .35519 m .54495 .35342 L .54588 .35988 L .906 .717 0 r
F
.5854 .36164 m .584 .35519 L .54588 .35988 L .906 .711 0 r
F
.63303 .39382 m .59192 .39418 L .59312 .40074 L .851 .622 0 r
F
.63461 .40036 m .63303 .39382 L .59312 .40074 L .85 .615 0 r
F
.61397 .60479 m .56491 .60289 L .56499 .6093 L .878 .441 0 r
F
.61397 .60479 m .61383 .59836 L .56491 .60289 L F
.65851 .54587 m .61143 .54619 L .61185 .55277 L .826 .448 0 r
F
.65851 .54587 m .65793 .53927 L .61143 .54619 L F
.65707 .539 m .61049 .53941 L .61092 .54596 L .822 .447 0 r
F
.65707 .539 m .65647 .53243 L .61049 .53941 L F
.6317 .38712 m .59081 .38754 L .59205 .39409 L .855 .635 0 r
F
.63334 .39365 m .6317 .38712 L .59205 .39409 L .854 .628 0 r
F
.56464 .62769 m .51496 .62394 L .51494 .6302 L .928 .462 0 r
F
.56464 .62769 m .56466 .62141 L .51496 .62394 L F
.63141 .38729 m .59068 .38764 L .59192 .39418 L .851 .63 0 r
F
.63303 .39382 m .63141 .38729 L .59192 .39418 L .851 .622 0 r
F
.65904 .55246 m .61185 .55277 L .61224 .55933 L .824 .439 0 r
F
.65904 .55246 m .65851 .54587 L .61185 .55277 L F
.61322 .60414 m .56455 .60242 L .56461 .60878 L .872 .429 0 r
F
.61322 .60414 m .61311 .59776 L .56455 .60242 L F
.5149 .63643 m .46476 .63066 L .46473 .63689 L .984 .509 0 r
F
.5149 .63643 m .51494 .6302 L .46476 .63066 L F
.65761 .54556 m .61092 .54596 L .61133 .5525 L .82 .438 0 r
F
.65761 .54556 m .65707 .539 L .61092 .54596 L F
.56508 .63471 m .51508 .6307 L .51506 .63701 L .933 .467 0 r
F
.56508 .63471 m .56509 .6284 L .51508 .6307 L F
.58266 .34865 m .544 .34697 L .54495 .35341 L .91 .728 0 r
F
.5841 .35508 m .58266 .34865 L .54495 .35341 L .91 .721 0 r
F
.58257 .34875 m .544 .34698 L .54495 .35342 L .907 .724 0 r
F
.584 .35519 m .58257 .34875 L .54495 .35342 L .906 .717 0 r
F
.63003 .38061 m .58953 .38102 L .59081 .38754 L .856 .642 0 r
F
.6317 .38712 m .63003 .38061 L .59081 .38754 L .855 .635 0 r
F
.61407 .61121 m .56499 .6093 L .56505 .61569 L .876 .432 0 r
F
.61407 .61121 m .61397 .60479 L .56499 .6093 L F
.62975 .38078 m .58941 .38112 L .59068 .38764 L .852 .637 0 r
F
.63141 .38729 m .62975 .38078 L .59068 .38764 L .851 .63 0 r
F
.65952 .55904 m .61224 .55933 L .6126 .56587 L .823 .431 0 r
F
.65952 .55904 m .65904 .55246 L .61224 .55933 L F
.65811 .55211 m .61133 .5525 L .61169 .55902 L .819 .429 0 r
F
.65811 .55211 m .65761 .54556 L .61133 .5525 L F
.5646 .63393 m .51494 .6302 L .5149 .63643 L .926 .453 0 r
F
.5646 .63393 m .56464 .62769 L .51494 .6302 L F
.6283 .37411 m .58822 .37451 L .58953 .38102 L .857 .649 0 r
F
.63003 .38061 m .6283 .37411 L .58953 .38102 L .856 .642 0 r
F
.61329 .61049 m .56461 .60878 L .56465 .61511 L .87 .42 0 r
F
.61329 .61049 m .61322 .60414 L .56461 .60878 L F
.62804 .37429 m .58811 .37461 L .58941 .38112 L .853 .645 0 r
F
.62975 .38078 m .62804 .37429 L .58941 .38112 L .852 .637 0 r
F
.58119 .34224 m .54303 .34055 L .544 .34697 L .91 .735 0 r
F
.58266 .34865 m .58119 .34224 L .544 .34697 L .91 .728 0 r
F
.58111 .34234 m .54303 .34056 L .544 .34698 L .907 .731 0 r
F
.58257 .34875 m .58111 .34234 L .544 .34698 L .907 .724 0 r
F
.56504 .641 m .51506 .63701 L .51503 .64329 L .931 .458 0 r
F
.56504 .641 m .56508 .63471 L .51506 .63701 L F
.61413 .6176 m .56505 .61569 L .56508 .62206 L .874 .423 0 r
F
.61413 .6176 m .61407 .61121 L .56505 .61569 L F
.51485 .64263 m .46473 .63689 L .46469 .64308 L .982 .5 0 r
F
.51485 .64263 m .5149 .63643 L .46473 .63689 L F
.65996 .5656 m .6126 .56587 L .61292 .5724 L .821 .422 0 r
F
.65996 .5656 m .65952 .55904 L .6126 .56587 L F
.65856 .55864 m .61169 .55902 L .61202 .56552 L .817 .42 0 r
F
.65856 .55864 m .65811 .55211 L .61169 .55902 L F
.62654 .36763 m .58688 .36801 L .58822 .37451 L .857 .657 0 r
F
.6283 .37411 m .62654 .36763 L .58822 .37451 L .857 .649 0 r
F
.62629 .36781 m .58677 .36812 L .58811 .37461 L .854 .652 0 r
F
.62804 .37429 m .62629 .36781 L .58811 .37461 L .853 .645 0 r
F
.56454 .64015 m .5149 .63643 L .51485 .64263 L .924 .444 0 r
F
.56454 .64015 m .5646 .63393 L .5149 .63643 L F
.66035 .57215 m .61292 .5724 L .6132 .57892 L .819 .413 0 r
F
.66035 .57215 m .65996 .5656 L .61292 .5724 L F
.61332 .61682 m .56465 .61511 L .56466 .62141 L .868 .411 0 r
F
.61332 .61682 m .61329 .61049 L .56465 .61511 L F
.65896 .56515 m .61202 .56552 L .61231 .57201 L .815 .411 0 r
F
.65896 .56515 m .65856 .55864 L .61202 .56552 L F
.57969 .33585 m .54204 .33415 L .54303 .34055 L .91 .741 0 r
F
.58119 .34224 m .57969 .33585 L .54303 .34055 L .91 .735 0 r
F
.57962 .33595 m .54204 .33416 L .54303 .34056 L .907 .737 0 r
F
.58111 .34234 m .57962 .33595 L .54303 .34056 L .907 .731 0 r
F
.62473 .36118 m .5855 .36154 L .58688 .36801 L .858 .664 0 r
F
.62654 .36763 m .62473 .36118 L .58688 .36801 L .857 .657 0 r
F
.61415 .62397 m .56508 .62206 L .56509 .6284 L .872 .414 0 r
F
.61415 .62397 m .61413 .6176 L .56508 .62206 L F
.56497 .64726 m .51503 .64329 L .51498 .64954 L .929 .449 0 r
F
.56497 .64726 m .56504 .641 L .51503 .64329 L F
.6245 .36136 m .5854 .36164 L .58677 .36812 L .854 .659 0 r
F
.62629 .36781 m .6245 .36136 L .58677 .36812 L .854 .652 0 r
F
.51479 .6488 m .46469 .64308 L .46466 .64925 L .981 .491 0 r
F
.51479 .6488 m .51485 .64263 L .46469 .64308 L F
.66068 .57868 m .6132 .57892 L .61345 .58542 L .817 .404 0 r
F
.66068 .57868 m .66035 .57215 L .6132 .57892 L F
.65931 .57165 m .61231 .57201 L .61257 .57848 L .813 .402 0 r
F
.65931 .57165 m .65896 .56515 L .61231 .57201 L F
.62288 .35474 m .5841 .35508 L .5855 .36154 L .858 .671 0 r
F
.62473 .36118 m .62288 .35474 L .5855 .36154 L .858 .664 0 r
F
.61331 .62312 m .56466 .62141 L .56464 .62769 L .866 .402 0 r
F
.61331 .62312 m .61332 .61682 L .56466 .62141 L F
.56445 .64633 m .51485 .64263 L .51479 .6488 L .922 .434 0 r
F
.56445 .64633 m .56454 .64015 L .51485 .64263 L F
.62266 .35493 m .584 .35519 L .5854 .36164 L .855 .667 0 r
F
.6245 .36136 m .62266 .35493 L .5854 .36164 L .854 .659 0 r
F
.4646 .65597 m .46464 .64972 L .41455 .64783 L 1 .56 0 r
F
.51493 .65576 m .46464 .64972 L .4646 .65597 L .987 .5 0 r
F
.51493 .65576 m .51498 .64954 L .46464 .64972 L F
.57816 .32949 m .54103 .32778 L .54204 .33415 L .91 .748 0 r
F
.57969 .33585 m .57816 .32949 L .54204 .33415 L .91 .741 0 r
F
.57809 .32959 m .54103 .32779 L .54204 .33416 L .907 .744 0 r
F
.57962 .33595 m .57809 .32959 L .54204 .33416 L .907 .737 0 r
F
.61414 .63031 m .56509 .6284 L .56508 .63471 L .87 .405 0 r
F
.61414 .63031 m .61415 .62397 L .56509 .6284 L F
.56489 .65349 m .51498 .64954 L .51493 .65576 L .927 .439 0 r
F
.56489 .65349 m .56497 .64726 L .51498 .64954 L F
.66097 .5852 m .61345 .58542 L .61366 .5919 L .815 .395 0 r
F
.66097 .5852 m .66068 .57868 L .61345 .58542 L F
.65961 .57813 m .61257 .57848 L .61278 .58493 L .811 .393 0 r
F
.65961 .57813 m .65931 .57165 L .61257 .57848 L F
.46463 .65538 m .46466 .64925 L .41461 .64768 L 1 .535 0 r
F
.51472 .65493 m .46466 .64925 L .46463 .65538 L .979 .482 0 r
F
.51472 .65493 m .51479 .6488 L .46466 .64925 L F
.62099 .34833 m .58266 .34865 L .5841 .35508 L .859 .678 0 r
F
.62288 .35474 m .62099 .34833 L .5841 .35508 L .858 .671 0 r
F
.62078 .34852 m .58257 .34875 L .584 .35519 L .856 .674 0 r
F
.62266 .35493 m .62078 .34852 L .584 .35519 L .855 .667 0 r
F
.61327 .6294 m .56464 .62769 L .5646 .63393 L .864 .392 0 r
F
.61327 .6294 m .61331 .62312 L .56464 .62769 L F
.56434 .65247 m .51479 .6488 L .51472 .65493 L .921 .425 0 r
F
.56434 .65247 m .56445 .64633 L .51479 .6488 L F
.5766 .32315 m .54 .32143 L .54103 .32778 L .91 .754 0 r
F
.57816 .32949 m .5766 .32315 L .54103 .32778 L .91 .748 0 r
F
.57653 .32325 m .53999 .32144 L .54103 .32779 L .907 .751 0 r
F
.57809 .32959 m .57653 .32325 L .54103 .32779 L .907 .744 0 r
F
.68743 .44379 m .64484 .44637 L .64608 .453 L .782 .505 0 r
F
.68892 .45042 m .64608 .453 L .64727 .45964 L .78 .497 0 r
F
.68892 .45042 m .68743 .44379 L .64608 .453 L F
.69035 .45706 m .64727 .45964 L .64841 .46628 L .778 .488 0 r
F
.69035 .45706 m .68892 .45042 L .64727 .45964 L F
.4646 .65597 m .41455 .64783 L .41449 .65418 L 1 .56 0 r
F
.46457 .66219 m .4646 .65597 L .41449 .65418 L 1 .549 0 r
F
.51486 .66195 m .4646 .65597 L .46457 .66219 L .984 .49 0 r
F
.51486 .66195 m .51493 .65576 L .4646 .65597 L F
.65986 .58458 m .61278 .58493 L .61297 .59136 L .809 .384 0 r
F
.65986 .58458 m .65961 .57813 L .61278 .58493 L F
.68588 .43716 m .64356 .43975 L .64484 .44637 L .783 .513 0 r
F
.68743 .44379 m .68588 .43716 L .64484 .44637 L .782 .505 0 r
F
.66121 .5917 m .61366 .5919 L .61383 .59836 L .813 .385 0 r
F
.66121 .5917 m .66097 .5852 L .61366 .5919 L F
.69173 .4637 m .64841 .46628 L .64951 .47292 L .776 .48 0 r
F
.69173 .4637 m .69035 .45706 L .64841 .46628 L F
.61409 .63663 m .56508 .63471 L .56504 .641 L .868 .395 0 r
F
.61409 .63663 m .61414 .63031 L .56508 .63471 L F
.68427 .43055 m .64223 .43313 L .64356 .43975 L .785 .521 0 r
F
.68588 .43716 m .68427 .43055 L .64356 .43975 L .783 .513 0 r
F
.69305 .47035 m .64951 .47292 L .65056 .47957 L .775 .471 0 r
F
.69305 .47035 m .69173 .4637 L .64951 .47292 L F
.68261 .42395 m .64086 .42652 L .64223 .43313 L .786 .53 0 r
F
.68427 .43055 m .68261 .42395 L .64223 .43313 L .785 .521 0 r
F
.69432 .47701 m .65056 .47957 L .65157 .48622 L .773 .463 0 r
F
.69432 .47701 m .69305 .47035 L .65056 .47957 L F
.61905 .34194 m .58119 .34224 L .58266 .34865 L .859 .685 0 r
F
.62099 .34833 m .61905 .34194 L .58266 .34865 L .859 .678 0 r
F
.56477 .65968 m .51493 .65576 L .51486 .66195 L .925 .429 0 r
F
.56477 .65968 m .56489 .65349 L .51493 .65576 L F
.68089 .41736 m .63945 .41992 L .64086 .42652 L .788 .538 0 r
F
.68261 .42395 m .68089 .41736 L .64086 .42652 L .786 .53 0 r
F
.61886 .34213 m .58111 .34234 L .58257 .34875 L .856 .681 0 r
F
.62078 .34852 m .61886 .34213 L .58257 .34875 L .856 .674 0 r
F
.69552 .48366 m .65157 .48622 L .65253 .49286 L .771 .454 0 r
F
.69552 .48366 m .69432 .47701 L .65157 .48622 L F
.68667 .44391 m .64438 .44646 L .64559 .45308 L .777 .498 0 r
F
.68813 .45053 m .64559 .45308 L .64676 .4597 L .775 .489 0 r
F
.68813 .45053 m .68667 .44391 L .64559 .45308 L F
.68515 .43731 m .64312 .43985 L .64438 .44646 L .779 .506 0 r
F
.68667 .44391 m .68515 .43731 L .64438 .44646 L .777 .498 0 r
F
.68953 .45715 m .64676 .4597 L .64788 .46632 L .774 .481 0 r
F
.68953 .45715 m .68813 .45053 L .64676 .4597 L F
.68358 .43071 m .64181 .43325 L .64312 .43985 L .781 .515 0 r
F
.68515 .43731 m .68358 .43071 L .64312 .43985 L .779 .506 0 r
F
.69087 .46377 m .64788 .46632 L .64895 .47295 L .772 .472 0 r
F
.69087 .46377 m .68953 .45715 L .64788 .46632 L F
.46463 .65538 m .41461 .64768 L .41461 .65382 L 1 .535 0 r
F
.4646 .66147 m .46463 .65538 L .41461 .65382 L 1 .525 0 r
F
.51464 .66103 m .46463 .65538 L .4646 .66147 L .977 .472 0 r
F
.51464 .66103 m .51472 .65493 L .46463 .65538 L F
.67912 .41078 m .63799 .41333 L .63945 .41992 L .789 .546 0 r
F
.68089 .41736 m .67912 .41078 L .63945 .41992 L .788 .538 0 r
F
.68195 .42412 m .64046 .42665 L .64181 .43325 L .782 .523 0 r
F
.68358 .43071 m .68195 .42412 L .64181 .43325 L .781 .515 0 r
F
.69216 .47039 m .64895 .47295 L .64997 .47957 L .77 .463 0 r
F
.69216 .47039 m .69087 .46377 L .64895 .47295 L F
.69667 .49032 m .65253 .49286 L .65344 .49951 L .769 .445 0 r
F
.69667 .49032 m .69552 .48366 L .65253 .49286 L F
.68026 .41755 m .63907 .42006 L .64046 .42665 L .784 .532 0 r
F
.68195 .42412 m .68026 .41755 L .64046 .42665 L .782 .523 0 r
F
.69338 .47702 m .64997 .47957 L .65095 .4862 L .768 .454 0 r
F
.69338 .47702 m .69216 .47039 L .64997 .47957 L F
.66006 .59102 m .61297 .59136 L .61311 .59776 L .806 .374 0 r
F
.66006 .59102 m .65986 .58458 L .61297 .59136 L F
.6614 .59817 m .61383 .59836 L .61397 .60479 L .81 .376 0 r
F
.6614 .59817 m .66121 .5917 L .61383 .59836 L F
.67729 .40422 m .63648 .40676 L .63799 .41333 L .791 .554 0 r
F
.67912 .41078 m .67729 .40422 L .63799 .41333 L .789 .546 0 r
F
.61319 .63564 m .5646 .63393 L .56454 .64015 L .861 .383 0 r
F
.61319 .63564 m .61327 .6294 L .5646 .63393 L F
.69776 .49698 m .65344 .49951 L .65431 .50615 L .767 .437 0 r
F
.69776 .49698 m .69667 .49032 L .65344 .49951 L F
.67851 .41098 m .63762 .41348 L .63907 .42006 L .785 .54 0 r
F
.68026 .41755 m .67851 .41098 L .63907 .42006 L .784 .532 0 r
F
.69455 .48365 m .65095 .4862 L .65189 .49282 L .766 .446 0 r
F
.69455 .48365 m .69338 .47702 L .65095 .4862 L F
.57501 .31684 m .53895 .31511 L .54 .32143 L .91 .761 0 r
F
.5766 .32315 m .57501 .31684 L .54 .32143 L .91 .754 0 r
F
.57495 .31694 m .53894 .31511 L .53999 .32144 L .907 .757 0 r
F
.57653 .32325 m .57495 .31694 L .53999 .32144 L .907 .751 0 r
F
.61401 .64291 m .56504 .641 L .56497 .64726 L .866 .385 0 r
F
.61401 .64291 m .61409 .63663 L .56504 .641 L F
.61708 .33558 m .57969 .33585 L .58119 .34224 L .86 .692 0 r
F
.61905 .34194 m .61708 .33558 L .58119 .34224 L .859 .685 0 r
F
.46457 .66219 m .41449 .65418 L .41446 .66049 L 1 .549 0 r
F
.46454 .66837 m .46457 .66219 L .41446 .66049 L 1 .538 0 r
F
.51478 .66811 m .46457 .66219 L .46454 .66837 L .982 .48 0 r
F
.51478 .66811 m .51486 .66195 L .46457 .66219 L F
.5642 .65859 m .51472 .65493 L .51464 .66103 L .918 .415 0 r
F
.5642 .65859 m .56434 .65247 L .51472 .65493 L F
.6754 .39767 m .63493 .4002 L .63648 .40676 L .792 .562 0 r
F
.67729 .40422 m .6754 .39767 L .63648 .40676 L .791 .554 0 r
F
.69879 .50364 m .65431 .50615 L .65513 .51279 L .765 .428 0 r
F
.69879 .50364 m .69776 .49698 L .65431 .50615 L F
.41455 .64783 m .36491 .63831 L .36475 .64479 L 1 .625 0 r
F
.41449 .65418 m .41455 .64783 L .36475 .64479 L 1 .612 0 r
F
.67671 .40443 m .63614 .40691 L .63762 .41348 L .787 .548 0 r
F
.67851 .41098 m .67671 .40443 L .63762 .41348 L .785 .54 0 r
F
.69566 .49028 m .65189 .49282 L .65277 .49944 L .764 .437 0 r
F
.69566 .49028 m .69455 .48365 L .65189 .49282 L F
.61689 .33577 m .57962 .33595 L .58111 .34234 L .857 .688 0 r
F
.61886 .34213 m .61689 .33577 L .58111 .34234 L .856 .681 0 r
F
.41461 .64768 m .36518 .6379 L .3652 .64411 L 1 .594 0 r
F
.41461 .65382 m .41461 .64768 L .3652 .64411 L 1 .585 0 r
F
.67347 .39114 m .63334 .39365 L .63493 .4002 L .793 .57 0 r
F
.6754 .39767 m .67347 .39114 L .63493 .4002 L .792 .562 0 r
F
.67486 .39789 m .63461 .40036 L .63614 .40691 L .788 .556 0 r
F
.67671 .40443 m .67486 .39789 L .63614 .40691 L .787 .548 0 r
F
.6967 .4969 m .65277 .49944 L .65361 .50605 L .762 .428 0 r
F
.6967 .4969 m .69566 .49028 L .65277 .49944 L F
.69976 .51029 m .65513 .51279 L .6559 .51942 L .763 .419 0 r
F
.69976 .51029 m .69879 .50364 L .65513 .51279 L F
.56464 .66585 m .51486 .66195 L .51478 .66811 L .923 .42 0 r
F
.56464 .66585 m .56477 .65968 L .51486 .66195 L F
.66021 .59744 m .61311 .59776 L .61322 .60414 L .804 .365 0 r
F
.66021 .59744 m .66006 .59102 L .61311 .59776 L F
.66154 .60463 m .61397 .60479 L .61407 .61121 L .808 .367 0 r
F
.66154 .60463 m .6614 .59817 L .61397 .60479 L F
.4646 .66147 m .41461 .65382 L .41463 .65993 L 1 .525 0 r
F
.46457 .66753 m .4646 .66147 L .41463 .65993 L 1 .516 0 r
F
.51455 .66709 m .4646 .66147 L .46457 .66753 L .975 .463 0 r
F
.51455 .66709 m .51464 .66103 L .4646 .66147 L F
.67295 .39137 m .63303 .39382 L .63461 .40036 L .79 .564 0 r
F
.67486 .39789 m .67295 .39137 L .63461 .40036 L .788 .556 0 r
F
.69769 .50352 m .65361 .50605 L .65439 .51266 L .76 .419 0 r
F
.69769 .50352 m .6967 .4969 L .65361 .50605 L F
.67147 .38463 m .6317 .38712 L .63334 .39365 L .795 .578 0 r
F
.67347 .39114 m .67147 .38463 L .63334 .39365 L .793 .57 0 r
F
.70067 .51694 m .6559 .51942 L .65662 .52605 L .761 .41 0 r
F
.70067 .51694 m .69976 .51029 L .6559 .51942 L F
.61307 .64185 m .56454 .64015 L .56445 .64633 L .859 .373 0 r
F
.61307 .64185 m .61319 .63564 L .56454 .64015 L F
.61506 .32925 m .57816 .32949 L .57969 .33585 L .86 .699 0 r
F
.61708 .33558 m .61506 .32925 L .57969 .33585 L .86 .692 0 r
F
.61489 .32943 m .57809 .32959 L .57962 .33595 L .857 .696 0 r
F
.61689 .33577 m .61489 .32943 L .57962 .33595 L .857 .688 0 r
F
.57339 .31055 m .53787 .30881 L .53895 .31511 L .91 .767 0 r
F
.57501 .31684 m .57339 .31055 L .53895 .31511 L .91 .761 0 r
F
.57333 .31065 m .53787 .30881 L .53894 .31511 L .907 .764 0 r
F
.57495 .31694 m .57333 .31065 L .53894 .31511 L .907 .757 0 r
F
.67098 .38487 m .63141 .38729 L .63303 .39382 L .791 .573 0 r
F
.67295 .39137 m .67098 .38487 L .63303 .39382 L .79 .564 0 r
F
.69862 .51014 m .65439 .51266 L .65513 .51926 L .758 .409 0 r
F
.69862 .51014 m .69769 .50352 L .65439 .51266 L F
.41449 .65418 m .36475 .64479 L .36466 .65119 L 1 .612 0 r
F
.41446 .66049 m .41449 .65418 L .36466 .65119 L 1 .599 0 r
F
.61388 .64917 m .56497 .64726 L .56489 .65349 L .863 .376 0 r
F
.61388 .64917 m .61401 .64291 L .56497 .64726 L F
.66943 .37814 m .63003 .38061 L .6317 .38712 L .796 .586 0 r
F
.67147 .38463 m .66943 .37814 L .6317 .38712 L .795 .578 0 r
F
.46454 .66837 m .41446 .66049 L .41444 .66675 L 1 .538 0 r
F
.46451 .67452 m .46454 .66837 L .41444 .66675 L 1 .527 0 r
F
.51469 .67423 m .46454 .66837 L .46451 .67452 L .98 .47 0 r
F
.51469 .67423 m .51478 .66811 L .46454 .66837 L F
.70152 .52359 m .65662 .52605 L .6573 .53266 L .759 .401 0 r
F
.70152 .52359 m .70067 .51694 L .65662 .52605 L F
.56404 .66466 m .51464 .66103 L .51455 .66709 L .916 .406 0 r
F
.56404 .66466 m .5642 .65859 L .51464 .66103 L F
.41461 .65382 m .3652 .64411 L .36524 .65028 L 1 .585 0 r
F
.41463 .65993 m .41461 .65382 L .36524 .65028 L 1 .575 0 r
F
.66031 .60383 m .61322 .60414 L .61329 .61049 L .802 .355 0 r
F
.66031 .60383 m .66021 .59744 L .61322 .60414 L F
.66896 .37838 m .62975 .38078 L .63141 .38729 L .793 .581 0 r
F
.67098 .38487 m .66896 .37838 L .63141 .38729 L .791 .573 0 r
F
.69949 .51675 m .65513 .51926 L .65583 .52585 L .756 .4 0 r
F
.69949 .51675 m .69862 .51014 L .65513 .51926 L F
.66163 .61106 m .61407 .61121 L .61413 .6176 L .806 .357 0 r
F
.66163 .61106 m .66154 .60463 L .61407 .61121 L F
.66733 .37167 m .6283 .37411 L .63003 .38061 L .797 .594 0 r
F
.66943 .37814 m .66733 .37167 L .63003 .38061 L .796 .586 0 r
F
.56447 .67198 m .51478 .66811 L .51469 .67423 L .92 .41 0 r
F
.56447 .67198 m .56464 .66585 L .51478 .66811 L F
.70231 .53023 m .6573 .53266 L .65793 .53927 L .757 .391 0 r
F
.70231 .53023 m .70152 .52359 L .6573 .53266 L F
.613 .32294 m .5766 .32315 L .57816 .32949 L .861 .706 0 r
F
.61506 .32925 m .613 .32294 L .57816 .32949 L .86 .699 0 r
F
.61284 .32312 m .57653 .32325 L .57809 .32959 L .858 .703 0 r
F
.61489 .32943 m .61284 .32312 L .57809 .32959 L .857 .696 0 r
F
.66688 .37191 m .62804 .37429 L .62975 .38078 L .794 .589 0 r
F
.66896 .37838 m .66688 .37191 L .62975 .38078 L .793 .581 0 r
F
.70029 .52336 m .65583 .52585 L .65647 .53243 L .753 .391 0 r
F
.70029 .52336 m .69949 .51675 L .65583 .52585 L F
.46457 .66753 m .41463 .65993 L .41467 .66601 L 1 .516 0 r
F
.46454 .67356 m .46457 .66753 L .41467 .66601 L 1 .507 0 r
F
.51444 .67311 m .46457 .66753 L .46454 .67356 L .973 .453 0 r
F
.51444 .67311 m .51455 .66709 L .46457 .66753 L F
.61291 .64802 m .56445 .64633 L .56434 .65247 L .857 .363 0 r
F
.61291 .64802 m .61307 .64185 L .56445 .64633 L F
.66517 .36522 m .62654 .36763 L .6283 .37411 L .799 .602 0 r
F
.66733 .37167 m .66517 .36522 L .6283 .37411 L .797 .594 0 r
F
.41446 .66049 m .36466 .65119 L .36463 .65753 L 1 .599 0 r
F
.41444 .66675 m .41446 .66049 L .36463 .65753 L 1 .587 0 r
F
.57173 .3043 m .53678 .30254 L .53787 .30881 L .909 .774 0 r
F
.57339 .31055 m .57173 .3043 L .53787 .30881 L .91 .767 0 r
F
.57168 .3044 m .53678 .30254 L .53787 .30881 L .906 .77 0 r
F
.57333 .31065 m .57168 .3044 L .53787 .30881 L .907 .764 0 r
F
.70304 .53686 m .65793 .53927 L .65851 .54587 L .755 .382 0 r
F
.70304 .53686 m .70231 .53023 L .65793 .53927 L F
.61372 .6554 m .56489 .65349 L .56477 .65968 L .861 .366 0 r
F
.61372 .6554 m .61388 .64917 L .56489 .65349 L F
.66036 .61019 m .61329 .61049 L .61332 .61682 L .799 .345 0 r
F
.66036 .61019 m .66031 .60383 L .61329 .61049 L F
.66475 .36547 m .62629 .36781 L .62804 .37429 L .795 .597 0 r
F
.66688 .37191 m .66475 .36547 L .62804 .37429 L .794 .589 0 r
F
.70104 .52995 m .65647 .53243 L .65707 .539 L .751 .381 0 r
F
.70104 .52995 m .70029 .52336 L .65647 .53243 L F
.46451 .67452 m .41444 .66675 L .41444 .67297 L 1 .527 0 r
F
.46448 .68064 m .46451 .67452 L .41444 .67297 L 1 .516 0 r
F
.51459 .68032 m .46451 .67452 L .46448 .68064 L .977 .459 0 r
F
.51459 .68032 m .51469 .67423 L .46451 .67452 L F
.66167 .61747 m .61413 .6176 L .61415 .62397 L .803 .347 0 r
F
.66167 .61747 m .66163 .61106 L .61413 .6176 L F
.36516 .63172 m .31489 .62166 L .31489 .628 L 1 .711 0 r
F
.36491 .63831 m .36516 .63172 L .31489 .628 L 1 .679 0 r
F
.56385 .6707 m .51455 .66709 L .51444 .67311 L .914 .396 0 r
F
.56385 .6707 m .56404 .66466 L .51455 .66709 L F
.3652 .63167 m .31703 .61974 L .31698 .62604 L 1 .659 0 r
F
.36518 .6379 m .3652 .63167 L .31698 .62604 L 1 .65 0 r
F
.41463 .65993 m .36524 .65028 L .3653 .65641 L 1 .575 0 r
F
.41467 .66601 m .41463 .65993 L .3653 .65641 L 1 .566 0 r
F
.66297 .35879 m .62473 .36118 L .62654 .36763 L .8 .61 0 r
F
.66517 .36522 m .66297 .35879 L .62654 .36763 L .799 .602 0 r
F
.70371 .54348 m .65851 .54587 L .65904 .55246 L .752 .373 0 r
F
.70371 .54348 m .70304 .53686 L .65851 .54587 L F
.6109 .31666 m .57501 .31684 L .5766 .32315 L .861 .713 0 r
F
.613 .32294 m .6109 .31666 L .5766 .32315 L .861 .706 0 r
F
.61075 .31684 m .57495 .31694 L .57653 .32325 L .858 .71 0 r
F
.61284 .32312 m .61075 .31684 L .57653 .32325 L .858 .703 0 r
F
.66256 .35905 m .6245 .36136 L .62629 .36781 L .796 .605 0 r
F
.66475 .36547 m .66256 .35905 L .62629 .36781 L .795 .597 0 r
F
.56429 .67807 m .51469 .67423 L .51459 .68032 L .918 .399 0 r
F
.56429 .67807 m .56447 .67198 L .51469 .67423 L F
.70173 .53654 m .65707 .539 L .65761 .54556 L .749 .372 0 r
F
.70173 .53654 m .70104 .52995 L .65707 .539 L F
.61272 .65417 m .56434 .65247 L .5642 .65859 L .854 .353 0 r
F
.61272 .65417 m .61291 .64802 L .56434 .65247 L F
.31821 .58144 m .27256 .56706 L .27212 .57355 L 1 .764 0 r
F
.36491 .63831 m .31489 .628 L .31491 .63432 L 1 .679 0 r
F
.36475 .64479 m .36491 .63831 L .31491 .63432 L 1 .659 0 r
F
.46454 .67356 m .41467 .66601 L .41472 .67204 L 1 .507 0 r
F
.46452 .67954 m .46454 .67356 L .41472 .67204 L 1 .497 0 r
F
.51432 .67909 m .46454 .67356 L .46452 .67954 L .971 .443 0 r
F
.51432 .67909 m .51444 .67311 L .46454 .67356 L F
.41444 .66675 m .36463 .65753 L .36464 .66382 L 1 .587 0 r
F
.41444 .67297 m .41444 .66675 L .36464 .66382 L 1 .576 0 r
F
.66071 .35239 m .62288 .35474 L .62473 .36118 L .801 .617 0 r
F
.66297 .35879 m .66071 .35239 L .62473 .36118 L .8 .61 0 r
F
.31499 .60892 m .3151 .60252 L .26748 .59494 L 1 .707 0 r
F
.70432 .55009 m .65904 .55246 L .65952 .55904 L .75 .363 0 r
F
.70432 .55009 m .70371 .54348 L .65904 .55246 L F
.66036 .61653 m .61332 .61682 L .61331 .62312 L .797 .335 0 r
F
.66036 .61653 m .66036 .61019 L .61332 .61682 L F
.57005 .29807 m .53567 .2963 L .53678 .30254 L .909 .78 0 r
F
.57173 .3043 m .57005 .29807 L .53678 .30254 L .909 .774 0 r
F
.57 .29817 m .53567 .29631 L .53678 .30254 L .906 .777 0 r
F
.57168 .3044 m .57 .29817 L .53678 .30254 L .906 .77 0 r
F
.66166 .62385 m .61415 .62397 L .61414 .63031 L .801 .337 0 r
F
.66166 .62385 m .66167 .61747 L .61415 .62397 L F
.61352 .66159 m .56477 .65968 L .56464 .66585 L .858 .356 0 r
F
.61352 .66159 m .61372 .6554 L .56477 .65968 L F
.66032 .35265 m .62266 .35493 L .6245 .36136 L .798 .613 0 r
F
.66256 .35905 m .66032 .35265 L .6245 .36136 L .796 .605 0 r
F
.70235 .54311 m .65761 .54556 L .65811 .55211 L .746 .362 0 r
F
.70235 .54311 m .70173 .53654 L .65761 .54556 L F
.36518 .6379 m .31698 .62604 L .31696 .63231 L 1 .65 0 r
F
.3652 .64411 m .36518 .6379 L .31696 .63231 L 1 .641 0 r
F
.46448 .68064 m .41444 .67297 L .41447 .67915 L 1 .516 0 r
F
.46445 .68671 m .46448 .68064 L .41447 .67915 L 1 .504 0 r
F
.51447 .68637 m .46448 .68064 L .46445 .68671 L .975 .449 0 r
F
.51447 .68637 m .51459 .68032 L .46448 .68064 L F
.60877 .31041 m .57339 .31055 L .57501 .31684 L .862 .72 0 r
F
.6109 .31666 m .60877 .31041 L .57501 .31684 L .861 .713 0 r
F
.56364 .6767 m .51444 .67311 L .51432 .67909 L .912 .385 0 r
F
.56364 .6767 m .56385 .6707 L .51444 .67311 L F
.60862 .31059 m .57333 .31065 L .57495 .31694 L .859 .717 0 r
F
.61075 .31684 m .60862 .31059 L .57495 .31694 L .858 .71 0 r
F
.65839 .34601 m .62099 .34833 L .62288 .35474 L .802 .625 0 r
F
.66071 .35239 m .65839 .34601 L .62288 .35474 L .801 .617 0 r
F
.41467 .66601 m .3653 .65641 L .3654 .66251 L 1 .566 0 r
F
.41472 .67204 m .41467 .66601 L .3654 .66251 L 1 .556 0 r
F
.70487 .55669 m .65952 .55904 L .65996 .5656 L .747 .354 0 r
F
.70487 .55669 m .70432 .55009 L .65952 .55904 L F
.36475 .64479 m .31491 .63432 L .31496 .64062 L 1 .659 0 r
F
.36466 .65119 m .36475 .64479 L .31496 .64062 L 1 .645 0 r
F
.65803 .34627 m .62078 .34852 L .62266 .35493 L .799 .621 0 r
F
.66032 .35265 m .65803 .34627 L .62266 .35493 L .798 .613 0 r
F
.70292 .54967 m .65811 .55211 L .65856 .55864 L .744 .353 0 r
F
.70292 .54967 m .70235 .54311 L .65811 .55211 L F
.56407 .68413 m .51459 .68032 L .51447 .68637 L .915 .389 0 r
F
.56407 .68413 m .56429 .67807 L .51459 .68032 L F
.31499 .60892 m .26748 .59494 L .26729 .60145 L 1 .707 0 r
F
.31493 .6153 m .31499 .60892 L .26729 .60145 L 1 .699 0 r
F
.66031 .62284 m .61331 .62312 L .61327 .6294 L .794 .325 0 r
F
.66031 .62284 m .66036 .61653 L .61331 .62312 L F
.61249 .66027 m .5642 .65859 L .56404 .66466 L .852 .343 0 r
F
.61249 .66027 m .61272 .65417 L .5642 .65859 L F
.41444 .67297 m .36464 .66382 L .36469 .67005 L 1 .576 0 r
F
.41447 .67915 m .41444 .67297 L .36469 .67005 L 1 .564 0 r
F
.6616 .63021 m .61414 .63031 L .61409 .63663 L .798 .327 0 r
F
.6616 .63021 m .66166 .62385 L .61414 .63031 L F
.65603 .33966 m .61905 .34194 L .62099 .34833 L .803 .633 0 r
F
.65839 .34601 m .65603 .33966 L .62099 .34833 L .802 .625 0 r
F
.46452 .67954 m .41472 .67204 L .41478 .67804 L 1 .497 0 r
F
.4645 .68548 m .46452 .67954 L .41478 .67804 L 1 .487 0 r
F
.51419 .68504 m .46452 .67954 L .4645 .68548 L .969 .433 0 r
F
.51419 .68504 m .51432 .67909 L .46452 .67954 L F
.56834 .29188 m .53454 .29009 L .53567 .2963 L .909 .786 0 r
F
.57005 .29807 m .56834 .29188 L .53567 .2963 L .909 .78 0 r
F
.56829 .29198 m .53454 .2901 L .53567 .29631 L .906 .784 0 r
F
.57 .29817 m .56829 .29198 L .53567 .29631 L .906 .777 0 r
F
.70536 .56328 m .65996 .5656 L .66035 .57215 L .745 .344 0 r
F
.70536 .56328 m .70487 .55669 L .65996 .5656 L F
.61328 .66775 m .56464 .66585 L .56447 .67198 L .856 .345 0 r
F
.61328 .66775 m .61352 .66159 L .56464 .66585 L F
.3652 .64411 m .31696 .63231 L .31699 .63855 L 1 .641 0 r
F
.36524 .65028 m .3652 .64411 L .31699 .63855 L 1 .632 0 r
F
.65569 .33992 m .61886 .34213 L .62078 .34852 L .8 .629 0 r
F
.65803 .34627 m .65569 .33992 L .62078 .34852 L .799 .621 0 r
F
.70342 .55622 m .65856 .55864 L .65896 .56515 L .741 .343 0 r
F
.70342 .55622 m .70292 .54967 L .65856 .55864 L F
.60659 .30419 m .57173 .3043 L .57339 .31055 L .862 .727 0 r
F
.60877 .31041 m .60659 .30419 L .57339 .31055 L .862 .72 0 r
F
.60645 .30437 m .57168 .3044 L .57333 .31065 L .859 .724 0 r
F
.60862 .31059 m .60645 .30437 L .57333 .31065 L .859 .717 0 r
F
.46445 .68671 m .41447 .67915 L .41451 .68528 L 1 .504 0 r
F
.46443 .69275 m .46445 .68671 L .41451 .68528 L 1 .493 0 r
F
.51435 .69239 m .46445 .68671 L .46443 .69275 L .972 .438 0 r
F
.51435 .69239 m .51447 .68637 L .46445 .68671 L F
.36466 .65119 m .31496 .64062 L .31505 .6469 L 1 .645 0 r
F
.36463 .65753 m .36466 .65119 L .31505 .6469 L 1 .632 0 r
F
.41472 .67204 m .3654 .66251 L .36552 .66858 L 1 .556 0 r
F
.41478 .67804 m .41472 .67204 L .36552 .66858 L 1 .547 0 r
F
.5634 .68266 m .51432 .67909 L .51419 .68504 L .909 .375 0 r
F
.5634 .68266 m .56364 .6767 L .51432 .67909 L F
.65362 .33334 m .61708 .33558 L .61905 .34194 L .804 .641 0 r
F
.65603 .33966 m .65362 .33334 L .61905 .34194 L .803 .633 0 r
F
.31493 .6153 m .26729 .60145 L .26716 .60793 L 1 .699 0 r
F
.31489 .62166 m .31493 .6153 L .26716 .60793 L 1 .691 0 r
F
.70578 .56986 m .66035 .57215 L .66068 .57868 L .742 .334 0 r
F
.70578 .56986 m .70536 .56328 L .66035 .57215 L F
.66021 .62912 m .61327 .6294 L .61319 .63564 L .791 .315 0 r
F
.66021 .62912 m .66031 .62284 L .61327 .6294 L F
.65329 .3336 m .61689 .33577 L .61886 .34213 L .801 .637 0 r
F
.65569 .33992 m .65329 .3336 L .61886 .34213 L .8 .629 0 r
F
.70386 .56275 m .65896 .56515 L .65931 .57165 L .739 .333 0 r
F
.70386 .56275 m .70342 .55622 L .65896 .56515 L F
.66149 .63654 m .61409 .63663 L .61401 .64291 L .795 .317 0 r
F
.66149 .63654 m .6616 .63021 L .61409 .63663 L F
.27156 .53553 m .22826 .51862 L .22735 .52533 L .739 .934 0 r
F
.27089 .5422 m .27156 .53553 L .22735 .52533 L 1 .838 0 r
F
.56383 .69015 m .51447 .68637 L .51435 .69239 L .912 .378 0 r
F
.56383 .69015 m .56407 .68413 L .51447 .68637 L F
.31726 .60706 m .31744 .60069 L .27112 .5929 L 1 .731 0 r
F
.41447 .67915 m .36469 .67005 L .36479 .67625 L 1 .564 0 r
F
.41451 .68528 m .41447 .67915 L .36479 .67625 L 1 .552 0 r
F
.61222 .66634 m .56404 .66466 L .56385 .6707 L .849 .332 0 r
F
.61222 .66634 m .61249 .66027 L .56404 .66466 L F
.60437 .298 m .57005 .29807 L .57173 .3043 L .862 .734 0 r
F
.60659 .30419 m .60437 .298 L .57173 .3043 L .862 .727 0 r
F
.5666 .28572 m .53338 .28392 L .53454 .29009 L .908 .793 0 r
F
.56834 .29188 m .5666 .28572 L .53454 .29009 L .909 .786 0 r
F
.36524 .65028 m .31699 .63855 L .31706 .64476 L 1 .632 0 r
F
.3653 .65641 m .36524 .65028 L .31706 .64476 L 1 .623 0 r
F
.56655 .28581 m .53338 .28392 L .53454 .2901 L .906 .79 0 r
F
.56829 .29198 m .56655 .28581 L .53454 .2901 L .906 .784 0 r
F
.613 .67387 m .56447 .67198 L .56429 .67807 L .853 .335 0 r
F
.613 .67387 m .61328 .66775 L .56447 .67198 L F
.60424 .29818 m .57 .29817 L .57168 .3044 L .859 .731 0 r
F
.60645 .30437 m .60424 .29818 L .57168 .3044 L .859 .724 0 r
F
.4645 .68548 m .41478 .67804 L .41487 .684 L 1 .487 0 r
F
.46447 .69138 m .4645 .68548 L .41487 .684 L 1 .477 0 r
F
.51405 .69094 m .4645 .68548 L .46447 .69138 L .967 .423 0 r
F
.51405 .69094 m .51419 .68504 L .4645 .68548 L F
.65115 .32705 m .61506 .32925 L .61708 .33558 L .805 .648 0 r
F
.65362 .33334 m .65115 .32705 L .61708 .33558 L .804 .641 0 r
F
.70615 .57642 m .66068 .57868 L .66097 .5852 L .74 .325 0 r
F
.70615 .57642 m .70578 .56986 L .66068 .57868 L F
.36463 .65753 m .31505 .6469 L .31517 .65315 L 1 .632 0 r
F
.36464 .66382 m .36463 .65753 L .31517 .65315 L 1 .621 0 r
F
.27089 .5422 m .22735 .52533 L .22652 .53204 L 1 .838 0 r
F
.27027 .54885 m .27089 .5422 L .22652 .53204 L 1 .83 0 r
F
.70424 .56927 m .65931 .57165 L .65961 .57813 L .736 .323 0 r
F
.70424 .56927 m .70386 .56275 L .65931 .57165 L F
.65084 .32731 m .61489 .32943 L .61689 .33577 L .802 .644 0 r
F
.65329 .3336 m .65084 .32731 L .61689 .33577 L .801 .637 0 r
F
.31489 .62166 m .26716 .60793 L .26708 .61438 L 1 .691 0 r
F
.31489 .628 m .31489 .62166 L .26708 .61438 L 1 .684 0 r
F
.46443 .69275 m .41451 .68528 L .41457 .69137 L 1 .493 0 r
F
.46441 .69874 m .46443 .69275 L .41457 .69137 L 1 .482 0 r
F
.51421 .69836 m .46443 .69275 L .46441 .69874 L .969 .427 0 r
F
.51421 .69836 m .51435 .69239 L .46443 .69275 L F
.41478 .67804 m .36552 .66858 L .36568 .67461 L 1 .547 0 r
F
.41487 .684 m .41478 .67804 L .36568 .67461 L 1 .537 0 r
F
.66006 .63537 m .61319 .63564 L .61307 .64185 L .789 .305 0 r
F
.66006 .63537 m .66021 .62912 L .61319 .63564 L F
.31726 .60706 m .27112 .5929 L .27089 .59932 L 1 .731 0 r
F
.31712 .61341 m .31726 .60706 L .27089 .59932 L 1 .722 0 r
F
.56314 .68858 m .51419 .68504 L .51405 .69094 L .907 .365 0 r
F
.56314 .68858 m .5634 .68266 L .51419 .68504 L F
.66132 .64285 m .61401 .64291 L .61388 .64917 L .793 .307 0 r
F
.66132 .64285 m .66149 .63654 L .61401 .64291 L F
.64863 .32078 m .613 .32294 L .61506 .32925 L .806 .656 0 r
F
.65115 .32705 m .64863 .32078 L .61506 .32925 L .805 .648 0 r
F
.27027 .54885 m .22652 .53204 L .22575 .53873 L 1 .83 0 r
F
.26971 .55549 m .27027 .54885 L .22575 .53873 L 1 .822 0 r
F
.70645 .58296 m .66097 .5852 L .66121 .5917 L .737 .315 0 r
F
.70645 .58296 m .70615 .57642 L .66097 .5852 L F
.41451 .68528 m .36479 .67625 L .36491 .68239 L 1 .552 0 r
F
.41457 .69137 m .41451 .68528 L .36491 .68239 L 1 .541 0 r
F
.70455 .57577 m .65961 .57813 L .65986 .58458 L .733 .313 0 r
F
.70455 .57577 m .70424 .56927 L .65961 .57813 L F
.64834 .32104 m .61284 .32312 L .61489 .32943 L .803 .652 0 r
F
.65084 .32731 m .64834 .32104 L .61489 .32943 L .802 .644 0 r
F
.56357 .69613 m .51435 .69239 L .51421 .69836 L .91 .368 0 r
F
.56357 .69613 m .56383 .69015 L .51435 .69239 L F
.61191 .67237 m .56385 .6707 L .56364 .6767 L .847 .322 0 r
F
.61191 .67237 m .61222 .66634 L .56385 .6707 L F
.60211 .29185 m .56834 .29188 L .57005 .29807 L .862 .741 0 r
F
.60437 .298 m .60211 .29185 L .57005 .29807 L .862 .734 0 r
F
.60199 .29202 m .56829 .29198 L .57 .29817 L .86 .738 0 r
F
.60424 .29818 m .60199 .29202 L .57 .29817 L .859 .731 0 r
F
.3653 .65641 m .31706 .64476 L .31717 .65094 L 1 .623 0 r
F
.3654 .66251 m .3653 .65641 L .31717 .65094 L 1 .613 0 r
F
.56482 .27959 m .53221 .27777 L .53338 .28392 L .908 .799 0 r
F
.5666 .28572 m .56482 .27959 L .53338 .28392 L .908 .793 0 r
F
.56478 .27969 m .53221 .27777 L .53338 .28392 L .905 .797 0 r
F
.56655 .28581 m .56478 .27969 L .53338 .28392 L .906 .79 0 r
F
.36464 .66382 m .31517 .65315 L .31532 .65937 L 1 .621 0 r
F
.36469 .67005 m .36464 .66382 L .31532 .65937 L 1 .61 0 r
F
.61269 .67996 m .56429 .67807 L .56407 .68413 L .85 .324 0 r
F
.61269 .67996 m .613 .67387 L .56429 .67807 L F
.46447 .69138 m .41487 .684 L .41496 .68992 L 1 .477 0 r
F
.46446 .69724 m .46447 .69138 L .41496 .68992 L 1 .466 0 r
F
.5139 .6968 m .46447 .69138 L .46446 .69724 L .965 .413 0 r
F
.5139 .6968 m .51405 .69094 L .46447 .69138 L F
.26971 .55549 m .22575 .53873 L .22504 .54542 L 1 .822 0 r
F
.2692 .56211 m .26971 .55549 L .22504 .54542 L 1 .814 0 r
F
.31489 .628 m .26708 .61438 L .26706 .62081 L 1 .684 0 r
F
.31491 .63432 m .31489 .628 L .26706 .62081 L 1 .677 0 r
F
.31712 .61341 m .27089 .59932 L .27072 .60571 L 1 .722 0 r
F
.31703 .61974 m .31712 .61341 L .27072 .60571 L 1 .714 0 r
F
.64606 .31455 m .6109 .31666 L .613 .32294 L .807 .664 0 r
F
.64863 .32078 m .64606 .31455 L .613 .32294 L .806 .656 0 r
F
.65986 .64159 m .61307 .64185 L .61291 .64802 L .786 .294 0 r
F
.65986 .64159 m .66006 .63537 L .61307 .64185 L F
.70669 .58949 m .66121 .5917 L .6614 .59817 L .734 .305 0 r
F
.70669 .58949 m .70645 .58296 L .66121 .5917 L F
.70481 .58225 m .65986 .58458 L .66006 .59102 L .73 .303 0 r
F
.70481 .58225 m .70455 .57577 L .65986 .58458 L F
.64579 .31481 m .61075 .31684 L .61284 .32312 L .804 .66 0 r
F
.64834 .32104 m .64579 .31481 L .61284 .32312 L .803 .652 0 r
F
.66111 .64912 m .61388 .64917 L .61372 .6554 L .79 .296 0 r
F
.66111 .64912 m .66132 .64285 L .61388 .64917 L F
.46441 .69874 m .41457 .69137 L .41465 .6974 L 1 .482 0 r
F
.46439 .7047 m .46441 .69874 L .41465 .6974 L 1 .471 0 r
F
.51406 .70429 m .46441 .69874 L .46439 .7047 L .966 .416 0 r
F
.51406 .70429 m .51421 .69836 L .46441 .69874 L F
.41487 .684 m .36568 .67461 L .36586 .6806 L 1 .537 0 r
F
.41496 .68992 m .41487 .684 L .36586 .6806 L 1 .527 0 r
F
.56286 .69446 m .51405 .69094 L .5139 .6968 L .904 .354 0 r
F
.56286 .69446 m .56314 .68858 L .51405 .69094 L F
.59981 .28573 m .5666 .28572 L .56834 .29188 L .863 .748 0 r
F
.60211 .29185 m .59981 .28573 L .56834 .29188 L .862 .741 0 r
F
.2692 .56211 m .22504 .54542 L .2244 .55209 L 1 .814 0 r
F
.26875 .56872 m .2692 .56211 L .2244 .55209 L 1 .805 0 r
F
.59969 .2859 m .56655 .28581 L .56829 .29198 L .86 .745 0 r
F
.60199 .29202 m .59969 .2859 L .56829 .29198 L .86 .738 0 r
F
.41457 .69137 m .36491 .68239 L .36508 .68849 L 1 .541 0 r
F
.41465 .6974 m .41457 .69137 L .36508 .68849 L 1 .529 0 r
F
.7243 .42591 m .68427 .43055 L .68588 .43716 L .711 .453 0 r
F
.72615 .43252 m .68588 .43716 L .68743 .44379 L .709 .444 0 r
F
.72615 .43252 m .7243 .42591 L .68588 .43716 L F
.61156 .67837 m .56364 .6767 L .5634 .68266 L .844 .311 0 r
F
.61156 .67837 m .61191 .67237 L .56364 .6767 L F
.72238 .41931 m .68261 .42395 L .68427 .43055 L .714 .462 0 r
F
.7243 .42591 m .72238 .41931 L .68427 .43055 L .711 .453 0 r
F
.3654 .66251 m .31717 .65094 L .31733 .65708 L 1 .613 0 r
F
.36552 .66858 m .3654 .66251 L .31733 .65708 L 1 .603 0 r
F
.72794 .43914 m .68743 .44379 L .68892 .45042 L .707 .435 0 r
F
.72794 .43914 m .72615 .43252 L .68743 .44379 L F
.7204 .41273 m .68089 .41736 L .68261 .42395 L .716 .471 0 r
F
.72238 .41931 m .7204 .41273 L .68261 .42395 L .714 .462 0 r
F
.56328 .70207 m .51421 .69836 L .51406 .70429 L .907 .357 0 r
F
.56328 .70207 m .56357 .69613 L .51421 .69836 L F
.72965 .44577 m .68892 .45042 L .69035 .45706 L .704 .426 0 r
F
.72965 .44577 m .72794 .43914 L .68892 .45042 L F
.36469 .67005 m .31532 .65937 L .31552 .66557 L 1 .61 0 r
F
.36479 .67625 m .36469 .67005 L .31552 .66557 L 1 .599 0 r
F
.71834 .40617 m .67912 .41078 L .68089 .41736 L .718 .48 0 r
F
.7204 .41273 m .71834 .40617 L .68089 .41736 L .716 .471 0 r
F
.64345 .30835 m .60877 .31041 L .6109 .31666 L .808 .672 0 r
F
.64606 .31455 m .64345 .30835 L .6109 .31666 L .807 .664 0 r
F
.31703 .61974 m .27072 .60571 L .2706 .61208 L 1 .714 0 r
F
.31698 .62604 m .31703 .61974 L .2706 .61208 L 1 .705 0 r
F
.7313 .45241 m .69035 .45706 L .69173 .4637 L .702 .416 0 r
F
.7313 .45241 m .72965 .44577 L .69035 .45706 L F
.56302 .2735 m .53102 .27166 L .53221 .27777 L .908 .806 0 r
F
.56482 .27959 m .56302 .2735 L .53221 .27777 L .908 .799 0 r
F
.56298 .27359 m .53102 .27166 L .53221 .27777 L .905 .803 0 r
F
.56478 .27969 m .56298 .27359 L .53221 .27777 L .905 .797 0 r
F
.71623 .39962 m .67729 .40422 L .67912 .41078 L .72 .489 0 r
F
.71834 .40617 m .71623 .39962 L .67912 .41078 L .718 .48 0 r
F
.70687 .59599 m .6614 .59817 L .66154 .60463 L .732 .294 0 r
F
.70687 .59599 m .70669 .58949 L .6614 .59817 L F
.31491 .63432 m .26706 .62081 L .26708 .62721 L 1 .677 0 r
F
.31496 .64062 m .31491 .63432 L .26708 .62721 L 1 .67 0 r
F
.61234 .68601 m .56407 .68413 L .56383 .69015 L .847 .313 0 r
F
.61234 .68601 m .61269 .67996 L .56407 .68413 L F
.27553 .53444 m .23355 .51779 L .23263 .52437 L 1 .856 0 r
F
.27483 .54098 m .27553 .53444 L .23263 .52437 L 1 .849 0 r
F
.705 .58871 m .66006 .59102 L .66021 .59744 L .727 .292 0 r
F
.705 .58871 m .70481 .58225 L .66006 .59102 L F
.64319 .30861 m .60862 .31059 L .61075 .31684 L .805 .668 0 r
F
.64579 .31481 m .64319 .30861 L .61075 .31684 L .804 .66 0 r
F
.73288 .45906 m .69173 .4637 L .69305 .47035 L .7 .407 0 r
F
.73288 .45906 m .7313 .45241 L .69173 .4637 L F
.71404 .3931 m .6754 .39767 L .67729 .40422 L .722 .498 0 r
F
.71623 .39962 m .71404 .3931 L .67729 .40422 L .72 .489 0 r
F
.72142 .41955 m .68195 .42412 L .68358 .43071 L .709 .455 0 r
F
.7233 .42612 m .68358 .43071 L .68515 .43731 L .707 .446 0 r
F
.7233 .42612 m .72142 .41955 L .68358 .43071 L F
.72511 .43271 m .68515 .43731 L .68667 .44391 L .704 .436 0 r
F
.72511 .43271 m .7233 .42612 L .68515 .43731 L F
.65961 .64778 m .61291 .64802 L .61272 .65417 L .783 .284 0 r
F
.65961 .64778 m .65986 .64159 L .61291 .64802 L F
.71948 .41298 m .68026 .41755 L .68195 .42412 L .711 .464 0 r
F
.72142 .41955 m .71948 .41298 L .68195 .42412 L .709 .455 0 r
F
.73439 .46572 m .69305 .47035 L .69432 .47701 L .697 .397 0 r
F
.73439 .46572 m .73288 .45906 L .69305 .47035 L F
.72685 .43931 m .68667 .44391 L .68813 .45053 L .702 .427 0 r
F
.72685 .43931 m .72511 .43271 L .68667 .44391 L F
.46446 .69724 m .41496 .68992 L .41507 .6958 L 1 .466 0 r
F
.46444 .70306 m .46446 .69724 L .41507 .6958 L 1 .456 0 r
F
.51374 .70261 m .46446 .69724 L .46444 .70306 L .962 .402 0 r
F
.51374 .70261 m .5139 .6968 L .46446 .69724 L F
.71747 .40643 m .67851 .41098 L .68026 .41755 L .714 .473 0 r
F
.71948 .41298 m .71747 .40643 L .68026 .41755 L .711 .464 0 r
F
.26875 .56872 m .2244 .55209 L .22383 .55875 L 1 .805 0 r
F
.26835 .5753 m .26875 .56872 L .22383 .55875 L 1 .797 0 r
F
.71179 .38659 m .67347 .39114 L .6754 .39767 L .724 .507 0 r
F
.71404 .3931 m .71179 .38659 L .6754 .39767 L .722 .498 0 r
F
.72852 .44592 m .68813 .45053 L .68953 .45715 L .699 .417 0 r
F
.72852 .44592 m .72685 .43931 L .68813 .45053 L F
.66085 .65536 m .61372 .6554 L .61352 .66159 L .787 .286 0 r
F
.66085 .65536 m .66111 .64912 L .61372 .6554 L F
.71539 .3999 m .67671 .40443 L .67851 .41098 L .716 .483 0 r
F
.71747 .40643 m .71539 .3999 L .67851 .41098 L .714 .473 0 r
F
.73584 .47239 m .69432 .47701 L .69552 .48366 L .695 .388 0 r
F
.73584 .47239 m .73439 .46572 L .69432 .47701 L F
.73012 .45254 m .68953 .45715 L .69087 .46377 L .697 .408 0 r
F
.73012 .45254 m .72852 .44592 L .68953 .45715 L F
.71324 .39339 m .67486 .39789 L .67671 .40443 L .718 .492 0 r
F
.71539 .3999 m .71324 .39339 L .67671 .40443 L .716 .483 0 r
F
.27483 .54098 m .23263 .52437 L .23177 .53093 L 1 .849 0 r
F
.27419 .54752 m .27483 .54098 L .23177 .53093 L 1 .841 0 r
F
.70948 .38011 m .67147 .38463 L .67347 .39114 L .726 .516 0 r
F
.71179 .38659 m .70948 .38011 L .67347 .39114 L .724 .507 0 r
F
.73165 .45917 m .69087 .46377 L .69216 .47039 L .694 .398 0 r
F
.73165 .45917 m .73012 .45254 L .69087 .46377 L F
.46439 .7047 m .41465 .6974 L .41475 .70339 L 1 .471 0 r
F
.46437 .7106 m .46439 .7047 L .41475 .70339 L 1 .459 0 r
F
.51389 .71018 m .46439 .7047 L .46437 .7106 L .964 .405 0 r
F
.51389 .71018 m .51406 .70429 L .46439 .7047 L F
.41496 .68992 m .36586 .6806 L .36607 .68655 L 1 .527 0 r
F
.41507 .6958 m .41496 .68992 L .36607 .68655 L 1 .516 0 r
F
.71103 .38689 m .67295 .39137 L .67486 .39789 L .72 .501 0 r
F
.71324 .39339 m .71103 .38689 L .67486 .39789 L .718 .492 0 r
F
.73721 .47906 m .69552 .48366 L .69667 .49032 L .692 .378 0 r
F
.73721 .47906 m .73584 .47239 L .69552 .48366 L F
.59747 .27964 m .56482 .27959 L .5666 .28572 L .863 .755 0 r
F
.59981 .28573 m .59747 .27964 L .5666 .28572 L .863 .748 0 r
F
.64078 .30218 m .60659 .30419 L .60877 .31041 L .809 .679 0 r
F
.64345 .30835 m .64078 .30218 L .60877 .31041 L .808 .672 0 r
F
.59736 .27981 m .56478 .27969 L .56655 .28581 L .86 .752 0 r
F
.59969 .2859 m .59736 .27981 L .56655 .28581 L .86 .745 0 r
F
.73311 .46579 m .69216 .47039 L .69338 .47702 L .692 .388 0 r
F
.73311 .46579 m .73165 .45917 L .69216 .47039 L F
.7071 .37364 m .66943 .37814 L .67147 .38463 L .728 .525 0 r
F
.70948 .38011 m .7071 .37364 L .67147 .38463 L .726 .516 0 r
F
.56254 .70029 m .5139 .6968 L .51374 .70261 L .901 .343 0 r
F
.56254 .70029 m .56286 .69446 L .5139 .6968 L F
.70698 .60248 m .66154 .60463 L .66163 .61106 L .729 .284 0 r
F
.70698 .60248 m .70687 .59599 L .66154 .60463 L F
.31698 .62604 m .2706 .61208 L .27053 .61842 L 1 .705 0 r
F
.31696 .63231 m .31698 .62604 L .27053 .61842 L 1 .696 0 r
F
.70513 .59514 m .66021 .59744 L .66031 .60383 L .725 .282 0 r
F
.70513 .59514 m .705 .58871 L .66021 .59744 L F
.64053 .30244 m .60645 .30437 L .60862 .31059 L .806 .676 0 r
F
.64319 .30861 m .64053 .30244 L .60862 .31059 L .805 .668 0 r
F
.70875 .38041 m .67098 .38487 L .67295 .39137 L .722 .51 0 r
F
.71103 .38689 m .70875 .38041 L .67295 .39137 L .72 .501 0 r
F
.36552 .66858 m .31733 .65708 L .31752 .66319 L 1 .603 0 r
F
.36568 .67461 m .36552 .66858 L .31752 .66319 L 1 .593 0 r
F
.41465 .6974 m .36508 .68849 L .36527 .69455 L 1 .529 0 r
F
.41475 .70339 m .41465 .6974 L .36527 .69455 L 1 .518 0 r
F
.73851 .48573 m .69667 .49032 L .69776 .49698 L .69 .369 0 r
F
.73851 .48573 m .73721 .47906 L .69667 .49032 L F
.36479 .67625 m .31552 .66557 L .31575 .67173 L 1 .599 0 r
F
.36491 .68239 m .36479 .67625 L .31575 .67173 L 1 .589 0 r
F
.61118 .68432 m .5634 .68266 L .56314 .68858 L .841 .3 0 r
F
.61118 .68432 m .61156 .67837 L .5634 .68266 L F
.7345 .47243 m .69338 .47702 L .69455 .48365 L .689 .379 0 r
F
.7345 .47243 m .73311 .46579 L .69338 .47702 L F
.31496 .64062 m .26708 .62721 L .26716 .63359 L 1 .67 0 r
F
.31505 .6469 m .31496 .64062 L .26716 .63359 L 1 .663 0 r
F
.26835 .5753 m .22383 .55875 L .22332 .5654 L 1 .797 0 r
F
.26801 .58187 m .26835 .5753 L .22332 .5654 L 1 .789 0 r
F
.27419 .54752 m .23177 .53093 L .23097 .5375 L 1 .841 0 r
F
.27359 .55405 m .27419 .54752 L .23097 .5375 L 1 .834 0 r
F
.70466 .3672 m .66733 .37167 L .66943 .37814 L .73 .533 0 r
F
.7071 .37364 m .70466 .3672 L .66943 .37814 L .728 .525 0 r
F
.70641 .37396 m .66896 .37838 L .67098 .38487 L .724 .519 0 r
F
.70875 .38041 m .70641 .37396 L .67098 .38487 L .722 .51 0 r
F
.56297 .70797 m .51406 .70429 L .51389 .71018 L .904 .345 0 r
F
.56297 .70797 m .56328 .70207 L .51406 .70429 L F
.56119 .26745 m .52981 .26558 L .53102 .27166 L .907 .812 0 r
F
.56302 .2735 m .56119 .26745 L .53102 .27166 L .908 .806 0 r
F
.56116 .26753 m .52981 .26559 L .53102 .27166 L .904 .809 0 r
F
.56298 .27359 m .56116 .26753 L .53102 .27166 L .905 .803 0 r
F
.73582 .47907 m .69455 .48365 L .69566 .49028 L .686 .369 0 r
F
.73582 .47907 m .7345 .47243 L .69455 .48365 L F
.61194 .69202 m .56383 .69015 L .56357 .69613 L .844 .302 0 r
F
.61194 .69202 m .61234 .68601 L .56383 .69015 L F
.73974 .49241 m .69776 .49698 L .69879 .50364 L .687 .359 0 r
F
.73974 .49241 m .73851 .48573 L .69776 .49698 L F
.65931 .65393 m .61272 .65417 L .61249 .66027 L .78 .273 0 r
F
.65931 .65393 m .65961 .64778 L .61272 .65417 L F
.704 .36752 m .66688 .37191 L .66896 .37838 L .727 .528 0 r
F
.70641 .37396 m .704 .36752 L .66896 .37838 L .724 .519 0 r
F
.70216 .36079 m .66517 .36522 L .66733 .37167 L .732 .542 0 r
F
.70466 .3672 m .70216 .36079 L .66733 .37167 L .73 .533 0 r
F
.66053 .66156 m .61352 .66159 L .61328 .66775 L .784 .275 0 r
F
.66053 .66156 m .66085 .65536 L .61352 .66159 L F
.63806 .29605 m .60437 .298 L .60659 .30419 L .81 .687 0 r
F
.64078 .30218 m .63806 .29605 L .60659 .30419 L .809 .679 0 r
F
.73707 .4857 m .69566 .49028 L .6967 .4969 L .684 .359 0 r
F
.73707 .4857 m .73582 .47907 L .69566 .49028 L F
.46444 .70306 m .41507 .6958 L .4152 .70163 L 1 .456 0 r
F
.46442 .70883 m .46444 .70306 L .4152 .70163 L 1 .445 0 r
F
.51356 .70838 m .46444 .70306 L .46442 .70883 L .96 .391 0 r
F
.51356 .70838 m .51374 .70261 L .46444 .70306 L F
.27359 .55405 m .23097 .5375 L .23023 .54405 L 1 .834 0 r
F
.27305 .56056 m .27359 .55405 L .23023 .54405 L 1 .826 0 r
F
.7409 .49908 m .69879 .50364 L .69976 .51029 L .684 .349 0 r
F
.7409 .49908 m .73974 .49241 L .69879 .50364 L F
.70704 .60894 m .66163 .61106 L .66167 .61747 L .726 .274 0 r
F
.70704 .60894 m .70698 .60248 L .66163 .61106 L F
.7052 .60155 m .66031 .60383 L .66036 .61019 L .721 .272 0 r
F
.7052 .60155 m .70513 .59514 L .66031 .60383 L F
.63783 .29631 m .60424 .29818 L .60645 .30437 L .807 .683 0 r
F
.64053 .30244 m .63783 .29631 L .60645 .30437 L .806 .676 0 r
F
.70153 .36112 m .66475 .36547 L .66688 .37191 L .729 .537 0 r
F
.704 .36752 m .70153 .36112 L .66688 .37191 L .727 .528 0 r
F
.69959 .3544 m .66297 .35879 L .66517 .36522 L .734 .551 0 r
F
.70216 .36079 m .69959 .3544 L .66517 .36522 L .732 .542 0 r
F
.31696 .63231 m .27053 .61842 L .27052 .62474 L 1 .696 0 r
F
.31699 .63855 m .31696 .63231 L .27052 .62474 L 1 .687 0 r
F
.26801 .58187 m .22332 .5654 L .22288 .57203 L 1 .789 0 r
F
.26772 .58842 m .26801 .58187 L .22288 .57203 L 1 .78 0 r
F
.59509 .2736 m .56302 .2735 L .56482 .27959 L .863 .762 0 r
F
.59747 .27964 m .59509 .2736 L .56482 .27959 L .863 .755 0 r
F
.59499 .27376 m .56298 .27359 L .56478 .27969 L .86 .759 0 r
F
.59736 .27981 m .59499 .27376 L .56478 .27969 L .86 .752 0 r
F
.73825 .49234 m .6967 .4969 L .69769 .50352 L .681 .349 0 r
F
.73825 .49234 m .73707 .4857 L .6967 .4969 L F
.41507 .6958 m .36607 .68655 L .36631 .69246 L 1 .516 0 r
F
.4152 .70163 m .41507 .6958 L .36631 .69246 L 1 .506 0 r
F
.46437 .7106 m .41475 .70339 L .41487 .70934 L 1 .459 0 r
F
.46435 .71646 m .46437 .7106 L .41487 .70934 L 1 .448 0 r
F
.51372 .71603 m .46437 .7106 L .46435 .71646 L .961 .394 0 r
F
.51372 .71603 m .51389 .71018 L .46437 .7106 L F
.742 .50576 m .69976 .51029 L .70067 .51694 L .681 .339 0 r
F
.742 .50576 m .7409 .49908 L .69976 .51029 L F
.699 .35473 m .66256 .35905 L .66475 .36547 L .731 .546 0 r
F
.70153 .36112 m .699 .35473 L .66475 .36547 L .729 .537 0 r
F
.31505 .6469 m .26716 .63359 L .26728 .63994 L 1 .663 0 r
F
.31517 .65315 m .31505 .6469 L .26728 .63994 L 1 .655 0 r
F
.36568 .67461 m .31752 .66319 L .31776 .66927 L 1 .593 0 r
F
.36586 .6806 m .36568 .67461 L .31776 .66927 L 1 .583 0 r
F
.36491 .68239 m .31575 .67173 L .31602 .67787 L 1 .589 0 r
F
.36508 .68849 m .36491 .68239 L .31602 .67787 L 1 .578 0 r
F
.56221 .70608 m .51374 .70261 L .51356 .70838 L .899 .332 0 r
F
.56221 .70608 m .56254 .70029 L .51374 .70261 L F
.69696 .34804 m .66071 .35239 L .66297 .35879 L .736 .559 0 r
F
.69959 .3544 m .69696 .34804 L .66297 .35879 L .734 .551 0 r
F
.27305 .56056 m .23023 .54405 L .22956 .5506 L 1 .826 0 r
F
.27256 .56706 m .27305 .56056 L .22956 .5506 L 1 .818 0 r
F
.41475 .70339 m .36527 .69455 L .3655 .70055 L 1 .518 0 r
F
.41487 .70934 m .41475 .70339 L .3655 .70055 L 1 .506 0 r
F
.73936 .49898 m .69769 .50352 L .69862 .51014 L .678 .339 0 r
F
.73936 .49898 m .73825 .49234 L .69769 .50352 L F
.61075 .69023 m .56314 .68858 L .56286 .69446 L .838 .289 0 r
F
.61075 .69023 m .61118 .68432 L .56314 .68858 L F
.74302 .51243 m .70067 .51694 L .70152 .52359 L .679 .329 0 r
F
.74302 .51243 m .742 .50576 L .70067 .51694 L F
.65895 .66005 m .61249 .66027 L .61222 .66634 L .777 .262 0 r
F
.65895 .66005 m .65931 .65393 L .61249 .66027 L F
.63529 .28996 m .60211 .29185 L .60437 .298 L .811 .694 0 r
F
.63806 .29605 m .63529 .28996 L .60437 .298 L .81 .687 0 r
F
.6964 .34838 m .66032 .35265 L .66256 .35905 L .732 .554 0 r
F
.699 .35473 m .6964 .34838 L .66256 .35905 L .731 .546 0 r
F
.56263 .71382 m .51389 .71018 L .51372 .71603 L .901 .334 0 r
F
.56263 .71382 m .56297 .70797 L .51389 .71018 L F
.55933 .26143 m .52859 .25955 L .52981 .26558 L .907 .818 0 r
F
.56119 .26745 m .55933 .26143 L .52981 .26558 L .907 .812 0 r
F
.5593 .26151 m .52859 .25955 L .52981 .26559 L .904 .816 0 r
F
.56116 .26753 m .5593 .26151 L .52981 .26559 L .904 .809 0 r
F
.7052 .60794 m .66036 .61019 L .66036 .61653 L .718 .261 0 r
F
.7052 .60794 m .7052 .60155 L .66036 .61019 L F
.70703 .61538 m .66167 .61747 L .66166 .62385 L .723 .263 0 r
F
.70703 .61538 m .70704 .60894 L .66167 .61747 L F
.61151 .69799 m .56357 .69613 L .56328 .70207 L .841 .291 0 r
F
.61151 .69799 m .61194 .69202 L .56357 .69613 L F
.63508 .29021 m .60199 .29202 L .60424 .29818 L .808 .691 0 r
F
.63783 .29631 m .63508 .29021 L .60424 .29818 L .807 .683 0 r
F
.26772 .58842 m .22288 .57203 L .22251 .57864 L 1 .78 0 r
F
.26748 .59494 m .26772 .58842 L .22251 .57864 L 1 .771 0 r
F
.69427 .34171 m .65839 .34601 L .66071 .35239 L .738 .568 0 r
F
.69696 .34804 m .69427 .34171 L .66071 .35239 L .736 .559 0 r
F
.66017 .66774 m .61328 .66775 L .613 .67387 L .781 .264 0 r
F
.66017 .66774 m .66053 .66156 L .61328 .66775 L F
.74039 .50561 m .69862 .51014 L .69949 .51675 L .675 .328 0 r
F
.74039 .50561 m .73936 .49898 L .69862 .51014 L F
.31699 .63855 m .27052 .62474 L .27057 .63104 L 1 .687 0 r
F
.31706 .64476 m .31699 .63855 L .27057 .63104 L 1 .677 0 r
F
.27256 .56706 m .22956 .5506 L .22896 .55713 L 1 .818 0 r
F
.27212 .57355 m .27256 .56706 L .22896 .55713 L 1 .81 0 r
F
.69373 .34205 m .65803 .34627 L .66032 .35265 L .734 .563 0 r
F
.6964 .34838 m .69373 .34205 L .66032 .35265 L .732 .554 0 r
F
.74396 .51911 m .70152 .52359 L .70231 .53023 L .676 .319 0 r
F
.74396 .51911 m .74302 .51243 L .70152 .52359 L F
.59268 .26759 m .56119 .26745 L .56302 .2735 L .863 .769 0 r
F
.59509 .2736 m .59268 .26759 L .56302 .2735 L .863 .762 0 r
F
.46442 .70883 m .4152 .70163 L .41534 .70742 L 1 .445 0 r
F
.46441 .71455 m .46442 .70883 L .41534 .70742 L 1 .434 0 r
F
.51338 .71411 m .46442 .70883 L .46441 .71455 L .957 .38 0 r
F
.51338 .71411 m .51356 .70838 L .46442 .70883 L F
.59259 .26775 m .56116 .26753 L .56298 .27359 L .86 .766 0 r
F
.59499 .27376 m .59259 .26775 L .56298 .27359 L .86 .759 0 r
F
.69152 .33541 m .65603 .33966 L .65839 .34601 L .739 .577 0 r
F
.69427 .34171 m .69152 .33541 L .65839 .34601 L .738 .568 0 r
F
.74135 .51224 m .69949 .51675 L .70029 .52336 L .672 .318 0 r
F
.74135 .51224 m .74039 .50561 L .69949 .51675 L F
.31517 .65315 m .26728 .63994 L .26746 .64626 L 1 .655 0 r
F
.31532 .65937 m .31517 .65315 L .26746 .64626 L 1 .647 0 r
F
.4152 .70163 m .36631 .69246 L .36657 .69833 L 1 .506 0 r
F
.41534 .70742 m .4152 .70163 L .36657 .69833 L 1 .495 0 r
F
.69101 .33575 m .65569 .33992 L .65803 .34627 L .736 .572 0 r
F
.69373 .34205 m .69101 .33575 L .65803 .34627 L .734 .563 0 r
F
.36586 .6806 m .31776 .66927 L .31803 .67531 L 1 .583 0 r
F
.36607 .68655 m .36586 .6806 L .31803 .67531 L 1 .573 0 r
F
.74484 .52577 m .70231 .53023 L .70304 .53686 L .673 .309 0 r
F
.74484 .52577 m .74396 .51911 L .70231 .53023 L F
.63248 .2839 m .59981 .28573 L .60211 .29185 L .812 .702 0 r
F
.63529 .28996 m .63248 .2839 L .60211 .29185 L .811 .694 0 r
F
.36508 .68849 m .31602 .67787 L .31633 .68396 L 1 .578 0 r
F
.36527 .69455 m .36508 .68849 L .31633 .68396 L 1 .567 0 r
F
.46435 .71646 m .41487 .70934 L .415 .71523 L 1 .448 0 r
F
.46434 .72228 m .46435 .71646 L .415 .71523 L 1 .436 0 r
F
.51353 .72183 m .46435 .71646 L .46434 .72228 L .958 .382 0 r
F
.51353 .72183 m .51372 .71603 L .46435 .71646 L F
.26748 .59494 m .22251 .57864 L .2222 .58524 L 1 .771 0 r
F
.26729 .60145 m .26748 .59494 L .2222 .58524 L 1 .763 0 r
F
.70514 .6143 m .66036 .61653 L .66031 .62284 L .715 .25 0 r
F
.70514 .6143 m .7052 .60794 L .66036 .61653 L F
.70695 .6218 m .66166 .62385 L .6616 .63021 L .719 .252 0 r
F
.70695 .6218 m .70703 .61538 L .66166 .62385 L F
.63228 .28415 m .59969 .2859 L .60199 .29202 L .809 .699 0 r
F
.63508 .29021 m .63228 .28415 L .60199 .29202 L .808 .691 0 r
F
.27212 .57355 m .22896 .55713 L .22842 .56366 L 1 .81 0 r
F
.27173 .58002 m .27212 .57355 L .22842 .56366 L 1 .802 0 r
F
.56184 .71182 m .51356 .70838 L .51338 .71411 L .896 .321 0 r
F
.56184 .71182 m .56221 .70608 L .51356 .70838 L F
.6887 .32914 m .65362 .33334 L .65603 .33966 L .741 .585 0 r
F
.69152 .33541 m .6887 .32914 L .65603 .33966 L .739 .577 0 r
F
.74225 .51886 m .70029 .52336 L .70104 .52995 L .669 .308 0 r
F
.74225 .51886 m .74135 .51224 L .70029 .52336 L F
.41487 .70934 m .3655 .70055 L .36577 .70652 L 1 .506 0 r
F
.415 .71523 m .41487 .70934 L .36577 .70652 L 1 .495 0 r
F
.65855 .66613 m .61222 .66634 L .61191 .67237 L .774 .251 0 r
F
.65855 .66613 m .65895 .66005 L .61222 .66634 L F
.61029 .69609 m .56286 .69446 L .56254 .70029 L .835 .278 0 r
F
.61029 .69609 m .61075 .69023 L .56286 .69446 L F
.65975 .67387 m .613 .67387 L .61269 .67996 L .777 .253 0 r
F
.65975 .67387 m .66017 .66774 L .613 .67387 L F
.31706 .64476 m .27057 .63104 L .27066 .6373 L 1 .677 0 r
F
.31717 .65094 m .31706 .64476 L .27066 .6373 L 1 .667 0 r
F
.68822 .32948 m .65329 .3336 L .65569 .33992 L .738 .581 0 r
F
.69101 .33575 m .68822 .32948 L .65569 .33992 L .736 .572 0 r
F
.55745 .25545 m .52734 .25354 L .52859 .25955 L .906 .825 0 r
F
.55933 .26143 m .55745 .25545 L .52859 .25955 L .907 .818 0 r
F
.55742 .25553 m .52734 .25354 L .52859 .25955 L .903 .822 0 r
F
.5593 .26151 m .55742 .25553 L .52859 .25955 L .904 .816 0 r
F
.74564 .53244 m .70304 .53686 L .70371 .54348 L .67 .299 0 r
F
.74564 .53244 m .74484 .52577 L .70304 .53686 L F
.61104 .70391 m .56328 .70207 L .56297 .70797 L .837 .28 0 r
F
.61104 .70391 m .61151 .69799 L .56328 .70207 L F
.56226 .71962 m .51372 .71603 L .51353 .72183 L .897 .322 0 r
F
.56226 .71962 m .56263 .71382 L .51372 .71603 L F
.74306 .52548 m .70104 .52995 L .70173 .53654 L .666 .297 0 r
F
.74306 .52548 m .74225 .51886 L .70104 .52995 L F
.68583 .3229 m .65115 .32705 L .65362 .33334 L .743 .594 0 r
F
.6887 .32914 m .68583 .3229 L .65362 .33334 L .741 .585 0 r
F
.59023 .26162 m .55933 .26143 L .56119 .26745 L .863 .776 0 r
F
.59268 .26759 m .59023 .26162 L .56119 .26745 L .863 .769 0 r
F
.59014 .26178 m .5593 .26151 L .56116 .26753 L .861 .773 0 r
F
.59259 .26775 m .59014 .26178 L .56116 .26753 L .86 .766 0 r
F
.27173 .58002 m .22842 .56366 L .22794 .57017 L 1 .802 0 r
F
.2714 .58647 m .27173 .58002 L .22794 .57017 L 1 .793 0 r
F
.26729 .60145 m .2222 .58524 L .22196 .59181 L 1 .763 0 r
F
.26716 .60793 m .26729 .60145 L .22196 .59181 L 1 .754 0 r
F
.31532 .65937 m .26746 .64626 L .26769 .65254 L 1 .647 0 r
F
.31552 .66557 m .31532 .65937 L .26769 .65254 L 1 .639 0 r
F
.62962 .27788 m .59747 .27964 L .59981 .28573 L .812 .71 0 r
F
.63248 .2839 m .62962 .27788 L .59981 .28573 L .812 .702 0 r
F
.68537 .32324 m .65084 .32731 L .65329 .3336 L .74 .589 0 r
F
.68822 .32948 m .68537 .32324 L .65329 .3336 L .738 .581 0 r
F
.70502 .62064 m .66031 .62284 L .66021 .62912 L .712 .239 0 r
F
.70502 .62064 m .70514 .6143 L .66031 .62284 L F
.46441 .71455 m .41534 .70742 L .4155 .71316 L 1 .434 0 r
F
.4644 .72023 m .46441 .71455 L .4155 .71316 L 1 .423 0 r
F
.51318 .71978 m .46441 .71455 L .4644 .72023 L .954 .369 0 r
F
.51318 .71978 m .51338 .71411 L .46441 .71455 L F
.74637 .53909 m .70371 .54348 L .70432 .55009 L .667 .288 0 r
F
.74637 .53909 m .74564 .53244 L .70371 .54348 L F
.62943 .27813 m .59736 .27981 L .59969 .2859 L .81 .706 0 r
F
.63228 .28415 m .62943 .27813 L .59969 .2859 L .809 .699 0 r
F
.70682 .62819 m .6616 .63021 L .66149 .63654 L .716 .242 0 r
F
.70682 .62819 m .70695 .6218 L .6616 .63021 L F
.36607 .68655 m .31803 .67531 L .31835 .68131 L 1 .573 0 r
F
.36631 .69246 m .36607 .68655 L .31835 .68131 L 1 .562 0 r
F
.74381 .53209 m .70173 .53654 L .70235 .54311 L .663 .287 0 r
F
.74381 .53209 m .74306 .52548 L .70173 .53654 L F
.36527 .69455 m .31633 .68396 L .31668 .69002 L 1 .567 0 r
F
.3655 .70055 m .36527 .69455 L .31668 .69002 L 1 .556 0 r
F
.68289 .3167 m .64863 .32078 L .65115 .32705 L .745 .602 0 r
F
.68583 .3229 m .68289 .3167 L .65115 .32705 L .743 .594 0 r
F
.41534 .70742 m .36657 .69833 L .36687 .70416 L 1 .495 0 r
F
.4155 .71316 m .41534 .70742 L .36687 .70416 L 1 .484 0 r
F
.65809 .67217 m .61191 .67237 L .61156 .67837 L .77 .239 0 r
F
.65809 .67217 m .65855 .66613 L .61191 .67237 L F
.46434 .72228 m .415 .71523 L .41515 .72107 L 1 .436 0 r
F
.46433 .72804 m .46434 .72228 L .41515 .72107 L 1 .424 0 r
F
.51333 .72758 m .46434 .72228 L .46433 .72804 L .955 .37 0 r
F
.51333 .72758 m .51353 .72183 L .46434 .72228 L F
.28253 .53251 m .24078 .51666 L .24022 .52297 L .373 .545 0 r
F
.28232 .53868 m .28253 .53251 L .24022 .52297 L 1 .764 0 r
F
.31717 .65094 m .27066 .6373 L .27081 .64353 L 1 .667 0 r
F
.31733 .65708 m .31717 .65094 L .27081 .64353 L 1 .658 0 r
F
.68246 .31703 m .64834 .32104 L .65084 .32731 L .742 .598 0 r
F
.68537 .32324 m .68246 .31703 L .65084 .32731 L .74 .589 0 r
F
.23374 .48501 m .19509 .4659 L .19356 .47263 L .699 .909 0 r
F
.23251 .49174 m .23374 .48501 L .19356 .47263 L 1 .928 0 r
F
.60979 .70192 m .56254 .70029 L .56221 .70608 L .831 .266 0 r
F
.60979 .70192 m .61029 .69609 L .56254 .70029 L F
.2714 .58647 m .22794 .57017 L .22753 .57666 L 1 .793 0 r
F
.27112 .5929 m .2714 .58647 L .22753 .57666 L 1 .785 0 r
F
.415 .71523 m .36577 .70652 L .36606 .71243 L 1 .495 0 r
F
.41515 .72107 m .415 .71523 L .36606 .71243 L 1 .483 0 r
F
.32894 .57438 m .28239 .56279 L .28263 .56864 L .465 .718 0 r
F
.3302 .57929 m .32894 .57438 L .28263 .56864 L 1 .274 0 r
F
.56146 .71751 m .51338 .71411 L .51318 .71978 L .892 .309 0 r
F
.56146 .71751 m .56184 .71182 L .51338 .71411 L F
.65928 .67997 m .61269 .67996 L .61234 .68601 L .774 .242 0 r
F
.65928 .67997 m .65975 .67387 L .61269 .67996 L F
.74703 .54574 m .70432 .55009 L .70487 .55669 L .664 .278 0 r
F
.74703 .54574 m .74637 .53909 L .70432 .55009 L F
.26716 .60793 m .22196 .59181 L .22178 .59837 L 1 .754 0 r
F
.26708 .61438 m .26716 .60793 L .22178 .59837 L 1 .745 0 r
F
.74448 .53869 m .70235 .54311 L .70292 .54967 L .66 .276 0 r
F
.74448 .53869 m .74381 .53209 L .70235 .54311 L F
.55553 .24951 m .52607 .24758 L .52734 .25354 L .905 .831 0 r
F
.55745 .25545 m .55553 .24951 L .52734 .25354 L .906 .825 0 r
F
.5555 .24959 m .52607 .24758 L .52734 .25354 L .903 .829 0 r
F
.55742 .25553 m .5555 .24959 L .52734 .25354 L .903 .822 0 r
F
.61054 .7098 m .56297 .70797 L .56263 .71382 L .834 .268 0 r
F
.61054 .7098 m .61104 .70391 L .56297 .70797 L F
.6799 .31053 m .64606 .31455 L .64863 .32078 L .746 .611 0 r
F
.68289 .3167 m .6799 .31053 L .64863 .32078 L .745 .602 0 r
F
.23251 .49174 m .19356 .47263 L .19211 .47937 L 1 .928 0 r
F
.23135 .49846 m .23251 .49174 L .19211 .47937 L 1 .921 0 r
F
.33455 .28662 m .33712 .28055 L .3078 .27214 L 1 1 0 r
F
.62671 .2719 m .59509 .2736 L .59747 .27964 L .813 .717 0 r
F
.62962 .27788 m .62671 .2719 L .59747 .27964 L .812 .71 0 r
F
.56187 .72538 m .51353 .72183 L .51333 .72758 L .894 .311 0 r
F
.56187 .72538 m .56226 .71962 L .51353 .72183 L F
.58774 .25569 m .55745 .25545 L .55933 .26143 L .863 .783 0 r
F
.59023 .26162 m .58774 .25569 L .55933 .26143 L .863 .776 0 r
F
.70484 .62695 m .66021 .62912 L .66006 .63537 L .708 .228 0 r
F
.70484 .62695 m .70502 .62064 L .66021 .62912 L F
.62653 .27214 m .59499 .27376 L .59736 .27981 L .811 .714 0 r
F
.62943 .27813 m .62653 .27214 L .59736 .27981 L .81 .706 0 r
F
.70662 .63455 m .66149 .63654 L .66132 .64285 L .713 .231 0 r
F
.70662 .63455 m .70682 .62819 L .66149 .63654 L F
.58766 .25584 m .55742 .25553 L .5593 .26151 L .861 .78 0 r
F
.59014 .26178 m .58766 .25584 L .5593 .26151 L .861 .773 0 r
F
.31552 .66557 m .26769 .65254 L .26798 .6588 L 1 .639 0 r
F
.31575 .67173 m .31552 .66557 L .26798 .6588 L 1 .63 0 r
F
.3347 .28683 m .33727 .28077 L .308 .27239 L 1 1 0 r
F
.67949 .31086 m .64579 .31481 L .64834 .32104 L .743 .607 0 r
F
.68246 .31703 m .67949 .31086 L .64834 .32104 L .742 .598 0 r
F
.28232 .53868 m .24022 .52297 L .23975 .52926 L 1 .764 0 r
F
.2822 .5448 m .28232 .53868 L .23975 .52926 L 1 .747 0 r
F
.74762 .55237 m .70487 .55669 L .70536 .56328 L .661 .267 0 r
F
.74762 .55237 m .74703 .54574 L .70487 .55669 L F
.23135 .49846 m .19211 .47937 L .19073 .48612 L 1 .921 0 r
F
.23026 .50519 m .23135 .49846 L .19073 .48612 L 1 .914 0 r
F
.27112 .5929 m .22753 .57666 L .22718 .58314 L 1 .785 0 r
F
.27089 .59932 m .27112 .5929 L .22718 .58314 L 1 .776 0 r
F
.74508 .54528 m .70292 .54967 L .70342 .55622 L .656 .266 0 r
F
.74508 .54528 m .74448 .53869 L .70292 .54967 L F
.36631 .69246 m .31835 .68131 L .31872 .68727 L 1 .562 0 r
F
.36657 .69833 m .36631 .69246 L .31872 .68727 L 1 .551 0 r
F
.4644 .72023 m .4155 .71316 L .41567 .71885 L 1 .423 0 r
F
.46439 .72586 m .4644 .72023 L .41567 .71885 L 1 .411 0 r
F
.51297 .72541 m .4644 .72023 L .46439 .72586 L .951 .357 0 r
F
.51297 .72541 m .51318 .71978 L .4644 .72023 L F
.67685 .30439 m .64345 .30835 L .64606 .31455 L .748 .619 0 r
F
.6799 .31053 m .67685 .30439 L .64606 .31455 L .746 .611 0 r
F
.3655 .70055 m .31668 .69002 L .31708 .69604 L 1 .556 0 r
F
.36577 .70652 m .3655 .70055 L .31708 .69604 L 1 .545 0 r
F
.31733 .65708 m .27081 .64353 L .27102 .64974 L 1 .658 0 r
F
.31752 .66319 m .31733 .65708 L .27102 .64974 L 1 .647 0 r
F
.65758 .67817 m .61156 .67837 L .61118 .68432 L .767 .228 0 r
F
.65758 .67817 m .65809 .67217 L .61156 .67837 L F
.26708 .61438 m .22178 .59837 L .22167 .6049 L 1 .745 0 r
F
.26706 .62081 m .26708 .61438 L .22167 .6049 L 1 .736 0 r
F
.23026 .50519 m .19073 .48612 L .18943 .49286 L 1 .914 0 r
F
.22922 .51191 m .23026 .50519 L .18943 .49286 L 1 .907 0 r
F
.4155 .71316 m .36687 .70416 L .3672 .70993 L 1 .484 0 r
F
.41567 .71885 m .4155 .71316 L .3672 .70993 L 1 .472 0 r
F
.67645 .30473 m .64319 .30861 L .64579 .31481 L .745 .615 0 r
F
.67949 .31086 m .67645 .30473 L .64579 .31481 L .743 .607 0 r
F
.65876 .68603 m .61234 .68601 L .61194 .69202 L .77 .23 0 r
F
.65876 .68603 m .65928 .67997 L .61234 .68601 L F
.33712 .28055 m .31099 .26625 L .3078 .27214 L 1 1 0 r
F
.33712 .28055 m .33973 .27453 L .31099 .26625 L F
.46433 .72804 m .41515 .72107 L .41532 .72686 L 1 .424 0 r
F
.46431 .73376 m .46433 .72804 L .41532 .72686 L 1 .412 0 r
F
.51312 .73328 m .46433 .72804 L .46431 .73376 L .951 .358 0 r
F
.51312 .73328 m .51333 .72758 L .46433 .72804 L F
.74813 .559 m .70536 .56328 L .70578 .56986 L .657 .257 0 r
F
.74813 .559 m .74762 .55237 L .70536 .56328 L F
.60926 .70769 m .56221 .70608 L .56184 .71182 L .828 .254 0 r
F
.60926 .70769 m .60979 .70192 L .56221 .70608 L F
.62375 .26596 m .59268 .26759 L .59509 .2736 L .814 .725 0 r
F
.62671 .2719 m .62375 .26596 L .59509 .2736 L .813 .717 0 r
F
.37863 .25705 m .38079 .25114 L .35337 .24512 L 1 1 0 r
F
.41515 .72107 m .36606 .71243 L .36639 .7183 L 1 .483 0 r
F
.41532 .72686 m .41515 .72107 L .36639 .7183 L 1 .471 0 r
F
.33727 .28077 m .31118 .26651 L .308 .27239 L 1 1 0 r
F
.33727 .28077 m .33987 .27475 L .31118 .26651 L F
.70459 .63322 m .66006 .63537 L .65986 .64159 L .705 .217 0 r
F
.70459 .63322 m .70484 .62695 L .66006 .63537 L F
.62358 .2662 m .59259 .26775 L .59499 .27376 L .812 .722 0 r
F
.62653 .27214 m .62358 .2662 L .59499 .27376 L .811 .714 0 r
F
.7456 .55185 m .70342 .55622 L .70386 .56275 L .653 .255 0 r
F
.7456 .55185 m .74508 .54528 L .70342 .55622 L F
.56104 .72315 m .51318 .71978 L .51297 .72541 L .889 .297 0 r
F
.56104 .72315 m .56146 .71751 L .51318 .71978 L F
.37871 .25723 m .38086 .25132 L .35349 .24536 L 1 1 0 r
F
.70636 .64089 m .66132 .64285 L .66111 .64912 L .709 .219 0 r
F
.70636 .64089 m .70662 .63455 L .66132 .64285 L F
.2822 .5448 m .23975 .52926 L .23934 .53551 L 1 .747 0 r
F
.28217 .55086 m .2822 .5448 L .23934 .53551 L 1 .728 0 r
F
.22922 .51191 m .18943 .49286 L .18821 .49961 L 1 .907 0 r
F
.22826 .51862 m .22922 .51191 L .18821 .49961 L 1 .9 0 r
F
.27089 .59932 m .22718 .58314 L .2269 .58961 L 1 .776 0 r
F
.27072 .60571 m .27089 .59932 L .2269 .58961 L 1 .767 0 r
F
.67373 .2983 m .64078 .30218 L .64345 .30835 L .75 .628 0 r
F
.67685 .30439 m .67373 .2983 L .64345 .30835 L .748 .619 0 r
F
.55359 .24361 m .52479 .24165 L .52607 .24758 L .905 .837 0 r
F
.55553 .24951 m .55359 .24361 L .52607 .24758 L .905 .831 0 r
F
.55356 .24369 m .52479 .24165 L .52607 .24758 L .902 .835 0 r
F
.5555 .24959 m .55356 .24369 L .52607 .24758 L .903 .829 0 r
F
.31575 .67173 m .26798 .6588 L .26832 .66502 L 1 .63 0 r
F
.31602 .67787 m .31575 .67173 L .26832 .66502 L 1 .62 0 r
F
.58521 .2498 m .55553 .24951 L .55745 .25545 L .863 .79 0 r
F
.58774 .25569 m .58521 .2498 L .55745 .25545 L .863 .783 0 r
F
.60999 .71564 m .56263 .71382 L .56226 .71962 L .83 .256 0 r
F
.60999 .71564 m .61054 .7098 L .56263 .71382 L F
.58513 .24995 m .5555 .24959 L .55742 .25553 L .861 .787 0 r
F
.58766 .25584 m .58513 .24995 L .55742 .25553 L .861 .78 0 r
F
.67336 .29863 m .64053 .30244 L .64319 .30861 L .747 .624 0 r
F
.67645 .30473 m .67336 .29863 L .64319 .30861 L .745 .615 0 r
F
.56145 .73109 m .51333 .72758 L .51312 .73328 L .891 .299 0 r
F
.56145 .73109 m .56187 .72538 L .51333 .72758 L F
.3302 .57929 m .28263 .56864 L .28296 .57443 L 1 .274 0 r
F
.33176 .58387 m .3302 .57929 L .28296 .57443 L .98 .15 0 r
F
.74857 .56561 m .70578 .56986 L .70615 .57642 L .654 .246 0 r
F
.74857 .56561 m .74813 .559 L .70578 .56986 L F
.22826 .51862 m .18821 .49961 L .18706 .50636 L 1 .9 0 r
F
.22735 .52533 m .22826 .51862 L .18706 .50636 L 1 .892 0 r
F
.26706 .62081 m .22167 .6049 L .22163 .61141 L 1 .736 0 r
F
.26708 .62721 m .26706 .62081 L .22163 .61141 L 1 .727 0 r
F
.31752 .66319 m .27102 .64974 L .27128 .65591 L 1 .647 0 r
F
.31776 .66927 m .31752 .66319 L .27128 .65591 L 1 .637 0 r
F
.74606 .55841 m .70386 .56275 L .70424 .56927 L .649 .244 0 r
F
.74606 .55841 m .7456 .55185 L .70386 .56275 L F
.36657 .69833 m .31872 .68727 L .31912 .69319 L 1 .551 0 r
F
.36687 .70416 m .36657 .69833 L .31912 .69319 L 1 .54 0 r
F
.33973 .27453 m .31423 .26042 L .31099 .26625 L 1 1 0 r
F
.33973 .27453 m .34238 .26856 L .31423 .26042 L F
.36577 .70652 m .31708 .69604 L .31751 .70202 L 1 .545 0 r
F
.36606 .71243 m .36577 .70652 L .31751 .70202 L 1 .533 0 r
F
.67056 .29224 m .63806 .29605 L .64078 .30218 L .751 .636 0 r
F
.67373 .2983 m .67056 .29224 L .64078 .30218 L .75 .628 0 r
F
.65703 .68413 m .61118 .68432 L .61075 .69023 L .763 .216 0 r
F
.65703 .68413 m .65758 .67817 L .61118 .68432 L F
.33987 .27475 m .31442 .26069 L .31118 .26651 L 1 1 0 r
F
.33987 .27475 m .34252 .26878 L .31442 .26069 L F
.28217 .55086 m .23934 .53551 L .23902 .54174 L 1 .728 0 r
F
.28224 .55686 m .28217 .55086 L .23902 .54174 L 1 .708 0 r
F
.27072 .60571 m .2269 .58961 L .22669 .59605 L 1 .767 0 r
F
.2706 .61208 m .27072 .60571 L .22669 .59605 L 1 .758 0 r
F
.62074 .26006 m .59023 .26162 L .59268 .26759 L .815 .732 0 r
F
.62375 .26596 m .62074 .26006 L .59268 .26759 L .814 .725 0 r
F
.46439 .72586 m .41567 .71885 L .41586 .7245 L 1 .411 0 r
F
.46438 .73143 m .46439 .72586 L .41586 .7245 L 1 .4 0 r
F
.51274 .73098 m .46439 .72586 L .46438 .73143 L .948 .345 0 r
F
.51274 .73098 m .51297 .72541 L .46439 .72586 L F
.70428 .63947 m .65986 .64159 L .65961 .64778 L .701 .206 0 r
F
.70428 .63947 m .70459 .63322 L .65986 .64159 L F
.67021 .29257 m .63783 .29631 L .64053 .30244 L .749 .632 0 r
F
.67336 .29863 m .67021 .29257 L .64053 .30244 L .747 .624 0 r
F
.62059 .2603 m .59014 .26178 L .59259 .26775 L .812 .729 0 r
F
.62358 .2662 m .62059 .2603 L .59259 .26775 L .812 .722 0 r
F
.65819 .69205 m .61194 .69202 L .61151 .69799 L .767 .219 0 r
F
.65819 .69205 m .65876 .68603 L .61194 .69202 L F
.22735 .52533 m .18706 .50636 L .18599 .51311 L 1 .892 0 r
F
.22652 .53204 m .22735 .52533 L .18599 .51311 L 1 .885 0 r
F
.70603 .64719 m .66111 .64912 L .66085 .65536 L .706 .208 0 r
F
.70603 .64719 m .70636 .64089 L .66111 .64912 L F
.41567 .71885 m .3672 .70993 L .36755 .71567 L 1 .472 0 r
F
.41586 .7245 m .41567 .71885 L .36755 .71567 L 1 .461 0 r
F
.38079 .25114 m .35621 .23939 L .35337 .24512 L 1 1 0 r
F
.38079 .25114 m .38298 .24527 L .35621 .23939 L F
.38086 .25132 m .35633 .23963 L .35349 .24536 L F
.38086 .25132 m .38305 .24546 L .35633 .23963 L F
.74893 .57221 m .70615 .57642 L .70645 .58296 L .651 .235 0 r
F
.74893 .57221 m .74857 .56561 L .70615 .57642 L F
.60868 .71342 m .56184 .71182 L .56146 .71751 L .824 .243 0 r
F
.60868 .71342 m .60926 .70769 L .56184 .71182 L F
.46431 .73376 m .41532 .72686 L .41551 .7326 L 1 .412 0 r
F
.46431 .73942 m .46431 .73376 L .41551 .7326 L 1 .399 0 r
F
.5129 .73893 m .46431 .73376 L .46431 .73942 L .948 .346 0 r
F
.5129 .73893 m .51312 .73328 L .46431 .73376 L F
.31602 .67787 m .26832 .66502 L .26871 .67121 L 1 .62 0 r
F
.31633 .68396 m .31602 .67787 L .26871 .67121 L 1 .61 0 r
F
.74643 .56496 m .70424 .56927 L .70455 .57577 L .646 .233 0 r
F
.74643 .56496 m .74606 .55841 L .70424 .56927 L F
.41532 .72686 m .36639 .7183 L .36675 .72411 L 1 .471 0 r
F
.41551 .7326 m .41532 .72686 L .36675 .72411 L 1 .458 0 r
F
.23913 .48491 m .20196 .46627 L .20041 .47283 L 1 .946 0 r
F
.23789 .49149 m .23913 .48491 L .20041 .47283 L 1 .939 0 r
F
.58264 .24395 m .55359 .24361 L .55553 .24951 L .863 .797 0 r
F
.58521 .2498 m .58264 .24395 L .55553 .24951 L .863 .79 0 r
F
.56061 .72874 m .51297 .72541 L .51274 .73098 L .886 .285 0 r
F
.56061 .72874 m .56104 .72315 L .51297 .72541 L F
.58257 .2441 m .55356 .24369 L .5555 .24959 L .861 .794 0 r
F
.58513 .24995 m .58257 .2441 L .5555 .24959 L .861 .787 0 r
F
.26708 .62721 m .22163 .61141 L .22166 .6179 L 1 .727 0 r
F
.26716 .63359 m .26708 .62721 L .22166 .6179 L 1 .718 0 r
F
.66733 .28622 m .63529 .28996 L .63806 .29605 L .753 .644 0 r
F
.67056 .29224 m .66733 .28622 L .63806 .29605 L .751 .636 0 r
F
.55162 .23775 m .52349 .23577 L .52479 .24165 L .904 .844 0 r
F
.55359 .24361 m .55162 .23775 L .52479 .24165 L .905 .837 0 r
F
.55159 .23783 m .52349 .23577 L .52479 .24165 L .902 .841 0 r
F
.55356 .24369 m .55159 .23783 L .52479 .24165 L .902 .835 0 r
F
.22652 .53204 m .18599 .51311 L .18499 .51985 L 1 .885 0 r
F
.22575 .53873 m .22652 .53204 L .18499 .51985 L 1 .877 0 r
F
.6094 .72143 m .56226 .71962 L .56187 .72538 L .827 .244 0 r
F
.6094 .72143 m .60999 .71564 L .56226 .71962 L F
.23789 .49149 m .20041 .47283 L .19894 .4794 L 1 .939 0 r
F
.23671 .49806 m .23789 .49149 L .19894 .4794 L 1 .932 0 r
F
.667 .28655 m .63508 .29021 L .63783 .29631 L .75 .641 0 r
F
.67021 .29257 m .667 .28655 L .63783 .29631 L .749 .632 0 r
F
.34238 .26856 m .31751 .25463 L .31423 .26042 L 1 1 0 r
F
.34238 .26856 m .34507 .26262 L .31751 .25463 L F
.31776 .66927 m .27128 .65591 L .27159 .66205 L 1 .637 0 r
F
.31803 .67531 m .31776 .66927 L .27159 .66205 L 1 .627 0 r
F
.2706 .61208 m .22669 .59605 L .22654 .60248 L 1 .758 0 r
F
.27053 .61842 m .2706 .61208 L .22654 .60248 L 1 .749 0 r
F
.28224 .55686 m .23902 .54174 L .23877 .54793 L 1 .708 0 r
F
.28239 .56279 m .28224 .55686 L .23877 .54793 L 1 .687 0 r
F
.56101 .73676 m .51312 .73328 L .5129 .73893 L .887 .286 0 r
F
.56101 .73676 m .56145 .73109 L .51312 .73328 L F
.34252 .26878 m .31771 .25491 L .31442 .26069 L 1 1 0 r
F
.34252 .26878 m .3452 .26285 L .31771 .25491 L F
.74922 .5788 m .70645 .58296 L .70669 .58949 L .647 .224 0 r
F
.74922 .5788 m .74893 .57221 L .70645 .58296 L F
.61769 .25421 m .58774 .25569 L .59023 .26162 L .815 .74 0 r
F
.62074 .26006 m .61769 .25421 L .59023 .26162 L .815 .732 0 r
F
.23671 .49806 m .19894 .4794 L .19755 .48598 L 1 .932 0 r
F
.2356 .50464 m .23671 .49806 L .19755 .48598 L 1 .925 0 r
F
.7039 .64568 m .65961 .64778 L .65931 .65393 L .698 .194 0 r
F
.7039 .64568 m .70428 .63947 L .65961 .64778 L F
.36687 .70416 m .31912 .69319 L .31957 .69907 L 1 .54 0 r
F
.3672 .70993 m .36687 .70416 L .31957 .69907 L 1 .529 0 r
F
.74674 .57149 m .70455 .57577 L .70481 .58225 L .642 .222 0 r
F
.74674 .57149 m .74643 .56496 L .70455 .57577 L F
.61754 .25444 m .58766 .25584 L .59014 .26178 L .813 .737 0 r
F
.62059 .2603 m .61754 .25444 L .59014 .26178 L .812 .729 0 r
F
.33804 .29156 m .34055 .28566 L .31265 .27832 L 1 1 0 r
F
.65642 .69005 m .61075 .69023 L .61029 .69609 L .759 .205 0 r
F
.65642 .69005 m .65703 .68413 L .61075 .69023 L F
.36606 .71243 m .31751 .70202 L .31799 .70795 L 1 .533 0 r
F
.36639 .7183 m .36606 .71243 L .31799 .70795 L 1 .522 0 r
F
.70564 .65346 m .66085 .65536 L .66053 .66156 L .702 .197 0 r
F
.70564 .65346 m .70603 .64719 L .66085 .65536 L F
.22575 .53873 m .18499 .51985 L .18408 .52659 L 1 .877 0 r
F
.22504 .54542 m .22575 .53873 L .18408 .52659 L 1 .869 0 r
F
.66405 .28024 m .63248 .2839 L .63529 .28996 L .754 .653 0 r
F
.66733 .28622 m .66405 .28024 L .63529 .28996 L .753 .644 0 r
F
.65756 .69803 m .61151 .69799 L .61104 .70391 L .763 .207 0 r
F
.65756 .69803 m .65819 .69205 L .61151 .69799 L F
.38298 .24527 m .3591 .2337 L .35621 .23939 L 1 1 0 r
F
.38298 .24527 m .38519 .23945 L .3591 .2337 L F
.2356 .50464 m .19755 .48598 L .19623 .49257 L 1 .925 0 r
F
.23454 .51122 m .2356 .50464 L .19623 .49257 L 1 .918 0 r
F
.46438 .73143 m .41586 .7245 L .41606 .7301 L 1 .4 0 r
F
.46437 .73696 m .46438 .73143 L .41606 .7301 L 1 .388 0 r
F
.51251 .7365 m .46438 .73143 L .46437 .73696 L .945 .333 0 r
F
.51251 .7365 m .51274 .73098 L .46438 .73143 L F
.66374 .28056 m .63228 .28415 L .63508 .29021 L .752 .649 0 r
F
.667 .28655 m .66374 .28056 L .63508 .29021 L .75 .641 0 r
F
.38305 .24546 m .35921 .23396 L .35633 .23963 L 1 1 0 r
F
.38305 .24546 m .38526 .23964 L .35921 .23396 L F
.26716 .63359 m .22166 .6179 L .22175 .62436 L 1 .718 0 r
F
.26728 .63994 m .26716 .63359 L .22175 .62436 L 1 .708 0 r
F
.41586 .7245 m .36755 .71567 L .36793 .72135 L 1 .461 0 r
F
.41606 .7301 m .41586 .7245 L .36793 .72135 L 1 .449 0 r
F
.31633 .68396 m .26871 .67121 L .26915 .67737 L 1 .61 0 r
F
.31668 .69002 m .31633 .68396 L .26915 .67737 L 1 .6 0 r
F
.38068 .26198 m .38279 .25619 L .35644 .25123 L 1 1 0 r
F
.27053 .61842 m .22654 .60248 L .22646 .60888 L 1 .749 0 r
F
.27052 .62474 m .27053 .61842 L .22646 .60888 L 1 .739 0 r
F
.60807 .7191 m .56146 .71751 L .56104 .72315 L .821 .23 0 r
F
.60807 .7191 m .60868 .71342 L .56146 .71751 L F
.33176 .58387 m .28296 .57443 L .28336 .58014 L .98 .15 0 r
F
.33358 .5881 m .33176 .58387 L .28336 .58014 L .902 .072 0 r
F
.58004 .23815 m .55162 .23775 L .55359 .24361 L .863 .804 0 r
F
.58264 .24395 m .58004 .23815 L .55359 .24361 L .863 .797 0 r
F
.27174 .37604 m .24148 .35871 L .23887 .36488 L 1 1 0 r
F
.74944 .58537 m .70669 .58949 L .70687 .59599 L .644 .213 0 r
F
.74944 .58537 m .74922 .5788 L .70669 .58949 L F
.22504 .54542 m .18408 .52659 L .18324 .53332 L 1 .869 0 r
F
.2244 .55209 m .22504 .54542 L .18324 .53332 L 1 .861 0 r
F
.34507 .26262 m .32085 .2489 L .31751 .25463 L 1 1 0 r
F
.34507 .26262 m .3478 .25674 L .32085 .2489 L F
.57998 .2383 m .55159 .23783 L .55356 .24369 L .86 .801 0 r
F
.58257 .2441 m .57998 .2383 L .55356 .24369 L .861 .794 0 r
F
.46431 .73942 m .41551 .7326 L .41571 .73829 L 1 .399 0 r
F
.4643 .74503 m .46431 .73942 L .41571 .73829 L 1 .387 0 r
F
.51266 .74453 m .46431 .73942 L .4643 .74503 L .945 .334 0 r
F
.51266 .74453 m .5129 .73893 L .46431 .73942 L F
.23454 .51122 m .19623 .49257 L .19498 .49916 L 1 .918 0 r
F
.23355 .51779 m .23454 .51122 L .19498 .49916 L 1 .911 0 r
F
.41551 .7326 m .36675 .72411 L .36714 .72987 L 1 .458 0 r
F
.41571 .73829 m .41551 .7326 L .36714 .72987 L 1 .446 0 r
F
.28239 .56279 m .23877 .54793 L .2386 .55409 L 1 .687 0 r
F
.28263 .56864 m .28239 .56279 L .2386 .55409 L 1 .666 0 r
F
.74697 .578 m .70481 .58225 L .705 .58871 L .639 .21 0 r
F
.74697 .578 m .74674 .57149 L .70481 .58225 L F
.3452 .26285 m .32104 .24919 L .31771 .25491 L 1 1 0 r
F
.3452 .26285 m .34793 .25697 L .32104 .24919 L F
.33896 .29286 m .31406 .28011 L .31098 .28575 L F
.33896 .29286 m .34145 .28699 L .31406 .28011 L F
.31803 .67531 m .27159 .66205 L .27196 .66815 L 1 .627 0 r
F
.31835 .68131 m .31803 .67531 L .27196 .66815 L 1 .616 0 r
F
.56014 .73428 m .51274 .73098 L .51251 .7365 L .882 .273 0 r
F
.56014 .73428 m .56061 .72874 L .51274 .73098 L F
.54962 .23193 m .52217 .22993 L .52349 .23577 L .903 .85 0 r
F
.55162 .23775 m .54962 .23193 L .52349 .23577 L .904 .844 0 r
F
.5496 .23201 m .52217 .22993 L .52349 .23577 L .901 .848 0 r
F
.55159 .23783 m .5496 .23201 L .52349 .23577 L .902 .841 0 r
F
.34055 .28566 m .31578 .27266 L .31265 .27832 L 1 1 0 r
F
.34055 .28566 m .34311 .27981 L .31578 .27266 L F
.29259 .30225 m .29553 .29614 L .26638 .28553 L F
.60878 .72717 m .56187 .72538 L .56145 .73109 L .823 .232 0 r
F
.60878 .72717 m .6094 .72143 L .56187 .72538 L F
.6607 .2743 m .62962 .27788 L .63248 .2839 L .756 .661 0 r
F
.66405 .28024 m .6607 .2743 L .63248 .2839 L .754 .653 0 r
F
.61459 .2484 m .58521 .2498 L .58774 .25569 L .816 .747 0 r
F
.61769 .25421 m .61459 .2484 L .58774 .25569 L .815 .74 0 r
F
.70346 .65186 m .65931 .65393 L .65895 .66005 L .694 .182 0 r
F
.70346 .65186 m .7039 .64568 L .65931 .65393 L F
.29281 .30247 m .29575 .29637 L .26661 .28575 L 1 1 0 r
F
.61446 .24862 m .58513 .24995 L .58766 .25584 L .814 .745 0 r
F
.61754 .25444 m .61446 .24862 L .58766 .25584 L .813 .737 0 r
F
.38109 .26297 m .3572 .25275 L .35447 .25833 L 1 1 0 r
F
.38109 .26297 m .38318 .25718 L .3572 .25275 L F
.66041 .27462 m .62943 .27813 L .63228 .28415 L .753 .658 0 r
F
.66374 .28056 m .66041 .27462 L .63228 .28415 L .752 .649 0 r
F
.70518 .6597 m .66053 .66156 L .66017 .66774 L .698 .185 0 r
F
.70518 .6597 m .70564 .65346 L .66053 .66156 L F
.23355 .51779 m .19498 .49916 L .1938 .50575 L 1 .911 0 r
F
.23263 .52437 m .23355 .51779 L .1938 .50575 L 1 .903 0 r
F
.75264 .39305 m .71623 .39962 L .71834 .40617 L .638 .416 0 r
F
.75501 .39958 m .71834 .40617 L .7204 .41273 L .635 .406 0 r
F
.75501 .39958 m .75264 .39305 L .71834 .40617 L F
.7573 .40613 m .7204 .41273 L .72238 .41931 L .632 .396 0 r
F
.7573 .40613 m .75501 .39958 L .7204 .41273 L F
.56054 .74237 m .5129 .73893 L .51266 .74453 L .883 .274 0 r
F
.56054 .74237 m .56101 .73676 L .5129 .73893 L F
.7502 .38655 m .71404 .3931 L .71623 .39962 L .641 .426 0 r
F
.75264 .39305 m .7502 .38655 L .71623 .39962 L .638 .416 0 r
F
.75952 .41269 m .72238 .41931 L .7243 .42591 L .629 .386 0 r
F
.75952 .41269 m .7573 .40613 L .72238 .41931 L F
.65575 .69592 m .61029 .69609 L .60979 .70192 L .756 .193 0 r
F
.65575 .69592 m .65642 .69005 L .61029 .69609 L F
.2244 .55209 m .18324 .53332 L .18247 .54005 L 1 .861 0 r
F
.22383 .55875 m .2244 .55209 L .18247 .54005 L 1 .852 0 r
F
.74768 .38007 m .71179 .38659 L .71404 .3931 L .644 .436 0 r
F
.7502 .38655 m .74768 .38007 L .71404 .3931 L .641 .426 0 r
F
.3672 .70993 m .31957 .69907 L .32005 .7049 L 1 .529 0 r
F
.36755 .71567 m .3672 .70993 L .32005 .7049 L 1 .517 0 r
F
.76166 .41928 m .7243 .42591 L .72615 .43252 L .626 .376 0 r
F
.76166 .41928 m .75952 .41269 L .7243 .42591 L F
.74508 .37361 m .70948 .38011 L .71179 .38659 L .647 .446 0 r
F
.74768 .38007 m .74508 .37361 L .71179 .38659 L .644 .436 0 r
F
.36639 .7183 m .31799 .70795 L .31851 .71385 L 1 .522 0 r
F
.36675 .72411 m .36639 .7183 L .31851 .71385 L 1 .51 0 r
F
.26728 .63994 m .22175 .62436 L .2219 .63079 L 1 .708 0 r
F
.26746 .64626 m .26728 .63994 L .2219 .63079 L 1 .698 0 r
F
.76372 .42588 m .72615 .43252 L .72794 .43914 L .623 .366 0 r
F
.76372 .42588 m .76166 .41928 L .72615 .43252 L F
.74958 .59191 m .70687 .59599 L .70698 .60248 L .64 .202 0 r
F
.74958 .59191 m .74944 .58537 L .70687 .59599 L F
.27052 .62474 m .22646 .60888 L .22645 .61526 L 1 .739 0 r
F
.27057 .63104 m .27052 .62474 L .22645 .61526 L 1 .73 0 r
F
.74242 .36718 m .7071 .37364 L .70948 .38011 L .65 .456 0 r
F
.74508 .37361 m .74242 .36718 L .70948 .38011 L .647 .446 0 r
F
.74712 .58449 m .705 .58871 L .70513 .59514 L .635 .199 0 r
F
.74712 .58449 m .74697 .578 L .705 .58871 L F
.65689 .70397 m .61104 .70391 L .61054 .7098 L .759 .195 0 r
F
.65689 .70397 m .65756 .69803 L .61104 .70391 L F
.29553 .29614 m .26989 .2796 L .26638 .28553 L 1 1 0 r
F
.29553 .29614 m .29852 .29007 L .26989 .2796 L F
.76571 .4325 m .72794 .43914 L .72965 .44577 L .619 .355 0 r
F
.76571 .4325 m .76372 .42588 L .72794 .43914 L F
.38519 .23945 m .36201 .22808 L .3591 .2337 L 1 1 0 r
F
.38519 .23945 m .38744 .23368 L .36201 .22808 L F
.23263 .52437 m .1938 .50575 L .1927 .51234 L 1 .903 0 r
F
.23177 .53093 m .23263 .52437 L .1927 .51234 L 1 .896 0 r
F
.75152 .3934 m .71539 .3999 L .71747 .40643 L .633 .409 0 r
F
.75383 .39991 m .71747 .40643 L .71948 .41298 L .63 .398 0 r
F
.75383 .39991 m .75152 .3934 L .71747 .40643 L F
.74912 .38691 m .71324 .39339 L .71539 .3999 L .636 .419 0 r
F
.75152 .3934 m .74912 .38691 L .71539 .3999 L .633 .409 0 r
F
.73968 .36078 m .70466 .3672 L .7071 .37364 L .652 .466 0 r
F
.74242 .36718 m .73968 .36078 L .7071 .37364 L .65 .456 0 r
F
.75607 .40645 m .71948 .41298 L .72142 .41955 L .627 .388 0 r
F
.75607 .40645 m .75383 .39991 L .71948 .41298 L F
.38526 .23964 m .36213 .22833 L .35921 .23396 L 1 1 0 r
F
.38526 .23964 m .3875 .23387 L .36213 .22833 L F
.31668 .69002 m .26915 .67737 L .26965 .68348 L 1 .6 0 r
F
.31708 .69604 m .31668 .69002 L .26965 .68348 L 1 .59 0 r
F
.34145 .28699 m .31718 .27452 L .31406 .28011 L 1 1 0 r
F
.34145 .28699 m .34397 .28117 L .31718 .27452 L F
.74665 .38044 m .71103 .38689 L .71324 .39339 L .639 .429 0 r
F
.74912 .38691 m .74665 .38044 L .71324 .39339 L .636 .419 0 r
F
.29575 .29637 m .27012 .27983 L .26661 .28575 L 1 1 0 r
F
.29575 .29637 m .29873 .2903 L .27012 .27983 L F
.3478 .25674 m .32423 .24322 L .32085 .2489 L F
.3478 .25674 m .35056 .25091 L .32423 .24322 L F
.38279 .25619 m .35922 .24567 L .35644 .25123 L F
.38279 .25619 m .38492 .25043 L .35922 .24567 L F
.75823 .413 m .72142 .41955 L .7233 .42612 L .624 .377 0 r
F
.75823 .413 m .75607 .40645 L .72142 .41955 L F
.28263 .56864 m .2386 .55409 L .23849 .56021 L 1 .666 0 r
F
.28296 .57443 m .28263 .56864 L .23849 .56021 L 1 .644 0 r
F
.76761 .43914 m .72965 .44577 L .7313 .45241 L .616 .345 0 r
F
.76761 .43914 m .76571 .4325 L .72965 .44577 L F
.7441 .37399 m .70875 .38041 L .71103 .38689 L .643 .439 0 r
F
.74665 .38044 m .7441 .37399 L .71103 .38689 L .639 .429 0 r
F
.65731 .26841 m .62671 .2719 L .62962 .27788 L .757 .669 0 r
F
.6607 .2743 m .65731 .26841 L .62962 .27788 L .756 .661 0 r
F
.34311 .27981 m .31896 .26705 L .31578 .27266 L 1 1 0 r
F
.34311 .27981 m .3457 .274 L .31896 .26705 L F
.76032 .41956 m .7233 .42612 L .72511 .43271 L .62 .367 0 r
F
.76032 .41956 m .75823 .413 L .7233 .42612 L F
.46437 .73696 m .41606 .7301 L .41628 .73564 L 1 .388 0 r
F
.46437 .74243 m .46437 .73696 L .41628 .73564 L 1 .375 0 r
F
.51226 .74197 m .46437 .73696 L .46437 .74243 L .941 .321 0 r
F
.51226 .74197 m .51251 .7365 L .46437 .73696 L F
.34793 .25697 m .32442 .24353 L .32104 .24919 L 1 1 0 r
F
.34793 .25697 m .35069 .25114 L .32442 .24353 L F
.73686 .35441 m .70216 .36079 L .70466 .3672 L .655 .476 0 r
F
.73968 .36078 m .73686 .35441 L .70466 .3672 L .652 .466 0 r
F
.74148 .36757 m .70641 .37396 L .70875 .38041 L .646 .449 0 r
F
.7441 .37399 m .74148 .36757 L .70875 .38041 L .643 .439 0 r
F
.41606 .7301 m .36793 .72135 L .36834 .72699 L 1 .449 0 r
F
.41628 .73564 m .41606 .7301 L .36834 .72699 L 1 .437 0 r
F
.65703 .26873 m .62653 .27214 L .62943 .27813 L .755 .666 0 r
F
.66041 .27462 m .65703 .26873 L .62943 .27813 L .753 .658 0 r
F
.76232 .42615 m .72511 .43271 L .72685 .43931 L .617 .356 0 r
F
.76232 .42615 m .76032 .41956 L .72511 .43271 L F
.76944 .44579 m .7313 .45241 L .73288 .45906 L .613 .334 0 r
F
.76944 .44579 m .76761 .43914 L .7313 .45241 L F
.5774 .23239 m .54962 .23193 L .55162 .23775 L .862 .81 0 r
F
.58004 .23815 m .5774 .23239 L .55162 .23775 L .863 .804 0 r
F
.22383 .55875 m .18247 .54005 L .18179 .54677 L 1 .852 0 r
F
.22332 .5654 m .22383 .55875 L .18179 .54677 L 1 .844 0 r
F
.57734 .23254 m .5496 .23201 L .55159 .23783 L .86 .808 0 r
F
.57998 .2383 m .57734 .23254 L .55159 .23783 L .86 .801 0 r
F
.73879 .36118 m .704 .36752 L .70641 .37396 L .648 .459 0 r
F
.74148 .36757 m .73879 .36118 L .70641 .37396 L .646 .449 0 r
F
.60741 .72473 m .56104 .72315 L .56061 .72874 L .817 .218 0 r
F
.60741 .72473 m .60807 .7191 L .56104 .72315 L F
.31835 .68131 m .27196 .66815 L .27239 .67422 L 1 .616 0 r
F
.31872 .68727 m .31835 .68131 L .27239 .67422 L 1 .605 0 r
F
.73398 .34807 m .69959 .3544 L .70216 .36079 L .658 .485 0 r
F
.73686 .35441 m .73398 .34807 L .70216 .36079 L .655 .476 0 r
F
.76424 .43274 m .72685 .43931 L .72852 .44592 L .614 .346 0 r
F
.76424 .43274 m .76232 .42615 L .72685 .43931 L F
.23177 .53093 m .1927 .51234 L .19168 .51893 L 1 .896 0 r
F
.23097 .5375 m .23177 .53093 L .19168 .51893 L 1 .888 0 r
F
.61145 .24264 m .58264 .24395 L .58521 .2498 L .816 .755 0 r
F
.61459 .2484 m .61145 .24264 L .58521 .2498 L .816 .747 0 r
F
.70296 .658 m .65895 .66005 L .65855 .66613 L .69 .171 0 r
F
.70296 .658 m .70346 .65186 L .65895 .66005 L F
.77119 .45245 m .73288 .45906 L .73439 .46572 L .61 .324 0 r
F
.77119 .45245 m .76944 .44579 L .73288 .45906 L F
.73602 .35481 m .70153 .36112 L .704 .36752 L .651 .469 0 r
F
.73879 .36118 m .73602 .35481 L .704 .36752 L .648 .459 0 r
F
.61132 .24286 m .58257 .2441 L .58513 .24995 L .814 .752 0 r
F
.61446 .24862 m .61132 .24286 L .58513 .24995 L .814 .745 0 r
F
.41571 .73829 m .36714 .72987 L .36756 .73559 L 1 .446 0 r
F
.41593 .74392 m .41571 .73829 L .36756 .73559 L 1 .433 0 r
F
.4643 .74503 m .41571 .73829 L .41593 .74392 L 1 .387 0 r
F
.24472 .48481 m .20758 .46656 L .20629 .473 L .267 .354 0 r
F
.24378 .49121 m .24472 .48481 L .20629 .473 L 1 .901 0 r
F
.4643 .75058 m .4643 .74503 L .41593 .74392 L .997 .374 0 r
F
.51241 .75007 m .4643 .74503 L .4643 .75058 L .941 .321 0 r
F
.51241 .75007 m .51266 .74453 L .4643 .74503 L F
.38318 .25718 m .35996 .24721 L .3572 .25275 L 1 1 0 r
F
.38318 .25718 m .3853 .25143 L .35996 .24721 L F
.70467 .6659 m .66017 .66774 L .65975 .67387 L .695 .174 0 r
F
.70467 .6659 m .70518 .6597 L .66017 .66774 L F
.29852 .29007 m .27346 .27372 L .26989 .2796 L 1 1 0 r
F
.29852 .29007 m .30156 .28405 L .27346 .27372 L F
.76609 .43935 m .72852 .44592 L .73012 .45254 L .61 .335 0 r
F
.76609 .43935 m .76424 .43274 L .72852 .44592 L F
.74964 .59844 m .70698 .60248 L .70704 .60894 L .636 .191 0 r
F
.74964 .59844 m .74958 .59191 L .70698 .60248 L F
.73102 .34176 m .69696 .34804 L .69959 .3544 L .661 .495 0 r
F
.73398 .34807 m .73102 .34176 L .69959 .3544 L .658 .485 0 r
F
.54759 .22616 m .52083 .22413 L .52217 .22993 L .902 .856 0 r
F
.54962 .23193 m .54759 .22616 L .52217 .22993 L .903 .85 0 r
F
.54757 .22623 m .52083 .22413 L .52217 .22993 L .9 .854 0 r
F
.5496 .23201 m .54757 .22623 L .52217 .22993 L .901 .848 0 r
F
.7472 .59096 m .70513 .59514 L .7052 .60155 L .631 .188 0 r
F
.7472 .59096 m .74712 .58449 L .70513 .59514 L F
.55966 .73977 m .51251 .7365 L .51226 .74197 L .878 .26 0 r
F
.55966 .73977 m .56014 .73428 L .51251 .7365 L F
.73317 .34848 m .699 .35473 L .70153 .36112 L .654 .479 0 r
F
.73602 .35481 m .73317 .34848 L .70153 .36112 L .651 .469 0 r
F
.60811 .73287 m .56145 .73109 L .56101 .73676 L .819 .22 0 r
F
.60811 .73287 m .60878 .72717 L .56145 .73109 L F
.29873 .2903 m .27369 .27397 L .27012 .27983 L 1 1 0 r
F
.29873 .2903 m .30177 .28429 L .27369 .27397 L F
.27057 .63104 m .22645 .61526 L .2265 .62162 L 1 .73 0 r
F
.27066 .6373 m .27057 .63104 L .2265 .62162 L 1 .72 0 r
F
.77286 .45912 m .73439 .46572 L .73584 .47239 L .606 .313 0 r
F
.77286 .45912 m .77119 .45245 L .73439 .46572 L F
.26746 .64626 m .2219 .63079 L .22213 .6372 L 1 .698 0 r
F
.26769 .65254 m .26746 .64626 L .22213 .6372 L 1 .689 0 r
F
.76785 .44597 m .73012 .45254 L .73165 .45917 L .607 .324 0 r
F
.76785 .44597 m .76609 .43935 L .73012 .45254 L F
.72799 .33548 m .69427 .34171 L .69696 .34804 L .663 .505 0 r
F
.73102 .34176 m .72799 .33548 L .69696 .34804 L .661 .495 0 r
F
.65504 .70175 m .60979 .70192 L .60926 .70769 L .752 .18 0 r
F
.65504 .70175 m .65575 .69592 L .60979 .70192 L F
.34397 .28117 m .32035 .269 L .31718 .27452 L 1 1 0 r
F
.34397 .28117 m .34654 .27539 L .32035 .269 L F
.73025 .34217 m .6964 .34838 L .699 .35473 L .657 .489 0 r
F
.73317 .34848 m .73025 .34217 L .699 .35473 L .654 .479 0 r
F
.65385 .26256 m .62375 .26596 L .62671 .2719 L .759 .678 0 r
F
.65731 .26841 m .65385 .26256 L .62671 .2719 L .757 .669 0 r
F
.23097 .5375 m .19168 .51893 L .19073 .52552 L 1 .888 0 r
F
.23023 .54405 m .23097 .5375 L .19073 .52552 L 1 .88 0 r
F
.24378 .49121 m .20629 .473 L .20509 .47943 L 1 .901 0 r
F
.24291 .4976 m .24378 .49121 L .20509 .47943 L 1 .892 0 r
F
.22332 .5654 m .18179 .54677 L .18118 .55348 L 1 .844 0 r
F
.22288 .57203 m .22332 .5654 L .18118 .55348 L 1 .835 0 r
F
.36755 .71567 m .32005 .7049 L .32058 .71069 L 1 .517 0 r
F
.36793 .72135 m .36755 .71567 L .32058 .71069 L 1 .505 0 r
F
.77445 .4658 m .73584 .47239 L .73721 .47906 L .603 .302 0 r
F
.77445 .4658 m .77286 .45912 L .73584 .47239 L F
.76954 .4526 m .73165 .45917 L .73311 .46579 L .603 .313 0 r
F
.76954 .4526 m .76785 .44597 L .73165 .45917 L F
.65359 .26287 m .62358 .2662 L .62653 .27214 L .756 .674 0 r
F
.65703 .26873 m .65359 .26287 L .62653 .27214 L .755 .666 0 r
F
.3457 .274 m .32219 .2615 L .31896 .26705 L 1 1 0 r
F
.3457 .274 m .34832 .26824 L .32219 .2615 L F
.56004 .74792 m .51266 .74453 L .51241 .75007 L .879 .261 0 r
F
.56004 .74792 m .56054 .74237 L .51266 .74453 L F
.35056 .25091 m .32766 .2376 L .32423 .24322 L 1 1 0 r
F
.35056 .25091 m .35337 .24512 L .32766 .2376 L F
.36675 .72411 m .31851 .71385 L .31908 .71969 L 1 .51 0 r
F
.36714 .72987 m .36675 .72411 L .31908 .71969 L 1 .498 0 r
F
.28296 .57443 m .23849 .56021 L .23846 .56629 L 1 .644 0 r
F
.28336 .58014 m .28296 .57443 L .23846 .56629 L 1 .623 0 r
F
.72726 .33589 m .69373 .34205 L .6964 .34838 L .66 .499 0 r
F
.73025 .34217 m .72726 .33589 L .6964 .34838 L .657 .489 0 r
F
.65616 .70986 m .61054 .7098 L .60999 .71564 L .755 .183 0 r
F
.65616 .70986 m .65689 .70397 L .61054 .7098 L F
.72489 .32924 m .69152 .33541 L .69427 .34171 L .666 .514 0 r
F
.72799 .33548 m .72489 .32924 L .69427 .34171 L .663 .505 0 r
F
.38744 .23368 m .36497 .2225 L .36201 .22808 L 1 1 0 r
F
.35069 .25114 m .32785 .23791 L .32442 .24353 L F
.35069 .25114 m .35349 .24536 L .32785 .23791 L F
.38492 .25043 m .36203 .24015 L .35922 .24567 L F
.38492 .25043 m .38708 .24473 L .36203 .24015 L F
.31708 .69604 m .26965 .68348 L .2702 .68956 L 1 .59 0 r
F
.31751 .70202 m .31708 .69604 L .2702 .68956 L 1 .579 0 r
F
.30156 .28405 m .27709 .2679 L .27346 .27372 L 1 1 0 r
F
.30156 .28405 m .30466 .27807 L .27709 .2679 L F
.3875 .23387 m .36508 .22276 L .36213 .22833 L F
.3875 .23387 m .38977 .22816 L .36508 .22276 L F
.77114 .45924 m .73311 .46579 L .7345 .47243 L .6 .302 0 r
F
.77114 .45924 m .76954 .4526 L .73311 .46579 L F
.33358 .5881 m .28336 .58014 L .28383 .58578 L .902 .072 0 r
F
.77595 .47249 m .73721 .47906 L .73851 .48573 L .599 .292 0 r
F
.77595 .47249 m .77445 .4658 L .73721 .47906 L F
.24291 .4976 m .20509 .47943 L .20397 .48586 L 1 .892 0 r
F
.24212 .50397 m .24291 .4976 L .20397 .48586 L 1 .881 0 r
F
.30177 .28429 m .27732 .26816 L .27369 .27397 L 1 1 0 r
F
.30177 .28429 m .30486 .27831 L .27732 .26816 L F
.74964 .60495 m .70704 .60894 L .70703 .61538 L .632 .179 0 r
F
.74964 .60495 m .74964 .59844 L .70704 .60894 L F
.7242 .32965 m .69101 .33575 L .69373 .34205 L .663 .509 0 r
F
.72726 .33589 m .7242 .32965 L .69373 .34205 L .66 .499 0 r
F
.74721 .59741 m .7052 .60155 L .7052 .60794 L .627 .176 0 r
F
.74721 .59741 m .7472 .59096 L .7052 .60155 L F
.23023 .54405 m .19073 .52552 L .18986 .53211 L 1 .88 0 r
F
.22956 .5506 m .23023 .54405 L .18986 .53211 L 1 .872 0 r
F
.72172 .32303 m .6887 .32914 L .69152 .33541 L .669 .524 0 r
F
.72489 .32924 m .72172 .32303 L .69152 .33541 L .666 .514 0 r
F
.31872 .68727 m .27239 .67422 L .27287 .68024 L 1 .605 0 r
F
.31912 .69319 m .31872 .68727 L .27287 .68024 L 1 .594 0 r
F
.60826 .23692 m .58004 .23815 L .58264 .24395 L .817 .762 0 r
F
.61145 .24264 m .60826 .23692 L .58264 .24395 L .816 .755 0 r
F
.7024 .6641 m .65855 .66613 L .65809 .67217 L .686 .159 0 r
F
.7024 .6641 m .70296 .658 L .65855 .66613 L F
.77266 .46588 m .7345 .47243 L .73582 .47907 L .596 .291 0 r
F
.77266 .46588 m .77114 .45924 L .7345 .47243 L F
.57473 .22668 m .54759 .22616 L .54962 .23193 L .862 .817 0 r
F
.5774 .23239 m .57473 .22668 L .54962 .23193 L .862 .81 0 r
F
.60814 .23713 m .57998 .2383 L .58257 .2441 L .815 .76 0 r
F
.61132 .24286 m .60814 .23713 L .58257 .2441 L .814 .752 0 r
F
.57467 .22682 m .54757 .22623 L .5496 .23201 L .86 .815 0 r
F
.57734 .23254 m .57467 .22682 L .5496 .23201 L .86 .808 0 r
F
.46437 .74243 m .41628 .73564 L .41652 .74114 L 1 .375 0 r
F
.46437 .74785 m .46437 .74243 L .41652 .74114 L .996 .363 0 r
F
.51201 .74739 m .46437 .74243 L .46437 .74785 L .938 .308 0 r
F
.51201 .74739 m .51226 .74197 L .46437 .74243 L F
.77738 .47918 m .73851 .48573 L .73974 .49241 L .596 .281 0 r
F
.77738 .47918 m .77595 .47249 L .73851 .48573 L F
.22288 .57203 m .18118 .55348 L .18065 .56017 L 1 .835 0 r
F
.22251 .57864 m .22288 .57203 L .18065 .56017 L 1 .826 0 r
F
.27066 .6373 m .2265 .62162 L .22662 .62795 L 1 .72 0 r
F
.27081 .64353 m .27066 .6373 L .22662 .62795 L 1 .709 0 r
F
.41628 .73564 m .36834 .72699 L .36879 .73257 L 1 .437 0 r
F
.41652 .74114 m .41628 .73564 L .36879 .73257 L 1 .424 0 r
F
.70408 .67207 m .65975 .67387 L .65928 .67997 L .691 .162 0 r
F
.70408 .67207 m .70467 .6659 L .65975 .67387 L F
.3853 .25143 m .36275 .24173 L .35996 .24721 L 1 1 0 r
F
.3853 .25143 m .38744 .24573 L .36275 .24173 L F
.60672 .7303 m .56061 .72874 L .56014 .73428 L .813 .206 0 r
F
.60672 .7303 m .60741 .72473 L .56061 .72874 L F
.72106 .32345 m .68822 .32948 L .69101 .33575 L .665 .519 0 r
F
.7242 .32965 m .72106 .32345 L .69101 .33575 L .663 .509 0 r
F
.65034 .25676 m .62074 .26006 L .62375 .26596 L .76 .686 0 r
F
.65385 .26256 m .65034 .25676 L .62375 .26596 L .759 .678 0 r
F
.26769 .65254 m .22213 .6372 L .22242 .64357 L 1 .689 0 r
F
.26798 .6588 m .26769 .65254 L .22242 .64357 L 1 .679 0 r
F
.34654 .27539 m .32358 .26354 L .32035 .269 L 1 1 0 r
F
.34654 .27539 m .34915 .26965 L .32358 .26354 L F
.71849 .31686 m .68583 .3229 L .6887 .32914 L .671 .533 0 r
F
.72172 .32303 m .71849 .31686 L .6887 .32914 L .669 .524 0 r
F
.6501 .25707 m .62059 .2603 L .62358 .2662 L .758 .683 0 r
F
.65359 .26287 m .6501 .25707 L .62358 .2662 L .756 .674 0 r
F
.24212 .50397 m .20397 .48586 L .20293 .49227 L 1 .881 0 r
F
.24141 .51033 m .24212 .50397 L .20293 .49227 L 1 .871 0 r
F
.7741 .47254 m .73582 .47907 L .73707 .4857 L .592 .28 0 r
F
.7741 .47254 m .77266 .46588 L .73582 .47907 L F
.41593 .74392 m .36756 .73559 L .36801 .74125 L 1 .433 0 r
F
.41617 .7495 m .41593 .74392 L .36801 .74125 L 1 .42 0 r
F
.4643 .75058 m .41593 .74392 L .41617 .7495 L .997 .374 0 r
F
.30466 .27807 m .28077 .26212 L .27709 .2679 L 1 1 0 r
F
.30466 .27807 m .3078 .27214 L .28077 .26212 L F
.34832 .26824 m .32546 .256 L .32219 .2615 L F
.34832 .26824 m .35099 .26252 L .32546 .256 L F
.77872 .48588 m .73974 .49241 L .7409 .49908 L .592 .27 0 r
F
.77872 .48588 m .77738 .47918 L .73974 .49241 L F
.46429 .75608 m .4643 .75058 L .41617 .7495 L .993 .361 0 r
F
.51215 .75556 m .4643 .75058 L .46429 .75608 L .937 .308 0 r
F
.51215 .75556 m .51241 .75007 L .4643 .75058 L F
.22956 .5506 m .18986 .53211 L .18906 .53869 L 1 .872 0 r
F
.22896 .55713 m .22956 .5506 L .18906 .53869 L 1 .863 0 r
F
.54554 .22043 m .51947 .21837 L .52083 .22413 L .902 .862 0 r
F
.54759 .22616 m .54554 .22043 L .52083 .22413 L .902 .856 0 r
F
.54552 .2205 m .51947 .21837 L .52083 .22413 L .899 .86 0 r
F
.54757 .22623 m .54552 .2205 L .52083 .22413 L .9 .854 0 r
F
.71786 .31727 m .68537 .32324 L .68822 .32948 L .668 .528 0 r
F
.72106 .32345 m .71786 .31727 L .68822 .32948 L .665 .519 0 r
F
.60741 .73851 m .56101 .73676 L .56054 .74237 L .815 .207 0 r
F
.60741 .73851 m .60811 .73287 L .56101 .73676 L F
.30486 .27831 m .28101 .2624 L .27732 .26816 L 1 1 0 r
F
.30486 .27831 m .308 .27239 L .28101 .2624 L F
.35337 .24512 m .33113 .23203 L .32766 .2376 L F
.35337 .24512 m .35621 .23939 L .33113 .23203 L F
.55914 .7452 m .51226 .74197 L .51201 .74739 L .874 .248 0 r
F
.55914 .7452 m .55966 .73977 L .51226 .74197 L F
.28336 .58014 m .23846 .56629 L .2385 .57234 L 1 .623 0 r
F
.28383 .58578 m .28336 .58014 L .2385 .57234 L 1 .603 0 r
F
.65428 .70753 m .60926 .70769 L .60868 .71342 L .747 .168 0 r
F
.65428 .70753 m .65504 .70175 L .60926 .70769 L F
.71518 .31072 m .68289 .3167 L .68583 .3229 L .674 .543 0 r
F
.71849 .31686 m .71518 .31072 L .68583 .3229 L .671 .533 0 r
F
.77546 .47919 m .73707 .4857 L .73825 .49234 L .589 .269 0 r
F
.77546 .47919 m .7741 .47254 L .73707 .4857 L F
.35349 .24536 m .33132 .23236 L .32785 .23791 L 1 1 0 r
F
.35349 .24536 m .35633 .23963 L .33132 .23236 L F
.74955 .61144 m .70703 .61538 L .70695 .6218 L .628 .168 0 r
F
.74955 .61144 m .74964 .60495 L .70703 .61538 L F
.74714 .60384 m .7052 .60794 L .70514 .6143 L .623 .165 0 r
F
.74714 .60384 m .74721 .59741 L .7052 .60794 L F
.36793 .72135 m .32058 .71069 L .32116 .71643 L 1 .505 0 r
F
.36834 .72699 m .36793 .72135 L .32116 .71643 L 1 .493 0 r
F
.22251 .57864 m .18065 .56017 L .1802 .56685 L 1 .826 0 r
F
.2222 .58524 m .22251 .57864 L .1802 .56685 L 1 .817 0 r
F
.24141 .51033 m .20293 .49227 L .20198 .49869 L 1 .871 0 r
F
.24078 .51666 m .24141 .51033 L .20198 .49869 L 1 .86 0 r
F
.77999 .49258 m .7409 .49908 L .742 .50576 L .589 .259 0 r
F
.77999 .49258 m .77872 .48588 L .7409 .49908 L F
.38708 .24473 m .36488 .23469 L .36203 .24015 L 1 1 0 r
F
.38708 .24473 m .38927 .23907 L .36488 .23469 L F
.36714 .72987 m .31908 .71969 L .31969 .72549 L 1 .498 0 r
F
.36756 .73559 m .36714 .72987 L .31969 .72549 L 1 .485 0 r
F
.71458 .31114 m .68246 .31703 L .68537 .32324 L .671 .538 0 r
F
.71786 .31727 m .71458 .31114 L .68537 .32324 L .668 .528 0 r
F
.65538 .71571 m .60999 .71564 L .6094 .72143 L .751 .17 0 r
F
.65538 .71571 m .65616 .70986 L .60999 .71564 L F
.31751 .70202 m .2702 .68956 L .2708 .6956 L 1 .579 0 r
F
.31799 .70795 m .31751 .70202 L .2708 .6956 L 1 .568 0 r
F
.29772 .30736 m .3006 .30146 L .27316 .29198 L 1 1 0 r
F
.55952 .75342 m .51241 .75007 L .51215 .75556 L .875 .248 0 r
F
.55952 .75342 m .56004 .74792 L .51241 .75007 L F
.38977 .22816 m .36806 .21725 L .36508 .22276 L 1 1 0 r
F
.64678 .251 m .61769 .25421 L .62074 .26006 L .762 .694 0 r
F
.65034 .25676 m .64678 .251 L .62074 .26006 L .76 .686 0 r
F
.27081 .64353 m .22662 .62795 L .22681 .63426 L 1 .709 0 r
F
.27102 .64974 m .27081 .64353 L .22681 .63426 L 1 .699 0 r
F
.22896 .55713 m .18906 .53869 L .18834 .54527 L 1 .863 0 r
F
.22842 .56366 m .22896 .55713 L .18834 .54527 L 1 .855 0 r
F
.77673 .48585 m .73825 .49234 L .73936 .49898 L .585 .258 0 r
F
.77673 .48585 m .77546 .47919 L .73825 .49234 L F
.7118 .30463 m .6799 .31053 L .68289 .3167 L .677 .552 0 r
F
.71518 .31072 m .7118 .30463 L .68289 .3167 L .674 .543 0 r
F
.70177 .67017 m .65809 .67217 L .65758 .67817 L .682 .147 0 r
F
.70177 .67017 m .7024 .6641 L .65809 .67217 L F
.60503 .23125 m .5774 .23239 L .58004 .23815 L .817 .77 0 r
F
.60826 .23692 m .60503 .23125 L .58004 .23815 L .817 .762 0 r
F
.60492 .23146 m .57734 .23254 L .57998 .2383 L .815 .767 0 r
F
.60814 .23713 m .60492 .23146 L .57998 .2383 L .815 .76 0 r
F
.31912 .69319 m .27287 .68024 L .2734 .68623 L 1 .594 0 r
F
.31957 .69907 m .31912 .69319 L .2734 .68623 L 1 .582 0 r
F
.64655 .2513 m .61754 .25444 L .62059 .2603 L .759 .691 0 r
F
.6501 .25707 m .64655 .2513 L .62059 .2603 L .758 .683 0 r
F
.3078 .27214 m .28451 .2564 L .28077 .26212 L 1 1 0 r
F
.3078 .27214 m .31099 .26625 L .28451 .2564 L F
.34915 .26965 m .32685 .25814 L .32358 .26354 L F
.34915 .26965 m .35179 .26397 L .32685 .25814 L F
.70344 .6782 m .65928 .67997 L .65876 .68603 L .686 .15 0 r
F
.70344 .6782 m .70408 .67207 L .65928 .67997 L F
.78117 .49929 m .742 .50576 L .74302 .51243 L .585 .248 0 r
F
.78117 .49929 m .77999 .49258 L .742 .50576 L F
.26798 .6588 m .22242 .64357 L .22277 .64992 L 1 .679 0 r
F
.26832 .66502 m .26798 .6588 L .22277 .64992 L 1 .668 0 r
F
.71124 .30504 m .67949 .31086 L .68246 .31703 L .673 .548 0 r
F
.71458 .31114 m .71124 .30504 L .68246 .31703 L .671 .538 0 r
F
.308 .27239 m .28476 .2567 L .28101 .2624 L 1 1 0 r
F
.308 .27239 m .31118 .26651 L .28476 .2567 L F
.38744 .24573 m .36558 .2363 L .36275 .24173 L F
.38744 .24573 m .38961 .24008 L .36558 .2363 L F
.57202 .22102 m .54554 .22043 L .54759 .22616 L .862 .824 0 r
F
.57473 .22668 m .57202 .22102 L .54759 .22616 L .862 .817 0 r
F
.57197 .22115 m .54552 .2205 L .54757 .22623 L .86 .822 0 r
F
.57467 .22682 m .57197 .22115 L .54757 .22623 L .86 .815 0 r
F
.29644 .31478 m .29924 .30888 L .27159 .29936 L 1 1 0 r
F
.24078 .51666 m .20198 .49869 L .2011 .50509 L 1 .86 0 r
F
.24022 .52297 m .24078 .51666 L .2011 .50509 L 1 .849 0 r
F
.35099 .26252 m .32878 .25056 L .32546 .256 L 1 1 0 r
F
.35099 .26252 m .3537 .25685 L .32878 .25056 L F
.77792 .4925 m .73936 .49898 L .74039 .50561 L .581 .246 0 r
F
.77792 .4925 m .77673 .48585 L .73936 .49898 L F
.70836 .29857 m .67685 .30439 L .6799 .31053 L .679 .562 0 r
F
.7118 .30463 m .70836 .29857 L .6799 .31053 L .677 .552 0 r
F
.2222 .58524 m .1802 .56685 L .17983 .57352 L 1 .817 0 r
F
.22196 .59181 m .2222 .58524 L .17983 .57352 L 1 .808 0 r
F
.41652 .74114 m .36879 .73257 L .36926 .73811 L 1 .424 0 r
F
.41677 .74657 m .41652 .74114 L .36926 .73811 L 1 .411 0 r
F
.46437 .74785 m .41652 .74114 L .41677 .74657 L .996 .363 0 r
F
.46437 .75321 m .46437 .74785 L .41677 .74657 L .993 .35 0 r
F
.51174 .75275 m .46437 .74785 L .46437 .75321 L .934 .296 0 r
F
.51174 .75275 m .51201 .74739 L .46437 .74785 L F
.74939 .6179 m .70695 .6218 L .70682 .62819 L .624 .157 0 r
F
.74939 .6179 m .74955 .61144 L .70695 .6218 L F
.74699 .61024 m .70514 .6143 L .70502 .62064 L .619 .153 0 r
F
.74699 .61024 m .74714 .60384 L .70514 .6143 L F
.3006 .30146 m .27664 .28633 L .27316 .29198 L 1 1 0 r
F
.3006 .30146 m .30354 .2956 L .27664 .28633 L F
.60599 .73583 m .56014 .73428 L .55966 .73977 L .808 .193 0 r
F
.60599 .73583 m .60672 .7303 L .56014 .73428 L F
.35621 .23939 m .33465 .22652 L .33113 .23203 L 1 1 0 r
F
.35621 .23939 m .3591 .2337 L .33465 .22652 L F
.28383 .58578 m .2385 .57234 L .2386 .57835 L 1 .603 0 r
F
.28436 .59134 m .28383 .58578 L .2386 .57835 L 1 .584 0 r
F
.22842 .56366 m .18834 .54527 L .1877 .55184 L 1 .855 0 r
F
.22794 .57017 m .22842 .56366 L .1877 .55184 L 1 .846 0 r
F
.78227 .506 m .74302 .51243 L .74396 .51911 L .581 .237 0 r
F
.78227 .506 m .78117 .49929 L .74302 .51243 L F
.70783 .29899 m .67645 .30473 L .67949 .31086 L .676 .557 0 r
F
.71124 .30504 m .70783 .29899 L .67949 .31086 L .673 .548 0 r
F
.35633 .23963 m .33483 .22686 L .33132 .23236 L 1 1 0 r
F
.35633 .23963 m .35921 .23396 L .33483 .22686 L F
.41617 .7495 m .36801 .74125 L .36849 .74685 L 1 .42 0 r
F
.41642 .75502 m .41617 .7495 L .36849 .74685 L 1 .407 0 r
F
.46429 .75608 m .41617 .7495 L .41642 .75502 L .993 .361 0 r
F
.77903 .49916 m .74039 .50561 L .74135 .51224 L .577 .235 0 r
F
.77903 .49916 m .77792 .4925 L .74039 .50561 L F
.54346 .21475 m .5181 .21266 L .51947 .21837 L .901 .869 0 r
F
.54554 .22043 m .54346 .21475 L .51947 .21837 L .902 .862 0 r
F
.54344 .21482 m .5181 .21266 L .51947 .21837 L .898 .866 0 r
F
.54552 .2205 m .54344 .21482 L .51947 .21837 L .899 .86 0 r
F
.64316 .24529 m .61459 .2484 L .61769 .25421 L .763 .703 0 r
F
.64678 .251 m .64316 .24529 L .61769 .25421 L .762 .694 0 r
F
.65346 .71326 m .60868 .71342 L .60807 .7191 L .743 .156 0 r
F
.65346 .71326 m .65428 .70753 L .60868 .71342 L F
.31099 .26625 m .28831 .25074 L .28451 .2564 L 1 1 0 r
F
.31099 .26625 m .31423 .26042 L .28831 .25074 L F
.29924 .30888 m .27501 .29373 L .27159 .29936 L F
.29924 .30888 m .30209 .30302 L .27501 .29373 L F
.24022 .52297 m .2011 .50509 L .20031 .51147 L 1 .849 0 r
F
.23975 .52926 m .24022 .52297 L .20031 .51147 L 1 .837 0 r
F
.70485 .29256 m .67373 .2983 L .67685 .30439 L .682 .571 0 r
F
.70836 .29857 m .70485 .29256 L .67685 .30439 L .679 .562 0 r
F
.46429 .76151 m .46429 .75608 L .41642 .75502 L .99 .348 0 r
F
.51188 .76099 m .46429 .75608 L .46429 .76151 L .933 .295 0 r
F
.51188 .76099 m .51215 .75556 L .46429 .75608 L F
.60666 .7441 m .56054 .74237 L .56004 .74792 L .811 .194 0 r
F
.60666 .7441 m .60741 .73851 L .56054 .74237 L F
.27102 .64974 m .22681 .63426 L .22706 .64053 L 1 .699 0 r
F
.27128 .65591 m .27102 .64974 L .22706 .64053 L 1 .688 0 r
F
.64294 .24559 m .61446 .24862 L .61754 .25444 L .761 .699 0 r
F
.64655 .2513 m .64294 .24559 L .61754 .25444 L .759 .691 0 r
F
.38927 .23907 m .36777 .22928 L .36488 .23469 L 1 1 0 r
F
.38927 .23907 m .39149 .23346 L .36777 .22928 L F
.31118 .26651 m .28856 .25105 L .28476 .2567 L F
.31118 .26651 m .31442 .26069 L .28856 .25105 L F
.55861 .75058 m .51201 .74739 L .51174 .75275 L .87 .235 0 r
F
.55861 .75058 m .55914 .7452 L .51201 .74739 L F
.33766 .59574 m .33559 .59203 L .28436 .59134 L .774 .053 0 r
F
.35179 .26397 m .33017 .2528 L .32685 .25814 L 1 1 0 r
F
.35179 .26397 m .35447 .25833 L .33017 .2528 L F
.36834 .72699 m .32116 .71643 L .32177 .72212 L 1 .493 0 r
F
.36879 .73257 m .36834 .72699 L .32177 .72212 L 1 .481 0 r
F
.31799 .70795 m .2708 .6956 L .27146 .70159 L 1 .568 0 r
F
.31851 .71385 m .31799 .70795 L .27146 .70159 L 1 .556 0 r
F
.70434 .29297 m .67336 .29863 L .67645 .30473 L .679 .567 0 r
F
.70783 .29899 m .70434 .29297 L .67645 .30473 L .676 .557 0 r
F
.78328 .51271 m .74396 .51911 L .74484 .52577 L .577 .226 0 r
F
.78328 .51271 m .78227 .506 L .74396 .51911 L F
.70108 .67619 m .65758 .67817 L .65703 .68413 L .677 .135 0 r
F
.70108 .67619 m .70177 .67017 L .65758 .67817 L F
.65455 .72151 m .6094 .72143 L .60878 .72717 L .747 .158 0 r
F
.65455 .72151 m .65538 .71571 L .6094 .72143 L F
.60175 .22563 m .57473 .22668 L .5774 .23239 L .818 .777 0 r
F
.60503 .23125 m .60175 .22563 L .5774 .23239 L .817 .77 0 r
F
.30354 .2956 m .28017 .28073 L .27664 .28633 L 1 1 0 r
F
.30354 .2956 m .30653 .28979 L .28017 .28073 L F
.36756 .73559 m .31969 .72549 L .32034 .73124 L 1 .485 0 r
F
.36801 .74125 m .36756 .73559 L .32034 .73124 L 1 .472 0 r
F
.60165 .22583 m .57467 .22682 L .57734 .23254 L .816 .775 0 r
F
.60492 .23146 m .60165 .22583 L .57734 .23254 L .815 .767 0 r
F
.22196 .59181 m .17983 .57352 L .17954 .58018 L 1 .808 0 r
F
.22178 .59837 m .22196 .59181 L .17954 .58018 L 1 .799 0 r
F
.22794 .57017 m .1877 .55184 L .18713 .5584 L 1 .846 0 r
F
.22753 .57666 m .22794 .57017 L .18713 .5584 L 1 .837 0 r
F
.26832 .66502 m .22277 .64992 L .2232 .65623 L 1 .668 0 r
F
.26871 .67121 m .26832 .66502 L .2232 .65623 L 1 .658 0 r
F
.31957 .69907 m .2734 .68623 L .27399 .69218 L 1 .582 0 r
F
.32005 .7049 m .31957 .69907 L .27399 .69218 L 1 .57 0 r
F
.78005 .50582 m .74135 .51224 L .74225 .51886 L .573 .223 0 r
F
.78005 .50582 m .77903 .49916 L .74135 .51224 L F
.70272 .6843 m .65876 .68603 L .65819 .69205 L .682 .138 0 r
F
.70272 .6843 m .70344 .6782 L .65876 .68603 L F
.3537 .25685 m .33215 .24518 L .32878 .25056 L 1 1 0 r
F
.3537 .25685 m .35644 .25123 L .33215 .24518 L F
.70128 .28659 m .67056 .29224 L .67373 .2983 L .684 .58 0 r
F
.70485 .29256 m .70128 .28659 L .67373 .2983 L .682 .571 0 r
F
.74677 .61661 m .70502 .62064 L .70484 .62695 L .615 .141 0 r
F
.74677 .61661 m .74699 .61024 L .70502 .62064 L F
.74916 .62434 m .70682 .62819 L .70662 .63455 L .62 .145 0 r
F
.74916 .62434 m .74939 .6179 L .70682 .62819 L F
.55898 .75887 m .51215 .75556 L .51188 .76099 L .871 .235 0 r
F
.55898 .75887 m .55952 .75342 L .51215 .75556 L F
.38961 .24008 m .36844 .23092 L .36558 .2363 L 1 1 0 r
F
.38961 .24008 m .39181 .23447 L .36844 .23092 L F
.30209 .30302 m .27849 .28818 L .27501 .29373 L F
.30209 .30302 m .305 .29721 L .27849 .28818 L F
.23975 .52926 m .20031 .51147 L .19959 .51785 L 1 .837 0 r
F
.23934 .53551 m .23975 .52926 L .19959 .51785 L 1 .825 0 r
F
.20384 .43238 m .20581 .42571 L .17083 .41142 L 1 1 0 r
F
.56927 .2154 m .54346 .21475 L .54554 .22043 L .862 .831 0 r
F
.57202 .22102 m .56927 .2154 L .54554 .22043 L .862 .824 0 r
F
.70079 .287 m .67021 .29257 L .67336 .29863 L .681 .576 0 r
F
.70434 .29297 m .70079 .287 L .67336 .29863 L .679 .567 0 r
F
.56922 .21553 m .54344 .21482 L .54552 .2205 L .86 .828 0 r
F
.57197 .22115 m .56922 .21553 L .54552 .2205 L .86 .822 0 r
F
.78421 .51941 m .74484 .52577 L .74564 .53244 L .574 .214 0 r
F
.78421 .51941 m .78328 .51271 L .74484 .52577 L F
.31423 .26042 m .29217 .24513 L .28831 .25074 L 1 1 0 r
F
.31423 .26042 m .31751 .25463 L .29217 .24513 L F
.3591 .2337 m .33821 .22107 L .33465 .22652 L F
.3591 .2337 m .36201 .22808 L .33821 .22107 L F
.20384 .43238 m .17083 .41142 L .16858 .41806 L F
.20194 .43906 m .20384 .43238 L .16858 .41806 L F
.28436 .59134 m .2386 .57835 L .23877 .58432 L 1 .584 0 r
F
.28494 .59684 m .28436 .59134 L .23877 .58432 L 1 .567 0 r
F
.33766 .59574 m .28436 .59134 L .28494 .59684 L .774 .053 0 r
F
.63949 .23964 m .61145 .24264 L .61459 .2484 L .765 .711 0 r
F
.64316 .24529 m .63949 .23964 L .61459 .2484 L .763 .703 0 r
F
.78099 .51247 m .74225 .51886 L .74306 .52548 L .569 .212 0 r
F
.78099 .51247 m .78005 .50582 L .74225 .51886 L F
.31442 .26069 m .29242 .24547 L .28856 .25105 L 1 1 0 r
F
.31442 .26069 m .31771 .25491 L .29242 .24547 L F
.35921 .23396 m .33839 .22142 L .33483 .22686 L F
.35921 .23396 m .36213 .22833 L .33839 .22142 L F
.30653 .28979 m .28376 .2752 L .28017 .28073 L F
.30653 .28979 m .30957 .28403 L .28376 .2752 L F
.63929 .23993 m .61132 .24286 L .61446 .24862 L .762 .708 0 r
F
.64294 .24559 m .63929 .23993 L .61446 .24862 L .761 .699 0 r
F
.20194 .43906 m .16858 .41806 L .1664 .42473 L 1 1 0 r
F
.20012 .44575 m .20194 .43906 L .1664 .42473 L F
.69764 .28066 m .66733 .28622 L .67056 .29224 L .687 .59 0 r
F
.70128 .28659 m .69764 .28066 L .67056 .29224 L .684 .58 0 r
F
.22753 .57666 m .18713 .5584 L .18664 .56495 L 1 .837 0 r
F
.22718 .58314 m .22753 .57666 L .18664 .56495 L 1 .828 0 r
F
.41677 .74657 m .36926 .73811 L .36975 .74359 L 1 .411 0 r
F
.41703 .75196 m .41677 .74657 L .36975 .74359 L 1 .398 0 r
F
.46437 .75321 m .41677 .74657 L .41703 .75196 L .993 .35 0 r
F
.27128 .65591 m .22706 .64053 L .22738 .64678 L 1 .688 0 r
F
.27159 .66205 m .27128 .65591 L .22738 .64678 L 1 .678 0 r
F
.60522 .7413 m .55966 .73977 L .55914 .7452 L .804 .18 0 r
F
.60522 .7413 m .60599 .73583 L .55966 .73977 L F
.46437 .75851 m .46437 .75321 L .41703 .75196 L .989 .337 0 r
F
.51146 .75805 m .46437 .75321 L .46437 .75851 L .93 .282 0 r
F
.51146 .75805 m .51174 .75275 L .46437 .75321 L F
.35447 .25833 m .33354 .24753 L .33017 .2528 L 1 1 0 r
F
.35447 .25833 m .3572 .25275 L .33354 .24753 L F
.22178 .59837 m .17954 .58018 L .17933 .58681 L 1 .799 0 r
F
.22167 .6049 m .22178 .59837 L .17933 .58681 L 1 .789 0 r
F
.69718 .28107 m .667 .28655 L .67021 .29257 L .684 .586 0 r
F
.70079 .287 m .69718 .28107 L .67021 .29257 L .681 .576 0 r
F
.20012 .44575 m .1664 .42473 L .16431 .43141 L 1 1 0 r
F
.19837 .45246 m .20012 .44575 L .16431 .43141 L F
.305 .29721 m .28205 .2827 L .27849 .28818 L F
.305 .29721 m .30796 .29145 L .28205 .2827 L F
.78506 .52611 m .74564 .53244 L .74637 .53909 L .57 .203 0 r
F
.78506 .52611 m .78421 .51941 L .74564 .53244 L F
.23934 .53551 m .19959 .51785 L .19896 .52421 L 1 .825 0 r
F
.23902 .54174 m .23934 .53551 L .19896 .52421 L 1 .813 0 r
F
.6526 .71895 m .60807 .7191 L .60741 .72473 L .739 .143 0 r
F
.6526 .71895 m .65346 .71326 L .60807 .7191 L F
.39149 .23346 m .37069 .22393 L .36777 .22928 L 1 1 0 r
F
.39149 .23346 m .39373 .22789 L .37069 .22393 L F
.41642 .75502 m .36849 .74685 L .36901 .7524 L 1 .407 0 r
F
.41669 .76048 m .41642 .75502 L .36901 .7524 L 1 .393 0 r
F
.46429 .76151 m .41642 .75502 L .41669 .76048 L .99 .348 0 r
F
.54135 .20912 m .5167 .20699 L .5181 .21266 L .9 .875 0 r
F
.54346 .21475 m .54135 .20912 L .5181 .21266 L .901 .869 0 r
F
.54134 .20918 m .5167 .20699 L .5181 .21266 L .897 .873 0 r
F
.54344 .21482 m .54134 .20918 L .5181 .21266 L .898 .866 0 r
F
.70032 .68218 m .65703 .68413 L .65642 .69005 L .673 .123 0 r
F
.70032 .68218 m .70108 .67619 L .65703 .68413 L F
.74648 .62295 m .70484 .62695 L .70459 .63322 L .61 .129 0 r
F
.74648 .62295 m .74677 .61661 L .70484 .62695 L F
.78185 .51912 m .74306 .52548 L .74381 .53209 L .565 .2 0 r
F
.78185 .51912 m .78099 .51247 L .74306 .52548 L F
.59843 .22006 m .57202 .22102 L .57473 .22668 L .818 .784 0 r
F
.60175 .22563 m .59843 .22006 L .57473 .22668 L .818 .777 0 r
F
.74884 .63075 m .70662 .63455 L .70636 .64089 L .616 .133 0 r
F
.74884 .63075 m .74916 .62434 L .70662 .63455 L F
.19837 .45246 m .16431 .43141 L .16231 .43811 L 1 1 0 r
F
.19669 .45918 m .19837 .45246 L .16231 .43811 L 1 .994 0 r
F
.35644 .25123 m .33555 .23986 L .33215 .24518 L 1 1 0 r
F
.35644 .25123 m .35922 .24567 L .33555 .23986 L F
.60588 .74964 m .56004 .74792 L .55952 .75342 L .806 .181 0 r
F
.60588 .74964 m .60666 .7441 L .56004 .74792 L F
.31851 .71385 m .27146 .70159 L .27218 .70755 L 1 .556 0 r
F
.31908 .71969 m .31851 .71385 L .27218 .70755 L 1 .544 0 r
F
.26871 .67121 m .2232 .65623 L .22369 .6625 L 1 .658 0 r
F
.26915 .67737 m .26871 .67121 L .22369 .6625 L 1 .647 0 r
F
.59833 .22025 m .57197 .22115 L .57467 .22682 L .816 .782 0 r
F
.60165 .22583 m .59833 .22025 L .57467 .22682 L .816 .775 0 r
F
.46429 .76689 m .46429 .76151 L .41669 .76048 L .986 .334 0 r
F
.5116 .76637 m .46429 .76151 L .46429 .76689 L .929 .281 0 r
F
.5116 .76637 m .51188 .76099 L .46429 .76151 L F
.69393 .27478 m .66405 .28024 L .66733 .28622 L .689 .599 0 r
F
.69764 .28066 m .69393 .27478 L .66733 .28622 L .687 .59 0 r
F
.36879 .73257 m .32177 .72212 L .32243 .72777 L 1 .481 0 r
F
.36926 .73811 m .36879 .73257 L .32243 .72777 L 1 .468 0 r
F
.31751 .25463 m .29608 .23958 L .29217 .24513 L 1 1 0 r
F
.31751 .25463 m .32085 .2489 L .29608 .23958 L F
.70195 .69035 m .65819 .69205 L .65756 .69803 L .678 .126 0 r
F
.70195 .69035 m .70272 .6843 L .65819 .69205 L F
.65366 .72726 m .60878 .72717 L .60811 .73287 L .742 .145 0 r
F
.65366 .72726 m .65455 .72151 L .60878 .72717 L F
.55804 .7559 m .51174 .75275 L .51146 .75805 L .866 .221 0 r
F
.55804 .7559 m .55861 .75058 L .51174 .75275 L F
.32005 .7049 m .27399 .69218 L .27464 .69808 L 1 .57 0 r
F
.32058 .71069 m .32005 .7049 L .27464 .69808 L 1 .558 0 r
F
.30957 .28403 m .28741 .26972 L .28376 .2752 L 1 1 0 r
F
.30957 .28403 m .31265 .27832 L .28741 .26972 L F
.19669 .45918 m .16231 .43811 L .16038 .44483 L 1 .994 0 r
F
.19509 .4659 m .19669 .45918 L .16038 .44483 L 1 .988 0 r
F
.36801 .74125 m .32034 .73124 L .32103 .73694 L 1 .472 0 r
F
.36849 .74685 m .36801 .74125 L .32103 .73694 L 1 .459 0 r
F
.31771 .25491 m .29634 .23994 L .29242 .24547 L 1 1 0 r
F
.31771 .25491 m .32104 .24919 L .29634 .23994 L F
.6935 .27518 m .66374 .28056 L .667 .28655 L .686 .595 0 r
F
.69718 .28107 m .6935 .27518 L .667 .28655 L .684 .586 0 r
F
.22718 .58314 m .18664 .56495 L .18623 .57148 L 1 .828 0 r
F
.2269 .58961 m .22718 .58314 L .18623 .57148 L 1 .819 0 r
F
.39181 .23447 m .37134 .2256 L .36844 .23092 L 1 1 0 r
F
.39181 .23447 m .39404 .22891 L .37134 .2256 L F
.63576 .23403 m .60826 .23692 L .61145 .24264 L .766 .719 0 r
F
.63949 .23964 m .63576 .23403 L .61145 .24264 L .765 .711 0 r
F
.78583 .53281 m .74637 .53909 L .74703 .54574 L .566 .191 0 r
F
.78583 .53281 m .78506 .52611 L .74637 .53909 L F
.30796 .29145 m .28568 .2773 L .28205 .2827 L 1 1 0 r
F
.30796 .29145 m .31098 .28575 L .28568 .2773 L F
.63557 .23431 m .60814 .23713 L .61132 .24286 L .763 .716 0 r
F
.63929 .23993 m .63557 .23431 L .61132 .24286 L .762 .708 0 r
F
.36201 .22808 m .34182 .21568 L .33821 .22107 L 1 1 0 r
F
.36201 .22808 m .36497 .2225 L .34182 .21568 L F
.28494 .59684 m .23877 .58432 L .239 .59025 L 1 .567 0 r
F
.28556 .60228 m .28494 .59684 L .239 .59025 L 1 .553 0 r
F
.33962 .59938 m .28494 .59684 L .28556 .60228 L .753 .053 0 r
F
.33962 .59938 m .33766 .59574 L .28494 .59684 L F
.23902 .54174 m .19896 .52421 L .1984 .53055 L 1 .813 0 r
F
.23877 .54793 m .23902 .54174 L .1984 .53055 L 1 .801 0 r
F
.78262 .52576 m .74381 .53209 L .74448 .53869 L .56 .188 0 r
F
.78262 .52576 m .78185 .51912 L .74381 .53209 L F
.22167 .6049 m .17933 .58681 L .17919 .59343 L 1 .789 0 r
F
.22163 .61141 m .22167 .6049 L .17919 .59343 L 1 .779 0 r
F
.19509 .4659 m .16038 .44483 L .15855 .45155 L 1 .988 0 r
F
.19356 .47263 m .19509 .4659 L .15855 .45155 L 1 .981 0 r
F
.36213 .22833 m .342 .21604 L .33839 .22142 L 1 1 0 r
F
.36213 .22833 m .36508 .22276 L .342 .21604 L F
.56649 .20984 m .54135 .20912 L .54346 .21475 L .861 .837 0 r
F
.56927 .2154 m .56649 .20984 L .54346 .21475 L .862 .831 0 r
F
.5584 .76426 m .51188 .76099 L .5116 .76637 L .866 .221 0 r
F
.5584 .76426 m .55898 .75887 L .51188 .76099 L F
.56645 .20996 m .54134 .20918 L .54344 .21482 L .859 .835 0 r
F
.56922 .21553 m .56645 .20996 L .54344 .21482 L .86 .828 0 r
F
.27159 .66205 m .22738 .64678 L .22777 .65299 L 1 .678 0 r
F
.27196 .66815 m .27159 .66205 L .22777 .65299 L 1 .666 0 r
F
.69016 .26894 m .6607 .2743 L .66405 .28024 L .692 .608 0 r
F
.69393 .27478 m .69016 .26894 L .66405 .28024 L .689 .599 0 r
F
.3572 .25275 m .33694 .24232 L .33354 .24753 L 1 1 0 r
F
.3572 .25275 m .35996 .24721 L .33694 .24232 L F
.68975 .26934 m .66041 .27462 L .66374 .28056 L .689 .605 0 r
F
.6935 .27518 m .68975 .26934 L .66374 .28056 L .686 .595 0 r
F
.7461 .62927 m .70459 .63322 L .70428 .63947 L .606 .117 0 r
F
.7461 .62927 m .74648 .62295 L .70459 .63322 L F
.19356 .47263 m .15855 .45155 L .15679 .4583 L 1 .981 0 r
F
.19211 .47937 m .19356 .47263 L .15679 .4583 L 1 .974 0 r
F
.74846 .63714 m .70636 .64089 L .70603 .64719 L .612 .122 0 r
F
.74846 .63714 m .74884 .63075 L .70636 .64089 L F
.31265 .27832 m .29111 .26431 L .28741 .26972 L 1 1 0 r
F
.31265 .27832 m .31578 .27266 L .29111 .26431 L F
.7865 .5395 m .74703 .54574 L .74762 .55237 L .561 .18 0 r
F
.7865 .5395 m .78583 .53281 L .74703 .54574 L F
.32085 .2489 m .30004 .23409 L .29608 .23958 L 1 1 0 r
F
.32085 .2489 m .32423 .24322 L .30004 .23409 L F
.2269 .58961 m .18623 .57148 L .1859 .57801 L 1 .819 0 r
F
.22669 .59605 m .2269 .58961 L .1859 .57801 L 1 .81 0 r
F
.35922 .24567 m .339 .2346 L .33555 .23986 L 1 1 0 r
F
.35922 .24567 m .36203 .24015 L .339 .2346 L F
.78331 .53239 m .74448 .53869 L .74508 .54528 L .556 .176 0 r
F
.78331 .53239 m .78262 .52576 L .74448 .53869 L F
.60442 .74671 m .55914 .7452 L .55861 .75058 L .799 .167 0 r
F
.60442 .74671 m .60522 .7413 L .55914 .7452 L F
.41703 .75196 m .36975 .74359 L .37028 .74901 L 1 .398 0 r
F
.41732 .75728 m .41703 .75196 L .37028 .74901 L 1 .385 0 r
F
.46437 .75851 m .41703 .75196 L .41732 .75728 L .989 .337 0 r
F
.39373 .22789 m .37364 .21864 L .37069 .22393 L 1 1 0 r
F
.32104 .24919 m .30031 .23448 L .29634 .23994 L F
.32104 .24919 m .32442 .24353 L .30031 .23448 L F
.31098 .28575 m .28938 .27199 L .28568 .2773 L F
.31098 .28575 m .31406 .28011 L .28938 .27199 L F
.6995 .68812 m .65642 .69005 L .65575 .69592 L .668 .111 0 r
F
.6995 .68812 m .70032 .68218 L .65642 .69005 L F
.26915 .67737 m .22369 .6625 L .22425 .66875 L 1 .647 0 r
F
.26965 .68348 m .26915 .67737 L .22425 .66875 L 1 .636 0 r
F
.59506 .21454 m .56927 .2154 L .57202 .22102 L .819 .792 0 r
F
.59843 .22006 m .59506 .21454 L .57202 .22102 L .818 .784 0 r
F
.23877 .54793 m .1984 .53055 L .19793 .53687 L 1 .801 0 r
F
.2386 .55409 m .23877 .54793 L .19793 .53687 L 1 .788 0 r
F
.65168 .72458 m .60741 .72473 L .60672 .7303 L .734 .13 0 r
F
.65168 .72458 m .6526 .71895 L .60741 .72473 L F
.46437 .76375 m .46437 .75851 L .41732 .75728 L .985 .323 0 r
F
.51117 .76329 m .46437 .75851 L .46437 .76375 L .926 .269 0 r
F
.51117 .76329 m .51146 .75805 L .46437 .75851 L F
.59498 .21473 m .56922 .21553 L .57197 .22115 L .817 .789 0 r
F
.59833 .22025 m .59498 .21473 L .57197 .22115 L .816 .782 0 r
F
.19211 .47937 m .15679 .4583 L .15513 .46505 L 1 .974 0 r
F
.19073 .48612 m .19211 .47937 L .15513 .46505 L 1 .967 0 r
F
.68632 .26315 m .65731 .26841 L .6607 .2743 L .694 .618 0 r
F
.69016 .26894 m .68632 .26315 L .6607 .2743 L .692 .608 0 r
F
.63199 .22847 m .60503 .23125 L .60826 .23692 L .767 .727 0 r
F
.63576 .23403 m .63199 .22847 L .60826 .23692 L .766 .719 0 r
F
.31908 .71969 m .27218 .70755 L .27295 .71345 L 1 .544 0 r
F
.31969 .72549 m .31908 .71969 L .27295 .71345 L 1 .532 0 r
F
.7011 .69636 m .65756 .69803 L .65689 .70397 L .673 .114 0 r
F
.7011 .69636 m .70195 .69035 L .65756 .69803 L F
.22163 .61141 m .17919 .59343 L .17914 .60002 L 1 .779 0 r
F
.22166 .6179 m .22163 .61141 L .17914 .60002 L 1 .769 0 r
F
.63181 .22875 m .60492 .23146 L .60814 .23713 L .765 .724 0 r
F
.63557 .23431 m .63181 .22875 L .60814 .23713 L .763 .716 0 r
F
.53922 .20353 m .51529 .20137 L .5167 .20699 L .899 .881 0 r
F
.54135 .20912 m .53922 .20353 L .5167 .20699 L .9 .875 0 r
F
.53921 .20359 m .51529 .20137 L .5167 .20699 L .896 .879 0 r
F
.54134 .20918 m .53921 .20359 L .5167 .20699 L .897 .873 0 r
F
.68594 .26355 m .65703 .26873 L .66041 .27462 L .691 .614 0 r
F
.68975 .26934 m .68594 .26355 L .66041 .27462 L .689 .605 0 r
F
.41669 .76048 m .36901 .7524 L .36955 .75789 L 1 .393 0 r
F
.41698 .76588 m .41669 .76048 L .36955 .75789 L 1 .379 0 r
F
.46429 .76689 m .41669 .76048 L .41698 .76588 L .986 .334 0 r
F
.32058 .71069 m .27464 .69808 L .27534 .70395 L 1 .558 0 r
F
.32116 .71643 m .32058 .71069 L .27534 .70395 L 1 .545 0 r
F
.60506 .75512 m .55952 .75342 L .55898 .75887 L .801 .167 0 r
F
.60506 .75512 m .60588 .74964 L .55952 .75342 L F
.39404 .22891 m .37427 .22033 L .37134 .2256 L 1 1 0 r
F
.39404 .22891 m .3963 .22339 L .37427 .22033 L F
.65272 .73296 m .60811 .73287 L .60741 .73851 L .737 .132 0 r
F
.65272 .73296 m .65366 .72726 L .60811 .73287 L F
.36926 .73811 m .32243 .72777 L .32313 .73336 L 1 .468 0 r
F
.36975 .74359 m .36926 .73811 L .32313 .73336 L 1 .455 0 r
F
.7871 .54619 m .74762 .55237 L .74813 .559 L .557 .168 0 r
F
.7871 .54619 m .7865 .5395 L .74762 .55237 L F
.28556 .60228 m .239 .59025 L .23929 .59614 L 1 .553 0 r
F
.2862 .60767 m .28556 .60228 L .23929 .59614 L 1 .542 0 r
F
.34135 .60308 m .28556 .60228 L .2862 .60767 L .761 .059 0 r
F
.34135 .60308 m .33962 .59938 L .28556 .60228 L F
.36497 .2225 m .34547 .21035 L .34182 .21568 L 1 1 0 r
F
.36497 .2225 m .36796 .21699 L .34547 .21035 L F
.4643 .77221 m .46429 .76689 L .41698 .76588 L .982 .32 0 r
F
.5113 .77168 m .46429 .76689 L .4643 .77221 L .925 .267 0 r
F
.5113 .77168 m .5116 .76637 L .46429 .76689 L F
.19073 .48612 m .15513 .46505 L .15354 .47181 L 1 .967 0 r
F
.18943 .49286 m .19073 .48612 L .15354 .47181 L 1 .96 0 r
F
.78391 .53902 m .74508 .54528 L .7456 .55185 L .552 .165 0 r
F
.78391 .53902 m .78331 .53239 L .74508 .54528 L F
.55745 .76116 m .51146 .75805 L .51117 .76329 L .861 .208 0 r
F
.55745 .76116 m .55804 .7559 L .51146 .75805 L F
.36849 .74685 m .32103 .73694 L .32177 .74258 L 1 .459 0 r
F
.36901 .7524 m .36849 .74685 L .32177 .74258 L 1 .446 0 r
F
.31578 .27266 m .29487 .25897 L .29111 .26431 L 1 1 0 r
F
.31578 .27266 m .31896 .26705 L .29487 .25897 L F
.27196 .66815 m .22777 .65299 L .22823 .65917 L 1 .666 0 r
F
.27239 .67422 m .27196 .66815 L .22823 .65917 L 1 .655 0 r
F
.35996 .24721 m .34039 .23718 L .33694 .24232 L 1 1 0 r
F
.35996 .24721 m .36275 .24173 L .34039 .23718 L F
.36508 .22276 m .34564 .21072 L .342 .21604 L F
.36508 .22276 m .36806 .21725 L .34564 .21072 L F
.22669 .59605 m .1859 .57801 L .18564 .58452 L 1 .81 0 r
F
.22654 .60248 m .22669 .59605 L .18564 .58452 L 1 .8 0 r
F
.74566 .63555 m .70428 .63947 L .7039 .64568 L .601 .106 0 r
F
.74566 .63555 m .7461 .62927 L .70428 .63947 L F
.32423 .24322 m .30405 .22866 L .30004 .23409 L 1 1 0 r
F
.32423 .24322 m .32766 .2376 L .30405 .22866 L F
.31406 .28011 m .29316 .26677 L .28938 .27199 L F
.31406 .28011 m .31718 .27452 L .29316 .26677 L F
.68242 .25741 m .65385 .26256 L .65731 .26841 L .696 .627 0 r
F
.68632 .26315 m .68242 .25741 L .65731 .26841 L .694 .618 0 r
F
.74799 .64349 m .70603 .64719 L .70564 .65346 L .607 .11 0 r
F
.74799 .64349 m .74846 .63714 L .70603 .64719 L F
.2386 .55409 m .19793 .53687 L .19754 .54317 L 1 .788 0 r
F
.23849 .56021 m .2386 .55409 L .19754 .54317 L 1 .776 0 r
F
.21076 .43362 m .21273 .42714 L .17941 .4134 L 1 1 0 r
F
.56368 .20432 m .53922 .20353 L .54135 .20912 L .861 .844 0 r
F
.56649 .20984 m .56368 .20432 L .54135 .20912 L .861 .837 0 r
F
.56364 .20444 m .53921 .20359 L .54134 .20918 L .859 .842 0 r
F
.56645 .20996 m .56364 .20444 L .54134 .20918 L .859 .835 0 r
F
.32442 .24353 m .30433 .22908 L .30031 .23448 L 1 1 0 r
F
.32442 .24353 m .32785 .23791 L .30433 .22908 L F
.18943 .49286 m .15354 .47181 L .15205 .47858 L 1 .96 0 r
F
.18821 .49961 m .18943 .49286 L .15205 .47858 L 1 .952 0 r
F
.68206 .2578 m .65359 .26287 L .65703 .26873 L .693 .623 0 r
F
.68594 .26355 m .68206 .2578 L .65703 .26873 L .691 .614 0 r
F
.21076 .43362 m .17941 .4134 L .17714 .41983 L 1 1 0 r
F
.20885 .44012 m .21076 .43362 L .17714 .41983 L F
.36203 .24015 m .3425 .22941 L .339 .2346 L F
.36203 .24015 m .36488 .23469 L .3425 .22941 L F
.5578 .76959 m .5116 .76637 L .5113 .77168 L .862 .207 0 r
F
.5578 .76959 m .5584 .76426 L .5116 .76637 L F
.78761 .55286 m .74813 .559 L .74857 .56561 L .553 .157 0 r
F
.78761 .55286 m .7871 .54619 L .74813 .559 L F
.20885 .44012 m .17714 .41983 L .17496 .42629 L 1 1 0 r
F
.20702 .44664 m .20885 .44012 L .17496 .42629 L F
.22166 .6179 m .17914 .60002 L .17916 .6066 L 1 .769 0 r
F
.22175 .62436 m .22166 .6179 L .17916 .6066 L 1 .759 0 r
F
.26965 .68348 m .22425 .66875 L .22487 .67495 L 1 .636 0 r
F
.2702 .68956 m .26965 .68348 L .22487 .67495 L 1 .624 0 r
F
.62816 .22296 m .60175 .22563 L .60503 .23125 L .768 .735 0 r
F
.63199 .22847 m .62816 .22296 L .60503 .23125 L .767 .727 0 r
F
.78443 .54563 m .7456 .55185 L .74606 .55841 L .547 .153 0 r
F
.78443 .54563 m .78391 .53902 L .7456 .55185 L F
.69861 .69402 m .65575 .69592 L .65504 .70175 L .664 .098 0 r
F
.69861 .69402 m .6995 .68812 L .65575 .69592 L F
.62799 .22323 m .60165 .22583 L .60492 .23146 L .766 .732 0 r
F
.63181 .22875 m .62799 .22323 L .60492 .23146 L .765 .724 0 r
F
.59166 .20907 m .56649 .20984 L .56927 .2154 L .819 .799 0 r
F
.59506 .21454 m .59166 .20907 L .56927 .2154 L .819 .792 0 r
F
.20702 .44664 m .17496 .42629 L .17285 .43278 L 1 1 0 r
F
.20526 .45317 m .20702 .44664 L .17285 .43278 L F
.59157 .20925 m .56645 .20996 L .56922 .21553 L .817 .797 0 r
F
.59498 .21473 m .59157 .20925 L .56922 .21553 L .817 .789 0 r
F
.18821 .49961 m .15205 .47858 L .15064 .48536 L 1 .952 0 r
F
.18706 .50636 m .18821 .49961 L .15064 .48536 L 1 .945 0 r
F
.31896 .26705 m .29869 .25369 L .29487 .25897 L 1 1 0 r
F
.31896 .26705 m .32219 .2615 L .29869 .25369 L F
.22654 .60248 m .18564 .58452 L .18546 .59101 L 1 .8 0 r
F
.22646 .60888 m .22654 .60248 L .18546 .59101 L 1 .79 0 r
F
.67846 .25172 m .65034 .25676 L .65385 .26256 L .699 .636 0 r
F
.68242 .25741 m .67846 .25172 L .65385 .26256 L .696 .627 0 r
F
.7002 .70233 m .65689 .70397 L .65616 .70986 L .669 .102 0 r
F
.7002 .70233 m .7011 .69636 L .65689 .70397 L F
.65071 .73016 m .60672 .7303 L .60599 .73583 L .729 .117 0 r
F
.65071 .73016 m .65168 .72458 L .60672 .7303 L F
.60357 .75207 m .55861 .75058 L .55804 .7559 L .795 .153 0 r
F
.60357 .75207 m .60442 .74671 L .55861 .75058 L F
.41732 .75728 m .37028 .74901 L .37084 .75438 L 1 .385 0 r
F
.41761 .76255 m .41732 .75728 L .37084 .75438 L 1 .371 0 r
F
.46437 .76375 m .41732 .75728 L .41761 .76255 L .985 .323 0 r
F
.31718 .27452 m .297 .26164 L .29316 .26677 L 1 1 0 r
F
.31718 .27452 m .32035 .269 L .297 .26164 L F
.20526 .45317 m .17285 .43278 L .17082 .43928 L F
.20357 .45971 m .20526 .45317 L .17082 .43928 L F
.31969 .72549 m .27295 .71345 L .27377 .71932 L 1 .532 0 r
F
.32034 .73124 m .31969 .72549 L .27377 .71932 L 1 .519 0 r
F
.23849 .56021 m .19754 .54317 L .19722 .54945 L 1 .776 0 r
F
.23846 .56629 m .23849 .56021 L .19722 .54945 L 1 .763 0 r
F
.67812 .25211 m .6501 .25707 L .65359 .26287 L .696 .632 0 r
F
.68206 .2578 m .67812 .25211 L .65359 .26287 L .693 .623 0 r
F
.32116 .71643 m .27534 .70395 L .27609 .70976 L 1 .545 0 r
F
.32177 .72212 m .32116 .71643 L .27609 .70976 L 1 .533 0 r
F
.2862 .60767 m .23929 .59614 L .23963 .60199 L 1 .542 0 r
F
.28686 .61302 m .2862 .60767 L .23963 .60199 L 1 .533 0 r
F
.34275 .60698 m .2862 .60767 L .28686 .61302 L .785 .07 0 r
F
.34275 .60698 m .34135 .60308 L .2862 .60767 L F
.46438 .76894 m .46437 .76375 L .41761 .76255 L .981 .309 0 r
F
.51086 .76847 m .46437 .76375 L .46438 .76894 L .922 .255 0 r
F
.51086 .76847 m .51117 .76329 L .46437 .76375 L F
.32766 .2376 m .30812 .22329 L .30405 .22866 L 1 1 0 r
F
.32766 .2376 m .33113 .23203 L .30812 .22329 L F
.36275 .24173 m .34388 .23209 L .34039 .23718 L F
.36275 .24173 m .36558 .2363 L .34388 .23209 L F
.3963 .22339 m .37724 .21511 L .37427 .22033 L F
.36796 .21699 m .34916 .20508 L .34547 .21035 L F
.36796 .21699 m .37099 .21153 L .34916 .20508 L F
.27239 .67422 m .22823 .65917 L .22875 .66532 L 1 .655 0 r
F
.27287 .68024 m .27239 .67422 L .22875 .66532 L 1 .643 0 r
F
.74514 .64181 m .7039 .64568 L .70346 .65186 L .597 .094 0 r
F
.74514 .64181 m .74566 .63555 L .7039 .64568 L F
.78803 .55953 m .74857 .56561 L .74893 .57221 L .549 .145 0 r
F
.78803 .55953 m .78761 .55286 L .74857 .56561 L F
.20357 .45971 m .17082 .43928 L .16888 .4458 L 1 1 0 r
F
.20196 .46627 m .20357 .45971 L .16888 .4458 L F
.36806 .21725 m .34933 .20546 L .34564 .21072 L F
.36806 .21725 m .37109 .2118 L .34933 .20546 L F
.32785 .23791 m .3084 .22374 L .30433 .22908 L F
.32785 .23791 m .33132 .23236 L .3084 .22374 L F
.53706 .198 m .51387 .1958 L .51529 .20137 L .897 .887 0 r
F
.53922 .20353 m .53706 .198 L .51529 .20137 L .899 .881 0 r
F
.53705 .19806 m .51387 .1958 L .51529 .20137 L .895 .885 0 r
F
.53921 .20359 m .53705 .19806 L .51529 .20137 L .896 .879 0 r
F
.74745 .64981 m .70564 .65346 L .70518 .6597 L .603 .098 0 r
F
.74745 .64981 m .74799 .64349 L .70564 .65346 L F
.65173 .73861 m .60741 .73851 L .60666 .7441 L .733 .119 0 r
F
.65173 .73861 m .65272 .73296 L .60741 .73851 L F
.36975 .74359 m .32313 .73336 L .32387 .7389 L 1 .455 0 r
F
.37028 .74901 m .36975 .74359 L .32387 .7389 L 1 .441 0 r
F
.18706 .50636 m .15064 .48536 L .14932 .49214 L 1 .945 0 r
F
.18599 .51311 m .18706 .50636 L .14932 .49214 L 1 .937 0 r
F
.78486 .55223 m .74606 .55841 L .74643 .56496 L .543 .141 0 r
F
.78486 .55223 m .78443 .54563 L .74606 .55841 L F
.41698 .76588 m .36955 .75789 L .37013 .76332 L 1 .379 0 r
F
.41728 .77122 m .41698 .76588 L .37013 .76332 L 1 .365 0 r
F
.4643 .77221 m .41698 .76588 L .41728 .77122 L .982 .32 0 r
F
.26638 .28553 m .26989 .2796 L .24409 .26755 L 1 1 0 r
F
.6042 .76055 m .55898 .75887 L .5584 .76426 L .797 .154 0 r
F
.6042 .76055 m .60506 .75512 L .55898 .75887 L F
.26661 .28575 m .27012 .27983 L .24429 .26774 L 1 1 0 r
F
.20196 .46627 m .16888 .4458 L .16702 .45234 L F
.20041 .47283 m .20196 .46627 L .16702 .45234 L 1 .993 0 r
F
.22175 .62436 m .17916 .6066 L .17927 .61315 L 1 .759 0 r
F
.2219 .63079 m .22175 .62436 L .17927 .61315 L 1 .748 0 r
F
.36901 .7524 m .32177 .74258 L .32255 .74817 L 1 .446 0 r
F
.36955 .75789 m .36901 .7524 L .32255 .74817 L 1 .432 0 r
F
.36488 .23469 m .34603 .22429 L .3425 .22941 L 1 1 0 r
F
.36488 .23469 m .36777 .22928 L .34603 .22429 L F
.4643 .77747 m .4643 .77221 L .41728 .77122 L .977 .306 0 r
F
.51099 .77693 m .4643 .77221 L .4643 .77747 L .92 .253 0 r
F
.51099 .77693 m .5113 .77168 L .4643 .77221 L F
.55063 .29252 m .52095 .29824 L .52133 .30567 L 1 .789 0 r
F
.55063 .29252 m .54967 .28552 L .52552 .29622 L F
.54967 .28552 m .52051 .2908 L .52095 .29824 L 1 .798 0 r
F
.54967 .28552 m .54863 .27854 L .52549 .28863 L F
.52549 .2899 m .52549 .28863 L .52051 .2908 L F
.54967 .28552 m .52549 .28863 L .52549 .2899 L F
.54863 .27854 m .52 .28337 L .52051 .2908 L 1 .806 0 r
F
.54863 .27854 m .5475 .27159 L .52532 .28109 L F
.52539 .28246 m .52532 .28109 L .52 .28337 L F
.54863 .27854 m .52532 .28109 L .52539 .28246 L F
.5475 .27159 m .51942 .27595 L .52 .28337 L 1 .814 0 r
F
.5475 .27159 m .54629 .26467 L .52504 .27359 L F
.52517 .27506 m .52504 .27359 L .51942 .27595 L F
.5475 .27159 m .52504 .27359 L .52517 .27506 L F
.54629 .26467 m .51878 .26857 L .51942 .27595 L 1 .822 0 r
F
.54629 .26467 m .545 .2578 L .52463 .26617 L F
.52485 .26771 m .52463 .26617 L .51878 .26857 L F
.54629 .26467 m .52463 .26617 L .52485 .26771 L F
.545 .2578 m .51807 .26124 L .51878 .26857 L 1 .83 0 r
F
.545 .2578 m .54363 .25097 L .52411 .25882 L F
.52442 .26043 m .52411 .25882 L .51807 .26124 L F
.545 .2578 m .52411 .25882 L .52442 .26043 L F
.54363 .25097 m .5173 .25397 L .51807 .26124 L 1 .838 0 r
F
.54363 .25097 m .54219 .2442 L .52349 .25154 L F
.5239 .25322 m .52349 .25154 L .5173 .25397 L F
.54363 .25097 m .52349 .25154 L .5239 .25322 L F
.54219 .2442 m .51647 .24677 L .5173 .25397 L 1 .845 0 r
F
.54219 .2442 m .54068 .23749 L .52277 .24435 L F
.52329 .24609 m .52277 .24435 L .51647 .24677 L F
.54219 .2442 m .52277 .24435 L .52329 .24609 L F
.54068 .23749 m .51558 .23963 L .51647 .24677 L 1 .853 0 r
F
.54068 .23749 m .5391 .23084 L .51558 .23963 L F
.5404 .23847 m .53887 .23171 L .52081 .23786 L 1 .826 0 r
F
.52126 .23937 m .52081 .23786 L .51558 .23964 L F
.5404 .23847 m .52081 .23786 L .52126 .23937 L F
.54186 .24531 m .5404 .23847 L .52187 .2449 L 1 .815 0 r
F
.52224 .24644 m .52187 .2449 L .51647 .24677 L F
.54186 .24531 m .52187 .2449 L .52224 .24644 L F
.54324 .25222 m .54186 .24531 L .52282 .25203 L 1 .804 0 r
F
.52312 .25358 m .52282 .25203 L .5173 .25398 L F
.54324 .25222 m .52282 .25203 L .52312 .25358 L F
.54454 .25919 m .54324 .25222 L .52366 .25925 L 1 .792 0 r
F
.52388 .2608 m .52366 .25925 L .51807 .26125 L F
.54454 .25919 m .52366 .25925 L .52388 .2608 L F
.54575 .26623 m .54454 .25919 L .52438 .26654 L 1 .78 0 r
F
.52452 .26808 m .52438 .26654 L .51878 .26859 L F
.54575 .26623 m .52438 .26654 L .52452 .26808 L F
.54687 .27332 m .54575 .26623 L .52497 .27391 L 1 .767 0 r
F
.52505 .27543 m .52497 .27391 L .51942 .27597 L F
.54687 .27332 m .52497 .27391 L .52505 .27543 L F
.54789 .28046 m .54687 .27332 L .52543 .28135 L 1 .754 0 r
F
.52544 .28282 m .52543 .28135 L .51999 .28339 L F
.54789 .28046 m .52543 .28135 L .52544 .28282 L F
.54882 .28764 m .54789 .28046 L .52575 .28884 L 1 .741 0 r
F
.52571 .29025 m .52575 .28884 L .5205 .29083 L F
.54882 .28764 m .52575 .28884 L .52571 .29025 L F
.52548 .29737 m .52552 .29622 L .52095 .29824 L 1 .789 0 r
F
.55063 .29252 m .52552 .29622 L .52548 .29737 L F
.55151 .29954 m .55063 .29252 L .52542 .30384 L 1 .781 0 r
F
.54965 .29485 m .54882 .28764 L .52593 .29638 L 1 .727 0 r
F
.52584 .2977 m .52593 .29638 L .52094 .29829 L F
.54965 .29485 m .52593 .29638 L .52584 .2977 L F
.52535 .30486 m .52542 .30384 L .52133 .30567 L 1 .781 0 r
F
.55151 .29954 m .52542 .30384 L .52535 .30486 L F
.57929 .28179 m .54967 .28552 L .55063 .29252 L .996 .729 0 r
F
.58078 .28849 m .55063 .29252 L .55151 .29954 L 1 .72 0 r
F
.58078 .28849 m .57929 .28179 L .55063 .29252 L F
.55151 .29954 m .52133 .30567 L .52164 .31307 L 1 .781 0 r
F
.5523 .30655 m .55151 .29954 L .52518 .31146 L 1 .773 0 r
F
.55038 .30208 m .54965 .29485 L .52597 .30394 L 1 .713 0 r
F
.52584 .30516 m .52597 .30394 L .52131 .30573 L F
.55038 .30208 m .52597 .30394 L .52584 .30516 L F
.52509 .31233 m .52518 .31146 L .52164 .31307 L 1 .773 0 r
F
.5523 .30655 m .52518 .31146 L .52509 .31233 L F
.58218 .29521 m .55151 .29954 L .5523 .30655 L 1 .712 0 r
F
.58218 .29521 m .58078 .28849 L .55151 .29954 L F
.67444 .24608 m .64678 .251 L .65034 .25676 L .701 .645 0 r
F
.67846 .25172 m .67444 .24608 L .65034 .25676 L .699 .636 0 r
F
.55684 .76636 m .51117 .76329 L .51086 .76847 L .857 .194 0 r
F
.55684 .76636 m .55745 .76116 L .51117 .76329 L F
.5777 .2751 m .54863 .27854 L .54967 .28552 L .991 .737 0 r
F
.57929 .28179 m .5777 .2751 L .54967 .28552 L .996 .729 0 r
F
.32219 .2615 m .30255 .24848 L .29869 .25369 L 1 1 0 r
F
.32219 .2615 m .32546 .256 L .30255 .24848 L F
.62428 .21751 m .59843 .22006 L .60175 .22563 L .77 .743 0 r
F
.62816 .22296 m .62428 .21751 L .60175 .22563 L .768 .735 0 r
F
.5523 .30655 m .52164 .31307 L .52189 .32041 L 1 .773 0 r
F
.55301 .31354 m .5523 .30655 L .52483 .31907 L 1 .765 0 r
F
.55101 .30932 m .55038 .30208 L .52587 .31151 L 1 .699 0 r
F
.52572 .31261 m .52587 .31151 L .52162 .31314 L F
.55101 .30932 m .52587 .31151 L .52572 .31261 L F
.52473 .31978 m .52483 .31907 L .52189 .32041 L 1 .765 0 r
F
.55301 .31354 m .52483 .31907 L .52473 .31978 L F
.58348 .30194 m .5523 .30655 L .55301 .31354 L 1 .703 0 r
F
.58348 .30194 m .58218 .29521 L .5523 .30655 L F
.58469 .30868 m .58348 .30194 L .55301 .31354 L 1 .695 0 r
F
.61235 .29119 m .58218 .29521 L .58348 .30194 L .903 .643 0 r
F
.61413 .29773 m .58348 .30194 L .58469 .30868 L .906 .633 0 r
F
.61413 .29773 m .61235 .29119 L .58348 .30194 L F
.23887 .36488 m .24148 .35871 L .21183 .34575 L 1 1 0 r
F
.58469 .30868 m .55301 .31354 L .55364 .32052 L 1 .695 0 r
F
.5858 .3154 m .58469 .30868 L .55364 .32052 L 1 .687 0 r
F
.6158 .30427 m .58469 .30868 L .5858 .3154 L .908 .624 0 r
F
.6158 .30427 m .61413 .29773 L .58469 .30868 L F
.56083 .19885 m .53706 .198 L .53922 .20353 L .86 .851 0 r
F
.56368 .20432 m .56083 .19885 L .53922 .20353 L .861 .844 0 r
F
.22646 .60888 m .18546 .59101 L .18536 .59748 L 1 .79 0 r
F
.22645 .61526 m .22646 .60888 L .18536 .59748 L 1 .78 0 r
F
.56079 .19897 m .53705 .19806 L .53921 .20359 L .858 .849 0 r
F
.56364 .20444 m .56079 .19897 L .53921 .20359 L .859 .842 0 r
F
.67411 .24646 m .64655 .2513 L .6501 .25707 L .698 .642 0 r
F
.67812 .25211 m .67411 .24646 L .6501 .25707 L .696 .632 0 r
F
.62412 .21777 m .59833 .22025 L .60165 .22583 L .767 .741 0 r
F
.62799 .22323 m .62412 .21777 L .60165 .22583 L .766 .732 0 r
F
.61047 .28467 m .58078 .28849 L .58218 .29521 L .901 .652 0 r
F
.61235 .29119 m .61047 .28467 L .58218 .29521 L .903 .643 0 r
F
.5858 .3154 m .55364 .32052 L .55418 .32745 L 1 .687 0 r
F
.58682 .32211 m .5858 .3154 L .55418 .32745 L 1 .679 0 r
F
.61736 .31082 m .5858 .3154 L .58682 .32211 L .911 .614 0 r
F
.61736 .31082 m .6158 .30427 L .5858 .3154 L F
.32035 .269 m .30092 .25662 L .297 .26164 L 1 1 0 r
F
.32035 .269 m .32358 .26354 L .30092 .25662 L F
.57602 .26844 m .5475 .27159 L .54863 .27854 L .986 .746 0 r
F
.5777 .2751 m .57602 .26844 L .54863 .27854 L .991 .737 0 r
F
.20041 .47283 m .16702 .45234 L .16524 .45889 L 1 .993 0 r
F
.19894 .4794 m .20041 .47283 L .16524 .45889 L 1 .986 0 r
F
.2702 .68956 m .22487 .67495 L .22557 .68112 L 1 .624 0 r
F
.2708 .6956 m .2702 .68956 L .22557 .68112 L 1 .613 0 r
F
.18599 .51311 m .14932 .49214 L .14809 .49893 L 1 .937 0 r
F
.18499 .51985 m .18599 .51311 L .14809 .49893 L 1 .929 0 r
F
.23846 .56629 m .19722 .54945 L .19698 .5557 L 1 .763 0 r
F
.2385 .57234 m .23846 .56629 L .19698 .5557 L 1 .751 0 r
F
.55301 .31354 m .52189 .32041 L .52209 .32767 L 1 .765 0 r
F
.55364 .32052 m .55301 .31354 L .52435 .32664 L 1 .757 0 r
F
.55154 .31655 m .55101 .30932 L .52563 .31906 L 1 .684 0 r
F
.52547 .32002 m .52563 .31906 L .52186 .3205 L F
.55154 .31655 m .52563 .31906 L .52547 .32002 L F
.52426 .32718 m .52435 .32664 L .52209 .32767 L 1 .757 0 r
F
.55364 .32052 m .52435 .32664 L .52426 .32718 L F
.26989 .2796 m .24815 .26184 L .24409 .26755 L 1 1 0 r
F
.26989 .2796 m .27346 .27372 L .24815 .26184 L F
.60849 .27817 m .57929 .28179 L .58078 .28849 L .898 .662 0 r
F
.61047 .28467 m .60849 .27817 L .58078 .28849 L .901 .652 0 r
F
.58682 .32211 m .55418 .32745 L .55465 .33433 L 1 .679 0 r
F
.58774 .32879 m .58682 .32211 L .55465 .33433 L 1 .672 0 r
F
.61883 .31736 m .58682 .32211 L .58774 .32879 L .914 .605 0 r
F
.61883 .31736 m .61736 .31082 L .58682 .32211 L F
.78837 .56618 m .74893 .57221 L .74922 .5788 L .544 .133 0 r
F
.78837 .56618 m .78803 .55953 L .74893 .57221 L F
.69766 .69987 m .65504 .70175 L .65428 .70753 L .659 .086 0 r
F
.69766 .69987 m .69861 .69402 L .65504 .70175 L F
.27012 .27983 m .24836 .26205 L .24429 .26774 L 1 1 0 r
F
.27012 .27983 m .27369 .27397 L .24836 .26205 L F
.2152 .43442 m .21697 .42801 L .18346 .41433 L F
.58821 .20365 m .56368 .20432 L .56649 .20984 L .819 .806 0 r
F
.59166 .20907 m .58821 .20365 L .56649 .20984 L .819 .799 0 r
F
.78521 .55882 m .74643 .56496 L .74674 .57149 L .538 .129 0 r
F
.78521 .55882 m .78486 .55223 L .74643 .56496 L F
.57425 .26182 m .54629 .26467 L .5475 .27159 L .982 .755 0 r
F
.57602 .26844 m .57425 .26182 L .5475 .27159 L .986 .746 0 r
F
.58813 .20383 m .56364 .20444 L .56645 .20996 L .817 .804 0 r
F
.59157 .20925 m .58813 .20383 L .56645 .20996 L .817 .797 0 r
F
.33113 .23203 m .31224 .21799 L .30812 .22329 L 1 1 0 r
F
.33113 .23203 m .33465 .22652 L .31224 .21799 L F
.55718 .77486 m .5113 .77168 L .51099 .77693 L .857 .193 0 r
F
.55718 .77486 m .5578 .76959 L .5113 .77168 L F
.6064 .27169 m .5777 .2751 L .57929 .28179 L .896 .672 0 r
F
.60849 .27817 m .6064 .27169 L .57929 .28179 L .898 .662 0 r
F
.55364 .32052 m .52209 .32767 L .52224 .33484 L 1 .757 0 r
F
.55418 .32745 m .55364 .32052 L .52378 .33414 L 1 .749 0 r
F
.55197 .32376 m .55154 .31655 L .52527 .32657 L 1 .669 0 r
F
.52511 .32738 m .52527 .32657 L .52205 .32779 L F
.55197 .32376 m .52527 .32657 L .52511 .32738 L F
.52371 .3345 m .52378 .33414 L .52224 .33484 L 1 .749 0 r
F
.55418 .32745 m .52378 .33414 L .52371 .3345 L F
.58774 .32879 m .55465 .33433 L .55504 .34115 L 1 .672 0 r
F
.58857 .33544 m .58774 .32879 L .55504 .34115 L 1 .664 0 r
F
.62018 .32388 m .58774 .32879 L .58857 .33544 L .917 .596 0 r
F
.62018 .32388 m .61883 .31736 L .58774 .32879 L F
.19894 .4794 m .16524 .45889 L .16355 .46546 L 1 .986 0 r
F
.19755 .48598 m .19894 .4794 L .16355 .46546 L 1 .979 0 r
F
.69923 .70825 m .65616 .70986 L .65538 .71571 L .664 .09 0 r
F
.69923 .70825 m .7002 .70233 L .65616 .70986 L F
.2152 .43442 m .18346 .41433 L .1814 .42071 L 1 1 0 r
F
.21352 .44084 m .2152 .43442 L .1814 .42071 L F
.33132 .23236 m .31252 .21846 L .3084 .22374 L F
.33132 .23236 m .33483 .22686 L .31252 .21846 L F
.74454 .64803 m .70346 .65186 L .70296 .658 L .592 .082 0 r
F
.74454 .64803 m .74514 .64181 L .70346 .65186 L F
.36558 .2363 m .3474 .22708 L .34388 .23209 L 1 1 0 r
F
.36558 .2363 m .36844 .23092 L .3474 .22708 L F
.28686 .61302 m .23963 .60199 L .24002 .6078 L 1 .533 0 r
F
.28752 .61834 m .28686 .61302 L .24002 .6078 L 1 .526 0 r
F
.3438 .61113 m .28686 .61302 L .28752 .61834 L .811 .132 0 r
F
.3438 .61113 m .34275 .60698 L .28686 .61302 L F
.27287 .68024 m .22875 .66532 L .22934 .67143 L 1 .643 0 r
F
.2734 .68623 m .27287 .68024 L .22934 .67143 L 1 .631 0 r
F
.74684 .6561 m .70518 .6597 L .70467 .6659 L .598 .087 0 r
F
.74684 .6561 m .74745 .64981 L .70518 .6597 L F
.67036 .2405 m .64316 .24529 L .64678 .251 L .703 .654 0 r
F
.67444 .24608 m .67036 .2405 L .64678 .251 L .701 .645 0 r
F
.64969 .73569 m .60599 .73583 L .60522 .7413 L .724 .104 0 r
F
.64969 .73569 m .65071 .73016 L .60599 .73583 L F
.18499 .51985 m .14809 .49893 L .14694 .50571 L 1 .929 0 r
F
.18408 .52659 m .18499 .51985 L .14694 .50571 L 1 .921 0 r
F
.58857 .33544 m .55504 .34115 L .55536 .3479 L 1 .664 0 r
F
.58931 .34204 m .58857 .33544 L .55536 .3479 L 1 .657 0 r
F
.62144 .33039 m .58857 .33544 L .58931 .34204 L .92 .588 0 r
F
.62144 .33039 m .62018 .32388 L .58857 .33544 L F
.37099 .21153 m .3529 .19988 L .34916 .20508 L 1 1 0 r
F
.37099 .21153 m .37405 .20613 L .3529 .19988 L F
.32034 .73124 m .27377 .71932 L .27465 .72513 L 1 .519 0 r
F
.32103 .73694 m .32034 .73124 L .27465 .72513 L 1 .506 0 r
F
.60421 .26524 m .57602 .26844 L .5777 .2751 L .893 .682 0 r
F
.6064 .27169 m .60421 .26524 L .5777 .2751 L .896 .672 0 r
F
.57239 .25524 m .545 .2578 L .54629 .26467 L .977 .764 0 r
F
.57425 .26182 m .57239 .25524 L .54629 .26467 L .982 .755 0 r
F
.27346 .27372 m .25228 .2562 L .24815 .26184 L 1 1 0 r
F
.27346 .27372 m .27709 .2679 L .25228 .2562 L F
.21352 .44084 m .1814 .42071 L .17942 .42711 L F
.21191 .44727 m .21352 .44084 L .17942 .42711 L 1 .994 0 r
F
.32177 .72212 m .27609 .70976 L .27691 .71553 L 1 .533 0 r
F
.32243 .72777 m .32177 .72212 L .27691 .71553 L 1 .52 0 r
F
.55418 .32745 m .52224 .33484 L .52234 .34189 L 1 .749 0 r
F
.55465 .33433 m .55418 .32745 L .52312 .34154 L 1 .742 0 r
F
.55231 .33092 m .55197 .32376 L .52479 .334 L 1 .654 0 r
F
.52465 .33465 m .52479 .334 L .52219 .33499 L F
.55231 .33092 m .52479 .334 L .52465 .33465 L F
.52308 .34172 m .52312 .34154 L .52234 .34189 L 1 .742 0 r
F
.55465 .33433 m .52312 .34154 L .52308 .34172 L F
.2219 .63079 m .17927 .61315 L .17945 .61968 L 1 .748 0 r
F
.22213 .6372 m .2219 .63079 L .17945 .61968 L 1 .738 0 r
F
.67005 .24087 m .64294 .24559 L .64655 .2513 L .701 .651 0 r
F
.67411 .24646 m .67005 .24087 L .64655 .2513 L .698 .642 0 r
F
.60269 .75736 m .55804 .7559 L .55745 .76116 L .79 .139 0 r
F
.60269 .75736 m .60357 .75207 L .55804 .7559 L F
.37109 .2118 m .35306 .20027 L .34933 .20546 L 1 1 0 r
F
.37109 .2118 m .37414 .2064 L .35306 .20027 L F
.19755 .48598 m .16355 .46546 L .16194 .47204 L 1 .979 0 r
F
.19623 .49257 m .19755 .48598 L .16194 .47204 L 1 .971 0 r
F
.27369 .27397 m .25251 .25643 L .24836 .26205 L 1 1 0 r
F
.27369 .27397 m .27732 .26816 L .25251 .25643 L F
.32546 .256 m .30648 .24335 L .30255 .24848 L F
.32546 .256 m .32878 .25056 L .30648 .24335 L F
.41761 .76255 m .37084 .75438 L .37143 .75969 L 1 .371 0 r
F
.41793 .76776 m .41761 .76255 L .37143 .75969 L 1 .357 0 r
F
.46438 .76894 m .41761 .76255 L .41793 .76776 L .981 .309 0 r
F
.22645 .61526 m .18536 .59748 L .18534 .60393 L 1 .78 0 r
F
.2265 .62162 m .22645 .61526 L .18534 .60393 L 1 .769 0 r
F
.32358 .26354 m .30489 .25169 L .30092 .25662 L 1 1 0 r
F
.32358 .26354 m .32685 .25814 L .30489 .25169 L F
.78862 .57282 m .74922 .5788 L .74944 .58537 L .54 .121 0 r
F
.78862 .57282 m .78837 .56618 L .74922 .5788 L F
.21191 .44727 m .17942 .42711 L .17754 .43353 L 1 .994 0 r
F
.21039 .4537 m .21191 .44727 L .17754 .43353 L 1 .986 0 r
F
.2385 .57234 m .19698 .5557 L .19682 .56193 L 1 .751 0 r
F
.2386 .57835 m .2385 .57234 L .19682 .56193 L 1 .738 0 r
F
.58931 .34204 m .55536 .3479 L .55563 .35455 L 1 .657 0 r
F
.58996 .34859 m .58931 .34204 L .55563 .35455 L 1 .651 0 r
F
.62259 .33687 m .58931 .34204 L .58996 .34859 L .923 .58 0 r
F
.62259 .33687 m .62144 .33039 L .58931 .34204 L F
.36777 .22928 m .34961 .21923 L .34603 .22429 L 1 1 0 r
F
.36777 .22928 m .37069 .22393 L .34961 .21923 L F
.65069 .74421 m .60666 .7441 L .60588 .74964 L .728 .107 0 r
F
.65069 .74421 m .65173 .73861 L .60666 .7441 L F
.46439 .77406 m .46438 .76894 L .41793 .76776 L .976 .295 0 r
F
.51055 .77359 m .46438 .76894 L .46439 .77406 L .917 .241 0 r
F
.51055 .77359 m .51086 .76847 L .46438 .76894 L F
.60192 .25883 m .57425 .26182 L .57602 .26844 L .891 .692 0 r
F
.60421 .26524 m .60192 .25883 L .57602 .26844 L .893 .682 0 r
F
.62034 .21211 m .59506 .21454 L .59843 .22006 L .771 .751 0 r
F
.62428 .21751 m .62034 .21211 L .59843 .22006 L .77 .743 0 r
F
.78547 .56539 m .74674 .57149 L .74697 .578 L .533 .117 0 r
F
.78547 .56539 m .78521 .55882 L .74674 .57149 L F
.54882 .28764 m .5205 .29083 L .52094 .29829 L 1 .741 0 r
F
.57608 .27822 m .54789 .28046 L .54882 .28764 L .961 .678 0 r
F
.57742 .28522 m .54882 .28764 L .54965 .29485 L .963 .663 0 r
F
.57742 .28522 m .57608 .27822 L .54882 .28764 L F
.54789 .28046 m .51999 .28339 L .5205 .29083 L 1 .754 0 r
F
.57462 .27127 m .54687 .27332 L .54789 .28046 L .959 .693 0 r
F
.57608 .27822 m .57462 .27127 L .54789 .28046 L .961 .678 0 r
F
.37028 .74901 m .32387 .7389 L .32466 .74439 L 1 .441 0 r
F
.37084 .75438 m .37028 .74901 L .32466 .74439 L 1 .427 0 r
F
.57044 .2487 m .54363 .25097 L .545 .2578 L .973 .773 0 r
F
.57239 .25524 m .57044 .2487 L .545 .2578 L .977 .764 0 r
F
.6202 .21237 m .59498 .21473 L .59833 .22025 L .769 .749 0 r
F
.62412 .21777 m .6202 .21237 L .59833 .22025 L .767 .741 0 r
F
.53488 .19251 m .51242 .19027 L .51387 .1958 L .896 .893 0 r
F
.53706 .198 m .53488 .19251 L .51387 .1958 L .897 .887 0 r
F
.53487 .19257 m .51242 .19027 L .51387 .1958 L .894 .891 0 r
F
.53705 .19806 m .53487 .19257 L .51387 .1958 L .895 .885 0 r
F
.54965 .29485 m .52094 .29829 L .52131 .30573 L 1 .727 0 r
F
.57864 .29226 m .54965 .29485 L .55038 .30208 L .964 .647 0 r
F
.57864 .29226 m .57742 .28522 L .54965 .29485 L F
.55465 .33433 m .52234 .34189 L .52241 .34881 L 1 .742 0 r
F
.55504 .34115 m .55465 .33433 L .52241 .34881 L 1 .734 0 r
F
.19623 .49257 m .16194 .47204 L .16042 .47863 L 1 .971 0 r
F
.19498 .49916 m .19623 .49257 L .16042 .47863 L 1 .964 0 r
F
.54687 .27332 m .51942 .27597 L .51999 .28339 L 1 .767 0 r
F
.57305 .26438 m .54575 .26623 L .54687 .27332 L .957 .707 0 r
F
.57462 .27127 m .57305 .26438 L .54687 .27332 L .959 .693 0 r
F
.18408 .52659 m .14694 .50571 L .14589 .5125 L 1 .921 0 r
F
.18324 .53332 m .18408 .52659 L .14589 .5125 L 1 .912 0 r
F
.6033 .76591 m .5584 .76426 L .5578 .76959 L .791 .14 0 r
F
.6033 .76591 m .6042 .76055 L .5584 .76426 L F
.41728 .77122 m .37013 .76332 L .37073 .76869 L 1 .365 0 r
F
.4176 .77649 m .41728 .77122 L .37073 .76869 L 1 .351 0 r
F
.4643 .77747 m .41728 .77122 L .4176 .77649 L .977 .306 0 r
F
.21039 .4537 m .17754 .43353 L .17574 .43995 L 1 .986 0 r
F
.20894 .46013 m .21039 .4537 L .17574 .43995 L 1 .978 0 r
F
.27709 .2679 m .25648 .25061 L .25228 .2562 L 1 1 0 r
F
.27709 .2679 m .28077 .26212 L .25648 .25061 L F
.55038 .30208 m .52131 .30573 L .52162 .31314 L 1 .713 0 r
F
.57972 .29933 m .55038 .30208 L .55101 .30932 L .965 .631 0 r
F
.57972 .29933 m .57864 .29226 L .55038 .30208 L F
.2708 .6956 m .22557 .68112 L .22633 .68725 L 1 .613 0 r
F
.27146 .70159 m .2708 .6956 L .22633 .68725 L 1 .6 0 r
F
.36955 .75789 m .32255 .74817 L .32337 .75371 L 1 .432 0 r
F
.37013 .76332 m .36955 .75789 L .32337 .75371 L 1 .418 0 r
F
.33465 .22652 m .31641 .21275 L .31224 .21799 L 1 1 0 r
F
.33465 .22652 m .33821 .22107 L .31641 .21275 L F
.58996 .34859 m .55563 .35455 L .55584 .3611 L 1 .651 0 r
F
.59054 .35508 m .58996 .34859 L .55584 .3611 L 1 .645 0 r
F
.62364 .34332 m .58996 .34859 L .59054 .35508 L .925 .572 0 r
F
.62364 .34332 m .62259 .33687 L .58996 .34859 L F
.66621 .23496 m .63949 .23964 L .64316 .24529 L .706 .663 0 r
F
.67036 .2405 m .66621 .23496 L .64316 .24529 L .703 .654 0 r
F
.27732 .26816 m .25672 .25087 L .25251 .25643 L 1 1 0 r
F
.27732 .26816 m .28101 .2624 L .25672 .25087 L F
.54575 .26623 m .51878 .26859 L .51942 .27597 L 1 .78 0 r
F
.57136 .25754 m .54454 .25919 L .54575 .26623 L .955 .721 0 r
F
.57305 .26438 m .57136 .25754 L .54575 .26623 L .957 .707 0 r
F
.59954 .25245 m .57239 .25524 L .57425 .26182 L .889 .702 0 r
F
.60192 .25883 m .59954 .25245 L .57425 .26182 L .891 .692 0 r
F
.55794 .19344 m .53488 .19251 L .53706 .198 L .86 .857 0 r
F
.56083 .19885 m .55794 .19344 L .53706 .198 L .86 .851 0 r
F
.33483 .22686 m .3167 .21325 L .31252 .21846 L 1 1 0 r
F
.33483 .22686 m .33839 .22142 L .3167 .21325 L F
.55791 .19355 m .53487 .19257 L .53705 .19806 L .858 .855 0 r
F
.56079 .19897 m .55791 .19355 L .53705 .19806 L .858 .849 0 r
F
.66592 .23533 m .63929 .23993 L .64294 .24559 L .703 .66 0 r
F
.67005 .24087 m .66592 .23533 L .64294 .24559 L .701 .651 0 r
F
.46431 .78267 m .4643 .77747 L .4176 .77649 L .973 .291 0 r
F
.51067 .78212 m .4643 .77747 L .46431 .78267 L .915 .239 0 r
F
.51067 .78212 m .51099 .77693 L .4643 .77747 L F
.5562 .7715 m .51086 .76847 L .51055 .77359 L .852 .18 0 r
F
.5562 .7715 m .55684 .76636 L .51086 .76847 L F
.69665 .70568 m .65428 .70753 L .65346 .71326 L .654 .075 0 r
F
.69665 .70568 m .69766 .69987 L .65428 .70753 L F
.74386 .65421 m .70296 .658 L .7024 .6641 L .587 .073 0 r
F
.74386 .65421 m .74454 .64803 L .70296 .658 L F
.20894 .46013 m .17574 .43995 L .17402 .44639 L 1 .978 0 r
F
.20758 .46656 m .20894 .46013 L .17402 .44639 L 1 .97 0 r
F
.56841 .24221 m .54219 .2442 L .54363 .25097 L .968 .781 0 r
F
.57044 .2487 m .56841 .24221 L .54363 .25097 L .973 .773 0 r
F
.58471 .19829 m .56083 .19885 L .56368 .20432 L .819 .814 0 r
F
.58821 .20365 m .58471 .19829 L .56368 .20432 L .819 .806 0 r
F
.55101 .30932 m .52162 .31314 L .52186 .3205 L 1 .699 0 r
F
.58067 .30643 m .55101 .30932 L .55154 .31655 L .965 .615 0 r
F
.58067 .30643 m .57972 .29933 L .55101 .30932 L F
.19498 .49916 m .16042 .47863 L .15898 .48523 L 1 .964 0 r
F
.1938 .50575 m .19498 .49916 L .15898 .48523 L 1 .956 0 r
F
.55504 .34115 m .52241 .34881 L .52244 .35557 L 1 .734 0 r
F
.55536 .3479 m .55504 .34115 L .52244 .35557 L 1 .727 0 r
F
.58464 .19846 m .56079 .19897 L .56364 .20444 L .818 .811 0 r
F
.58813 .20383 m .58464 .19846 L .56364 .20444 L .817 .804 0 r
F
.36844 .23092 m .35096 .22212 L .3474 .22708 L 1 1 0 r
F
.36844 .23092 m .37134 .2256 L .35096 .22212 L F
.7747 .35885 m .74242 .36718 L .74508 .37361 L .557 .377 0 r
F
.77762 .36524 m .74508 .37361 L .74768 .38007 L .553 .366 0 r
F
.77762 .36524 m .7747 .35885 L .74508 .37361 L F
.74614 .66236 m .70467 .6659 L .70408 .67207 L .593 .076 0 r
F
.74614 .66236 m .74684 .6561 L .70467 .6659 L F
.28752 .61834 m .24002 .6078 L .24046 .61358 L 1 .526 0 r
F
.28817 .62363 m .28752 .61834 L .24046 .61358 L 1 .522 0 r
F
.34452 .61556 m .28752 .61834 L .28817 .62363 L .835 .222 0 r
F
.34452 .61556 m .3438 .61113 L .28752 .61834 L F
.77171 .35249 m .73968 .36078 L .74242 .36718 L .561 .388 0 r
F
.7747 .35885 m .77171 .35249 L .74242 .36718 L .557 .377 0 r
F
.78045 .37166 m .74768 .38007 L .7502 .38655 L .549 .355 0 r
F
.78045 .37166 m .77762 .36524 L .74768 .38007 L F
.32878 .25056 m .31045 .23829 L .30648 .24335 L 1 1 0 r
F
.32878 .25056 m .33215 .24518 L .31045 .23829 L F
.78879 .57944 m .74944 .58537 L .74958 .59191 L .535 .11 0 r
F
.78879 .57944 m .78862 .57282 L .74944 .58537 L F
.22213 .6372 m .17945 .61968 L .17972 .62618 L 1 .738 0 r
F
.22242 .64357 m .22213 .6372 L .17972 .62618 L 1 .727 0 r
F
.76863 .34617 m .73686 .35441 L .73968 .36078 L .565 .399 0 r
F
.77171 .35249 m .76863 .34617 L .73968 .36078 L .561 .388 0 r
F
.54454 .25919 m .51807 .26125 L .51878 .26859 L 1 .792 0 r
F
.56956 .25077 m .54324 .25222 L .54454 .25919 L .953 .734 0 r
F
.57136 .25754 m .56956 .25077 L .54454 .25919 L .955 .721 0 r
F
.2734 .68623 m .22934 .67143 L .23 .6775 L 1 .631 0 r
F
.27399 .69218 m .2734 .68623 L .23 .6775 L 1 .619 0 r
F
.7832 .37811 m .7502 .38655 L .75264 .39305 L .545 .344 0 r
F
.7832 .37811 m .78045 .37166 L .7502 .38655 L F
.2265 .62162 m .18534 .60393 L .1854 .61037 L 1 .769 0 r
F
.22662 .62795 m .2265 .62162 L .1854 .61037 L 1 .758 0 r
F
.59054 .35508 m .55584 .3611 L .556 .36753 L 1 .645 0 r
F
.59104 .36151 m .59054 .35508 L .556 .36753 L 1 .639 0 r
F
.6246 .34972 m .59054 .35508 L .59104 .36151 L .928 .564 0 r
F
.6246 .34972 m .62364 .34332 L .59054 .35508 L F
.69819 .71413 m .65538 .71571 L .65455 .72151 L .659 .078 0 r
F
.69819 .71413 m .69923 .70825 L .65538 .71571 L F
.78564 .57195 m .74697 .578 L .74712 .58449 L .528 .105 0 r
F
.78564 .57195 m .78547 .56539 L .74697 .578 L F
.76547 .33988 m .73398 .34807 L .73686 .35441 L .568 .41 0 r
F
.76863 .34617 m .76547 .33988 L .73686 .35441 L .565 .399 0 r
F
.32685 .25814 m .30893 .24687 L .30489 .25169 L 1 1 0 r
F
.32685 .25814 m .33017 .2528 L .30893 .24687 L F
.18324 .53332 m .14589 .5125 L .14492 .51929 L 1 .912 0 r
F
.18247 .54005 m .18324 .53332 L .14492 .51929 L 1 .904 0 r
F
.78586 .38459 m .75264 .39305 L .75501 .39958 L .541 .332 0 r
F
.78586 .38459 m .7832 .37811 L .75264 .39305 L F
.2386 .57835 m .19682 .56193 L .19673 .56814 L 1 .738 0 r
F
.23877 .58432 m .2386 .57835 L .19673 .56814 L 1 .726 0 r
F
.28077 .26212 m .26073 .24509 L .25648 .25061 L 1 1 0 r
F
.28077 .26212 m .28451 .2564 L .26073 .24509 L F
.76223 .33362 m .73102 .34176 L .73398 .34807 L .572 .421 0 r
F
.76547 .33988 m .76223 .33362 L .73398 .34807 L .568 .41 0 r
F
.78844 .3911 m .75501 .39958 L .7573 .40613 L .536 .321 0 r
F
.78844 .3911 m .78586 .38459 L .75501 .39958 L F
.59706 .24612 m .57044 .2487 L .57239 .25524 L .887 .712 0 r
F
.59954 .25245 m .59706 .24612 L .57239 .25524 L .889 .702 0 r
F
.37405 .20613 m .35667 .19475 L .3529 .19988 L 1 1 0 r
F
.37405 .20613 m .37714 .20079 L .35667 .19475 L F
.20758 .46656 m .17402 .44639 L .1724 .45284 L 1 .97 0 r
F
.20629 .473 m .20758 .46656 L .1724 .45284 L 1 .962 0 r
F
.55154 .31655 m .52186 .3205 L .52205 .32779 L 1 .684 0 r
F
.58149 .31354 m .55154 .31655 L .55197 .32376 L .966 .598 0 r
F
.58149 .31354 m .58067 .30643 L .55154 .31655 L F
.75891 .32741 m .72799 .33548 L .73102 .34176 L .576 .432 0 r
F
.76223 .33362 m .75891 .32741 L .73102 .34176 L .572 .421 0 r
F
.28101 .2624 m .261 .24538 L .25672 .25087 L 1 1 0 r
F
.28101 .2624 m .28476 .2567 L .261 .24538 L F
.55653 .78006 m .51099 .77693 L .51067 .78212 L .852 .179 0 r
F
.55653 .78006 m .55718 .77486 L .51099 .77693 L F
.37414 .2064 m .35683 .19514 L .35306 .20027 L 1 1 0 r
F
.37414 .2064 m .37724 .20106 L .35683 .19514 L F
.41504 .56409 m .34135 .60308 L .34275 .60698 L .506 .399 0 r
F
.79094 .39763 m .7573 .40613 L .75952 .41269 L .532 .309 0 r
F
.79094 .39763 m .78844 .3911 L .7573 .40613 L F
.77058 .35297 m .73879 .36118 L .74148 .36757 L .556 .381 0 r
F
.77352 .35932 m .74148 .36757 L .7441 .37399 L .552 .369 0 r
F
.77352 .35932 m .77058 .35297 L .74148 .36757 L F
.77638 .36571 m .7441 .37399 L .74665 .38044 L .548 .358 0 r
F
.77638 .36571 m .77352 .35932 L .7441 .37399 L F
.1938 .50575 m .15898 .48523 L .15763 .49184 L 1 .956 0 r
F
.1927 .51234 m .1938 .50575 L .15763 .49184 L 1 .948 0 r
F
.76756 .34665 m .73602 .35481 L .73879 .36118 L .56 .392 0 r
F
.77058 .35297 m .76756 .34665 L .73879 .36118 L .556 .381 0 r
F
.77915 .37212 m .74665 .38044 L .74912 .38691 L .544 .346 0 r
F
.77915 .37212 m .77638 .36571 L .74665 .38044 L F
.32103 .73694 m .27465 .72513 L .27559 .7309 L 1 .506 0 r
F
.32177 .74258 m .32103 .73694 L .27559 .7309 L 1 .492 0 r
F
.32243 .72777 m .27691 .71553 L .27777 .72126 L 1 .52 0 r
F
.32313 .73336 m .32243 .72777 L .27777 .72126 L 1 .506 0 r
F
.64862 .74116 m .60522 .7413 L .60442 .74671 L .719 .092 0 r
F
.64862 .74116 m .64969 .73569 L .60522 .7413 L F
.61636 .20677 m .59166 .20907 L .59506 .21454 L .772 .759 0 r
F
.62034 .21211 m .61636 .20677 L .59506 .21454 L .771 .751 0 r
F
.76445 .34037 m .73317 .34848 L .73602 .35481 L .564 .404 0 r
F
.76756 .34665 m .76445 .34037 L .73602 .35481 L .56 .392 0 r
F
.78183 .37856 m .74912 .38691 L .75152 .3934 L .539 .334 0 r
F
.78183 .37856 m .77915 .37212 L .74912 .38691 L F
.55536 .3479 m .52244 .35557 L .52245 .36217 L 1 .727 0 r
F
.55563 .35455 m .55536 .3479 L .52245 .36217 L 1 .72 0 r
F
.66201 .22948 m .63576 .23403 L .63949 .23964 L .708 .673 0 r
F
.66621 .23496 m .66201 .22948 L .63949 .23964 L .706 .663 0 r
F
.54324 .25222 m .5173 .25398 L .51807 .26125 L 1 .804 0 r
F
.56766 .24406 m .54186 .24531 L .54324 .25222 L .95 .747 0 r
F
.56956 .25077 m .56766 .24406 L .54324 .25222 L .953 .734 0 r
F
.75551 .32123 m .72489 .32924 L .72799 .33548 L .58 .443 0 r
F
.75891 .32741 m .75551 .32123 L .72799 .33548 L .576 .432 0 r
F
.37069 .22393 m .35323 .21425 L .34961 .21923 L 1 1 0 r
F
.37069 .22393 m .37364 .21864 L .35323 .21425 L F
.60372 .27583 m .57608 .27822 L .57742 .28522 L .866 .6 0 r
F
.60541 .28271 m .57742 .28522 L .57864 .29226 L .865 .583 0 r
F
.60541 .28271 m .60372 .27583 L .57742 .28522 L F
.5663 .23576 m .54068 .23749 L .54219 .2442 L .964 .79 0 r
F
.56841 .24221 m .5663 .23576 L .54219 .2442 L .968 .781 0 r
F
.79335 .40419 m .75952 .41269 L .76166 .41928 L .528 .298 0 r
F
.79335 .40419 m .79094 .39763 L .75952 .41269 L F
.61623 .20702 m .59157 .20925 L .59498 .21473 L .77 .757 0 r
F
.6202 .21237 m .61623 .20702 L .59498 .21473 L .769 .749 0 r
F
.76126 .33411 m .73025 .34217 L .73317 .34848 L .568 .415 0 r
F
.76445 .34037 m .76126 .33411 L .73317 .34848 L .564 .404 0 r
F
.60695 .28963 m .57864 .29226 L .57972 .29933 L .864 .564 0 r
F
.60695 .28963 m .60541 .28271 L .57864 .29226 L F
.78443 .38503 m .75152 .3934 L .75383 .39991 L .535 .323 0 r
F
.78443 .38503 m .78183 .37856 L .75152 .3934 L F
.60189 .26901 m .57462 .27127 L .57608 .27822 L .867 .618 0 r
F
.60372 .27583 m .60189 .26901 L .57608 .27822 L .866 .6 0 r
F
.59104 .36151 m .556 .36753 L .55611 .37385 L 1 .639 0 r
F
.59147 .36785 m .59104 .36151 L .55611 .37385 L 1 .634 0 r
F
.62547 .35608 m .59104 .36151 L .59147 .36785 L .931 .557 0 r
F
.62547 .35608 m .6246 .34972 L .59104 .36151 L F
.66174 .22984 m .63557 .23431 L .63929 .23993 L .705 .669 0 r
F
.66592 .23533 m .66174 .22984 L .63929 .23993 L .703 .66 0 r
F
.75799 .3279 m .72726 .33589 L .73025 .34217 L .572 .426 0 r
F
.76126 .33411 m .75799 .3279 L .73025 .34217 L .568 .415 0 r
F
.75204 .31509 m .72172 .32303 L .72489 .32924 L .584 .454 0 r
F
.75551 .32123 m .75204 .31509 L .72489 .32924 L .58 .443 0 r
F
.60177 .7626 m .55745 .76116 L .55684 .76636 L .784 .126 0 r
F
.60177 .7626 m .60269 .75736 L .55745 .76116 L F
.78695 .39152 m .75383 .39991 L .75607 .40645 L .531 .311 0 r
F
.78695 .39152 m .78443 .38503 L .75383 .39991 L F
.20629 .473 m .1724 .45284 L .17086 .45929 L 1 .962 0 r
F
.20509 .47943 m .20629 .473 L .17086 .45929 L 1 .953 0 r
F
.60833 .2966 m .57972 .29933 L .58067 .30643 L .863 .545 0 r
F
.60833 .2966 m .60695 .28963 L .57972 .29933 L F
.33821 .22107 m .32063 .20758 L .31641 .21275 L 1 1 0 r
F
.33821 .22107 m .34182 .21568 L .32063 .20758 L F
.79567 .41077 m .76166 .41928 L .76372 .42588 L .524 .286 0 r
F
.79567 .41077 m .79335 .40419 L .76166 .41928 L F
.59991 .26225 m .57305 .26438 L .57462 .27127 L .867 .634 0 r
F
.60189 .26901 m .59991 .26225 L .57462 .27127 L .867 .618 0 r
F
.18247 .54005 m .14492 .51929 L .14404 .52607 L 1 .904 0 r
F
.18179 .54677 m .18247 .54005 L .14404 .52607 L 1 .895 0 r
F
.41793 .76776 m .37143 .75969 L .37204 .76495 L 1 .357 0 r
F
.41825 .77291 m .41793 .76776 L .37204 .76495 L 1 .343 0 r
F
.46439 .77406 m .41793 .76776 L .41825 .77291 L .976 .295 0 r
F
.75464 .32172 m .7242 .32965 L .72726 .33589 L .576 .437 0 r
F
.75799 .3279 m .75464 .32172 L .72726 .33589 L .572 .426 0 r
F
.59449 .23984 m .56841 .24221 L .57044 .2487 L .885 .722 0 r
F
.59706 .24612 m .59449 .23984 L .57044 .2487 L .887 .712 0 r
F
.78937 .39804 m .75607 .40645 L .75823 .413 L .526 .299 0 r
F
.78937 .39804 m .78695 .39152 L .75607 .40645 L F
.55197 .32376 m .52205 .32779 L .52219 .33499 L 1 .669 0 r
F
.58217 .32064 m .55197 .32376 L .55231 .33092 L .965 .58 0 r
F
.58217 .32064 m .58149 .31354 L .55197 .32376 L F
.33839 .22142 m .32091 .2081 L .3167 .21325 L 1 1 0 r
F
.33839 .22142 m .342 .21604 L .32091 .2081 L F
.6496 .74975 m .60588 .74964 L .60506 .75512 L .722 .094 0 r
F
.6496 .74975 m .65069 .74421 L .60588 .74964 L F
.28451 .2564 m .26505 .23962 L .26073 .24509 L 1 1 0 r
F
.28451 .2564 m .28831 .25074 L .26505 .23962 L F
.78887 .58605 m .74958 .59191 L .74964 .59844 L .531 .098 0 r
F
.78887 .58605 m .78879 .57944 L .74958 .59191 L F
.74849 .309 m .71849 .31686 L .72172 .32303 L .587 .465 0 r
F
.75204 .31509 m .74849 .309 L .72172 .32303 L .584 .454 0 r
F
.1927 .51234 m .15763 .49184 L .15636 .49846 L 1 .948 0 r
F
.19168 .51893 m .1927 .51234 L .15636 .49846 L 1 .94 0 r
F
.78573 .57849 m .74712 .58449 L .7472 .59096 L .523 .093 0 r
F
.78573 .57849 m .78564 .57195 L .74712 .58449 L F
.27146 .70159 m .22633 .68725 L .22716 .69334 L 1 .6 0 r
F
.27218 .70755 m .27146 .70159 L .22716 .69334 L 1 .588 0 r
F
.7979 .41737 m .76372 .42588 L .76571 .4325 L .52 .274 0 r
F
.7979 .41737 m .79567 .41077 L .76372 .42588 L F
.60955 .3036 m .58067 .30643 L .58149 .31354 L .861 .525 0 r
F
.60955 .3036 m .60833 .2966 L .58067 .30643 L F
.7512 .31559 m .72106 .32345 L .7242 .32965 L .58 .448 0 r
F
.75464 .32172 m .7512 .31559 L .7242 .32965 L .576 .437 0 r
F
.64342 .29315 m .61413 .29773 L .6158 .30427 L .805 .559 0 r
F
.64548 .29955 m .6158 .30427 L .61736 .31082 L .805 .547 0 r
F
.64548 .29955 m .64342 .29315 L .6158 .30427 L F
.64743 .30596 m .61736 .31082 L .61883 .31736 L .805 .536 0 r
F
.64743 .30596 m .64548 .29955 L .61736 .31082 L F
.37084 .75438 m .32466 .74439 L .32548 .74982 L 1 .427 0 r
F
.37143 .75969 m .37084 .75438 L .32548 .74982 L 1 .413 0 r
F
.5978 .25555 m .57136 .25754 L .57305 .26438 L .867 .65 0 r
F
.59991 .26225 m .5978 .25555 L .57305 .26438 L .867 .634 0 r
F
.79171 .40458 m .75823 .413 L .76032 .41956 L .522 .287 0 r
F
.79171 .40458 m .78937 .39804 L .75823 .413 L F
.33215 .24518 m .31448 .23331 L .31045 .23829 L 1 1 0 r
F
.33215 .24518 m .33555 .23986 L .31448 .23331 L F
.28476 .2567 m .26534 .23996 L .261 .24538 L F
.28476 .2567 m .28856 .25105 L .26534 .23996 L F
.64124 .28675 m .61235 .29119 L .61413 .29773 L .804 .57 0 r
F
.64342 .29315 m .64124 .28675 L .61413 .29773 L .805 .559 0 r
F
.54186 .24531 m .51647 .24677 L .5173 .25398 L 1 .815 0 r
F
.56566 .23742 m .5404 .23847 L .54186 .24531 L .948 .759 0 r
F
.56766 .24406 m .56566 .23742 L .54186 .24531 L .95 .747 0 r
F
.46439 .77912 m .46439 .77406 L .41825 .77291 L .972 .281 0 r
F
.51022 .77865 m .46439 .77406 L .46439 .77912 L .912 .227 0 r
F
.51022 .77865 m .51055 .77359 L .46439 .77406 L F
.64927 .31238 m .61883 .31736 L .62018 .32388 L .806 .525 0 r
F
.64927 .31238 m .64743 .30596 L .61883 .31736 L F
.74311 .66035 m .7024 .6641 L .70177 .67017 L .582 .071 0 r
F
.74311 .66035 m .74386 .65421 L .7024 .6641 L F
.22662 .62795 m .1854 .61037 L .18554 .61678 L 1 .758 0 r
F
.22681 .63426 m .22662 .62795 L .18554 .61678 L 1 .748 0 r
F
.53267 .18707 m .51096 .1848 L .51242 .19027 L .895 .899 0 r
F
.53488 .19251 m .53267 .18707 L .51242 .19027 L .896 .893 0 r
F
.53266 .18713 m .51096 .1848 L .51242 .19027 L .893 .897 0 r
F
.53487 .19257 m .53266 .18713 L .51242 .19027 L .894 .891 0 r
F
.33017 .2528 m .31302 .24215 L .30893 .24687 L 1 1 0 r
F
.33017 .2528 m .33354 .24753 L .31302 .24215 L F
.55563 .35455 m .52245 .36217 L .52244 .3686 L 1 .72 0 r
F
.55584 .3611 m .55563 .35455 L .52244 .3686 L 1 .714 0 r
F
.22242 .64357 m .17972 .62618 L .18006 .63265 L 1 .727 0 r
F
.22277 .64992 m .22242 .64357 L .18006 .63265 L 1 .715 0 r
F
.23877 .58432 m .19673 .56814 L .19672 .57431 L 1 .726 0 r
F
.239 .59025 m .23877 .58432 L .19672 .57431 L 1 .714 0 r
F
.74486 .30294 m .71518 .31072 L .71849 .31686 L .591 .476 0 r
F
.74849 .309 m .74486 .30294 L .71849 .31686 L .587 .465 0 r
F
.20509 .47943 m .17086 .45929 L .16942 .46575 L 1 .953 0 r
F
.20397 .48586 m .20509 .47943 L .16942 .46575 L 1 .944 0 r
F
.59147 .36785 m .55611 .37385 L .5562 .38004 L 1 .634 0 r
F
.59184 .37411 m .59147 .36785 L .5562 .38004 L 1 .629 0 r
F
.62626 .36239 m .59147 .36785 L .59184 .37411 L .933 .551 0 r
F
.62626 .36239 m .62547 .35608 L .59147 .36785 L F
.63894 .28038 m .61047 .28467 L .61235 .29119 L .804 .582 0 r
F
.64124 .28675 m .63894 .28038 L .61235 .29119 L .804 .57 0 r
F
.65099 .31879 m .62018 .32388 L .62144 .33039 L .806 .514 0 r
F
.65099 .31879 m .64927 .31238 L .62018 .32388 L F
.74769 .30949 m .71786 .31727 L .72106 .32345 L .584 .459 0 r
F
.7512 .31559 m .74769 .30949 L .72106 .32345 L .58 .448 0 r
F
.74537 .66858 m .70408 .67207 L .70344 .6782 L .588 .072 0 r
F
.74537 .66858 m .74614 .66236 L .70408 .67207 L F
.80005 .42399 m .76571 .4325 L .76761 .43914 L .515 .263 0 r
F
.80005 .42399 m .7979 .41737 L .76571 .4325 L F
.60236 .77122 m .5578 .76959 L .55718 .77486 L .786 .126 0 r
F
.60236 .77122 m .6033 .76591 L .5578 .76959 L F
.37134 .2256 m .35455 .21722 L .35096 .22212 L 1 1 0 r
F
.37134 .2256 m .37427 .22033 L .35455 .21722 L F
.79396 .41114 m .76032 .41956 L .76232 .42615 L .517 .275 0 r
F
.79396 .41114 m .79171 .40458 L .76032 .41956 L F
.69557 .71143 m .65346 .71326 L .6526 .71895 L .648 .071 0 r
F
.69557 .71143 m .69665 .70568 L .65346 .71326 L F
.28817 .62363 m .24046 .61358 L .24095 .61933 L 1 .522 0 r
F
.28881 .62891 m .28817 .62363 L .24095 .61933 L 1 .52 0 r
F
.34495 .62026 m .28817 .62363 L .28881 .62891 L .854 .297 0 r
F
.34495 .62026 m .34452 .61556 L .28817 .62363 L F
.56412 .22938 m .5391 .23084 L .54068 .23749 L .96 .799 0 r
F
.5663 .23576 m .56412 .22938 L .54068 .23749 L .964 .79 0 r
F
.4176 .77649 m .37073 .76869 L .37137 .774 L 1 .351 0 r
F
.41794 .78171 m .4176 .77649 L .37137 .774 L 1 .336 0 r
F
.46431 .78267 m .4176 .77649 L .41794 .78171 L .973 .291 0 r
F
.37013 .76332 m .32337 .75371 L .32424 .75919 L 1 .418 0 r
F
.37073 .76869 m .37013 .76332 L .32424 .75919 L 1 .403 0 r
F
.6106 .31062 m .58149 .31354 L .58217 .32064 L .859 .505 0 r
F
.6106 .31062 m .60955 .3036 L .58149 .31354 L F
.63654 .27403 m .60849 .27817 L .61047 .28467 L .804 .593 0 r
F
.63894 .28038 m .63654 .27403 L .61047 .28467 L .804 .582 0 r
F
.58118 .19299 m .55794 .19344 L .56083 .19885 L .82 .821 0 r
F
.58471 .19829 m .58118 .19299 L .56083 .19885 L .819 .814 0 r
F
.27399 .69218 m .23 .6775 L .23073 .68354 L 1 .619 0 r
F
.27464 .69808 m .27399 .69218 L .23073 .68354 L 1 .606 0 r
F
.59556 .24892 m .56956 .25077 L .57136 .25754 L .867 .666 0 r
F
.5978 .25555 m .59556 .24892 L .57136 .25754 L .867 .65 0 r
F
.55503 .18808 m .53267 .18707 L .53488 .19251 L .859 .864 0 r
F
.55794 .19344 m .55503 .18808 L .53488 .19251 L .86 .857 0 r
F
.6526 .32519 m .62144 .33039 L .62259 .33687 L .807 .504 0 r
F
.6526 .32519 m .65099 .31879 L .62144 .33039 L F
.65775 .22406 m .63199 .22847 L .63576 .23403 L .71 .682 0 r
F
.66201 .22948 m .65775 .22406 L .63576 .23403 L .708 .673 0 r
F
.555 .18819 m .53266 .18713 L .53487 .19257 L .857 .862 0 r
F
.55791 .19355 m .555 .18819 L .53487 .19257 L .858 .855 0 r
F
.58112 .19315 m .55791 .19355 L .56079 .19897 L .818 .819 0 r
F
.58464 .19846 m .58112 .19315 L .56079 .19897 L .818 .811 0 r
F
.74116 .29693 m .7118 .30463 L .71518 .31072 L .595 .486 0 r
F
.74486 .30294 m .74116 .29693 L .71518 .31072 L .591 .476 0 r
F
.7441 .30343 m .71458 .31114 L .71786 .31727 L .588 .47 0 r
F
.74769 .30949 m .7441 .30343 L .71786 .31727 L .584 .459 0 r
F
.19168 .51893 m .15636 .49846 L .15518 .50508 L 1 .94 0 r
F
.19073 .52552 m .19168 .51893 L .15518 .50508 L 1 .932 0 r
F
.27316 .29198 m .27664 .28633 L .25292 .27582 L 1 1 0 r
F
.55231 .33092 m .52219 .33499 L .52228 .34207 L 1 .654 0 r
F
.55255 .33802 m .55231 .33092 L .52228 .34207 L 1 .639 0 r
F
.58272 .32774 m .55231 .33092 L .55255 .33802 L .964 .563 0 r
F
.58272 .32774 m .58217 .32064 L .55231 .33092 L F
.79611 .41772 m .76232 .42615 L .76424 .43274 L .512 .263 0 r
F
.79611 .41772 m .79396 .41114 L .76232 .42615 L F
.80211 .43063 m .76761 .43914 L .76944 .44579 L .511 .251 0 r
F
.80211 .43063 m .80005 .42399 L .76761 .43914 L F
.65749 .22441 m .63181 .22875 L .63557 .23431 L .707 .678 0 r
F
.66174 .22984 m .65749 .22441 L .63557 .23431 L .705 .669 0 r
F
.18179 .54677 m .14404 .52607 L .14325 .53285 L 1 .895 0 r
F
.18118 .55348 m .18179 .54677 L .14325 .53285 L 1 .886 0 r
F
.59183 .2336 m .5663 .23576 L .56841 .24221 L .883 .732 0 r
F
.59449 .23984 m .59183 .2336 L .56841 .24221 L .885 .722 0 r
F
.69709 .71996 m .65455 .72151 L .65366 .72726 L .654 .072 0 r
F
.69709 .71996 m .69819 .71413 L .65455 .72151 L F
.63402 .26771 m .6064 .27169 L .60849 .27817 L .804 .605 0 r
F
.63654 .27403 m .63402 .26771 L .60849 .27817 L .804 .593 0 r
F
.55554 .77657 m .51055 .77359 L .51022 .77865 L .847 .165 0 r
F
.55554 .77657 m .5562 .7715 L .51055 .77359 L F
.6541 .33157 m .62259 .33687 L .62364 .34332 L .808 .494 0 r
F
.6541 .33157 m .6526 .32519 L .62259 .33687 L F
.46432 .78779 m .46431 .78267 L .41794 .78171 L .968 .276 0 r
F
.51034 .78725 m .46431 .78267 L .46432 .78779 L .91 .224 0 r
F
.51034 .78725 m .51067 .78212 L .46431 .78267 L F
.28831 .25074 m .26944 .23422 L .26505 .23962 L 1 1 0 r
F
.28831 .25074 m .29217 .24513 L .26944 .23422 L F
.20397 .48586 m .16942 .46575 L .16806 .47221 L 1 .944 0 r
F
.20293 .49227 m .20397 .48586 L .16806 .47221 L 1 .935 0 r
F
.61233 .20149 m .58821 .20365 L .59166 .20907 L .773 .767 0 r
F
.61636 .20677 m .61233 .20149 L .59166 .20907 L .772 .759 0 r
F
.74044 .29742 m .71124 .30504 L .71458 .31114 L .592 .481 0 r
F
.7441 .30343 m .74044 .29742 L .71458 .31114 L .588 .47 0 r
F
.5404 .23847 m .51558 .23964 L .51647 .24677 L 1 .826 0 r
F
.56357 .23086 m .53887 .23171 L .5404 .23847 L .945 .771 0 r
F
.56566 .23742 m .56357 .23086 L .5404 .23847 L .948 .759 0 r
F
.73738 .29097 m .70836 .29857 L .7118 .30463 L .599 .497 0 r
F
.74116 .29693 m .73738 .29097 L .7118 .30463 L .595 .486 0 r
F
.59184 .37411 m .5562 .38004 L .55625 .3861 L 1 .629 0 r
F
.59215 .38028 m .59184 .37411 L .55625 .3861 L 1 .624 0 r
F
.62696 .36864 m .59184 .37411 L .59215 .38028 L .936 .545 0 r
F
.62696 .36864 m .62626 .36239 L .59184 .37411 L F
.79818 .42431 m .76424 .43274 L .76609 .43935 L .508 .251 0 r
F
.79818 .42431 m .79611 .41772 L .76424 .43274 L F
.61221 .20173 m .58813 .20383 L .59157 .20925 L .771 .765 0 r
F
.61623 .20702 m .61221 .20173 L .59157 .20925 L .77 .757 0 r
F
.28856 .25105 m .26976 .23461 L .26534 .23996 L 1 1 0 r
F
.28856 .25105 m .29242 .24547 L .26976 .23461 L F
.37724 .20106 m .36063 .19007 L .35683 .19514 L F
.37724 .20106 m .38036 .19579 L .36063 .19007 L F
.61148 .31766 m .58217 .32064 L .58272 .32774 L .856 .484 0 r
F
.61148 .31766 m .6106 .31062 L .58217 .32064 L F
.78886 .59264 m .74964 .59844 L .74964 .60495 L .526 .087 0 r
F
.78886 .59264 m .78887 .58605 L .74964 .59844 L F
.55584 .3611 m .52244 .3686 L .52242 .37486 L 1 .714 0 r
F
.556 .36753 m .55584 .3611 L .52242 .37486 L 1 .708 0 r
F
.80408 .43729 m .76944 .44579 L .77119 .45245 L .506 .239 0 r
F
.80408 .43729 m .80211 .43063 L .76944 .44579 L F
.5932 .24236 m .56766 .24406 L .56956 .25077 L .867 .68 0 r
F
.59556 .24892 m .5932 .24236 L .56956 .25077 L .867 .666 0 r
F
.37364 .21864 m .35689 .20934 L .35323 .21425 L 1 1 0 r
F
.37364 .21864 m .37663 .2134 L .35689 .20934 L F
.78573 .58501 m .7472 .59096 L .74721 .59741 L .518 .082 0 r
F
.78573 .58501 m .78573 .57849 L .7472 .59096 L F
.34182 .21568 m .32489 .20248 L .32063 .20758 L 1 1 0 r
F
.34182 .21568 m .34547 .21035 L .32489 .20248 L F
.63139 .26142 m .60421 .26524 L .6064 .27169 L .804 .617 0 r
F
.63402 .26771 m .63139 .26142 L .6064 .27169 L .804 .605 0 r
F
.65549 .33793 m .62364 .34332 L .6246 .34972 L .808 .484 0 r
F
.65549 .33793 m .6541 .33157 L .62364 .34332 L F
.32313 .73336 m .27777 .72126 L .2787 .72693 L 1 .506 0 r
F
.32387 .7389 m .32313 .73336 L .2787 .72693 L 1 .492 0 r
F
.73669 .29146 m .70783 .29899 L .71124 .30504 L .595 .492 0 r
F
.74044 .29742 m .73669 .29146 L .71124 .30504 L .592 .481 0 r
F
.342 .21604 m .32518 .20301 L .32091 .2081 L 1 1 0 r
F
.342 .21604 m .34564 .21072 L .32518 .20301 L F
.32177 .74258 m .27559 .7309 L .27658 .73661 L 1 .492 0 r
F
.32255 .74817 m .32177 .74258 L .27658 .73661 L 1 .479 0 r
F
.19073 .52552 m .15518 .50508 L .15408 .5117 L 1 .932 0 r
F
.18986 .53211 m .19073 .52552 L .15408 .5117 L 1 .923 0 r
F
.80016 .43093 m .76609 .43935 L .76785 .44597 L .503 .238 0 r
F
.80016 .43093 m .79818 .42431 L .76609 .43935 L F
.5391 .23084 m .51463 .23258 L .51558 .23963 L 1 .861 0 r
F
.5391 .23084 m .53746 .22425 L .51463 .23258 L F
.56185 .22305 m .53746 .22425 L .5391 .23084 L .956 .807 0 r
F
.56412 .22938 m .56185 .22305 L .5391 .23084 L .96 .799 0 r
F
.73352 .28505 m .70485 .29256 L .70836 .29857 L .602 .507 0 r
F
.73738 .29097 m .73352 .28505 L .70836 .29857 L .599 .497 0 r
F
.27664 .28633 m .25699 .2705 L .25292 .27582 L 1 1 0 r
F
.27664 .28633 m .28017 .28073 L .25699 .2705 L F
.64749 .74657 m .60442 .74671 L .60357 .75207 L .713 .079 0 r
F
.64749 .74657 m .64862 .74116 L .60442 .74671 L F
.33555 .23986 m .31855 .22841 L .31448 .23331 L 1 1 0 r
F
.33555 .23986 m .339 .2346 L .31855 .22841 L F
.22681 .63426 m .18554 .61678 L .18576 .62316 L 1 .748 0 r
F
.22706 .64053 m .22681 .63426 L .18576 .62316 L 1 .736 0 r
F
.33354 .24753 m .31715 .23752 L .31302 .24215 L 1 1 0 r
F
.33354 .24753 m .33694 .24232 L .31715 .23752 L F
.239 .59025 m .19672 .57431 L .19678 .58046 L 1 .714 0 r
F
.23929 .59614 m .239 .59025 L .19678 .58046 L 1 .702 0 r
F
.80596 .44396 m .77119 .45245 L .77286 .45912 L .502 .227 0 r
F
.80596 .44396 m .80408 .43729 L .77119 .45245 L F
.20293 .49227 m .16806 .47221 L .16679 .47867 L 1 .935 0 r
F
.20198 .49869 m .20293 .49227 L .16679 .47867 L 1 .926 0 r
F
.55585 .7852 m .51067 .78212 L .51034 .78725 L .847 .164 0 r
F
.55585 .7852 m .55653 .78006 L .51067 .78212 L F
.55255 .33802 m .52228 .34207 L .52233 .34901 L 1 .639 0 r
F
.55271 .34505 m .55255 .33802 L .52233 .34901 L 1 .624 0 r
F
.58313 .3348 m .55255 .33802 L .55271 .34505 L .963 .545 0 r
F
.58313 .3348 m .58272 .32774 L .55255 .33802 L F
.18118 .55348 m .14325 .53285 L .14255 .53963 L 1 .886 0 r
F
.18065 .56017 m .18118 .55348 L .14255 .53963 L 1 .876 0 r
F
.65678 .34426 m .6246 .34972 L .62547 .35608 L .809 .475 0 r
F
.65678 .34426 m .65549 .33793 L .6246 .34972 L F
.58908 .22742 m .56412 .22938 L .5663 .23576 L .881 .742 0 r
F
.59183 .2336 m .58908 .22742 L .5663 .23576 L .883 .732 0 r
F
.22277 .64992 m .18006 .63265 L .18049 .6391 L 1 .715 0 r
F
.2232 .65623 m .22277 .64992 L .18049 .6391 L 1 .704 0 r
F
.62865 .25517 m .60192 .25883 L .60421 .26524 L .804 .628 0 r
F
.63139 .26142 m .62865 .25517 L .60421 .26524 L .804 .617 0 r
F
.65342 .21869 m .62816 .22296 L .63199 .22847 L .712 .691 0 r
F
.65775 .22406 m .65342 .21869 L .63199 .22847 L .71 .682 0 r
F
.74229 .66646 m .70177 .67017 L .70108 .67619 L .576 .07 0 r
F
.74229 .66646 m .74311 .66035 L .70177 .67017 L F
.73287 .28553 m .70434 .29297 L .70783 .29899 L .599 .503 0 r
F
.73669 .29146 m .73287 .28553 L .70783 .29899 L .595 .492 0 r
F
.53887 .23171 m .51463 .23258 L .51558 .23964 L 1 .836 0 r
F
.41279 .57085 m .34275 .60698 L .3438 .61113 L .539 .425 0 r
F
.41279 .57085 m .41504 .56409 L .34275 .60698 L F
.27218 .70755 m .22716 .69334 L .22806 .69938 L 1 .588 0 r
F
.27295 .71345 m .27218 .70755 L .22806 .69938 L 1 .575 0 r
F
.61219 .3247 m .58272 .32774 L .58313 .3348 L .853 .463 0 r
F
.61219 .3247 m .61148 .31766 L .58272 .32774 L F
.59072 .23587 m .56566 .23742 L .56766 .24406 L .867 .695 0 r
F
.5932 .24236 m .59072 .23587 L .56766 .24406 L .867 .68 0 r
F
.59215 .38028 m .55625 .3861 L .55628 .39203 L 1 .624 0 r
F
.59241 .38635 m .59215 .38028 L .55628 .39203 L 1 .62 0 r
F
.62758 .37482 m .59215 .38028 L .59241 .38635 L .939 .539 0 r
F
.62758 .37482 m .62696 .36864 L .59215 .38028 L F
.29217 .24513 m .27388 .22889 L .26944 .23422 L 1 1 0 r
F
.29217 .24513 m .29608 .23958 L .27388 .22889 L F
.80205 .43755 m .76785 .44597 L .76954 .4526 L .498 .226 0 r
F
.80205 .43755 m .80016 .43093 L .76785 .44597 L F
.65318 .21904 m .62799 .22323 L .63181 .22875 L .71 .687 0 r
F
.65749 .22441 m .65318 .21904 L .63181 .22875 L .707 .678 0 r
F
.7296 .27918 m .70128 .28659 L .70485 .29256 L .606 .518 0 r
F
.73352 .28505 m .7296 .27918 L .70485 .29256 L .602 .507 0 r
F
.53887 .23171 m .53726 .22502 L .51463 .23258 L 1 .836 0 r
F
.56139 .22436 m .53726 .22502 L .53887 .23171 L .943 .783 0 r
F
.56357 .23086 m .56139 .22436 L .53887 .23171 L .945 .771 0 r
F
.60081 .76778 m .55684 .76636 L .5562 .7715 L .779 .112 0 r
F
.60081 .76778 m .60177 .7626 L .55684 .76636 L F
.74452 .67476 m .70344 .6782 L .70272 .6843 L .583 .07 0 r
F
.74452 .67476 m .74537 .66858 L .70344 .6782 L F
.27501 .29373 m .27849 .28818 L .25467 .27746 L 1 1 0 r
F
.28881 .62891 m .24095 .61933 L .24148 .62504 L 1 .52 0 r
F
.28944 .63419 m .28881 .62891 L .24148 .62504 L F
.34517 .62519 m .28881 .62891 L .28944 .63419 L .872 .356 0 r
F
.34517 .62519 m .34495 .62026 L .28881 .62891 L F
.556 .36753 m .52242 .37486 L .52239 .38093 L 1 .708 0 r
F
.55611 .37385 m .556 .36753 L .52239 .38093 L 1 .703 0 r
F
.80776 .45065 m .77286 .45912 L .77445 .4658 L .497 .215 0 r
F
.80776 .45065 m .80596 .44396 L .77286 .45912 L F
.29242 .24547 m .27423 .22934 L .26976 .23461 L 1 1 0 r
F
.29242 .24547 m .29634 .23994 L .27423 .22934 L F
.37427 .22033 m .35818 .21239 L .35455 .21722 L F
.37427 .22033 m .37724 .21511 L .35818 .21239 L F
.64845 .75523 m .60506 .75512 L .6042 .76055 L .717 .081 0 r
F
.64845 .75523 m .6496 .74975 L .60506 .75512 L F
.41825 .77291 m .37204 .76495 L .37269 .77014 L 1 .343 0 r
F
.4186 .77799 m .41825 .77291 L .37269 .77014 L 1 .328 0 r
F
.46439 .77912 m .41825 .77291 L .4186 .77799 L .972 .281 0 r
F
.65797 .35056 m .62547 .35608 L .62626 .36239 L .81 .466 0 r
F
.65797 .35056 m .65678 .34426 L .62547 .35608 L F
.18986 .53211 m .15408 .5117 L .15307 .51832 L 1 .923 0 r
F
.18906 .53869 m .18986 .53211 L .15307 .51832 L 1 .914 0 r
F
.72898 .27966 m .70079 .287 L .70434 .29297 L .603 .513 0 r
F
.73287 .28553 m .72898 .27966 L .70434 .29297 L .599 .503 0 r
F
.28017 .28073 m .26113 .26526 L .25699 .2705 L 1 1 0 r
F
.28017 .28073 m .28376 .2752 L .26113 .26526 L F
.27464 .69808 m .23073 .68354 L .23152 .68953 L 1 .606 0 r
F
.27534 .70395 m .27464 .69808 L .23152 .68953 L 1 .593 0 r
F
.62581 .24896 m .59954 .25245 L .60192 .25883 L .804 .64 0 r
F
.62865 .25517 m .62581 .24896 L .60192 .25883 L .804 .628 0 r
F
.37143 .75969 m .32548 .74982 L .32635 .7552 L 1 .413 0 r
F
.37204 .76495 m .37143 .75969 L .32635 .7552 L 1 .399 0 r
F
.20198 .49869 m .16679 .47867 L .16561 .48514 L 1 .926 0 r
F
.2011 .50509 m .20198 .49869 L .16561 .48514 L 1 .916 0 r
F
.69443 .71714 m .6526 .71895 L .65168 .72458 L .643 .07 0 r
F
.69443 .71714 m .69557 .71143 L .6526 .71895 L F
.78876 .59921 m .74964 .60495 L .74955 .61144 L .521 .076 0 r
F
.78876 .59921 m .78886 .59264 L .74964 .60495 L F
.80385 .44419 m .76954 .4526 L .77114 .45924 L .493 .214 0 r
F
.80385 .44419 m .80205 .43755 L .76954 .4526 L F
.78565 .59151 m .74721 .59741 L .74714 .60384 L .513 .073 0 r
F
.78565 .59151 m .78573 .58501 L .74721 .59741 L F
.7256 .27335 m .69764 .28066 L .70128 .28659 L .61 .529 0 r
F
.7296 .27918 m .7256 .27335 L .70128 .28659 L .606 .518 0 r
F
.5776 .18774 m .55503 .18808 L .55794 .19344 L .82 .828 0 r
F
.58118 .19299 m .5776 .18774 L .55794 .19344 L .82 .821 0 r
F
.53043 .18169 m .50949 .17937 L .51096 .1848 L .894 .905 0 r
F
.53267 .18707 m .53043 .18169 L .51096 .1848 L .895 .899 0 r
F
.53042 .18174 m .50949 .17937 L .51096 .1848 L .892 .903 0 r
F
.53266 .18713 m .53042 .18174 L .51096 .1848 L .893 .897 0 r
F
.57755 .1879 m .555 .18819 L .55791 .19355 L .818 .826 0 r
F
.58112 .19315 m .57755 .1879 L .55791 .19355 L .818 .819 0 r
F
.46441 .78412 m .46439 .77912 L .4186 .77799 L .967 .266 0 r
F
.50988 .78364 m .46439 .77912 L .46441 .78412 L .907 .212 0 r
F
.50988 .78364 m .51022 .77865 L .46439 .77912 L F
.80946 .45735 m .77445 .4658 L .77595 .47249 L .493 .203 0 r
F
.80946 .45735 m .80776 .45065 L .77445 .4658 L F
.60825 .19626 m .58471 .19829 L .58821 .20365 L .774 .775 0 r
F
.61233 .20149 m .60825 .19626 L .58821 .20365 L .773 .767 0 r
F
.53746 .22425 m .51362 .22561 L .51463 .23258 L 1 .868 0 r
F
.53746 .22425 m .53575 .21773 L .51362 .22561 L F
.55952 .21678 m .53575 .21773 L .53746 .22425 L .952 .816 0 r
F
.56185 .22305 m .55952 .21678 L .53746 .22425 L .956 .807 0 r
F
.58813 .22945 m .56357 .23086 L .56566 .23742 L .867 .708 0 r
F
.59072 .23587 m .58813 .22945 L .56566 .23742 L .867 .695 0 r
F
.55271 .34505 m .52233 .34901 L .52234 .35581 L 1 .624 0 r
F
.55279 .35197 m .55271 .34505 L .52234 .35581 L 1 .61 0 r
F
.58342 .34182 m .55271 .34505 L .55279 .35197 L .961 .528 0 r
F
.58342 .34182 m .58313 .3348 L .55271 .34505 L F
.60138 .77646 m .55718 .77486 L .55653 .78006 L .781 .112 0 r
F
.60138 .77646 m .60236 .77122 L .55718 .77486 L F
.53726 .22502 m .51362 .22561 L .51463 .23258 L 1 .846 0 r
F
.59241 .38635 m .55628 .39203 L .5563 .39783 L 1 .62 0 r
F
.59263 .39232 m .59241 .38635 L .5563 .39783 L 1 .617 0 r
F
.62814 .38093 m .59241 .38635 L .59263 .39232 L .941 .534 0 r
F
.62814 .38093 m .62758 .37482 L .59241 .38635 L F
.18065 .56017 m .14255 .53963 L .14194 .54639 L 1 .876 0 r
F
.1802 .56685 m .18065 .56017 L .14194 .54639 L 1 .867 0 r
F
.60814 .19649 m .58464 .19846 L .58813 .20383 L .772 .773 0 r
F
.61221 .20173 m .60814 .19649 L .58813 .20383 L .771 .765 0 r
F
.61273 .33173 m .58313 .3348 L .58342 .34182 L .85 .442 0 r
F
.61273 .33173 m .61219 .3247 L .58313 .3348 L F
.34547 .21035 m .32921 .19744 L .32489 .20248 L 1 1 0 r
F
.34547 .21035 m .34916 .20508 L .32921 .19744 L F
.55208 .18278 m .53043 .18169 L .53267 .18707 L .858 .87 0 r
F
.55503 .18808 m .55208 .18278 L .53267 .18707 L .859 .864 0 r
F
.37073 .76869 m .32424 .75919 L .32515 .76461 L 1 .403 0 r
F
.37137 .774 m .37073 .76869 L .32515 .76461 L 1 .389 0 r
F
.72501 .27383 m .69718 .28107 L .70079 .287 L .606 .524 0 r
F
.72898 .27966 m .72501 .27383 L .70079 .287 L .603 .513 0 r
F
.55205 .18288 m .53042 .18174 L .53266 .18713 L .857 .868 0 r
F
.555 .18819 m .55205 .18288 L .53266 .18713 L .857 .862 0 r
F
.69592 .72574 m .65366 .72726 L .65272 .73296 L .648 .07 0 r
F
.69592 .72574 m .69709 .71996 L .65366 .72726 L F
.58624 .22129 m .56185 .22305 L .56412 .22938 L .879 .752 0 r
F
.58908 .22742 m .58624 .22129 L .56412 .22938 L .881 .742 0 r
F
.65905 .35682 m .62626 .36239 L .62696 .36864 L .811 .457 0 r
F
.65905 .35682 m .65797 .35056 L .62626 .36239 L F
.41794 .78171 m .37137 .774 L .37203 .77925 L 1 .336 0 r
F
.41829 .78686 m .41794 .78171 L .37203 .77925 L 1 .321 0 r
F
.46432 .78779 m .41794 .78171 L .41829 .78686 L .968 .276 0 r
F
.27849 .28818 m .25886 .27233 L .25467 .27746 L 1 1 0 r
F
.27849 .28818 m .28205 .2827 L .25886 .27233 L F
.80555 .45085 m .77114 .45924 L .77266 .46588 L .488 .201 0 r
F
.80555 .45085 m .80385 .44419 L .77114 .45924 L F
.339 .2346 m .32268 .22359 L .31855 .22841 L 1 1 0 r
F
.339 .2346 m .3425 .22941 L .32268 .22359 L F
.29608 .23958 m .27838 .22362 L .27388 .22889 L F
.29608 .23958 m .30004 .23409 L .27838 .22362 L F
.23929 .59614 m .19678 .58046 L .19692 .58658 L 1 .702 0 r
F
.23963 .60199 m .23929 .59614 L .19692 .58658 L 1 .691 0 r
F
.34564 .21072 m .32949 .19799 L .32518 .20301 L 1 1 0 r
F
.34564 .21072 m .34933 .20546 L .32949 .19799 L F
.22706 .64053 m .18576 .62316 L .18605 .62952 L 1 .736 0 r
F
.22738 .64678 m .22706 .64053 L .18605 .62952 L 1 .725 0 r
F
.37663 .2134 m .36059 .20451 L .35689 .20934 L 1 1 0 r
F
.37663 .2134 m .37965 .20823 L .36059 .20451 L F
.33694 .24232 m .32133 .23298 L .31715 .23752 L F
.33694 .24232 m .34039 .23718 L .32133 .23298 L F
.62286 .2428 m .59706 .24612 L .59954 .25245 L .804 .651 0 r
F
.62581 .24896 m .62286 .2428 L .59954 .25245 L .804 .64 0 r
F
.64904 .21338 m .62428 .21751 L .62816 .22296 L .715 .7 0 r
F
.65342 .21869 m .64904 .21338 L .62816 .22296 L .712 .691 0 r
F
.72153 .26758 m .69393 .27478 L .69764 .28066 L .613 .539 0 r
F
.7256 .27335 m .72153 .26758 L .69764 .28066 L .61 .529 0 r
F
.55611 .37385 m .52239 .38093 L .52236 .38683 L 1 .703 0 r
F
.5562 .38004 m .55611 .37385 L .52236 .38683 L 1 .698 0 r
F
.53726 .22502 m .53558 .21841 L .51362 .22561 L 1 .846 0 r
F
.55913 .21795 m .53558 .21841 L .53726 .22502 L .94 .794 0 r
F
.56139 .22436 m .55913 .21795 L .53726 .22502 L .943 .783 0 r
F
.2011 .50509 m .16561 .48514 L .16451 .49159 L 1 .916 0 r
F
.20031 .51147 m .2011 .50509 L .16451 .49159 L 1 .906 0 r
F
.18906 .53869 m .15307 .51832 L .15215 .52495 L 1 .914 0 r
F
.18834 .54527 m .18906 .53869 L .15215 .52495 L 1 .906 0 r
F
.29634 .23994 m .27877 .22414 L .27423 .22934 L 1 1 0 r
F
.29634 .23994 m .30031 .23448 L .27877 .22414 L F
.64882 .21372 m .62412 .21777 L .62799 .22323 L .712 .696 0 r
F
.65318 .21904 m .64882 .21372 L .62799 .22323 L .71 .687 0 r
F
.28376 .2752 m .26534 .26009 L .26113 .26526 L 1 1 0 r
F
.28376 .2752 m .28741 .26972 L .26534 .26009 L F
.81107 .46406 m .77595 .47249 L .77738 .47918 L .488 .191 0 r
F
.81107 .46406 m .80946 .45735 L .77595 .47249 L F
.2232 .65623 m .18049 .6391 L .18099 .64551 L 1 .704 0 r
F
.22369 .6625 m .2232 .65623 L .18099 .64551 L 1 .692 0 r
F
.55485 .78158 m .51022 .77865 L .50988 .78364 L .841 .151 0 r
F
.55485 .78158 m .55554 .77657 L .51022 .77865 L F
.72096 .26806 m .6935 .27518 L .69718 .28107 L .61 .535 0 r
F
.72501 .27383 m .72096 .26806 L .69718 .28107 L .606 .524 0 r
F
.46433 .79286 m .46432 .78779 L .41829 .78686 L .963 .261 0 r
F
.50999 .79231 m .46432 .78779 L .46433 .79286 L .905 .209 0 r
F
.50999 .79231 m .51034 .78725 L .46432 .78779 L F
.32387 .7389 m .2787 .72693 L .27967 .73255 L 1 .492 0 r
F
.32466 .74439 m .32387 .7389 L .27967 .73255 L 1 .478 0 r
F
.66005 .36304 m .62696 .36864 L .62758 .37482 L .812 .449 0 r
F
.66005 .36304 m .65905 .35682 L .62696 .36864 L F
.74139 .67253 m .70108 .67619 L .70032 .68218 L .571 .068 0 r
F
.74139 .67253 m .74229 .66646 L .70108 .67619 L F
.80716 .45751 m .77266 .46588 L .7741 .47254 L .483 .189 0 r
F
.80716 .45751 m .80555 .45085 L .77266 .46588 L F
.32255 .74817 m .27658 .73661 L .27763 .74227 L 1 .479 0 r
F
.32337 .75371 m .32255 .74817 L .27763 .74227 L 1 .464 0 r
F
.59263 .39232 m .5563 .39783 L .55631 .40349 L 1 .617 0 r
F
.59281 .3982 m .59263 .39232 L .55631 .40349 L 1 .614 0 r
F
.62863 .38698 m .59263 .39232 L .59281 .3982 L .943 .529 0 r
F
.62863 .38698 m .62814 .38093 L .59263 .39232 L F
.78858 .60576 m .74955 .61144 L .74939 .6179 L .516 .072 0 r
F
.78858 .60576 m .78876 .59921 L .74955 .61144 L F
.78548 .59798 m .74714 .60384 L .74699 .61024 L .508 .071 0 r
F
.78548 .59798 m .78565 .59151 L .74714 .60384 L F
.71738 .26186 m .69016 .26894 L .69393 .27478 L .617 .549 0 r
F
.72153 .26758 m .71738 .26186 L .69393 .27478 L .613 .539 0 r
F
.58544 .22311 m .56139 .22436 L .56357 .23086 L .866 .722 0 r
F
.58813 .22945 m .58544 .22311 L .56357 .23086 L .867 .708 0 r
F
.28944 .63419 m .24148 .62504 L .24206 .63072 L 1 .52 0 r
F
.29006 .63946 m .28944 .63419 L .24206 .63072 L F
.34522 .63033 m .28944 .63419 L .29006 .63946 L .887 .402 0 r
F
.34522 .63033 m .34517 .62519 L .28944 .63419 L F
.7436 .68091 m .70272 .6843 L .70195 .69035 L .578 .069 0 r
F
.7436 .68091 m .74452 .67476 L .70272 .6843 L F
.64632 .75193 m .60357 .75207 L .60269 .75736 L .708 .072 0 r
F
.64632 .75193 m .64749 .74657 L .60357 .75207 L F
.28205 .2827 m .26317 .26734 L .25886 .27233 L 1 1 0 r
F
.28205 .2827 m .28568 .2773 L .26317 .26734 L F
.61981 .23668 m .59449 .23984 L .59706 .24612 L .804 .663 0 r
F
.62286 .2428 m .61981 .23668 L .59706 .24612 L .804 .651 0 r
F
.27295 .71345 m .22806 .69938 L .22902 .70538 L 1 .575 0 r
F
.27377 .71932 m .27295 .71345 L .22902 .70538 L 1 .562 0 r
F
.58358 .34877 m .58342 .34182 L .55279 .35197 L .958 .51 0 r
F
.6131 .33873 m .58342 .34182 L .58358 .34877 L .846 .42 0 r
F
.6131 .33873 m .61273 .33173 L .58342 .34182 L F
.53575 .21773 m .51257 .21873 L .51362 .22561 L 1 .876 0 r
F
.53558 .21841 m .51257 .21873 L .51362 .22561 L 1 .856 0 r
F
.81258 .47079 m .77738 .47918 L .77872 .48588 L .483 .179 0 r
F
.81258 .47079 m .81107 .46406 L .77738 .47918 L F
.1802 .56685 m .14194 .54639 L .14142 .55315 L 1 .867 0 r
F
.17983 .57352 m .1802 .56685 L .14142 .55315 L 1 .857 0 r
F
.37724 .21511 m .36184 .20763 L .35818 .21239 L 1 1 0 r
F
.37724 .21511 m .38023 .20995 L .36184 .20763 L F
.55279 .35197 m .52234 .35581 L .52233 .36245 L 1 .61 0 r
F
.5528 .35879 m .55279 .35197 L .52233 .36245 L 1 .596 0 r
F
.58358 .34877 m .55279 .35197 L .5528 .35879 L .958 .51 0 r
F
.71685 .26233 m .68975 .26934 L .6935 .27518 L .614 .545 0 r
F
.72096 .26806 m .71685 .26233 L .6935 .27518 L .61 .535 0 r
F
.20031 .51147 m .16451 .49159 L .16351 .49805 L 1 .906 0 r
F
.19959 .51785 m .20031 .51147 L .16351 .49805 L 1 .896 0 r
F
.53575 .21773 m .53398 .21129 L .51257 .21873 L 1 .876 0 r
F
.55711 .21058 m .53398 .21129 L .53575 .21773 L .948 .825 0 r
F
.55952 .21678 m .55711 .21058 L .53575 .21773 L .952 .816 0 r
F
.58333 .21523 m .55952 .21678 L .56185 .22305 L .877 .762 0 r
F
.58624 .22129 m .58333 .21523 L .56185 .22305 L .879 .752 0 r
F
.18834 .54527 m .15215 .52495 L .15132 .53157 L 1 .906 0 r
F
.1877 .55184 m .18834 .54527 L .15132 .53157 L 1 .896 0 r
F
.30004 .23409 m .28294 .21842 L .27838 .22362 L 1 1 0 r
F
.30004 .23409 m .30405 .22866 L .28294 .21842 L F
.41059 .57781 m .3438 .61113 L .34452 .61556 L .573 .453 0 r
F
.41059 .57781 m .41279 .57085 L .3438 .61113 L F
.80868 .46418 m .7741 .47254 L .77546 .47919 L .478 .176 0 r
F
.80868 .46418 m .80716 .45751 L .7741 .47254 L F
.5562 .38004 m .52236 .38683 L .52233 .39256 L 1 .698 0 r
F
.55625 .3861 m .5562 .38004 L .52233 .39256 L 1 .695 0 r
F
.63002 .27295 m .60372 .27583 L .60541 .28271 L .766 .512 0 r
F
.63197 .27975 m .60541 .28271 L .60695 .28963 L .762 .491 0 r
F
.63197 .27975 m .63002 .27295 L .60541 .28271 L F
.28741 .26972 m .26962 .25501 L .26534 .26009 L 1 1 0 r
F
.28741 .26972 m .29111 .26431 L .26962 .25501 L F
.6279 .26621 m .60189 .26901 L .60372 .27583 L .77 .533 0 r
F
.63002 .27295 m .6279 .26621 L .60372 .27583 L .766 .512 0 r
F
.66095 .36921 m .62758 .37482 L .62814 .38093 L .813 .441 0 r
F
.66095 .36921 m .66005 .36304 L .62758 .37482 L F
.55515 .79028 m .51034 .78725 L .50999 .79231 L .841 .149 0 r
F
.55515 .79028 m .55585 .7852 L .51034 .78725 L F
.27534 .70395 m .23152 .68953 L .23239 .69549 L 1 .593 0 r
F
.27609 .70976 m .27534 .70395 L .23239 .69549 L 1 .58 0 r
F
.63373 .28661 m .60695 .28963 L .60833 .2966 L .758 .468 0 r
F
.63373 .28661 m .63197 .27975 L .60695 .28963 L F
.30031 .23448 m .28337 .21902 L .27877 .22414 L 1 1 0 r
F
.30031 .23448 m .30433 .22908 L .28337 .21902 L F
.62561 .25954 m .59991 .26225 L .60189 .26901 L .773 .553 0 r
F
.6279 .26621 m .62561 .25954 L .60189 .26901 L .77 .533 0 r
F
.71317 .25619 m .68632 .26315 L .69016 .26894 L .62 .56 0 r
F
.71738 .26186 m .71317 .25619 L .69016 .26894 L .617 .549 0 r
F
.53558 .21841 m .53384 .21188 L .51257 .21873 L 1 .856 0 r
F
.55678 .21161 m .53384 .21188 L .53558 .21841 L .937 .805 0 r
F
.55913 .21795 m .55678 .21161 L .53558 .21841 L .94 .794 0 r
F
.23963 .60199 m .19692 .58658 L .19713 .59267 L 1 .691 0 r
F
.24002 .6078 m .23963 .60199 L .19713 .59267 L 1 .68 0 r
F
.64461 .20813 m .62034 .21211 L .62428 .21751 L .717 .709 0 r
F
.64904 .21338 m .64461 .20813 L .62428 .21751 L .715 .7 0 r
F
.34916 .20508 m .33357 .19248 L .32921 .19744 L 1 1 0 r
F
.34916 .20508 m .3529 .19988 L .33357 .19248 L F
.69323 .72279 m .65168 .72458 L .65071 .73016 L .637 .068 0 r
F
.69323 .72279 m .69443 .71714 L .65168 .72458 L F
.64725 .76066 m .6042 .76055 L .6033 .76591 L .711 .072 0 r
F
.64725 .76066 m .64845 .75523 L .6042 .76055 L F
.59981 .77289 m .5562 .7715 L .55554 .77657 L .773 .098 0 r
F
.59981 .77289 m .60081 .76778 L .5562 .7715 L F
.60413 .1911 m .58118 .19299 L .58471 .19829 L .775 .783 0 r
F
.60825 .19626 m .60413 .1911 L .58471 .19829 L .774 .775 0 r
F
.3425 .22941 m .32686 .21886 L .32268 .22359 L 1 1 0 r
F
.3425 .22941 m .34603 .22429 L .32686 .21886 L F
.22738 .64678 m .18605 .62952 L .18643 .63586 L 1 .725 0 r
F
.22777 .65299 m .22738 .64678 L .18643 .63586 L 1 .713 0 r
F
.34039 .23718 m .32554 .22852 L .32133 .23298 L 1 1 0 r
F
.34039 .23718 m .34388 .23209 L .32554 .22852 L F
.63531 .29352 m .60833 .2966 L .60955 .3036 L .753 .445 0 r
F
.63531 .29352 m .63373 .28661 L .60833 .2966 L F
.81401 .47752 m .77872 .48588 L .77999 .49258 L .479 .167 0 r
F
.81401 .47752 m .81258 .47079 L .77872 .48588 L F
.60403 .19132 m .58112 .19315 L .58464 .19846 L .773 .781 0 r
F
.60814 .19649 m .60403 .19132 L .58464 .19846 L .772 .773 0 r
F
.6444 .20846 m .6202 .21237 L .62412 .21777 L .714 .705 0 r
F
.64882 .21372 m .6444 .20846 L .62412 .21777 L .712 .696 0 r
F
.59281 .3982 m .55631 .40349 L .55632 .40902 L 1 .614 0 r
F
.59296 .40397 m .59281 .3982 L .55632 .40902 L 1 .612 0 r
F
.62906 .39294 m .59281 .3982 L .59296 .40397 L .945 .525 0 r
F
.62906 .39294 m .62863 .38698 L .59281 .3982 L F
.62316 .25293 m .5978 .25555 L .59991 .26225 L .776 .572 0 r
F
.62561 .25954 m .62316 .25293 L .59991 .26225 L .773 .553 0 r
F
.57399 .18255 m .55208 .18278 L .55503 .18808 L .82 .835 0 r
F
.5776 .18774 m .57399 .18255 L .55503 .18808 L .82 .828 0 r
F
.34933 .20546 m .33384 .19304 L .32949 .19799 L 1 1 0 r
F
.34933 .20546 m .35306 .20027 L .33384 .19304 L F
.71266 .25666 m .68594 .26355 L .68975 .26934 L .617 .556 0 r
F
.71685 .26233 m .71266 .25666 L .68975 .26934 L .614 .545 0 r
F
.61666 .23062 m .59183 .2336 L .59449 .23984 L .804 .674 0 r
F
.61981 .23668 m .61666 .23062 L .59449 .23984 L .804 .663 0 r
F
.57394 .1827 m .55205 .18288 L .555 .18819 L .818 .833 0 r
F
.57755 .1879 m .57394 .1827 L .555 .18819 L .818 .826 0 r
F
.4186 .77799 m .37269 .77014 L .37336 .77527 L 1 .328 0 r
F
.41896 .78301 m .4186 .77799 L .37336 .77527 L 1 .313 0 r
F
.46441 .78412 m .4186 .77799 L .41896 .78301 L .967 .266 0 r
F
.37204 .76495 m .32635 .7552 L .32726 .76052 L 1 .399 0 r
F
.37269 .77014 m .37204 .76495 L .32726 .76052 L 1 .384 0 r
F
.28568 .2773 m .2676 .26251 L .26317 .26734 L 1 1 0 r
F
.28568 .2773 m .28938 .27199 L .2676 .26251 L F
.81011 .47086 m .77546 .47919 L .77673 .48585 L .473 .163 0 r
F
.81011 .47086 m .80868 .46418 L .77546 .47919 L F
.58264 .21685 m .55913 .21795 L .56139 .22436 L .866 .735 0 r
F
.58544 .22311 m .58264 .21685 L .56139 .22436 L .866 .722 0 r
F
.19959 .51785 m .16351 .49805 L .1626 .5045 L 1 .896 0 r
F
.19896 .52421 m .19959 .51785 L .1626 .5045 L 1 .886 0 r
F
.6367 .30047 m .60955 .3036 L .6106 .31062 L .748 .421 0 r
F
.6367 .30047 m .63531 .29352 L .60955 .3036 L F
.37965 .20823 m .36433 .19975 L .36059 .20451 L 1 1 0 r
F
.37965 .20823 m .38271 .20311 L .36433 .19975 L F
.69469 .73147 m .65272 .73296 L .65173 .73861 L .643 .069 0 r
F
.69469 .73147 m .69592 .72574 L .65272 .73296 L F
.66177 .37532 m .62814 .38093 L .62863 .38698 L .814 .434 0 r
F
.66177 .37532 m .66095 .36921 L .62814 .38093 L F
.22369 .6625 m .18099 .64551 L .18158 .65189 L 1 .692 0 r
F
.22425 .66875 m .22369 .6625 L .18158 .65189 L 1 .68 0 r
F
.58364 .35564 m .58358 .34877 L .5528 .35879 L .955 .493 0 r
F
.61331 .34569 m .58358 .34877 L .58364 .35564 L .841 .399 0 r
F
.61331 .34569 m .6131 .33873 L .58358 .34877 L F
.17983 .57352 m .14142 .55315 L .141 .5599 L 1 .857 0 r
F
.17954 .58018 m .17983 .57352 L .141 .5599 L 1 .847 0 r
F
.62056 .2464 m .59556 .24892 L .5978 .25555 L .778 .59 0 r
F
.62316 .25293 m .62056 .2464 L .5978 .25555 L .776 .572 0 r
F
.78522 .60443 m .74699 .61024 L .74677 .61661 L .502 .07 0 r
F
.78522 .60443 m .78548 .59798 L .74699 .61024 L F
.52817 .17636 m .50799 .174 L .50949 .17937 L .892 .911 0 r
F
.53043 .18169 m .52817 .17636 L .50949 .17937 L .894 .905 0 r
F
.52817 .17641 m .50799 .174 L .50949 .17937 L .89 .909 0 r
F
.53042 .18174 m .52817 .17641 L .50949 .17937 L .892 .903 0 r
F
.78831 .61229 m .74939 .6179 L .74916 .62434 L .511 .071 0 r
F
.78831 .61229 m .78858 .60576 L .74939 .6179 L F
.1877 .55184 m .15132 .53157 L .15057 .53819 L 1 .896 0 r
F
.18713 .5584 m .1877 .55184 L .15057 .53819 L 1 .887 0 r
F
.53398 .21129 m .51147 .21193 L .51257 .21873 L 1 .883 0 r
F
.53384 .21188 m .51147 .21193 L .51257 .21873 L 1 .866 0 r
F
.70889 .25057 m .68242 .25741 L .68632 .26315 L .624 .57 0 r
F
.71317 .25619 m .70889 .25057 L .68632 .26315 L .62 .56 0 r
F
.54909 .17753 m .52817 .17636 L .53043 .18169 L .858 .877 0 r
F
.55208 .18278 m .54909 .17753 L .53043 .18169 L .858 .87 0 r
F
.54907 .17762 m .52817 .17641 L .53042 .18174 L .856 .875 0 r
F
.55205 .18288 m .54907 .17762 L .53042 .18174 L .857 .868 0 r
F
.29111 .26431 m .27396 .25002 L .26962 .25501 L 1 1 0 r
F
.29111 .26431 m .29487 .25897 L .27396 .25002 L F
.46442 .78905 m .46441 .78412 L .41896 .78301 L .961 .25 0 r
F
.50953 .78857 m .46441 .78412 L .46442 .78905 L .902 .197 0 r
F
.50953 .78857 m .50988 .78364 L .46441 .78412 L F
.5528 .35879 m .52233 .36245 L .52229 .36892 L 1 .596 0 r
F
.55275 .36547 m .5528 .35879 L .52229 .36892 L 1 .583 0 r
F
.58364 .35564 m .5528 .35879 L .55275 .36547 L .955 .493 0 r
F
.55625 .3861 m .52233 .39256 L .5223 .39812 L 1 .695 0 r
F
.55628 .39203 m .55625 .3861 L .5223 .39812 L 1 .691 0 r
F
.81534 .48426 m .77999 .49258 L .78117 .49929 L .474 .154 0 r
F
.81534 .48426 m .81401 .47752 L .77999 .49258 L F
.37137 .774 m .32515 .76461 L .32611 .76997 L 1 .389 0 r
F
.37203 .77925 m .37137 .774 L .32611 .76997 L 1 .373 0 r
F
.30405 .22866 m .28756 .21329 L .28294 .21842 L 1 1 0 r
F
.30405 .22866 m .30812 .22329 L .28756 .21329 L F
.60036 .78165 m .55653 .78006 L .55585 .7852 L .775 .098 0 r
F
.60036 .78165 m .60138 .77646 L .55653 .78006 L F
.74041 .67856 m .70032 .68218 L .6995 .68812 L .565 .066 0 r
F
.74041 .67856 m .74139 .67253 L .70032 .68218 L F
.7084 .25104 m .68206 .2578 L .68594 .26355 L .621 .566 0 r
F
.71266 .25666 m .7084 .25104 L .68594 .26355 L .617 .556 0 r
F
.58033 .20922 m .55711 .21058 L .55952 .21678 L .876 .772 0 r
F
.58333 .21523 m .58033 .20922 L .55952 .21678 L .877 .762 0 r
F
.63788 .30746 m .6106 .31062 L .61148 .31766 L .742 .396 0 r
F
.63788 .30746 m .6367 .30047 L .6106 .31062 L F
.29006 .63946 m .24206 .63072 L .24268 .63636 L 1 .52 0 r
F
.29066 .64473 m .29006 .63946 L .24268 .63636 L 1 .521 0 r
F
.34515 .63563 m .29006 .63946 L .29066 .64473 L .901 .436 0 r
F
.34515 .63563 m .34522 .63033 L .29006 .63946 L F
.53398 .21129 m .53215 .20491 L .51147 .21193 L 1 .883 0 r
F
.55463 .20444 m .53215 .20491 L .53398 .21129 L .944 .833 0 r
F
.55711 .21058 m .55463 .20444 L .53398 .21129 L .948 .825 0 r
F
.41829 .78686 m .37203 .77925 L .37273 .78443 L 1 .321 0 r
F
.41866 .79194 m .41829 .78686 L .37273 .78443 L 1 .305 0 r
F
.46433 .79286 m .41829 .78686 L .41866 .79194 L .963 .261 0 r
F
.81144 .47754 m .77673 .48585 L .77792 .4925 L .468 .151 0 r
F
.81144 .47754 m .81011 .47086 L .77673 .48585 L F
.30433 .22908 m .28802 .21396 L .28337 .21902 L 1 1 0 r
F
.30433 .22908 m .3084 .22374 L .28802 .21396 L F
.61782 .23995 m .5932 .24236 L .59556 .24892 L .781 .608 0 r
F
.62056 .2464 m .61782 .23995 L .59556 .24892 L .778 .59 0 r
F
.7426 .68701 m .70195 .69035 L .7011 .69636 L .573 .067 0 r
F
.7426 .68701 m .7436 .68091 L .70195 .69035 L F
.61342 .22461 m .58908 .22742 L .59183 .2336 L .804 .686 0 r
F
.61666 .23062 m .61342 .22461 L .59183 .2336 L .804 .674 0 r
F
.59296 .40397 m .55632 .40902 L .55632 .41442 L 1 .612 0 r
F
.59309 .40964 m .59296 .40397 L .55632 .41442 L 1 .61 0 r
F
.62944 .39882 m .59296 .40397 L .59309 .40964 L .947 .521 0 r
F
.62944 .39882 m .62906 .39294 L .59296 .40397 L F
.32466 .74439 m .27967 .73255 L .28071 .73812 L 1 .478 0 r
F
.32548 .74982 m .32466 .74439 L .28071 .73812 L 1 .464 0 r
F
.66251 .38137 m .62863 .38698 L .62906 .39294 L .815 .428 0 r
F
.66251 .38137 m .66177 .37532 L .62863 .38698 L F
.28938 .27199 m .27216 .25785 L .2676 .26251 L 1 1 0 r
F
.28938 .27199 m .29316 .26677 L .27216 .25785 L F
.53384 .21188 m .53203 .20543 L .51147 .21193 L 1 .866 0 r
F
.55436 .20535 m .53203 .20543 L .53384 .21188 L .934 .816 0 r
F
.55678 .21161 m .55436 .20535 L .53384 .21188 L .937 .805 0 r
F
.64011 .20294 m .61636 .20677 L .62034 .21211 L .719 .717 0 r
F
.64461 .20813 m .64011 .20294 L .62034 .21211 L .717 .709 0 r
F
.70453 .24501 m .67846 .25172 L .68242 .25741 L .627 .581 0 r
F
.70889 .25057 m .70453 .24501 L .68242 .25741 L .624 .57 0 r
F
.19896 .52421 m .1626 .5045 L .16177 .51094 L 1 .886 0 r
F
.1984 .53055 m .19896 .52421 L .16177 .51094 L 1 .876 0 r
F
.38023 .20995 m .36554 .20293 L .36184 .20763 L 1 1 0 r
F
.38023 .20995 m .38326 .20484 L .36554 .20293 L F
.27377 .71932 m .22902 .70538 L .23006 .71134 L 1 .562 0 r
F
.27465 .72513 m .27377 .71932 L .23006 .71134 L 1 .548 0 r
F
.32337 .75371 m .27763 .74227 L .27874 .74788 L 1 .464 0 r
F
.32424 .75919 m .32337 .75371 L .27874 .74788 L 1 .45 0 r
F
.24002 .6078 m .19713 .59267 L .1974 .59873 L 1 .68 0 r
F
.24046 .61358 m .24002 .6078 L .1974 .59873 L 1 .669 0 r
F
.55413 .78652 m .50988 .78364 L .50953 .78857 L .835 .136 0 r
F
.55413 .78652 m .55485 .78158 L .50988 .78364 L F
.63992 .20326 m .61623 .20702 L .6202 .21237 L .716 .714 0 r
F
.6444 .20846 m .63992 .20326 L .6202 .21237 L .714 .705 0 r
F
.57975 .21067 m .55678 .21161 L .55913 .21795 L .865 .747 0 r
F
.58264 .21685 m .57975 .21067 L .55913 .21795 L .866 .735 0 r
F
.81658 .491 m .78117 .49929 L .78227 .506 L .469 .142 0 r
F
.81658 .491 m .81534 .48426 L .78117 .49929 L F
.40844 .58495 m .34452 .61556 L .34495 .62026 L .607 .481 0 r
F
.40844 .58495 m .41059 .57781 L .34452 .61556 L F
.34388 .23209 m .32977 .22412 L .32554 .22852 L 1 1 0 r
F
.34388 .23209 m .3474 .22708 L .32977 .22412 L F
.34603 .22429 m .33108 .21422 L .32686 .21886 L F
.34603 .22429 m .34961 .21923 L .33108 .21422 L F
.46435 .79785 m .46433 .79286 L .41866 .79194 L .958 .245 0 r
F
.50963 .7973 m .46433 .79286 L .46435 .79785 L .9 .193 0 r
F
.50963 .7973 m .50999 .79231 L .46433 .79286 L F
.22777 .65299 m .18643 .63586 L .18688 .64216 L 1 .713 0 r
F
.22823 .65917 m .22777 .65299 L .18688 .64216 L 1 .701 0 r
F
.70407 .24547 m .67812 .25211 L .68206 .2578 L .624 .577 0 r
F
.7084 .25104 m .70407 .24547 L .68206 .2578 L .621 .566 0 r
F
.18713 .5584 m .15057 .53819 L .14992 .5448 L 1 .887 0 r
F
.18664 .56495 m .18713 .5584 L .14992 .5448 L 1 .877 0 r
F
.63886 .31447 m .61148 .31766 L .61219 .3247 L .736 .37 0 r
F
.63886 .31447 m .63788 .30746 L .61148 .31766 L F
.64509 .75722 m .60269 .75736 L .60177 .7626 L .702 .07 0 r
F
.64509 .75722 m .64632 .75193 L .60269 .75736 L F
.3529 .19988 m .33798 .18759 L .33357 .19248 L 1 1 0 r
F
.3529 .19988 m .35667 .19475 L .33798 .18759 L F
.27609 .70976 m .23239 .69549 L .23332 .7014 L 1 .58 0 r
F
.27691 .71553 m .27609 .70976 L .23332 .7014 L 1 .566 0 r
F
.61495 .23357 m .59072 .23587 L .5932 .24236 L .783 .625 0 r
F
.61782 .23995 m .61495 .23357 L .5932 .24236 L .781 .608 0 r
F
.17954 .58018 m .141 .5599 L .14066 .56663 L 1 .847 0 r
F
.17933 .58681 m .17954 .58018 L .14066 .56663 L 1 .837 0 r
F
.29487 .25897 m .27836 .24511 L .27396 .25002 L 1 1 0 r
F
.29487 .25897 m .29869 .25369 L .27836 .24511 L F
.81268 .48423 m .77792 .4925 L .77903 .49916 L .463 .138 0 r
F
.81268 .48423 m .81144 .47754 L .77792 .4925 L F
.58359 .36241 m .58364 .35564 L .55275 .36547 L .952 .477 0 r
F
.61337 .35258 m .58364 .35564 L .58359 .36241 L .836 .378 0 r
F
.61337 .35258 m .61331 .34569 L .58364 .35564 L F
.59995 .18599 m .5776 .18774 L .58118 .19299 L .776 .791 0 r
F
.60413 .1911 m .59995 .18599 L .58118 .19299 L .775 .783 0 r
F
.55628 .39203 m .5223 .39812 L .52228 .40352 L 1 .691 0 r
F
.5563 .39783 m .55628 .39203 L .52228 .40352 L 1 .689 0 r
F
.35306 .20027 m .33824 .18816 L .33384 .19304 L 1 1 0 r
F
.35306 .20027 m .35683 .19514 L .33824 .18816 L F
.59986 .1862 m .57755 .1879 L .58112 .19315 L .774 .789 0 r
F
.60403 .19132 m .59986 .1862 L .58112 .19315 L .773 .781 0 r
F
.53215 .20491 m .51031 .20522 L .51147 .21193 L 1 .89 0 r
F
.53203 .20543 m .51031 .20522 L .51147 .21193 L 1 .875 0 r
F
.78488 .61086 m .74677 .61661 L .74648 .62295 L .497 .068 0 r
F
.78488 .61086 m .78522 .60443 L .74677 .61661 L F
.78795 .61879 m .74916 .62434 L .74884 .63075 L .506 .069 0 r
F
.78795 .61879 m .78831 .61229 L .74916 .62434 L F
.30812 .22329 m .29223 .20823 L .28756 .21329 L 1 1 0 r
F
.30812 .22329 m .31224 .21799 L .29223 .20823 L F
.66318 .38737 m .62906 .39294 L .62944 .39882 L .816 .421 0 r
F
.66318 .38737 m .66251 .38137 L .62906 .39294 L F
.59309 .40964 m .55632 .41442 L .55632 .41971 L 1 .61 0 r
F
.5932 .4152 m .59309 .40964 L .55632 .41971 L 1 .608 0 r
F
.62978 .40463 m .59309 .40964 L .5932 .4152 L .949 .518 0 r
F
.62978 .40463 m .62944 .39882 L .59309 .40964 L F
.69196 .7284 m .65071 .73016 L .64969 .73569 L .631 .067 0 r
F
.69196 .7284 m .69323 .72279 L .65071 .73016 L F
.55275 .36547 m .52229 .36892 L .52225 .37521 L 1 .583 0 r
F
.55265 .37201 m .55275 .36547 L .52225 .37521 L 1 .57 0 r
F
.58359 .36241 m .55275 .36547 L .55265 .37201 L .952 .477 0 r
F
.70011 .2395 m .67444 .24608 L .67846 .25172 L .631 .591 0 r
F
.70453 .24501 m .70011 .2395 L .67846 .25172 L .627 .581 0 r
F
.61007 .21866 m .58624 .22129 L .58908 .22742 L .804 .697 0 r
F
.61342 .22461 m .61007 .21866 L .58908 .22742 L .804 .686 0 r
F
.22425 .66875 m .18158 .65189 L .18224 .65824 L 1 .68 0 r
F
.22487 .67495 m .22425 .66875 L .18224 .65824 L 1 .668 0 r
F
.3084 .22374 m .29272 .20897 L .28802 .21396 L 1 1 0 r
F
.3084 .22374 m .31252 .21846 L .29272 .20897 L F
.57725 .20328 m .55463 .20444 L .55711 .21058 L .874 .781 0 r
F
.58033 .20922 m .57725 .20328 L .55711 .21058 L .876 .772 0 r
F
.57033 .17742 m .54909 .17753 L .55208 .18278 L .82 .842 0 r
F
.57399 .18255 m .57033 .17742 L .55208 .18278 L .82 .835 0 r
F
.1984 .53055 m .16177 .51094 L .16103 .51738 L 1 .876 0 r
F
.19793 .53687 m .1984 .53055 L .16103 .51738 L 1 .865 0 r
F
.81773 .49775 m .78227 .506 L .78328 .51271 L .464 .13 0 r
F
.81773 .49775 m .81658 .491 L .78227 .506 L F
.646 .76603 m .6033 .76591 L .60236 .77122 L .705 .071 0 r
F
.646 .76603 m .64725 .76066 L .6033 .76591 L F
.57029 .17756 m .54907 .17762 L .55205 .18288 L .818 .84 0 r
F
.57394 .1827 m .57029 .17756 L .55205 .18288 L .818 .833 0 r
F
.55442 .79529 m .50999 .79231 L .50963 .7973 L .835 .134 0 r
F
.55442 .79529 m .55515 .79028 L .50999 .79231 L F
.29316 .26677 m .27686 .25341 L .27216 .25785 L 1 1 0 r
F
.29316 .26677 m .297 .26164 L .27686 .25341 L F
.69968 .23996 m .67411 .24646 L .67812 .25211 L .628 .587 0 r
F
.70407 .24547 m .69968 .23996 L .67812 .25211 L .624 .577 0 r
F
.38271 .20311 m .36811 .19509 L .36433 .19975 L 1 1 0 r
F
.38271 .20311 m .38579 .19806 L .36811 .19509 L F
.63963 .32149 m .61219 .3247 L .61273 .33173 L .729 .344 0 r
F
.63963 .32149 m .63886 .31447 L .61219 .3247 L F
.61194 .22727 m .58813 .22945 L .59072 .23587 L .785 .641 0 r
F
.61495 .23357 m .61194 .22727 L .59072 .23587 L .783 .625 0 r
F
.59877 .77794 m .55554 .77657 L .55485 .78158 L .767 .084 0 r
F
.59877 .77794 m .59981 .77289 L .55554 .77657 L F
.53215 .20491 m .53026 .19861 L .51031 .20522 L 1 .89 0 r
F
.55209 .19837 m .53026 .19861 L .53215 .20491 L .94 .841 0 r
F
.55463 .20444 m .55209 .19837 L .53215 .20491 L .944 .833 0 r
F
.81383 .49092 m .77903 .49916 L .78005 .50582 L .457 .125 0 r
F
.81383 .49092 m .81268 .48423 L .77903 .49916 L F
.69339 .73714 m .65173 .73861 L .65069 .74421 L .637 .067 0 r
F
.69339 .73714 m .69469 .73147 L .65173 .73861 L F
.73936 .68454 m .6995 .68812 L .69861 .69402 L .56 .065 0 r
F
.73936 .68454 m .74041 .67856 L .6995 .68812 L F
.29066 .64473 m .24268 .63636 L .24333 .64198 L 1 .521 0 r
F
.29126 .65001 m .29066 .64473 L .24333 .64198 L 1 .522 0 r
F
.34502 .64106 m .29066 .64473 L .29126 .65001 L .915 .461 0 r
F
.34502 .64106 m .34515 .63563 L .29066 .64473 L F
.18664 .56495 m .14992 .5448 L .14935 .55141 L 1 .877 0 r
F
.18623 .57148 m .18664 .56495 L .14935 .55141 L 1 .867 0 r
F
.37269 .77014 m .32726 .76052 L .32822 .76577 L 1 .384 0 r
F
.37336 .77527 m .37269 .77014 L .32822 .76577 L 1 .368 0 r
F
.63556 .19782 m .61233 .20149 L .61636 .20677 L .721 .726 0 r
F
.64011 .20294 m .63556 .19782 L .61636 .20677 L .719 .717 0 r
F
.53203 .20543 m .53017 .19906 L .51031 .20522 L 1 .875 0 r
F
.55186 .19916 m .53017 .19906 L .53203 .20543 L .932 .826 0 r
F
.55436 .20535 m .55186 .19916 L .53203 .20543 L .934 .816 0 r
F
.41896 .78301 m .37336 .77527 L .37406 .78034 L 1 .313 0 r
F
.41933 .78797 m .41896 .78301 L .37406 .78034 L 1 .297 0 r
F
.46442 .78905 m .41896 .78301 L .41933 .78797 L .961 .25 0 r
F
.57676 .20456 m .55436 .20535 L .55678 .21161 L .864 .76 0 r
F
.57975 .21067 m .57676 .20456 L .55678 .21161 L .865 .747 0 r
F
.67056 .2879 m .64342 .29315 L .64548 .29955 L .696 .472 0 r
F
.67292 .29421 m .64548 .29955 L .64743 .30596 L .693 .458 0 r
F
.67292 .29421 m .67056 .2879 L .64548 .29955 L F
.29869 .25369 m .28284 .2403 L .27836 .24511 L 1 1 0 r
F
.29869 .25369 m .30255 .24848 L .28284 .2403 L F
.66807 .28162 m .64124 .28675 L .64342 .29315 L .698 .486 0 r
F
.67056 .2879 m .66807 .28162 L .64342 .29315 L .696 .472 0 r
F
.67516 .30052 m .64743 .30596 L .64927 .31238 L .691 .444 0 r
F
.67516 .30052 m .67292 .29421 L .64743 .30596 L F
.63539 .19813 m .61221 .20173 L .61623 .20702 L .718 .723 0 r
F
.63992 .20326 m .63539 .19813 L .61623 .20702 L .716 .714 0 r
F
.66378 .3933 m .62944 .39882 L .62978 .40463 L .817 .416 0 r
F
.66378 .3933 m .66318 .38737 L .62944 .39882 L F
.24046 .61358 m .1974 .59873 L .19775 .60476 L 1 .669 0 r
F
.24095 .61933 m .24046 .61358 L .19775 .60476 L 1 .659 0 r
F
.5563 .39783 m .52228 .40352 L .52227 .40876 L 1 .689 0 r
F
.55631 .40349 m .5563 .39783 L .52227 .40876 L 1 .687 0 r
F
.69562 .23405 m .67036 .2405 L .67444 .24608 L .634 .601 0 r
F
.70011 .2395 m .69562 .23405 L .67444 .24608 L .631 .591 0 r
F
.74152 .69307 m .7011 .69636 L .7002 .70233 L .567 .065 0 r
F
.74152 .69307 m .7426 .68701 L .7011 .69636 L F
.17933 .58681 m .14066 .56663 L .14041 .57336 L 1 .837 0 r
F
.17919 .59343 m .17933 .58681 L .14041 .57336 L 1 .826 0 r
F
.66546 .27536 m .63894 .28038 L .64124 .28675 L .701 .5 0 r
F
.66807 .28162 m .66546 .27536 L .64124 .28675 L .698 .486 0 r
F
.67728 .30685 m .64927 .31238 L .65099 .31879 L .688 .431 0 r
F
.67728 .30685 m .67516 .30052 L .64927 .31238 L F
.5932 .4152 m .55632 .41971 L .55633 .42488 L 1 .608 0 r
F
.59329 .42067 m .5932 .4152 L .55633 .42488 L 1 .607 0 r
F
.63007 .41035 m .5932 .4152 L .59329 .42067 L .95 .515 0 r
F
.63007 .41035 m .62978 .40463 L .5932 .4152 L F
.16858 .41806 m .17083 .41142 L .13976 .3953 L 1 1 0 r
F
.52817 .17636 m .52589 .17108 L .50799 .174 L .892 .911 0 r
F
.54608 .17234 m .52589 .17108 L .52817 .17636 L .857 .883 0 r
F
.54909 .17753 m .54608 .17234 L .52817 .17636 L .858 .877 0 r
F
.52817 .17641 m .52588 .17113 L .50799 .174 L .89 .909 0 r
F
.54606 .17242 m .52588 .17113 L .52817 .17641 L .855 .881 0 r
F
.54907 .17762 m .54606 .17242 L .52817 .17641 L .856 .875 0 r
F
.52589 .17108 m .50648 .16868 L .50799 .174 L .891 .917 0 r
F
.52588 .17113 m .50648 .16868 L .50799 .174 L .889 .915 0 r
F
.40636 .59224 m .34495 .62026 L .34517 .62519 L .639 .506 0 r
F
.40636 .59224 m .40844 .58495 L .34495 .62026 L F
.66272 .26913 m .63654 .27403 L .63894 .28038 L .703 .514 0 r
F
.66546 .27536 m .66272 .26913 L .63894 .28038 L .701 .5 0 r
F
.3474 .22708 m .33402 .21979 L .32977 .22412 L 1 1 0 r
F
.3474 .22708 m .35096 .22212 L .33402 .21979 L F
.81878 .50451 m .78328 .51271 L .78421 .51941 L .459 .118 0 r
F
.81878 .50451 m .81773 .49775 L .78328 .51271 L F
.58344 .36907 m .58359 .36241 L .55265 .37201 L .948 .461 0 r
F
.61328 .3594 m .58359 .36241 L .58344 .36907 L .831 .357 0 r
F
.61328 .3594 m .61337 .35258 L .58359 .36241 L F
.67927 .31317 m .65099 .31879 L .6526 .32519 L .686 .417 0 r
F
.67927 .31317 m .67728 .30685 L .65099 .31879 L F
.22823 .65917 m .18688 .64216 L .18742 .64844 L 1 .701 0 r
F
.22875 .66532 m .22823 .65917 L .18742 .64844 L 1 .688 0 r
F
.69521 .23451 m .67005 .24087 L .67411 .24646 L .631 .597 0 r
F
.69968 .23996 m .69521 .23451 L .67411 .24646 L .628 .587 0 r
F
.34961 .21923 m .33536 .20968 L .33108 .21422 L 1 1 0 r
F
.34961 .21923 m .35323 .21425 L .33536 .20968 L F
.60664 .21277 m .58333 .21523 L .58624 .22129 L .805 .708 0 r
F
.61007 .21866 m .60664 .21277 L .58624 .22129 L .804 .697 0 r
F
.31224 .21799 m .29696 .20324 L .29223 .20823 L 1 1 0 r
F
.31224 .21799 m .31641 .21275 L .29696 .20324 L F
.37203 .77925 m .32611 .76997 L .32711 .77527 L 1 .373 0 r
F
.37273 .78443 m .37203 .77925 L .32711 .77527 L 1 .358 0 r
F
.38326 .20484 m .36927 .19831 L .36554 .20293 L 1 1 0 r
F
.38326 .20484 m .38632 .1998 L .36927 .19831 L F
.60881 .22105 m .58544 .22311 L .58813 .22945 L .787 .657 0 r
F
.61194 .22727 m .60881 .22105 L .58813 .22945 L .785 .641 0 r
F
.6402 .32851 m .61273 .33173 L .6131 .33873 L .722 .317 0 r
F
.6402 .32851 m .63963 .32149 L .61273 .33173 L F
.19793 .53687 m .16103 .51738 L .16038 .5238 L 1 .865 0 r
F
.19754 .54317 m .19793 .53687 L .16038 .5238 L 1 .854 0 r
F
.46443 .79391 m .46442 .78905 L .41933 .78797 L .956 .235 0 r
F
.50917 .79343 m .46442 .78905 L .46443 .79391 L .896 .181 0 r
F
.50917 .79343 m .50953 .78857 L .46442 .78905 L F
.5993 .78676 m .55585 .7852 L .55515 .79028 L .769 .084 0 r
F
.5993 .78676 m .60036 .78165 L .55585 .7852 L F
.81488 .49761 m .78005 .50582 L .78099 .51247 L .452 .113 0 r
F
.81488 .49761 m .81383 .49092 L .78005 .50582 L F
.78444 .61726 m .74648 .62295 L .7461 .62927 L .491 .067 0 r
F
.78444 .61726 m .78488 .61086 L .74648 .62295 L F
.65986 .26293 m .63402 .26771 L .63654 .27403 L .706 .528 0 r
F
.66272 .26913 m .65986 .26293 L .63654 .27403 L .703 .514 0 r
F
.35667 .19475 m .34244 .18278 L .33798 .18759 L 1 1 0 r
F
.35667 .19475 m .36049 .18968 L .34244 .18278 L F
.16858 .41806 m .13976 .3953 L .13724 .40192 L F
.1664 .42473 m .16858 .41806 L .13724 .40192 L F
.53026 .19861 m .50912 .19861 L .51031 .20522 L 1 .898 0 r
F
.53017 .19906 m .50912 .19861 L .51031 .20522 L 1 .884 0 r
F
.68114 .31949 m .6526 .32519 L .6541 .33157 L .684 .404 0 r
F
.68114 .31949 m .67927 .31317 L .6526 .32519 L F
.27465 .72513 m .23006 .71134 L .23116 .71725 L 1 .548 0 r
F
.27559 .7309 m .27465 .72513 L .23116 .71725 L 1 .534 0 r
F
.78751 .62527 m .74884 .63075 L .74846 .63714 L .5 .067 0 r
F
.78751 .62527 m .78795 .61879 L .74884 .63075 L F
.32548 .74982 m .28071 .73812 L .2818 .74364 L 1 .464 0 r
F
.32635 .7552 m .32548 .74982 L .2818 .74364 L 1 .449 0 r
F
.297 .26164 m .28172 .2492 L .27686 .25341 L 1 1 0 r
F
.297 .26164 m .30092 .25662 L .28172 .2492 L F
.31252 .21846 m .29746 .20404 L .29272 .20897 L F
.31252 .21846 m .3167 .21325 L .29746 .20404 L F
.55265 .37201 m .52225 .37521 L .52219 .38133 L 1 .57 0 r
F
.55251 .3784 m .55265 .37201 L .52219 .38133 L 1 .558 0 r
F
.58344 .36907 m .55265 .37201 L .55251 .3784 L .948 .461 0 r
F
.41866 .79194 m .37273 .78443 L .37346 .78955 L 1 .305 0 r
F
.41904 .79695 m .41866 .79194 L .37346 .78955 L 1 .289 0 r
F
.46435 .79785 m .41866 .79194 L .41904 .79695 L .958 .245 0 r
F
.35683 .19514 m .34269 .18335 L .33824 .18816 L 1 1 0 r
F
.35683 .19514 m .36063 .19007 L .34269 .18335 L F
.59573 .18095 m .57399 .18255 L .5776 .18774 L .777 .799 0 r
F
.59995 .18599 m .59573 .18095 L .5776 .18774 L .776 .791 0 r
F
.27691 .71553 m .23332 .7014 L .23432 .70726 L 1 .566 0 r
F
.27777 .72126 m .27691 .71553 L .23432 .70726 L 1 .552 0 r
F
.65688 .25677 m .63139 .26142 L .63402 .26771 L .708 .542 0 r
F
.65986 .26293 m .65688 .25677 L .63402 .26771 L .706 .528 0 r
F
.32424 .75919 m .27874 .74788 L .2799 .75343 L 1 .45 0 r
F
.32515 .76461 m .32424 .75919 L .2799 .75343 L 1 .434 0 r
F
.18623 .57148 m .14935 .55141 L .14887 .55801 L 1 .867 0 r
F
.1859 .57801 m .18623 .57148 L .14887 .55801 L 1 .857 0 r
F
.68289 .3258 m .6541 .33157 L .65549 .33793 L .682 .391 0 r
F
.68289 .3258 m .68114 .31949 L .6541 .33157 L F
.59565 .18115 m .57394 .1827 L .57755 .1879 L .775 .797 0 r
F
.59986 .1862 m .59565 .18115 L .57755 .1879 L .774 .789 0 r
F
.5741 .1974 m .55209 .19837 L .55463 .20444 L .872 .791 0 r
F
.57725 .20328 m .5741 .1974 L .55463 .20444 L .874 .781 0 r
F
.66432 .39917 m .62978 .40463 L .63007 .41035 L .818 .41 0 r
F
.66432 .39917 m .66378 .3933 L .62978 .40463 L F
.69107 .22866 m .66621 .23496 L .67036 .2405 L .638 .611 0 r
F
.69562 .23405 m .69107 .22866 L .67036 .2405 L .634 .601 0 r
F
.1664 .42473 m .13724 .40192 L .13481 .40856 L 1 1 0 r
F
.16431 .43141 m .1664 .42473 L .13481 .40856 L F
.22487 .67495 m .18224 .65824 L .18299 .66455 L 1 .668 0 r
F
.22557 .68112 m .22487 .67495 L .18299 .66455 L 1 .655 0 r
F
.30255 .24848 m .28737 .23558 L .28284 .2403 L 1 1 0 r
F
.30255 .24848 m .30648 .24335 L .28737 .23558 L F
.59329 .42067 m .55633 .42488 L .55635 .42993 L 1 .607 0 r
F
.59337 .42604 m .59329 .42067 L .55635 .42993 L 1 .606 0 r
F
.63032 .41599 m .59329 .42067 L .59337 .42604 L .951 .512 0 r
F
.63032 .41599 m .63007 .41035 L .59329 .42067 L F
.55631 .40349 m .52227 .40876 L .52226 .41387 L 1 .687 0 r
F
.55632 .40902 m .55631 .40349 L .52226 .41387 L 1 .685 0 r
F
.64381 .76246 m .60177 .7626 L .60081 .76778 L .696 .069 0 r
F
.64381 .76246 m .64509 .75722 L .60177 .7626 L F
.69068 .22911 m .66592 .23533 L .67005 .24087 L .635 .607 0 r
F
.69521 .23451 m .69068 .22911 L .67005 .24087 L .631 .597 0 r
F
.81974 .51126 m .78421 .51941 L .78506 .52611 L .454 .106 0 r
F
.81974 .51126 m .81878 .50451 L .78421 .51941 L F
.55339 .7914 m .50953 .78857 L .50917 .79343 L .829 .121 0 r
F
.55339 .7914 m .55413 .78652 L .50953 .78857 L F
.65378 .25065 m .62865 .25517 L .63139 .26142 L .711 .556 0 r
F
.65688 .25677 m .65378 .25065 L .63139 .26142 L .708 .542 0 r
F
.68452 .33209 m .65549 .33793 L .65678 .34426 L .68 .379 0 r
F
.68452 .33209 m .68289 .3258 L .65549 .33793 L F
.53026 .19861 m .52832 .19239 L .50912 .19861 L 1 .898 0 r
F
.54948 .19237 m .52832 .19239 L .53026 .19861 L .937 .85 0 r
F
.55209 .19837 m .54948 .19237 L .53026 .19861 L .94 .841 0 r
F
.81583 .5043 m .78099 .51247 L .78185 .51912 L .447 .1 0 r
F
.81583 .5043 m .81488 .49761 L .78099 .51247 L F
.17919 .59343 m .14041 .57336 L .14025 .58006 L 1 .826 0 r
F
.17914 .60002 m .17919 .59343 L .14025 .58006 L 1 .815 0 r
F
.57369 .19854 m .55186 .19916 L .55436 .20535 L .863 .771 0 r
F
.57676 .20456 m .57369 .19854 L .55436 .20535 L .864 .76 0 r
F
.60555 .21492 m .58264 .21685 L .58544 .22311 L .789 .672 0 r
F
.60881 .22105 m .60555 .21492 L .58544 .22311 L .787 .657 0 r
F
.63096 .19275 m .60825 .19626 L .61233 .20149 L .723 .735 0 r
F
.63556 .19782 m .63096 .19275 L .61233 .20149 L .721 .726 0 r
F
.69063 .73395 m .64969 .73569 L .64862 .74116 L .625 .065 0 r
F
.69063 .73395 m .69196 .7284 L .64969 .73569 L F
.46436 .80278 m .46435 .79785 L .41904 .79695 L .952 .229 0 r
F
.50926 .80223 m .46435 .79785 L .46436 .80278 L .894 .178 0 r
F
.50926 .80223 m .50963 .7973 L .46435 .79785 L F
.16431 .43141 m .13481 .40856 L .13247 .41523 L 1 1 0 r
F
.16231 .43811 m .16431 .43141 L .13247 .41523 L F
.29126 .65001 m .24333 .64198 L .24403 .64757 L 1 .522 0 r
F
.29184 .65529 m .29126 .65001 L .24403 .64757 L F
.34484 .64658 m .29126 .65001 L .29184 .65529 L .928 .481 0 r
F
.34484 .64658 m .34502 .64106 L .29126 .65001 L F
.6308 .19305 m .60814 .19649 L .61221 .20173 L .72 .732 0 r
F
.63539 .19813 m .6308 .19305 L .61221 .20173 L .718 .723 0 r
F
.38579 .19806 m .37192 .19051 L .36811 .19509 L 1 1 0 r
F
.53017 .19906 m .52825 .19278 L .50912 .19861 L 1 .884 0 r
F
.54929 .19306 m .52825 .19278 L .53017 .19906 L .929 .836 0 r
F
.55186 .19916 m .54929 .19306 L .53017 .19906 L .932 .826 0 r
F
.19754 .54317 m .16038 .5238 L .15982 .53021 L 1 .854 0 r
F
.19722 .54945 m .19754 .54317 L .15982 .53021 L 1 .844 0 r
F
.64056 .33551 m .6131 .33873 L .61331 .34569 L .714 .29 0 r
F
.64056 .33551 m .6402 .32851 L .6131 .33873 L F
.60312 .20695 m .58033 .20922 L .58333 .21523 L .805 .719 0 r
F
.60664 .21277 m .60312 .20695 L .58333 .21523 L .805 .708 0 r
F
.40437 .59964 m .34517 .62519 L .34522 .63033 L .671 .528 0 r
F
.40437 .59964 m .40636 .59224 L .34517 .62519 L F
.24095 .61933 m .19775 .60476 L .19816 .61076 L 1 .659 0 r
F
.24148 .62504 m .24095 .61933 L .19816 .61076 L 1 .649 0 r
F
.56664 .17235 m .54608 .17234 L .54909 .17753 L .82 .849 0 r
F
.57033 .17742 m .56664 .17235 L .54909 .17753 L .82 .842 0 r
F
.73823 .69048 m .69861 .69402 L .69766 .69987 L .554 .063 0 r
F
.73823 .69048 m .73936 .68454 L .69861 .69402 L F
.31641 .21275 m .30174 .19832 L .29696 .20324 L 1 1 0 r
F
.31641 .21275 m .32063 .20758 L .30174 .19832 L F
.5666 .17248 m .54606 .17242 L .54907 .17762 L .818 .847 0 r
F
.57029 .17756 m .5666 .17248 L .54907 .17762 L .818 .84 0 r
F
.68604 .33836 m .65678 .34426 L .65797 .35056 L .678 .367 0 r
F
.68604 .33836 m .68452 .33209 L .65678 .34426 L F
.65056 .24457 m .62581 .24896 L .62865 .25517 L .713 .57 0 r
F
.65378 .25065 m .65056 .24457 L .62865 .25517 L .711 .556 0 r
F
.58322 .3756 m .58344 .36907 L .55251 .3784 L .943 .446 0 r
F
.61306 .36612 m .58344 .36907 L .58322 .3756 L .825 .337 0 r
F
.61306 .36612 m .61328 .3594 L .58344 .36907 L F
.6648 .40497 m .63007 .41035 L .63032 .41599 L .819 .406 0 r
F
.6648 .40497 m .66432 .39917 L .63007 .41035 L F
.30092 .25662 m .28673 .24526 L .28172 .2492 L 1 1 0 r
F
.30092 .25662 m .30489 .25169 L .28673 .24526 L F
.68645 .22333 m .66201 .22948 L .66621 .23496 L .641 .621 0 r
F
.69107 .22866 m .68645 .22333 L .66621 .23496 L .638 .611 0 r
F
.16231 .43811 m .13247 .41523 L .13023 .42192 L 1 1 0 r
F
.16038 .44483 m .16231 .43811 L .13023 .42192 L F
.35096 .22212 m .3383 .21553 L .33402 .21979 L F
.35096 .22212 m .35455 .21722 L .3383 .21553 L F
.64469 .77133 m .60236 .77122 L .60138 .77646 L .699 .069 0 r
F
.64469 .77133 m .646 .76603 L .60236 .77122 L F
.3167 .21325 m .30225 .19917 L .29746 .20404 L 1 1 0 r
F
.3167 .21325 m .32091 .2081 L .30225 .19917 L F
.22875 .66532 m .18742 .64844 L .18804 .65468 L 1 .688 0 r
F
.22934 .67143 m .22875 .66532 L .18804 .65468 L 1 .676 0 r
F
.69203 .74276 m .65069 .74421 L .6496 .74975 L .631 .065 0 r
F
.69203 .74276 m .69339 .73714 L .65069 .74421 L F
.35323 .21425 m .33968 .20525 L .33536 .20968 L 1 1 0 r
F
.35323 .21425 m .35689 .20934 L .33968 .20525 L F
.74036 .69909 m .7002 .70233 L .69923 .70825 L .561 .064 0 r
F
.74036 .69909 m .74152 .69307 L .7002 .70233 L F
.78393 .62363 m .7461 .62927 L .74566 .63555 L .486 .065 0 r
F
.78393 .62363 m .78444 .61726 L .7461 .62927 L F
.1859 .57801 m .14887 .55801 L .14848 .5646 L 1 .857 0 r
F
.18564 .58452 m .1859 .57801 L .14848 .5646 L 1 .847 0 r
F
.68608 .22377 m .66174 .22984 L .66592 .23533 L .638 .618 0 r
F
.69068 .22911 m .68608 .22377 L .66592 .23533 L .635 .607 0 r
F
.78697 .63172 m .74846 .63714 L .74799 .64349 L .495 .066 0 r
F
.78697 .63172 m .78751 .62527 L .74846 .63714 L F
.55251 .3784 m .52219 .38133 L .52212 .38727 L 1 .558 0 r
F
.55233 .38463 m .55251 .3784 L .52212 .38727 L 1 .548 0 r
F
.58322 .3756 m .55251 .3784 L .55233 .38463 L .943 .446 0 r
F
.82061 .51801 m .78506 .52611 L .78583 .53281 L .449 .094 0 r
F
.82061 .51801 m .81974 .51126 L .78506 .52611 L F
.59337 .42604 m .55635 .42993 L .55637 .43489 L 1 .606 0 r
F
.59344 .43132 m .59337 .42604 L .55637 .43489 L 1 .605 0 r
F
.63055 .42155 m .59337 .42604 L .59344 .43132 L .952 .51 0 r
F
.63055 .42155 m .63032 .41599 L .59337 .42604 L F
.52832 .19239 m .50788 .19209 L .50912 .19861 L 1 .905 0 r
F
.52825 .19278 m .50788 .19209 L .50912 .19861 L 1 .892 0 r
F
.55367 .80024 m .50963 .7973 L .50926 .80223 L .829 .119 0 r
F
.55367 .80024 m .55442 .79529 L .50963 .7973 L F
.55632 .40902 m .52226 .41387 L .52227 .41884 L 1 .685 0 r
F
.55632 .41442 m .55632 .40902 L .52227 .41884 L 1 .684 0 r
F
.5977 .78292 m .55485 .78158 L .55413 .78652 L .761 .073 0 r
F
.5977 .78292 m .59877 .77794 L .55485 .78158 L F
.68744 .34461 m .65797 .35056 L .65905 .35682 L .676 .355 0 r
F
.68744 .34461 m .68604 .33836 L .65797 .35056 L F
.81669 .51099 m .78185 .51912 L .78262 .52576 L .441 .088 0 r
F
.81669 .51099 m .81583 .5043 L .78185 .51912 L F
.30648 .24335 m .29196 .23097 L .28737 .23558 L 1 1 0 r
F
.30648 .24335 m .31045 .23829 L .29196 .23097 L F
.64722 .23855 m .62286 .2428 L .62581 .24896 L .716 .584 0 r
F
.65056 .24457 m .64722 .23855 L .62581 .24896 L .713 .57 0 r
F
.37336 .77527 m .32822 .76577 L .32922 .77097 L 1 .368 0 r
F
.37406 .78034 m .37336 .77527 L .32922 .77097 L 1 .353 0 r
F
.36049 .18968 m .34694 .17805 L .34244 .18278 L 1 1 0 r
F
.36049 .18968 m .36434 .18469 L .34694 .17805 L F
.38632 .1998 m .37304 .19378 L .36927 .19831 L F
.38632 .1998 m .38941 .19481 L .37304 .19378 L F
.60219 .20887 m .57975 .21067 L .58264 .21685 L .79 .687 0 r
F
.60555 .21492 m .60219 .20887 L .58264 .21685 L .789 .672 0 r
F
.16038 .44483 m .13023 .42192 L .12807 .42863 L 1 1 0 r
F
.15855 .45155 m .16038 .44483 L .12807 .42863 L F
.57088 .1916 m .54948 .19237 L .55209 .19837 L .87 .8 0 r
F
.5741 .1974 m .57088 .1916 L .55209 .19837 L .872 .791 0 r
F
.36063 .19007 m .34717 .17861 L .34269 .18335 L 1 1 0 r
F
.36063 .19007 m .36448 .18508 L .34717 .17861 L F
.41933 .78797 m .37406 .78034 L .37479 .78534 L 1 .297 0 r
F
.41972 .79286 m .41933 .78797 L .37479 .78534 L 1 .281 0 r
F
.46443 .79391 m .41933 .78797 L .41972 .79286 L .956 .235 0 r
F
.19722 .54945 m .15982 .53021 L .15935 .53661 L 1 .844 0 r
F
.19698 .5557 m .19722 .54945 L .15935 .53661 L 1 .833 0 r
F
.52589 .17108 m .52358 .16586 L .50648 .16868 L .891 .917 0 r
F
.54303 .1672 m .52358 .16586 L .52589 .17108 L .856 .889 0 r
F
.54608 .17234 m .54303 .1672 L .52589 .17108 L .857 .883 0 r
F
.52588 .17113 m .52357 .1659 L .50648 .16868 L .889 .915 0 r
F
.54301 .16728 m .52357 .1659 L .52588 .17113 L .854 .888 0 r
F
.54606 .17242 m .54301 .16728 L .52588 .17113 L .855 .881 0 r
F
.24409 .26755 m .22608 .24855 L .22156 .25405 L 1 1 0 r
F
.24409 .26755 m .24815 .26184 L .22608 .24855 L F
.17914 .60002 m .14025 .58006 L .14019 .58676 L 1 .815 0 r
F
.17916 .6066 m .17914 .60002 L .14019 .58676 L 1 .804 0 r
F
.66523 .4107 m .63032 .41599 L .63055 .42155 L .819 .401 0 r
F
.66523 .4107 m .6648 .40497 L .63032 .41599 L F
.27559 .7309 m .23116 .71725 L .23233 .72311 L 1 .534 0 r
F
.27658 .73661 m .27559 .7309 L .23233 .72311 L 1 .52 0 r
F
.40248 .6071 m .34522 .63033 L .34515 .63563 L .701 .546 0 r
F
.40248 .6071 m .40437 .59964 L .34522 .63033 L F
.59146 .17596 m .57033 .17742 L .57399 .18255 L .778 .807 0 r
F
.59573 .18095 m .59146 .17596 L .57399 .18255 L .777 .799 0 r
F
.64072 .34249 m .61331 .34569 L .61337 .35258 L .706 .263 0 r
F
.64072 .34249 m .64056 .33551 L .61331 .34569 L F
.68874 .35082 m .65905 .35682 L .66005 .36304 L .675 .344 0 r
F
.68874 .35082 m .68744 .34461 L .65905 .35682 L F
.24429 .26774 m .22611 .24858 L .22159 .25407 L 1 1 0 r
F
.24429 .26774 m .24836 .26205 L .22611 .24858 L F
.68176 .21806 m .65775 .22406 L .66201 .22948 L .645 .632 0 r
F
.68645 .22333 m .68176 .21806 L .66201 .22948 L .641 .621 0 r
F
.59139 .17616 m .57029 .17756 L .57394 .1827 L .776 .804 0 r
F
.59565 .18115 m .59139 .17616 L .57394 .1827 L .775 .797 0 r
F
.5995 .20119 m .57725 .20328 L .58033 .20922 L .805 .73 0 r
F
.60312 .20695 m .5995 .20119 L .58033 .20922 L .805 .719 0 r
F
.22557 .68112 m .18299 .66455 L .18382 .67083 L 1 .655 0 r
F
.22633 .68725 m .22557 .68112 L .18382 .67083 L 1 .642 0 r
F
.27777 .72126 m .23432 .70726 L .23539 .71308 L 1 .552 0 r
F
.2787 .72693 m .27777 .72126 L .23539 .71308 L 1 .538 0 r
F
.52358 .16586 m .50496 .16341 L .50648 .16868 L .889 .922 0 r
F
.52357 .1659 m .50496 .16341 L .50648 .16868 L .888 .921 0 r
F
.57053 .1926 m .54929 .19306 L .55186 .19916 L .862 .783 0 r
F
.57369 .19854 m .57053 .1926 L .55186 .19916 L .863 .771 0 r
F
.6263 .18775 m .60413 .1911 L .60825 .19626 L .725 .744 0 r
F
.63096 .19275 m .6263 .18775 L .60825 .19626 L .723 .735 0 r
F
.32635 .7552 m .2818 .74364 L .28294 .7491 L 1 .449 0 r
F
.32726 .76052 m .32635 .7552 L .28294 .7491 L 1 .433 0 r
F
.64377 .23258 m .61981 .23668 L .62286 .2428 L .718 .597 0 r
F
.64722 .23855 m .64377 .23258 L .62286 .2428 L .716 .584 0 r
F
.37273 .78443 m .32711 .77527 L .32815 .78051 L 1 .358 0 r
F
.37346 .78955 m .37273 .78443 L .32815 .78051 L 1 .341 0 r
F
.68141 .21849 m .65749 .22441 L .66174 .22984 L .641 .628 0 r
F
.68608 .22377 m .68141 .21849 L .66174 .22984 L .638 .618 0 r
F
.15855 .45155 m .12807 .42863 L .12602 .43536 L 1 1 0 r
F
.15679 .4583 m .15855 .45155 L .12602 .43536 L F
.62615 .18804 m .60403 .19132 L .60814 .19649 L .722 .741 0 r
F
.6308 .19305 m .62615 .18804 L .60814 .19649 L .72 .732 0 r
F
.32063 .20758 m .30658 .19349 L .30174 .19832 L 1 1 0 r
F
.32063 .20758 m .32489 .20248 L .30658 .19349 L F
.59344 .43132 m .55637 .43489 L .55641 .43975 L 1 .605 0 r
F
.59352 .4365 m .59344 .43132 L .55641 .43975 L F
.63075 .42703 m .59344 .43132 L .59352 .4365 L .953 .508 0 r
F
.63075 .42703 m .63055 .42155 L .59344 .43132 L F
.52832 .19239 m .52633 .18624 L .50788 .19209 L 1 .905 0 r
F
.54681 .18644 m .52633 .18624 L .52832 .19239 L .933 .858 0 r
F
.54948 .19237 m .54681 .18644 L .52832 .19239 L .937 .85 0 r
F
.82138 .52477 m .78583 .53281 L .7865 .5395 L .443 .082 0 r
F
.82138 .52477 m .82061 .51801 L .78583 .53281 L F
.30489 .25169 m .29189 .24161 L .28673 .24526 L 1 1 0 r
F
.30489 .25169 m .30893 .24687 L .29189 .24161 L F
.5982 .79182 m .55515 .79028 L .55442 .79529 L .762 .073 0 r
F
.5982 .79182 m .5993 .78676 L .55515 .79028 L F
.29184 .65529 m .24403 .64757 L .24476 .65313 L 1 .522 0 r
F
.29242 .66058 m .29184 .65529 L .24476 .65313 L 1 .523 0 r
F
.34466 .65217 m .29184 .65529 L .29242 .66058 L .94 .495 0 r
F
.34466 .65217 m .34484 .64658 L .29184 .65529 L F
.24148 .62504 m .19816 .61076 L .19864 .61673 L 1 .649 0 r
F
.24206 .63072 m .24148 .62504 L .19864 .61673 L 1 .64 0 r
F
.46445 .79871 m .46443 .79391 L .41972 .79286 L .95 .219 0 r
F
.50879 .79822 m .46443 .79391 L .46445 .79871 L .89 .166 0 r
F
.50879 .79822 m .50917 .79343 L .46443 .79391 L F
.81746 .51768 m .78262 .52576 L .78331 .53239 L .435 .077 0 r
F
.81746 .51768 m .81669 .51099 L .78262 .52576 L F
.18564 .58452 m .14848 .5646 L .14818 .57118 L 1 .847 0 r
F
.18546 .59101 m .18564 .58452 L .14818 .57118 L 1 .836 0 r
F
.55632 .41442 m .52227 .41884 L .52228 .42369 L 1 .684 0 r
F
.55632 .41971 m .55632 .41442 L .52228 .42369 L F
.52825 .19278 m .52627 .18658 L .50788 .19209 L 1 .892 0 r
F
.54665 .18704 m .52627 .18658 L .52825 .19278 L .926 .846 0 r
F
.54929 .19306 m .54665 .18704 L .52825 .19278 L .929 .836 0 r
F
.32515 .76461 m .2799 .75343 L .28112 .75892 L 1 .434 0 r
F
.32611 .76997 m .32515 .76461 L .28112 .75892 L 1 .419 0 r
F
.58293 .38199 m .58322 .3756 L .55233 .38463 L .939 .431 0 r
F
.61272 .37273 m .58322 .3756 L .58293 .38199 L .819 .317 0 r
F
.61272 .37273 m .61306 .36612 L .58322 .3756 L F
.24815 .26184 m .23067 .24311 L .22608 .24855 L 1 1 0 r
F
.24815 .26184 m .25228 .2562 L .23067 .24311 L F
.32091 .2081 m .30708 .19435 L .30225 .19917 L F
.32091 .2081 m .32518 .20301 L .30708 .19435 L F
.68994 .357 m .66005 .36304 L .66095 .36921 L .673 .334 0 r
F
.68994 .357 m .68874 .35082 L .66005 .36304 L F
.24836 .26205 m .23072 .24316 L .22611 .24858 L 1 1 0 r
F
.24836 .26205 m .25251 .25643 L .23072 .24316 L F
.41904 .79695 m .37346 .78955 L .37421 .7946 L 1 .289 0 r
F
.41944 .8019 m .41904 .79695 L .37421 .7946 L 1 .273 0 r
F
.46436 .80278 m .41904 .79695 L .41944 .8019 L .952 .229 0 r
F
.31045 .23829 m .29662 .22646 L .29196 .23097 L 1 1 0 r
F
.31045 .23829 m .31448 .23331 L .29662 .22646 L F
.78332 .62997 m .74566 .63555 L .74514 .64181 L .48 .063 0 r
F
.78332 .62997 m .78393 .62363 L .74566 .63555 L F
.55233 .38463 m .52212 .38727 L .52206 .39303 L 1 .548 0 r
F
.55214 .39069 m .55233 .38463 L .52206 .39303 L 1 .538 0 r
F
.58293 .38199 m .55233 .38463 L .55214 .39069 L .939 .431 0 r
F
.59872 .2029 m .57676 .20456 L .57975 .21067 L .792 .701 0 r
F
.60219 .20887 m .59872 .2029 L .57975 .21067 L .79 .687 0 r
F
.73702 .69638 m .69766 .69987 L .69665 .70568 L .548 .061 0 r
F
.73702 .69638 m .73823 .69048 L .69766 .69987 L F
.35455 .21722 m .34259 .21132 L .3383 .21553 L 1 1 0 r
F
.35455 .21722 m .35818 .21239 L .34259 .21132 L F
.66561 .41636 m .63055 .42155 L .63075 .42703 L .82 .397 0 r
F
.66561 .41636 m .66523 .4107 L .63055 .42155 L F
.64249 .76763 m .60081 .76778 L .59981 .77289 L .689 .067 0 r
F
.64249 .76763 m .64381 .76246 L .60081 .76778 L F
.68923 .73944 m .64862 .74116 L .64749 .74657 L .619 .063 0 r
F
.68923 .73944 m .69063 .73395 L .64862 .74116 L F
.15679 .4583 m .12602 .43536 L .12405 .44211 L 1 1 0 r
F
.15513 .46505 m .15679 .4583 L .12405 .44211 L F
.78635 .63814 m .74799 .64349 L .74745 .64981 L .489 .064 0 r
F
.78635 .63814 m .78697 .63172 L .74799 .64349 L F
.64021 .22667 m .61666 .23062 L .61981 .23668 L .721 .611 0 r
F
.64377 .23258 m .64021 .22667 L .61981 .23668 L .718 .597 0 r
F
.22934 .67143 m .18804 .65468 L .18873 .66089 L 1 .676 0 r
F
.23 .6775 m .22934 .67143 L .18873 .66089 L 1 .662 0 r
F
.35689 .20934 m .34406 .20093 L .33968 .20525 L 1 1 0 r
F
.35689 .20934 m .36059 .20451 L .34406 .20093 L F
.40071 .61459 m .34515 .63563 L .34502 .64106 L .729 .56 0 r
F
.40071 .61459 m .40248 .6071 L .34515 .63563 L F
.19698 .5557 m .15935 .53661 L .15896 .54299 L 1 .833 0 r
F
.19682 .56193 m .19698 .5557 L .15896 .54299 L 1 .821 0 r
F
.67701 .21285 m .65342 .21869 L .65775 .22406 L .648 .642 0 r
F
.68176 .21806 m .67701 .21285 L .65775 .22406 L .645 .632 0 r
F
.52633 .18624 m .5066 .18566 L .50788 .19209 L 1 .912 0 r
F
.52627 .18658 m .5066 .18566 L .50788 .19209 L .995 .901 0 r
F
.56291 .16733 m .54303 .1672 L .54608 .17234 L .82 .856 0 r
F
.56664 .17235 m .56291 .16733 L .54608 .17234 L .82 .849 0 r
F
.25228 .2562 m .23533 .23774 L .23067 .24311 L 1 1 0 r
F
.25228 .2562 m .25648 .25061 L .23533 .23774 L F
.55263 .79621 m .50917 .79343 L .50879 .79822 L .823 .106 0 r
F
.55263 .79621 m .55339 .7914 L .50917 .79343 L F
.56287 .16746 m .54301 .16728 L .54606 .17242 L .818 .854 0 r
F
.5666 .17248 m .56287 .16746 L .54606 .17242 L .818 .847 0 r
F
.73913 .70507 m .69923 .70825 L .69819 .71413 L .556 .062 0 r
F
.73913 .70507 m .74036 .69909 L .69923 .70825 L F
.59352 .4365 m .55641 .43975 L .55645 .44452 L 1 .605 0 r
F
.59359 .4416 m .59352 .4365 L .55645 .44452 L F
.63092 .43244 m .59352 .4365 L .59359 .4416 L .954 .506 0 r
F
.63092 .43244 m .63075 .42703 L .59352 .4365 L F
.67668 .21328 m .65318 .21904 L .65749 .22441 L .645 .638 0 r
F
.68141 .21849 m .67668 .21328 L .65749 .22441 L .641 .628 0 r
F
.69105 .36314 m .66095 .36921 L .66177 .37532 L .672 .324 0 r
F
.69105 .36314 m .68994 .357 L .66095 .36921 L F
.17916 .6066 m .14019 .58676 L .14022 .59343 L 1 .804 0 r
F
.17927 .61315 m .17916 .6066 L .14022 .59343 L 1 .793 0 r
F
.64069 .3494 m .61337 .35258 L .61328 .3594 L .697 .237 0 r
F
.64069 .3494 m .64072 .34249 L .61337 .35258 L F
.82205 .53151 m .7865 .5395 L .7871 .54619 L .438 .074 0 r
F
.82205 .53151 m .82138 .52477 L .7865 .5395 L F
.25251 .25643 m .23541 .23782 L .23072 .24316 L 1 1 0 r
F
.25251 .25643 m .25672 .25087 L .23541 .23782 L F
.56758 .18586 m .54681 .18644 L .54948 .19237 L .869 .809 0 r
F
.57088 .1916 m .56758 .18586 L .54948 .19237 L .87 .8 0 r
F
.59581 .19549 m .5741 .1974 L .57725 .20328 L .805 .74 0 r
F
.5995 .20119 m .59581 .19549 L .57725 .20328 L .805 .73 0 r
F
.46438 .80763 m .46436 .80278 L .41944 .8019 L .946 .213 0 r
F
.50888 .80708 m .46436 .80278 L .46438 .80763 L .888 .162 0 r
F
.50888 .80708 m .50926 .80223 L .46436 .80278 L F
.81813 .52435 m .78331 .53239 L .78391 .53902 L .43 .073 0 r
F
.81813 .52435 m .81746 .51768 L .78331 .53239 L F
.36434 .18469 m .35149 .17339 L .34694 .17805 L 1 1 0 r
F
.36434 .18469 m .36824 .17976 L .35149 .17339 L F
.6906 .74833 m .6496 .74975 L .64845 .75523 L .625 .064 0 r
F
.6906 .74833 m .69203 .74276 L .6496 .74975 L F
.55632 .41971 m .52228 .42369 L .52231 .42843 L 1 .684 0 r
F
.55633 .42488 m .55632 .41971 L .52231 .42843 L F
.15513 .46505 m .12405 .44211 L .12219 .44887 L 1 1 0 r
F
.15354 .47181 m .15513 .46505 L .12219 .44887 L F
.17714 .41983 m .17941 .4134 L .15011 .39797 L F
.36448 .18508 m .35171 .17395 L .34717 .17861 L F
.36448 .18508 m .36837 .18016 L .35171 .17395 L F
.64936 .25622 m .62561 .25954 L .6279 .26621 L .662 .453 0 r
F
.65184 .26285 m .6279 .26621 L .63002 .27295 L .655 .428 0 r
F
.65184 .26285 m .64936 .25622 L .6279 .26621 L F
.65412 .26956 m .63002 .27295 L .63197 .27975 L .647 .402 0 r
F
.65412 .26956 m .65184 .26285 L .63002 .27295 L F
.30893 .24687 m .29718 .23823 L .29189 .24161 L 1 1 0 r
F
.30893 .24687 m .31302 .24215 L .29718 .23823 L F
.63654 .22082 m .61342 .22461 L .61666 .23062 L .723 .624 0 r
F
.64021 .22667 m .63654 .22082 L .61666 .23062 L .721 .611 0 r
F
.64333 .77658 m .60138 .77646 L .60036 .78165 L .693 .067 0 r
F
.64333 .77658 m .64469 .77133 L .60138 .77646 L F
.32489 .20248 m .31147 .18872 L .30658 .19349 L 1 1 0 r
F
.32489 .20248 m .32921 .19744 L .31147 .18872 L F
.38941 .19481 m .37685 .18933 L .37304 .19378 L F
.18546 .59101 m .14818 .57118 L .14797 .57775 L 1 .836 0 r
F
.18536 .59748 m .18546 .59101 L .14797 .57775 L 1 .825 0 r
F
.5673 .18674 m .54665 .18704 L .54929 .19306 L .862 .794 0 r
F
.57053 .1926 m .5673 .18674 L .54929 .19306 L .862 .783 0 r
F
.62159 .18281 m .59995 .18599 L .60413 .1911 L .727 .753 0 r
F
.6263 .18775 m .62159 .18281 L .60413 .1911 L .725 .744 0 r
F
.66596 .42196 m .63075 .42703 L .63092 .43244 L .821 .394 0 r
F
.66596 .42196 m .66561 .41636 L .63075 .42703 L F
.64669 .24967 m .62316 .25293 L .62561 .25954 L .669 .477 0 r
F
.64936 .25622 m .64669 .24967 L .62561 .25954 L .662 .453 0 r
F
.6562 .27633 m .63197 .27975 L .63373 .28661 L .638 .375 0 r
F
.6562 .27633 m .65412 .26956 L .63197 .27975 L F
.62145 .18309 m .59986 .1862 L .60403 .19132 L .724 .749 0 r
F
.62615 .18804 m .62145 .18309 L .60403 .19132 L .722 .741 0 r
F
.21183 .34575 m .18869 .325 L .18525 .33093 L .798 .077 0 r
F
.25648 .25061 m .24006 .23244 L .23533 .23774 L 1 1 0 r
F
.25648 .25061 m .26073 .24509 L .24006 .23244 L F
.17714 .41983 m .15011 .39797 L .14757 .40435 L F
.17496 .42629 m .17714 .41983 L .14757 .40435 L F
.22633 .68725 m .18382 .67083 L .18472 .67707 L 1 .642 0 r
F
.22716 .69334 m .22633 .68725 L .18472 .67707 L 1 .628 0 r
F
.39907 .62205 m .34502 .64106 L .34484 .64658 L .755 .571 0 r
F
.39907 .62205 m .40071 .61459 L .34502 .64106 L F
.32518 .20301 m .31195 .1896 L .30708 .19435 L 1 1 0 r
F
.32518 .20301 m .32949 .19799 L .31195 .1896 L F
.58715 .17105 m .56664 .17235 L .57033 .17742 L .779 .815 0 r
F
.59146 .17596 m .58715 .17105 L .57033 .17742 L .778 .807 0 r
F
.69205 .36923 m .66177 .37532 L .66251 .38137 L .671 .314 0 r
F
.69205 .36923 m .69105 .36314 L .66177 .37532 L F
.64385 .2432 m .62056 .2464 L .62316 .25293 L .675 .5 0 r
F
.64669 .24967 m .64385 .2432 L .62316 .25293 L .669 .477 0 r
F
.25672 .25087 m .24018 .23257 L .23541 .23782 L 1 1 0 r
F
.25672 .25087 m .261 .24538 L .24018 .23257 L F
.24206 .63072 m .19864 .61673 L .19919 .62267 L 1 .64 0 r
F
.24268 .63636 m .24206 .63072 L .19919 .62267 L 1 .63 0 r
F
.58708 .17123 m .5666 .17248 L .57029 .17756 L .777 .812 0 r
F
.59139 .17616 m .58708 .17123 L .57029 .17756 L .776 .804 0 r
F
.65807 .28318 m .63373 .28661 L .63531 .29352 L .629 .346 0 r
F
.65807 .28318 m .6562 .27633 L .63373 .28661 L F
.31448 .23331 m .30134 .22207 L .29662 .22646 L 1 1 0 r
F
.31448 .23331 m .31855 .22841 L .30134 .22207 L F
.59514 .19702 m .57369 .19854 L .57676 .20456 L .793 .715 0 r
F
.59872 .2029 m .59514 .19702 L .57676 .20456 L .792 .701 0 r
F
.29242 .66058 m .24476 .65313 L .24554 .65866 L 1 .523 0 r
F
.293 .66588 m .29242 .66058 L .24554 .65866 L F
.34447 .6578 m .29242 .66058 L .293 .66588 L .952 .505 0 r
F
.34447 .6578 m .34466 .65217 L .29242 .66058 L F
.6722 .2077 m .64904 .21338 L .65342 .21869 L .652 .652 0 r
F
.67701 .21285 m .6722 .2077 L .65342 .21869 L .648 .642 0 r
F
.58258 .38823 m .58293 .38199 L .55214 .39069 L .934 .418 0 r
F
.61228 .3792 m .58293 .38199 L .58258 .38823 L .813 .299 0 r
F
.61228 .3792 m .61272 .37273 L .58293 .38199 L F
.59658 .78784 m .55413 .78652 L .55339 .7914 L .754 .071 0 r
F
.59658 .78784 m .5977 .78292 L .55413 .78652 L F
.27658 .73661 m .23233 .72311 L .23357 .72892 L 1 .52 0 r
F
.27763 .74227 m .27658 .73661 L .23357 .72892 L 1 .505 0 r
F
.59359 .4416 m .55645 .44452 L .55651 .4492 L 1 .605 0 r
F
.59366 .44662 m .59359 .4416 L .55651 .4492 L F
.63108 .43776 m .59359 .4416 L .59366 .44662 L .954 .505 0 r
F
.63108 .43776 m .63092 .43244 L .59359 .4416 L F
.52633 .18624 m .52429 .18018 L .5066 .18566 L 1 .912 0 r
F
.54408 .18058 m .52429 .18018 L .52633 .18624 L .929 .866 0 r
F
.54681 .18644 m .54408 .18058 L .52633 .18624 L .933 .858 0 r
F
.37406 .78034 m .32922 .77097 L .33026 .77611 L 1 .353 0 r
F
.37479 .78534 m .37406 .78034 L .33026 .77611 L 1 .336 0 r
F
.55288 .80511 m .50926 .80223 L .50888 .80708 L .823 .104 0 r
F
.55288 .80511 m .55367 .80024 L .50926 .80223 L F
.2787 .72693 m .23539 .71308 L .23652 .71885 L 1 .538 0 r
F
.27967 .73255 m .2787 .72693 L .23652 .71885 L 1 .523 0 r
F
.19682 .56193 m .15896 .54299 L .15866 .54936 L 1 .821 0 r
F
.19673 .56814 m .19682 .56193 L .15866 .54936 L 1 .81 0 r
F
.15354 .47181 m .12219 .44887 L .12042 .45565 L 1 1 0 r
F
.15205 .47858 m .15354 .47181 L .12042 .45565 L F
.17496 .42629 m .14757 .40435 L .14511 .41076 L F
.17285 .43278 m .17496 .42629 L .14511 .41076 L F
.67189 .20812 m .64882 .21372 L .65318 .21904 L .648 .648 0 r
F
.67668 .21328 m .67189 .20812 L .65318 .21904 L .645 .638 0 r
F
.55214 .39069 m .52206 .39303 L .52199 .39862 L 1 .538 0 r
F
.55193 .39658 m .55214 .39069 L .52199 .39862 L 1 .528 0 r
F
.58258 .38823 m .55214 .39069 L .55193 .39658 L .934 .418 0 r
F
.52627 .18658 m .52424 .18047 L .5066 .18566 L .995 .901 0 r
F
.54395 .18111 m .52424 .18047 L .52627 .18658 L .923 .855 0 r
F
.54665 .18704 m .54395 .18111 L .52627 .18658 L .926 .846 0 r
F
.82263 .53826 m .7871 .54619 L .78761 .55286 L .433 .072 0 r
F
.82263 .53826 m .82205 .53151 L .7871 .54619 L F
.64083 .23681 m .61782 .23995 L .62056 .2464 L .681 .521 0 r
F
.64385 .2432 m .64083 .23681 L .62056 .2464 L .675 .5 0 r
F
.78263 .63628 m .74514 .64181 L .74454 .64803 L .474 .061 0 r
F
.78263 .63628 m .78332 .62997 L .74514 .64181 L F
.52358 .16586 m .52125 .16069 L .50496 .16341 L .889 .922 0 r
F
.53995 .16212 m .52125 .16069 L .52358 .16586 L .855 .896 0 r
F
.54303 .1672 m .53995 .16212 L .52358 .16586 L .856 .889 0 r
F
.65971 .29008 m .63531 .29352 L .6367 .30047 L .62 .317 0 r
F
.65971 .29008 m .65807 .28318 L .63531 .29352 L F
.52357 .1659 m .52124 .16073 L .50496 .16341 L .888 .921 0 r
F
.53993 .1622 m .52124 .16073 L .52357 .1659 L .854 .894 0 r
F
.54301 .16728 m .53993 .1622 L .52357 .1659 L .854 .888 0 r
F
.8187 .53103 m .78391 .53902 L .78443 .54563 L .424 .071 0 r
F
.8187 .53103 m .81813 .52435 L .78391 .53902 L F
.55633 .42488 m .52231 .42843 L .52234 .43306 L 1 .684 0 r
F
.55635 .42993 m .55633 .42488 L .52234 .43306 L 1 .685 0 r
F
.78564 .64453 m .74745 .64981 L .74684 .6561 L .484 .062 0 r
F
.78564 .64453 m .78635 .63814 L .74745 .64981 L F
.41972 .79286 m .37479 .78534 L .37555 .79028 L 1 .281 0 r
F
.42013 .79768 m .41972 .79286 L .37555 .79028 L 1 .264 0 r
F
.46445 .79871 m .41972 .79286 L .42013 .79768 L .95 .219 0 r
F
.63277 .21503 m .61007 .21866 L .61342 .22461 L .725 .637 0 r
F
.63654 .22082 m .63277 .21503 L .61342 .22461 L .723 .624 0 r
F
.35818 .21239 m .34691 .20719 L .34259 .21132 L 1 1 0 r
F
.35818 .21239 m .36184 .20763 L .34691 .20719 L F
.32726 .76052 m .28294 .7491 L .28414 .7545 L 1 .433 0 r
F
.32822 .76577 m .32726 .76052 L .28414 .7545 L 1 .418 0 r
F
.26073 .24509 m .24486 .22721 L .24006 .23244 L 1 1 0 r
F
.26073 .24509 m .26505 .23962 L .24486 .22721 L F
.17285 .43278 m .14511 .41076 L .14274 .41721 L F
.17082 .43928 m .17285 .43278 L .14274 .41721 L F
.23 .6775 m .18873 .66089 L .18951 .66707 L 1 .662 0 r
F
.23073 .68354 m .23 .6775 L .18951 .66707 L 1 .649 0 r
F
.66626 .42748 m .63092 .43244 L .63108 .43776 L .821 .39 0 r
F
.66626 .42748 m .66596 .42196 L .63092 .43244 L F
.17927 .61315 m .14022 .59343 L .14034 .60008 L 1 .793 0 r
F
.17945 .61968 m .17927 .61315 L .14034 .60008 L 1 .781 0 r
F
.69298 .37527 m .66251 .38137 L .66318 .38737 L .67 .305 0 r
F
.69298 .37527 m .69205 .36923 L .66251 .38137 L F
.64048 .35625 m .61328 .3594 L .61306 .36612 L .688 .211 0 r
F
.64048 .35625 m .64069 .3494 L .61328 .3594 L F
.36059 .20451 m .34848 .19672 L .34406 .20093 L 1 1 0 r
F
.36059 .20451 m .36433 .19975 L .34848 .19672 L F
.261 .24538 m .24504 .22742 L .24018 .23257 L F
.261 .24538 m .26534 .23996 L .24504 .22742 L F
.52125 .16069 m .50341 .15819 L .50496 .16341 L .888 .928 0 r
F
.52124 .16073 m .50341 .15819 L .50496 .16341 L .886 .927 0 r
F
.63766 .23051 m .61495 .23357 L .61782 .23995 L .687 .542 0 r
F
.64083 .23681 m .63766 .23051 L .61782 .23995 L .681 .521 0 r
F
.73574 .70223 m .69665 .70568 L .69557 .71143 L .541 .059 0 r
F
.73574 .70223 m .73702 .69638 L .69665 .70568 L F
.59203 .18987 m .57088 .1916 L .5741 .1974 L .805 .751 0 r
F
.59581 .19549 m .59203 .18987 L .5741 .1974 L .805 .74 0 r
F
.37346 .78955 m .32815 .78051 L .32924 .78568 L 1 .341 0 r
F
.37421 .7946 m .37346 .78955 L .32924 .78568 L 1 .325 0 r
F
.39757 .62947 m .34484 .64658 L .34466 .65217 L .78 .578 0 r
F
.39757 .62947 m .39907 .62205 L .34484 .64658 L F
.66113 .29703 m .6367 .30047 L .63788 .30746 L .609 .286 0 r
F
.66113 .29703 m .65971 .29008 L .6367 .30047 L F
.32611 .76997 m .28112 .75892 L .28239 .76436 L 1 .419 0 r
F
.32711 .77527 m .32611 .76997 L .28239 .76436 L 1 .403 0 r
F
.15205 .47858 m .12042 .45565 L .11874 .46245 L 1 1 0 r
F
.15064 .48536 m .15205 .47858 L .11874 .46245 L 1 .993 0 r
F
.18536 .59748 m .14797 .57775 L .14785 .5843 L 1 .825 0 r
F
.18534 .60393 m .18536 .59748 L .14785 .5843 L 1 .814 0 r
F
.52429 .18018 m .50529 .17933 L .5066 .18566 L .999 .919 0 r
F
.52424 .18047 m .50529 .17933 L .5066 .18566 L .99 .909 0 r
F
.31302 .24215 m .30256 .23509 L .29718 .23823 L 1 1 0 r
F
.31302 .24215 m .31715 .23752 L .30256 .23509 L F
.59366 .44662 m .55651 .4492 L .55658 .45381 L 1 .605 0 r
F
.59374 .45156 m .59366 .44662 L .55658 .45381 L 1 .606 0 r
F
.63123 .44301 m .59366 .44662 L .59374 .45156 L .955 .503 0 r
F
.63123 .44301 m .63108 .43776 L .59366 .44662 L F
.59706 .7968 m .55442 .79529 L .55367 .80024 L .756 .071 0 r
F
.59706 .7968 m .5982 .79182 L .55442 .79529 L F
.17082 .43928 m .14274 .41721 L .14047 .42368 L 1 1 0 r
F
.16888 .4458 m .17082 .43928 L .14047 .42368 L F
.32921 .19744 m .31641 .18404 L .31147 .18872 L F
.32921 .19744 m .33357 .19248 L .31641 .18404 L F
.56422 .1802 m .54408 .18058 L .54681 .18644 L .867 .818 0 r
F
.56758 .18586 m .56422 .1802 L .54681 .18644 L .869 .809 0 r
F
.66732 .20262 m .64461 .20813 L .64904 .21338 L .655 .662 0 r
F
.6722 .2077 m .66732 .20262 L .64904 .21338 L .652 .652 0 r
F
.68777 .74487 m .64749 .74657 L .64632 .75193 L .612 .061 0 r
F
.68777 .74487 m .68923 .73944 L .64749 .74657 L F
.46447 .80344 m .46445 .79871 L .42013 .79768 L .944 .202 0 r
F
.50841 .80294 m .46445 .79871 L .46447 .80344 L .884 .149 0 r
F
.50841 .80294 m .50879 .79822 L .46445 .79871 L F
.73781 .711 m .69819 .71413 L .69709 .71996 L .549 .06 0 r
F
.73781 .711 m .73913 .70507 L .69819 .71413 L F
.66703 .20303 m .6444 .20846 L .64882 .21372 L .651 .658 0 r
F
.67189 .20812 m .66703 .20303 L .64882 .21372 L .648 .648 0 r
F
.63433 .2243 m .61194 .22727 L .61495 .23357 L .692 .562 0 r
F
.63766 .23051 m .63433 .2243 L .61495 .23357 L .687 .542 0 r
F
.61683 .17794 m .59573 .18095 L .59995 .18599 L .729 .761 0 r
F
.62159 .18281 m .61683 .17794 L .59995 .18599 L .727 .753 0 r
F
.36824 .17976 m .35608 .16882 L .35149 .17339 L 1 1 0 r
F
.36824 .17976 m .37217 .17491 L .35608 .16882 L F
.26505 .23962 m .24972 .22205 L .24486 .22721 L F
.26505 .23962 m .26944 .23422 L .24972 .22205 L F
.31855 .22841 m .30611 .21779 L .30134 .22207 L F
.31855 .22841 m .32268 .22359 L .30611 .21779 L F
.64111 .77274 m .59981 .77289 L .59877 .77794 L .683 .065 0 r
F
.64111 .77274 m .64249 .76763 L .59981 .77289 L F
.59147 .19122 m .57053 .1926 L .57369 .19854 L .794 .728 0 r
F
.59514 .19702 m .59147 .19122 L .57369 .19854 L .793 .715 0 r
F
.32949 .19799 m .31687 .18491 L .31195 .1896 L 1 1 0 r
F
.32949 .19799 m .33384 .19304 L .31687 .18491 L F
.56398 .18096 m .54395 .18111 L .54665 .18704 L .861 .805 0 r
F
.5673 .18674 m .56398 .18096 L .54665 .18704 L .862 .794 0 r
F
.41944 .8019 m .37421 .7946 L .375 .79958 L 1 .273 0 r
F
.41986 .80677 m .41944 .8019 L .375 .79958 L .999 .256 0 r
F
.46438 .80763 m .41944 .8019 L .41986 .80677 L .946 .213 0 r
F
.82311 .545 m .78761 .55286 L .78803 .55953 L .427 .07 0 r
F
.82311 .545 m .82263 .53826 L .78761 .55286 L F
.55635 .42993 m .52234 .43306 L .52239 .4376 L 1 .685 0 r
F
.55637 .43489 m .55635 .42993 L .52239 .4376 L F
.6167 .1782 m .59565 .18115 L .59986 .1862 L .726 .758 0 r
F
.62145 .18309 m .6167 .1782 L .59986 .1862 L .724 .749 0 r
F
.19673 .56814 m .15866 .54936 L .15845 .55571 L 1 .81 0 r
F
.19672 .57431 m .19673 .56814 L .15845 .55571 L 1 .799 0 r
F
.6289 .20931 m .60664 .21277 L .61007 .21866 L .727 .65 0 r
F
.63277 .21503 m .6289 .20931 L .61007 .21866 L .725 .637 0 r
F
.55914 .16238 m .53995 .16212 L .54303 .1672 L .819 .863 0 r
F
.56291 .16733 m .55914 .16238 L .54303 .1672 L .82 .856 0 r
F
.69382 .38126 m .66318 .38737 L .66378 .3933 L .669 .297 0 r
F
.69382 .38126 m .69298 .37527 L .66318 .38737 L F
.5591 .1625 m .53993 .1622 L .54301 .16728 L .818 .861 0 r
F
.56287 .16746 m .5591 .1625 L .54301 .16728 L .818 .854 0 r
F
.1814 .42071 m .18346 .41433 L .15341 .39881 L 1 1 0 r
F
.36837 .18016 m .35628 .16938 L .35171 .17395 L F
.36837 .18016 m .3723 .1753 L .35628 .16938 L F
.81918 .53769 m .78443 .54563 L .78486 .55223 L .418 .07 0 r
F
.81918 .53769 m .8187 .53103 L .78443 .54563 L F
.26534 .23996 m .24999 .22237 L .24504 .22742 L 1 1 0 r
F
.26534 .23996 m .26976 .23461 L .24999 .22237 L F
.66231 .30402 m .63788 .30746 L .63886 .31447 L .598 .254 0 r
F
.66231 .30402 m .66113 .29703 L .63788 .30746 L F
.16888 .4458 m .14047 .42368 L .13828 .43017 L 1 1 0 r
F
.16702 .45234 m .16888 .4458 L .13828 .43017 L F
.66653 .43295 m .63108 .43776 L .63123 .44301 L .821 .387 0 r
F
.66653 .43295 m .66626 .42748 L .63108 .43776 L F
.24268 .63636 m .19919 .62267 L .19981 .62857 L 1 .63 0 r
F
.24333 .64198 m .24268 .63636 L .19981 .62857 L 1 .621 0 r
F
.5822 .39431 m .58258 .38823 L .55193 .39658 L .928 .406 0 r
F
.61175 .38554 m .58258 .38823 L .5822 .39431 L .806 .282 0 r
F
.61175 .38554 m .61228 .3792 L .58258 .38823 L F
.55193 .39658 m .52199 .39862 L .52193 .40405 L 1 .528 0 r
F
.55171 .40231 m .55193 .39658 L .52193 .40405 L 1 .52 0 r
F
.5822 .39431 m .55193 .39658 L .55171 .40231 L .928 .406 0 r
F
.15064 .48536 m .11874 .46245 L .11716 .46926 L 1 .993 0 r
F
.14932 .49214 m .15064 .48536 L .11716 .46926 L 1 .984 0 r
F
.293 .66588 m .24554 .65866 L .24635 .66417 L 1 .523 0 r
F
.29359 .67117 m .293 .66588 L .24635 .66417 L 1 .522 0 r
F
.34431 .66346 m .293 .66588 L .29359 .67117 L .963 .511 0 r
F
.34431 .66346 m .34447 .6578 L .293 .66588 L F
.39621 .63681 m .34466 .65217 L .34447 .6578 L .803 .583 0 r
F
.39621 .63681 m .39757 .62947 L .34466 .65217 L F
.22716 .69334 m .18472 .67707 L .18571 .68327 L 1 .628 0 r
F
.22806 .69938 m .22716 .69334 L .18571 .68327 L 1 .614 0 r
F
.68911 .75384 m .64845 .75523 L .64725 .76066 L .618 .062 0 r
F
.68911 .75384 m .6906 .74833 L .64845 .75523 L F
.1814 .42071 m .15341 .39881 L .15108 .40518 L 1 1 0 r
F
.17942 .42711 m .1814 .42071 L .15108 .40518 L F
.59374 .45156 m .55658 .45381 L .55666 .45835 L 1 .606 0 r
F
.59382 .45643 m .59374 .45156 L .55666 .45835 L F
.63136 .4482 m .59374 .45156 L .59382 .45643 L .955 .502 0 r
F
.63136 .4482 m .63123 .44301 L .59374 .45156 L F
.55184 .80095 m .50879 .79822 L .50841 .80294 L .816 .09 0 r
F
.55184 .80095 m .55263 .79621 L .50879 .79822 L F
.78185 .64255 m .74454 .64803 L .74386 .65421 L .468 .06 0 r
F
.78185 .64255 m .78263 .63628 L .74454 .64803 L F
.63086 .21817 m .60881 .22105 L .61194 .22727 L .697 .581 0 r
F
.63433 .2243 m .63086 .21817 L .61194 .22727 L .692 .562 0 r
F
.58279 .16619 m .56291 .16733 L .56664 .17235 L .779 .822 0 r
F
.58715 .17105 m .58279 .16619 L .56664 .17235 L .779 .815 0 r
F
.58273 .16636 m .56287 .16746 L .5666 .17248 L .778 .82 0 r
F
.58708 .17123 m .58273 .16636 L .5666 .17248 L .777 .812 0 r
F
.52429 .18018 m .5222 .17419 L .50529 .17933 L .999 .919 0 r
F
.54129 .1748 m .5222 .17419 L .52429 .18018 L .926 .874 0 r
F
.54408 .18058 m .54129 .1748 L .52429 .18018 L .929 .866 0 r
F
.78484 .65089 m .74684 .6561 L .74614 .66236 L .478 .061 0 r
F
.78484 .65089 m .78564 .64453 L .74684 .6561 L F
.16702 .45234 m .13828 .43017 L .13619 .43669 L 1 1 0 r
F
.16524 .45889 m .16702 .45234 L .13619 .43669 L F
.17945 .61968 m .14034 .60008 L .14055 .60671 L 1 .781 0 r
F
.17972 .62618 m .17945 .61968 L .14055 .60671 L 1 .769 0 r
F
.26944 .23422 m .25465 .21697 L .24972 .22205 L 1 1 0 r
F
.26944 .23422 m .27388 .22889 L .25465 .21697 L F
.4644 .81242 m .46438 .80763 L .41986 .80677 L .94 .196 0 r
F
.50849 .81186 m .46438 .80763 L .4644 .81242 L .881 .145 0 r
F
.50849 .81186 m .50888 .80708 L .46438 .80763 L F
.52424 .18047 m .52216 .17444 L .50529 .17933 L .99 .909 0 r
F
.54119 .17526 m .52216 .17444 L .52424 .18047 L .92 .865 0 r
F
.54395 .18111 m .54119 .17526 L .52424 .18047 L .923 .855 0 r
F
.6401 .36301 m .61306 .36612 L .61272 .37273 L .679 .186 0 r
F
.6401 .36301 m .64048 .35625 L .61306 .36612 L F
.64192 .78176 m .60036 .78165 L .5993 .78676 L .686 .065 0 r
F
.64192 .78176 m .64333 .77658 L .60036 .78165 L F
.66239 .1976 m .64011 .20294 L .64461 .20813 L .658 .672 0 r
F
.66732 .20262 m .66239 .1976 L .64461 .20813 L .655 .662 0 r
F
.69458 .3872 m .66378 .3933 L .66432 .39917 L .668 .289 0 r
F
.69458 .3872 m .69382 .38126 L .66378 .3933 L F
.18534 .60393 m .14785 .5843 L .14782 .59084 L 1 .814 0 r
F
.1854 .61037 m .18534 .60393 L .14782 .59084 L 1 .802 0 r
F
.36184 .20763 m .35127 .20316 L .34691 .20719 L 1 1 0 r
F
.36184 .20763 m .36554 .20293 L .35127 .20316 L F
.58817 .18432 m .56758 .18586 L .57088 .1916 L .805 .761 0 r
F
.59203 .18987 m .58817 .18432 L .57088 .1916 L .805 .751 0 r
F
.66325 .31105 m .63886 .31447 L .63963 .32149 L .586 .222 0 r
F
.66325 .31105 m .66231 .30402 L .63886 .31447 L F
.27763 .74227 m .23357 .72892 L .23488 .73467 L 1 .505 0 r
F
.27874 .74788 m .27763 .74227 L .23488 .73467 L 1 .49 0 r
F
.27967 .73255 m .23652 .71885 L .23773 .72457 L 1 .523 0 r
F
.28071 .73812 m .27967 .73255 L .23773 .72457 L 1 .508 0 r
F
.55637 .43489 m .52239 .4376 L .52244 .44204 L 1 .685 0 r
F
.55641 .43975 m .55637 .43489 L .52244 .44204 L 1 .686 0 r
F
.17942 .42711 m .15108 .40518 L .14883 .41156 L 1 1 0 r
F
.17754 .43353 m .17942 .42711 L .14883 .41156 L F
.26976 .23461 m .25504 .21744 L .24999 .22237 L F
.26976 .23461 m .27423 .22934 L .25504 .21744 L F
.66211 .19801 m .63992 .20326 L .6444 .20846 L .655 .668 0 r
F
.66703 .20303 m .66211 .19801 L .6444 .20846 L .651 .658 0 r
F
.62492 .20365 m .60312 .20695 L .60664 .21277 L .729 .662 0 r
F
.6289 .20931 m .62492 .20365 L .60664 .21277 L .727 .65 0 r
F
.23073 .68354 m .18951 .66707 L .19036 .67321 L 1 .649 0 r
F
.23152 .68953 m .23073 .68354 L .19036 .67321 L 1 .635 0 r
F
.31715 .23752 m .30795 .23211 L .30256 .23509 L 1 1 0 r
F
.31715 .23752 m .32133 .23298 L .30795 .23211 L F
.66677 .43834 m .63123 .44301 L .63136 .4482 L .821 .384 0 r
F
.66677 .43834 m .66653 .43295 L .63123 .44301 L F
.14932 .49214 m .11716 .46926 L .11568 .47607 L 1 .984 0 r
F
.14809 .49893 m .14932 .49214 L .11568 .47607 L 1 .976 0 r
F
.36433 .19975 m .35296 .19266 L .34848 .19672 L 1 1 0 r
F
.36433 .19975 m .36811 .19509 L .35296 .19266 L F
.82349 .55172 m .78803 .55953 L .78837 .56618 L .422 .069 0 r
F
.82349 .55172 m .82311 .545 L .78803 .55953 L F
.33357 .19248 m .3214 .17944 L .31641 .18404 L 1 1 0 r
F
.33357 .19248 m .33798 .18759 L .3214 .17944 L F
.81956 .54434 m .78486 .55223 L .78521 .55882 L .412 .068 0 r
F
.81956 .54434 m .81918 .53769 L .78486 .55223 L F
.16524 .45889 m .13619 .43669 L .1342 .44323 L 1 1 0 r
F
.16355 .46546 m .16524 .45889 L .1342 .44323 L F
.19672 .57431 m .15845 .55571 L .15832 .56204 L 1 .799 0 r
F
.19678 .58046 m .19672 .57431 L .15832 .56204 L 1 .787 0 r
F
.39499 .64404 m .34447 .6578 L .34431 .66346 L .825 .584 0 r
F
.39499 .64404 m .39621 .63681 L .34447 .6578 L F
.62725 .21214 m .60555 .21492 L .60881 .22105 L .702 .6 0 r
F
.63086 .21817 m .62725 .21214 L .60881 .22105 L .697 .581 0 r
F
.32268 .22359 m .31095 .21364 L .30611 .21779 L 1 1 0 r
F
.32268 .22359 m .32686 .21886 L .31095 .21364 L F
.37479 .78534 m .33026 .77611 L .33134 .78118 L 1 .336 0 r
F
.37555 .79028 m .37479 .78534 L .33134 .78118 L 1 .32 0 r
F
.59543 .79269 m .55339 .7914 L .55263 .79621 L .747 .069 0 r
F
.59543 .79269 m .59658 .78784 L .55339 .7914 L F
.59382 .45643 m .55666 .45835 L .55675 .46283 L 1 .606 0 r
F
.59391 .46124 m .59382 .45643 L .55675 .46283 L F
.63149 .45331 m .59382 .45643 L .59391 .46124 L .954 .501 0 r
F
.63149 .45331 m .63136 .4482 L .59382 .45643 L F
.5877 .18551 m .5673 .18674 L .57053 .1926 L .796 .741 0 r
F
.59147 .19122 m .5877 .18551 L .57053 .1926 L .794 .728 0 r
F
.73438 .70803 m .69557 .71143 L .69443 .71714 L .535 .058 0 r
F
.73438 .70803 m .73574 .70223 L .69557 .71143 L F
.17754 .43353 m .14883 .41156 L .14669 .41797 L 1 1 0 r
F
.17574 .43995 m .17754 .43353 L .14669 .41797 L F
.33384 .19304 m .32183 .18029 L .31687 .18491 L F
.33384 .19304 m .33824 .18816 L .32183 .18029 L F
.56078 .17461 m .54129 .1748 L .54408 .18058 L .865 .827 0 r
F
.56422 .1802 m .56078 .17461 L .54408 .18058 L .867 .818 0 r
F
.52125 .16069 m .51889 .15558 L .50341 .15819 L .888 .928 0 r
F
.53684 .1571 m .51889 .15558 L .52125 .16069 L .854 .902 0 r
F
.53995 .16212 m .53684 .1571 L .52125 .16069 L .855 .896 0 r
F
.5222 .17419 m .50393 .17309 L .50529 .17933 L .992 .926 0 r
F
.52216 .17444 m .50393 .17309 L .50529 .17933 L .985 .917 0 r
F
.52124 .16073 m .51889 .15562 L .50341 .15819 L .886 .927 0 r
F
.53683 .15718 m .51889 .15562 L .52124 .16073 L .853 .9 0 r
F
.53993 .1622 m .53683 .15718 L .52124 .16073 L .854 .894 0 r
F
.32822 .76577 m .28414 .7545 L .2854 .75985 L 1 .418 0 r
F
.32922 .77097 m .32822 .76577 L .2854 .75985 L 1 .401 0 r
F
.61202 .17314 m .59146 .17596 L .59573 .18095 L .731 .77 0 r
F
.61683 .17794 m .61202 .17314 L .59573 .18095 L .729 .761 0 r
F
.55208 .80991 m .50888 .80708 L .50849 .81186 L .816 .088 0 r
F
.55208 .80991 m .55288 .80511 L .50888 .80708 L F
.27388 .22889 m .25964 .21196 L .25465 .21697 L 1 1 0 r
F
.27388 .22889 m .27838 .22362 L .25964 .21196 L F
.6119 .17339 m .59139 .17616 L .59565 .18115 L .728 .767 0 r
F
.6167 .1782 m .6119 .17339 L .59565 .18115 L .726 .758 0 r
F
.69527 .39308 m .66432 .39917 L .6648 .40497 L .668 .282 0 r
F
.69527 .39308 m .69458 .3872 L .66432 .39917 L F
.55171 .40231 m .52193 .40405 L .52187 .40932 L 1 .52 0 r
F
.55148 .40787 m .55171 .40231 L .52187 .40932 L 1 .513 0 r
F
.58178 .40023 m .55171 .40231 L .55148 .40787 L .923 .395 0 r
F
.58178 .40023 m .5822 .39431 L .55171 .40231 L F
.56059 .17527 m .54119 .17526 L .54395 .18111 L .859 .816 0 r
F
.56398 .18096 m .56059 .17527 L .54395 .18111 L .861 .805 0 r
F
.55641 .43975 m .52244 .44204 L .52251 .44641 L 1 .686 0 r
F
.55645 .44452 m .55641 .43975 L .52251 .44641 L 1 .688 0 r
F
.66395 .31809 m .63963 .32149 L .6402 .32851 L .574 .189 0 r
F
.66395 .31809 m .66325 .31105 L .63963 .32149 L F
.42013 .79768 m .37555 .79028 L .37634 .79515 L 1 .264 0 r
F
.42055 .80244 m .42013 .79768 L .37634 .79515 L .999 .248 0 r
F
.46447 .80344 m .42013 .79768 L .42055 .80244 L .944 .202 0 r
F
.27423 .22934 m .2602 .21266 L .25504 .21744 L 1 1 0 r
F
.27423 .22934 m .27877 .22414 L .2602 .21266 L F
.73643 .71688 m .69709 .71996 L .69592 .72574 L .543 .058 0 r
F
.73643 .71688 m .73781 .711 L .69709 .71996 L F
.37217 .17491 m .36071 .16433 L .35608 .16882 L 1 1 0 r
F
.37217 .17491 m .37614 .17014 L .36071 .16433 L F
.61116 .39173 m .5822 .39431 L .58178 .40023 L .8 .267 0 r
F
.61116 .39173 m .61175 .38554 L .5822 .39431 L F
.16355 .46546 m .1342 .44323 L .13229 .44979 L 1 1 0 r
F
.16194 .47204 m .16355 .46546 L .13229 .44979 L F
.24333 .64198 m .19981 .62857 L .20049 .63444 L 1 .621 0 r
F
.24403 .64757 m .24333 .64198 L .20049 .63444 L 1 .613 0 r
F
.17574 .43995 m .14669 .41797 L .14464 .42439 L 1 1 0 r
F
.17402 .44639 m .17574 .43995 L .14464 .42439 L F
.14809 .49893 m .11568 .47607 L .1143 .4829 L 1 .976 0 r
F
.14694 .50571 m .14809 .49893 L .1143 .4829 L 1 .967 0 r
F
.65739 .19265 m .63556 .19782 L .64011 .20294 L .662 .682 0 r
F
.66239 .1976 m .65739 .19265 L .64011 .20294 L .658 .672 0 r
F
.29359 .67117 m .24635 .66417 L .2472 .66965 L 1 .522 0 r
F
.29419 .67647 m .29359 .67117 L .2472 .66965 L 1 .52 0 r
F
.34419 .66914 m .29359 .67117 L .29419 .67647 L .973 .515 0 r
F
.34419 .66914 m .34431 .66346 L .29359 .67117 L F
.66698 .44368 m .63136 .4482 L .63149 .45331 L .821 .381 0 r
F
.66698 .44368 m .66677 .43834 L .63136 .4482 L F
.32711 .77527 m .28239 .76436 L .28372 .76973 L 1 .403 0 r
F
.32815 .78051 m .32711 .77527 L .28372 .76973 L 1 .386 0 r
F
.3723 .1753 m .36091 .16489 L .35628 .16938 L 1 1 0 r
F
.3723 .1753 m .37626 .17053 L .36091 .16489 L F
.25292 .27582 m .23743 .25928 L .23281 .26425 L F
.25292 .27582 m .25699 .2705 L .23743 .25928 L F
.68625 .75025 m .64632 .75193 L .64509 .75722 L .606 .059 0 r
F
.68625 .75025 m .68777 .74487 L .64632 .75193 L F
.51889 .15558 m .50186 .15303 L .50341 .15819 L .886 .934 0 r
F
.51889 .15562 m .50186 .15303 L .50341 .15819 L .885 .932 0 r
F
.62085 .19806 m .5995 .20119 L .60312 .20695 L .731 .675 0 r
F
.62492 .20365 m .62085 .19806 L .60312 .20695 L .729 .662 0 r
F
.37421 .7946 m .32924 .78568 L .33037 .79079 L 1 .325 0 r
F
.375 .79958 m .37421 .7946 L .33037 .79079 L 1 .308 0 r
F
.62351 .20619 m .60219 .20887 L .60555 .21492 L .707 .617 0 r
F
.62725 .21214 m .62351 .20619 L .60555 .21492 L .702 .6 0 r
F
.65713 .19305 m .63539 .19813 L .63992 .20326 L .658 .678 0 r
F
.66211 .19801 m .65713 .19305 L .63992 .20326 L .655 .668 0 r
F
.78098 .64879 m .74386 .65421 L .74311 .66035 L .461 .058 0 r
F
.78098 .64879 m .78185 .64255 L .74386 .65421 L F
.17972 .62618 m .14055 .60671 L .14085 .61332 L 1 .769 0 r
F
.18006 .63265 m .17972 .62618 L .14085 .61332 L 1 .757 0 r
F
.59391 .46124 m .55675 .46283 L .55686 .46725 L 1 .606 0 r
F
.59401 .46598 m .59391 .46124 L .55686 .46725 L 1 .607 0 r
F
.6316 .45836 m .59391 .46124 L .59401 .46598 L .954 .5 0 r
F
.6316 .45836 m .63149 .45331 L .59391 .46124 L F
.1854 .61037 m .14782 .59084 L .14788 .59736 L 1 .802 0 r
F
.18554 .61678 m .1854 .61037 L .14788 .59736 L 1 .791 0 r
F
.39391 .65117 m .34431 .66346 L .34419 .66914 L .845 .584 0 r
F
.39391 .65117 m .39499 .64404 L .34431 .66346 L F
.82378 .55844 m .78837 .56618 L .78862 .57282 L .416 .067 0 r
F
.82378 .55844 m .82349 .55172 L .78837 .56618 L F
.22806 .69938 m .18571 .68327 L .18678 .68943 L 1 .614 0 r
F
.22902 .70538 m .22806 .69938 L .18678 .68943 L 1 .6 0 r
F
.81984 .55099 m .78521 .55882 L .78547 .56539 L .406 .066 0 r
F
.81984 .55099 m .81956 .54434 L .78521 .55882 L F
.59589 .80171 m .55367 .80024 L .55288 .80511 L .749 .069 0 r
F
.59589 .80171 m .59706 .7968 L .55367 .80024 L F
.78395 .65722 m .74614 .66236 L .74537 .66858 L .472 .059 0 r
F
.78395 .65722 m .78484 .65089 L .74614 .66236 L F
.63958 .36967 m .61272 .37273 L .61228 .3792 L .67 .163 0 r
F
.63958 .36967 m .6401 .36301 L .61272 .37273 L F
.55533 .1575 m .53684 .1571 L .53995 .16212 L .819 .87 0 r
F
.55914 .16238 m .55533 .1575 L .53995 .16212 L .819 .863 0 r
F
.78272 .31151 m .75551 .32123 L .75891 .32741 L .477 .36 0 r
F
.78636 .31761 m .75891 .32741 L .76223 .33362 L .472 .347 0 r
F
.78636 .31761 m .78272 .31151 L .75891 .32741 L F
.5553 .1576 m .53683 .15718 L .53993 .1622 L .818 .868 0 r
F
.5591 .1625 m .5553 .1576 L .53993 .1622 L .818 .861 0 r
F
.78992 .32376 m .76223 .33362 L .76547 .33988 L .467 .335 0 r
F
.78992 .32376 m .78636 .31761 L .76223 .33362 L F
.77899 .30545 m .75204 .31509 L .75551 .32123 L .482 .372 0 r
F
.78272 .31151 m .77899 .30545 L .75551 .32123 L .477 .36 0 r
F
.58423 .17885 m .56422 .1802 L .56758 .18586 L .805 .772 0 r
F
.58817 .18432 m .58423 .17885 L .56758 .18586 L .805 .761 0 r
F
.27838 .22362 m .2647 .20702 L .25964 .21196 L 1 1 0 r
F
.27838 .22362 m .28294 .21842 L .2647 .20702 L F
.31332 .22917 m .3185 .22619 L .31328 .22918 L .828 .734 0 r
F
.32554 .22852 m .3185 .22619 L .31332 .22917 L F
.31854 .22618 m .32358 .22308 L .3185 .22619 L .734 .52 0 r
F
.32977 .22412 m .32358 .22308 L .31854 .22618 L F
.32361 .22307 m .32854 .21985 L .32358 .22308 L .689 .315 0 r
F
.33402 .21979 m .32854 .21985 L .32361 .22307 L F
.32854 .21985 m .33341 .21655 L .32854 .21985 L .638 .225 0 r
F
.3383 .21553 m .33341 .21655 L .32854 .21985 L F
.34259 .21132 m .33826 .21325 L .33341 .21655 L .579 .215 0 r
F
.33341 .21655 m .33826 .21325 L .33826 .21326 L .321 .013 0 r
F
.33402 .21979 m .3383 .21553 L .32854 .21985 L .689 .315 0 r
F
.3383 .21553 m .34259 .21132 L .33341 .21655 L .638 .225 0 r
F
.33341 .21655 m .33826 .21326 L .34284 .23766 L .321 .013 0 r
F
.32854 .21985 m .33341 .21655 L .33343 .21665 L .338 .019 0 r
F
.32977 .22412 m .33402 .21979 L .32358 .22308 L .734 .52 0 r
F
.32854 .21985 m .33343 .21665 L .3398 .24331 L .338 .019 0 r
F
.32358 .22308 m .32854 .21985 L .32858 .22001 L .36 .026 0 r
F
.32554 .22852 m .32977 .22412 L .3185 .22619 L .828 .734 0 r
F
.32358 .22308 m .32858 .22001 L .33718 .24947 L .36 .026 0 r
F
.3185 .22619 m .32358 .22308 L .32363 .22323 L .379 .031 0 r
F
.32133 .23298 m .32554 .22852 L .31328 .22918 L .936 .927 0 r
F
.3185 .22619 m .32363 .22323 L .33465 .25554 L .379 .031 0 r
F
.31328 .22918 m .3185 .22619 L .31853 .22627 L .39 .034 0 r
F
.32133 .23298 m .31328 .22918 L .30797 .23211 L .936 .927 0 r
F
.31328 .22918 m .31853 .22627 L .33149 .26038 L .39 .034 0 r
F
.30797 .23211 m .31328 .22918 L .30795 .23211 L .936 .927 0 r
F
.79339 .32995 m .76547 .33988 L .76863 .34617 L .461 .322 0 r
F
.79339 .32995 m .78992 .32376 L .76547 .33988 L F
.77518 .29943 m .74849 .309 L .75204 .31509 L .488 .385 0 r
F
.77899 .30545 m .77518 .29943 L .75204 .31509 L .482 .372 0 r
F
.63967 .77779 m .59877 .77794 L .5977 .78292 L .676 .063 0 r
F
.63967 .77779 m .64111 .77274 L .59877 .77794 L F
.16194 .47204 m .13229 .44979 L .13049 .45637 L 1 1 0 r
F
.16042 .47863 m .16194 .47204 L .13049 .45637 L F
.6959 .39891 m .6648 .40497 L .66523 .4107 L .667 .276 0 r
F
.6959 .39891 m .69527 .39308 L .6648 .40497 L F
.17402 .44639 m .14464 .42439 L .14268 .43084 L 1 1 0 r
F
.1724 .45284 m .17402 .44639 L .14268 .43084 L F
.46449 .80809 m .46447 .80344 L .42055 .80244 L .937 .185 0 r
F
.50801 .80759 m .46447 .80344 L .46449 .80809 L .877 .133 0 r
F
.50801 .80759 m .50841 .80294 L .46447 .80344 L F
.79678 .33619 m .76863 .34617 L .77171 .35249 L .456 .31 0 r
F
.79678 .33619 m .79339 .32995 L .76863 .34617 L F
.19678 .58046 m .15832 .56204 L .15828 .56835 L 1 .787 0 r
F
.19692 .58658 m .19678 .58046 L .15828 .56835 L 1 .776 0 r
F
.77129 .29347 m .74486 .30294 L .74849 .309 L .493 .397 0 r
F
.77518 .29943 m .77129 .29347 L .74849 .309 L .488 .385 0 r
F
.57839 .1614 m .55914 .16238 L .56291 .16733 L .78 .83 0 r
F
.58279 .16619 m .57839 .1614 L .56291 .16733 L .779 .822 0 r
F
.55645 .44452 m .52251 .44641 L .52258 .45071 L 1 .688 0 r
F
.55651 .4492 m .55645 .44452 L .52258 .45071 L 1 .689 0 r
F
.57833 .16156 m .5591 .1625 L .56287 .16746 L .778 .828 0 r
F
.58273 .16636 m .57833 .16156 L .56287 .16746 L .778 .82 0 r
F
.36554 .20293 m .35567 .19925 L .35127 .20316 L 1 1 0 r
F
.36554 .20293 m .36927 .19831 L .35567 .19925 L F
.33798 .18759 m .32645 .17492 L .3214 .17944 L F
.33798 .18759 m .34244 .18278 L .32645 .17492 L F
.5222 .17419 m .52007 .16829 L .50393 .17309 L .992 .926 0 r
F
.53845 .1691 m .52007 .16829 L .5222 .17419 L .922 .882 0 r
F
.54129 .1748 m .53845 .1691 L .5222 .17419 L .926 .874 0 r
F
.80007 .34246 m .77171 .35249 L .7747 .35885 L .451 .297 0 r
F
.80007 .34246 m .79678 .33619 L .77171 .35249 L F
.76731 .28755 m .74116 .29693 L .74486 .30294 L .498 .409 0 r
F
.77129 .29347 m .76731 .28755 L .74486 .30294 L .493 .397 0 r
F
.25699 .2705 m .24214 .25442 L .23743 .25928 L 1 1 0 r
F
.25699 .2705 m .26113 .26526 L .24214 .25442 L F
.27877 .22414 m .26546 .20803 L .2602 .21266 L F
.27877 .22414 m .28337 .21902 L .26546 .20803 L F
.32686 .21886 m .31585 .20962 L .31095 .21364 L F
.32686 .21886 m .33108 .21422 L .31585 .20962 L F
.68755 .7593 m .64725 .76066 L .646 .76603 L .612 .06 0 r
F
.68755 .7593 m .68911 .75384 L .64725 .76066 L F
.41986 .80677 m .375 .79958 L .37582 .8045 L .999 .256 0 r
F
.4203 .81158 m .41986 .80677 L .37582 .8045 L .993 .238 0 r
F
.4644 .81242 m .41986 .80677 L .4203 .81158 L .94 .196 0 r
F
.52216 .17444 m .52003 .1685 L .50393 .17309 L .985 .917 0 r
F
.53837 .16949 m .52003 .1685 L .52216 .17444 L .917 .874 0 r
F
.54119 .17526 m .53837 .16949 L .52216 .17444 L .92 .865 0 r
F
.6644 .32514 m .6402 .32851 L .64056 .33551 L .561 .156 0 r
F
.6644 .32514 m .66395 .31809 L .6402 .32851 L F
.23152 .68953 m .19036 .67321 L .1913 .67931 L 1 .635 0 r
F
.23239 .69549 m .23152 .68953 L .1913 .67931 L 1 .621 0 r
F
.14694 .50571 m .1143 .4829 L .11302 .48974 L 1 .967 0 r
F
.14589 .5125 m .14694 .50571 L .11302 .48974 L 1 .958 0 r
F
.78168 .31207 m .75464 .32172 L .75799 .3279 L .473 .353 0 r
F
.78527 .31818 m .75799 .3279 L .76126 .33411 L .468 .34 0 r
F
.78527 .31818 m .78168 .31207 L .75799 .3279 L F
.58384 .17989 m .56398 .18096 L .5673 .18674 L .796 .754 0 r
F
.5877 .18551 m .58384 .17989 L .5673 .18674 L .796 .741 0 r
F
.778 .30601 m .7512 .31559 L .75464 .32172 L .479 .366 0 r
F
.78168 .31207 m .778 .30601 L .75464 .32172 L .473 .353 0 r
F
.80328 .34877 m .7747 .35885 L .77762 .36524 L .445 .284 0 r
F
.80328 .34877 m .80007 .34246 L .7747 .35885 L F
.76325 .28168 m .73738 .29097 L .74116 .29693 L .503 .421 0 r
F
.76731 .28755 m .76325 .28168 L .74116 .29693 L .498 .409 0 r
F
.78877 .32433 m .76126 .33411 L .76445 .34037 L .462 .327 0 r
F
.78877 .32433 m .78527 .31818 L .76126 .33411 L F
.77424 .3 m .74769 .30949 L .7512 .31559 L .484 .379 0 r
F
.778 .30601 m .77424 .3 L .7512 .31559 L .479 .366 0 r
F
.66717 .44895 m .63149 .45331 L .6316 .45836 L .821 .379 0 r
F
.66717 .44895 m .66698 .44368 L .63149 .45331 L F
.33824 .18816 m .32684 .17575 L .32183 .18029 L 1 1 0 r
F
.33824 .18816 m .34269 .18335 L .32684 .17575 L F
.79218 .33052 m .76445 .34037 L .76756 .34665 L .457 .314 0 r
F
.79218 .33052 m .78877 .32433 L .76445 .34037 L F
.36811 .19509 m .35748 .18874 L .35296 .19266 L 1 1 0 r
F
.36811 .19509 m .37192 .19051 L .35748 .18874 L F
.77039 .29403 m .7441 .30343 L .74769 .30949 L .489 .391 0 r
F
.77424 .3 m .77039 .29403 L .74769 .30949 L .484 .379 0 r
F
.59401 .46598 m .55686 .46725 L .55697 .47161 L 1 .607 0 r
F
.59411 .47066 m .59401 .46598 L .55697 .47161 L F
.63172 .46335 m .59401 .46598 L .59411 .47066 L .953 .499 0 r
F
.63172 .46335 m .6316 .45836 L .59401 .46598 L F
.61965 .20034 m .59872 .2029 L .60219 .20887 L .711 .635 0 r
F
.62351 .20619 m .61965 .20034 L .60219 .20887 L .707 .617 0 r
F
.8064 .35512 m .77762 .36524 L .78045 .37166 L .44 .271 0 r
F
.8064 .35512 m .80328 .34877 L .77762 .36524 L F
.7955 .33675 m .76756 .34665 L .77058 .35297 L .451 .301 0 r
F
.7955 .33675 m .79218 .33052 L .76756 .34665 L F
.75911 .27587 m .73352 .28505 L .73738 .29097 L .508 .433 0 r
F
.76325 .28168 m .75911 .27587 L .73738 .29097 L .503 .421 0 r
F
.28071 .73812 m .23773 .72457 L .239 .73025 L 1 .508 0 r
F
.2818 .74364 m .28071 .73812 L .239 .73025 L 1 .492 0 r
F
.76645 .28811 m .74044 .29742 L .7441 .30343 L .495 .404 0 r
F
.77039 .29403 m .76645 .28811 L .7441 .30343 L .489 .391 0 r
F
.25467 .27746 m .23777 .2596 L .23304 .26446 L 1 1 0 r
F
.25467 .27746 m .25886 .27233 L .23777 .2596 L F
.1724 .45284 m .14268 .43084 L .14082 .43729 L F
.17086 .45929 m .1724 .45284 L .14082 .43729 L F
.55148 .40787 m .52187 .40932 L .52182 .41445 L 1 .513 0 r
F
.55126 .41328 m .55148 .40787 L .52182 .41445 L 1 .506 0 r
F
.58135 .40598 m .55148 .40787 L .55126 .41328 L .917 .385 0 r
F
.58135 .40598 m .58178 .40023 L .55148 .40787 L F
.65233 .18777 m .63096 .19275 L .63556 .19782 L .665 .691 0 r
F
.65739 .19265 m .65233 .18777 L .63556 .19782 L .662 .682 0 r
F
.27874 .74788 m .23488 .73467 L .23626 .74038 L 1 .49 0 r
F
.2799 .75343 m .27874 .74788 L .23626 .74038 L 1 .474 0 r
F
.16042 .47863 m .13049 .45637 L .12877 .46296 L 1 1 0 r
F
.15898 .48523 m .16042 .47863 L .12877 .46296 L F
.61668 .19255 m .59581 .19549 L .5995 .20119 L .733 .687 0 r
F
.62085 .19806 m .61668 .19255 L .5995 .20119 L .731 .675 0 r
F
.79873 .34302 m .77058 .35297 L .77352 .35932 L .446 .288 0 r
F
.79873 .34302 m .7955 .33675 L .77058 .35297 L F
.76243 .28224 m .73669 .29146 L .74044 .29742 L .5 .416 0 r
F
.76645 .28811 m .76243 .28224 L .74044 .29742 L .495 .404 0 r
F
.60715 .1684 m .58715 .17105 L .59146 .17596 L .733 .778 0 r
F
.61202 .17314 m .60715 .1684 L .59146 .17596 L .731 .77 0 r
F
.3441 .67481 m .34419 .66914 L .29419 .67647 L .982 .517 0 r
F
.39296 .65818 m .34419 .66914 L .3441 .67481 L .863 .581 0 r
F
.39296 .65818 m .39391 .65117 L .34419 .66914 L F
.80942 .36151 m .78045 .37166 L .7832 .37811 L .434 .259 0 r
F
.80942 .36151 m .8064 .35512 L .78045 .37166 L F
.65209 .18815 m .6308 .19305 L .63539 .19813 L .661 .687 0 r
F
.65713 .19305 m .65209 .18815 L .63539 .19813 L .658 .678 0 r
F
.55103 .80561 m .50841 .80294 L .50801 .80759 L .809 .076 0 r
F
.55103 .80561 m .55184 .80095 L .50841 .80294 L F
.75489 .2701 m .7296 .27918 L .73352 .28505 L .513 .445 0 r
F
.75911 .27587 m .75489 .2701 L .73352 .28505 L .508 .433 0 r
F
.60705 .16864 m .58708 .17123 L .59139 .17616 L .73 .775 0 r
F
.6119 .17339 m .60705 .16864 L .59139 .17616 L .728 .767 0 r
F
.69646 .40467 m .66523 .4107 L .66561 .41636 L .667 .269 0 r
F
.69646 .40467 m .6959 .39891 L .66523 .4107 L F
.28294 .21842 m .26981 .20216 L .2647 .20702 L 1 1 0 r
F
.28294 .21842 m .28756 .21329 L .26981 .20216 L F
.80187 .34933 m .77352 .35932 L .77638 .36571 L .44 .275 0 r
F
.80187 .34933 m .79873 .34302 L .77352 .35932 L F
.64046 .78687 m .5993 .78676 L .5982 .79182 L .679 .063 0 r
F
.64046 .78687 m .64192 .78176 L .5993 .78676 L F
.55729 .16909 m .53845 .1691 L .54129 .1748 L .863 .836 0 r
F
.56078 .17461 m .55729 .16909 L .54129 .1748 L .865 .827 0 r
F
.75833 .27642 m .73287 .28553 L .73669 .29146 L .505 .429 0 r
F
.76243 .28224 m .75833 .27642 L .73669 .29146 L .5 .416 0 r
F
.73295 .71378 m .69443 .71714 L .69323 .72279 L .528 .056 0 r
F
.73295 .71378 m .73438 .70803 L .69443 .71714 L F
.26113 .26526 m .24693 .24967 L .24214 .25442 L 1 1 0 r
F
.26113 .26526 m .26534 .26009 L .24693 .24967 L F
.61052 .39776 m .58178 .40023 L .58135 .40598 L .793 .252 0 r
F
.61052 .39776 m .61116 .39173 L .58178 .40023 L F
.55651 .4492 m .52258 .45071 L .52266 .45493 L 1 .689 0 r
F
.55658 .45381 m .55651 .4492 L .52266 .45493 L 1 .691 0 r
F
.82397 .56515 m .78862 .57282 L .78879 .57944 L .41 .065 0 r
F
.82397 .56515 m .82378 .55844 L .78862 .57282 L F
.82003 .55762 m .78547 .56539 L .78564 .57195 L .4 .064 0 r
F
.82003 .55762 m .81984 .55099 L .78547 .56539 L F
.24403 .64757 m .20049 .63444 L .20123 .64028 L 1 .613 0 r
F
.24476 .65313 m .24403 .64757 L .20123 .64028 L 1 .604 0 r
F
.81236 .36793 m .7832 .37811 L .78586 .38459 L .429 .246 0 r
F
.81236 .36793 m .80942 .36151 L .7832 .37811 L F
.18554 .61678 m .14788 .59736 L .14803 .60386 L 1 .791 0 r
F
.18576 .62316 m .18554 .61678 L .14803 .60386 L 1 .778 0 r
F
.7506 .2644 m .7256 .27335 L .7296 .27918 L .518 .457 0 r
F
.75489 .2701 m .7506 .2644 L .7296 .27918 L .513 .445 0 r
F
.52007 .16829 m .50255 .16695 L .50393 .17309 L .986 .932 0 r
F
.52003 .1685 m .50255 .16695 L .50393 .17309 L .98 .925 0 r
F
.55713 .16967 m .53837 .16949 L .54119 .17526 L .858 .826 0 r
F
.56059 .17527 m .55713 .16967 L .54119 .17526 L .859 .816 0 r
F
.80491 .35568 m .77638 .36571 L .77915 .37212 L .434 .261 0 r
F
.80491 .35568 m .80187 .34933 L .77638 .36571 L F
.46442 .81713 m .4644 .81242 L .4203 .81158 L .933 .179 0 r
F
.50808 .81657 m .4644 .81242 L .46442 .81713 L .874 .129 0 r
F
.50808 .81657 m .50849 .81186 L .4644 .81242 L F
.75415 .27066 m .72898 .27966 L .73287 .28553 L .51 .441 0 r
F
.75833 .27642 m .75415 .27066 L .73287 .28553 L .505 .429 0 r
F
.29419 .67647 m .2472 .66965 L .2481 .6751 L 1 .52 0 r
F
.29481 .68177 m .29419 .67647 L .2481 .6751 L 1 .517 0 r
F
.3441 .67481 m .29419 .67647 L .29481 .68177 L .982 .517 0 r
F
.28337 .21902 m .2708 .20352 L .26546 .20803 L 1 1 0 r
F
.28337 .21902 m .28802 .21396 L .2708 .20352 L F
.18006 .63265 m .14085 .61332 L .14125 .6199 L 1 .757 0 r
F
.18049 .6391 m .18006 .63265 L .14125 .6199 L 1 .744 0 r
F
.14589 .5125 m .11302 .48974 L .11183 .49658 L 1 .958 0 r
F
.14492 .51929 m .14589 .5125 L .11183 .49658 L 1 .949 0 r
F
.17086 .45929 m .14082 .43729 L .13906 .44377 L 1 1 0 r
F
.16942 .46575 m .17086 .45929 L .13906 .44377 L 1 .999 0 r
F
.66734 .45417 m .6316 .45836 L .63172 .46335 L .821 .376 0 r
F
.66734 .45417 m .66717 .44895 L .6316 .45836 L F
.59411 .47066 m .55697 .47161 L .5571 .47593 L 1 .607 0 r
F
.59422 .4753 m .59411 .47066 L .5571 .47593 L F
.63183 .46829 m .59411 .47066 L .59422 .4753 L .952 .497 0 r
F
.63183 .46829 m .63172 .46335 L .59411 .47066 L F
.37614 .17014 m .36539 .15993 L .36071 .16433 L 1 1 0 r
F
.37614 .17014 m .38015 .16544 L .36539 .15993 L F
.78002 .655 m .74311 .66035 L .74229 .66646 L .455 .056 0 r
F
.78002 .655 m .78098 .64879 L .74311 .66035 L F
.80786 .36206 m .77915 .37212 L .78183 .37856 L .429 .248 0 r
F
.80786 .36206 m .80491 .35568 L .77915 .37212 L F
.8152 .37439 m .78586 .38459 L .78844 .3911 L .424 .233 0 r
F
.8152 .37439 m .81236 .36793 L .78586 .38459 L F
.19692 .58658 m .15828 .56835 L .15832 .57464 L 1 .776 0 r
F
.19713 .59267 m .19692 .58658 L .15832 .57464 L 1 .764 0 r
F
.15898 .48523 m .12877 .46296 L .12715 .46958 L 1 1 0 r
F
.15763 .49184 m .15898 .48523 L .12715 .46958 L 1 .996 0 r
F
.25886 .27233 m .24267 .25494 L .23777 .2596 L 1 1 0 r
F
.25886 .27233 m .26317 .26734 L .24267 .25494 L F
.74622 .25874 m .72153 .26758 L .7256 .27335 L .523 .469 0 r
F
.7506 .2644 m .74622 .25874 L .7256 .27335 L .518 .457 0 r
F
.73496 .72271 m .69592 .72574 L .69469 .73147 L .537 .057 0 r
F
.73496 .72271 m .73643 .71688 L .69592 .72574 L F
.74988 .26495 m .72501 .27383 L .72898 .27966 L .515 .453 0 r
F
.75415 .27066 m .74988 .26495 L .72898 .27966 L .51 .441 0 r
F
.37555 .79028 m .33134 .78118 L .33246 .78619 L 1 .32 0 r
F
.37634 .79515 m .37555 .79028 L .33246 .78619 L 1 .302 0 r
F
.66462 .33218 m .64056 .33551 L .64072 .34249 L .547 .123 0 r
F
.66462 .33218 m .6644 .32514 L .64056 .33551 L F
.37626 .17053 m .36557 .16049 L .36091 .16489 L 1 1 0 r
F
.37626 .17053 m .38026 .16583 L .36557 .16049 L F
.63893 .3762 m .61228 .3792 L .61175 .38554 L .66 .141 0 r
F
.63893 .3762 m .63958 .36967 L .61228 .3792 L F
.32922 .77097 m .2854 .75985 L .28671 .76513 L 1 .401 0 r
F
.33026 .77611 m .32922 .77097 L .28671 .76513 L 1 .385 0 r
F
.61566 .19458 m .59514 .19702 L .59872 .2029 L .715 .651 0 r
F
.61965 .20034 m .61566 .19458 L .59872 .2029 L .711 .635 0 r
F
.6892 .26964 m .66546 .27536 L .66807 .28162 L .576 .396 0 r
F
.69201 .27583 m .66807 .28162 L .67056 .2879 L .57 .378 0 r
F
.69201 .27583 m .6892 .26964 L .66807 .28162 L F
.78297 .66351 m .74537 .66858 L .74452 .67476 L .466 .057 0 r
F
.78297 .66351 m .78395 .65722 L .74537 .66858 L F
.68625 .26349 m .66272 .26913 L .66546 .27536 L .583 .414 0 r
F
.6892 .26964 m .68625 .26349 L .66546 .27536 L .576 .396 0 r
F
.59424 .79747 m .55263 .79621 L .55184 .80095 L .74 .067 0 r
F
.59424 .79747 m .59543 .79269 L .55263 .79621 L F
.58022 .17345 m .56078 .17461 L .56422 .1802 L .805 .782 0 r
F
.58423 .17885 m .58022 .17345 L .56422 .1802 L .805 .772 0 r
F
.69468 .28204 m .67056 .2879 L .67292 .29421 L .563 .36 0 r
F
.69468 .28204 m .69201 .27583 L .67056 .2879 L F
.51889 .15558 m .51651 .15053 L .50186 .15303 L .886 .934 0 r
F
.5337 .15215 m .51651 .15053 L .51889 .15558 L .853 .908 0 r
F
.53684 .1571 m .5337 .15215 L .51889 .15558 L .854 .902 0 r
F
.51889 .15562 m .51651 .15056 L .50186 .15303 L .885 .932 0 r
F
.53369 .15221 m .51651 .15056 L .51889 .15562 L .852 .906 0 r
F
.53683 .15718 m .53369 .15221 L .51889 .15562 L .853 .9 0 r
F
.68316 .25737 m .65986 .26293 L .66272 .26913 L .589 .432 0 r
F
.68625 .26349 m .68316 .25737 L .66272 .26913 L .583 .414 0 r
F
.81071 .36847 m .78183 .37856 L .78443 .38503 L .423 .234 0 r
F
.81071 .36847 m .80786 .36206 L .78183 .37856 L F
.33108 .21422 m .32081 .20575 L .31585 .20962 L 1 1 0 r
F
.33108 .21422 m .33536 .20968 L .32081 .20575 L F
.69722 .28828 m .67292 .29421 L .67516 .30052 L .556 .342 0 r
F
.69722 .28828 m .69468 .28204 L .67292 .29421 L F
.74554 .25929 m .72096 .26806 L .72501 .27383 L .52 .465 0 r
F
.74988 .26495 m .74554 .25929 L .72501 .27383 L .515 .453 0 r
F
.81795 .38087 m .78844 .3911 L .79094 .39763 L .418 .22 0 r
F
.81795 .38087 m .8152 .37439 L .78844 .3911 L F
.26534 .26009 m .25181 .24505 L .24693 .24967 L 1 1 0 r
F
.26534 .26009 m .26962 .25501 L .25181 .24505 L F
.34244 .18278 m .33154 .17049 L .32645 .17492 L F
.34244 .18278 m .34694 .17805 L .33154 .17049 L F
.22902 .70538 m .18678 .68943 L .18794 .69555 L 1 .6 0 r
F
.23006 .71134 m .22902 .70538 L .18794 .69555 L 1 .585 0 r
F
.55658 .45381 m .52266 .45493 L .52275 .4591 L 1 .691 0 r
F
.55666 .45835 m .55658 .45381 L .52275 .4591 L 1 .692 0 r
F
.69697 .41038 m .66561 .41636 L .66596 .42196 L .666 .264 0 r
F
.69697 .41038 m .69646 .40467 L .66561 .41636 L F
.74177 .25314 m .71738 .26186 L .72153 .26758 L .529 .481 0 r
F
.74622 .25874 m .74177 .25314 L .72153 .26758 L .523 .469 0 r
F
.67993 .2513 m .65688 .25677 L .65986 .26293 L .595 .45 0 r
F
.68316 .25737 m .67993 .2513 L .65986 .26293 L .589 .432 0 r
F
.28756 .21329 m .27499 .19738 L .26981 .20216 L 1 1 0 r
F
.28756 .21329 m .29223 .20823 L .27499 .19738 L F
.34407 .68048 m .3441 .67481 L .29481 .68177 L .991 .517 0 r
F
.39213 .66506 m .3441 .67481 L .34407 .68048 L .879 .576 0 r
F
.39213 .66506 m .39296 .65818 L .3441 .67481 L F
.69962 .29453 m .67516 .30052 L .67728 .30685 L .55 .324 0 r
F
.69962 .29453 m .69722 .28828 L .67516 .30052 L F
.64721 .18296 m .6263 .18775 L .63096 .19275 L .668 .701 0 r
F
.65233 .18777 m .64721 .18296 L .63096 .19275 L .665 .691 0 r
F
.61243 .18711 m .59203 .18987 L .59581 .19549 L .735 .699 0 r
F
.61668 .19255 m .61243 .18711 L .59581 .19549 L .733 .687 0 r
F
.68466 .75556 m .64509 .75722 L .64381 .76246 L .599 .057 0 r
F
.68466 .75556 m .68625 .75025 L .64509 .75722 L F
.5799 .17436 m .56059 .17527 L .56398 .18096 L .797 .766 0 r
F
.58384 .17989 m .5799 .17436 L .56398 .18096 L .796 .754 0 r
F
.55125 .81464 m .50849 .81186 L .50808 .81657 L .809 .074 0 r
F
.55125 .81464 m .55208 .80991 L .50849 .81186 L F
.16942 .46575 m .13906 .44377 L .13739 .45025 L 1 .999 0 r
F
.16806 .47221 m .16942 .46575 L .13739 .45025 L 1 .99 0 r
F
.34269 .18335 m .3319 .1713 L .32684 .17575 L 1 1 0 r
F
.34269 .18335 m .34717 .17861 L .3319 .1713 L F
.81347 .37492 m .78443 .38503 L .78695 .39152 L .417 .221 0 r
F
.81347 .37492 m .81071 .36847 L .78443 .38503 L F
.36927 .19831 m .36012 .19549 L .35567 .19925 L 1 1 0 r
F
.36927 .19831 m .37304 .19378 L .36012 .19549 L F
.64699 .18333 m .62615 .18804 L .6308 .19305 L .665 .697 0 r
F
.65209 .18815 m .64699 .18333 L .6308 .19305 L .661 .687 0 r
F
.55126 .41328 m .52182 .41445 L .52177 .41945 L 1 .506 0 r
F
.55105 .41853 m .55126 .41328 L .52177 .41945 L 1 .5 0 r
F
.5809 .41157 m .55126 .41328 L .55105 .41853 L .912 .376 0 r
F
.5809 .41157 m .58135 .40598 L .55126 .41328 L F
.67658 .24528 m .65378 .25065 L .65688 .25677 L .601 .467 0 r
F
.67993 .2513 m .67658 .24528 L .65688 .25677 L .595 .45 0 r
F
.32815 .78051 m .28372 .76973 L .28511 .77505 L 1 .386 0 r
F
.32924 .78568 m .32815 .78051 L .28511 .77505 L 1 .37 0 r
F
.74111 .25369 m .71685 .26233 L .72096 .26806 L .525 .477 0 r
F
.74554 .25929 m .74111 .25369 L .72096 .26806 L .52 .465 0 r
F
.70188 .3008 m .67728 .30685 L .67927 .31317 L .543 .306 0 r
F
.70188 .3008 m .69962 .29453 L .67728 .30685 L F
.42055 .80244 m .37634 .79515 L .37716 .79995 L .999 .248 0 r
F
.42099 .80712 m .42055 .80244 L .37716 .79995 L .992 .23 0 r
F
.46449 .80809 m .42055 .80244 L .42099 .80712 L .937 .185 0 r
F
.59422 .4753 m .5571 .47593 L .55724 .48021 L 1 .607 0 r
F
.59434 .47988 m .59422 .4753 L .55724 .48021 L F
.63193 .47317 m .59422 .4753 L .59434 .47988 L .951 .496 0 r
F
.63193 .47317 m .63183 .46829 L .59422 .4753 L F
.8206 .38739 m .79094 .39763 L .79335 .40419 L .412 .206 0 r
F
.8206 .38739 m .81795 .38087 L .79094 .39763 L F
.73724 .2476 m .71317 .25619 L .71738 .26186 L .534 .493 0 r
F
.74177 .25314 m .73724 .2476 L .71738 .26186 L .529 .481 0 r
F
.15763 .49184 m .12715 .46958 L .12563 .4762 L 1 .996 0 r
F
.15636 .49846 m .15763 .49184 L .12563 .4762 L 1 .987 0 r
F
.28802 .21396 m .27613 .19902 L .2708 .20352 L 1 1 0 r
F
.28802 .21396 m .29272 .20897 L .27613 .19902 L F
.66749 .45933 m .63172 .46335 L .63183 .46829 L .82 .373 0 r
F
.66749 .45933 m .66734 .45417 L .63172 .46335 L F
.82406 .57185 m .78879 .57944 L .78887 .58605 L .404 .064 0 r
F
.82406 .57185 m .82397 .56515 L .78879 .57944 L F
.23239 .69549 m .1913 .67931 L .19232 .68537 L 1 .621 0 r
F
.23332 .7014 m .23239 .69549 L .19232 .68537 L 1 .606 0 r
F
.57394 .15668 m .55533 .1575 L .55914 .16238 L .781 .837 0 r
F
.57839 .1614 m .57394 .15668 L .55914 .16238 L .78 .83 0 r
F
.14492 .51929 m .11183 .49658 L .11074 .50342 L 1 .949 0 r
F
.14404 .52607 m .14492 .51929 L .11074 .50342 L 1 .939 0 r
F
.82012 .56423 m .78564 .57195 L .78573 .57849 L .394 .063 0 r
F
.82012 .56423 m .82003 .55762 L .78564 .57195 L F
.26317 .26734 m .24777 .25053 L .24267 .25494 L 1 1 0 r
F
.26317 .26734 m .2676 .26251 L .24777 .25053 L F
.57389 .15683 m .5553 .1576 L .5591 .1625 L .779 .835 0 r
F
.57833 .16156 m .57389 .15683 L .5591 .1625 L .778 .828 0 r
F
.55148 .15267 m .5337 .15215 L .53684 .1571 L .819 .877 0 r
F
.55533 .1575 m .55148 .15267 L .53684 .1571 L .819 .87 0 r
F
.52007 .16829 m .51789 .16247 L .50255 .16695 L .986 .932 0 r
F
.53555 .16347 m .51789 .16247 L .52007 .16829 L .918 .89 0 r
F
.53845 .1691 m .53555 .16347 L .52007 .16829 L .922 .882 0 r
F
.51651 .15053 m .50028 .14792 L .50186 .15303 L .885 .939 0 r
F
.51651 .15056 m .50028 .14792 L .50186 .15303 L .883 .938 0 r
F
.375 .79958 m .33037 .79079 L .33154 .79582 L 1 .308 0 r
F
.37582 .8045 m .375 .79958 L .33154 .79582 L 1 .29 0 r
F
.55145 .15277 m .53369 .15221 L .53683 .15718 L .818 .875 0 r
F
.5553 .1576 m .55145 .15277 L .53683 .15718 L .818 .868 0 r
F
.67309 .23932 m .65056 .24457 L .65378 .25065 L .607 .485 0 r
F
.67658 .24528 m .67309 .23932 L .65378 .25065 L .601 .467 0 r
F
.81613 .38139 m .78695 .39152 L .78937 .39804 L .411 .207 0 r
F
.81613 .38139 m .81347 .37492 L .78695 .39152 L F
.37192 .19051 m .36206 .18499 L .35748 .18874 L 1 1 0 r
F
.37192 .19051 m .37578 .18602 L .36206 .18499 L F
.52003 .1685 m .51786 .16265 L .50255 .16695 L .98 .925 0 r
F
.53549 .16381 m .51786 .16265 L .52003 .1685 L .914 .882 0 r
F
.53837 .16949 m .53549 .16381 L .52003 .1685 L .917 .874 0 r
F
.70401 .30707 m .67927 .31317 L .68114 .31949 L .537 .289 0 r
F
.70401 .30707 m .70188 .3008 L .67927 .31317 L F
.73661 .24815 m .71266 .25666 L .71685 .26233 L .53 .489 0 r
F
.74111 .25369 m .73661 .24815 L .71685 .26233 L .525 .477 0 r
F
.60223 .16373 m .58279 .16619 L .58715 .17105 L .734 .787 0 r
F
.60715 .1684 m .60223 .16373 L .58715 .17105 L .733 .778 0 r
F
.55666 .45835 m .52275 .4591 L .52284 .46321 L 1 .692 0 r
F
.55675 .46283 m .55666 .45835 L .52284 .46321 L 1 .694 0 r
F
.18576 .62316 m .14803 .60386 L .14828 .61034 L 1 .778 0 r
F
.18605 .62952 m .18576 .62316 L .14828 .61034 L 1 .766 0 r
F
.82317 .39394 m .79335 .40419 L .79567 .41077 L .407 .193 0 r
F
.82317 .39394 m .8206 .38739 L .79335 .40419 L F
.26962 .25501 m .25678 .24054 L .25181 .24505 L 1 1 0 r
F
.26962 .25501 m .27396 .25002 L .25678 .24054 L F
.60984 .40363 m .58135 .40598 L .5809 .41157 L .787 .24 0 r
F
.60984 .40363 m .61052 .39776 L .58135 .40598 L F
.73264 .24212 m .70889 .25057 L .71317 .25619 L .539 .505 0 r
F
.73724 .2476 m .73264 .24212 L .71317 .25619 L .534 .493 0 r
F
.60214 .16395 m .58273 .16636 L .58708 .17123 L .732 .784 0 r
F
.60705 .16864 m .60214 .16395 L .58708 .17123 L .73 .775 0 r
F
.63819 .78276 m .5977 .78292 L .59658 .78784 L .668 .061 0 r
F
.63819 .78276 m .63967 .77779 L .5977 .78292 L F
.61156 .18892 m .59147 .19122 L .59514 .19702 L .719 .667 0 r
F
.61566 .19458 m .61156 .18892 L .59514 .19702 L .715 .651 0 r
F
.59467 .80656 m .55288 .80511 L .55208 .80991 L .742 .067 0 r
F
.59467 .80656 m .59589 .80171 L .55288 .80511 L F
.69743 .41602 m .66596 .42196 L .66626 .42748 L .666 .258 0 r
F
.69743 .41602 m .69697 .41038 L .66596 .42196 L F
.68593 .76469 m .646 .76603 L .64469 .77133 L .605 .058 0 r
F
.68593 .76469 m .68755 .7593 L .646 .76603 L F
.66947 .23341 m .64722 .23855 L .65056 .24457 L .613 .502 0 r
F
.67309 .23932 m .66947 .23341 L .65056 .24457 L .607 .485 0 r
F
.16806 .47221 m .13739 .45025 L .13582 .45675 L 1 .99 0 r
F
.16679 .47867 m .16806 .47221 L .13582 .45675 L 1 .981 0 r
F
.24476 .65313 m .20123 .64028 L .20204 .64608 L 1 .604 0 r
F
.24554 .65866 m .24476 .65313 L .20204 .64608 L 1 .595 0 r
F
.70601 .31333 m .68114 .31949 L .68289 .3258 L .531 .272 0 r
F
.70601 .31333 m .70401 .30707 L .68114 .31949 L F
.8187 .3879 m .78937 .39804 L .79171 .40458 L .405 .193 0 r
F
.8187 .3879 m .81613 .38139 L .78937 .39804 L F
.19713 .59267 m .15832 .57464 L .15845 .5809 L 1 .764 0 r
F
.1974 .59873 m .19713 .59267 L .15845 .5809 L 1 .753 0 r
F
.6646 .33918 m .64072 .34249 L .64069 .3494 L .533 .092 0 r
F
.6646 .33918 m .66462 .33218 L .64072 .34249 L F
.18049 .6391 m .14125 .6199 L .14173 .62646 L 1 .744 0 r
F
.18099 .64551 m .18049 .6391 L .14173 .62646 L 1 .731 0 r
F
.2818 .74364 m .239 .73025 L .24035 .73586 L 1 .492 0 r
F
.28294 .7491 m .2818 .74364 L .24035 .73586 L 1 .476 0 r
F
.29223 .20823 m .28022 .19268 L .27499 .19738 L 1 1 0 r
F
.29223 .20823 m .29696 .20324 L .28022 .19268 L F
.73203 .24267 m .7084 .25104 L .71266 .25666 L .535 .501 0 r
F
.73661 .24815 m .73203 .24267 L .71266 .25666 L .53 .489 0 r
F
.59434 .47988 m .55724 .48021 L .55739 .48445 L 1 .607 0 r
F
.59447 .48442 m .59434 .47988 L .55739 .48445 L F
.63204 .478 m .59434 .47988 L .59447 .48442 L .95 .495 0 r
F
.63204 .478 m .63193 .47317 L .59434 .47988 L F
.55373 .16366 m .53555 .16347 L .53845 .1691 L .861 .845 0 r
F
.55729 .16909 m .55373 .16366 L .53845 .1691 L .863 .836 0 r
F
.29481 .68177 m .2481 .6751 L .24903 .68052 L 1 .517 0 r
F
.29545 .68705 m .29481 .68177 L .24903 .68052 L 1 .514 0 r
F
.34407 .68048 m .29481 .68177 L .29545 .68705 L .991 .517 0 r
F
.46451 .81267 m .46449 .80809 L .42099 .80712 L .931 .168 0 r
F
.5076 .81217 m .46449 .80809 L .46451 .81267 L .87 .117 0 r
F
.5076 .81217 m .50801 .80759 L .46449 .80809 L F
.2799 .75343 m .23626 .74038 L .23771 .74603 L 1 .474 0 r
F
.28112 .75892 m .2799 .75343 L .23771 .74603 L 1 .458 0 r
F
.15636 .49846 m .12563 .4762 L .1242 .48284 L 1 .987 0 r
F
.15518 .50508 m .15636 .49846 L .1242 .48284 L 1 .978 0 r
F
.34408 .68613 m .34407 .68048 L .29545 .68705 L .998 .515 0 r
F
.39143 .67182 m .34407 .68048 L .34408 .68613 L .894 .57 0 r
F
.39143 .67182 m .39213 .66506 L .34407 .68048 L F
.82563 .40051 m .79567 .41077 L .7979 .41737 L .401 .18 0 r
F
.82563 .40051 m .82317 .39394 L .79567 .41077 L F
.72796 .2367 m .70453 .24501 L .70889 .25057 L .544 .517 0 r
F
.73264 .24212 m .72796 .2367 L .70889 .25057 L .539 .505 0 r
F
.73144 .71947 m .69323 .72279 L .69196 .7284 L .521 .054 0 r
F
.73144 .71947 m .73295 .71378 L .69323 .72279 L F
.5536 .16415 m .53549 .16381 L .53837 .16949 L .857 .836 0 r
F
.55713 .16967 m .5536 .16415 L .53837 .16949 L .858 .826 0 r
F
.66762 .46443 m .63183 .46829 L .63193 .47317 L .819 .371 0 r
F
.66762 .46443 m .66749 .45933 L .63183 .46829 L F
.77898 .66117 m .74229 .66646 L .74139 .67253 L .448 .054 0 r
F
.77898 .66117 m .78002 .655 L .74229 .66646 L F
.66572 .22756 m .64377 .23258 L .64722 .23855 L .619 .519 0 r
F
.66947 .23341 m .66572 .22756 L .64722 .23855 L .613 .502 0 r
F
.4203 .81158 m .37582 .8045 L .37667 .80934 L .993 .238 0 r
F
.42075 .8163 m .4203 .81158 L .37667 .80934 L .986 .221 0 r
F
.46442 .81713 m .4203 .81158 L .42075 .8163 L .933 .179 0 r
F
.64204 .17821 m .62159 .18281 L .6263 .18775 L .671 .711 0 r
F
.64721 .18296 m .64204 .17821 L .6263 .18775 L .668 .701 0 r
F
.70788 .31959 m .68289 .3258 L .68452 .33209 L .524 .255 0 r
F
.70788 .31959 m .70601 .31333 L .68289 .3258 L F
.60808 .18175 m .58817 .18432 L .59203 .18987 L .737 .711 0 r
F
.61243 .18711 m .60808 .18175 L .59203 .18987 L .735 .699 0 r
F
.63816 .3826 m .61175 .38554 L .61116 .39173 L .651 .12 0 r
F
.63816 .3826 m .63893 .3762 L .61175 .38554 L F
.2676 .26251 m .25314 .24647 L .24777 .25053 L 1 1 0 r
F
.2676 .26251 m .27216 .25785 L .25314 .24647 L F
.29272 .20897 m .2814 .19445 L .27613 .19902 L F
.29272 .20897 m .29746 .20404 L .2814 .19445 L F
.33536 .20968 m .32583 .20205 L .32081 .20575 L F
.33536 .20968 m .33968 .20525 L .32583 .20205 L F
.82117 .39443 m .79171 .40458 L .79396 .41114 L .399 .18 0 r
F
.82117 .39443 m .8187 .3879 L .79171 .40458 L F
.55675 .46283 m .52284 .46321 L .52294 .46728 L 1 .694 0 r
F
.55686 .46725 m .55675 .46283 L .52294 .46728 L 1 .695 0 r
F
.14404 .52607 m .11074 .50342 L .10976 .51027 L 1 .939 0 r
F
.14325 .53285 m .14404 .52607 L .10976 .51027 L 1 .929 0 r
F
.51789 .16247 m .50113 .1609 L .50255 .16695 L .98 .939 0 r
F
.51786 .16265 m .50113 .1609 L .50255 .16695 L .974 .932 0 r
F
.64184 .17857 m .62145 .18309 L .62615 .18804 L .668 .707 0 r
F
.64699 .18333 m .64184 .17857 L .62615 .18804 L .665 .697 0 r
F
.57613 .16812 m .55729 .16909 L .56078 .17461 L .805 .792 0 r
F
.58022 .17345 m .57613 .16812 L .56078 .17461 L .805 .782 0 r
F
.72738 .23725 m .70407 .24547 L .7084 .25104 L .54 .513 0 r
F
.73203 .24267 m .72738 .23725 L .7084 .25104 L .535 .501 0 r
F
.78191 .66977 m .74452 .67476 L .7436 .68091 L .459 .055 0 r
F
.78191 .66977 m .78297 .66351 L .74452 .67476 L F
.34694 .17805 m .33668 .16615 L .33154 .17049 L 1 1 0 r
F
.34694 .17805 m .35149 .17339 L .33668 .16615 L F
.38015 .16544 m .3701 .15562 L .36539 .15993 L F
.38015 .16544 m .38419 .16082 L .3701 .15562 L F
.55105 .41853 m .52177 .41945 L .52173 .42431 L 1 .5 0 r
F
.55084 .42364 m .55105 .41853 L .52173 .42431 L 1 .495 0 r
F
.58046 .417 m .55105 .41853 L .55084 .42364 L .906 .368 0 r
F
.58046 .417 m .5809 .41157 L .55105 .41853 L F
.27396 .25002 m .26183 .23617 L .25678 .24054 L 1 1 0 r
F
.27396 .25002 m .27836 .24511 L .26183 .23617 L F
.16679 .47867 m .13582 .45675 L .13435 .46325 L 1 .981 0 r
F
.16561 .48514 m .16679 .47867 L .13435 .46325 L 1 .972 0 r
F
.828 .40711 m .7979 .41737 L .80005 .42399 L .396 .167 0 r
F
.828 .40711 m .82563 .40051 L .7979 .41737 L F
.82405 .57853 m .78887 .58605 L .78886 .59264 L .399 .062 0 r
F
.82405 .57853 m .82406 .57185 L .78887 .58605 L F
.82011 .57083 m .78573 .57849 L .78573 .58501 L .388 .061 0 r
F
.82011 .57083 m .82012 .56423 L .78573 .57849 L F
.38026 .16583 m .37028 .15618 L .36557 .16049 L 1 1 0 r
F
.38026 .16583 m .3843 .16121 L .37028 .15618 L F
.72321 .23134 m .70011 .2395 L .70453 .24501 L .549 .529 0 r
F
.72796 .2367 m .72321 .23134 L .70453 .24501 L .544 .517 0 r
F
.63894 .79192 m .5982 .79182 L .59706 .7968 L .672 .061 0 r
F
.63894 .79192 m .64046 .78687 L .5982 .79182 L F
.73341 .72849 m .69469 .73147 L .69339 .73714 L .53 .055 0 r
F
.73341 .72849 m .73496 .72271 L .69469 .73147 L F
.69784 .42161 m .66626 .42748 L .66653 .43295 L .665 .253 0 r
F
.69784 .42161 m .69743 .41602 L .66626 .42748 L F
.57587 .16892 m .55713 .16967 L .56059 .17527 L .798 .778 0 r
F
.5799 .17436 m .57587 .16892 L .56059 .17527 L .797 .766 0 r
F
.34717 .17861 m .33702 .16693 L .3319 .1713 L 1 1 0 r
F
.34717 .17861 m .35171 .17395 L .33702 .16693 L F
.66185 .22177 m .64021 .22667 L .64377 .23258 L .624 .535 0 r
F
.66572 .22756 m .66185 .22177 L .64377 .23258 L .619 .519 0 r
F
.70962 .32583 m .68452 .33209 L .68604 .33836 L .519 .239 0 r
F
.70962 .32583 m .70788 .31959 L .68452 .33209 L F
.59447 .48442 m .55739 .48445 L .55754 .48866 L 1 .607 0 r
F
.59461 .48893 m .59447 .48442 L .55754 .48866 L F
.63214 .48279 m .59447 .48442 L .59461 .48893 L .949 .493 0 r
F
.63214 .48279 m .63204 .478 L .59447 .48442 L F
.55019 .81021 m .50801 .80759 L .5076 .81217 L .802 .072 0 r
F
.55019 .81021 m .55103 .80561 L .50801 .80759 L F
.82354 .40099 m .79396 .41114 L .79611 .41772 L .393 .166 0 r
F
.82354 .40099 m .82117 .39443 L .79396 .41114 L F
.23006 .71134 m .18794 .69555 L .18917 .70162 L 1 .585 0 r
F
.23116 .71725 m .23006 .71134 L .18917 .70162 L 1 .57 0 r
F
.60735 .18335 m .5877 .18551 L .59147 .19122 L .722 .682 0 r
F
.61156 .18892 m .60735 .18335 L .59147 .19122 L .719 .667 0 r
F
.72265 .23189 m .69968 .23996 L .70407 .24547 L .545 .525 0 r
F
.72738 .23725 m .72265 .23189 L .70407 .24547 L .54 .513 0 r
F
.15518 .50508 m .1242 .48284 L .12287 .48948 L 1 .978 0 r
F
.15408 .5117 m .15518 .50508 L .12287 .48948 L 1 .969 0 r
F
.29696 .20324 m .28551 .18806 L .28022 .19268 L 1 1 0 r
F
.29696 .20324 m .30174 .19832 L .28551 .18806 L F
.37304 .19378 m .36463 .19193 L .36012 .19549 L .969 .99 0 r
F
.37304 .19378 m .37685 .18933 L .36463 .19193 L F
.55686 .46725 m .52294 .46728 L .52305 .4713 L 1 .695 0 r
F
.55697 .47161 m .55686 .46725 L .52305 .4713 L 1 .696 0 r
F
.66773 .46948 m .63193 .47317 L .63204 .478 L .818 .368 0 r
F
.66773 .46948 m .66762 .46443 L .63193 .47317 L F
.18605 .62952 m .14828 .61034 L .14861 .6168 L 1 .766 0 r
F
.18643 .63586 m .18605 .62952 L .14861 .6168 L 1 .753 0 r
F
.83027 .41374 m .80005 .42399 L .80211 .43063 L .39 .154 0 r
F
.83027 .41374 m .828 .40711 L .80005 .42399 L F
.33026 .77611 m .28671 .76513 L .28808 .77036 L 1 .385 0 r
F
.33134 .78118 m .33026 .77611 L .28808 .77036 L 1 .368 0 r
F
.46445 .82176 m .46442 .81713 L .42075 .8163 L .926 .161 0 r
F
.50767 .82121 m .46442 .81713 L .46445 .82176 L .867 .112 0 r
F
.50767 .82121 m .50808 .81657 L .46442 .81713 L F
.71838 .22604 m .69562 .23405 L .70011 .2395 L .554 .54 0 r
F
.72321 .23134 m .71838 .22604 L .70011 .2395 L .549 .529 0 r
F
.71125 .33206 m .68604 .33836 L .68744 .34461 L .513 .224 0 r
F
.71125 .33206 m .70962 .32583 L .68604 .33836 L F
.60913 .40933 m .5809 .41157 L .58046 .417 L .78 .228 0 r
F
.60913 .40933 m .60984 .40363 L .5809 .41157 L F
.23332 .7014 m .19232 .68537 L .19342 .69139 L 1 .606 0 r
F
.23432 .70726 m .23332 .7014 L .19342 .69139 L 1 .591 0 r
F
.65785 .21606 m .63654 .22082 L .64021 .22667 L .629 .551 0 r
F
.66185 .22177 m .65785 .21606 L .64021 .22667 L .624 .535 0 r
F
.66436 .34614 m .64069 .3494 L .64048 .35625 L .518 .072 0 r
F
.66436 .34614 m .6646 .33918 L .64069 .3494 L F
.1974 .59873 m .15845 .5809 L .15867 .58714 L 1 .753 0 r
F
.19775 .60476 m .1974 .59873 L .15867 .58714 L 1 .741 0 r
F
.37634 .79515 m .33246 .78619 L .33363 .79113 L 1 .302 0 r
F
.37716 .79995 m .37634 .79515 L .33363 .79113 L 1 .285 0 r
F
.34408 .68613 m .29545 .68705 L .29612 .69233 L .998 .515 0 r
F
.34414 .69175 m .34408 .68613 L .29612 .69233 L 1 .511 0 r
F
.39083 .67846 m .34408 .68613 L .34414 .69175 L .908 .562 0 r
F
.39083 .67846 m .39143 .67182 L .34408 .68613 L F
.8258 .40757 m .79611 .41772 L .79818 .42431 L .387 .152 0 r
F
.8258 .40757 m .82354 .40099 L .79611 .41772 L F
.27216 .25785 m .25888 .24289 L .25314 .24647 L 1 1 0 r
F
.27216 .25785 m .27686 .25341 L .25888 .24289 L F
.29746 .20404 m .28664 .18982 L .2814 .19445 L F
.29746 .20404 m .30225 .19917 L .28664 .18982 L F
.16561 .48514 m .13435 .46325 L .13297 .46976 L 1 .972 0 r
F
.16451 .49159 m .16561 .48514 L .13297 .46976 L 1 .963 0 r
F
.59727 .15913 m .57839 .1614 L .58279 .16619 L .736 .795 0 r
F
.60223 .16373 m .59727 .15913 L .58279 .16619 L .734 .787 0 r
F
.51651 .15053 m .51411 .14553 L .50028 .14792 L .885 .939 0 r
F
.53053 .14725 m .51411 .14553 L .51651 .15053 L .852 .914 0 r
F
.5337 .15215 m .53053 .14725 L .51651 .15053 L .853 .908 0 r
F
.14325 .53285 m .10976 .51027 L .10887 .51711 L 1 .929 0 r
F
.14255 .53963 m .14325 .53285 L .10887 .51711 L 1 .919 0 r
F
.51651 .15056 m .5141 .14556 L .50028 .14792 L .883 .938 0 r
F
.53052 .14731 m .5141 .14556 L .51651 .15056 L .851 .912 0 r
F
.53369 .15221 m .53052 .14731 L .51651 .15056 L .852 .906 0 r
F
.71785 .22659 m .69521 .23451 L .69968 .23996 L .55 .536 0 r
F
.72265 .23189 m .71785 .22659 L .69968 .23996 L .545 .525 0 r
F
.68301 .76082 m .64381 .76246 L .64249 .76763 L .591 .055 0 r
F
.68301 .76082 m .68466 .75556 L .64381 .76246 L F
.37578 .18602 m .3667 .18142 L .36206 .18499 L 1 1 0 r
F
.37578 .18602 m .37967 .18163 L .3667 .18142 L F
.27836 .24511 m .26696 .23194 L .26183 .23617 L F
.27836 .24511 m .28284 .2403 L .26696 .23194 L F
.59719 .15934 m .57833 .16156 L .58273 .16636 L .734 .792 0 r
F
.60214 .16395 m .59719 .15934 L .58273 .16636 L .732 .784 0 r
F
.59461 .48893 m .55754 .48866 L .55771 .49284 L 1 .607 0 r
F
.59475 .4934 m .59461 .48893 L .55771 .49284 L 1 .606 0 r
F
.63224 .48753 m .59461 .48893 L .59475 .4934 L .947 .492 0 r
F
.63224 .48753 m .63214 .48279 L .59461 .48893 L F
.59301 .80217 m .55184 .80095 L .55103 .80561 L .733 .065 0 r
F
.59301 .80217 m .59424 .79747 L .55184 .80095 L F
.56945 .15202 m .55148 .15267 L .55533 .1575 L .781 .845 0 r
F
.57394 .15668 m .56945 .15202 L .55533 .1575 L .781 .837 0 r
F
.18099 .64551 m .14173 .62646 L .14232 .63299 L 1 .731 0 r
F
.18158 .65189 m .18099 .64551 L .14232 .63299 L 1 .718 0 r
F
.56941 .15216 m .55145 .15277 L .5553 .1576 L .78 .843 0 r
F
.57389 .15683 m .56941 .15216 L .5553 .1576 L .779 .835 0 r
F
.6368 .17354 m .61683 .17794 L .62159 .18281 L .674 .72 0 r
F
.64204 .17821 m .6368 .17354 L .62159 .18281 L .671 .711 0 r
F
.24554 .65866 m .20204 .64608 L .20291 .65185 L 1 .595 0 r
F
.24635 .66417 m .24554 .65866 L .20291 .65185 L 1 .587 0 r
F
.6982 .42714 m .66653 .43295 L .66677 .43834 L .665 .249 0 r
F
.6982 .42714 m .69784 .42161 L .66653 .43295 L F
.60365 .17646 m .58423 .17885 L .58817 .18432 L .739 .722 0 r
F
.60808 .18175 m .60365 .17646 L .58817 .18432 L .737 .711 0 r
F
.51789 .16247 m .51566 .15674 L .50113 .1609 L .98 .939 0 r
F
.5326 .15793 m .51566 .15674 L .51789 .16247 L .915 .897 0 r
F
.53555 .16347 m .5326 .15793 L .51789 .16247 L .918 .89 0 r
F
.51786 .16265 m .51564 .15689 L .50113 .1609 L .974 .932 0 r
F
.53255 .15821 m .51564 .15689 L .51786 .16265 L .911 .891 0 r
F
.53549 .16381 m .53255 .15821 L .51786 .16265 L .914 .882 0 r
F
.63662 .17388 m .6167 .1782 L .62145 .18309 L .671 .717 0 r
F
.64184 .17857 m .63662 .17388 L .62145 .18309 L .668 .707 0 r
F
.83245 .42039 m .80211 .43063 L .80408 .43729 L .385 .14 0 r
F
.83245 .42039 m .83027 .41374 L .80211 .43063 L F
.55697 .47161 m .52305 .4713 L .52317 .47528 L 1 .696 0 r
F
.5571 .47593 m .55697 .47161 L .52317 .47528 L 1 .698 0 r
F
.71349 .22081 m .69107 .22866 L .69562 .23405 L .559 .552 0 r
F
.71838 .22604 m .71349 .22081 L .69562 .23405 L .554 .54 0 r
F
.32924 .78568 m .28511 .77505 L .28655 .7803 L 1 .37 0 r
F
.33037 .79079 m .32924 .78568 L .28655 .7803 L 1 .352 0 r
F
.29545 .68705 m .24903 .68052 L .25001 .68592 L 1 .514 0 r
F
.29612 .69233 m .29545 .68705 L .25001 .68592 L 1 .509 0 r
F
.55084 .42364 m .52173 .42431 L .5217 .42905 L 1 .495 0 r
F
.55064 .42861 m .55084 .42364 L .5217 .42905 L 1 .49 0 r
F
.58001 .42228 m .55084 .42364 L .55064 .42861 L .9 .361 0 r
F
.58001 .42228 m .58046 .417 L .55084 .42364 L F
.15408 .5117 m .12287 .48948 L .12163 .49614 L 1 .969 0 r
F
.15307 .51832 m .15408 .5117 L .12163 .49614 L 1 .96 0 r
F
.71276 .33826 m .68744 .34461 L .68874 .35082 L .508 .209 0 r
F
.71276 .33826 m .71125 .33206 L .68744 .34461 L F
.54759 .14791 m .53053 .14725 L .5337 .15215 L .819 .883 0 r
F
.55148 .15267 m .54759 .14791 L .5337 .15215 L .819 .877 0 r
F
.65374 .21041 m .63277 .21503 L .63654 .22082 L .634 .567 0 r
F
.65785 .21606 m .65374 .21041 L .63654 .22082 L .629 .551 0 r
F
.54757 .148 m .53052 .14731 L .53369 .15221 L .817 .882 0 r
F
.55145 .15277 m .54757 .148 L .53369 .15221 L .818 .875 0 r
F
.82797 .41417 m .79818 .42431 L .80016 .43093 L .382 .138 0 r
F
.82797 .41417 m .8258 .40757 L .79818 .42431 L F
.33968 .20525 m .33092 .19853 L .32583 .20205 L 1 1 0 r
F
.33968 .20525 m .34406 .20093 L .33092 .19853 L F
.82001 .57741 m .78573 .58501 L .78565 .59151 L .383 .059 0 r
F
.82001 .57741 m .82011 .57083 L .78573 .58501 L F
.82395 .5852 m .78886 .59264 L .78876 .59921 L .393 .06 0 r
F
.82395 .5852 m .82405 .57853 L .78886 .59264 L F
.66783 .47449 m .63204 .478 L .63214 .48279 L .817 .365 0 r
F
.66783 .47449 m .66773 .46948 L .63204 .478 L F
.55039 .8193 m .50808 .81657 L .50767 .82121 L .801 .072 0 r
F
.55039 .8193 m .55125 .81464 L .50808 .81657 L F
.77785 .6673 m .74139 .67253 L .74041 .67856 L .442 .052 0 r
F
.77785 .6673 m .77898 .66117 L .74139 .67253 L F
.71298 .22135 m .69068 .22911 L .69521 .23451 L .555 .548 0 r
F
.71785 .22659 m .71298 .22135 L .69521 .23451 L .55 .536 0 r
F
.63732 .38884 m .61116 .39173 L .61052 .39776 L .641 .102 0 r
F
.63732 .38884 m .63816 .3826 L .61116 .39173 L F
.5501 .1583 m .5326 .15793 L .53555 .16347 L .86 .854 0 r
F
.55373 .16366 m .5501 .1583 L .53555 .16347 L .861 .845 0 r
F
.42099 .80712 m .37716 .79995 L .37801 .80468 L .992 .23 0 r
F
.42144 .81173 m .42099 .80712 L .37801 .80468 L .985 .212 0 r
F
.46451 .81267 m .42099 .80712 L .42144 .81173 L .931 .168 0 r
F
.30174 .19832 m .29086 .18352 L .28551 .18806 L 1 1 0 r
F
.30174 .19832 m .30658 .19349 L .29086 .18352 L F
.35149 .17339 m .34187 .16191 L .33668 .16615 L F
.35149 .17339 m .35608 .16882 L .34187 .16191 L F
.60303 .17787 m .58384 .17989 L .5877 .18551 L .726 .697 0 r
F
.60735 .18335 m .60303 .17787 L .5877 .18551 L .722 .682 0 r
F
.57198 .16288 m .55373 .16366 L .55729 .16909 L .805 .802 0 r
F
.57613 .16812 m .57198 .16288 L .55729 .16909 L .805 .792 0 r
F
.59475 .4934 m .55771 .49284 L .55788 .497 L 1 .606 0 r
F
.5949 .49784 m .59475 .4934 L .55788 .497 L F
.63234 .49223 m .59475 .4934 L .5949 .49784 L .945 .49 0 r
F
.63234 .49223 m .63224 .48753 L .59475 .4934 L F
.55 .15873 m .53255 .15821 L .53549 .16381 L .856 .846 0 r
F
.5536 .16415 m .55 .15873 L .53549 .16381 L .857 .836 0 r
F
.37582 .8045 m .33154 .79582 L .33276 .80079 L 1 .29 0 r
F
.37667 .80934 m .37582 .8045 L .33276 .80079 L 1 .272 0 r
F
.28294 .7491 m .24035 .73586 L .24176 .74143 L 1 .476 0 r
F
.28414 .7545 m .28294 .7491 L .24176 .74143 L 1 .46 0 r
F
.68424 .77002 m .64469 .77133 L .64333 .77658 L .598 .056 0 r
F
.68424 .77002 m .68593 .76469 L .64469 .77133 L F
.16451 .49159 m .13297 .46976 L .13169 .47628 L 1 .963 0 r
F
.16351 .49805 m .16451 .49159 L .13169 .47628 L 1 .953 0 r
F
.51411 .14553 m .49869 .14287 L .50028 .14792 L .883 .945 0 r
F
.5141 .14556 m .49869 .14287 L .50028 .14792 L .881 .943 0 r
F
.78075 .67598 m .7436 .68091 L .7426 .68701 L .453 .053 0 r
F
.78075 .67598 m .78191 .66977 L .7436 .68091 L F
.83453 .42706 m .80408 .43729 L .80596 .44396 L .381 .127 0 r
F
.83453 .42706 m .83245 .42039 L .80408 .43729 L F
.72985 .72512 m .69196 .7284 L .69063 .73395 L .514 .052 0 r
F
.72985 .72512 m .73144 .71947 L .69196 .7284 L F
.5571 .47593 m .52317 .47528 L .52329 .47923 L 1 .698 0 r
F
.55724 .48021 m .5571 .47593 L .52329 .47923 L 1 .699 0 r
F
.35171 .17395 m .34218 .16267 L .33702 .16693 L 1 1 0 r
F
.35171 .17395 m .35628 .16938 L .34218 .16267 L F
.70852 .21564 m .68645 .22333 L .69107 .22866 L .564 .563 0 r
F
.71349 .22081 m .70852 .21564 L .69107 .22866 L .559 .552 0 r
F
.63666 .78767 m .59658 .78784 L .59543 .79269 L .661 .059 0 r
F
.63666 .78767 m .63819 .78276 L .59658 .78784 L F
.71416 .34443 m .68874 .35082 L .68994 .357 L .503 .195 0 r
F
.71416 .34443 m .71276 .33826 L .68874 .35082 L F
.57176 .16357 m .5536 .16415 L .55713 .16967 L .799 .789 0 r
F
.57587 .16892 m .57176 .16357 L .55713 .16967 L .798 .778 0 r
F
.28284 .2403 m .27218 .22785 L .26696 .23194 L 1 1 0 r
F
.28284 .2403 m .28737 .23558 L .27218 .22785 L F
.28112 .75892 m .23771 .74603 L .23922 .75162 L 1 .458 0 r
F
.28239 .76436 m .28112 .75892 L .23922 .75162 L 1 .441 0 r
F
.83004 .42079 m .80016 .43093 L .80205 .43755 L .378 .124 0 r
F
.83004 .42079 m .82797 .41417 L .80016 .43093 L F
.30225 .19917 m .29188 .1852 L .28664 .18982 L 1 1 0 r
F
.30225 .19917 m .30708 .19435 L .29188 .1852 L F
.14255 .53963 m .10887 .51711 L .10809 .52396 L 1 .919 0 r
F
.14194 .54639 m .14255 .53963 L .10809 .52396 L 1 .909 0 r
F
.27686 .25341 m .26515 .24004 L .25888 .24289 L 1 1 0 r
F
.27686 .25341 m .28172 .2492 L .26515 .24004 L F
.69852 .43261 m .66677 .43834 L .66698 .44368 L .664 .244 0 r
F
.69852 .43261 m .6982 .42714 L .66677 .43834 L F
.38419 .16082 m .37486 .15141 L .3701 .15562 L 1 1 0 r
F
.64952 .20484 m .6289 .20931 L .63277 .21503 L .639 .582 0 r
F
.65374 .21041 m .64952 .20484 L .63277 .21503 L .634 .567 0 r
F
.34414 .69175 m .29612 .69233 L .29681 .69759 L 1 .511 0 r
F
.34427 .69734 m .34414 .69175 L .29681 .69759 L 1 .506 0 r
F
.39034 .68496 m .34414 .69175 L .34427 .69734 L .919 .553 0 r
F
.39034 .68496 m .39083 .67846 L .34414 .69175 L F
.70803 .21618 m .68608 .22377 L .69068 .22911 L .56 .559 0 r
F
.71298 .22135 m .70803 .21618 L .69068 .22911 L .555 .548 0 r
F
.59342 .81133 m .55208 .80991 L .55125 .81464 L .734 .065 0 r
F
.59342 .81133 m .59467 .80656 L .55208 .80991 L F
.18643 .63586 m .14861 .6168 L .14903 .62323 L 1 .753 0 r
F
.18688 .64216 m .18643 .63586 L .14903 .62323 L 1 .74 0 r
F
.51566 .15674 m .49967 .15496 L .50113 .1609 L .974 .945 0 r
F
.51564 .15689 m .49967 .15496 L .50113 .1609 L .969 .939 0 r
F
.66457 .23952 m .64385 .2432 L .64669 .24967 L .542 .378 0 r
F
.66751 .24599 m .64669 .24967 L .64936 .25622 L .529 .348 0 r
F
.66751 .24599 m .66457 .23952 L .64669 .24967 L F
.67025 .25254 m .64936 .25622 L .65184 .26285 L .516 .317 0 r
F
.67025 .25254 m .66751 .24599 L .64936 .25622 L F
.3843 .16121 m .37502 .15198 L .37028 .15618 L 1 1 0 r
F
.3843 .16121 m .38837 .15667 L .37502 .15198 L F
.15307 .51832 m .12163 .49614 L .1205 .5028 L 1 .96 0 r
F
.15215 .52495 m .15307 .51832 L .1205 .5028 L 1 .95 0 r
F
.19775 .60476 m .15867 .58714 L .15897 .59336 L 1 .741 0 r
F
.19816 .61076 m .19775 .60476 L .15897 .59336 L 1 .729 0 r
F
.66392 .35302 m .64048 .35625 L .6401 .36301 L .504 .068 0 r
F
.66392 .35302 m .66436 .34614 L .64048 .35625 L F
.66142 .23315 m .64083 .23681 L .64385 .2432 L .553 .406 0 r
F
.66457 .23952 m .66142 .23315 L .64385 .2432 L .542 .378 0 r
F
.60842 .41487 m .58046 .417 L .58001 .42228 L .774 .218 0 r
F
.60842 .41487 m .60913 .40933 L .58046 .417 L F
.66792 .47945 m .63214 .48279 L .63224 .48753 L .816 .362 0 r
F
.66792 .47945 m .66783 .47449 L .63214 .48279 L F
.67277 .25919 m .65184 .26285 L .65412 .26956 L .502 .284 0 r
F
.67277 .25919 m .67025 .25254 L .65184 .26285 L F
.73179 .73421 m .69339 .73714 L .69203 .74276 L .523 .053 0 r
F
.73179 .73421 m .73341 .72849 L .69339 .73714 L F
.5949 .49784 m .55788 .497 L .55807 .50114 L 1 .606 0 r
F
.59506 .50225 m .5949 .49784 L .55807 .50114 L 1 .605 0 r
F
.63244 .4969 m .5949 .49784 L .59506 .50225 L .943 .488 0 r
F
.63244 .4969 m .63234 .49223 L .5949 .49784 L F
.23116 .71725 m .18917 .70162 L .19048 .70765 L 1 .57 0 r
F
.23233 .72311 m .23116 .71725 L .19048 .70765 L 1 .555 0 r
F
.63152 .16894 m .61202 .17314 L .61683 .17794 L .677 .73 0 r
F
.6368 .17354 m .63152 .16894 L .61683 .17794 L .674 .72 0 r
F
.46454 .81718 m .46451 .81267 L .42144 .81173 L .923 .151 0 r
F
.50718 .81667 m .46451 .81267 L .46454 .81718 L .862 .1 0 r
F
.50718 .81667 m .5076 .81217 L .46451 .81267 L F
.83651 .43375 m .80596 .44396 L .80776 .45065 L .377 .114 0 r
F
.83651 .43375 m .83453 .42706 L .80596 .44396 L F
.37685 .18933 m .36922 .18862 L .36463 .19193 L .881 .836 0 r
F
.37685 .18933 m .3807 .18498 L .36922 .18862 L F
.55724 .48021 m .52329 .47923 L .52341 .48314 L 1 .699 0 r
F
.55739 .48445 m .55724 .48021 L .52341 .48314 L 1 .7 0 r
F
.65809 .22688 m .63766 .23051 L .64083 .23681 L .564 .433 0 r
F
.66142 .23315 m .65809 .22688 L .64083 .23681 L .553 .406 0 r
F
.70348 .21054 m .68176 .21806 L .68645 .22333 L .569 .575 0 r
F
.70852 .21564 m .70348 .21054 L .68645 .22333 L .564 .563 0 r
F
.59913 .17125 m .58022 .17345 L .58423 .17885 L .741 .734 0 r
F
.60365 .17646 m .59913 .17125 L .58423 .17885 L .739 .722 0 r
F
.63135 .16926 m .6119 .17339 L .6167 .1782 L .674 .726 0 r
F
.63662 .17388 m .63135 .16926 L .6167 .1782 L .671 .717 0 r
F
.67506 .26591 m .65412 .26956 L .6562 .27633 L .487 .25 0 r
F
.67506 .26591 m .67277 .25919 L .65412 .26956 L F
.71545 .35056 m .68994 .357 L .69105 .36314 L .498 .182 0 r
F
.71545 .35056 m .71416 .34443 L .68994 .357 L F
.55064 .42861 m .5217 .42905 L .52167 .43369 L 1 .49 0 r
F
.55045 .43345 m .55064 .42861 L .52167 .43369 L .998 .485 0 r
F
.57958 .42741 m .55064 .42861 L .55045 .43345 L .895 .355 0 r
F
.57958 .42741 m .58001 .42228 L .55064 .42861 L F
.83201 .42743 m .80205 .43755 L .80385 .44419 L .375 .111 0 r
F
.83201 .42743 m .83004 .42079 L .80205 .43755 L F
.16351 .49805 m .13169 .47628 L .13051 .4828 L 1 .953 0 r
F
.1626 .5045 m .16351 .49805 L .13051 .4828 L 1 .943 0 r
F
.18158 .65189 m .14232 .63299 L .14299 .63949 L 1 .718 0 r
F
.18224 .65824 m .18158 .65189 L .14299 .63949 L 1 .704 0 r
F
.42075 .8163 m .37667 .80934 L .37755 .8141 L .986 .221 0 r
F
.42121 .82096 m .42075 .8163 L .37755 .8141 L .979 .202 0 r
F
.46445 .82176 m .42075 .8163 L .42121 .82096 L .926 .161 0 r
F
.30658 .19349 m .29626 .17906 L .29086 .18352 L 1 1 0 r
F
.30658 .19349 m .31147 .18872 L .29626 .17906 L F
.23432 .70726 m .19342 .69139 L .1946 .69737 L 1 .591 0 r
F
.23539 .71308 m .23432 .70726 L .1946 .69737 L 1 .576 0 r
F
.59226 .1546 m .57394 .15668 L .57839 .1614 L .738 .803 0 r
F
.59727 .15913 m .59226 .1546 L .57839 .1614 L .736 .795 0 r
F
.70302 .21107 m .68141 .21849 L .68608 .22377 L .564 .571 0 r
F
.70803 .21618 m .70302 .21107 L .68608 .22377 L .56 .559 0 r
F
.81981 .58397 m .78565 .59151 L .78548 .59798 L .379 .057 0 r
F
.81981 .58397 m .82001 .57741 L .78565 .59151 L F
.65458 .2207 m .63433 .2243 L .63766 .23051 L .575 .459 0 r
F
.65809 .22688 m .65458 .2207 L .63766 .23051 L .564 .433 0 r
F
.82375 .59185 m .78876 .59921 L .78858 .60576 L .387 .058 0 r
F
.82375 .59185 m .82395 .5852 L .78876 .59921 L F
.59218 .1548 m .57389 .15683 L .57833 .16156 L .736 .801 0 r
F
.59719 .15934 m .59218 .1548 L .57833 .16156 L .734 .792 0 r
F
.64518 .19934 m .62492 .20365 L .6289 .20931 L .644 .597 0 r
F
.64952 .20484 m .64518 .19934 L .6289 .20931 L .639 .582 0 r
F
.24635 .66417 m .20291 .65185 L .20385 .65758 L 1 .587 0 r
F
.2472 .66965 m .24635 .66417 L .20385 .65758 L 1 .578 0 r
F
.63738 .7969 m .59706 .7968 L .59589 .80171 L .664 .059 0 r
F
.63738 .7969 m .63894 .79192 L .59706 .7968 L F
.67711 .27272 m .6562 .27633 L .65807 .28318 L .472 .215 0 r
F
.67711 .27272 m .67506 .26591 L .6562 .27633 L F
.69881 .43803 m .66698 .44368 L .66717 .44895 L .664 .24 0 r
F
.69881 .43803 m .69852 .43261 L .66698 .44368 L F
.28737 .23558 m .27747 .22392 L .27218 .22785 L 1 1 0 r
F
.28737 .23558 m .29196 .23097 L .27747 .22392 L F
.59862 .17249 m .5799 .17436 L .58384 .17989 L .729 .711 0 r
F
.60303 .17787 m .59862 .17249 L .58384 .17989 L .726 .697 0 r
F
.37967 .18163 m .37139 .17808 L .3667 .18142 L .998 1 0 r
F
.37967 .18163 m .3836 .17735 L .37139 .17808 L F
.34406 .20093 m .33608 .19523 L .33092 .19853 L .996 1 0 r
F
.34406 .20093 m .34848 .19672 L .33608 .19523 L F
.29612 .69233 m .25001 .68592 L .25103 .69129 L 1 .509 0 r
F
.29681 .69759 m .29612 .69233 L .25103 .69129 L 1 .504 0 r
F
.55739 .48445 m .52341 .48314 L .52355 .48704 L 1 .7 0 r
F
.55754 .48866 m .55739 .48445 L .52355 .48704 L 1 .701 0 r
F
.59506 .50225 m .55807 .50114 L .55826 .50526 L 1 .605 0 r
F
.59522 .50664 m .59506 .50225 L .55826 .50526 L 1 .604 0 r
F
.63254 .50154 m .59506 .50225 L .59522 .50664 L .94 .486 0 r
F
.63254 .50154 m .63244 .4969 L .59506 .50225 L F
.30708 .19435 m .29717 .18062 L .29188 .1852 L 1 1 0 r
F
.30708 .19435 m .31195 .1896 L .29717 .18062 L F
.14194 .54639 m .10809 .52396 L .1074 .5308 L 1 .909 0 r
F
.14142 .55315 m .14194 .54639 L .1074 .5308 L 1 .898 0 r
F
.83839 .44046 m .80776 .45065 L .80946 .45735 L .374 .101 0 r
F
.83839 .44046 m .83651 .43375 L .80776 .45065 L F
.6509 .21463 m .63086 .21817 L .63433 .2243 L .585 .484 0 r
F
.65458 .2207 m .6509 .21463 L .63433 .2243 L .575 .459 0 r
F
.668 .48437 m .63224 .48753 L .63234 .49223 L .814 .359 0 r
F
.668 .48437 m .66792 .47945 L .63224 .48753 L F
.15215 .52495 m .1205 .5028 L .11946 .50947 L 1 .95 0 r
F
.15132 .53157 m .15215 .52495 L .11946 .50947 L 1 .94 0 r
F
.69837 .2055 m .67701 .21285 L .68176 .21806 L .574 .586 0 r
F
.70348 .21054 m .69837 .2055 L .68176 .21806 L .569 .575 0 r
F
.54932 .81473 m .5076 .81217 L .50718 .81667 L .794 .07 0 r
F
.54932 .81473 m .55019 .81021 L .5076 .81217 L F
.56492 .14743 m .54759 .14791 L .55148 .15267 L .782 .852 0 r
F
.56945 .15202 m .56492 .14743 L .55148 .15267 L .781 .845 0 r
F
.33134 .78118 m .28808 .77036 L .2895 .77552 L 1 .368 0 r
F
.33246 .78619 m .33134 .78118 L .2895 .77552 L 1 .35 0 r
F
.6364 .39493 m .61052 .39776 L .60984 .40363 L .632 .086 0 r
F
.6364 .39493 m .63732 .38884 L .61052 .39776 L F
.56488 .14756 m .54757 .148 L .55145 .15277 L .78 .85 0 r
F
.56941 .15216 m .56488 .14756 L .55145 .15277 L .78 .843 0 r
F
.71665 .35666 m .69105 .36314 L .69205 .36923 L .494 .17 0 r
F
.71665 .35666 m .71545 .35056 L .69105 .36314 L F
.28172 .2492 m .27228 .2384 L .26515 .24004 L 1 1 0 r
F
.28172 .2492 m .28673 .24526 L .27228 .2384 L F
.83388 .43409 m .80385 .44419 L .80555 .45085 L .371 .097 0 r
F
.83388 .43409 m .83201 .42743 L .80385 .44419 L F
.35608 .16882 m .34711 .15776 L .34187 .16191 L 1 1 0 r
F
.35608 .16882 m .36071 .16433 L .34711 .15776 L F
.77664 .67338 m .74041 .67856 L .73936 .68454 L .435 .05 0 r
F
.77664 .67338 m .77785 .6673 L .74041 .67856 L F
.67891 .2796 m .65807 .28318 L .65971 .29008 L .455 .178 0 r
F
.67891 .2796 m .67711 .27272 L .65807 .28318 L F
.69793 .20603 m .67668 .21328 L .68141 .21849 L .569 .582 0 r
F
.70302 .21107 m .69793 .20603 L .68141 .21849 L .564 .571 0 r
F
.51566 .15674 m .5134 .15109 L .49967 .15496 L .974 .945 0 r
F
.5296 .15247 m .5134 .15109 L .51566 .15674 L .911 .905 0 r
F
.5326 .15793 m .5296 .15247 L .51566 .15674 L .915 .897 0 r
F
.68129 .76601 m .64249 .76763 L .64111 .77274 L .584 .053 0 r
F
.68129 .76601 m .68301 .76082 L .64249 .76763 L F
.34427 .69734 m .29681 .69759 L .29754 .70284 L 1 .506 0 r
F
.34445 .70289 m .34427 .69734 L .29754 .70284 L 1 .5 0 r
F
.38995 .69135 m .34427 .69734 L .34445 .70289 L .93 .542 0 r
F
.38995 .69135 m .39034 .68496 L .34427 .69734 L F
.51564 .15689 m .51338 .15121 L .49967 .15496 L .969 .939 0 r
F
.52956 .15271 m .51338 .15121 L .51564 .15689 L .907 .899 0 r
F
.53255 .15821 m .52956 .15271 L .51564 .15689 L .911 .891 0 r
F
.56775 .15772 m .5501 .1583 L .55373 .16366 L .804 .811 0 r
F
.57198 .16288 m .56775 .15772 L .55373 .16366 L .805 .802 0 r
F
.35628 .16938 m .3474 .15851 L .34218 .16267 L 1 1 0 r
F
.35628 .16938 m .36091 .16489 L .3474 .15851 L F
.1626 .5045 m .13051 .4828 L .12942 .48932 L 1 .943 0 r
F
.16177 .51094 m .1626 .5045 L .12942 .48932 L 1 .933 0 r
F
.37716 .79995 m .33363 .79113 L .33484 .796 L 1 .285 0 r
F
.37801 .80468 m .37716 .79995 L .33484 .796 L 1 .267 0 r
F
.77951 .68216 m .7426 .68701 L .74152 .69307 L .446 .052 0 r
F
.77951 .68216 m .78075 .67598 L .7426 .68701 L F
.51411 .14553 m .51168 .14059 L .49869 .14287 L .883 .945 0 r
F
.52733 .14241 m .51168 .14059 L .51411 .14553 L .851 .92 0 r
F
.53053 .14725 m .52733 .14241 L .51411 .14553 L .852 .914 0 r
F
.64074 .19392 m .62085 .19806 L .62492 .20365 L .648 .612 0 r
F
.64518 .19934 m .64074 .19392 L .62492 .20365 L .644 .597 0 r
F
.64706 .20865 m .62725 .21214 L .63086 .21817 L .594 .507 0 r
F
.6509 .21463 m .64706 .20865 L .63086 .21817 L .585 .484 0 r
F
.5141 .14556 m .51168 .14062 L .49869 .14287 L .881 .943 0 r
F
.52732 .14247 m .51168 .14062 L .5141 .14556 L .85 .918 0 r
F
.53052 .14731 m .52732 .14247 L .5141 .14556 L .851 .912 0 r
F
.55754 .48866 m .52355 .48704 L .52368 .49091 L 1 .701 0 r
F
.55771 .49284 m .55754 .48866 L .52368 .49091 L 1 .702 0 r
F
.46447 .82632 m .46445 .82176 L .42121 .82096 L .919 .143 0 r
F
.50724 .82576 m .46445 .82176 L .46447 .82632 L .86 .095 0 r
F
.50724 .82576 m .50767 .82121 L .46445 .82176 L F
.54642 .15303 m .5296 .15247 L .5326 .15793 L .858 .863 0 r
F
.5501 .1583 m .54642 .15303 L .5326 .15793 L .86 .854 0 r
F
.18688 .64216 m .14903 .62323 L .14955 .62964 L 1 .74 0 r
F
.18742 .64844 m .18688 .64216 L .14955 .62964 L 1 .726 0 r
F
.19816 .61076 m .15897 .59336 L .15935 .59954 L 1 .729 0 r
F
.19864 .61673 m .19816 .61076 L .15935 .59954 L 1 .718 0 r
F
.56758 .15831 m .55 .15873 L .5536 .16415 L .799 .801 0 r
F
.57176 .16357 m .56758 .15831 L .5536 .16415 L .799 .789 0 r
F
.59522 .50664 m .55826 .50526 L .55846 .50937 L 1 .604 0 r
F
.59539 .511 m .59522 .50664 L .55846 .50937 L 1 .602 0 r
F
.63263 .50614 m .59522 .50664 L .59539 .511 L .938 .483 0 r
F
.63263 .50614 m .63254 .50154 L .59522 .50664 L F
.55045 .43345 m .52167 .43369 L .52165 .43822 L .998 .485 0 r
F
.55027 .43817 m .55045 .43345 L .52165 .43822 L .993 .481 0 r
F
.57916 .43239 m .55045 .43345 L .55027 .43817 L .889 .349 0 r
F
.57916 .43239 m .57958 .42741 L .55045 .43345 L F
.54634 .15339 m .52956 .15271 L .53255 .15821 L .854 .856 0 r
F
.55 .15873 m .54634 .15339 L .53255 .15821 L .856 .846 0 r
F
.62617 .16441 m .60715 .1684 L .61202 .17314 L .68 .739 0 r
F
.63152 .16894 m .62617 .16441 L .61202 .17314 L .677 .73 0 r
F
.59175 .8068 m .55103 .80561 L .55019 .81021 L .725 .063 0 r
F
.59175 .8068 m .59301 .80217 L .55103 .80561 L F
.60771 .42025 m .58001 .42228 L .57958 .42741 L .768 .209 0 r
F
.60771 .42025 m .60842 .41487 L .58001 .42228 L F
.84017 .44719 m .80946 .45735 L .81107 .46406 L .371 .089 0 r
F
.84017 .44719 m .83839 .44046 L .80946 .45735 L F
.54368 .14321 m .52733 .14241 L .53053 .14725 L .818 .89 0 r
F
.54759 .14791 m .54368 .14321 L .53053 .14725 L .819 .883 0 r
F
.66329 .35981 m .6401 .36301 L .63958 .36967 L .489 .064 0 r
F
.66329 .35981 m .66392 .35302 L .6401 .36301 L F
.69906 .44339 m .66717 .44895 L .66734 .45417 L .663 .236 0 r
F
.69906 .44339 m .69881 .43803 L .66717 .44895 L F
.31147 .18872 m .30172 .17469 L .29626 .17906 L 1 1 0 r
F
.31147 .18872 m .31641 .18404 L .30172 .17469 L F
.54366 .1433 m .52732 .14247 L .53052 .14731 L .817 .888 0 r
F
.54757 .148 m .54366 .1433 L .53052 .14731 L .817 .882 0 r
F
.33037 .79079 m .28655 .7803 L .28805 .78548 L 1 .352 0 r
F
.33154 .79582 m .33037 .79079 L .28805 .78548 L 1 .334 0 r
F
.6932 .20053 m .6722 .2077 L .67701 .21285 L .579 .598 0 r
F
.69837 .2055 m .6932 .20053 L .67701 .21285 L .574 .586 0 r
F
.62602 .16472 m .60705 .16864 L .6119 .17339 L .677 .736 0 r
F
.63135 .16926 m .62602 .16472 L .6119 .17339 L .674 .726 0 r
F
.68046 .28655 m .65971 .29008 L .66113 .29703 L .438 .14 0 r
F
.68046 .28655 m .67891 .2796 L .65971 .29008 L F
.59453 .16613 m .57613 .16812 L .58022 .17345 L .742 .745 0 r
F
.59913 .17125 m .59453 .16613 L .58022 .17345 L .741 .734 0 r
F
.71775 .36271 m .69205 .36923 L .69298 .37527 L .49 .158 0 r
F
.71775 .36271 m .71665 .35666 L .69205 .36923 L F
.83564 .44076 m .80555 .45085 L .80716 .45751 L .367 .084 0 r
F
.83564 .44076 m .83388 .43409 L .80555 .45085 L F
.72819 .73071 m .69063 .73395 L .68923 .73944 L .507 .05 0 r
F
.72819 .73071 m .72985 .72512 L .69063 .73395 L F
.29196 .23097 m .28284 .22015 L .27747 .22392 L 1 1 0 r
F
.29196 .23097 m .29662 .22646 L .28284 .22015 L F
.66806 .48924 m .63234 .49223 L .63244 .4969 L .813 .356 0 r
F
.66806 .48924 m .668 .48437 L .63234 .49223 L F
.28414 .7545 m .24176 .74143 L .24323 .74694 L 1 .46 0 r
F
.2854 .75985 m .28414 .7545 L .24323 .74694 L 1 .443 0 r
F
.69278 .20106 m .67189 .20812 L .67668 .21328 L .574 .593 0 r
F
.69793 .20603 m .69278 .20106 L .67668 .21328 L .569 .582 0 r
F
.81951 .59051 m .78548 .59798 L .78522 .60443 L .376 .055 0 r
F
.81951 .59051 m .81981 .58397 L .78548 .59798 L F
.15132 .53157 m .11946 .50947 L .11852 .51614 L 1 .94 0 r
F
.15057 .53819 m .15132 .53157 L .11852 .51614 L 1 .93 0 r
F
.64306 .20278 m .62351 .20619 L .62725 .21214 L .603 .53 0 r
F
.64706 .20865 m .64306 .20278 L .62725 .21214 L .594 .507 0 r
F
.82344 .59848 m .78858 .60576 L .78831 .61229 L .383 .057 0 r
F
.82344 .59848 m .82375 .59185 L .78858 .60576 L F
.55771 .49284 m .52368 .49091 L .52383 .49476 L 1 .702 0 r
F
.55788 .497 m .55771 .49284 L .52383 .49476 L 1 .703 0 r
F
.68248 .77528 m .64333 .77658 L .64192 .78176 L .59 .054 0 r
F
.68248 .77528 m .68424 .77002 L .64333 .77658 L F
.31195 .1896 m .30251 .17612 L .29717 .18062 L 1 1 0 r
F
.31195 .1896 m .31687 .18491 L .30251 .17612 L F
.14142 .55315 m .1074 .5308 L .10682 .53764 L 1 .898 0 r
F
.141 .5599 m .14142 .55315 L .10682 .53764 L 1 .887 0 r
F
.34259 .21132 m .34691 .20719 L .33826 .21325 L .579 .215 0 r
F
.38837 .15667 m .37981 .14787 L .37502 .15198 L 1 1 0 r
F
.28239 .76436 m .23922 .75162 L .24081 .75716 L 1 .441 0 r
F
.28372 .76973 m .28239 .76436 L .24081 .75716 L 1 .424 0 r
F
.59411 .16721 m .57587 .16892 L .5799 .17436 L .732 .725 0 r
F
.59862 .17249 m .59411 .16721 L .5799 .17436 L .729 .711 0 r
F
.18224 .65824 m .14299 .63949 L .14376 .64596 L 1 .704 0 r
F
.18299 .66455 m .18224 .65824 L .14376 .64596 L 1 .69 0 r
F
.5495 .82387 m .50767 .82121 L .50724 .82576 L .793 .07 0 r
F
.5495 .82387 m .55039 .8193 L .50767 .82121 L F
.3807 .18498 m .37388 .18562 L .36922 .18862 L .75 .585 0 r
F
.3807 .18498 m .38458 .18075 L .37388 .18562 L F
.42144 .81173 m .37801 .80468 L .37889 .80934 L .985 .212 0 r
F
.42191 .81626 m .42144 .81173 L .37889 .80934 L .978 .194 0 r
F
.46454 .81718 m .42144 .81173 L .42191 .81626 L .923 .151 0 r
F
.59539 .511 m .55846 .50937 L .55866 .51347 L 1 .602 0 r
F
.59556 .51536 m .59539 .511 L .55866 .51347 L 1 .601 0 r
F
.63273 .51072 m .59539 .511 L .59556 .51536 L .935 .48 0 r
F
.63273 .51072 m .63263 .50614 L .59539 .511 L F
.63619 .18858 m .61668 .19255 L .62085 .19806 L .652 .626 0 r
F
.64074 .19392 m .63619 .18858 L .62085 .19806 L .648 .612 0 r
F
.23233 .72311 m .19048 .70765 L .19188 .71363 L 1 .555 0 r
F
.23357 .72892 m .23233 .72311 L .19188 .71363 L 1 .539 0 r
F
.16177 .51094 m .12942 .48932 L .12844 .49584 L 1 .933 0 r
F
.16103 .51738 m .16177 .51094 L .12844 .49584 L 1 .923 0 r
F
.5134 .15109 m .49819 .1491 L .49967 .15496 L .968 .952 0 r
F
.51338 .15121 m .49819 .1491 L .49967 .15496 L .964 .947 0 r
F
.37667 .80934 m .33276 .80079 L .33402 .80569 L 1 .272 0 r
F
.37755 .8141 m .37667 .80934 L .33402 .80569 L 1 .254 0 r
F
.63508 .79251 m .59543 .79269 L .59424 .79747 L .653 .057 0 r
F
.63508 .79251 m .63666 .78767 L .59543 .79269 L F
.84184 .45394 m .81107 .46406 L .81258 .47079 L .367 .077 0 r
F
.84184 .45394 m .84017 .44719 L .81107 .46406 L F
.73009 .73989 m .69203 .74276 L .6906 .74833 L .516 .051 0 r
F
.73009 .73989 m .73179 .73421 L .69203 .74276 L F
.5872 .15015 m .56945 .15202 L .57394 .15668 L .739 .812 0 r
F
.59226 .1546 m .5872 .15015 L .57394 .15668 L .738 .803 0 r
F
.2472 .66965 m .20385 .65758 L .20485 .66328 L 1 .578 0 r
F
.2481 .6751 m .2472 .66965 L .20485 .66328 L 1 .569 0 r
F
.51168 .14059 m .49709 .13787 L .49869 .14287 L .881 .95 0 r
F
.51168 .14062 m .49709 .13787 L .49869 .14287 L .88 .949 0 r
F
.68174 .29355 m .66113 .29703 L .66231 .30402 L .42 .102 0 r
F
.68174 .29355 m .68046 .28655 L .66113 .29703 L F
.68796 .19564 m .66732 .20262 L .6722 .2077 L .584 .609 0 r
F
.6932 .20053 m .68796 .19564 L .6722 .2077 L .579 .598 0 r
F
.58713 .15033 m .56941 .15216 L .57389 .15683 L .738 .809 0 r
F
.59218 .1548 m .58713 .15033 L .57389 .15683 L .736 .801 0 r
F
.28673 .24526 m .28083 .23883 L .27228 .2384 L .79 .873 0 r
F
.28673 .24526 m .29189 .24161 L .28083 .23883 L F
.34848 .19672 m .34133 .19219 L .33608 .19523 L .931 1 0 r
F
.34848 .19672 m .35296 .19266 L .34133 .19219 L F
.8373 .44745 m .80716 .45751 L .80868 .46418 L .363 .075 0 r
F
.8373 .44745 m .83564 .44076 L .80716 .45751 L F
.23539 .71308 m .1946 .69737 L .19586 .7033 L 1 .576 0 r
F
.23652 .71885 m .23539 .71308 L .19586 .7033 L 1 .56 0 r
F
.55788 .497 m .52383 .49476 L .52397 .4986 L 1 .703 0 r
F
.55807 .50114 m .55788 .497 L .52397 .4986 L F
.71876 .36872 m .69298 .37527 L .69382 .38126 L .486 .147 0 r
F
.71876 .36872 m .71775 .36271 L .69298 .37527 L F
.69928 .4487 m .66734 .45417 L .66749 .45933 L .663 .232 0 r
F
.69928 .4487 m .69906 .44339 L .66734 .45417 L F
.29681 .69759 m .25103 .69129 L .2521 .69662 L 1 .504 0 r
F
.29754 .70284 m .29681 .69759 L .2521 .69662 L 1 .498 0 r
F
.63891 .19701 m .61965 .20034 L .62351 .20619 L .611 .551 0 r
F
.64306 .20278 m .63891 .19701 L .62351 .20619 L .603 .53 0 r
F
.34445 .70289 m .29754 .70284 L .29831 .70807 L 1 .5 0 r
F
.34468 .7084 m .34445 .70289 L .29831 .70807 L 1 .493 0 r
F
.38965 .69762 m .34445 .70289 L .34468 .7084 L .939 .531 0 r
F
.38965 .69762 m .38995 .69135 L .34445 .70289 L F
.68756 .19616 m .66703 .20303 L .67189 .20812 L .579 .604 0 r
F
.69278 .20106 m .68756 .19616 L .67189 .20812 L .574 .593 0 r
F
.66811 .49408 m .63244 .4969 L .63254 .50154 L .81 .353 0 r
F
.66811 .49408 m .66806 .48924 L .63244 .4969 L F
.63545 .40085 m .60984 .40363 L .60913 .40933 L .624 .073 0 r
F
.63545 .40085 m .6364 .39493 L .60984 .40363 L F
.55027 .43817 m .52165 .43822 L .52164 .44265 L .993 .481 0 r
F
.55011 .44278 m .55027 .43817 L .52164 .44265 L .987 .477 0 r
F
.57876 .43725 m .55027 .43817 L .55011 .44278 L .884 .344 0 r
F
.57876 .43725 m .57916 .43239 L .55027 .43817 L F
.59212 .81603 m .55125 .81464 L .55039 .8193 L .726 .063 0 r
F
.59212 .81603 m .59342 .81133 L .55125 .81464 L F
.3836 .17735 m .37615 .175 L .37139 .17808 L .93 .998 0 r
F
.3836 .17735 m .38757 .17318 L .37615 .175 L F
.36071 .16433 m .3524 .15372 L .34711 .15776 L 1 1 0 r
F
.36071 .16433 m .36539 .15993 L .3524 .15372 L F
.31641 .18404 m .30723 .17041 L .30172 .17469 L F
.31641 .18404 m .3214 .17944 L .30723 .17041 L F
.29662 .22646 m .28828 .21654 L .28284 .22015 L F
.29662 .22646 m .30134 .22207 L .28828 .21654 L F
.59556 .51536 m .55866 .51347 L .55888 .51756 L 1 .601 0 r
F
.59573 .51969 m .59556 .51536 L .55888 .51756 L 1 .599 0 r
F
.63282 .51528 m .59556 .51536 L .59573 .51969 L .932 .477 0 r
F
.63282 .51528 m .63273 .51072 L .59556 .51536 L F
.77533 .67943 m .73936 .68454 L .73823 .69048 L .428 .048 0 r
F
.77533 .67943 m .77664 .67338 L .73936 .68454 L F
.15057 .53819 m .11852 .51614 L .11767 .52281 L 1 .93 0 r
F
.14992 .5448 m .15057 .53819 L .11767 .52281 L 1 .919 0 r
F
.19864 .61673 m .15935 .59954 L .15981 .60571 L 1 .718 0 r
F
.19919 .62267 m .19864 .61673 L .15981 .60571 L 1 .706 0 r
F
.62078 .15995 m .60223 .16373 L .60715 .1684 L .683 .749 0 r
F
.62617 .16441 m .62078 .15995 L .60715 .1684 L .68 .739 0 r
F
.55807 .50114 m .52397 .4986 L .52413 .50242 L 1 .703 0 r
F
.55826 .50526 m .55807 .50114 L .52413 .50242 L 1 .704 0 r
F
.36091 .16489 m .35267 .15447 L .3474 .15851 L 1 1 0 r
F
.36091 .16489 m .36557 .16049 L .35267 .15447 L F
.60701 .42547 m .57958 .42741 L .57916 .43239 L .762 .202 0 r
F
.60701 .42547 m .60771 .42025 L .57958 .42741 L F
.18742 .64844 m .14955 .62964 L .15016 .63603 L 1 .726 0 r
F
.18804 .65468 m .18742 .64844 L .15016 .63603 L 1 .712 0 r
F
.62064 .16024 m .60214 .16395 L .60705 .16864 L .68 .745 0 r
F
.62602 .16472 m .62064 .16024 L .60705 .16864 L .677 .736 0 r
F
.84342 .4607 m .81258 .47079 L .81401 .47752 L .363 .074 0 r
F
.84342 .4607 m .84184 .45394 L .81258 .47079 L F
.46457 .82161 m .46454 .81718 L .42191 .81626 L .916 .133 0 r
F
.50675 .82109 m .46454 .81718 L .46457 .82161 L .855 .084 0 r
F
.50675 .82109 m .50718 .81667 L .46454 .81718 L F
.63154 .18332 m .61243 .18711 L .61668 .19255 L .656 .64 0 r
F
.63619 .18858 m .63154 .18332 L .61668 .19255 L .652 .626 0 r
F
.68265 .19081 m .66239 .1976 L .66732 .20262 L .588 .621 0 r
F
.68796 .19564 m .68265 .19081 L .66732 .20262 L .584 .609 0 r
F
.56346 .15264 m .54642 .15303 L .5501 .1583 L .804 .821 0 r
F
.56775 .15772 m .56346 .15264 L .5501 .1583 L .804 .811 0 r
F
.56035 .14291 m .54368 .14321 L .54759 .14791 L .782 .859 0 r
F
.56492 .14743 m .56035 .14291 L .54759 .14791 L .782 .852 0 r
F
.68275 .3006 m .66231 .30402 L .66325 .31105 L .401 .073 0 r
F
.68275 .3006 m .68174 .29355 L .66231 .30402 L F
.31687 .18491 m .30791 .17171 L .30251 .17612 L 1 1 0 r
F
.31687 .18491 m .32183 .18029 L .30791 .17171 L F
.141 .5599 m .10682 .53764 L .10634 .54448 L 1 .887 0 r
F
.14066 .56663 m .141 .5599 L .10634 .54448 L 1 .875 0 r
F
.56032 .14303 m .54366 .1433 L .54757 .148 L .781 .858 0 r
F
.56488 .14756 m .56032 .14303 L .54757 .148 L .78 .85 0 r
F
.58986 .16108 m .57198 .16288 L .57613 .16812 L .744 .756 0 r
F
.59453 .16613 m .58986 .16108 L .57613 .16812 L .742 .745 0 r
F
.83886 .45415 m .80868 .46418 L .81011 .47086 L .359 .073 0 r
F
.83886 .45415 m .8373 .44745 L .80868 .46418 L F
.77817 .6883 m .74152 .69307 L .74036 .69909 L .44 .05 0 r
F
.77817 .6883 m .77951 .68216 L .74152 .69307 L F
.16103 .51738 m .12844 .49584 L .12755 .50235 L 1 .923 0 r
F
.16038 .5238 m .16103 .51738 L .12755 .50235 L 1 .913 0 r
F
.66249 .3665 m .63958 .36967 L .63893 .3762 L .474 .061 0 r
F
.66249 .3665 m .66329 .35981 L .63958 .36967 L F
.71969 .37468 m .69382 .38126 L .69458 .3872 L .483 .137 0 r
F
.71969 .37468 m .71876 .36872 L .69382 .38126 L F
.63463 .19134 m .61566 .19458 L .61965 .20034 L .619 .572 0 r
F
.63891 .19701 m .63463 .19134 L .61965 .20034 L .611 .551 0 r
F
.81911 .59703 m .78522 .60443 L .78488 .61086 L .372 .053 0 r
F
.81911 .59703 m .81951 .59051 L .78522 .60443 L F
.56332 .15315 m .54634 .15339 L .55 .15873 L .8 .812 0 r
F
.56758 .15831 m .56332 .15315 L .55 .15873 L .799 .801 0 r
F
.82304 .60509 m .78831 .61229 L .78795 .61879 L .379 .055 0 r
F
.82304 .60509 m .82344 .59848 L .78831 .61229 L F
.63576 .80181 m .59589 .80171 L .59467 .80656 L .656 .057 0 r
F
.63576 .80181 m .63738 .7969 L .59589 .80171 L F
.42121 .82096 m .37755 .8141 L .37845 .8188 L .979 .202 0 r
F
.4217 .82554 m .42121 .82096 L .37845 .8188 L .972 .184 0 r
F
.46447 .82632 m .42121 .82096 L .4217 .82554 L .919 .143 0 r
F
.68228 .19132 m .66211 .19801 L .66703 .20303 L .583 .616 0 r
F
.68756 .19616 m .68228 .19132 L .66703 .20303 L .579 .604 0 r
F
.66815 .49888 m .63254 .50154 L .63263 .50614 L .808 .349 0 r
F
.66815 .49888 m .66811 .49408 L .63254 .50154 L F
.69948 .45395 m .66749 .45933 L .66762 .46443 L .662 .228 0 r
F
.69948 .45395 m .69928 .4487 L .66749 .45933 L F
.55826 .50526 m .52413 .50242 L .52429 .50624 L 1 .704 0 r
F
.55846 .50937 m .55826 .50526 L .52429 .50624 L F
.5134 .15109 m .5111 .14553 L .49819 .1491 L .968 .952 0 r
F
.52655 .14709 m .5111 .14553 L .5134 .15109 L .907 .912 0 r
F
.5296 .15247 m .52655 .14709 L .5134 .15109 L .911 .905 0 r
F
.59573 .51969 m .55888 .51756 L .5591 .52166 L 1 .599 0 r
F
.59591 .52402 m .59573 .51969 L .5591 .52166 L 1 .596 0 r
F
.6329 .51981 m .59573 .51969 L .59591 .52402 L .929 .474 0 r
F
.6329 .51981 m .63282 .51528 L .59573 .51969 L F
.58951 .16203 m .57176 .16357 L .57587 .16892 L .735 .739 0 r
F
.59411 .16721 m .58951 .16203 L .57587 .16892 L .732 .725 0 r
F
.33246 .78619 m .2895 .77552 L .29098 .78062 L 1 .35 0 r
F
.33363 .79113 m .33246 .78619 L .29098 .78062 L 1 .332 0 r
F
.51338 .15121 m .51109 .14563 L .49819 .1491 L .964 .947 0 r
F
.52652 .14729 m .51109 .14563 L .51338 .15121 L .904 .907 0 r
F
.52956 .15271 m .52652 .14729 L .51338 .15121 L .907 .899 0 r
F
.54269 .14783 m .52655 .14709 L .5296 .15247 L .856 .871 0 r
F
.54642 .15303 m .54269 .14783 L .5296 .15247 L .858 .863 0 r
F
.67951 .77114 m .64111 .77274 L .63967 .77779 L .576 .051 0 r
F
.67951 .77114 m .68129 .76601 L .64111 .77274 L F
.34691 .20719 m .34314 .21009 L .33826 .21325 L .507 .202 0 r
F
.34691 .20719 m .35127 .20316 L .34314 .21009 L F
.54262 .14814 m .52652 .14729 L .52956 .15271 L .853 .865 0 r
F
.54634 .15339 m .54262 .14814 L .52956 .15271 L .854 .856 0 r
F
.55011 .44278 m .52164 .44265 L .52163 .447 L .987 .477 0 r
F
.18299 .66455 m .14376 .64596 L .14462 .6524 L 1 .69 0 r
F
.18382 .67083 m .18299 .66455 L .14462 .6524 L 1 .675 0 r
F
.43202 .65821 m .39213 .66506 L .39143 .67182 L .878 .622 0 r
F
.43152 .6652 m .39143 .67182 L .39083 .67846 L .885 .609 0 r
F
.43152 .6652 m .43202 .65821 L .39143 .67182 L F
.54995 .44728 m .55011 .44278 L .52163 .447 L .981 .473 0 r
F
.57837 .44197 m .55011 .44278 L .54995 .44728 L .878 .34 0 r
F
.57837 .44197 m .57876 .43725 L .55011 .44278 L F
.22156 .25405 m .20764 .23397 L .20272 .23924 L 1 1 0 r
F
.22156 .25405 m .22608 .24855 L .20764 .23397 L F
.43258 .65115 m .39296 .65818 L .39213 .66506 L .87 .634 0 r
F
.43202 .65821 m .43258 .65115 L .39213 .66506 L .878 .622 0 r
F
.22159 .25407 m .21817 .24382 L .21328 .24873 L .976 .83 0 r
F
.22159 .25407 m .22611 .24858 L .21817 .24382 L F
.54843 .81917 m .50718 .81667 L .50675 .82109 L .786 .068 0 r
F
.54843 .81917 m .54932 .81473 L .50718 .81667 L F
.29189 .24161 m .29162 .24264 L .28083 .23883 L 0 0 0 r
F
.29189 .24161 m .29718 .23823 L .29162 .24264 L F
.8449 .46747 m .81401 .47752 L .81534 .48426 L .36 .072 0 r
F
.8449 .46747 m .84342 .4607 L .81401 .47752 L F
.72646 .73624 m .68923 .73944 L .68777 .74487 L .499 .048 0 r
F
.72646 .73624 m .72819 .73071 L .68923 .73944 L F
.55846 .50937 m .52429 .50624 L .52445 .51006 L 1 .704 0 r
F
.55866 .51347 m .55846 .50937 L .52445 .51006 L F
.67728 .18605 m .65739 .19265 L .66239 .1976 L .593 .632 0 r
F
.68265 .19081 m .67728 .18605 L .66239 .1976 L .588 .621 0 r
F
.43107 .67211 m .39083 .67846 L .39034 .68496 L .891 .596 0 r
F
.43107 .67211 m .43152 .6652 L .39083 .67846 L F
.14992 .5448 m .11767 .52281 L .11693 .52949 L 1 .919 0 r
F
.14935 .55141 m .14992 .5448 L .11693 .52949 L 1 .908 0 r
F
.30134 .22207 m .2938 .21312 L .28828 .21654 L 1 1 0 r
F
.30134 .22207 m .30611 .21779 L .2938 .21312 L F
.84032 .46086 m .81011 .47086 L .81144 .47754 L .355 .071 0 r
F
.84032 .46086 m .83886 .45415 L .81011 .47086 L F
.3214 .17944 m .31279 .16622 L .30723 .17041 L 1 1 0 r
F
.3214 .17944 m .32645 .17492 L .31279 .16622 L F
.63021 .18578 m .61156 .18892 L .61566 .19458 L .627 .592 0 r
F
.63463 .19134 m .63021 .18578 L .61566 .19458 L .619 .572 0 r
F
.34468 .7084 m .29831 .70807 L .29911 .71327 L 1 .493 0 r
F
.34498 .71386 m .34468 .7084 L .29911 .71327 L 1 .484 0 r
F
.38943 .70378 m .34468 .7084 L .34498 .71386 L .947 .519 0 r
F
.38943 .70378 m .38965 .69762 L .34468 .7084 L F
.72054 .38059 m .69458 .3872 L .69527 .39308 L .48 .128 0 r
F
.72054 .38059 m .71969 .37468 L .69458 .3872 L F
.51168 .14059 m .50923 .13571 L .49709 .13787 L .881 .95 0 r
F
.5241 .13764 m .50923 .13571 L .51168 .14059 L .85 .926 0 r
F
.52733 .14241 m .5241 .13764 L .51168 .14059 L .851 .92 0 r
F
.37801 .80468 m .33484 .796 L .33609 .8008 L 1 .267 0 r
F
.37889 .80934 m .37801 .80468 L .33609 .8008 L 1 .248 0 r
F
.51168 .14062 m .50923 .13573 L .49709 .13787 L .88 .949 0 r
F
.52409 .13768 m .50923 .13573 L .51168 .14062 L .848 .924 0 r
F
.52732 .14247 m .52409 .13768 L .51168 .14062 L .85 .918 0 r
F
.43318 .64406 m .39391 .65117 L .39296 .65818 L .863 .645 0 r
F
.43258 .65115 m .43318 .64406 L .39296 .65818 L .87 .634 0 r
F
.68349 .30769 m .66325 .31105 L .66395 .31809 L .382 .068 0 r
F
.68349 .30769 m .68275 .3006 L .66325 .31105 L F
.2481 .6751 m .20485 .66328 L .20591 .66895 L 1 .569 0 r
F
.24903 .68052 m .2481 .6751 L .20591 .66895 L 1 .56 0 r
F
.53972 .13858 m .5241 .13764 L .52733 .14241 L .818 .896 0 r
F
.54368 .14321 m .53972 .13858 L .52733 .14241 L .818 .89 0 r
F
.62679 .17814 m .60808 .18175 L .61243 .18711 L .661 .654 0 r
F
.63154 .18332 m .62679 .17814 L .61243 .18711 L .656 .64 0 r
F
.2854 .75985 m .24323 .74694 L .24478 .75239 L 1 .443 0 r
F
.28671 .76513 m .2854 .75985 L .24478 .75239 L 1 .425 0 r
F
.35296 .19266 m .34668 .18947 L .34133 .19219 L .829 .871 0 r
F
.35296 .19266 m .35748 .18874 L .34668 .18947 L F
.5397 .13866 m .52409 .13768 L .52732 .14247 L .817 .895 0 r
F
.54366 .1433 m .5397 .13866 L .52732 .14247 L .817 .888 0 r
F
.59591 .52402 m .5591 .52166 L .55932 .52575 L 1 .596 0 r
F
.59609 .52834 m .59591 .52402 L .55932 .52575 L 1 .594 0 r
F
.63299 .52432 m .59591 .52402 L .59609 .52834 L .926 .47 0 r
F
.63299 .52432 m .6329 .51981 L .59591 .52402 L F
.67693 .18656 m .65713 .19305 L .66211 .19801 L .588 .627 0 r
F
.68228 .19132 m .67693 .18656 L .66211 .19801 L .583 .616 0 r
F
.22608 .24855 m .21264 .22877 L .20764 .23397 L 1 1 0 r
F
.22608 .24855 m .23067 .24311 L .21264 .22877 L F
.38458 .18075 m .37864 .183 L .37388 .18562 L .669 .229 0 r
F
.22611 .24858 m .22319 .23903 L .21817 .24382 L .932 .772 0 r
F
.22611 .24858 m .23072 .24316 L .22319 .23903 L F
.58209 .14576 m .56492 .14743 L .56945 .15202 L .741 .82 0 r
F
.5872 .15015 m .58209 .14576 L .56945 .15202 L .739 .812 0 r
F
.66818 .50365 m .63263 .50614 L .63273 .51072 L .806 .345 0 r
F
.66818 .50365 m .66815 .49888 L .63263 .50614 L F
.16038 .5238 m .12755 .50235 L .12675 .50887 L 1 .913 0 r
F
.15982 .53021 m .16038 .5238 L .12675 .50887 L 1 .902 0 r
F
.58203 .14593 m .56488 .14756 L .56941 .15216 L .739 .817 0 r
F
.58713 .15033 m .58203 .14593 L .56941 .15216 L .738 .809 0 r
F
.33154 .79582 m .28805 .78548 L .28961 .7906 L 1 .334 0 r
F
.33276 .80079 m .33154 .79582 L .28961 .7906 L 1 .316 0 r
F
.29754 .70284 m .2521 .69662 L .25321 .70193 L 1 .498 0 r
F
.29831 .70807 m .29754 .70284 L .25321 .70193 L 1 .491 0 r
F
.43068 .67892 m .39034 .68496 L .38995 .69135 L .897 .582 0 r
F
.43068 .67892 m .43107 .67211 L .39034 .68496 L F
.23357 .72892 m .19188 .71363 L .19335 .71956 L 1 .539 0 r
F
.23488 .73467 m .23357 .72892 L .19335 .71956 L 1 .522 0 r
F
.63446 .4066 m .60913 .40933 L .60842 .41487 L .615 .071 0 r
F
.63446 .4066 m .63545 .40085 L .60913 .40933 L F
.69964 .45916 m .66762 .46443 L .66773 .46948 L .661 .224 0 r
F
.69964 .45916 m .69948 .45395 L .66762 .46443 L F
.32183 .18029 m .31338 .1674 L .30791 .17171 L 1 1 0 r
F
.32183 .18029 m .32684 .17575 L .31338 .1674 L F
.4645 .8308 m .46447 .82632 L .4217 .82554 L .911 .125 0 r
F
.50679 .83024 m .46447 .82632 L .4645 .8308 L .852 .079 0 r
F
.50679 .83024 m .50724 .82576 L .46447 .82632 L F
.59044 .81136 m .55019 .81021 L .54932 .81473 L .716 .061 0 r
F
.59044 .81136 m .59175 .8068 L .55019 .81021 L F
.61533 .15557 m .59727 .15913 L .60223 .16373 L .686 .758 0 r
F
.62078 .15995 m .61533 .15557 L .60223 .16373 L .683 .749 0 r
F
.14066 .56663 m .10634 .54448 L .10596 .5513 L 1 .875 0 r
F
.14041 .57336 m .14066 .56663 L .10596 .5513 L 1 .864 0 r
F
.55866 .51347 m .52445 .51006 L .52463 .51388 L 1 .704 0 r
F
.55888 .51756 m .55866 .51347 L .52463 .51388 L 1 .703 0 r
F
.60632 .43054 m .57916 .43239 L .57876 .43725 L .756 .196 0 r
F
.60632 .43054 m .60701 .42547 L .57916 .43239 L F
.19919 .62267 m .15981 .60571 L .16036 .61184 L 1 .706 0 r
F
.19981 .62857 m .19919 .62267 L .16036 .61184 L 1 .694 0 r
F
.23652 .71885 m .19586 .7033 L .1972 .70919 L 1 .56 0 r
F
.23773 .72457 m .23652 .71885 L .1972 .70919 L 1 .544 0 r
F
.6152 .15584 m .59719 .15934 L .60214 .16395 L .684 .755 0 r
F
.62064 .16024 m .6152 .15584 L .60214 .16395 L .68 .745 0 r
F
.28372 .76973 m .24081 .75716 L .24246 .76264 L 1 .424 0 r
F
.28511 .77505 m .28372 .76973 L .24246 .76264 L 1 .406 0 r
F
.68067 .78049 m .64192 .78176 L .64046 .78687 L .582 .052 0 r
F
.68067 .78049 m .68248 .77528 L .64192 .78176 L F
.36539 .15993 m .35773 .14978 L .3524 .15372 L 1 1 0 r
F
.36539 .15993 m .3701 .15562 L .35773 .14978 L F
.54995 .44728 m .52163 .447 L .52162 .45127 L .981 .473 0 r
F
.23067 .24311 m .21772 .22365 L .21264 .22877 L 1 1 0 r
F
.23067 .24311 m .23533 .23774 L .21772 .22365 L F
.72832 .7455 m .6906 .74833 L .68911 .75384 L .509 .049 0 r
F
.72832 .7455 m .73009 .73989 L .6906 .74833 L F
.23072 .24316 m .22832 .23438 L .22319 .23903 L .879 .697 0 r
F
.23072 .24316 m .23541 .23782 L .22832 .23438 L F
.43384 .63694 m .39499 .64404 L .39391 .65117 L .857 .655 0 r
F
.43318 .64406 m .43384 .63694 L .39391 .65117 L .863 .645 0 r
F
.18804 .65468 m .15016 .63603 L .15086 .64238 L 1 .712 0 r
F
.18873 .66089 m .18804 .65468 L .15086 .64238 L 1 .698 0 r
F
.47806 .33102 m .47184 .15861 L .47172 .1656 L 0 0 0 r
F
.47822 .33709 m .47172 .1656 L .47152 .34441 L F
.5111 .14553 m .49668 .14335 L .49819 .1491 L .962 .958 0 r
F
.51109 .14563 m .49668 .14335 L .49819 .1491 L .958 .953 0 r
F
.81862 .60352 m .78488 .61086 L .78444 .61726 L .368 .051 0 r
F
.81862 .60352 m .81911 .59703 L .78488 .61086 L F
.36557 .16049 m .35799 .15056 L .35267 .15447 L 1 1 0 r
F
.36557 .16049 m .37028 .15618 L .35799 .15056 L F
.84627 .47426 m .81534 .48426 L .81658 .491 L .356 .071 0 r
F
.84627 .47426 m .8449 .46747 L .81534 .48426 L F
.77394 .68543 m .73823 .69048 L .73702 .69638 L .421 .046 0 r
F
.77394 .68543 m .77533 .67943 L .73823 .69048 L F
.5851 .15612 m .56775 .15772 L .57198 .16288 L .746 .767 0 r
F
.58986 .16108 m .5851 .15612 L .57198 .16288 L .744 .756 0 r
F
.59609 .52834 m .55932 .52575 L .55956 .52985 L 1 .594 0 r
F
.59628 .53265 m .59609 .52834 L .55956 .52985 L 1 .591 0 r
F
.63306 .52882 m .59609 .52834 L .59628 .53265 L .922 .466 0 r
F
.63306 .52882 m .63299 .52432 L .59609 .52834 L F
.82254 .61167 m .78795 .61879 L .78751 .62527 L .376 .053 0 r
F
.82254 .61167 m .82304 .60509 L .78795 .61879 L F
.67184 .18137 m .65233 .18777 L .65739 .19265 L .598 .643 0 r
F
.67728 .18605 m .67184 .18137 L .65739 .19265 L .593 .632 0 r
F
.84167 .46759 m .81144 .47754 L .81268 .48423 L .351 .07 0 r
F
.84167 .46759 m .84032 .46086 L .81144 .47754 L F
.38757 .17318 m .38097 .17224 L .37615 .175 L .816 .794 0 r
F
.72131 .38645 m .69527 .39308 L .6959 .39891 L .477 .12 0 r
F
.72131 .38645 m .72054 .38059 L .69527 .39308 L F
.43034 .68563 m .38995 .69135 L .38965 .69762 L .903 .566 0 r
F
.43034 .68563 m .43068 .67892 L .38995 .69135 L F
.62567 .18032 m .60735 .18335 L .61156 .18892 L .634 .611 0 r
F
.63021 .18578 m .62567 .18032 L .61156 .18892 L .627 .592 0 r
F
.55888 .51756 m .52463 .51388 L .5248 .5177 L 1 .703 0 r
F
.5591 .52166 m .55888 .51756 L .5248 .5177 L F
.66155 .37306 m .63893 .3762 L .63816 .3826 L .46 .057 0 r
F
.66155 .37306 m .66249 .3665 L .63893 .3762 L F
.54981 .45168 m .54995 .44728 L .52162 .45127 L .975 .469 0 r
F
.578 .44657 m .54995 .44728 L .54981 .45168 L .873 .336 0 r
F
.578 .44657 m .57837 .44197 L .54995 .44728 L F
.23533 .23774 m .22287 .21861 L .21772 .22365 L 1 1 0 r
F
.23533 .23774 m .24006 .23244 L .22287 .21861 L F
.67151 .18186 m .65209 .18815 L .65713 .19305 L .593 .638 0 r
F
.67693 .18656 m .67151 .18186 L .65713 .19305 L .588 .627 0 r
F
.63344 .79728 m .59424 .79747 L .59301 .80217 L .644 .055 0 r
F
.63344 .79728 m .63508 .79251 L .59424 .79747 L F
.23541 .23782 m .23358 .22989 L .22832 .23438 L .815 .601 0 r
F
.23541 .23782 m .24018 .23257 L .23358 .22989 L F
.58482 .15694 m .56758 .15831 L .57176 .16357 L .737 .752 0 r
F
.58951 .16203 m .58482 .15694 L .57176 .16357 L .735 .739 0 r
F
.66819 .50839 m .63273 .51072 L .63282 .51528 L .803 .341 0 r
F
.66819 .50839 m .66818 .50365 L .63273 .51072 L F
.14935 .55141 m .11693 .52949 L .11628 .53616 L 1 .908 0 r
F
.14887 .55801 m .14935 .55141 L .11628 .53616 L 1 .897 0 r
F
.42191 .81626 m .37889 .80934 L .37979 .81393 L .978 .194 0 r
F
.42239 .82072 m .42191 .81626 L .37979 .81393 L .97 .176 0 r
F
.46457 .82161 m .42191 .81626 L .42239 .82072 L .916 .133 0 r
F
.37755 .8141 m .33402 .80569 L .33533 .81052 L 1 .254 0 r
F
.37845 .8188 m .37755 .8141 L .33533 .81052 L 1 .235 0 r
F
.5591 .14764 m .54269 .14783 L .54642 .15303 L .804 .831 0 r
F
.56346 .15264 m .5591 .14764 L .54642 .15303 L .804 .821 0 r
F
.77675 .69439 m .74036 .69909 L .73913 .70507 L .433 .048 0 r
F
.77675 .69439 m .77817 .6883 L .74036 .69909 L F
.54859 .82838 m .50724 .82576 L .50679 .83024 L .785 .068 0 r
F
.54859 .82838 m .5495 .82387 L .50724 .82576 L F
.62195 .17304 m .60365 .17646 L .60808 .18175 L .664 .667 0 r
F
.62679 .17814 m .62195 .17304 L .60808 .18175 L .661 .654 0 r
F
.68395 .31479 m .66395 .31809 L .6644 .32514 L .371 .063 0 r
F
.68395 .31479 m .68349 .30769 L .66395 .31809 L F
.30611 .21779 m .29939 .20988 L .2938 .21312 L .995 1 0 r
F
.30611 .21779 m .31095 .21364 L .29939 .20988 L F
.50923 .13571 m .49547 .13292 L .49709 .13787 L .879 .955 0 r
F
.50923 .13573 m .49547 .13292 L .49709 .13787 L .878 .954 0 r
F
.55899 .14807 m .54262 .14814 L .54634 .15339 L .8 .822 0 r
F
.56332 .15315 m .55899 .14807 L .54634 .15339 L .8 .812 0 r
F
.32645 .17492 m .31841 .16213 L .31279 .16622 L 1 1 0 r
F
.32645 .17492 m .33154 .17049 L .31841 .16213 L F
.69977 .46432 m .66773 .46948 L .66783 .47449 L .66 .22 0 r
F
.69977 .46432 m .69964 .45916 L .66773 .46948 L F
.15982 .53021 m .12675 .50887 L .12606 .51538 L 1 .902 0 r
F
.15935 .53661 m .15982 .53021 L .12606 .51538 L 1 .891 0 r
F
.35127 .20316 m .34811 .20721 L .34314 .21009 L 0 0 0 r
F
.35127 .20316 m .35567 .19925 L .34811 .20721 L F
.43453 .62985 m .39621 .63681 L .39499 .64404 L .85 .664 0 r
F
.43384 .63694 m .43453 .62985 L .39499 .64404 L .857 .655 0 r
F
.5591 .52166 m .5248 .5177 L .52499 .52153 L 1 .703 0 r
F
.55932 .52575 m .5591 .52166 L .52499 .52153 L 1 .702 0 r
F
.54981 .45168 m .52162 .45127 L .52161 .45546 L .975 .469 0 r
F
.24006 .23244 m .2281 .21365 L .22287 .21861 L 1 1 0 r
F
.24006 .23244 m .24486 .22721 L .2281 .21365 L F
.55573 .13846 m .53972 .13858 L .54368 .14321 L .783 .866 0 r
F
.56035 .14291 m .55573 .13846 L .54368 .14321 L .782 .859 0 r
F
.59628 .53265 m .55956 .52985 L .55979 .53396 L 1 .591 0 r
F
.59646 .53696 m .59628 .53265 L .55979 .53396 L 1 .587 0 r
F
.63314 .5333 m .59628 .53265 L .59646 .53696 L .918 .461 0 r
F
.63314 .5333 m .63306 .52882 L .59628 .53265 L F
.55571 .13857 m .5397 .13866 L .54366 .1433 L .782 .865 0 r
F
.56032 .14303 m .55571 .13857 L .54366 .1433 L .781 .858 0 r
F
.29718 .23823 m .30476 .25041 L .29162 .24264 L .18 0 0 r
F
.29718 .23823 m .30256 .23509 L .30476 .25041 L F
.24018 .23257 m .23899 .22559 L .23358 .22989 L .759 .476 0 r
F
.24018 .23257 m .24504 .22742 L .23899 .22559 L F
.18382 .67083 m .14462 .6524 L .14557 .65881 L 1 .675 0 r
F
.18472 .67707 m .18382 .67083 L .14557 .65881 L 1 .66 0 r
F
.34498 .71386 m .29911 .71327 L .29995 .71845 L 1 .484 0 r
F
.34533 .71928 m .34498 .71386 L .29995 .71845 L 1 .475 0 r
F
.3893 .70983 m .34498 .71386 L .34533 .71928 L .954 .506 0 r
F
.3893 .70983 m .38943 .70378 L .34498 .71386 L F
.43005 .69222 m .38965 .69762 L .38943 .70378 L .908 .551 0 r
F
.43005 .69222 m .43034 .68563 L .38965 .69762 L F
.59079 .82065 m .55039 .8193 L .5495 .82387 L .718 .061 0 r
F
.59079 .82065 m .59212 .81603 L .55039 .8193 L F
.32684 .17575 m .31892 .1632 L .31338 .1674 L 1 1 0 r
F
.32684 .17575 m .3319 .1713 L .31892 .1632 L F
.84754 .48105 m .81658 .491 L .81773 .49775 L .353 .069 0 r
F
.84754 .48105 m .84627 .47426 L .81658 .491 L F
.14041 .57336 m .10596 .5513 L .10568 .55812 L 1 .864 0 r
F
.14025 .58006 m .14041 .57336 L .10568 .55812 L 1 .852 0 r
F
.66634 .17677 m .64721 .18296 L .65233 .18777 L .603 .654 0 r
F
.67184 .18137 m .66634 .17677 L .65233 .18777 L .598 .643 0 r
F
.84291 .47431 m .81268 .48423 L .81383 .49092 L .347 .068 0 r
F
.84291 .47431 m .84167 .46759 L .81268 .48423 L F
.72202 .39225 m .6959 .39891 L .69646 .40467 L .475 .112 0 r
F
.72202 .39225 m .72131 .38645 L .6959 .39891 L F
.55932 .52575 m .52499 .52153 L .52518 .52537 L 1 .702 0 r
F
.55956 .52985 m .55932 .52575 L .52518 .52537 L 1 .701 0 r
F
.621 .17498 m .60303 .17787 L .60735 .18335 L .641 .629 0 r
F
.62567 .18032 m .621 .17498 L .60735 .18335 L .634 .611 0 r
F
.60566 .43546 m .57876 .43725 L .57837 .44197 L .75 .19 0 r
F
.60566 .43546 m .60632 .43054 L .57876 .43725 L F
.52655 .14709 m .52346 .1418 L .5111 .14553 L .907 .912 0 r
F
.53889 .14273 m .52346 .1418 L .52655 .14709 L .854 .879 0 r
F
.54269 .14783 m .53889 .14273 L .52655 .14709 L .856 .871 0 r
F
.66819 .5131 m .63282 .51528 L .6329 .51981 L .8 .337 0 r
F
.66819 .5131 m .66819 .50839 L .63282 .51528 L F
.66604 .17724 m .64699 .18333 L .65209 .18815 L .598 .649 0 r
F
.67151 .18186 m .66604 .17724 L .65209 .18815 L .593 .638 0 r
F
.60982 .15126 m .59226 .1546 L .59727 .15913 L .689 .767 0 r
F
.61533 .15557 m .60982 .15126 L .59727 .15913 L .686 .758 0 r
F
.35748 .18874 m .35213 .18714 L .34668 .18947 L .686 .589 0 r
F
.35748 .18874 m .36206 .18499 L .35213 .18714 L F
.24486 .22721 m .2334 .20878 L .2281 .21365 L 1 1 0 r
F
.24486 .22721 m .24972 .22205 L .2334 .20878 L F
.5111 .14553 m .50876 .14006 L .49668 .14335 L .962 .958 0 r
F
.52346 .1418 m .50876 .14006 L .5111 .14553 L .903 .919 0 r
F
.24903 .68052 m .20591 .66895 L .20703 .67457 L 1 .56 0 r
F
.25001 .68592 m .24903 .68052 L .20703 .67457 L 1 .55 0 r
F
.52652 .14729 m .52343 .14196 L .51109 .14563 L .904 .907 0 r
F
.53884 .14298 m .52343 .14196 L .52652 .14729 L .851 .874 0 r
F
.54262 .14814 m .53884 .14298 L .52652 .14729 L .853 .865 0 r
F
.51109 .14563 m .50875 .14014 L .49668 .14335 L .958 .953 0 r
F
.52343 .14196 m .50875 .14014 L .51109 .14563 L .901 .915 0 r
F
.60972 .15152 m .59218 .1548 L .59719 .15934 L .687 .764 0 r
F
.6152 .15584 m .60972 .15152 L .59719 .15934 L .684 .755 0 r
F
.54967 .45599 m .54981 .45168 L .52161 .45546 L .969 .464 0 r
F
.57765 .45107 m .54981 .45168 L .54967 .45599 L .867 .332 0 r
F
.57765 .45107 m .578 .44657 L .54981 .45168 L F
.24504 .22742 m .24455 .22151 L .23899 .22559 L .714 .32 0 r
F
.24504 .22742 m .24999 .22237 L .24455 .22151 L F
.19981 .62857 m .16036 .61184 L .16099 .61794 L 1 .694 0 r
F
.20049 .63444 m .19981 .62857 L .16099 .61794 L 1 .682 0 r
F
.63347 .41219 m .60842 .41487 L .60771 .42025 L .608 .07 0 r
F
.63347 .41219 m .63446 .4066 L .60842 .41487 L F
.59646 .53696 m .55979 .53396 L .56004 .53807 L 1 .587 0 r
F
.59664 .54126 m .59646 .53696 L .56004 .53807 L 1 .584 0 r
F
.6332 .53776 m .59646 .53696 L .59664 .54126 L .914 .456 0 r
F
.6332 .53776 m .63314 .5333 L .59646 .53696 L F
.4646 .82597 m .46457 .82161 L .42239 .82072 L .907 .115 0 r
F
.50631 .82544 m .46457 .82161 L .4646 .82597 L .846 .074 0 r
F
.50631 .82544 m .50675 .82109 L .46457 .82161 L F
.63409 .80665 m .59467 .80656 L .59342 .81133 L .648 .055 0 r
F
.63409 .80665 m .63576 .80181 L .59467 .80656 L F
.13724 .40192 m .13976 .3953 L .1132 .37751 L 1 1 0 r
F
.57694 .14145 m .56035 .14291 L .56492 .14743 L .743 .828 0 r
F
.58209 .14576 m .57694 .14145 L .56492 .14743 L .741 .82 0 r
F
.54967 .45599 m .52161 .45546 L .52161 .45958 L .969 .464 0 r
F
.33363 .79113 m .29098 .78062 L .29251 .78565 L 1 .332 0 r
F
.33484 .796 m .33363 .79113 L .29251 .78565 L 1 .313 0 r
F
.67767 .7762 m .63967 .77779 L .63819 .78276 L .567 .049 0 r
F
.67767 .7762 m .67951 .77114 L .63967 .77779 L F
.29831 .70807 m .25321 .70193 L .25437 .70721 L 1 .491 0 r
F
.29911 .71327 m .29831 .70807 L .25437 .70721 L 1 .483 0 r
F
.81803 .60999 m .78444 .61726 L .78393 .62363 L .364 .049 0 r
F
.81803 .60999 m .81862 .60352 L .78444 .61726 L F
.57689 .1416 m .56032 .14303 L .56488 .14756 L .741 .825 0 r
F
.58203 .14593 m .57689 .1416 L .56488 .14756 L .739 .817 0 r
F
.72464 .74172 m .68777 .74487 L .68625 .75025 L .491 .046 0 r
F
.72464 .74172 m .72646 .73624 L .68777 .74487 L F
.14887 .55801 m .11628 .53616 L .11574 .54283 L 1 .897 0 r
F
.14848 .5646 m .14887 .55801 L .11574 .54283 L 1 .885 0 r
F
.69989 .46943 m .66783 .47449 L .66792 .47945 L .658 .216 0 r
F
.69989 .46943 m .69977 .46432 L .66783 .47449 L F
.55956 .52985 m .52518 .52537 L .52537 .52923 L 1 .701 0 r
F
.55979 .53396 m .55956 .52985 L .52537 .52923 L 1 .7 0 r
F
.61701 .16803 m .59913 .17125 L .60365 .17646 L .668 .681 0 r
F
.62195 .17304 m .61701 .16803 L .60365 .17646 L .664 .667 0 r
F
.82194 .61824 m .78751 .62527 L .78697 .63172 L .372 .051 0 r
F
.82194 .61824 m .82254 .61167 L .78751 .62527 L F
.18873 .66089 m .15086 .64238 L .15165 .6487 L 1 .698 0 r
F
.18951 .66707 m .18873 .66089 L .15165 .6487 L 1 .683 0 r
F
.3701 .15562 m .3631 .14597 L .35773 .14978 L 1 1 0 r
F
.3701 .15562 m .37486 .15141 L .3631 .14597 L F
.4217 .82554 m .37845 .8188 L .37939 .82341 L .972 .184 0 r
F
.42219 .83003 m .4217 .82554 L .37939 .82341 L .964 .165 0 r
F
.4645 .8308 m .4217 .82554 L .42219 .83003 L .911 .125 0 r
F
.68414 .32189 m .6644 .32514 L .66462 .33218 L .359 .058 0 r
F
.68414 .32189 m .68395 .31479 L .6644 .32514 L F
.43526 .6228 m .39757 .62947 L .39621 .63681 L .845 .674 0 r
F
.43453 .62985 m .43526 .6228 L .39621 .63681 L .85 .664 0 r
F
.58028 .15125 m .56346 .15264 L .56775 .15772 L .747 .778 0 r
F
.5851 .15612 m .58028 .15125 L .56775 .15772 L .746 .767 0 r
F
.15935 .53661 m .12606 .51538 L .12546 .52188 L 1 .891 0 r
F
.15896 .54299 m .15935 .53661 L .12546 .52188 L 1 .88 0 r
F
.24972 .22205 m .23876 .20398 L .2334 .20878 L 1 1 0 r
F
.24972 .22205 m .25465 .21697 L .23876 .20398 L F
.31095 .21364 m .30505 .20685 L .29939 .20988 L .932 1 0 r
F
.31095 .21364 m .31585 .20962 L .30505 .20685 L F
.42981 .69869 m .38943 .70378 L .3893 .70983 L .912 .534 0 r
F
.42981 .69869 m .43005 .69222 L .38943 .70378 L F
.28671 .76513 m .24478 .75239 L .2464 .75779 L 1 .425 0 r
F
.28808 .77036 m .28671 .76513 L .2464 .75779 L 1 .407 0 r
F
.23488 .73467 m .19335 .71956 L .19491 .72544 L 1 .522 0 r
F
.23626 .74038 m .23488 .73467 L .19491 .72544 L 1 .506 0 r
F
.37028 .15618 m .36337 .14678 L .35799 .15056 L 1 1 0 r
F
.37028 .15618 m .37502 .15198 L .36337 .14678 L F
.23773 .72457 m .1972 .70919 L .19862 .71503 L 1 .544 0 r
F
.239 .73025 m .23773 .72457 L .19862 .71503 L 1 .527 0 r
F
.84871 .48785 m .81773 .49775 L .81878 .50451 L .349 .067 0 r
F
.84871 .48785 m .84754 .48105 L .81773 .49775 L F
.24999 .22237 m .25027 .21766 L .24455 .22151 L .653 .225 0 r
F
.24999 .22237 m .25504 .21744 L .25027 .21766 L F
.72267 .39801 m .69646 .40467 L .69697 .41038 L .473 .105 0 r
F
.72267 .39801 m .72202 .39225 L .69646 .40467 L F
.33154 .17049 m .32408 .15815 L .31841 .16213 L 1 1 0 r
F
.33154 .17049 m .33668 .16615 L .32408 .15815 L F
.58004 .15195 m .56332 .15315 L .56758 .15831 L .74 .765 0 r
F
.58482 .15694 m .58004 .15195 L .56758 .15831 L .737 .752 0 r
F
.47798 .32261 m .47197 .15181 L .47184 .15861 L 0 0 0 r
F
.47806 .33102 m .47798 .32261 L .47184 .15861 L F
.84405 .48105 m .81383 .49092 L .81488 .49761 L .343 .066 0 r
F
.84405 .48105 m .84291 .47431 L .81383 .49092 L F
.66078 .17224 m .64204 .17821 L .64721 .18296 L .607 .665 0 r
F
.66634 .17677 m .66078 .17224 L .64721 .18296 L .603 .654 0 r
F
.13724 .40192 m .1132 .37751 L .11044 .38409 L 1 1 0 r
F
.13481 .40856 m .13724 .40192 L .11044 .38409 L F
.55979 .53396 m .52537 .52923 L .52558 .5331 L 1 .7 0 r
F
.56004 .53807 m .55979 .53396 L .52558 .5331 L 1 .698 0 r
F
.66049 .37947 m .63816 .3826 L .63732 .38884 L .447 .054 0 r
F
.66049 .37947 m .66155 .37306 L .63816 .3826 L F
.77246 .69139 m .73702 .69638 L .73574 .70223 L .413 .044 0 r
F
.77246 .69139 m .77394 .68543 L .73702 .69638 L F
.5241 .13764 m .52084 .13292 L .50923 .13571 L .85 .926 0 r
F
.53573 .13402 m .52084 .13292 L .5241 .13764 L .817 .903 0 r
F
.53972 .13858 m .53573 .13402 L .5241 .13764 L .818 .896 0 r
F
.66818 .51778 m .6329 .51981 L .63299 .52432 L .797 .332 0 r
F
.66818 .51778 m .66819 .5131 L .6329 .51981 L F
.52409 .13768 m .52083 .13297 L .50923 .13573 L .848 .924 0 r
F
.53572 .13409 m .52083 .13297 L .52409 .13768 L .816 .901 0 r
F
.5397 .13866 m .53572 .13409 L .52409 .13768 L .817 .895 0 r
F
.59664 .54126 m .56004 .53807 L .56028 .5422 L 1 .584 0 r
F
.59682 .54557 m .59664 .54126 L .56028 .5422 L 1 .58 0 r
F
.63326 .54222 m .59664 .54126 L .59682 .54557 L .91 .451 0 r
F
.63326 .54222 m .6332 .53776 L .59664 .54126 L F
.6605 .17269 m .64184 .17857 L .64699 .18333 L .602 .66 0 r
F
.66604 .17724 m .6605 .17269 L .64699 .18333 L .598 .649 0 r
F
.61622 .16973 m .59862 .17249 L .60303 .17787 L .647 .647 0 r
F
.621 .17498 m .61622 .16973 L .60303 .17787 L .641 .629 0 r
F
.54752 .82353 m .50675 .82109 L .50631 .82544 L .777 .066 0 r
F
.54752 .82353 m .54843 .81917 L .50675 .82109 L F
.50923 .13571 m .50676 .13089 L .49547 .13292 L .879 .955 0 r
F
.52084 .13292 m .50676 .13089 L .50923 .13571 L .848 .931 0 r
F
.50923 .13573 m .50676 .13091 L .49547 .13292 L .878 .954 0 r
F
.52083 .13297 m .50676 .13091 L .50923 .13573 L .847 .93 0 r
F
.72646 .75106 m .68911 .75384 L .68755 .7593 L .501 .047 0 r
F
.72646 .75106 m .72832 .7455 L .68911 .75384 L F
.37889 .80934 m .33609 .8008 L .33738 .80553 L 1 .248 0 r
F
.37979 .81393 m .37889 .80934 L .33738 .80553 L 1 .229 0 r
F
.3319 .1713 m .32452 .15912 L .31892 .1632 L 1 1 0 r
F
.3319 .1713 m .33702 .16693 L .32452 .15912 L F
.54954 .46021 m .52161 .45958 L .52161 .46363 L .963 .46 0 r
F
.54954 .46021 m .54967 .45599 L .52161 .45958 L F
.14025 .58006 m .10568 .55812 L .1055 .56493 L 1 .852 0 r
F
.14019 .58676 m .14025 .58006 L .1055 .56493 L 1 .839 0 r
F
.28511 .77505 m .24246 .76264 L .24418 .76805 L 1 .406 0 r
F
.28655 .7803 m .28511 .77505 L .24418 .76805 L 1 .388 0 r
F
.25465 .21697 m .2442 .19927 L .23876 .20398 L 1 1 0 r
F
.25465 .21697 m .25964 .21196 L .2442 .19927 L F
.33276 .80079 m .28961 .7906 L .29122 .79565 L 1 .316 0 r
F
.33402 .80569 m .33276 .80079 L .29122 .79565 L 1 .297 0 r
F
.35567 .19925 m .35324 .20477 L .34811 .20721 L 0 0 0 r
F
.35567 .19925 m .36012 .19549 L .35324 .20477 L F
.57731 .45546 m .54967 .45599 L .54954 .46021 L .862 .328 0 r
F
.57731 .45546 m .57765 .45107 L .54967 .45599 L F
.77524 .70044 m .73913 .70507 L .73781 .711 L .426 .046 0 r
F
.77524 .70044 m .77675 .69439 L .73913 .70507 L F
.56004 .53807 m .52558 .5331 L .52579 .537 L 1 .698 0 r
F
.56028 .5422 m .56004 .53807 L .52579 .537 L 1 .696 0 r
F
.67878 .78562 m .64046 .78687 L .63894 .79192 L .574 .05 0 r
F
.67878 .78562 m .68067 .78049 L .64046 .78687 L F
.55468 .14273 m .53889 .14273 L .54269 .14783 L .804 .84 0 r
F
.5591 .14764 m .55468 .14273 L .54269 .14783 L .804 .831 0 r
F
.69997 .4745 m .66792 .47945 L .668 .48437 L .657 .212 0 r
F
.69997 .4745 m .69989 .46943 L .66792 .47945 L F
.60501 .44026 m .57837 .44197 L .578 .44657 L .745 .185 0 r
F
.60501 .44026 m .60566 .43546 L .57837 .44197 L F
.30256 .23509 m .31749 .25864 L .30476 .25041 L .343 .016 0 r
F
.30256 .23509 m .30795 .23211 L .31749 .25864 L F
.13481 .40856 m .11044 .38409 L .10777 .3907 L 1 1 0 r
F
.13247 .41523 m .13481 .40856 L .10777 .3907 L F
.34533 .71928 m .29995 .71845 L .30084 .7236 L 1 .475 0 r
F
.34574 .72465 m .34533 .71928 L .30084 .7236 L 1 .465 0 r
F
.38923 .71577 m .34533 .71928 L .34574 .72465 L .959 .493 0 r
F
.38923 .71577 m .3893 .70983 L .34533 .71928 L F
.25504 .21744 m .25603 .21391 L .25027 .21766 L .583 .215 0 r
F
.25504 .21744 m .2602 .21266 L .25603 .21391 L F
.50876 .14006 m .49514 .13769 L .49668 .14335 L .956 .964 0 r
F
.50875 .14014 m .49514 .13769 L .49668 .14335 L .953 .96 0 r
F
.55459 .1431 m .53884 .14298 L .54262 .14814 L .8 .833 0 r
F
.55899 .14807 m .55459 .1431 L .54262 .14814 L .8 .822 0 r
F
.5891 .81585 m .54932 .81473 L .54843 .81917 L .707 .059 0 r
F
.5891 .81585 m .59044 .81136 L .54932 .81473 L F
.18472 .67707 m .14557 .65881 L .14662 .66517 L 1 .66 0 r
F
.18571 .68327 m .18472 .67707 L .14662 .66517 L 1 .645 0 r
F
.59682 .54557 m .56028 .5422 L .56053 .54634 L 1 .58 0 r
F
.597 .54988 m .59682 .54557 L .56053 .54634 L 1 .575 0 r
F
.6333 .54667 m .59682 .54557 L .597 .54988 L .906 .446 0 r
F
.6333 .54667 m .63326 .54222 L .59682 .54557 L F
.14848 .5646 m .11574 .54283 L .11529 .5495 L 1 .885 0 r
F
.14818 .57118 m .14848 .5646 L .11529 .5495 L 1 .874 0 r
F
.61199 .1631 m .59453 .16613 L .59913 .17125 L .672 .693 0 r
F
.61701 .16803 m .61199 .1631 L .59913 .17125 L .668 .681 0 r
F
.60427 .14703 m .5872 .15015 L .59226 .1546 L .692 .776 0 r
F
.60982 .15126 m .60427 .14703 L .59226 .1546 L .689 .767 0 r
F
.46453 .8352 m .4645 .8308 L .42219 .83003 L .903 .107 0 r
F
.50634 .83465 m .4645 .8308 L .46453 .8352 L .843 .073 0 r
F
.50634 .83465 m .50679 .83024 L .4645 .8308 L F
.42961 .70505 m .3893 .70983 L .38923 .71577 L .916 .517 0 r
F
.42961 .70505 m .42981 .69869 L .3893 .70983 L F
.72326 .4037 m .69697 .41038 L .69743 .41602 L .472 .098 0 r
F
.72326 .4037 m .72267 .39801 L .69697 .41038 L F
.60418 .14727 m .58713 .15033 L .59218 .1548 L .69 .773 0 r
F
.60972 .15152 m .60418 .14727 L .59218 .1548 L .687 .764 0 r
F
.56028 .5422 m .52579 .537 L .52601 .54092 L 1 .696 0 r
F
.56053 .54634 m .56028 .5422 L .52601 .54092 L 1 .693 0 r
F
.66815 .52244 m .63299 .52432 L .63306 .52882 L .794 .327 0 r
F
.66815 .52244 m .66818 .51778 L .63299 .52432 L F
.84977 .49466 m .81878 .50451 L .81974 .51126 L .345 .065 0 r
F
.84977 .49466 m .84871 .48785 L .81878 .50451 L F
.15896 .54299 m .12546 .52188 L .12496 .52838 L 1 .88 0 r
F
.15866 .54936 m .15896 .54299 L .12496 .52838 L 1 .868 0 r
F
.84509 .48778 m .81488 .49761 L .81583 .5043 L .339 .064 0 r
F
.84509 .48778 m .84405 .48105 L .81488 .49761 L F
.25964 .21196 m .2497 .19465 L .2442 .19927 L 1 1 0 r
F
.25964 .21196 m .2647 .20702 L .2497 .19465 L F
.65515 .16778 m .6368 .17354 L .64204 .17821 L .612 .676 0 r
F
.66078 .17224 m .65515 .16778 L .64204 .17821 L .607 .665 0 r
F
.20049 .63444 m .16099 .61794 L .1617 .62401 L 1 .682 0 r
F
.20123 .64028 m .20049 .63444 L .1617 .62401 L 1 .67 0 r
F
.43526 .6228 m .43602 .61584 L .39757 .62947 L .845 .674 0 r
F
.68407 .32898 m .66462 .33218 L .6646 .33918 L .347 .053 0 r
F
.68407 .32898 m .68414 .32189 L .66462 .33218 L F
.63247 .41761 m .60771 .42025 L .60701 .42547 L .6 .069 0 r
F
.63247 .41761 m .63347 .41219 L .60771 .42025 L F
.54942 .46435 m .52161 .46363 L .52161 .46762 L .958 .456 0 r
F
.54942 .46435 m .54954 .46021 L .52161 .46363 L F
.81734 .61643 m .78393 .62363 L .78332 .62997 L .36 .047 0 r
F
.81734 .61643 m .81803 .60999 L .78393 .62363 L F
.6549 .16822 m .63662 .17388 L .64184 .17857 L .607 .67 0 r
F
.6605 .17269 m .6549 .16822 L .64184 .17857 L .602 .66 0 r
F
.55108 .13408 m .53573 .13402 L .53972 .13858 L .783 .874 0 r
F
.55573 .13846 m .55108 .13408 L .53972 .13858 L .783 .866 0 r
F
.36206 .18499 m .35772 .18531 L .35213 .18714 L .577 .223 0 r
F
.36206 .18499 m .3667 .18142 L .35772 .18531 L F
.25001 .68592 m .20703 .67457 L .20822 .68016 L 1 .55 0 r
F
.25103 .69129 m .25001 .68592 L .20822 .68016 L 1 .54 0 r
F
.31585 .20962 m .31078 .20405 L .30505 .20685 L .845 .912 0 r
F
.31585 .20962 m .32081 .20575 L .31078 .20405 L F
.55106 .13417 m .53572 .13409 L .5397 .13866 L .782 .872 0 r
F
.55571 .13857 m .55106 .13417 L .5397 .13866 L .782 .865 0 r
F
.63176 .80197 m .59301 .80217 L .59175 .8068 L .635 .053 0 r
F
.63176 .80197 m .63344 .79728 L .59301 .80217 L F
.13247 .41523 m .10777 .3907 L .10521 .39735 L 1 1 0 r
F
.13023 .42192 m .13247 .41523 L .10521 .39735 L F
.82124 .62477 m .78697 .63172 L .78635 .63814 L .369 .049 0 r
F
.82124 .62477 m .82194 .61824 L .78697 .63172 L F
.61133 .1646 m .59411 .16721 L .59862 .17249 L .654 .664 0 r
F
.61622 .16973 m .61133 .1646 L .59862 .17249 L .647 .647 0 r
F
.2602 .21266 m .26119 .20947 L .25603 .21391 L .562 .214 0 r
F
.2602 .21266 m .26546 .20803 L .26119 .20947 L F
.56053 .54634 m .52601 .54092 L .52623 .54487 L 1 .693 0 r
F
.56079 .5505 m .56053 .54634 L .52623 .54487 L 1 .691 0 r
F
.597 .54988 m .56053 .54634 L .56079 .5505 L 1 .575 0 r
F
.33668 .16615 m .3298 .15428 L .32408 .15815 L 1 1 0 r
F
.33668 .16615 m .34187 .16191 L .3298 .15428 L F
.59718 .55419 m .597 .54988 L .56079 .5505 L 1 .57 0 r
F
.63334 .5511 m .597 .54988 L .59718 .55419 L .901 .44 0 r
F
.63334 .5511 m .6333 .54667 L .597 .54988 L F
.37845 .8188 m .33533 .81052 L .33667 .81527 L 1 .235 0 r
F
.37939 .82341 m .37845 .8188 L .33667 .81527 L 1 .215 0 r
F
.18951 .66707 m .15165 .6487 L .15254 .655 L 1 .683 0 r
F
.19036 .67321 m .18951 .66707 L .15254 .655 L 1 .668 0 r
F
.17546 .34898 m .17863 .34292 L .15499 .32617 L 1 1 0 r
F
.57699 .45975 m .54954 .46021 L .54942 .46435 L .856 .325 0 r
F
.57699 .45975 m .57731 .45546 L .54954 .46021 L F
.29911 .71327 m .25437 .70721 L .25557 .71245 L 1 .483 0 r
F
.29995 .71845 m .29911 .71327 L .25557 .71245 L 1 .474 0 r
F
.42239 .82072 m .37979 .81393 L .38073 .81844 L .97 .176 0 r
F
.42289 .82511 m .42239 .82072 L .38073 .81844 L .962 .157 0 r
F
.4646 .82597 m .42239 .82072 L .42289 .82511 L .907 .115 0 r
F
.70004 .47953 m .668 .48437 L .66806 .48924 L .655 .208 0 r
F
.70004 .47953 m .69997 .4745 L .668 .48437 L F
.57538 .14646 m .5591 .14764 L .56346 .15264 L .749 .789 0 r
F
.58028 .15125 m .57538 .14646 L .56346 .15264 L .747 .778 0 r
F
.57174 .13721 m .55573 .13846 L .56035 .14291 L .744 .836 0 r
F
.57694 .14145 m .57174 .13721 L .56035 .14291 L .743 .828 0 r
F
.5717 .13735 m .55571 .13857 L .56032 .14303 L .743 .834 0 r
F
.57689 .1416 m .5717 .13735 L .56032 .14303 L .741 .825 0 r
F
.50676 .13089 m .49383 .12803 L .49547 .13292 L .878 .961 0 r
F
.50676 .13091 m .49383 .12803 L .49547 .13292 L .876 .96 0 r
F
.37486 .15141 m .36852 .14227 L .3631 .14597 L 1 1 0 r
F
.37486 .15141 m .37965 .14729 L .36852 .14227 L F
.54766 .8328 m .50679 .83024 L .50634 .83465 L .776 .066 0 r
F
.54766 .8328 m .54859 .82838 L .50679 .83024 L F
.52346 .1418 m .52031 .13659 L .50876 .14006 L .903 .919 0 r
F
.53504 .1377 m .52031 .13659 L .52346 .1418 L .852 .887 0 r
F
.53889 .14273 m .53504 .1377 L .52346 .1418 L .854 .879 0 r
F
.69625 .2393 m .67658 .24528 L .67993 .2513 L .459 .345 0 r
F
.69972 .24528 m .67993 .2513 L .68316 .25737 L .447 .321 0 r
F
.69972 .24528 m .69625 .2393 L .67993 .2513 L F
.2647 .20702 m .25526 .19011 L .2497 .19465 L 1 1 0 r
F
.2647 .20702 m .26981 .20216 L .25526 .19011 L F
.70302 .25132 m .68316 .25737 L .68625 .26349 L .434 .296 0 r
F
.70302 .25132 m .69972 .24528 L .68316 .25737 L F
.17546 .34898 m .15499 .32617 L .15154 .33216 L 1 1 0 r
F
.69264 .23339 m .67309 .23932 L .67658 .24528 L .471 .369 0 r
F
.69625 .2393 m .69264 .23339 L .67658 .24528 L .459 .345 0 r
F
.52343 .14196 m .5203 .13672 L .50875 .14014 L .901 .915 0 r
F
.53501 .13791 m .5203 .13672 L .52343 .14196 L .849 .883 0 r
F
.53884 .14298 m .53501 .13791 L .52343 .14196 L .851 .874 0 r
F
.33702 .16693 m .33019 .15518 L .32452 .15912 L 1 1 0 r
F
.33702 .16693 m .34218 .16267 L .33019 .15518 L F
.57519 .14706 m .55899 .14807 L .56332 .15315 L .742 .777 0 r
F
.58004 .15195 m .57519 .14706 L .56332 .15315 L .74 .765 0 r
F
.70617 .25741 m .68625 .26349 L .6892 .26964 L .421 .27 0 r
F
.70617 .25741 m .70302 .25132 L .68625 .26349 L F
.14019 .58676 m .1055 .56493 L .10543 .57172 L 1 .839 0 r
F
.14022 .59343 m .14019 .58676 L .10543 .57172 L 1 .827 0 r
F
.56079 .5505 m .52623 .54487 L .52647 .54886 L 1 .691 0 r
F
.56105 .55469 m .56079 .5505 L .52647 .54886 L 1 .687 0 r
F
.59718 .55419 m .56079 .5505 L .56105 .55469 L 1 .57 0 r
F
.66811 .52707 m .63306 .52882 L .63314 .5333 L .79 .321 0 r
F
.66811 .52707 m .66815 .52244 L .63306 .52882 L F
.68887 .22754 m .66947 .23341 L .67309 .23932 L .483 .392 0 r
F
.69264 .23339 m .68887 .22754 L .67309 .23932 L .471 .369 0 r
F
.37502 .15198 m .36879 .14313 L .36337 .14678 L 1 1 0 r
F
.37502 .15198 m .37981 .14787 L .36879 .14313 L F
.72379 .40935 m .69743 .41602 L .69784 .42161 L .47 .092 0 r
F
.72379 .40935 m .72326 .4037 L .69743 .41602 L F
.50876 .14006 m .50638 .13468 L .49514 .13769 L .956 .964 0 r
F
.52031 .13659 m .50638 .13468 L .50876 .14006 L .899 .927 0 r
F
.13023 .42192 m .10521 .39735 L .10275 .40402 L 1 1 0 r
F
.12807 .42863 m .13023 .42192 L .10275 .40402 L F
.65935 .38573 m .63732 .38884 L .6364 .39493 L .434 .051 0 r
F
.65935 .38573 m .66049 .37947 L .63732 .38884 L F
.70917 .26355 m .6892 .26964 L .69201 .27583 L .407 .245 0 r
F
.70917 .26355 m .70617 .25741 L .6892 .26964 L F
.50875 .14014 m .50637 .13474 L .49514 .13769 L .953 .96 0 r
F
.5203 .13672 m .50637 .13474 L .50875 .14014 L .897 .923 0 r
F
.5493 .46843 m .52161 .46762 L .52161 .47156 L .952 .452 0 r
F
.5493 .46843 m .54942 .46435 L .52161 .46762 L F
.6044 .44492 m .578 .44657 L .57765 .45107 L .739 .181 0 r
F
.6044 .44492 m .60501 .44026 L .578 .44657 L F
.72276 .74713 m .68625 .75025 L .68466 .75556 L .483 .043 0 r
F
.72276 .74713 m .72464 .74172 L .68625 .75025 L F
.68495 .22177 m .66572 .22756 L .66947 .23341 L .494 .415 0 r
F
.68887 .22754 m .68495 .22177 L .66947 .23341 L .483 .392 0 r
F
.85073 .50147 m .81974 .51126 L .82061 .51801 L .341 .063 0 r
F
.85073 .50147 m .84977 .49466 L .81974 .51126 L F
.84602 .49452 m .81583 .5043 L .81669 .51099 L .334 .062 0 r
F
.84602 .49452 m .84509 .48778 L .81583 .5043 L F
.58941 .8252 m .5495 .82387 L .54859 .82838 L .709 .059 0 r
F
.58941 .8252 m .59079 .82065 L .5495 .82387 L F
.38924 .7216 m .38923 .71577 L .34574 .72465 L .964 .479 0 r
F
.42947 .71128 m .38923 .71577 L .38924 .7216 L .919 .499 0 r
F
.42947 .71128 m .42961 .70505 L .38923 .71577 L F
.64947 .1634 m .63152 .16894 L .6368 .17354 L .617 .686 0 r
F
.65515 .16778 m .64947 .1634 L .6368 .17354 L .612 .676 0 r
F
.14818 .57118 m .11529 .5495 L .11495 .55616 L 1 .874 0 r
F
.14797 .57775 m .14818 .57118 L .11495 .55616 L 1 .861 0 r
F
.60688 .15826 m .58986 .16108 L .59453 .16613 L .676 .706 0 r
F
.61199 .1631 m .60688 .15826 L .59453 .16613 L .672 .693 0 r
F
.7709 .6973 m .73574 .70223 L .73438 .70803 L .406 .042 0 r
F
.7709 .6973 m .77246 .69139 L .73574 .70223 L F
.71201 .26972 m .69201 .27583 L .69468 .28204 L .394 .219 0 r
F
.71201 .26972 m .70917 .26355 L .69201 .27583 L F
.59735 .55851 m .59718 .55419 L .56105 .55469 L 1 .565 0 r
F
.63336 .55553 m .59718 .55419 L .59735 .55851 L .897 .433 0 r
F
.63336 .55553 m .63334 .5511 L .59718 .55419 L F
.239 .73025 m .19862 .71503 L .20012 .72082 L 1 .527 0 r
F
.24035 .73586 m .239 .73025 L .20012 .72082 L 1 .51 0 r
F
.26546 .20803 m .26416 .20207 L .26119 .20947 L .711 .523 0 r
F
.26546 .20803 m .2708 .20352 L .26416 .20207 L F
.23626 .74038 m .19491 .72544 L .19655 .73126 L 1 .506 0 r
F
.23771 .74603 m .23626 .74038 L .19655 .73126 L 1 .488 0 r
F
.6809 .21607 m .66185 .22177 L .66572 .22756 L .504 .437 0 r
F
.68495 .22177 m .6809 .21607 L .66572 .22756 L .494 .415 0 r
F
.15866 .54936 m .12496 .52838 L .12455 .53487 L 1 .868 0 r
F
.15845 .55571 m .15866 .54936 L .12455 .53487 L 1 .856 0 r
F
.64924 .16382 m .63135 .16926 L .63662 .17388 L .612 .681 0 r
F
.6549 .16822 m .64924 .16382 L .63662 .17388 L .607 .67 0 r
F
.56105 .55469 m .52647 .54886 L .52671 .55289 L 1 .687 0 r
F
.56131 .55889 m .56105 .55469 L .52671 .55289 L 1 .684 0 r
F
.59735 .55851 m .56105 .55469 L .56131 .55889 L 1 .565 0 r
F
.67577 .78119 m .63819 .78276 L .63666 .78767 L .559 .047 0 r
F
.67577 .78119 m .67767 .7762 L .63819 .78276 L F
.47798 .32261 m .47805 .30943 L .47197 .15181 L 0 0 0 r
F
.36012 .19549 m .35858 .20298 L .35324 .20477 L F
.36012 .19549 m .36463 .19193 L .35858 .20298 L F
.33484 .796 m .29251 .78565 L .2941 .79061 L 1 .313 0 r
F
.33609 .8008 m .33484 .796 L .2941 .79061 L 1 .294 0 r
F
.26981 .20216 m .26088 .18565 L .25526 .19011 L 1 1 0 r
F
.26981 .20216 m .27499 .19738 L .26088 .18565 L F
.34574 .72465 m .30084 .7236 L .30178 .72871 L 1 .465 0 r
F
.3462 .72996 m .34574 .72465 L .30178 .72871 L 1 .454 0 r
F
.38924 .7216 m .34574 .72465 L .3462 .72996 L .964 .479 0 r
F
.71469 .27593 m .69468 .28204 L .69722 .28828 L .382 .194 0 r
F
.71469 .27593 m .71201 .26972 L .69468 .28204 L F
.30795 .23211 m .32636 .26214 L .31749 .25864 L .385 .032 0 r
F
.30795 .23211 m .31328 .22918 L .32636 .26214 L F
.63236 .81141 m .59342 .81133 L .59212 .81603 L .639 .053 0 r
F
.63236 .81141 m .63409 .80665 L .59342 .81133 L F
.28808 .77036 m .2464 .75779 L .24808 .76312 L 1 .407 0 r
F
.2895 .77552 m .28808 .77036 L .24808 .76312 L 1 .389 0 r
F
.6767 .21046 m .65785 .21606 L .66185 .22177 L .514 .458 0 r
F
.6809 .21607 m .6767 .21046 L .66185 .22177 L .504 .437 0 r
F
.59867 .14288 m .58209 .14576 L .5872 .15015 L .695 .785 0 r
F
.60427 .14703 m .59867 .14288 L .5872 .15015 L .692 .776 0 r
F
.70008 .48452 m .66806 .48924 L .66811 .49408 L .653 .204 0 r
F
.70008 .48452 m .70004 .47953 L .66806 .48924 L F
.57669 .46395 m .54942 .46435 L .5493 .46843 L .851 .321 0 r
F
.57669 .46395 m .57699 .45975 L .54942 .46435 L F
.68374 .33602 m .6646 .33918 L .66436 .34614 L .335 .047 0 r
F
.68374 .33602 m .68407 .32898 L .6646 .33918 L F
.60633 .15957 m .58951 .16203 L .59411 .16721 L .659 .68 0 r
F
.61133 .1646 m .60633 .15957 L .59411 .16721 L .654 .664 0 r
F
.59858 .1431 m .58203 .14593 L .58713 .15033 L .693 .782 0 r
F
.60418 .14727 m .59858 .1431 L .58713 .15033 L .69 .773 0 r
F
.77364 .70644 m .73781 .711 L .73643 .71688 L .418 .044 0 r
F
.77364 .70644 m .77524 .70044 L .73781 .711 L F
.12807 .42863 m .10275 .40402 L .10039 .41072 L 1 1 0 r
F
.12602 .43536 m .12807 .42863 L .10039 .41072 L F
.32081 .20575 m .31661 .20153 L .31078 .20405 L .723 .722 0 r
F
.32081 .20575 m .32583 .20205 L .31661 .20153 L F
.46463 .83024 m .4646 .82597 L .42289 .82511 L .899 .097 0 r
F
.50585 .82971 m .4646 .82597 L .46463 .83024 L .837 .072 0 r
F
.50585 .82971 m .50631 .82544 L .4646 .82597 L F
.56131 .55889 m .52671 .55289 L .52696 .55695 L 1 .684 0 r
F
.56157 .56312 m .56131 .55889 L .52696 .55695 L 1 .679 0 r
F
.59752 .56284 m .56131 .55889 L .56157 .56312 L .997 .559 0 r
F
.59752 .56284 m .59735 .55851 L .56131 .55889 L F
.66805 .53168 m .63314 .5333 L .6332 .53776 L .786 .316 0 r
F
.66805 .53168 m .66811 .52707 L .63314 .5333 L F
.18571 .68327 m .14662 .66517 L .14776 .67151 L 1 .645 0 r
F
.18678 .68943 m .18571 .68327 L .14776 .67151 L 1 .629 0 r
F
.43602 .61584 m .4368 .60901 L .39907 .62205 L .842 .683 0 r
F
.54919 .47243 m .52161 .47156 L .52161 .47544 L .946 .447 0 r
F
.54919 .47243 m .5493 .46843 L .52161 .47156 L F
.71722 .28216 m .69722 .28828 L .69962 .29453 L .374 .169 0 r
F
.71722 .28216 m .71469 .27593 L .69722 .28828 L F
.72453 .75656 m .68755 .7593 L .68593 .76469 L .493 .044 0 r
F
.72453 .75656 m .72646 .75106 L .68755 .7593 L F
.20123 .64028 m .1617 .62401 L .1625 .63006 L 1 .67 0 r
F
.20204 .64608 m .20123 .64028 L .1625 .63006 L 1 .657 0 r
F
.5502 .13791 m .53504 .1377 L .53889 .14273 L .803 .849 0 r
F
.55468 .14273 m .5502 .13791 L .53889 .14273 L .804 .84 0 r
F
.81655 .62284 m .78332 .62997 L .78263 .63628 L .356 .045 0 r
F
.81655 .62284 m .81734 .61643 L .78332 .62997 L F
.63149 .42286 m .60701 .42547 L .60632 .43054 L .593 .068 0 r
F
.63149 .42286 m .63247 .41761 L .60701 .42547 L F
.72428 .41494 m .69784 .42161 L .6982 .42714 L .469 .087 0 r
F
.72428 .41494 m .72379 .40935 L .69784 .42161 L F
.52084 .13292 m .51755 .12827 L .50676 .13089 L .848 .931 0 r
F
.5317 .12952 m .51755 .12827 L .52084 .13292 L .817 .909 0 r
F
.53573 .13402 m .5317 .12952 L .52084 .13292 L .817 .903 0 r
F
.63338 .55996 m .59735 .55851 L .59752 .56284 L .892 .426 0 r
F
.63338 .55996 m .63336 .55553 L .59735 .55851 L F
.52083 .13297 m .51754 .12831 L .50676 .13091 L .847 .93 0 r
F
.53169 .12958 m .51754 .12831 L .52083 .13297 L .816 .908 0 r
F
.53572 .13409 m .53169 .12958 L .52083 .13297 L .816 .901 0 r
F
.67236 .20492 m .65374 .21041 L .65785 .21606 L .523 .479 0 r
F
.6767 .21046 m .67236 .20492 L .65785 .21606 L .514 .458 0 r
F
.55013 .13821 m .53501 .13791 L .53884 .14298 L .8 .843 0 r
F
.55459 .1431 m .55013 .13821 L .53884 .14298 L .8 .833 0 r
F
.34187 .16191 m .33558 .15052 L .3298 .15428 L 1 1 0 r
F
.34187 .16191 m .34711 .15776 L .33558 .15052 L F
.42219 .83003 m .37939 .82341 L .38036 .82795 L .964 .165 0 r
F
.42271 .83445 m .42219 .83003 L .38036 .82795 L .955 .146 0 r
F
.46453 .8352 m .42219 .83003 L .42271 .83445 L .903 .107 0 r
F
.82045 .63128 m .78635 .63814 L .78564 .64453 L .365 .047 0 r
F
.82045 .63128 m .82124 .62477 L .78635 .63814 L F
.2708 .20352 m .26635 .19332 L .26416 .20207 L 1 1 0 r
F
.2708 .20352 m .27613 .19902 L .26635 .19332 L F
.28655 .7803 m .24418 .76805 L .24597 .77341 L 1 .388 0 r
F
.28805 .78548 m .28655 .7803 L .24597 .77341 L 1 .369 0 r
F
.85158 .50829 m .82061 .51801 L .82138 .52477 L .337 .061 0 r
F
.85158 .50829 m .85073 .50147 L .82061 .51801 L F
.23281 .26425 m .22173 .24714 L .21653 .25165 L 1 1 0 r
F
.23281 .26425 m .23743 .25928 L .22173 .24714 L F
.7196 .2884 m .69962 .29453 L .70188 .3008 L .366 .145 0 r
F
.7196 .2884 m .71722 .28216 L .69962 .29453 L F
.56157 .56312 m .52696 .55695 L .52721 .56106 L 1 .679 0 r
F
.56183 .56737 m .56157 .56312 L .52721 .56106 L 1 .675 0 r
F
.59768 .56718 m .56157 .56312 L .56183 .56737 L .992 .553 0 r
F
.59768 .56718 m .59752 .56284 L .56157 .56312 L F
.84685 .50126 m .81669 .51099 L .81746 .51768 L .33 .06 0 r
F
.84685 .50126 m .84602 .49452 L .81669 .51099 L F
.27499 .19738 m .26655 .18128 L .26088 .18565 L 1 1 0 r
F
.27499 .19738 m .28022 .19268 L .26655 .18128 L F
.25103 .69129 m .20822 .68016 L .20947 .68572 L 1 .54 0 r
F
.2521 .69662 m .25103 .69129 L .20947 .68572 L 1 .53 0 r
F
.64373 .1591 m .62617 .16441 L .63152 .16894 L .621 .697 0 r
F
.64947 .1634 m .64373 .1591 L .63152 .16894 L .617 .686 0 r
F
.34218 .16267 m .33594 .15139 L .33019 .15518 L 1 1 0 r
F
.34218 .16267 m .3474 .15851 L .33594 .15139 L F
.3667 .18142 m .36347 .18413 L .35772 .18531 L 0 0 0 r
F
.3667 .18142 m .37139 .17808 L .36347 .18413 L F
.23304 .26446 m .35863 .37514 L .35667 .37749 L .67 .181 0 r
F
.3547 .37985 m .34802 .36856 L .3459 .3709 L 1 1 0 r
F
.35471 .37986 m .3547 .37985 L .3547 .37985 L F
.3547 .37985 m .34802 .36856 L .3547 .37985 L F
.35667 .37749 m .35883 .37601 L .35696 .37775 L .67 .181 0 r
F
.35863 .37514 m .35928 .37571 L .35667 .37749 L F
.3547 .37985 m .35696 .37775 L .34802 .36856 L 1 1 0 r
F
.35471 .37986 m .35696 .37775 L .3547 .37985 L F
.35883 .37601 m .35928 .37571 L .35696 .37775 L .67 .181 0 r
F
.23304 .26446 m .23777 .2596 L .35928 .37571 L F
.14022 .59343 m .10543 .57172 L .10546 .5785 L 1 .827 0 r
F
.14034 .60008 m .14022 .59343 L .10546 .5785 L 1 .813 0 r
F
.50676 .13089 m .50427 .12612 L .49383 .12803 L .878 .961 0 r
F
.51755 .12827 m .50427 .12612 L .50676 .13089 L .847 .937 0 r
F
.50676 .13091 m .50427 .12614 L .49383 .12803 L .876 .96 0 r
F
.51754 .12831 m .50427 .12614 L .50676 .13091 L .846 .936 0 r
F
.6679 .19947 m .64952 .20484 L .65374 .21041 L .532 .498 0 r
F
.67236 .20492 m .6679 .19947 L .65374 .21041 L .523 .479 0 r
F
.67683 .79069 m .63894 .79192 L .63738 .7969 L .566 .047 0 r
F
.67683 .79069 m .67878 .78562 L .63894 .79192 L F
.60381 .44946 m .57765 .45107 L .57731 .45546 L .734 .178 0 r
F
.60381 .44946 m .6044 .44492 L .57765 .45107 L F
.64352 .1595 m .62602 .16472 L .63135 .16926 L .617 .692 0 r
F
.64924 .16382 m .64352 .1595 L .63135 .16926 L .612 .681 0 r
F
.33402 .80569 m .29122 .79565 L .29289 .80063 L 1 .297 0 r
F
.33533 .81052 m .33402 .80569 L .29289 .80063 L 1 .277 0 r
F
.19036 .67321 m .15254 .655 L .15351 .66125 L 1 .668 0 r
F
.1913 .67931 m .19036 .67321 L .15351 .66125 L 1 .653 0 r
F
.4664 .67118 m .43107 .67211 L .43068 .67892 L .925 .608 0 r
F
.46634 .67755 m .43068 .67892 L .43034 .68563 L .92 .587 0 r
F
.46634 .67755 m .4664 .67118 L .43068 .67892 L F
.37979 .81393 m .33738 .80553 L .33872 .81019 L 1 .229 0 r
F
.38073 .81844 m .37979 .81393 L .33872 .81019 L 1 .21 0 r
F
.12602 .43536 m .10039 .41072 L .09814 .41745 L 1 1 0 r
F
.12405 .44211 m .12602 .43536 L .09814 .41745 L F
.57041 .14176 m .55468 .14273 L .5591 .14764 L .75 .799 0 r
F
.57538 .14646 m .57041 .14176 L .5591 .14764 L .749 .789 0 r
F
.50638 .13468 m .49357 .13213 L .49514 .13769 L .95 .969 0 r
F
.50637 .13474 m .49357 .13213 L .49514 .13769 L .947 .966 0 r
F
.46647 .66477 m .43152 .6652 L .43107 .67211 L .93 .629 0 r
F
.4664 .67118 m .46647 .66477 L .43107 .67211 L .925 .608 0 r
F
.14797 .57775 m .11495 .55616 L .1147 .56281 L 1 .861 0 r
F
.14785 .5843 m .14797 .57775 L .1147 .56281 L 1 .849 0 r
F
.38932 .72733 m .38924 .7216 L .3462 .72996 L .968 .464 0 r
F
.42937 .7174 m .38924 .7216 L .38932 .72733 L .921 .481 0 r
F
.42937 .7174 m .42947 .71128 L .38924 .7216 L F
.54658 .82782 m .50631 .82544 L .50585 .82971 L .768 .064 0 r
F
.54658 .82782 m .54752 .82353 L .50631 .82544 L F
.60169 .15351 m .5851 .15612 L .58986 .16108 L .679 .719 0 r
F
.60688 .15826 m .60169 .15351 L .58986 .16108 L .676 .706 0 r
F
.46627 .68389 m .43034 .68563 L .43005 .69222 L .916 .565 0 r
F
.46627 .68389 m .46634 .67755 L .43034 .68563 L F
.54909 .47637 m .52161 .47544 L .52161 .47927 L .941 .442 0 r
F
.54909 .47637 m .54919 .47243 L .52161 .47544 L F
.15845 .55571 m .12455 .53487 L .12425 .54134 L 1 .856 0 r
F
.15832 .56204 m .15845 .55571 L .12425 .54134 L 1 .844 0 r
F
.70009 .48947 m .66811 .49408 L .66815 .49888 L .651 .199 0 r
F
.70009 .48947 m .70008 .48452 L .66811 .49408 L F
.29995 .71845 m .25557 .71245 L .25683 .71765 L 1 .474 0 r
F
.30084 .7236 m .29995 .71845 L .25683 .71765 L 1 .465 0 r
F
.63338 .56438 m .59752 .56284 L .59768 .56718 L .886 .419 0 r
F
.63338 .56438 m .63338 .55996 L .59752 .56284 L F
.72183 .29465 m .70188 .3008 L .70401 .30707 L .358 .121 0 r
F
.72183 .29465 m .7196 .2884 L .70188 .3008 L F
.66798 .53628 m .6332 .53776 L .63326 .54222 L .782 .309 0 r
F
.66798 .53628 m .66805 .53168 L .6332 .53776 L F
.5764 .46807 m .5493 .46843 L .54919 .47243 L .846 .318 0 r
F
.5764 .46807 m .57669 .46395 L .5493 .46843 L F
.56183 .56737 m .52721 .56106 L .52748 .56522 L 1 .675 0 r
F
.5621 .57165 m .56183 .56737 L .52748 .56522 L 1 .669 0 r
F
.59783 .57152 m .56183 .56737 L .5621 .57165 L .986 .546 0 r
F
.59783 .57152 m .59768 .56718 L .56183 .56737 L F
.57026 .14227 m .55459 .1431 L .55899 .14807 L .745 .789 0 r
F
.56989 .14739 m .57026 .14227 L .55899 .14807 L .742 .777 0 r
F
.57033 .14234 m .57026 .14227 L .56989 .14739 L F
.59301 .1388 m .57694 .14145 L .58209 .14576 L .151 .166 0 r
F
.59867 .14288 m .59301 .1388 L .58209 .14576 L .695 .785 0 r
F
.59294 .139 m .57689 .1416 L .58203 .14593 L .696 .791 0 r
F
.57721 .1414 m .57174 .13721 L .57694 .14145 L .327 .43 0 r
F
.57721 .1414 m .5717 .13735 L .57689 .1416 L .698 .8 0 r
F
.58725 .13498 m .57214 .13728 L .57721 .1414 L F
.57214 .13728 m .57213 .13728 L .57721 .1414 L .327 .43 0 r
F
.57213 .13728 m .57174 .13721 L .57509 .13977 L F
.57213 .13728 m .57509 .13977 L .57721 .1414 L F
.57174 .13721 m .5665 .13304 L .55573 .13846 L .744 .836 0 r
F
.57201 .13715 m .5665 .13304 L .57174 .13721 L .346 .467 0 r
F
.58151 .13105 m .56713 .13308 L .57151 .13676 L .701 .809 0 r
F
.58151 .13105 m .57151 .13676 L .57201 .13715 L F
.56688 .13311 m .56688 .13311 L .57201 .13715 L .346 .467 0 r
F
.56688 .13311 m .5665 .13304 L .56972 .13545 L F
.56688 .13311 m .56972 .13545 L .57201 .13715 L F
.5665 .13304 m .55108 .13408 L .55573 .13846 L .237 .178 0 r
F
.55108 .13408 m .54638 .12977 L .53573 .13402 L .783 .874 0 r
F
.55132 .13404 m .54638 .12977 L .55108 .13408 L .422 .585 0 r
F
.56118 .12907 m .5467 .12984 L .5512 .13394 L .746 .849 0 r
F
.5467 .12984 m .54669 .12983 L .55132 .13404 L .422 .585 0 r
F
.54669 .12983 m .54638 .12977 L .54876 .13183 L F
.54669 .12983 m .54876 .13183 L .55132 .13404 L F
.54638 .12977 m .5317 .12952 L .53573 .13402 L .784 .88 0 r
F
.54638 .12977 m .54165 .12553 L .5317 .12952 L F
.54661 .12973 m .54165 .12553 L .54638 .12977 L .447 .615 0 r
F
.55586 .12504 m .54229 .12558 L .5463 .12945 L .308 .28 0 r
F
.55586 .12504 m .5463 .12945 L .54661 .12973 L F
.54196 .12559 m .54165 .12553 L .54176 .12563 L .447 .615 0 r
F
.54196 .12559 m .54176 .12563 L .54661 .12973 L F
.54196 .12559 m .54988 .12388 L .54165 .12553 L F
.55586 .12504 m .55025 .12419 L .54196 .12559 L .308 .28 0 r
F
.56118 .12907 m .55094 .13407 L .55132 .13404 L .746 .849 0 r
F
.56298 .13328 m .56295 .13327 L .55108 .13408 L .237 .178 0 r
F
.5665 .13304 m .56628 .13303 L .56298 .13328 L F
.56646 .13317 m .56628 .13303 L .55106 .13417 L .744 .841 0 r
F
.56628 .13303 m .56118 .12907 L .55132 .13404 L F
.56295 .13327 m .5629 .13326 L .55132 .13404 L .237 .178 0 r
F
.56295 .13327 m .55132 .13404 L .55108 .13408 L F
.56628 .13303 m .56027 .13263 L .56298 .13328 L F
.56628 .13303 m .55132 .13404 L .55106 .13417 L .744 .841 0 r
F
.5629 .13326 m .56027 .13263 L .55132 .13404 L .237 .178 0 r
F
.56118 .12907 m .55586 .12504 L .54661 .12973 L .746 .849 0 r
F
.5467 .12984 m .54661 .12973 L .54638 .12977 L .422 .585 0 r
F
.5467 .12984 m .54661 .12973 L .54637 .12985 L .746 .849 0 r
F
.56118 .12907 m .54661 .12973 L .5467 .12984 L F
.5467 .12984 m .54661 .12973 L .54661 .12973 L .422 .585 0 r
F
.56027 .13263 m .55511 .12821 L .54661 .12973 L F
.56027 .13263 m .54661 .12973 L .5467 .12984 L F
.54229 .12558 m .54196 .12559 L .5466 .12974 L .308 .28 0 r
F
.54196 .12559 m .54164 .1256 L .54289 .12665 L F
.54196 .12559 m .54289 .12665 L .5466 .12974 L F
.55511 .12821 m .55025 .12419 L .54196 .12559 L .447 .615 0 r
F
.55025 .12419 m .54988 .12388 L .54196 .12559 L F
.55025 .12419 m .54988 .12413 L .54196 .12559 L .308 .28 0 r
F
.54196 .12559 m .54982 .12412 L .54164 .1256 L F
.54988 .12413 m .54982 .12412 L .54196 .12559 L F
.55511 .12821 m .54196 .12559 L .54661 .12973 L .447 .615 0 r
F
.54661 .12973 m .5463 .12945 L .5466 .12974 L .308 .28 0 r
F
.5466 .12974 m .54164 .1256 L .54637 .12985 L F
.56027 .13263 m .5467 .12984 L .55132 .13404 L .422 .585 0 r
F
.5512 .13394 m .54637 .12985 L .55094 .13407 L .746 .849 0 r
F
.5467 .12984 m .54637 .12985 L .5512 .13394 L F
.55132 .13404 m .55094 .13407 L .55106 .13417 L F
.56672 .13299 m .56118 .12907 L .56628 .13303 L .233 .179 0 r
F
.56675 .13298 m .56185 .12898 L .56674 .13299 L F
.57573 .12719 m .56274 .12887 L .56675 .13298 L F
.56274 .12887 m .56185 .12898 L .56675 .13298 L F
.58725 .13498 m .58151 .13105 L .57201 .13715 L .698 .8 0 r
F
.57214 .13728 m .57201 .13715 L .57174 .13721 L .327 .43 0 r
F
.57214 .13728 m .57201 .13715 L .5717 .13735 L .698 .8 0 r
F
.58725 .13498 m .57201 .13715 L .57214 .13728 L F
.59294 .139 m .59271 .13884 L .57689 .1416 L .696 .791 0 r
F
.59271 .13884 m .58725 .13498 L .57721 .1414 L F
.58854 .13954 m .59271 .13884 L .57694 .14145 L .151 .166 0 r
F
.59301 .1388 m .59271 .13884 L .58854 .13954 L F
.60193 .13148 m .58725 .13498 L .59271 .13884 L .648 .764 0 r
F
.59324 .13875 m .59271 .13884 L .59294 .139 L F
.60193 .13148 m .59271 .13884 L .59327 .13873 L F
.60803 .13524 m .60193 .13148 L .59327 .13873 L .644 .754 0 r
F
.60803 .13524 m .59327 .13873 L .59328 .13874 L F
.60803 .13524 m .59325 .13874 L .59344 .13888 L F
.6142 .13879 m .59867 .14288 L .60427 .14703 L 0 0 0 r
F
.6142 .13879 m .61393 .13887 L .59867 .14288 L F
.62021 .14269 m .6142 .13879 L .60427 .14703 L .639 .738 0 r
F
.60735 .14082 m .6138 .1389 L .59912 .14295 L .639 .744 0 r
F
.61408 .13908 m .6138 .1389 L .60735 .14082 L F
.61241 .13927 m .6138 .1389 L .59892 .14281 L 0 0 0 r
F
.61393 .13887 m .6138 .1389 L .61241 .13927 L F
.61393 .13887 m .59892 .14281 L .59867 .14288 L F
.6217 .13036 m .60803 .13524 L .6138 .1389 L .585 .713 0 r
F
.61436 .13876 m .6138 .1389 L .61408 .13908 L F
.61437 .13874 m .6138 .1389 L .6142 .13879 L .523 .625 0 r
F
.61439 .13873 m .6138 .1389 L .61437 .13874 L F
.6217 .13036 m .6138 .1389 L .61439 .13873 L .585 .713 0 r
F
.62806 .13392 m .6217 .13036 L .61437 .13875 L .578 .701 0 r
F
.6146 .13889 m .61437 .13875 L .61408 .13908 L F
.62806 .13392 m .6144 .13874 L .6146 .13889 L F
.63456 .13718 m .62021 .14269 L .62617 .14667 L 0 0 0 r
F
.62617 .14667 m .60982 .15126 L .61533 .15557 L .634 .728 0 r
F
.63208 .15074 m .62617 .14667 L .61533 .15557 L .63 .718 0 r
F
.62617 .14667 m .62021 .14269 L .60982 .15126 L .634 .728 0 r
F
.64084 .14089 m .63456 .13718 L .62617 .14667 L .572 .684 0 r
F
.62646 .14651 m .62008 .143 L .62602 .14701 L .572 .69 0 r
F
.62752 .14018 m .62063 .14279 L .62094 .14298 L F
.63456 .13718 m .63416 .13735 L .62021 .14269 L 0 0 0 r
F
.62752 .14018 m .63405 .1374 L .62062 .14278 L .572 .69 0 r
F
.62063 .14279 m .62062 .14278 L .62008 .143 L F
.62752 .14018 m .62062 .14278 L .62063 .14279 L F
.63296 .13781 m .63405 .1374 L .6204 .14264 L 0 0 0 r
F
.63416 .13735 m .63405 .1374 L .63296 .13781 L F
.63416 .13735 m .6204 .14264 L .62021 .14269 L F
.64007 .12772 m .62806 .13392 L .63405 .1374 L .509 .652 0 r
F
.6346 .13719 m .63405 .1374 L .63437 .13758 L F
.63461 .13716 m .63405 .1374 L .63456 .13718 L .404 .52 0 r
F
.64007 .12772 m .63405 .1374 L .6346 .13719 L .509 .652 0 r
F
.63405 .1374 m .62806 .13392 L .6204 .14264 L .572 .69 0 r
F
.62062 .14278 m .6204 .14264 L .62008 .143 L F
.63405 .1374 m .6204 .14264 L .62062 .14278 L F
.6204 .14264 m .62026 .14255 L .6204 .14264 L .011 .102 0 r
F
.63405 .1374 m .6247 .14137 L .6204 .14264 L 0 0 0 r
F
.62806 .13392 m .62017 .14249 L .6204 .14264 L .578 .701 0 r
F
.62026 .14255 m .62026 .14255 L .6204 .14264 L .011 .102 0 r
F
.62026 .14255 m .62026 .14255 L .6204 .14264 L F
.6204 .14264 m .62026 .14255 L .6204 .14264 L F
.62017 .14249 m .61985 .14285 L .6204 .14264 L .578 .701 0 r
F
.6247 .14137 m .62026 .14255 L .6204 .14264 L .011 .102 0 r
F
.6204 .14264 m .6142 .13879 L .62021 .14269 L F
.62021 .14269 m .60427 .14703 L .60982 .15126 L .639 .738 0 r
F
.62017 .14249 m .61408 .13908 L .61985 .14285 L .578 .701 0 r
F
.62806 .13392 m .6146 .13889 L .62017 .14249 L F
.62025 .14255 m .6146 .13889 L .62025 .14255 L .011 .102 0 r
F
.6146 .13889 m .6142 .13879 L .6204 .14264 L F
.6146 .13889 m .61408 .13908 L .62017 .14249 L .578 .701 0 r
F
.6247 .14137 m .6146 .13889 L .62025 .14255 L .011 .102 0 r
F
.64659 .13109 m .64007 .12772 L .63462 .13716 L .5 .638 0 r
F
.65335 .13399 m .64084 .14089 L .64706 .14469 L 0 0 0 r
F
.65335 .13399 m .65133 .13512 L .64752 .13721 L F
.6528 .13431 m .65269 .13437 L .64088 .14088 L F
.64706 .14469 m .64084 .14089 L .63208 .15074 L .566 .673 0 r
F
.64114 .14103 m .64088 .14088 L .64063 .14132 L .491 .624 0 r
F
.65269 .13437 m .64088 .14088 L .64114 .14103 L F
.65269 .13437 m .64181 .14062 L .64088 .14088 L 0 0 0 r
F
.65335 .13399 m .6528 .13431 L .65133 .13512 L F
.64752 .13721 m .65133 .13512 L .64084 .14089 L F
.6528 .13431 m .64088 .14088 L .64084 .14089 L F
.65269 .13437 m .64659 .13109 L .64088 .14088 L .491 .624 0 r
F
.64084 .14089 m .62617 .14667 L .63208 .15074 L .572 .684 0 r
F
.64063 .14073 m .63437 .13758 L .64036 .14117 L .5 .638 0 r
F
.64659 .13109 m .63486 .13732 L .64063 .14073 L F
.64073 .14079 m .63486 .13732 L .64073 .14079 L 0 .059 0 r
F
.64088 .14088 m .63456 .13718 L .64084 .14089 L F
.63486 .13732 m .63456 .13718 L .64088 .14088 L F
.63486 .13732 m .63437 .13758 L .64063 .14073 L .5 .638 0 r
F
.64088 .14088 m .64073 .14079 L .64088 .14088 L 0 .059 0 r
F
.64659 .13109 m .64041 .14109 L .64088 .14088 L .5 .638 0 r
F
.64041 .14109 m .64036 .14117 L .64045 .14112 L F
.64041 .14109 m .64045 .14112 L .64088 .14088 L F
.63486 .13732 m .63462 .13716 L .63456 .13718 L 0 .059 0 r
F
.63463 .13716 m .63462 .13716 L .63461 .13717 L .5 .638 0 r
F
.63743 .13596 m .63462 .13716 L .63463 .13716 L F
.63743 .13596 m .63463 .13716 L .63486 .13732 L F
.63463 .13716 m .63461 .13717 L .63486 .13732 L F
.64181 .14062 m .63462 .13716 L .63486 .13732 L 0 .059 0 r
F
.63462 .13716 m .63462 .13716 L .63486 .13732 L F
.64181 .14062 m .63581 .13664 L .63462 .13716 L F
.64181 .14062 m .63486 .13732 L .64073 .14079 L F
.64181 .14062 m .64073 .14079 L .64088 .14088 L F
.6598 .13751 m .65335 .13399 L .64706 .14469 L .493 .622 0 r
F
.65305 .13457 m .65269 .13437 L .64063 .14132 L .491 .624 0 r
F
.65627 .12365 m .64659 .13109 L .65269 .13437 L .419 .576 0 r
F
.65319 .1341 m .65269 .13437 L .65305 .13457 L F
.65028 .13523 m .64181 .14062 L .65269 .13437 L .319 .398 0 r
F
.66326 .12608 m .65335 .13399 L .6598 .13751 L .475 .205 0 r
F
.66024 .10318 m .65644 .11245 L .66259 .11513 L .346 .476 0 r
F
.66258 .11588 m .65627 .12365 L .66166 .12629 L .367 .499 0 r
F
.66258 .11588 m .66166 .12629 L .66242 .12666 L F
.66242 .12666 m .65627 .12365 L .6532 .13405 L .411 .558 0 r
F
.65627 .12365 m .65269 .13437 L .6532 .13405 L .419 .576 0 r
F
.65627 .12365 m .64965 .12055 L .64659 .13109 L F
.65644 .11245 m .64965 .12055 L .65627 .12365 L .381 .527 0 r
F
.66258 .11588 m .65644 .11245 L .65627 .12365 L .367 .499 0 r
F
.66263 .1158 m .66258 .11584 L .66258 .11588 L 1 1 0 r
F
.66349 .11444 m .66264 .11515 L .66263 .1158 L F
.66303 .11532 m .66264 .11515 L .66258 .11588 L .367 .499 0 r
F
.66264 .11515 m .65644 .11245 L .66232 .11574 L F
.65242 .11881 m .64956 .12613 L .66264 .11515 L .307 .431 0 r
F
.66291 .11467 m .6627 .11505 L .66349 .11444 L F
.6627 .11505 m .66265 .11514 L .66349 .11444 L F
.66349 .11444 m .66263 .1158 L .66326 .12608 L 1 1 0 r
F
.67016 .11721 m .66326 .12608 L .66983 .12929 L .378 .519 0 r
F
.67016 .11721 m .66349 .11444 L .66326 .12608 L F
.66714 .10499 m .66349 .11444 L .67016 .11721 L .762 .552 0 r
F
.66248 .11291 m .66259 .11513 L .66264 .11515 L .346 .476 0 r
F
.66714 .10499 m .66655 .10554 L .66349 .11444 L .762 .552 0 r
F
.6627 .11505 m .66264 .11515 L .66265 .11514 L .307 .431 0 r
F
.66269 .11507 m .66264 .11515 L .66269 .11517 L .346 .476 0 r
F
.66268 .1138 m .66264 .11515 L .66269 .11507 L F
.66288 .11468 m .66264 .11515 L .66291 .11467 L .307 .431 0 r
F
.66268 .1138 m .66269 .11517 L .66288 .11468 L .346 .476 0 r
F
.66248 .11291 m .66264 .11515 L .66268 .1138 L F
.66024 .10318 m .66259 .11513 L .66248 .11291 L F
.65242 .11881 m .66264 .11515 L .66288 .11468 L .307 .431 0 r
F
.66655 .10554 m .66645 .10564 L .66288 .11468 L .762 .552 0 r
F
.66655 .10554 m .66288 .11468 L .66349 .11444 L F
.66674 .10575 m .66645 .10564 L .66303 .11532 L .328 .439 0 r
F
.66645 .10564 m .66024 .10318 L .66288 .11468 L F
.66645 .10564 m .66288 .11468 L .66303 .11532 L F
.66645 .10564 m .65242 .11881 L .66288 .11468 L .762 .552 0 r
F
.66288 .11468 m .66269 .11517 L .66303 .11532 L .346 .476 0 r
F
.66693 .1066 m .66303 .11532 L .66953 .11835 L .328 .439 0 r
F
.66674 .10575 m .66464 .11118 L .66693 .1066 L F
.66464 .11118 m .66303 .11532 L .66693 .1066 L F
.66264 .11515 m .66232 .11574 L .66258 .11588 L .367 .499 0 r
F
.66258 .11584 m .66258 .11584 L .66258 .11588 L 1 1 0 r
F
.66258 .11588 m .64956 .12613 L .65028 .13523 L F
.66258 .11584 m .64956 .12613 L .66258 .11588 L F
.66264 .11515 m .64956 .12613 L .66263 .1158 L F
.66263 .1158 m .66258 .11588 L .6628 .11918 L F
.66263 .1158 m .6628 .11918 L .66326 .12608 L F
.66258 .11588 m .65028 .13523 L .66242 .12666 L F
.66258 .11588 m .66242 .12666 L .66326 .12608 L F
.66303 .11532 m .66258 .11588 L .66242 .12666 L .367 .499 0 r
F
.66284 .12632 m .66242 .12666 L .66283 .12686 L F
.66303 .11532 m .66242 .12666 L .66284 .12632 L F
.65738 .13077 m .66242 .12666 L .65335 .13399 L .475 .205 0 r
F
.66326 .12608 m .66242 .12666 L .65738 .13077 L F
.66242 .12666 m .65028 .13523 L .6532 .13405 L F
.66242 .12666 m .6532 .13405 L .65335 .13399 L F
.66283 .12686 m .66242 .12666 L .6532 .13405 L .411 .558 0 r
F
.65563 .13254 m .6532 .13405 L .65305 .13457 L F
.66283 .12686 m .6532 .13405 L .65563 .13254 L F
.6532 .13405 m .65269 .13437 L .6527 .13437 L .319 .398 0 r
F
.6532 .13405 m .6527 .13437 L .65335 .13399 L F
.65028 .13523 m .65269 .13437 L .6532 .13405 L F
.6532 .13405 m .65269 .13437 L .65319 .1341 L .419 .576 0 r
F
.64088 .14088 m .64036 .14117 L .64063 .14132 L .5 .638 0 r
F
.63486 .13732 m .63461 .13717 L .63437 .13758 L F
.64659 .13109 m .63462 .13716 L .63743 .13596 L F
.63581 .13664 m .63405 .1374 L .63411 .13737 L .404 .52 0 r
F
.63462 .13716 m .63411 .13737 L .63461 .13716 L F
.63581 .13664 m .63411 .13737 L .63462 .13716 L F
.63581 .13664 m .6247 .14137 L .63405 .1374 L F
.63437 .13758 m .63405 .1374 L .62752 .14018 L .572 .69 0 r
F
.6204 .14264 m .61985 .14285 L .62008 .143 L .578 .701 0 r
F
.63437 .13758 m .62752 .14018 L .62646 .14651 L .572 .69 0 r
F
.62752 .14018 m .62094 .14298 L .62646 .14651 L F
.62063 .14279 m .62008 .143 L .62646 .14651 L F
.6247 .14137 m .61875 .13725 L .61439 .13873 L .011 .102 0 r
F
.6146 .13889 m .61439 .13873 L .6142 .13879 L F
.6247 .14137 m .61439 .13873 L .6146 .13889 L F
.6144 .13874 m .61437 .13875 L .6146 .13889 L .578 .701 0 r
F
.61875 .13725 m .6138 .1389 L .61439 .13873 L .523 .625 0 r
F
.61439 .13873 m .6138 .1389 L .61436 .13876 L .585 .713 0 r
F
.6138 .1389 m .60803 .13524 L .59892 .14281 L .639 .744 0 r
F
.6138 .1389 m .59892 .14281 L .59858 .1431 L F
.6138 .1389 m .60569 .14117 L .59892 .14281 L 0 0 0 r
F
.61875 .13725 m .60569 .14117 L .6138 .1389 L .523 .625 0 r
F
.59892 .14281 m .59301 .1388 L .59867 .14288 L .206 .241 0 r
F
.59873 .14268 m .59294 .139 L .59839 .14295 L .644 .754 0 r
F
.60803 .13524 m .59344 .13888 L .59873 .14268 L F
.59891 .1428 m .59344 .13888 L .59891 .1428 L .206 .241 0 r
F
.59344 .13888 m .59301 .1388 L .59892 .14281 L F
.59344 .13888 m .59294 .139 L .59873 .14268 L .644 .754 0 r
F
.59892 .14281 m .59891 .1428 L .59892 .14281 L .206 .241 0 r
F
.60803 .13524 m .59873 .14268 L .59892 .14281 L .644 .754 0 r
F
.59891 .1428 m .59891 .1428 L .59892 .14281 L .206 .241 0 r
F
.59873 .14268 m .59839 .14295 L .59892 .14281 L .644 .754 0 r
F
.60569 .14117 m .59891 .1428 L .59892 .14281 L .206 .241 0 r
F
.60569 .14117 m .59344 .13888 L .59891 .1428 L F
.59913 .14296 m .59912 .14295 L .59858 .1431 L .639 .744 0 r
F
.61408 .13908 m .59912 .14295 L .59913 .14296 L F
.59892 .14281 m .59839 .14295 L .59858 .1431 L .644 .754 0 r
F
.60569 .14117 m .5999 .13692 L .59327 .13873 L .206 .241 0 r
F
.59344 .13888 m .59327 .13873 L .59301 .1388 L F
.60569 .14117 m .59327 .13873 L .59344 .13888 L F
.59328 .13874 m .59327 .13873 L .59325 .13874 L .644 .754 0 r
F
.59344 .13888 m .59325 .13874 L .59294 .139 L F
.5999 .13692 m .58564 .13981 L .59271 .13884 L .619 .704 0 r
F
.59327 .13873 m .59271 .13884 L .59301 .1388 L F
.5999 .13692 m .59271 .13884 L .59327 .13873 L F
.59327 .13873 m .59271 .13884 L .59324 .13875 L .648 .764 0 r
F
.59271 .13884 m .57721 .1414 L .57694 .14145 L .151 .166 0 r
F
.59271 .13884 m .57721 .1414 L .57689 .1416 L .696 .791 0 r
F
.59271 .13884 m .58564 .13981 L .57721 .1414 L .151 .166 0 r
F
.58564 .13981 m .58014 .13542 L .57201 .13715 L .327 .43 0 r
F
.58564 .13981 m .57201 .13715 L .57214 .13728 L F
.56688 .13311 m .56675 .13298 L .5665 .13304 L .346 .467 0 r
F
.58151 .13105 m .57573 .12719 L .56675 .13298 L .701 .809 0 r
F
.56688 .13311 m .56675 .13298 L .56688 .13311 L .346 .467 0 r
F
.56688 .13311 m .56675 .13298 L .56646 .13317 L .701 .809 0 r
F
.58151 .13105 m .56675 .13298 L .56688 .13311 L F
.56713 .13308 m .56688 .13311 L .57199 .13716 L F
.56688 .13311 m .56646 .13317 L .56832 .13452 L F
.56688 .13311 m .56832 .13452 L .57199 .13716 L F
.58014 .13542 m .56675 .13298 L .56688 .13311 L .346 .467 0 r
F
.56675 .13298 m .56675 .13298 L .56688 .13311 L F
.58014 .13542 m .57456 .13113 L .56675 .13298 L F
.56185 .12898 m .56118 .12907 L .56674 .13299 L .233 .179 0 r
F
.57456 .13113 m .56027 .13263 L .56628 .13303 L .697 .778 0 r
F
.56675 .13298 m .56628 .13303 L .5665 .13304 L F
.57456 .13113 m .56628 .13303 L .56675 .13298 L F
.56674 .13299 m .56672 .13299 L .56628 .13303 L .233 .179 0 r
F
.56673 .13299 m .56628 .13303 L .56646 .13317 L F
.56674 .13299 m .56628 .13303 L .56673 .13299 L F
.58014 .13542 m .56688 .13311 L .57201 .13715 L .346 .467 0 r
F
.57201 .13715 m .57151 .13676 L .57199 .13716 L .701 .809 0 r
F
.57199 .13716 m .56646 .13317 L .5717 .13735 L F
.57214 .13728 m .5717 .13735 L .57721 .1414 L .698 .8 0 r
F
.58564 .13981 m .57214 .13728 L .57721 .1414 L .327 .43 0 r
F
.59858 .1431 m .59294 .139 L .58203 .14593 L .693 .782 0 r
F
.59106 .14428 m .57538 .14646 L .58028 .15125 L .564 .055 0 r
F
.57526 .14702 m .57041 .14176 L .57538 .14646 L .76 .165 0 r
F
.57526 .14702 m .57034 .14226 L .57519 .14706 L .68 .74 0 r
F
.57034 .14226 m .57033 .14234 L .57519 .14706 L F
.57519 .14706 m .57033 .14234 L .56989 .14739 L .742 .777 0 r
F
.58013 .15189 m .57519 .14706 L .58004 .15195 L .675 .726 0 r
F
.59642 .14885 m .58028 .15125 L .5851 .15612 L .683 .731 0 r
F
.59642 .14885 m .59106 .14428 L .58028 .15125 L F
.59077 .14512 m .57529 .14705 L .58013 .15189 L .675 .726 0 r
F
.57529 .14705 m .57519 .14706 L .58013 .15189 L F
.59077 .14512 m .59072 .14508 L .57519 .14706 L F
.58102 .14568 m .59072 .14508 L .57538 .14646 L .564 .055 0 r
F
.59106 .14428 m .59072 .14508 L .58102 .14568 L F
.60169 .15351 m .59642 .14885 L .5851 .15612 L .679 .719 0 r
F
.59614 .14966 m .59106 .14428 L .59642 .14885 L 1 .86 0 r
F
.60124 .15464 m .58482 .15694 L .58951 .16203 L .665 .696 0 r
F
.60633 .15957 m .60124 .15464 L .58951 .16203 L .659 .68 0 r
F
.59605 .14983 m .58004 .15195 L .58482 .15694 L .67 .711 0 r
F
.60124 .15464 m .59605 .14983 L .58482 .15694 L .665 .696 0 r
F
.59228 .15033 m .59077 .14512 L .58004 .15195 L .67 .711 0 r
F
.59605 .14983 m .59085 .14519 L .59228 .15033 L F
.59085 .14519 m .59077 .14512 L .59228 .15033 L F
.59609 .1498 m .59082 .14511 L .59614 .14966 L 1 .86 0 r
F
.59609 .1498 m .59082 .14511 L .59605 .14983 L .593 .663 0 r
F
.59082 .14511 m .59085 .14519 L .59605 .14983 L F
.60129 .1546 m .59605 .14983 L .60124 .15464 L .584 .645 0 r
F
.62008 .143 m .60418 .14727 L .60972 .15152 L .635 .734 0 r
F
.63208 .15074 m .61533 .15557 L .62078 .15995 L .63 .718 0 r
F
.62602 .14701 m .60972 .15152 L .6152 .15584 L .63 .723 0 r
F
.61701 .14996 m .60169 .15351 L .60688 .15826 L .601 .662 0 r
F
.61408 .13908 m .59858 .1431 L .60418 .14727 L .639 .744 0 r
F
.62008 .143 m .61408 .13908 L .60418 .14727 L .635 .734 0 r
F
.61139 .14552 m .59642 .14885 L .60169 .15351 L .394 .033 0 r
F
.62602 .14701 m .62008 .143 L .60972 .15152 L .63 .723 0 r
F
.61701 .14996 m .61139 .14552 L .60169 .15351 L .601 .662 0 r
F
.61082 .1469 m .60855 .14735 L .60129 .1546 L .584 .645 0 r
F
.63794 .15488 m .62078 .15995 L .62617 .16441 L .626 .707 0 r
F
.63794 .15488 m .63208 .15074 L .62078 .15995 L F
.63191 .15109 m .6152 .15584 L .62064 .16024 L .626 .713 0 r
F
.62255 .1545 m .60688 .15826 L .61199 .1631 L .595 .648 0 r
F
.63191 .15109 m .62602 .14701 L .6152 .15584 L .626 .713 0 r
F
.62255 .1545 m .61701 .14996 L .60688 .15826 L .595 .648 0 r
F
.61631 .15156 m .60124 .15464 L .60633 .15957 L .575 .626 0 r
F
.61533 .15176 m .61082 .1469 L .60124 .15464 L F
.61631 .15156 m .61116 .14719 L .61533 .15176 L F
.61116 .14719 m .61082 .1469 L .61533 .15176 L F
.64706 .14469 m .63208 .15074 L .63794 .15488 L .566 .673 0 r
F
.64063 .14132 m .62602 .14701 L .63191 .15109 L .566 .678 0 r
F
.63057 .14559 m .61701 .14996 L .62255 .1545 L .261 .001 0 r
F
.61635 .15152 m .61139 .14552 L .61701 .14996 L 1 .794 0 r
F
.61635 .15152 m .61087 .14688 L .61631 .15156 L .471 .555 0 r
F
.61087 .14688 m .61082 .1469 L .61116 .14719 L F
.61087 .14688 m .61116 .14719 L .61631 .15156 L F
.64373 .1591 m .63794 .15488 L .62617 .16441 L .621 .697 0 r
F
.63774 .15526 m .62064 .16024 L .62602 .16472 L .621 .702 0 r
F
.628 .15913 m .61199 .1631 L .61701 .16803 L .589 .633 0 r
F
.63774 .15526 m .63191 .15109 L .62064 .16024 L .621 .702 0 r
F
.628 .15913 m .62255 .1545 L .61199 .1631 L .589 .633 0 r
F
.6217 .15634 m .60633 .15957 L .61133 .1646 L .565 .606 0 r
F
.6217 .15634 m .61631 .15156 L .60633 .15957 L F
.62174 .15629 m .61631 .15156 L .6217 .15634 L .455 .529 0 r
F
.65323 .14857 m .63794 .15488 L .64373 .1591 L .56 .661 0 r
F
.65323 .14857 m .64706 .14469 L .63794 .15488 L F
.64682 .14515 m .63191 .15109 L .63774 .15526 L .559 .666 0 r
F
.63634 .14991 m .62255 .1545 L .628 .15913 L .497 .576 0 r
F
.64682 .14515 m .64063 .14132 L .63191 .15109 L .559 .666 0 r
F
.63634 .14991 m .63057 .14559 L .62255 .1545 L .497 .576 0 r
F
.62946 .14792 m .62909 .14802 L .62174 .15629 L .455 .529 0 r
F
.63335 .16385 m .61701 .16803 L .62195 .17304 L .583 .618 0 r
F
.63861 .16867 m .62195 .17304 L .62679 .17814 L .577 .603 0 r
F
.63861 .16867 m .63335 .16385 L .62195 .17304 L F
.63212 .16626 m .61622 .16973 L .621 .17498 L .543 .563 0 r
F
.64352 .1595 m .63774 .15526 L .62602 .16472 L .617 .692 0 r
F
.63335 .16385 m .628 .15913 L .61701 .16803 L .583 .618 0 r
F
.62697 .16124 m .61133 .1646 L .61622 .16973 L .555 .585 0 r
F
.63212 .16626 m .62697 .16124 L .61622 .16973 L .543 .563 0 r
F
.62697 .16124 m .6217 .15634 L .61133 .1646 L .555 .585 0 r
F
.65934 .15254 m .64373 .1591 L .64947 .1634 L .553 .649 0 r
F
.65934 .15254 m .65323 .14857 L .64373 .1591 L F
.65296 .14907 m .63774 .15526 L .64352 .1595 L .553 .654 0 r
F
.64202 .15433 m .628 .15913 L .63335 .16385 L .488 .559 0 r
F
.65296 .14907 m .64682 .14515 L .63774 .15526 L .553 .654 0 r
F
.64202 .15433 m .63634 .14991 L .628 .15913 L .488 .559 0 r
F
.635 .15261 m .6217 .15634 L .62697 .16124 L .438 .501 0 r
F
.635 .15261 m .62946 .14792 L .6217 .15634 L F
.64063 .14132 m .63437 .13758 L .62602 .14701 L .566 .678 0 r
F
.62946 .14792 m .62942 .14789 L .61631 .15156 L .455 .529 0 r
F
.61792 .14967 m .62942 .14789 L .61701 .14996 L .261 .001 0 r
F
.63057 .14559 m .62942 .14789 L .61792 .14967 L F
.6295 .14786 m .62942 .14789 L .63057 .14559 L .837 .145 0 r
F
.63512 .15237 m .63057 .14559 L .63634 .14991 L 1 .636 0 r
F
.64376 .17357 m .62679 .17814 L .63154 .18332 L .57 .587 0 r
F
.64376 .17357 m .63861 .16867 L .62679 .17814 L F
.63714 .17141 m .621 .17498 L .62567 .18032 L .532 .539 0 r
F
.63714 .17141 m .63212 .16626 L .621 .17498 L F
.66539 .15659 m .64947 .1634 L .65515 .16778 L .547 .637 0 r
F
.66539 .15659 m .65934 .15254 L .64947 .1634 L F
.65904 .15307 m .64352 .1595 L .64924 .16382 L .546 .642 0 r
F
.6476 .15885 m .63335 .16385 L .63861 .16867 L .479 .541 0 r
F
.65904 .15307 m .65296 .14907 L .64352 .1595 L .546 .642 0 r
F
.6476 .15885 m .64202 .15433 L .63335 .16385 L .479 .541 0 r
F
.64039 .15745 m .62697 .16124 L .63212 .16626 L .419 .47 0 r
F
.64039 .15745 m .635 .15261 L .62697 .16124 L F
.64044 .15737 m .635 .15261 L .64039 .15745 L .315 .33 0 r
F
.67252 .14481 m .65934 .15254 L .66539 .15659 L .477 .595 0 r
F
.66619 .14111 m .65323 .14857 L .65934 .15254 L .485 .609 0 r
F
.67252 .14481 m .66619 .14111 L .65934 .15254 L .477 .595 0 r
F
.6658 .14179 m .65296 .14907 L .65904 .15307 L .473 .596 0 r
F
.65355 .14888 m .64202 .15433 L .6476 .15885 L .385 .467 0 r
F
.6598 .13751 m .64706 .14469 L .65323 .14857 L .493 .622 0 r
F
.66619 .14111 m .6598 .13751 L .65323 .14857 L .485 .609 0 r
F
.65945 .13813 m .64682 .14515 L .65296 .14907 L .482 .61 0 r
F
.65305 .13457 m .64063 .14132 L .64682 .14515 L .491 .624 0 r
F
.65945 .13813 m .65305 .13457 L .64682 .14515 L .482 .61 0 r
F
.64773 .1447 m .63634 .14991 L .64202 .15433 L .069 0 0 r
F
.6658 .14179 m .65945 .13813 L .65296 .14907 L .473 .596 0 r
F
.65355 .14888 m .64773 .1447 L .64202 .15433 L .385 .467 0 r
F
.64555 .14886 m .64532 .14894 L .64044 .15737 L .315 .33 0 r
F
.64532 .14894 m .64522 .14897 L .64518 .14903 L F
.64532 .14894 m .64518 .14903 L .64044 .15737 L F
.65628 .13897 m .64773 .1447 L .65355 .14888 L 0 0 0 r
F
.65628 .13897 m .65423 .14262 L .64773 .1447 L F
.64882 .17857 m .63154 .18332 L .63619 .18858 L .563 .57 0 r
F
.64882 .17857 m .64376 .17357 L .63154 .18332 L F
.64202 .17668 m .62567 .18032 L .63021 .18578 L .519 .515 0 r
F
.64202 .17668 m .63714 .17141 L .62567 .18032 L F
.67138 .16073 m .65515 .16778 L .66078 .17224 L .541 .625 0 r
F
.67138 .16073 m .66539 .15659 L .65515 .16778 L F
.66506 .15715 m .64924 .16382 L .6549 .16822 L .539 .629 0 r
F
.65308 .16347 m .63861 .16867 L .64376 .17357 L .47 .523 0 r
F
.66506 .15715 m .65904 .15307 L .64924 .16382 L .539 .629 0 r
F
.65308 .16347 m .6476 .15885 L .63861 .16867 L .47 .523 0 r
F
.67731 .16495 m .66078 .17224 L .66634 .17677 L .534 .613 0 r
F
.67731 .16495 m .67138 .16073 L .66078 .17224 L F
.67102 .16131 m .6549 .16822 L .6605 .17269 L .533 .617 0 r
F
.65845 .16819 m .64376 .17357 L .64882 .17857 L .46 .503 0 r
F
.67102 .16131 m .66506 .15715 L .6549 .16822 L .533 .617 0 r
F
.65845 .16819 m .65308 .16347 L .64376 .17357 L .46 .503 0 r
F
.65073 .16757 m .63714 .17141 L .64202 .17668 L .386 .403 0 r
F
.64564 .16243 m .63212 .16626 L .63714 .17141 L .4 .438 0 r
F
.65073 .16757 m .64564 .16243 L .63714 .17141 L .386 .403 0 r
F
.64564 .16243 m .64039 .15745 L .63212 .16626 L .4 .438 0 r
F
.67879 .1486 m .66539 .15659 L .67138 .16073 L .468 .581 0 r
F
.67879 .1486 m .67252 .14481 L .66539 .15659 L F
.67208 .14554 m .65904 .15307 L .66506 .15715 L .463 .581 0 r
F
.65926 .15318 m .6476 .15885 L .65308 .16347 L .378 .446 0 r
F
.67208 .14554 m .6658 .14179 L .65904 .15307 L .463 .581 0 r
F
.65926 .15318 m .65355 .14888 L .6476 .15885 L .378 .446 0 r
F
.65086 .15379 m .64039 .15745 L .64564 .16243 L .291 .276 0 r
F
.65086 .15379 m .64555 .14886 L .64039 .15745 L F
.64555 .14886 m .64549 .1488 L .635 .15261 L .315 .33 0 r
F
.64773 .1447 m .64568 .14846 L .63634 .14991 L .069 0 0 r
F
.64568 .14846 m .64549 .1488 L .64446 .14893 L F
.64568 .14846 m .64446 .14893 L .63634 .14991 L F
.64549 .1488 m .63503 .15255 L .63634 .14991 L F
.63232 .15026 m .62953 .14789 L .63236 .15017 L 1 .636 0 r
F
.63499 .15253 m .62946 .14792 L .63496 .15258 L .337 .377 0 r
F
.635 .15252 m .63363 .15138 L .63499 .15253 L F
.63363 .15138 m .62946 .14792 L .63499 .15253 L F
.62953 .1479 m .62946 .14792 L .635 .15252 L F
.62953 .14789 m .63057 .14559 L .63512 .15237 L 1 .636 0 r
F
.62953 .1479 m .62949 .14787 L .63057 .14559 L F
.64006 .14413 m .63439 .1396 L .62949 .14787 L .337 .377 0 r
F
.62988 .14777 m .62949 .14787 L .62946 .14792 L F
.64006 .14413 m .62949 .14787 L .62988 .14777 L F
.54912 .31804 m .62942 .14789 L .62944 .14788 L .837 .145 0 r
F
.62949 .14787 m .62944 .14788 L .6295 .14786 L F
.62949 .14788 m .62942 .14789 L .62946 .14792 L .355 .419 0 r
F
.54912 .31804 m .62944 .14788 L .62949 .14787 L .837 .145 0 r
F
.55033 .32318 m .54912 .31804 L .62949 .14787 L 1 .636 0 r
F
.55033 .32318 m .62949 .14787 L .62953 .1479 L F
.55033 .32318 m .62953 .1479 L .63232 .15026 L F
.62953 .1479 m .62953 .14789 L .63232 .15026 L F
.63503 .15255 m .63236 .15017 L .63512 .15237 L F
.635 .15252 m .63496 .15258 L .63503 .15255 L .337 .377 0 r
F
.63503 .15255 m .635 .15252 L .63503 .15255 L 1 .636 0 r
F
.635 .15252 m .63236 .15017 L .63503 .15255 L F
.64006 .14413 m .635 .15252 L .63503 .15255 L .337 .377 0 r
F
.63503 .15255 m .63496 .15258 L .635 .15261 L F
.64549 .1488 m .63503 .15255 L .635 .15261 L .315 .33 0 r
F
.63507 .15258 m .635 .15261 L .64044 .15737 L F
.55033 .32318 m .63236 .15017 L .63503 .15255 L 1 .636 0 r
F
.64006 .14413 m .62953 .1479 L .635 .15252 L .337 .377 0 r
F
.64549 .1488 m .64006 .14413 L .63503 .15255 L .315 .33 0 r
F
.64522 .14897 m .63507 .15258 L .6368 .15413 L F
.64522 .14897 m .6368 .15413 L .64044 .15737 L F
.64549 .1488 m .55033 .32318 L .63503 .15255 L .069 0 0 r
F
.64743 .14072 m .64006 .14413 L .6455 .14881 L .169 .122 0 r
F
.64557 .14877 m .6455 .14881 L .64555 .14886 L F
.64558 .14875 m .64552 .14879 L .64773 .1447 L .721 .066 0 r
F
.64552 .14879 m .6455 .1488 L .64773 .1447 L F
.6455 .1488 m .64549 .1488 L .64773 .1447 L F
.65423 .14262 m .65286 .14508 L .65107 .14598 L 0 0 0 r
F
.64906 .14629 m .65107 .14598 L .64558 .14875 L F
.65423 .14262 m .65107 .14598 L .64906 .14629 L F
.65286 .14508 m .65247 .14577 L .64557 .14877 L F
.65247 .14589 m .65247 .14577 L .64557 .14877 L .106 .086 0 r
F
.65256 .14585 m .65247 .14577 L .65247 .14589 L F
.66283 .12686 m .65305 .13457 L .65945 .13813 L .411 .558 0 r
F
.65577 .12916 m .65242 .13549 L .65628 .13897 L 1 .625 0 r
F
.64633 .14852 m .64557 .14877 L .64555 .14886 L .106 .086 0 r
F
.65256 .14585 m .64557 .14877 L .64633 .14852 L F
.65248 .14619 m .64555 .14886 L .65086 .15379 L F
.65256 .14585 m .65247 .14589 L .65248 .14619 L F
.65247 .14589 m .64555 .14886 L .65248 .14619 L F
.65286 .14508 m .64557 .14877 L .64558 .14875 L 0 0 0 r
F
.65423 .14262 m .64558 .14875 L .64773 .1447 L F
.65242 .13549 m .65208 .13613 L .65247 .14577 L 1 .625 0 r
F
.65247 .14577 m .55137 .32624 L .64557 .14877 L 0 0 0 r
F
.65247 .14577 m .55137 .32624 L .65247 .14577 L F
.65247 .14577 m .64743 .14072 L .64557 .14877 L .106 .086 0 r
F
.65208 .13613 m .6512 .13779 L .65247 .14573 L 1 .625 0 r
F
.65128 .13773 m .6512 .13779 L .65247 .14577 L 0 .048 0 r
F
.6512 .13779 m .65109 .13787 L .65232 .14561 L F
.65109 .13787 m .64743 .14072 L .64936 .14265 L F
.65109 .13787 m .64936 .14265 L .65232 .14561 L F
.64552 .14879 m .6455 .1488 L .6455 .1488 L .721 .066 0 r
F
.64743 .14072 m .6455 .1488 L .64557 .14877 L .169 .122 0 r
F
.55137 .32624 m .55033 .32318 L .64549 .14881 L .721 .066 0 r
F
.65028 .13523 m .64419 .13159 L .64181 .14062 L .319 .398 0 r
F
.64965 .12055 m .64007 .12772 L .64659 .13109 L .431 .594 0 r
F
.64956 .12613 m .64419 .13159 L .65028 .13523 L .256 .332 0 r
F
.65109 .13787 m .64654 .13215 L .64743 .14072 L 0 .048 0 r
F
.65128 .13773 m .65119 .13762 L .65109 .13787 L F
.65119 .13762 m .64654 .13215 L .65109 .13787 L F
.64965 .12055 m .64297 .11756 L .64007 .12772 L .431 .594 0 r
F
.64956 .12613 m .64327 .12325 L .64419 .13159 L .256 .332 0 r
F
.64976 .10974 m .64297 .11756 L .64965 .12055 L .393 .552 0 r
F
.64595 .11685 m .64327 .12325 L .64956 .12613 L .308 .436 0 r
F
.65644 .11245 m .64976 .10974 L .64965 .12055 L .381 .527 0 r
F
.65242 .11881 m .64595 .11685 L .64956 .12613 L .307 .431 0 r
F
.65018 .1233 m .64654 .13215 L .65119 .13762 L .207 .164 0 r
F
.65577 .12916 m .65118 .13763 L .6512 .13779 L 1 .625 0 r
F
.65126 .13746 m .65119 .13762 L .65128 .13773 L .207 .164 0 r
F
.65018 .1233 m .65119 .13762 L .65126 .13746 L F
.65127 .13743 m .6512 .13759 L .65577 .12916 L .049 .131 0 r
F
.65208 .13613 m .65247 .14577 L .65247 .14577 L 1 .625 0 r
F
.65242 .13549 m .65247 .14577 L .65628 .13897 L F
.66218 .14284 m .65628 .13897 L .65355 .14888 L .309 .366 0 r
F
.65876 .12107 m .65477 .12849 L .65577 .12916 L .718 .205 0 r
F
.65477 .12849 m .65018 .1233 L .65126 .13746 L .099 .072 0 r
F
.54953 .32399 m .54889 .31754 L .54643 .31878 L 0 0 0 r
F
.54242 .33555 m .53485 .33472 L .53559 .3403 L .469 .103 0 r
F
.54242 .33555 m .54174 .32966 L .53485 .33472 L F
.54342 .34045 m .53559 .3403 L .53658 .345 L .497 .178 0 r
F
.54342 .34045 m .54242 .33555 L .53559 .3403 L F
.54464 .34467 m .53658 .345 L .53775 .3491 L .519 .245 0 r
F
.54464 .34467 m .54342 .34045 L .53658 .345 L F
.54615 .32645 m .54154 .32224 L .54174 .32966 L .212 .032 0 r
F
.54671 .32605 m .54616 .32565 L .54615 .32645 L F
.54616 .32565 m .54154 .32224 L .54615 .32645 L F
.54694 .30911 m .54399 .29841 L .54213 .31236 L .115 0 0 r
F
.54694 .30911 m .54876 .29548 L .54399 .29841 L F
.54625 .31852 m .54694 .30911 L .54213 .31236 L .163 .014 0 r
F
.54643 .31878 m .54694 .30911 L .54625 .31852 L F
.5464 .31047 m .54723 .30517 L .54694 .30911 L 1 .592 0 r
F
.54723 .30517 m .54876 .29548 L .54694 .30911 L F
.54154 .32224 m .5348 .31873 L .53451 .3278 L .401 .058 0 r
F
.54154 .32224 m .54213 .31236 L .5348 .31873 L F
.53559 .3403 m .52658 .34066 L .52742 .34565 L .679 .301 0 r
F
.53559 .3403 m .53485 .33472 L .52658 .34066 L F
.53658 .345 m .52742 .34565 L .52843 .34995 L .689 .357 0 r
F
.53658 .345 m .53559 .3403 L .52742 .34565 L F
.54174 .32966 m .53451 .3278 L .53485 .33472 L .436 .068 0 r
F
.54174 .32966 m .54154 .32224 L .53451 .3278 L F
.52742 .34565 m .5175 .34676 L .5184 .35106 L .826 .466 0 r
F
.52742 .34565 m .52658 .34066 L .5175 .34676 L F
.52843 .34995 m .52742 .34565 L .5184 .35106 L .825 .508 0 r
F
.53352 .34483 m .52508 .34445 L .5261 .34882 L .636 .323 0 r
F
.53352 .34483 m .53247 .34021 L .52508 .34445 L F
.53775 .3491 m .53658 .345 L .52843 .34995 L .695 .406 0 r
F
.53474 .34884 m .53352 .34483 L .5261 .34882 L .646 .38 0 r
F
.54643 .31878 m .54213 .31236 L .54154 .32224 L .163 .014 0 r
F
.53451 .3278 m .52583 .32704 L .526 .33465 L .65 .177 0 r
F
.53485 .33472 m .53451 .3278 L .526 .33465 L .666 .239 0 r
F
.53761 .33113 m .5313 .32768 L .53168 .33467 L .364 .061 0 r
F
.53451 .3278 m .5348 .31873 L .52583 .32704 L .65 .177 0 r
F
.53761 .33113 m .53725 .32399 L .5313 .32768 L .364 .061 0 r
F
.53485 .33472 m .526 .33465 L .52658 .34066 L .666 .239 0 r
F
.53844 .33674 m .53168 .33467 L .53247 .34021 L .389 .073 0 r
F
.53844 .33674 m .53761 .33113 L .53168 .33467 L F
.54153 .31289 m .53611 .3061 L .5348 .31873 L .376 .048 0 r
F
.54213 .31236 m .54167 .31189 L .54153 .31289 L F
.54167 .31189 m .53611 .3061 L .54153 .31289 L F
.54783 .27783 m .5442 .26042 L .53907 .28754 L .344 .036 0 r
F
.54783 .27783 m .55394 .24866 L .5442 .26042 L F
.54388 .29816 m .54783 .27783 L .53907 .28754 L .358 .041 0 r
F
.54399 .29841 m .54783 .27783 L .54388 .29816 L F
.5458 .28379 m .55119 .26054 L .54783 .27783 L 1 .667 0 r
F
.55119 .26054 m .55394 .24866 L .54783 .27783 L F
.55394 .24866 m .55038 .22682 L .5442 .26042 L .619 .064 0 r
F
.55394 .24866 m .54533 .27105 L .55038 .22682 L F
.54533 .27105 m .54507 .26842 L .55038 .22682 L F
.5442 .26042 m .55038 .22682 L .53657 .24847 L .587 .069 0 r
F
.5442 .26042 m .53657 .24847 L .53132 .27986 L F
.53132 .27986 m .53657 .24847 L .52083 .27826 L .794 .232 0 r
F
.53907 .28754 m .5442 .26042 L .53132 .27986 L .601 .07 0 r
F
.53645 .28387 m .54243 .25239 L .53092 .26863 L .532 .062 0 r
F
.53773 .28284 m .54243 .25239 L .53645 .28387 L .288 .024 0 r
F
.54342 .27823 m .54307 .2689 L .53773 .28284 L F
.55452 .19616 m .54387 .18661 L .54161 .2141 L .612 .14 0 r
F
.55452 .19616 m .55538 .1737 L .54387 .18661 L F
.55538 .1737 m .54343 .16737 L .54387 .18661 L .755 .152 0 r
F
.54551 .16847 m .54427 .17404 L .54343 .16737 L F
.54387 .18661 m .54343 .16737 L .53099 .18231 L .81 .36 0 r
F
.54427 .17404 m .54224 .17306 L .54343 .16737 L .755 .152 0 r
F
.55538 .1737 m .55244 .18386 L .54551 .16847 L F
.54387 .18661 m .53099 .18231 L .52956 .20913 L .81 .36 0 r
F
.52956 .20913 m .53099 .18231 L .51597 .21116 L .957 .453 0 r
F
.54161 .2141 m .54387 .18661 L .52956 .20913 L .796 .282 0 r
F
.54119 .19751 m .54209 .1732 L .52967 .18894 L .762 .277 0 r
F
.5417 .19692 m .54209 .1732 L .54119 .19751 L .582 .138 0 r
F
.55244 .18443 m .55149 .1834 L .5417 .19692 L F
.55263 .18428 m .55244 .18386 L .55244 .18443 L .665 .073 0 r
F
.55269 .18423 m .55244 .18386 L .55263 .18428 L F
.55038 .22682 m .55452 .19616 L .54161 .2141 L .587 .072 0 r
F
.54954 .21457 m .55244 .18443 L .54901 .21504 L .318 .038 0 r
F
.55024 .20789 m .55244 .18443 L .54954 .21457 L F
.54954 .21457 m .55271 .19236 L .55271 .20285 L 1 .732 0 r
F
.55261 .18524 m .55538 .1737 L .55012 .21054 L F
.55261 .18524 m .55012 .21054 L .54954 .21457 L F
.55271 .20285 m .55538 .1737 L .55452 .19616 L F
.55271 .19236 m .55538 .1737 L .55271 .20285 L F
.55261 .18524 m .55269 .18423 L .55244 .18443 L .318 .038 0 r
F
.55038 .22682 m .54161 .2141 L .53657 .24847 L .587 .072 0 r
F
.54337 .25155 m .54796 .22876 L .54665 .23997 L 1 .726 0 r
F
.5434 .25138 m .54378 .24951 L .54337 .25155 L F
.54378 .24951 m .55452 .19616 L .54376 .24961 L F
.54378 .24951 m .54376 .24961 L .54337 .25155 L F
.54911 .21755 m .54955 .21452 L .55452 .19616 L F
.54665 .23997 m .55452 .19616 L .55038 .22682 L F
.54796 .22876 m .55452 .19616 L .54665 .23997 L F
.54392 .2483 m .54901 .21504 L .54308 .24868 L .291 .026 0 r
F
.54911 .21755 m .55045 .21225 L .54344 .25117 L 1 .726 0 r
F
.55045 .21225 m .55452 .19616 L .54339 .25144 L F
.55045 .21225 m .54339 .25144 L .54344 .25117 L F
.54339 .25144 m .5434 .25138 L .54337 .25155 L F
.54504 .26813 m .54337 .25155 L .54938 .23034 L .619 .064 0 r
F
.54443 .27338 m .54337 .25155 L .54504 .26813 L F
.54443 .27338 m .54938 .23034 L .55038 .22682 L F
.54307 .2689 m .55025 .24542 L .54337 .25155 L .288 .024 0 r
F
.54257 .25598 m .54337 .25155 L .54243 .25239 L F
.54307 .2689 m .54337 .25155 L .54257 .25598 L F
.54342 .27823 m .54443 .27338 L .54307 .2689 L F
.54533 .27105 m .54443 .27338 L .54507 .26842 L .619 .064 0 r
F
.54443 .27338 m .55025 .24542 L .54307 .2689 L .288 .024 0 r
F
.54307 .2689 m .54257 .25598 L .5413 .26301 L F
.54307 .2689 m .5413 .26301 L .53773 .28284 L F
.54257 .25598 m .54243 .25239 L .53773 .28284 L F
.53132 .27986 m .52083 .27826 L .51781 .30201 L .794 .232 0 r
F
.52795 .30204 m .53132 .27986 L .51781 .30201 L .798 .245 0 r
F
.53907 .28754 m .53132 .27986 L .52795 .30204 L .601 .07 0 r
F
.53645 .28387 m .53092 .26863 L .52657 .29579 L .532 .062 0 r
F
.52795 .30204 m .51781 .30201 L .5164 .31746 L .798 .245 0 r
F
.53611 .3061 m .53907 .28754 L .52795 .30204 L .616 .079 0 r
F
.52633 .31679 m .52795 .30204 L .5164 .31746 L .805 .275 0 r
F
.53611 .3061 m .52795 .30204 L .52633 .31679 L .616 .079 0 r
F
.53304 .30474 m .52657 .29579 L .52441 .31322 L .548 .066 0 r
F
.53304 .30474 m .53645 .28387 L .52657 .29579 L F
.54399 .29841 m .53907 .28754 L .53611 .3061 L .358 .041 0 r
F
.53942 .30016 m .53645 .28387 L .53304 .30474 L .298 .028 0 r
F
.53942 .30016 m .54342 .27823 L .53645 .28387 L F
.52633 .31679 m .5164 .31746 L .516 .32798 L .805 .275 0 r
F
.52583 .32704 m .52633 .31679 L .516 .32798 L .812 .318 0 r
F
.5348 .31873 m .52633 .31679 L .52583 .32704 L .632 .121 0 r
F
.5348 .31873 m .53611 .3061 L .52633 .31679 L F
.52583 .32704 m .516 .32798 L .51619 .33571 L .812 .318 0 r
F
.516 .32798 m .5164 .31746 L .5057 .33065 L .941 .446 0 r
F
.52366 .32476 m .52441 .31322 L .51475 .32346 L .769 .266 0 r
F
.53159 .3183 m .52441 .31322 L .52366 .32476 L .566 .072 0 r
F
.53159 .3183 m .53304 .30474 L .52441 .31322 L F
.516 .32798 m .5057 .33065 L .50601 .33784 L .941 .446 0 r
F
.51619 .33571 m .516 .32798 L .50601 .33784 L .942 .489 0 r
F
.52366 .32476 m .51475 .32346 L .51471 .3324 L .769 .266 0 r
F
.526 .33465 m .51619 .33571 L .51673 .34176 L .819 .368 0 r
F
.526 .33465 m .52583 .32704 L .51619 .33571 L F
.5175 .34676 m .51673 .34176 L .50728 .34826 L .937 .574 0 r
F
.51619 .33571 m .50601 .33784 L .50657 .34352 L .942 .489 0 r
F
.51673 .34176 m .51619 .33571 L .50657 .34352 L .941 .533 0 r
F
.52372 .333 m .51471 .3324 L .51514 .33913 L .777 .319 0 r
F
.52372 .333 m .52366 .32476 L .51471 .3324 L F
.52658 .34066 m .51673 .34176 L .5175 .34676 L .824 .419 0 r
F
.52658 .34066 m .526 .33465 L .51673 .34176 L F
.5313 .32768 m .52366 .32476 L .52372 .333 L .585 .12 0 r
F
.5313 .32768 m .53159 .3183 L .52366 .32476 L F
.51673 .34176 m .50657 .34352 L .50728 .34826 L .941 .533 0 r
F
.52425 .33932 m .51514 .33913 L .51583 .34452 L .783 .375 0 r
F
.52425 .33932 m .52372 .333 L .51514 .33913 L F
.5175 .34676 m .50728 .34826 L .50808 .35238 L .937 .574 0 r
F
.5184 .35106 m .5175 .34676 L .50808 .35238 L .931 .61 0 r
F
.52508 .34445 m .51583 .34452 L .5167 .34906 L .787 .429 0 r
F
.52508 .34445 m .52425 .33932 L .51583 .34452 L F
.54443 .27338 m .51685 .3451 L .54337 .25155 L .619 .064 0 r
F
.55025 .24542 m .54392 .2483 L .54337 .25155 L .291 .026 0 r
F
.54392 .2483 m .54308 .24868 L .54337 .25155 L F
.54336 .25159 m .54339 .25144 L .54337 .25155 L 1 .726 0 r
F
.54344 .25117 m .54339 .25144 L .54336 .25159 L F
.54911 .21755 m .54901 .21504 L .54711 .22941 L .291 .026 0 r
F
.54911 .21755 m .54711 .22941 L .54466 .24796 L F
.54466 .24796 m .54711 .22941 L .54392 .2483 L F
.54711 .22941 m .54901 .21504 L .54392 .2483 L F
.54337 .25155 m .54308 .24868 L .54243 .25239 L F
.53657 .24847 m .54161 .2141 L .52548 .24452 L .792 .241 0 r
F
.54243 .25239 m .54901 .21504 L .5369 .23197 L .52 .062 0 r
F
.53657 .24847 m .52548 .24452 L .52083 .27826 L .792 .241 0 r
F
.54243 .25239 m .5369 .23197 L .53092 .26863 L .52 .062 0 r
F
.51685 .3451 m .54911 .21755 L .54336 .25159 L 1 .726 0 r
F
.54911 .21755 m .54344 .25117 L .54336 .25159 L F
.55025 .24542 m .55738 .20768 L .54962 .2145 L .291 .026 0 r
F
.54911 .21755 m .54954 .21457 L .54901 .21504 L F
.5164 .31746 m .51781 .30201 L .5058 .32091 L .938 .41 0 r
F
.52441 .31322 m .52657 .29579 L .51558 .31059 L .761 .223 0 r
F
.5164 .31746 m .5058 .32091 L .5057 .33065 L .938 .41 0 r
F
.52441 .31322 m .51558 .31059 L .51475 .32346 L .761 .223 0 r
F
.50728 .34826 m .50657 .34352 L .49724 .34993 L 1 .682 0 r
F
.51583 .34452 m .51514 .33913 L .50614 .34517 L .91 .535 0 r
F
.51685 .3451 m .51491 .34256 L .54954 .21457 L 1 .726 0 r
F
.54954 .21458 m .54954 .21457 L .54955 .21452 L F
.51685 .3451 m .54954 .21457 L .54954 .21458 L F
.54911 .21755 m .54962 .2145 L .54954 .21457 L .291 .026 0 r
F
.55025 .24542 m .54962 .2145 L .54911 .21755 L F
.51685 .3451 m .54955 .21452 L .54911 .21755 L 1 .726 0 r
F
.55025 .24542 m .54911 .21755 L .54466 .24796 L .291 .026 0 r
F
.55157 .19776 m .55244 .18443 L .54962 .2145 L .318 .038 0 r
F
.55288 .18649 m .55261 .18524 L .55157 .19776 L F
.55261 .18524 m .55244 .18443 L .55157 .19776 L F
.54161 .2141 m .52956 .20913 L .52548 .24452 L .796 .282 0 r
F
.54901 .21504 m .54119 .19751 L .5369 .23197 L .536 .068 0 r
F
.54901 .21504 m .55244 .18443 L .54119 .19751 L F
.51781 .30201 m .52083 .27826 L .50662 .30659 L .938 .387 0 r
F
.52657 .29579 m .53092 .26863 L .51782 .29061 L .754 .196 0 r
F
.51781 .30201 m .50662 .30659 L .5058 .32091 L .938 .387 0 r
F
.52657 .29579 m .51782 .29061 L .51558 .31059 L .754 .196 0 r
F
.50657 .34352 m .50601 .33784 L .49661 .34565 L 1 .647 0 r
F
.51514 .33913 m .51471 .3324 L .50552 .33988 L .913 .489 0 r
F
.50657 .34352 m .49661 .34565 L .49724 .34993 L 1 .647 0 r
F
.51514 .33913 m .50552 .33988 L .50614 .34517 L .913 .489 0 r
F
.51491 .34256 m .51305 .33963 L .55269 .18423 L 1 .732 0 r
F
.55271 .18482 m .55269 .18423 L .55538 .1737 L F
.55269 .18423 m .55247 .18375 L .55278 .18386 L .555 .382 0 r
F
.55244 .18443 m .55244 .18386 L .54224 .17306 L .582 .138 0 r
F
.55244 .18443 m .54224 .17306 L .54225 .17337 L F
.55149 .1834 m .54225 .17337 L .54209 .18006 L F
.55149 .1834 m .54209 .18006 L .5417 .19692 L F
.54225 .17337 m .54209 .1732 L .5417 .19692 L F
.52956 .20913 m .51597 .21116 L .51238 .24968 L .957 .453 0 r
F
.52548 .24452 m .52956 .20913 L .51238 .24968 L .953 .41 0 r
F
.54119 .19751 m .52967 .18894 L .52703 .22099 L .762 .277 0 r
F
.5369 .23197 m .54119 .19751 L .52703 .22099 L .745 .207 0 r
F
.52548 .24452 m .51238 .24968 L .50871 .28398 L .953 .41 0 r
F
.52083 .27826 m .52548 .24452 L .50871 .28398 L .944 .386 0 r
F
.5369 .23197 m .52703 .22099 L .52205 .25952 L .745 .207 0 r
F
.53092 .26863 m .5369 .23197 L .52205 .25952 L .747 .187 0 r
F
.52083 .27826 m .50871 .28398 L .50662 .30659 L .944 .386 0 r
F
.53092 .26863 m .52205 .25952 L .51782 .29061 L .747 .187 0 r
F
.5058 .32091 m .50662 .30659 L .49547 .32627 L 1 .531 0 r
F
.51558 .31059 m .51782 .29061 L .50559 .31173 L .91 .367 0 r
F
.5058 .32091 m .50147 .32316 L .49834 .33086 L 1 .531 0 r
F
.5057 .33065 m .5058 .32091 L .49566 .33444 L 1 .567 0 r
F
.51558 .31059 m .50614 .31167 L .50503 .32448 L .91 .367 0 r
F
.50614 .31167 m .50559 .31173 L .50552 .3132 L F
.50614 .31167 m .50552 .3132 L .50503 .32448 L F
.49834 .33086 m .49547 .32627 L .49566 .33444 L 1 .531 0 r
F
.50147 .32316 m .49547 .32627 L .49834 .33086 L F
.51475 .32346 m .51558 .31059 L .50503 .32448 L .911 .399 0 r
F
.5057 .33065 m .49566 .33444 L .49607 .34063 L 1 .567 0 r
F
.50601 .33784 m .5057 .33065 L .49607 .34063 L 1 .607 0 r
F
.51475 .32346 m .50503 .32448 L .5051 .33328 L .911 .399 0 r
F
.51471 .3324 m .51475 .32346 L .5051 .33328 L .913 .442 0 r
F
.50601 .33784 m .49607 .34063 L .49661 .34565 L 1 .607 0 r
F
.51471 .3324 m .5051 .33328 L .50552 .33988 L .913 .442 0 r
F
.55244 .18386 m .50773 .33845 L .54406 .17499 L .755 .152 0 r
F
.55244 .18386 m .54406 .17499 L .54551 .16847 L F
.54225 .17337 m .54224 .17306 L .54209 .1732 L .582 .138 0 r
F
.50662 .30659 m .50871 .28398 L .49569 .31455 L 1 .507 0 r
F
.51782 .29061 m .52205 .25952 L .50727 .29161 L .911 .353 0 r
F
.50662 .30659 m .50236 .30969 L .49865 .32067 L 1 .507 0 r
F
.51782 .29061 m .50853 .29149 L .50559 .31173 L .911 .353 0 r
F
.50853 .29149 m .50727 .29161 L .50687 .29638 L F
.50853 .29149 m .50687 .29638 L .50559 .31173 L F
.49865 .32067 m .49569 .31455 L .49547 .32627 L 1 .507 0 r
F
.50236 .30969 m .49569 .31455 L .49865 .32067 L F
.54427 .17404 m .50773 .33845 L .54224 .17306 L .755 .152 0 r
F
.55244 .18386 m .55235 .16366 L .54224 .17306 L .582 .138 0 r
F
.54343 .16737 m .53018 .16395 L .53099 .18231 L .826 .458 0 r
F
.54343 .16737 m .5413 .15359 L .53018 .16395 L F
.54224 .17306 m .54252 .16151 L .54225 .173 L 1 .787 0 r
F
.54222 .17284 m .54062 .15676 L .54207 .17298 L .636 .28 0 r
F
.5416 .16621 m .54211 .16359 L .54224 .17306 L 1 .787 0 r
F
.54211 .16359 m .54252 .16151 L .54224 .17306 L F
.54077 .15741 m .54062 .15676 L .54222 .17284 L .636 .28 0 r
F
.54071 .15681 m .54071 .15681 L .54077 .15741 L F
.54071 .15681 m .54062 .15676 L .54077 .15741 L F
.5413 .15359 m .52805 .15078 L .53018 .16395 L .838 .556 0 r
F
.5413 .15359 m .53819 .14305 L .52805 .15078 L F
.53018 .16395 m .51666 .16234 L .51731 .18182 L .957 .596 0 r
F
.53018 .16395 m .52805 .15078 L .51666 .16234 L F
.53099 .18231 m .53018 .16395 L .51731 .18182 L .958 .518 0 r
F
.54062 .15676 m .52774 .15264 L .52954 .1674 L .812 .497 0 r
F
.54062 .15676 m .53783 .14485 L .52774 .15264 L F
.53099 .18231 m .51731 .18182 L .51597 .21116 L .958 .518 0 r
F
.54209 .1732 m .52954 .1674 L .52967 .18894 L .789 .383 0 r
F
.54209 .1732 m .54062 .15676 L .52954 .1674 L F
.54069 .1567 m .53783 .14485 L .54062 .15676 L .797 .212 0 r
F
.53945 .15149 m .5382 .14311 L .53992 .14892 L 1 .805 0 r
F
.5382 .14311 m .53819 .14305 L .5382 .14309 L F
.5382 .14311 m .5382 .14309 L .53992 .14892 L F
.53788 .14487 m .53783 .14485 L .54069 .1567 L .797 .212 0 r
F
.51238 .24968 m .51365 .23601 L .49889 .26506 L 1 .542 0 r
F
.51365 .23601 m .51597 .21116 L .50945 .23173 L F
.51365 .23601 m .50945 .23173 L .49889 .26506 L F
.51597 .21116 m .51678 .19352 L .50198 .2226 L 1 .589 0 r
F
.51678 .19352 m .51731 .18182 L .51394 .19078 L F
.51678 .19352 m .51394 .19078 L .50198 .2226 L F
.51731 .18182 m .51689 .16916 L .5037 .18621 L 1 .64 0 r
F
.51689 .16916 m .51666 .16234 L .51399 .16726 L F
.51689 .16916 m .51399 .16726 L .5037 .18621 L F
.51666 .16234 m .51547 .15323 L .50354 .16278 L 1 .703 0 r
F
.51547 .15323 m .51487 .1487 L .51236 .15183 L F
.51547 .15323 m .51236 .15183 L .50354 .16278 L F
.51487 .1487 m .5023 .14736 L .50354 .16278 L 1 .767 0 r
F
.51487 .1487 m .51248 .13831 L .5023 .14736 L F
.51473 .14979 m .5124 .1389 L .50273 .14748 L 1 .746 0 r
F
.50354 .16278 m .50245 .14919 L .49133 .16745 L 1 .795 0 r
F
.50245 .14919 m .5023 .14736 L .50163 .14859 L F
.50245 .14919 m .50163 .14859 L .49133 .16745 L F
.5023 .14736 m .49077 .14754 L .49133 .16745 L 1 .849 0 r
F
.5023 .14736 m .50072 .13737 L .49077 .14754 L F
.50072 .13737 m .50051 .1361 L .49984 .13689 L F
.50072 .13737 m .49984 .13689 L .49077 .14754 L F
.50638 .13468 m .50397 .12939 L .49357 .13213 L .95 .969 0 r
F
.50637 .13474 m .50396 .12944 L .49357 .13213 L .947 .966 0 r
F
.5038 .12621 m .49218 .1232 L .49383 .12803 L .876 .966 0 r
F
.50427 .12612 m .5037 .12599 L .5038 .12621 L F
.5037 .12599 m .49218 .1232 L .5038 .12621 L F
.51755 .12827 m .51423 .12369 L .50427 .12612 L .847 .937 0 r
F
.50427 .12612 m .50175 .12142 L .49218 .1232 L .876 .966 0 r
F
.51423 .12369 m .50175 .12142 L .50427 .12612 L .846 .942 0 r
F
.51422 .12372 m .5018 .12144 L .50427 .12614 L .845 .941 0 r
F
.5018 .12144 m .50175 .12144 L .50195 .12181 L F
.5018 .12144 m .50195 .12181 L .50427 .12614 L F
.50427 .12614 m .49218 .1232 L .49383 .12803 L .875 .965 0 r
F
.50397 .12939 m .49198 .12667 L .49357 .13213 L .944 .975 0 r
F
.50396 .12944 m .49198 .12667 L .49357 .13213 L .941 .972 0 r
F
.50427 .12614 m .50175 .12144 L .49218 .1232 L .875 .965 0 r
F
.50397 .12939 m .50152 .12419 L .49198 .12667 L .944 .975 0 r
F
.50396 .12944 m .50151 .12423 L .49198 .12667 L .941 .972 0 r
F
.50051 .1361 m .48968 .1343 L .49077 .14754 L 1 .899 0 r
F
.50051 .1361 m .49864 .12804 L .48968 .1343 L F
.49864 .12804 m .49842 .12713 L .49777 .12766 L F
.49864 .12804 m .49777 .12766 L .48968 .1343 L F
.50135 .1215 m .49052 .11842 L .49218 .1232 L .874 .971 0 r
F
.50175 .12142 m .50126 .12129 L .50135 .1215 L F
.50126 .12129 m .49052 .11842 L .50135 .1215 L F
.51423 .12369 m .51088 .11917 L .50175 .12142 L .846 .942 0 r
F
.50175 .12142 m .49921 .11678 L .49052 .11842 L .874 .971 0 r
F
.51088 .11917 m .49921 .11678 L .50175 .12142 L .844 .948 0 r
F
.51088 .11919 m .49934 .11682 L .50175 .12144 L .843 .947 0 r
F
.49934 .11682 m .49921 .11679 L .49974 .11775 L F
.49934 .11682 m .49974 .11775 L .50175 .12144 L F
.50175 .12144 m .49052 .11842 L .49218 .1232 L .873 .97 0 r
F
.50152 .12419 m .49037 .12131 L .49198 .12667 L .937 .98 0 r
F
.50151 .12423 m .49037 .12131 L .49198 .12667 L .935 .978 0 r
F
.50175 .12144 m .49921 .11679 L .49052 .11842 L .873 .97 0 r
F
.50152 .12419 m .49904 .11909 L .49037 .12131 L .937 .98 0 r
F
.50151 .12423 m .49904 .11912 L .49037 .12131 L .935 .978 0 r
F
.49887 .11684 m .48884 .11369 L .49052 .11842 L .872 .976 0 r
F
.49921 .11678 m .49879 .11665 L .49887 .11684 L F
.49879 .11665 m .48884 .11369 L .49887 .11684 L F
.51088 .11917 m .50751 .11471 L .49921 .11678 L .844 .948 0 r
F
.50751 .11471 m .49665 .11219 L .49921 .11678 L .843 .953 0 r
F
.50751 .11473 m .49685 .11225 L .49921 .11679 L .842 .952 0 r
F
.49685 .11225 m .49665 .1122 L .49748 .11369 L F
.49685 .11225 m .49748 .11369 L .49921 .11679 L F
.49921 .11679 m .48884 .11369 L .49052 .11842 L .871 .975 0 r
F
.49904 .11909 m .48873 .11605 L .49037 .12131 L .931 .986 0 r
F
.49904 .11912 m .48873 .11605 L .49037 .12131 L .929 .984 0 r
F
.49842 .12713 m .48833 .12437 L .48968 .1343 L 1 .937 0 r
F
.49842 .12713 m .49615 .11954 L .48833 .12437 L F
.49841 .12728 m .49615 .11963 L .48911 .1239 L 1 .931 0 r
F
.49391 .12598 m .48911 .1239 L .48833 .12437 L F
.49841 .12728 m .48911 .1239 L .49391 .12598 L F
.50049 .13638 m .49841 .12728 L .49188 .13253 L 1 .89 0 r
F
.49806 .13591 m .49188 .13253 L .48968 .1343 L F
.50049 .13638 m .49188 .13253 L .49806 .13591 L F
.50225 .1479 m .50049 .13638 L .49445 .14331 L 1 .836 0 r
F
.50062 .14785 m .49445 .14331 L .49077 .14754 L F
.50225 .1479 m .49445 .14331 L .50062 .14785 L F
.50437 .14822 m .50273 .14748 L .50225 .1479 L 1 .746 0 r
F
.51473 .14979 m .50273 .14748 L .50437 .14822 L F
.51666 .16234 m .50354 .16278 L .5037 .18621 L 1 .703 0 r
F
.51636 .16443 m .51473 .14979 L .5053 .16156 L 1 .674 0 r
F
.5037 .18621 m .50356 .16569 L .49077 .20088 L 1 .746 0 r
F
.50356 .16569 m .50354 .16278 L .50282 .16492 L F
.50356 .16569 m .50282 .16492 L .49077 .20088 L F
.50354 .16278 m .49133 .16745 L .49077 .20088 L 1 .795 0 r
F
.50343 .1639 m .50225 .1479 L .49646 .15828 L 1 .777 0 r
F
.50219 .16426 m .49646 .15828 L .49133 .16745 L F
.50343 .1639 m .49646 .15828 L .50219 .16426 L F
.50922 .16413 m .5053 .16156 L .50343 .1639 L 1 .674 0 r
F
.51636 .16443 m .5053 .16156 L .50922 .16413 L F
.51731 .18182 m .5037 .18621 L .50198 .2226 L 1 .64 0 r
F
.51667 .18601 m .51636 .16443 L .50626 .18333 L 1 .605 0 r
F
.50198 .2226 m .50344 .19169 L .48879 .24886 L 1 .696 0 r
F
.50344 .19169 m .5037 .18621 L .50258 .1909 L F
.50344 .19169 m .50258 .1909 L .48879 .24886 L F
.5037 .18621 m .49077 .20088 L .48879 .24886 L 1 .746 0 r
F
.50344 .18859 m .50343 .1639 L .49619 .18506 L 1 .724 0 r
F
.5018 .19018 m .49619 .18506 L .49077 .20088 L F
.50344 .18859 m .49619 .18506 L .5018 .19018 L F
.51031 .18725 m .50626 .18333 L .50344 .18859 L 1 .605 0 r
F
.51667 .18601 m .50626 .18333 L .51031 .18725 L F
.51597 .21116 m .50198 .2226 L .49889 .26506 L 1 .589 0 r
F
.51468 .21895 m .51667 .18601 L .50236 .22451 L 1 .55 0 r
F
.49889 .26506 m .50099 .23614 L .48699 .28799 L 1 .635 0 r
F
.50099 .23614 m .50198 .2226 L .49841 .23818 L F
.50099 .23614 m .49841 .23818 L .48699 .28799 L F
.50198 .2226 m .48879 .24886 L .48699 .28799 L 1 .696 0 r
F
.50147 .22691 m .50344 .18859 L .48971 .24504 L 1 .671 0 r
F
.49206 .24319 m .48971 .24504 L .48879 .24886 L F
.50147 .22691 m .48971 .24504 L .49206 .24319 L F
.50351 .22568 m .50236 .22451 L .50147 .22691 L 1 .55 0 r
F
.51468 .21895 m .50236 .22451 L .50351 .22568 L F
.52703 .22099 m .52967 .18894 L .51468 .21895 L .92 .397 0 r
F
.51238 .24968 m .49889 .26506 L .49666 .29598 L 1 .542 0 r
F
.50871 .28398 m .51238 .24968 L .49666 .29598 L 1 .508 0 r
F
.52703 .22099 m .51468 .21895 L .51065 .25942 L .92 .397 0 r
F
.52205 .25952 m .52703 .22099 L .51065 .25942 L .915 .362 0 r
F
.50871 .28398 m .50431 .28837 L .50109 .30187 L 1 .508 0 r
F
.52205 .25952 m .5112 .25943 L .50727 .29161 L .915 .362 0 r
F
.5112 .25943 m .51065 .25942 L .51021 .26356 L F
.5112 .25943 m .51021 .26356 L .50727 .29161 L F
.50109 .30187 m .49666 .29598 L .49569 .31455 L 1 .508 0 r
F
.50431 .28837 m .49666 .29598 L .50109 .30187 L F
.49607 .34063 m .49566 .33444 L .48927 .341 L 1 .727 0 r
F
.48825 .34305 m .48927 .341 L .48685 .34348 L F
.49607 .34063 m .48927 .341 L .48825 .34305 L F
.49566 .33444 m .49547 .32627 L .48683 .33794 L 1 .688 0 r
F
.48663 .33836 m .48683 .33794 L .48647 .33843 L F
.49566 .33444 m .48683 .33794 L .48663 .33836 L F
.50559 .31173 m .49792 .31536 L .49526 .32768 L 1 .493 0 r
F
.49547 .32627 m .49569 .31455 L .48618 .33206 L 1 .649 0 r
F
.49792 .31536 m .4954 .31655 L .49535 .3206 L 1 .493 0 r
F
.48683 .33794 m .48618 .33206 L .48647 .33843 L 1 .649 0 r
F
.49547 .32627 m .49309 .32776 L .48683 .33794 L F
.49309 .32776 m .48618 .33206 L .48683 .33794 L F
.49792 .31536 m .49535 .3206 L .4953 .32416 L 1 .493 0 r
F
.4964 .32236 m .4953 .32416 L .49526 .32768 L F
.49792 .31536 m .4953 .32416 L .4964 .32236 L F
.48927 .341 m .48647 .33843 L .48685 .34348 L 1 .688 0 r
F
.49566 .33444 m .49319 .33551 L .48927 .341 L F
.49319 .33551 m .48647 .33843 L .48927 .341 L F
.50503 .32448 m .49986 .32617 L .49549 .33549 L 1 .522 0 r
F
.49986 .32617 m .49598 .32744 L .4957 .33199 L F
.49986 .32617 m .4957 .33199 L .49549 .33549 L F
.49598 .32744 m .49526 .32768 L .49529 .32883 L F
.49598 .32744 m .49529 .32883 L .49549 .33549 L F
.5051 .33328 m .50503 .32448 L .49549 .33549 L 1 .561 0 r
F
.53788 .14487 m .50475 .32914 L .53783 .14485 L .797 .212 0 r
F
.53788 .14487 m .53819 .14305 L .53945 .15149 L 1 .805 0 r
F
.5407 .15669 m .53992 .14892 L .5413 .15359 L F
.54069 .1567 m .53992 .14892 L .5407 .15669 L F
.54071 .15681 m .54069 .1567 L .54062 .15676 L .636 .28 0 r
F
.50631 .33374 m .53973 .14998 L .54069 .1567 L 1 .805 0 r
F
.53973 .14998 m .53992 .14892 L .54069 .1567 L F
.50773 .33845 m .50631 .33374 L .54069 .1567 L 1 .787 0 r
F
.54071 .15681 m .54069 .1567 L .5413 .15359 L F
.54071 .15681 m .54069 .1567 L .54071 .15681 L .636 .28 0 r
F
.50773 .33845 m .54069 .1567 L .54071 .15681 L 1 .787 0 r
F
.54218 .16322 m .5413 .15359 L .54252 .16151 L F
.54164 .16083 m .5413 .15359 L .54218 .16322 L F
.54071 .15681 m .5413 .15359 L .54183 .165 L F
.55235 .16366 m .54069 .1567 L .54071 .15681 L .636 .28 0 r
F
.5407 .1567 m .53788 .14487 L .54069 .1567 L .797 .212 0 r
F
.55009 .14935 m .53801 .14492 L .5407 .1567 L F
.53801 .14492 m .53788 .14487 L .5407 .1567 L F
.54183 .165 m .54164 .16083 L .54218 .16322 L 1 .787 0 r
F
.50773 .33845 m .54071 .15681 L .54183 .165 L F
.55235 .16366 m .55009 .14935 L .5407 .1567 L .636 .28 0 r
F
.5407 .1567 m .5407 .1567 L .54069 .1567 L F
.55235 .16366 m .5407 .1567 L .5407 .1567 L F
.50631 .33374 m .52672 .21166 L .53945 .15149 L 1 .805 0 r
F
.52672 .21166 m .53788 .14487 L .53855 .14768 L F
.52672 .21166 m .53855 .14768 L .53945 .15149 L F
.54225 .173 m .54252 .16151 L .54343 .16737 L 1 .787 0 r
F
.55235 .16366 m .54071 .15681 L .54222 .17284 L .636 .28 0 r
F
.54224 .17306 m .54207 .17298 L .54209 .1732 L F
.55235 .16366 m .54207 .17298 L .54224 .17306 L F
.50773 .33845 m .5416 .16621 L .54224 .17306 L 1 .787 0 r
F
.51305 .33963 m .50773 .33845 L .55244 .18386 L .555 .382 0 r
F
.52672 .21166 m .50695 .31779 L .53788 .14487 L 1 .805 0 r
F
.50631 .33374 m .50533 .32686 L .52672 .21166 L F
.50533 .32686 m .50475 .32914 L .50519 .32668 L .797 .212 0 r
F
.50533 .32686 m .50519 .32668 L .53788 .14487 L F
.50535 .32671 m .5053 .32665 L .52672 .21166 L 1 .805 0 r
F
.50567 .32549 m .50533 .32686 L .53788 .14487 L .797 .212 0 r
F
.50902 .33172 m .50533 .32686 L .50631 .33374 L .459 .106 0 r
F
.50496 .32933 m .50488 .32926 L .50537 .3269 L .435 .121 0 r
F
.5054 .32693 m .50537 .3269 L .50567 .32549 L F
.50496 .32933 m .50537 .3269 L .5054 .32693 L F
.5097 .3312 m .50533 .32686 L .50902 .33172 L .459 .106 0 r
F
.50488 .32926 m .50533 .32686 L .50567 .32549 L .435 .121 0 r
F
.51121 .33597 m .50974 .33133 L .50631 .33374 L .513 .253 0 r
F
.51121 .33597 m .5097 .3312 L .55009 .14935 L 1 .748 0 r
F
.50983 .33127 m .5097 .3312 L .50631 .33374 L .513 .253 0 r
F
.51128 .33588 m .55009 .14935 L .55235 .16366 L 1 .748 0 r
F
.51124 .33602 m .51127 .33587 L .51128 .33588 L F
.51127 .33587 m .55009 .14935 L .51128 .33588 L F
.51124 .33602 m .55009 .14935 L .51124 .33602 L F
.51123 .33606 m .50631 .33374 L .50773 .33845 L .513 .253 0 r
F
.51123 .33605 m .50631 .33374 L .51123 .33606 L F
.51121 .33597 m .55009 .14935 L .51123 .33606 L 1 .748 0 r
F
.51121 .33597 m .50631 .33374 L .51123 .33605 L .513 .253 0 r
F
.51121 .33597 m .51123 .33606 L .51123 .33606 L 1 .748 0 r
F
.51121 .33597 m .51123 .33605 L .51124 .33605 L .513 .253 0 r
F
.51305 .33963 m .55244 .18386 L .55269 .18423 L .555 .382 0 r
F
.55244 .18386 m .55247 .18375 L .55269 .18423 L F
.55278 .18386 m .55247 .18375 L .55538 .1737 L F
.55271 .18421 m .55235 .16366 L .55241 .17737 L .665 .073 0 r
F
.55244 .18386 m .55244 .18386 L .55247 .18375 L .555 .382 0 r
F
.55269 .18418 m .55241 .17737 L .55244 .18386 L .665 .073 0 r
F
.55271 .18421 m .55241 .17737 L .55269 .18418 L F
.55261 .18524 m .55269 .18423 L .55271 .18482 L 1 .732 0 r
F
.51491 .34256 m .55269 .18423 L .55261 .18524 L F
.55261 .18524 m .55271 .18421 L .55269 .18423 L .318 .038 0 r
F
.55738 .20768 m .56083 .17768 L .55271 .18421 L F
.55738 .20768 m .55271 .18421 L .55261 .18524 L F
.55271 .18421 m .55244 .18386 L .55269 .18423 L .665 .073 0 r
F
.51305 .33963 m .55244 .18386 L .55244 .18386 L .555 .382 0 r
F
.56083 .17768 m .55272 .16426 L .55271 .18421 L .665 .073 0 r
F
.55272 .16426 m .55235 .16366 L .55271 .18421 L F
.51491 .34256 m .55261 .18524 L .54954 .21457 L 1 .732 0 r
F
.54962 .2145 m .55024 .20789 L .54954 .21457 L .318 .038 0 r
F
.55738 .20768 m .55288 .18649 L .54962 .2145 L F
.56083 .17768 m .51133 .33608 L .55235 .16366 L .665 .073 0 r
F
.51305 .33963 m .51133 .33608 L .51127 .33612 L .555 .382 0 r
F
.51266 .33954 m .51126 .33613 L .50773 .33845 L F
.51088 .33753 m .5112 .33599 L .51123 .33606 L 1 .748 0 r
F
.5112 .33599 m .51121 .33597 L .51123 .33604 L F
.5112 .33599 m .51123 .33604 L .51123 .33606 L F
.51291 .3396 m .51127 .33612 L .51126 .33613 L .555 .382 0 r
F
.51291 .3396 m .51126 .33613 L .51266 .33954 L F
.51305 .33963 m .51127 .33612 L .51291 .3396 L F
.51127 .33612 m .51123 .33606 L .50773 .33845 L F
.51133 .33608 m .51124 .33606 L .51127 .33612 L F
.51124 .33606 m .51123 .33606 L .51127 .33612 L F
.5102 .33386 m .50965 .33143 L .50985 .33202 L 1 .748 0 r
F
.51088 .33753 m .5101 .33366 L .5102 .33386 L F
.5101 .33366 m .50965 .33143 L .5102 .33386 L F
.51088 .33753 m .50926 .33321 L .50946 .3323 L F
.5101 .33366 m .50946 .3323 L .50965 .33143 L F
.51088 .33753 m .50946 .3323 L .5101 .33366 L F
.51133 .33608 m .51088 .33753 L .51123 .33606 L .665 .073 0 r
F
.51133 .33608 m .51124 .33603 L .55235 .16366 L F
.51516 .33811 m .51133 .33608 L .51305 .33963 L .352 .213 0 r
F
.51788 .3404 m .56083 .17768 L .55738 .20768 L 1 .684 0 r
F
.53766 .3143 m .53304 .30474 L .53159 .3183 L .316 .037 0 r
F
.54213 .31236 m .54399 .29841 L .53611 .3061 L .376 .048 0 r
F
.53766 .3143 m .53942 .30016 L .53304 .30474 L .316 .037 0 r
F
.53168 .33467 m .52372 .333 L .52425 .33932 L .605 .188 0 r
F
.53168 .33467 m .5313 .32768 L .52372 .333 L F
.52215 .34493 m .51685 .3451 L .54442 .27342 L .469 .501 0 r
F
.54506 .27556 m .54442 .27342 L .54443 .27338 L F
.54508 .2755 m .54443 .27338 L .55394 .24866 L F
.54506 .27556 m .54443 .27338 L .54508 .2755 L F
.54384 .27849 m .54443 .27338 L .54342 .27823 L 0 0 0 r
F
.52215 .34493 m .54442 .27342 L .54443 .27345 L .469 .501 0 r
F
.54405 .27861 m .54443 .27345 L .54506 .27556 L F
.54405 .27861 m .54443 .27338 L .54384 .27849 L 0 0 0 r
F
.54022 .30018 m .54342 .27823 L .53942 .30016 L F
.54053 .29928 m .54813 .26793 L .5458 .28379 L 1 .667 0 r
F
.54022 .30018 m .54076 .29799 L .54053 .29928 L F
.54076 .29799 m .54813 .26793 L .54053 .29928 L F
.5411 .29554 m .54813 .26793 L .54022 .30018 L F
.54325 .28411 m .54342 .27823 L .54022 .30018 L 0 0 0 r
F
.53826 .31413 m .53942 .30016 L .53766 .3143 L .002 0 0 r
F
.54134 .31326 m .54048 .30739 L .53826 .31413 L F
.54116 .32225 m .53766 .3143 L .53725 .32399 L .064 0 0 r
F
.5261 .34882 m .52508 .34445 L .5167 .34906 L .788 .476 0 r
F
.53725 .32399 m .53159 .3183 L .5313 .32768 L .339 .048 0 r
F
.53725 .32399 m .53766 .3143 L .53159 .3183 L F
.53247 .34021 m .52425 .33932 L .52508 .34445 L .622 .258 0 r
F
.53247 .34021 m .53168 .33467 L .52425 .33932 L F
.54142 .29216 m .54136 .29257 L .54094 .29455 L 1 .667 0 r
F
.53985 .3031 m .54022 .30018 L .53942 .30016 L .002 0 0 r
F
.53985 .3031 m .53942 .30016 L .53826 .31413 L F
.54098 .29428 m .54094 .29455 L .539 .30377 L 1 .667 0 r
F
.54142 .29216 m .54094 .29455 L .54098 .29428 L F
.54876 .29548 m .54783 .27783 L .54399 .29841 L .479 .044 0 r
F
.54876 .29548 m .54165 .31045 L .54783 .27783 L F
.54048 .30739 m .541 .30577 L .54022 .30018 L .002 0 0 r
F
.54048 .30739 m .54022 .30018 L .53985 .3031 L F
.54134 .31326 m .54165 .31045 L .54048 .30739 L F
.54165 .31045 m .54022 .30018 L .54202 .29491 L .479 .044 0 r
F
.54165 .31045 m .54202 .29491 L .54783 .27783 L F
.54165 .31047 m .54165 .31045 L .5417 .31034 L .39 .486 0 r
F
.5417 .31034 m .5417 .31034 L .54172 .31029 L F
.54157 .31348 m .54165 .31045 L .54134 .31326 L 0 0 0 r
F
.54165 .3105 m .5417 .31034 L .5417 .31034 L .39 .486 0 r
F
.54116 .32225 m .54134 .31326 L .53766 .3143 L .064 0 0 r
F
.52912 .34616 m .54165 .31049 L .54165 .3105 L .39 .486 0 r
F
.54165 .31049 m .5417 .31034 L .54165 .3105 L F
.54173 .31363 m .54165 .31045 L .54157 .31348 L 0 0 0 r
F
.54172 .32893 m .53725 .32399 L .53761 .33113 L .129 .021 0 r
F
.54172 .32893 m .54116 .32225 L .53725 .32399 L F
.54671 .32605 m .54643 .31878 L .54622 .31893 L .212 .032 0 r
F
.54616 .32565 m .54622 .31893 L .54154 .32224 L F
.54671 .32605 m .54622 .31893 L .54616 .32565 L F
.54628 .31077 m .54653 .30222 L .5464 .31047 L 1 .592 0 r
F
.54206 .32129 m .54634 .303 L .54628 .31077 L F
.54205 .32076 m .54634 .303 L .54206 .32129 L F
.54191 .31618 m .54215 .31543 L .5417 .3222 L F
.54215 .31543 m .54653 .30222 L .54176 .32192 L F
.54215 .31543 m .54176 .32192 L .5417 .3222 L F
.54241 .31188 m .54172 .31029 L .54876 .29548 L .39 .486 0 r
F
.54191 .31618 m .54173 .31363 L .54134 .31326 L 0 0 0 r
F
.5417 .3222 m .54134 .31326 L .54116 .32225 L F
.54191 .31618 m .54134 .31326 L .5417 .3222 L F
.53957 .34137 m .53247 .34021 L .53352 .34483 L .425 .142 0 r
F
.53957 .34137 m .53844 .33674 L .53247 .34021 L F
.53142 .34785 m .52912 .34616 L .54173 .31363 L 1 .592 0 r
F
.54191 .31618 m .54173 .31363 L .54876 .29548 L F
.53142 .34785 m .54173 .31363 L .54191 .31618 L F
.54191 .31618 m .54183 .31372 L .54173 .31363 L 0 0 0 r
F
.54282 .30868 m .54328 .30394 L .54298 .30172 L F
.54274 .30566 m .54298 .30172 L .54277 .30025 L F
.54269 .31454 m .54298 .30172 L .54274 .30566 L F
.54173 .31363 m .54172 .31029 L .54241 .31188 L .39 .486 0 r
F
.52912 .34616 m .54165 .3105 L .54173 .31363 L F
.54165 .3105 m .54172 .31029 L .54173 .31363 L F
.54269 .31454 m .54277 .30025 L .54165 .31045 L 0 0 0 r
F
.54813 .26793 m .55394 .24866 L .5458 .28379 L 1 .667 0 r
F
.54328 .30394 m .5464 .28007 L .54277 .30025 L 0 0 0 r
F
.54182 .30912 m .54395 .29708 L .54328 .30394 L .339 .022 0 r
F
.54328 .30394 m .54559 .28786 L .5464 .28007 L 0 0 0 r
F
.54395 .29708 m .54559 .28786 L .54328 .30394 L .339 .022 0 r
F
.54269 .31454 m .54328 .30394 L .54282 .30868 L 0 0 0 r
F
.54749 .33182 m .54174 .32966 L .54242 .33555 L .257 .048 0 r
F
.54749 .33182 m .54671 .32605 L .54174 .32966 L F
.54889 .31754 m .54694 .30911 L .54643 .31878 L .321 .011 0 r
F
.54273 .33421 m .53761 .33113 L .53844 .33674 L .189 .042 0 r
F
.54273 .33421 m .54172 .32893 L .53761 .33113 L F
.54953 .32399 m .54643 .31878 L .54671 .32605 L 0 0 0 r
F
.54212 .32874 m .54116 .32225 L .54172 .32893 L F
.544 .32785 m .54262 .32514 L .54212 .32874 L F
.5409 .34536 m .53352 .34483 L .53474 .34884 L .455 .219 0 r
F
.5409 .34536 m .53957 .34137 L .53352 .34483 L F
.5486 .33662 m .54242 .33555 L .54342 .34045 L .295 .063 0 r
F
.54403 .3386 m .53844 .33674 L .53957 .34137 L .238 .059 0 r
F
.5486 .33662 m .54749 .33182 L .54242 .33555 L .295 .063 0 r
F
.54403 .3386 m .54273 .33421 L .53844 .33674 L .238 .059 0 r
F
.54187 .32365 m .5417 .3222 L .54116 .32225 L 0 0 0 r
F
.54187 .32365 m .54116 .32225 L .54212 .32874 L F
.53142 .34785 m .54123 .31823 L .5417 .3222 L 1 .592 0 r
F
.54123 .31823 m .54155 .31724 L .5417 .3222 L F
.54889 .31754 m .54376 .32643 L .54694 .30911 L .321 .011 0 r
F
.54262 .32514 m .54274 .32433 L .5417 .3222 L 0 0 0 r
F
.54262 .32514 m .5417 .3222 L .54187 .32365 L F
.544 .32785 m .54376 .32643 L .54262 .32514 L F
.54376 .32643 m .5417 .3222 L .54226 .3208 L .321 .011 0 r
F
.54376 .32643 m .54226 .3208 L .54694 .30911 L F
.54378 .32645 m .54376 .32643 L .54386 .32627 L .343 .446 0 r
F
.54456 .32692 m .54386 .32627 L .54889 .31754 L F
.54412 .32776 m .54376 .32643 L .544 .32785 L 0 0 0 r
F
.5442 .3277 m .54386 .32627 L .54456 .32692 L .343 .446 0 r
F
.5442 .3277 m .54376 .32643 L .54412 .32776 L 0 0 0 r
F
.54529 .33251 m .54172 .32893 L .54273 .33421 L F
.54529 .33251 m .544 .32785 L .54172 .32893 L F
.5506 .3292 m .54671 .32605 L .54749 .33182 L 0 .004 0 r
F
.55001 .32655 m .54953 .32399 L .54928 .32813 L F
.5506 .3292 m .54953 .32399 L .5505 .32911 L F
.55022 .32318 m .55029 .32305 L .55033 .32318 L .943 .111 0 r
F
.54858 .31891 m .54889 .31754 L .54953 .32399 L 1 .498 0 r
F
.54938 .32312 m .55029 .32305 L .55022 .32318 L .943 .111 0 r
F
.54938 .32312 m .54912 .31804 L .55029 .32305 L F
.55181 .32747 m .54953 .32399 L .5506 .3292 L .129 0 0 r
F
.54928 .32813 m .54953 .32399 L .54671 .32605 L 0 .004 0 r
F
.5505 .32911 m .55001 .32655 L .54928 .32813 L F
.546 .34843 m .53775 .3491 L .53903 .35279 L .536 .301 0 r
F
.546 .34843 m .54464 .34467 L .53775 .3491 L F
.54236 .34891 m .5409 .34536 L .53474 .34884 L .478 .284 0 r
F
.54993 .34075 m .54342 .34045 L .54464 .34467 L .325 .075 0 r
F
.54551 .34239 m .53957 .34137 L .5409 .34536 L .278 .074 0 r
F
.54993 .34075 m .5486 .33662 L .54342 .34045 L .325 .075 0 r
F
.54551 .34239 m .54403 .3386 L .53957 .34137 L .278 .074 0 r
F
.55194 .33358 m .54749 .33182 L .5486 .33662 L .058 .03 0 r
F
.55194 .33358 m .5506 .3292 L .54749 .33182 L F
.54681 .33644 m .54273 .33421 L .54403 .3386 L 0 .028 0 r
F
.54681 .33644 m .54529 .33251 L .54273 .33421 L F
.54848 .33988 m .54403 .3386 L .54551 .34239 L .071 .05 0 r
F
.54848 .33988 m .54681 .33644 L .54403 .3386 L F
.55347 .33118 m .5506 .3292 L .55194 .33358 L 0 0 0 r
F
.55347 .33118 m .55181 .32747 L .5506 .3292 L F
.54708 .33604 m .54529 .33251 L .54681 .33644 L F
.54803 .33466 m .54659 .33353 L .54708 .33604 L F
.54659 .33353 m .54617 .33349 L .54708 .33604 L F
.54604 .3331 m .54529 .33251 L .54708 .33604 L F
.55141 .34443 m .54464 .34467 L .546 .34843 L .349 .133 0 r
F
.54712 .34576 m .5409 .34536 L .54236 .34891 L .309 .119 0 r
F
.55141 .34443 m .54993 .34075 L .54464 .34467 L .349 .133 0 r
F
.54712 .34576 m .54551 .34239 L .5409 .34536 L .309 .119 0 r
F
.54604 .3331 m .54559 .33213 L .54529 .33251 L 0 0 0 r
F
.54559 .33213 m .544 .32785 L .54529 .33251 L F
.53789 .34799 m .54448 .32976 L .54559 .33213 L 1 .498 0 r
F
.54476 .32899 m .544 .32785 L .54559 .33213 L 0 0 0 r
F
.54448 .32976 m .54466 .32925 L .54559 .33213 L 1 .498 0 r
F
.55181 .32747 m .54756 .33374 L .54953 .32399 L .129 0 0 r
F
.54659 .33353 m .5465 .33288 L .54559 .33213 L 0 0 0 r
F
.54659 .33353 m .54559 .33213 L .54604 .3331 L F
.54803 .33466 m .54756 .33374 L .54659 .33353 L F
.54756 .33374 m .54559 .33213 L .54583 .33162 L .129 0 0 r
F
.54756 .33374 m .54583 .33162 L .54953 .32399 L F
.54796 .33283 m .54628 .33126 L .54756 .33374 L 0 0 0 r
F
.54802 .33431 m .54756 .33374 L .54803 .33466 L F
.54757 .33374 m .54756 .33374 L .54763 .33364 L .298 .391 0 r
F
.54822 .3337 m .54763 .33364 L .55181 .32747 L F
.54801 .33407 m .54763 .33364 L .54822 .3337 L F
.54801 .33407 m .54756 .33374 L .54802 .33431 L 0 0 0 r
F
.54106 .34614 m .54757 .33375 L .54801 .33407 L .298 .391 0 r
F
.54757 .33375 m .54763 .33364 L .54801 .33407 L F
.54796 .33283 m .54756 .33374 L .54801 .33407 L 0 0 0 r
F
.54756 .33374 m .54628 .33126 L .54659 .33353 L F
.54659 .33353 m .54604 .3331 L .54617 .33349 L F
.54756 .33374 m .53789 .34799 L .54559 .33213 L .129 0 0 r
F
.5465 .33288 m .54628 .33126 L .54559 .33213 L 0 0 0 r
F
.54106 .34614 m .53789 .34799 L .54756 .33374 L .298 .391 0 r
F
.54106 .34614 m .54756 .33374 L .54757 .33374 L F
.54466 .32925 m .54476 .32899 L .54528 .33098 L 1 .498 0 r
F
.54466 .32925 m .54528 .33098 L .54559 .33213 L F
.55137 .32624 m .54938 .32312 L .55033 .32318 L .721 .066 0 r
F
.54963 .325 m .54938 .32312 L .55137 .32624 L .613 .012 0 r
F
.54998 .3236 m .54963 .325 L .55698 .31144 L .049 .131 0 r
F
.55911 .30682 m .55698 .31144 L .65118 .13763 L F
.54998 .3236 m .55698 .31144 L .55911 .30682 L F
.54581 .33168 m .54858 .31891 L .54953 .32399 L 1 .498 0 r
F
.54573 .33149 m .54858 .31891 L .54581 .33168 L F
.54476 .32899 m .54889 .31754 L .54559 .33213 L F
.54476 .32899 m .5442 .3277 L .544 .32785 L 0 0 0 r
F
.53789 .34799 m .53551 .34652 L .5442 .3277 L 1 .498 0 r
F
.54496 .32844 m .54453 .32699 L .54889 .31754 L F
.54467 .32735 m .54329 .32269 L .54309 .32218 L 0 0 0 r
F
.54334 .32301 m .54309 .32218 L .54306 .32208 L F
.54467 .32735 m .54309 .32218 L .54334 .32301 L F
.54476 .32899 m .5442 .3277 L .54453 .32699 L 1 .498 0 r
F
.54476 .32899 m .54453 .32699 L .54496 .32844 L F
.53789 .34799 m .5442 .3277 L .54476 .32899 L F
.54476 .32899 m .54424 .32767 L .5442 .3277 L 0 0 0 r
F
.54628 .33126 m .54467 .32735 L .54424 .32767 L F
.54628 .33126 m .54424 .32767 L .54476 .32899 L F
.54559 .33213 m .54573 .33149 L .54581 .33168 L 1 .498 0 r
F
.54628 .33126 m .54476 .32899 L .54559 .33213 L 0 0 0 r
F
.53551 .34652 m .54378 .32647 L .5442 .3277 L .343 .446 0 r
F
.54378 .32647 m .54386 .32627 L .5442 .3277 L F
.54467 .32735 m .54376 .32643 L .5442 .3277 L 0 0 0 r
F
.54467 .32735 m .54306 .32208 L .54376 .32643 L F
.54376 .32643 m .54306 .32208 L .54262 .32514 L F
.54262 .32514 m .54187 .32365 L .54191 .32448 L F
.54262 .32514 m .54191 .32448 L .54212 .32874 L F
.54376 .32643 m .53142 .34785 L .5417 .3222 L .321 .011 0 r
F
.54274 .32433 m .54306 .32208 L .5417 .3222 L 0 0 0 r
F
.53551 .34652 m .53142 .34785 L .54376 .32643 L .343 .446 0 r
F
.53551 .34652 m .54376 .32643 L .54378 .32645 L F
.54155 .31724 m .54191 .31618 L .54174 .321 L 1 .592 0 r
F
.54155 .31724 m .54174 .321 L .5417 .3222 L F
.54254 .31858 m .54269 .31454 L .54183 .31372 L 0 0 0 r
F
.54306 .32208 m .54183 .31372 L .54191 .31618 L F
.54269 .31454 m .54165 .31045 L .54173 .31363 L F
.54226 .31687 m .54289 .30897 L .54269 .31454 L .996 .218 0 r
F
.54289 .30897 m .54328 .30394 L .54269 .31454 L F
.54306 .32208 m .54269 .31454 L .54254 .31858 L 0 0 0 r
F
.5417 .3222 m .54205 .32076 L .54206 .32129 L 1 .592 0 r
F
.54634 .303 m .54653 .30222 L .54628 .31077 L F
.54306 .32208 m .54191 .31618 L .5417 .3222 L 0 0 0 r
F
.54165 .31045 m .54277 .30025 L .54048 .30739 L .002 0 0 r
F
.54048 .30739 m .53985 .3031 L .53954 .30522 L F
.54048 .30739 m .53954 .30522 L .53826 .31413 L F
.54165 .31045 m .52431 .34694 L .54022 .30018 L .479 .044 0 r
F
.541 .30577 m .54277 .30025 L .54022 .30018 L .002 0 0 r
F
.52912 .34616 m .52431 .34694 L .54165 .31045 L .39 .486 0 r
F
.52912 .34616 m .54165 .31045 L .54165 .31047 L F
.54275 .28578 m .54289 .28531 L .54136 .29257 L 1 .667 0 r
F
.54275 .28578 m .54136 .29257 L .54142 .29216 L F
.54289 .28531 m .54813 .26793 L .53937 .30231 L F
.54289 .28531 m .53937 .30231 L .539 .30377 L F
.54325 .28411 m .54405 .27861 L .54342 .27823 L 0 0 0 r
F
.52431 .34694 m .52215 .34493 L .54405 .27861 L 1 .667 0 r
F
.54325 .28411 m .54405 .27861 L .55394 .24866 L F
.52431 .34694 m .54405 .27861 L .54325 .28411 L F
.54325 .28411 m .54422 .27872 L .54405 .27861 L 0 0 0 r
F
.5464 .28007 m .55313 .24882 L .55097 .24626 L F
.54921 .25475 m .55097 .24626 L .55025 .24542 L F
.5464 .28007 m .55097 .24626 L .54921 .25475 L F
.54277 .30025 m .5464 .28007 L .54422 .27872 L F
.54277 .30025 m .54422 .27872 L .54325 .28411 L F
.54277 .30025 m .54325 .28411 L .54022 .30018 L F
.539 .30377 m .5411 .29554 L .54022 .30018 L 1 .667 0 r
F
.52215 .34493 m .54443 .27345 L .54405 .27861 L .469 .501 0 r
F
.54422 .27872 m .54443 .27338 L .54405 .27861 L 0 0 0 r
F
.54422 .27872 m .55025 .24542 L .54443 .27338 L F
.5464 .28007 m .54921 .25475 L .54422 .27872 L F
.54921 .25475 m .55025 .24542 L .54422 .27872 L F
.55313 .24882 m .55738 .20768 L .55025 .24542 L .56 .059 0 r
F
.55313 .24882 m .51798 .34041 L .55738 .20768 L F
.51937 .34274 m .5179 .34042 L .51491 .34256 L .438 .439 0 r
F
.5179 .34042 m .51788 .3404 L .51785 .34043 L F
.5179 .34042 m .51785 .34043 L .51491 .34256 L F
.52002 .34277 m .51798 .34041 L .51788 .3404 L F
.52002 .34277 m .51788 .3404 L .51937 .34274 L F
.5225 .33985 m .51798 .34041 L .55313 .24882 L .318 .344 0 r
F
.52224 .34064 m .51798 .34041 L .5225 .33985 L F
.51798 .34041 m .51788 .3404 L .55738 .20768 L .56 .059 0 r
F
.52431 .34694 m .54275 .28578 L .539 .30377 L 1 .667 0 r
F
.54559 .28786 m .55313 .24882 L .5464 .28007 L .468 .047 0 r
F
.52454 .34257 m .52234 .34065 L .52002 .34277 L .349 .395 0 r
F
.52234 .34065 m .52224 .34064 L .52002 .34277 L F
.52233 .34066 m .52224 .34064 L .52224 .34064 L .468 .047 0 r
F
.52234 .34065 m .52224 .34063 L .55313 .24882 L F
.54559 .28786 m .52234 .34065 L .55313 .24882 L F
.52234 .34065 m .52234 .34065 L .55313 .24882 L F
.52531 .34135 m .52234 .34065 L .52454 .34257 L .244 .271 0 r
F
.54182 .30912 m .52603 .3404 L .54559 .28786 L .339 .022 0 r
F
.52833 .34198 m .52603 .3404 L .52454 .34257 L .284 .341 0 r
F
.52603 .3404 m .52558 .3413 L .52592 .3404 L .339 .022 0 r
F
.52597 .3404 m .52592 .34039 L .54559 .28786 L F
.52592 .3404 m .52234 .34065 L .54559 .28786 L .262 .311 0 r
F
.52595 .34035 m .52358 .3386 L .5226 .3401 L .244 .271 0 r
F
.52562 .34037 m .5226 .3401 L .52228 .3406 L F
.52595 .34035 m .5226 .3401 L .52562 .34037 L F
.52603 .3404 m .52597 .34039 L .54559 .28786 L .339 .022 0 r
F
.52858 .34077 m .52603 .3404 L .52833 .34198 L .182 .208 0 r
F
.52879 .33975 m .52603 .3404 L .52858 .34077 L F
.52849 .34045 m .52558 .3413 L .52603 .3404 L .226 .282 0 r
F
.52879 .33975 m .52603 .3404 L .54182 .30912 L F
.52849 .34045 m .52603 .3404 L .52879 .33975 L F
.5288 .33969 m .52603 .3404 L .52879 .33975 L .182 .208 0 r
F
.5288 .33969 m .52595 .34035 L .52603 .3404 L F
.52603 .3404 m .52597 .3404 L .52597 .34039 L .339 .022 0 r
F
.52597 .3404 m .52592 .3404 L .52592 .34039 L F
.52603 .3404 m .52601 .34039 L .526 .3404 L .284 .341 0 r
F
.52603 .3404 m .526 .3404 L .52454 .34257 L F
.52601 .34039 m .52595 .34035 L .52592 .3404 L F
.52601 .34039 m .52592 .3404 L .52454 .34257 L F
.52558 .3413 m .52189 .34166 L .52224 .34086 L .262 .311 0 r
F
.52295 .34077 m .52224 .34086 L .52234 .34065 L F
.52558 .3413 m .52224 .34086 L .52295 .34077 L F
.52592 .3404 m .52234 .34065 L .52531 .34135 L .244 .271 0 r
F
.52558 .3413 m .52234 .34065 L .52592 .3404 L .262 .311 0 r
F
.52595 .34035 m .52234 .34065 L .52592 .3404 L .244 .271 0 r
F
.52595 .34035 m .52228 .3406 L .52234 .34065 L F
.52234 .34065 m .52224 .34064 L .52224 .34063 L .468 .047 0 r
F
.52234 .34065 m .52224 .34063 L .52234 .34065 L F
.52233 .34066 m .52224 .34064 L .52234 .34065 L F
.52228 .3406 m .52005 .33841 L .51841 .33992 L .312 .313 0 r
F
.52194 .34058 m .51841 .33992 L .51793 .34036 L F
.52228 .3406 m .51841 .33992 L .52194 .34058 L F
.52234 .34065 m .52228 .3406 L .52224 .34064 L .349 .395 0 r
F
.52234 .34065 m .52233 .34066 L .52234 .34065 L .468 .047 0 r
F
.52233 .34066 m .52189 .34166 L .52224 .34064 L F
.52196 .34058 m .51793 .34036 L .51798 .34041 L .312 .313 0 r
F
.52228 .3406 m .52194 .34058 L .52196 .34058 L F
.52194 .34058 m .51793 .34036 L .52196 .34058 L F
.52224 .34064 m .51798 .34041 L .52002 .34277 L F
.52228 .3406 m .51798 .34041 L .52224 .34064 L F
.52189 .34166 m .51798 .34041 L .52224 .34064 L .318 .344 0 r
F
.52189 .34166 m .51756 .3415 L .51798 .34041 L F
.51798 .34041 m .51756 .3415 L .51788 .3404 L .56 .059 0 r
F
.51798 .34041 m .51793 .34036 L .51788 .3404 L .438 .439 0 r
F
.51788 .3404 m .51786 .34035 L .51788 .3404 L 1 .684 0 r
F
.51756 .3415 m .51786 .34036 L .51788 .3404 L F
.51786 .34035 m .56083 .17768 L .51788 .3404 L F
.51789 .34039 m .51305 .33963 L .51491 .34256 L .394 .347 0 r
F
.51793 .34036 m .51786 .34035 L .51789 .34039 L F
.51786 .34035 m .51305 .33963 L .51789 .34039 L F
.51786 .34035 m .5159 .33766 L .51305 .33963 L F
.51756 .3415 m .51594 .33772 L .51786 .34035 L 1 .684 0 r
F
.51594 .33772 m .51588 .33756 L .51786 .34035 L F
.5159 .33766 m .51586 .33761 L .51305 .33963 L .394 .347 0 r
F
.51594 .33772 m .51586 .33761 L .51588 .33756 L 1 .684 0 r
F
.51595 .33762 m .51586 .33761 L .5159 .33766 L .394 .347 0 r
F
.51786 .34035 m .51595 .33762 L .5159 .33766 L F
.51756 .3415 m .51549 .33894 L .51586 .33761 L 1 .684 0 r
F
.51756 .3415 m .51586 .33761 L .51594 .33772 L F
.51786 .34035 m .51588 .33756 L .56083 .17768 L F
.51786 .34036 m .51786 .34035 L .51788 .3404 L F
.51793 .34036 m .51767 .34 L .51786 .34035 L .394 .347 0 r
F
.51767 .34 m .51595 .33762 L .51786 .34035 L F
.51595 .33762 m .51592 .33757 L .51586 .33761 L F
.51549 .33894 m .51088 .33753 L .51114 .3367 L .348 .248 0 r
F
.51267 .337 m .51114 .3367 L .51133 .33608 L F
.51549 .33894 m .51114 .3367 L .51267 .337 L F
.51586 .33761 m .51133 .33608 L .56083 .17768 L F
.51586 .33761 m .51133 .33608 L .51516 .33811 L .352 .213 0 r
F
.51549 .33894 m .51133 .33608 L .51586 .33761 L .348 .248 0 r
F
.51592 .33757 m .51133 .33608 L .51586 .33761 L .352 .213 0 r
F
.51592 .33757 m .5113 .33601 L .51133 .33608 L F
.51133 .33608 m .51123 .33606 L .51124 .33603 L .665 .073 0 r
F
.51133 .33608 m .5113 .33601 L .51123 .33606 L .555 .382 0 r
F
.51402 .33412 m .51236 .32947 L .50987 .33109 L .293 .073 0 r
F
.50991 .33122 m .50987 .33109 L .50979 .33114 L F
.51402 .33412 m .50987 .33109 L .50991 .33122 L F
.51402 .33412 m .50991 .33122 L .5113 .33601 L F
.50991 .33122 m .50979 .33114 L .5107 .33408 L F
.50991 .33122 m .5107 .33408 L .5113 .33601 L F
.51123 .33606 m .51124 .33602 L .51124 .33602 L 1 .748 0 r
F
.51124 .33605 m .51123 .33605 L .51123 .33606 L .513 .253 0 r
F
.5113 .33601 m .51121 .33597 L .51124 .33605 L F
.50985 .33202 m .50965 .33143 L .5097 .3312 L 1 .748 0 r
F
.51088 .33753 m .5097 .3312 L .51121 .33597 L F
.51121 .33597 m .50983 .33127 L .50974 .33133 L .513 .253 0 r
F
.5113 .33601 m .5107 .33408 L .51121 .33597 L F
.5107 .33408 m .50983 .33127 L .51121 .33597 L F
.50926 .33321 m .50496 .32933 L .50512 .3287 L .435 .121 0 r
F
.5097 .3312 m .50512 .3287 L .55009 .14935 L F
.50926 .33321 m .50512 .3287 L .5097 .3312 L F
.50983 .33127 m .50979 .33114 L .5097 .3312 L .513 .253 0 r
F
.50496 .32933 m .50567 .32549 L .55009 .14935 L .435 .121 0 r
F
.50979 .33114 m .50533 .32686 L .5097 .3312 L .459 .106 0 r
F
.50979 .33114 m .5053 .32665 L .50533 .32686 L F
.53788 .14487 m .5053 .32665 L .53819 .14305 L 1 .805 0 r
F
.50695 .31779 m .5053 .32665 L .53788 .14487 L F
.50488 .32926 m .50475 .32914 L .50533 .32686 L .435 .121 0 r
F
.55009 .14935 m .50567 .32549 L .53788 .14487 L .797 .212 0 r
F
.54653 .30222 m .54876 .29548 L .5464 .31047 L 1 .592 0 r
F
.65477 .12849 m .54998 .3236 L .65126 .13746 L .718 .205 0 r
F
.65477 .12849 m .65126 .13746 L .65577 .12916 L F
.65485 .12858 m .65477 .12849 L .65128 .13773 L .099 .072 0 r
F
.65477 .12849 m .65126 .13746 L .65128 .13773 L F
.65486 .12913 m .65128 .13773 L .65515 .14465 L F
.65485 .12858 m .65253 .13453 L .65486 .12913 L F
.65253 .13453 m .65128 .13773 L .65486 .12913 L F
.65126 .13746 m .65119 .13762 L .6512 .13759 L .049 .131 0 r
F
.65126 .13746 m .6512 .13759 L .65127 .13743 L F
.65123 .13752 m .65119 .13762 L .65126 .13746 L F
.65122 .13753 m .65118 .13763 L .65119 .13762 L F
.65122 .13753 m .65119 .13762 L .65123 .13752 L F
.54998 .3236 m .65118 .13763 L .65122 .13753 L F
.6512 .13779 m .54963 .325 L .55137 .32624 L 1 .625 0 r
F
.65118 .13763 m .54963 .325 L .6512 .13779 L F
.6512 .13779 m .65232 .14561 L .65247 .14577 L 0 .048 0 r
F
.65247 .14573 m .55137 .32624 L .65247 .14577 L 1 .625 0 r
F
.6455 .1488 m .64549 .14881 L .64549 .1488 L .721 .066 0 r
F
.6455 .1488 m .6455 .14881 L .64557 .14877 L .169 .122 0 r
F
.55137 .32624 m .64549 .14881 L .64558 .14875 L .721 .066 0 r
F
.6512 .13779 m .55137 .32624 L .65247 .14573 L 1 .625 0 r
F
.65254 .14576 m .65247 .14577 L .65256 .14585 L 0 .048 0 r
F
.65128 .13773 m .65247 .14577 L .65254 .14576 L F
.62945 .14783 m .6238 .14337 L .62942 .14789 L .355 .419 0 r
F
.63439 .1396 m .62386 .14335 L .62945 .14783 L F
.62386 .14335 m .6238 .14337 L .62945 .14783 L F
.63439 .1396 m .62942 .14789 L .62949 .14788 L F
.62942 .14789 m .61635 .15152 L .61701 .14996 L .261 .001 0 r
F
.62942 .14789 m .6238 .14337 L .61635 .15152 L .455 .529 0 r
F
.62942 .14789 m .61635 .15152 L .61631 .15156 L F
.62909 .14802 m .61637 .15154 L .61764 .15266 L F
.62909 .14802 m .61764 .15266 L .62174 .15629 L F
.61637 .15154 m .61631 .15156 L .62174 .15629 L F
.62942 .14789 m .54891 .30912 L .61635 .15152 L .261 .001 0 r
F
.54912 .31804 m .54891 .30912 L .62942 .14789 L .837 .145 0 r
F
.54891 .30912 m .61087 .14688 L .61634 .15151 L 1 .794 0 r
F
.61635 .15152 m .61634 .15151 L .61635 .15152 L F
.54891 .30912 m .61634 .15151 L .61635 .15152 L F
.60855 .14735 m .59611 .14982 L .59629 .14998 L .584 .645 0 r
F
.60855 .14735 m .59629 .14998 L .60129 .1546 L F
.59611 .14982 m .59605 .14983 L .60129 .1546 L F
.61082 .1469 m .61078 .14687 L .59605 .14983 L F
.59963 .14814 m .59925 .14917 L .59642 .14885 L .394 .033 0 r
F
.59925 .14917 m .59609 .1498 L .59642 .14885 L F
.61139 .14552 m .61078 .14687 L .59963 .14814 L F
.61078 .14687 m .59609 .1498 L .59605 .14983 L .584 .645 0 r
F
.61078 .14687 m .55261 .27536 L .59963 .14814 L .394 .033 0 r
F
.61078 .14687 m .60522 .14236 L .59609 .1498 L .584 .645 0 r
F
.59925 .14917 m .55261 .27536 L .59609 .1498 L .394 .033 0 r
F
.61085 .14686 m .61085 .14686 L .61082 .1469 L .486 .579 0 r
F
.61085 .14686 m .60522 .14236 L .61078 .14687 L F
.61085 .14686 m .61078 .14687 L .61082 .1469 L F
.61087 .14688 m .61139 .14552 L .61586 .15092 L 1 .794 0 r
F
.61087 .14688 m .61085 .14685 L .61139 .14552 L F
.61087 .14688 m .61085 .14685 L .61087 .14688 L F
.6238 .14337 m .61801 .13897 L .61085 .14686 L .471 .555 0 r
F
.61087 .14688 m .61085 .14686 L .61082 .1469 L F
.61087 .14688 m .61085 .14686 L .61087 .14688 L 1 .794 0 r
F
.61085 .14686 m .61085 .14685 L .61087 .14688 L F
.6238 .14337 m .61085 .14686 L .61087 .14688 L .471 .555 0 r
F
.54891 .30912 m .61085 .14686 L .61087 .14688 L 1 .794 0 r
F
.61085 .14686 m .60527 .14234 L .61085 .14686 L .486 .579 0 r
F
.61085 .14685 m .61078 .14687 L .61139 .14552 L 0 0 0 r
F
.61801 .13897 m .60619 .1421 L .61085 .14686 L .486 .579 0 r
F
.60619 .1421 m .60527 .14234 L .61085 .14686 L F
.60527 .14234 m .60522 .14236 L .61085 .14686 L F
.61087 .14688 m .61087 .14688 L .61635 .15152 L 1 .794 0 r
F
.61087 .14688 m .61586 .15092 L .61635 .15152 L F
.6238 .14337 m .61087 .14688 L .61635 .15152 L .471 .555 0 r
F
.54891 .30912 m .55002 .29744 L .61085 .14686 L 1 .794 0 r
F
.55002 .29744 m .55261 .27536 L .61078 .14687 L 0 0 0 r
F
.55002 .29744 m .61078 .14687 L .61085 .14685 L F
.55261 .27536 m .59082 .14511 L .59609 .14979 L 1 .86 0 r
F
.59082 .14511 m .59082 .14511 L .59609 .1498 L F
.59082 .14511 m .59106 .14428 L .59614 .14966 L F
.60522 .14236 m .59082 .14511 L .59609 .1498 L .593 .663 0 r
F
.59082 .14511 m .59077 .14512 L .59085 .14519 L F
.60522 .14236 m .59952 .13794 L .59081 .14508 L F
.59082 .14511 m .59081 .14508 L .59077 .14512 L F
.59082 .14511 m .59081 .14508 L .59082 .14511 L 1 .86 0 r
F
.59081 .14508 m .59081 .14508 L .59082 .14511 L F
.60522 .14236 m .59081 .14508 L .59082 .14511 L .593 .663 0 r
F
.55261 .27536 m .59081 .14508 L .59082 .14511 L 1 .86 0 r
F
.55372 .27161 m .55893 .24654 L .59081 .14508 L F
.55893 .24654 m .56043 .21503 L .59072 .14508 L .073 0 0 r
F
.59081 .14508 m .59072 .14508 L .59106 .14428 L F
.59081 .14508 m .59072 .14508 L .59077 .14512 L .602 .68 0 r
F
.55893 .24654 m .59072 .14508 L .59081 .14508 L .073 0 0 r
F
.59082 .14507 m .59072 .14508 L .59081 .14508 L .602 .68 0 r
F
.55836 .25466 m .56552 .21482 L .55893 .24654 L 0 0 0 r
F
.56552 .21482 m .56595 .21247 L .55893 .24654 L F
.55261 .27536 m .55893 .24654 L .55372 .27161 L 1 .86 0 r
F
.59082 .14511 m .59081 .14508 L .59106 .14428 L F
.59075 .14505 m .5854 .14052 L .59072 .14508 L .602 .68 0 r
F
.59952 .13794 m .58545 .14051 L .59075 .14505 L F
.58545 .14051 m .5854 .14052 L .59075 .14505 L F
.59952 .13794 m .59072 .14508 L .59082 .14507 L F
.59072 .14508 m .57526 .14702 L .57538 .14646 L .564 .055 0 r
F
.59072 .14508 m .5854 .14052 L .57526 .14702 L .675 .726 0 r
F
.59072 .14508 m .57526 .14702 L .57519 .14706 L F
.59072 .14508 m .56043 .21503 L .57526 .14702 L .564 .055 0 r
F
.56043 .21503 m .57034 .14226 L .57526 .14702 L .76 .165 0 r
F
.5717 .13735 m .56646 .13317 L .55571 .13857 L .743 .834 0 r
F
.57041 .14176 m .56537 .13715 L .55468 .14273 L .75 .799 0 r
F
.57034 .14226 m .57041 .14176 L .57425 .14593 L .76 .165 0 r
F
.57034 .14222 m .56534 .13757 L .57031 .14224 L .685 .754 0 r
F
.57034 .14222 m .57034 .14222 L .57035 .14221 L .76 .165 0 r
F
.57034 .14226 m .57035 .14221 L .57041 .14176 L F
.57034 .14226 m .57035 .14221 L .57034 .14226 L F
.57034 .14222 m .56537 .13715 L .57041 .14176 L .774 .152 0 r
F
.56536 .13757 m .56536 .13757 L .57034 .14222 L F
.56536 .13757 m .56537 .13715 L .56917 .14102 L F
.56536 .13757 m .56917 .14102 L .57034 .14222 L F
.56646 .13317 m .55106 .13417 L .55571 .13857 L .744 .841 0 r
F
.56537 .13715 m .5502 .13791 L .55468 .14273 L .693 .063 0 r
F
.55478 .143 m .55013 .13821 L .55459 .1431 L .747 .801 0 r
F
.56525 .13758 m .55029 .13821 L .55478 .143 L F
.55029 .13821 m .55013 .13821 L .55478 .143 L F
.55106 .13417 m .54637 .12985 L .53572 .13409 L .782 .872 0 r
F
.5502 .13791 m .54566 .13318 L .53504 .1377 L .803 .849 0 r
F
.55024 .13815 m .54566 .13318 L .5502 .13791 L 0 0 0 r
F
.54635 .13814 m .5456 .13343 L .53501 .13791 L .8 .843 0 r
F
.55013 .13821 m .54576 .13359 L .54635 .13814 L F
.54576 .13359 m .5456 .13343 L .54635 .13814 L F
.55024 .13815 m .5457 .13329 L .55024 .13815 L 0 0 0 r
F
.55024 .13815 m .5456 .13343 L .55013 .13821 L .749 .812 0 r
F
.54574 .13342 m .5456 .13343 L .54576 .13358 L F
.54574 .13342 m .54576 .13358 L .55024 .13815 L F
.54574 .13342 m .54574 .13342 L .55024 .13815 L 0 0 0 r
F
.54574 .13342 m .5457 .13329 L .54799 .13574 L F
.54574 .13342 m .54799 .13574 L .55024 .13815 L F
.54637 .12985 m .53169 .12958 L .53572 .13409 L .782 .879 0 r
F
.54566 .13318 m .53115 .13277 L .53504 .1377 L .803 .858 0 r
F
.54637 .12985 m .54164 .1256 L .53169 .12958 L .782 .879 0 r
F
.54566 .13318 m .54106 .12853 L .53115 .13277 L .803 .858 0 r
F
.5457 .13338 m .54122 .12894 L .5456 .13343 L .682 .053 0 r
F
.54122 .12894 m .54122 .12895 L .5456 .13343 L F
.54573 .13336 m .54573 .13336 L .54573 .13335 L 0 0 0 r
F
.54574 .13342 m .54573 .13335 L .54566 .13318 L F
.54573 .13336 m .54106 .12853 L .54566 .13318 L F
.54573 .13336 m .54266 .13025 L .5457 .13338 L .682 .053 0 r
F
.56525 .13758 m .56517 .13751 L .55013 .13821 L .747 .801 0 r
F
.55829 .13751 m .55822 .13781 L .5502 .13791 L .693 .063 0 r
F
.55822 .13781 m .55024 .13815 L .5502 .13791 L F
.56537 .13715 m .56517 .13751 L .55829 .13751 L F
.56517 .13751 m .55024 .13815 L .55013 .13821 L .747 .801 0 r
F
.57026 .14227 m .56525 .13758 L .55459 .1431 L .745 .789 0 r
F
.56517 .13751 m .55384 .15784 L .55829 .13751 L .693 .063 0 r
F
.56517 .13751 m .56018 .13299 L .55024 .13815 L .747 .801 0 r
F
.55822 .13781 m .55384 .15784 L .55024 .13815 L .693 .063 0 r
F
.55292 .15284 m .54574 .13342 L .55024 .13815 L 0 0 0 r
F
.55384 .15784 m .55059 .14804 L .55292 .15284 L F
.55059 .14804 m .54574 .13342 L .55292 .15284 L F
.5457 .13329 m .54566 .13318 L .55024 .13815 L F
.56018 .13299 m .54574 .13342 L .55024 .13815 L .749 .812 0 r
F
.56018 .13299 m .55503 .12851 L .54573 .13336 L F
.54574 .13342 m .54573 .13335 L .54574 .13342 L 0 0 0 r
F
.54573 .13336 m .54573 .13335 L .54574 .13342 L F
.54574 .13342 m .54573 .13336 L .5456 .13343 L .749 .812 0 r
F
.56018 .13299 m .54573 .13336 L .54574 .13342 L F
.55142 .15053 m .54573 .13336 L .54573 .13336 L 0 0 0 r
F
.55142 .15053 m .54573 .13336 L .55142 .15053 L F
.55059 .14803 m .55086 .14609 L .54573 .13336 L F
.5412 .12873 m .54102 .12874 L .5457 .13338 L .682 .053 0 r
F
.55261 .15414 m .54573 .13336 L .54574 .13342 L 0 0 0 r
F
.55384 .15784 m .55261 .15413 L .55261 .15414 L F
.55261 .15413 m .54573 .13336 L .55261 .15414 L F
.53504 .1377 m .53115 .13277 L .52031 .13659 L .852 .887 0 r
F
.5456 .13343 m .53112 .13294 L .53501 .13791 L .8 .853 0 r
F
.5456 .13343 m .54102 .12874 L .53137 .13283 L F
.53148 .13295 m .53137 .13283 L .53112 .13294 L F
.5456 .13343 m .53137 .13283 L .53148 .13295 L F
.52764 .12509 m .51423 .12369 L .51755 .12827 L .816 .915 0 r
F
.5317 .12952 m .52764 .12509 L .51755 .12827 L .817 .909 0 r
F
.52763 .12514 m .51422 .12372 L .51754 .12831 L .815 .914 0 r
F
.53169 .12958 m .52763 .12514 L .51754 .12831 L .816 .908 0 r
F
.54165 .12553 m .52764 .12509 L .5317 .12952 L .35 .429 0 r
F
.54164 .1256 m .52763 .12514 L .53169 .12958 L .783 .886 0 r
F
.54106 .12853 m .52719 .12792 L .53115 .13277 L .721 .048 0 r
F
.53115 .13277 m .51713 .13147 L .52031 .13659 L .849 .895 0 r
F
.53115 .13277 m .52719 .12792 L .51713 .13147 L F
.53137 .13283 m .52717 .12806 L .53112 .13294 L .8 .863 0 r
F
.54102 .12874 m .52734 .12807 L .53137 .13283 L F
.52734 .12807 m .52717 .12806 L .53137 .13283 L F
.52764 .12509 m .52355 .12073 L .51423 .12369 L .816 .915 0 r
F
.52763 .12514 m .52354 .12077 L .51422 .12372 L .815 .914 0 r
F
.54106 .12853 m .541 .12858 L .52719 .12792 L .721 .048 0 r
F
.527 .12766 m .5238 .12389 L .52699 .12766 L .143 .08 0 r
F
.54102 .12874 m .54093 .12865 L .52734 .12807 L .8 .863 0 r
F
.54102 .12874 m .52734 .12807 L .52734 .12807 L F
.54089 .12858 m .54093 .12865 L .52729 .12801 L .721 .048 0 r
F
.541 .12858 m .54093 .12865 L .54089 .12858 L F
.54522 .13623 m .54436 .13518 L .54102 .12874 L 0 .021 0 r
F
.541 .12858 m .52729 .12801 L .52719 .12792 L .721 .048 0 r
F
.54164 .1256 m .5415 .12549 L .52763 .12514 L .783 .886 0 r
F
.5415 .12549 m .53687 .12143 L .52782 .12507 L F
.54133 .12552 m .5415 .12549 L .52782 .12507 L .35 .429 0 r
F
.54165 .12553 m .5415 .12549 L .54133 .12552 L F
.54982 .12412 m .54915 .12398 L .54164 .1256 L .454 .626 0 r
F
.54988 .12388 m .5487 .12389 L .54165 .12553 L .756 .84 0 r
F
.54845 .12395 m .53687 .12143 L .5415 .12549 L .454 .626 0 r
F
.5487 .12389 m .54824 .1238 L .54845 .12395 L F
.54824 .1238 m .53687 .12143 L .54845 .12395 L F
.52782 .12507 m .52355 .12073 L .52764 .12509 L .542 .696 0 r
F
.52774 .12499 m .52354 .12077 L .52756 .12506 L .783 .893 0 r
F
.53687 .12143 m .52376 .12078 L .52774 .12499 L F
.52376 .12078 m .52376 .12078 L .52782 .12507 L .542 .696 0 r
F
.52376 .12078 m .52355 .12073 L .52494 .12214 L F
.52376 .12078 m .52494 .12214 L .52782 .12507 L F
.52355 .12073 m .51088 .11917 L .51423 .12369 L .815 .921 0 r
F
.52355 .12073 m .51942 .11643 L .51088 .11917 L F
.52371 .12071 m .51942 .11643 L .52355 .12073 L .563 .722 0 r
F
.53206 .11732 m .52005 .11651 L .52353 .12052 L .425 .623 0 r
F
.53206 .11732 m .52353 .12052 L .52371 .12071 L F
.51962 .11649 m .52693 .11516 L .51942 .11643 L .563 .722 0 r
F
.53206 .11732 m .52715 .11535 L .52204 .11612 L .425 .623 0 r
F
.52715 .11535 m .52693 .11516 L .51962 .11649 L .563 .722 0 r
F
.53206 .11732 m .52178 .11609 L .51962 .11649 L .425 .623 0 r
F
.52005 .11651 m .51962 .11649 L .52369 .12071 L F
.51962 .11649 m .5195 .11651 L .52125 .11826 L .563 .722 0 r
F
.51962 .11649 m .51942 .11647 L .5201 .11715 L .425 .623 0 r
F
.52127 .11819 m .52125 .11826 L .52371 .12071 L .563 .722 0 r
F
.51962 .11649 m .52125 .11826 L .52127 .11819 L F
.51962 .11649 m .5201 .11715 L .52369 .12071 L .425 .623 0 r
F
.53687 .12143 m .53206 .11732 L .52371 .12071 L .783 .893 0 r
F
.52376 .12078 m .52371 .12071 L .52355 .12073 L .542 .696 0 r
F
.52376 .12078 m .52371 .12071 L .52354 .12077 L .783 .893 0 r
F
.53687 .12143 m .52371 .12071 L .52376 .12078 L F
.53687 .12143 m .52756 .12506 L .52782 .12507 L F
.5364 .12398 m .5317 .11952 L .52371 .12071 L .542 .696 0 r
F
.5364 .12398 m .52371 .12071 L .52376 .12078 L F
.5317 .11952 m .52715 .11535 L .51962 .11649 L .563 .722 0 r
F
.52204 .11612 m .52692 .11526 L .52178 .11609 L .425 .623 0 r
F
.52715 .11535 m .52692 .11526 L .52204 .11612 L F
.51962 .11649 m .51942 .11643 L .5195 .11651 L .563 .722 0 r
F
.51962 .11649 m .52178 .11609 L .51942 .11647 L .425 .623 0 r
F
.51942 .11643 m .50751 .11471 L .51088 .11917 L .452 .688 0 r
F
.51921 .1164 m .51912 .11635 L .50751 .11471 L F
.51942 .11643 m .51933 .11638 L .51921 .1164 L F
.51933 .11638 m .51526 .11224 L .5077 .11467 L .814 .926 0 r
F
.51933 .11638 m .5077 .11467 L .50761 .1147 L F
.52154 .11595 m .51526 .11224 L .51933 .11638 L .578 .74 0 r
F
.52693 .11516 m .51933 .11638 L .51955 .11641 L .8 .893 0 r
F
.52692 .11526 m .52625 .11509 L .52178 .11609 L .578 .74 0 r
F
.52625 .11509 m .52228 .11406 L .52182 .11592 L F
.52693 .11516 m .52625 .11509 L .51933 .11638 L .8 .893 0 r
F
.52625 .11509 m .52182 .11592 L .52178 .11609 L .578 .74 0 r
F
.52228 .11406 m .51526 .11224 L .52178 .11609 L F
.52625 .11509 m .51506 .11394 L .51933 .11638 L .8 .893 0 r
F
.51955 .11641 m .51933 .11638 L .51942 .11643 L F
.51933 .11638 m .51506 .11394 L .51921 .1164 L .452 .688 0 r
F
.51942 .11647 m .51933 .11638 L .50751 .11473 L .814 .926 0 r
F
.50971 .11502 m .50761 .1147 L .50751 .11471 L .452 .688 0 r
F
.51912 .11635 m .50761 .1147 L .50971 .11502 L F
.50751 .11471 m .50411 .11031 L .49665 .11219 L .843 .953 0 r
F
.50422 .11035 m .51092 .10946 L .50411 .11031 L .637 .785 0 r
F
.51526 .11224 m .51103 .10958 L .50512 .11025 L .492 .747 0 r
F
.51103 .10958 m .51092 .10946 L .50422 .11035 L .637 .785 0 r
F
.51526 .11224 m .50499 .11022 L .50422 .11035 L .492 .747 0 r
F
.51526 .11224 m .50422 .11035 L .50756 .11464 L F
.50761 .1147 m .50415 .11036 L .50751 .11471 L .637 .785 0 r
F
.50415 .11036 m .50415 .11036 L .50751 .11471 L F
.50422 .11035 m .50411 .11031 L .50761 .1147 L F
.51526 .11224 m .50746 .11468 L .50761 .1147 L .492 .747 0 r
F
.51506 .11394 m .51103 .10958 L .50422 .11035 L .637 .785 0 r
F
.50512 .11025 m .51091 .10951 L .50499 .11022 L .492 .747 0 r
F
.51103 .10958 m .51091 .10951 L .50512 .11025 L F
.50422 .11035 m .50499 .11022 L .50411 .11033 L F
.50415 .11036 m .50411 .11031 L .50415 .11036 L .637 .785 0 r
F
.51506 .11394 m .50422 .11035 L .50761 .1147 L F
.50756 .11464 m .50411 .11033 L .50746 .11468 L .492 .747 0 r
F
.50422 .11035 m .50411 .11033 L .50756 .11464 L F
.50761 .1147 m .50746 .11468 L .50751 .11473 L F
.51933 .11638 m .50761 .1147 L .50751 .11473 L .814 .926 0 r
F
.51912 .11635 m .51506 .11394 L .50761 .1147 L .452 .688 0 r
F
.52178 .11609 m .52154 .11595 L .51942 .11647 L .578 .74 0 r
F
.52154 .11595 m .51933 .11638 L .51942 .11647 L F
.5317 .11952 m .51962 .11649 L .52371 .12071 L .563 .722 0 r
F
.52371 .12071 m .52353 .12052 L .52369 .12071 L .425 .623 0 r
F
.52369 .12071 m .51942 .11647 L .52354 .12077 L F
.52376 .12078 m .52354 .12077 L .52774 .12499 L .783 .893 0 r
F
.5364 .12398 m .52376 .12078 L .52782 .12507 L .542 .696 0 r
F
.54369 .12002 m .53206 .11732 L .53687 .12143 L .482 .658 0 r
F
.54342 .11983 m .53206 .11732 L .54369 .12002 L F
.54353 .11964 m .53206 .11732 L .54401 .11996 L F
.54353 .11964 m .54401 .11996 L .54401 .11996 L F
.54459 .11965 m .53925 .11551 L .53875 .11578 L .757 .85 0 r
F
.54459 .11965 m .53875 .11578 L .54122 .11777 L F
.54301 .11953 m .53875 .11578 L .53206 .11732 L .482 .658 0 r
F
.54353 .11964 m .53875 .11578 L .54301 .11953 L F
.53875 .11578 m .52715 .11535 L .53206 .11732 L .755 .855 0 r
F
.53818 .11608 m .52693 .11516 L .5317 .11952 L .758 .859 0 r
F
.53731 .11546 m .52693 .11516 L .53818 .11608 L F
.53922 .11567 m .52692 .11526 L .52715 .11535 L .755 .855 0 r
F
.53875 .11578 m .53731 .11546 L .5377 .11574 L .758 .859 0 r
F
.53922 .11567 m .52715 .11535 L .53875 .11578 L .755 .855 0 r
F
.53875 .11578 m .5377 .11574 L .53818 .11608 L .758 .859 0 r
F
.53925 .11551 m .53842 .11549 L .53875 .11578 L F
.53842 .11549 m .53731 .11546 L .53875 .11578 L F
.54459 .11965 m .53818 .11608 L .54353 .11964 L .757 .85 0 r
F
.54988 .12388 m .54459 .11965 L .54401 .11996 L .756 .84 0 r
F
.5487 .12389 m .54401 .11996 L .53687 .12143 L .454 .626 0 r
F
.5487 .12389 m .54401 .11996 L .5364 .12398 L .756 .84 0 r
F
.54988 .12388 m .54401 .11996 L .5487 .12389 L F
.54982 .12412 m .54455 .11984 L .54401 .11996 L .454 .626 0 r
F
.54982 .12412 m .54401 .11996 L .5487 .12389 L F
.54455 .11984 m .53922 .11567 L .53875 .11578 L .482 .658 0 r
F
.54455 .11984 m .53875 .11578 L .54353 .11964 L F
.54122 .11777 m .53875 .11578 L .53818 .11608 L .757 .85 0 r
F
.54353 .11964 m .53818 .11608 L .5317 .11952 L F
.54401 .11996 m .54342 .11983 L .54369 .12002 L .482 .658 0 r
F
.54459 .11965 m .54353 .11964 L .54401 .11996 L .757 .85 0 r
F
.54455 .11984 m .54353 .11964 L .54401 .11996 L .482 .658 0 r
F
.54401 .11996 m .54257 .11963 L .54343 .12026 L .757 .85 0 r
F
.54353 .11964 m .54257 .11963 L .54401 .11996 L F
.54343 .12026 m .5317 .11952 L .5364 .12398 L F
.54257 .11963 m .5317 .11952 L .54343 .12026 L F
.5487 .12389 m .5364 .12398 L .5415 .12549 L .756 .84 0 r
F
.5487 .12389 m .5415 .12549 L .54165 .12553 L F
.54915 .12398 m .5487 .12389 L .5415 .12549 L .454 .626 0 r
F
.54915 .12398 m .5415 .12549 L .54164 .1256 L F
.53736 .1254 m .52782 .12507 L .52764 .12509 L .35 .429 0 r
F
.54165 .12553 m .52782 .12507 L .53736 .1254 L F
.5415 .12549 m .52782 .12507 L .52763 .12514 L .783 .886 0 r
F
.5415 .12549 m .5364 .12398 L .52782 .12507 L .35 .429 0 r
F
.52782 .12507 m .52756 .12506 L .52763 .12514 L .783 .893 0 r
F
.53949 .12858 m .53637 .12415 L .52729 .12801 L .8 .863 0 r
F
.52734 .12807 m .52729 .12801 L .52717 .12806 L F
.54093 .12865 m .52729 .12801 L .52734 .12807 L F
.52729 .12801 m .5269 .12758 L .52721 .12794 L .143 .08 0 r
F
.53767 .1285 m .53449 .13448 L .52729 .12801 L .721 .048 0 r
F
.54093 .12865 m .53923 .13019 L .53767 .1285 L F
.53923 .13019 m .53449 .13448 L .53767 .1285 L F
.54501 .13645 m .53449 .13448 L .53923 .13019 L .738 .594 0 r
F
.54501 .13645 m .53923 .13019 L .54093 .12865 L F
.54481 .13605 m .5448 .13604 L .54469 .13583 L 0 .021 0 r
F
.5447 .13585 m .54469 .13583 L .54093 .12865 L F
.54481 .13605 m .54469 .13583 L .5447 .13585 L F
.54501 .13645 m .53637 .12415 L .54093 .12865 L F
.54661 .13873 m .54504 .13648 L .54503 .13647 L F
.5456 .13713 m .54503 .13647 L .54436 .13518 L F
.54661 .13873 m .54503 .13647 L .5456 .13713 L F
.54661 .13873 m .54436 .13518 L .54522 .13623 L F
.54962 .143 m .54117 .12874 L .54573 .13336 L 0 0 0 r
F
.5478 .14061 m .54117 .12873 L .54962 .143 L F
.54504 .13648 m .54501 .13645 L .5448 .13604 L 0 .021 0 r
F
.54504 .13648 m .5448 .13604 L .54481 .13605 L F
.54504 .13648 m .54093 .12865 L .54102 .12874 L F
.54122 .12894 m .54102 .12874 L .54122 .12895 L .682 .053 0 r
F
.54117 .12874 m .54117 .12873 L .54119 .12876 L 0 0 0 r
F
.54117 .12874 m .54119 .12876 L .54573 .13336 L F
.54117 .12873 m .54661 .13873 L .54102 .12874 L .682 .053 0 r
F
.54117 .12873 m .54106 .12853 L .54573 .13336 L 0 0 0 r
F
.54573 .13336 m .5412 .12873 L .54266 .13025 L .682 .053 0 r
F
.55503 .12851 m .54518 .12867 L .54573 .13336 L F
.54518 .12867 m .5412 .12873 L .54573 .13336 L F
.55503 .12851 m .54742 .13776 L .54117 .12873 L F
.55086 .14609 m .54128 .12889 L .54123 .12882 L 0 0 0 r
F
.54124 .12885 m .54116 .1287 L .54117 .12873 L F
.55086 .14609 m .54116 .1287 L .54124 .12885 L F
.55086 .14609 m .5478 .14061 L .54962 .143 L F
.55086 .14609 m .54742 .13776 L .54115 .12867 L F
.54742 .13776 m .54703 .13683 L .54413 .1328 L F
.54742 .13776 m .54413 .1328 L .54115 .12867 L F
.55737 .14115 m .54938 .13842 L .55503 .12851 L .519 .3 0 r
F
.55737 .14115 m .54742 .13776 L .55086 .14609 L .578 .409 0 r
F
.54867 .13965 m .54742 .13776 L .55503 .12851 L .519 .3 0 r
F
.56438 .16565 m .55384 .15784 L .56517 .13751 L .453 .106 0 r
F
.56536 .13751 m .56517 .13751 L .56537 .13715 L F
.56533 .13754 m .5653 .13751 L .56525 .13758 L .601 .055 0 r
F
.5653 .13751 m .56529 .13751 L .56525 .13758 L F
.56529 .13751 m .56517 .13751 L .56525 .13758 L F
.56536 .13757 m .56534 .13757 L .57034 .14222 L .685 .754 0 r
F
.56537 .13768 m .56525 .13758 L .56537 .13769 L F
.56534 .13757 m .56525 .13758 L .57031 .14224 L F
.57995 .13603 m .57441 .13165 L .56525 .13758 L F
.56438 .16565 m .56517 .13751 L .56536 .13751 L .453 .106 0 r
F
.5653 .13751 m .56529 .13751 L .56529 .13751 L .601 .055 0 r
F
.56039 .1503 m .55503 .12851 L .56018 .13299 L .706 .112 0 r
F
.56027 .1501 m .55503 .12851 L .56039 .1503 L F
.55866 .14783 m .55503 .12851 L .5604 .15065 L F
.55967 .15313 m .55086 .14609 L .55384 .15784 L .523 .265 0 r
F
.5604 .15065 m .56027 .1501 L .56039 .1503 L .706 .112 0 r
F
.55778 .14328 m .55736 .1411 L .55761 .1424 L F
.55833 .14615 m .55737 .14115 L .55545 .14261 L .523 .265 0 r
F
.55899 .14959 m .55545 .14261 L .55086 .14609 L F
.56042 .15241 m .55866 .14783 L .5604 .15065 L .706 .112 0 r
F
.56026 .1521 m .55866 .14783 L .56042 .15241 L F
.55899 .14959 m .55866 .14783 L .56042 .15252 L F
.55899 .14959 m .55761 .1424 L .55859 .14746 L F
.55859 .14746 m .55736 .1411 L .55503 .12851 L F
.56529 .13751 m .56018 .13299 L .56517 .13751 L .601 .055 0 r
F
.56536 .13751 m .5603 .13298 L .56533 .13754 L F
.56536 .13757 m .56536 .13751 L .56537 .13715 L .774 .152 0 r
F
.57441 .13165 m .56518 .13252 L .56536 .13751 L .601 .055 0 r
F
.56518 .13252 m .5603 .13298 L .56536 .13751 L F
.56536 .13757 m .56536 .13751 L .56536 .13757 L .774 .152 0 r
F
.5603 .13298 m .56018 .13299 L .56533 .13754 L .601 .055 0 r
F
.57078 .137 m .56536 .13757 L .57034 .14222 L .685 .754 0 r
F
.57034 .14226 m .57034 .14222 L .57026 .14227 L .68 .74 0 r
F
.57031 .14224 m .56537 .13768 L .57026 .14227 L .685 .754 0 r
F
.56537 .13768 m .56537 .13769 L .57026 .14227 L F
.57034 .14226 m .57026 .14227 L .57033 .14234 L .68 .74 0 r
F
.56412 .18629 m .56536 .13757 L .57034 .14222 L .774 .152 0 r
F
.56437 .1764 m .56438 .16565 L .56451 .16177 L F
.56458 .1683 m .56451 .16177 L .56536 .13751 L F
.56437 .1764 m .56451 .16177 L .56458 .1683 L F
.57995 .13603 m .57078 .137 L .57034 .14222 L .685 .754 0 r
F
.56456 .16917 m .56536 .13751 L .56536 .13757 L .774 .152 0 r
F
.56456 .16915 m .56536 .13751 L .56456 .16917 L F
.56437 .1764 m .56536 .13751 L .56437 .17643 L F
.57441 .13165 m .56293 .15301 L .56018 .13299 L .601 .055 0 r
F
.56437 .17643 m .56456 .16915 L .56456 .16917 L .774 .152 0 r
F
.56412 .18629 m .56438 .16565 L .56437 .1764 L F
.56427 .18683 m .57034 .14222 L .57034 .14226 L .76 .165 0 r
F
.56428 .1868 m .57034 .14222 L .56427 .18683 L F
.56342 .19215 m .56412 .18629 L .56496 .1803 L F
.56408 .18821 m .56496 .1803 L .57034 .14222 L F
.56043 .21503 m .56496 .1803 L .56408 .18821 L F
.56698 .16695 m .57034 .14222 L .57034 .14222 L F
.56698 .16695 m .57034 .14222 L .56698 .16695 L F
.56249 .19989 m .56698 .16695 L .56249 .19989 L F
.56698 .16695 m .56698 .16695 L .56223 .20184 L F
.56223 .20184 m .56698 .16695 L .56698 .16695 L F
.5854 .14052 m .57995 .13603 L .57034 .14222 L .68 .74 0 r
F
.57034 .14222 m .57035 .14221 L .57034 .14226 L .76 .165 0 r
F
.5854 .14052 m .57034 .14222 L .57034 .14226 L .68 .74 0 r
F
.57034 .14226 m .57034 .14226 L .57526 .14702 L .76 .165 0 r
F
.57034 .14226 m .57425 .14593 L .57526 .14702 L F
.5854 .14052 m .57034 .14226 L .57526 .14702 L .68 .74 0 r
F
.56897 .17437 m .57441 .13165 L .56952 .17709 L .893 .187 0 r
F
.56725 .17407 m .57441 .13165 L .56772 .18416 L F
.56698 .16695 m .57034 .14222 L .56698 .16695 L .76 .165 0 r
F
.56855 .16278 m .56265 .15353 L .57441 .13165 L .151 .015 0 r
F
.56601 .18517 m .56601 .17044 L .56412 .18629 L .18 .02 0 r
F
.56772 .18416 m .56688 .17739 L .56601 .18517 L F
.56688 .17739 m .56601 .17044 L .56601 .18517 L F
.56725 .17407 m .56601 .17044 L .56688 .17739 L F
.56725 .17407 m .56688 .17739 L .56772 .18416 L F
.56725 .17407 m .56855 .16278 L .56801 .1696 L .893 .187 0 r
F
.56801 .1696 m .56855 .16278 L .56915 .15957 L F
.56901 .16365 m .56915 .15957 L .57441 .13165 L F
.56801 .1696 m .56915 .15957 L .56901 .16365 L F
.5698 .14108 m .56903 .13201 L .56495 .13524 L .083 .032 0 r
F
.57244 .14425 m .57 .13549 L .5698 .14108 L F
.57 .13549 m .56903 .13201 L .5698 .14108 L F
.56952 .17709 m .57441 .13165 L .57995 .13603 L .893 .187 0 r
F
.56772 .18416 m .56897 .17437 L .56952 .17709 L F
.59578 .12781 m .58151 .13105 L .58725 .13498 L .18 .171 0 r
F
.60193 .13148 m .59578 .12781 L .58725 .13498 L .648 .764 0 r
F
.59404 .13277 m .58014 .13542 L .58564 .13981 L .625 .717 0 r
F
.5999 .13692 m .59404 .13277 L .58564 .13981 L .619 .704 0 r
F
.59373 .13363 m .57995 .13603 L .5854 .14052 L .461 .044 0 r
F
.59952 .13794 m .59373 .13363 L .5854 .14052 L .602 .68 0 r
F
.56223 .20184 m .56249 .19989 L .56223 .20184 L .76 .165 0 r
F
.56249 .19989 m .56249 .19989 L .56223 .20184 L F
.56043 .21503 m .56223 .20184 L .56223 .20184 L F
.56043 .21503 m .56412 .18629 L .56342 .19215 L F
.56043 .21503 m .56428 .1868 L .56427 .18683 L F
.56563 .21262 m .56412 .18629 L .56043 .21503 L .114 0 0 r
F
.56595 .21247 m .56579 .21025 L .56563 .21262 L F
.56579 .21025 m .56412 .18629 L .56563 .21262 L F
.59373 .13363 m .5689 .1918 L .57995 .13603 L .461 .044 0 r
F
.56595 .21247 m .5689 .1918 L .56412 .18629 L .114 0 0 r
F
.5689 .1918 m .56772 .18416 L .56412 .18629 L F
.5689 .1918 m .56122 .20978 L .56772 .18416 L .461 .044 0 r
F
.5689 .1918 m .57125 .17029 L .57995 .13603 L F
.55893 .24654 m .56595 .21247 L .56043 .21503 L .073 0 0 r
F
.5508 .26205 m .56122 .20978 L .5689 .1918 L 0 0 0 r
F
.56588 .21694 m .5689 .1918 L .59373 .13363 L F
.56588 .21694 m .5689 .1918 L .56595 .21247 L F
.55836 .25466 m .56323 .2325 L .56595 .21247 L F
.56323 .2325 m .56588 .21694 L .57264 .19672 L .333 .023 0 r
F
.56323 .2325 m .57264 .19672 L .59373 .13363 L F
.56323 .2325 m .56582 .22067 L .56588 .21694 L 0 0 0 r
F
.56323 .2325 m .56588 .21694 L .56595 .21247 L F
.56323 .2325 m .5508 .26205 L .56588 .21694 L .333 .023 0 r
F
.54241 .29798 m .5508 .26205 L .56323 .2325 L 1 .648 0 r
F
.55291 .28028 m .55893 .24654 L .55261 .27536 L 0 0 0 r
F
.55319 .27867 m .55836 .25466 L .55893 .24654 L F
.55447 .26629 m .56266 .23469 L .55836 .25466 L .967 .323 0 r
F
.56266 .23469 m .56323 .2325 L .55836 .25466 L F
.55291 .28028 m .55836 .25466 L .55319 .27867 L 0 0 0 r
F
.61529 .12688 m .60193 .13148 L .60803 .13524 L .591 .724 0 r
F
.6217 .13036 m .61529 .12688 L .60803 .13524 L .585 .713 0 r
F
.61271 .13322 m .5999 .13692 L .60569 .14117 L .532 .64 0 r
F
.61875 .13725 m .61271 .13322 L .60569 .14117 L .523 .625 0 r
F
.61211 .1347 m .59952 .13794 L .60522 .14236 L .5 .601 0 r
F
.61529 .12688 m .60882 .12348 L .60193 .13148 L .591 .724 0 r
F
.61271 .13322 m .60659 .1293 L .5999 .13692 L .532 .64 0 r
F
.61211 .1347 m .6061 .13056 L .59952 .13794 L .5 .601 0 r
F
.55059 .29256 m .55291 .28028 L .55261 .27536 L 0 0 0 r
F
.54955 .29028 m .55572 .26536 L .55291 .28028 L 1 .483 0 r
F
.55572 .26536 m .55836 .25466 L .55291 .28028 L F
.55002 .29744 m .55291 .28028 L .55059 .29256 L 0 0 0 r
F
.54955 .29028 m .55155 .27869 L .55836 .25466 L 1 .483 0 r
F
.61801 .13897 m .61211 .1347 L .60522 .14236 L .486 .579 0 r
F
.62687 .12125 m .61529 .12688 L .6217 .13036 L .525 .678 0 r
F
.6335 .12443 m .6217 .13036 L .62806 .13392 L .517 .665 0 r
F
.6335 .12443 m .62687 .12125 L .6217 .13036 L F
.62353 .12895 m .61271 .13322 L .61875 .13725 L .42 .554 0 r
F
.62687 .12125 m .62019 .11815 L .61529 .12688 L .525 .678 0 r
F
.62353 .12895 m .61728 .12525 L .61271 .13322 L .42 .554 0 r
F
.64007 .12772 m .6335 .12443 L .62806 .13392 L .509 .652 0 r
F
.62971 .13275 m .61875 .13725 L .6247 .14137 L .41 .537 0 r
F
.62971 .13275 m .62353 .12895 L .61875 .13725 L F
.62261 .1311 m .61211 .1347 L .61801 .13897 L .383 .487 0 r
F
.62261 .1311 m .61652 .12709 L .61211 .1347 L F
.62551 .12108 m .61728 .12525 L .62353 .12895 L .334 .438 0 r
F
.62443 .12361 m .61652 .12709 L .62261 .1311 L 0 0 0 r
F
.54834 .30282 m .55291 .28028 L .55002 .29744 L 1 .414 0 r
F
.54834 .30282 m .54955 .29028 L .55291 .28028 L F
.55206 .27574 m .54241 .29798 L .55447 .26629 L .191 0 0 r
F
.53926 .31398 m .54241 .29798 L .55206 .27574 L 1 .713 0 r
F
.5474 .29175 m .55206 .27574 L .55155 .27869 L 1 .875 0 r
F
.54492 .30031 m .55155 .27869 L .54955 .29028 L F
.54226 .31687 m .54182 .30912 L .54328 .30394 L .996 .218 0 r
F
.53926 .31398 m .54742 .28959 L .54492 .30031 L 1 .713 0 r
F
.54742 .28959 m .55206 .27574 L .54492 .30031 L F
.54468 .3097 m .5443 .30367 L .54955 .29028 L 1 .777 0 r
F
.63581 .13664 m .62971 .13275 L .6247 .14137 L .404 .52 0 r
F
.62857 .13526 m .61801 .13897 L .6238 .14337 L .37 .455 0 r
F
.62857 .13526 m .62261 .1311 L .61801 .13897 L F
.63624 .11467 m .62687 .12125 L .6335 .12443 L .453 .626 0 r
F
.63179 .12454 m .62353 .12895 L .62971 .13275 L .328 .427 0 r
F
.63179 .12454 m .62551 .12108 L .62353 .12895 L F
.63047 .12748 m .62261 .1311 L .62857 .13526 L .271 .319 0 r
F
.63047 .12748 m .62443 .12361 L .62261 .1311 L F
.62944 .1119 m .62019 .11815 L .62687 .12125 L 0 0 0 r
F
.63624 .11467 m .62944 .1119 L .62687 .12125 L .453 .626 0 r
F
.63051 .11776 m .62551 .12108 L .63179 .12454 L .177 .212 0 r
F
.62957 .11991 m .62443 .12361 L .63047 .12748 L 0 0 0 r
F
.54468 .3097 m .54955 .29028 L .54834 .30282 L 1 .777 0 r
F
.54068 .31904 m .54182 .30912 L .54226 .31687 L .16 0 0 r
F
.54068 .31904 m .52889 .33974 L .54182 .30912 L F
.52889 .33974 m .52849 .34045 L .52879 .33975 L F
.52889 .33974 m .52879 .33974 L .54182 .30912 L F
.53093 .3398 m .52889 .33974 L .53126 .34103 L .121 .129 0 r
F
.53067 .33882 m .52889 .33974 L .53093 .3398 L F
.53126 .34103 m .52889 .33974 L .52833 .34198 L .223 .274 0 r
F
.52889 .33974 m .52879 .33975 L .52833 .34198 L F
.53053 .33909 m .52849 .34045 L .52889 .33974 L .227 .295 0 r
F
.53867 .32301 m .53835 .32313 L .54068 .31904 L F
.54069 .32264 m .54068 .31904 L .54234 .32317 L 0 0 0 r
F
.54069 .32264 m .53072 .3388 L .54068 .31904 L F
.53072 .3388 m .53053 .33909 L .53067 .33882 L F
.53072 .3388 m .53068 .33881 L .54068 .31904 L F
.53067 .33882 m .52889 .33974 L .53835 .32313 L .227 .295 0 r
F
.53067 .33882 m .53835 .32313 L .53867 .32301 L F
.53979 .31719 m .53843 .32019 L .53983 .31698 L 0 0 0 r
F
.54329 .32269 m .54269 .31454 L .54306 .32208 L .839 .138 0 r
F
.54329 .32269 m .54226 .31687 L .54269 .31454 L F
.54234 .32317 m .54226 .31687 L .54329 .32269 L 1 .156 0 r
F
.54234 .32317 m .54068 .31904 L .54226 .31687 L F
.54207 .31949 m .53979 .31719 L .54468 .3097 L 1 .319 0 r
F
.53979 .31719 m .53983 .31698 L .53989 .31685 L 0 0 0 r
F
.53843 .32019 m .53926 .31398 L .54063 .31093 L 1 .189 0 r
F
.5443 .30367 m .54426 .3031 L .54544 .30025 L 1 .777 0 r
F
.5443 .30367 m .54544 .30025 L .54955 .29028 L F
.5439 .30361 m .53926 .31398 L .54492 .30031 L 0 0 0 r
F
.54456 .30182 m .54419 .30189 L .54492 .30031 L 1 .777 0 r
F
.54426 .3031 m .54425 .30284 L .54456 .30182 L F
.54425 .30284 m .54419 .30189 L .54456 .30182 L F
.53983 .31698 m .54063 .31093 L .54425 .30284 L 1 .189 0 r
F
.54426 .3031 m .54492 .30031 L .54955 .29028 L 1 .777 0 r
F
.53843 .32019 m .54063 .31093 L .53983 .31698 L 1 .189 0 r
F
.53971 .31711 m .54419 .30189 L .54425 .30284 L 1 .528 0 r
F
.53989 .31685 m .54425 .30284 L .54468 .3097 L F
.53983 .31698 m .54425 .30284 L .53989 .31685 L 1 .189 0 r
F
.53971 .31711 m .54425 .30284 L .53989 .31685 L 1 .528 0 r
F
.53989 .31685 m .54425 .30284 L .54 .3166 L 1 .189 0 r
F
.54 .3166 m .54425 .30284 L .62443 .12361 L F
.53979 .31719 m .53989 .31685 L .54468 .3097 L 1 .319 0 r
F
.62957 .11991 m .53983 .31711 L .62443 .12361 L 0 0 0 r
F
.53983 .31711 m .54 .3166 L .62443 .12361 L F
.62443 .12361 m .54578 .29942 L .61652 .12709 L F
.62019 .11815 m .60882 .12348 L .61529 .12688 L F
.62944 .1119 m .62047 .11833 L .62019 .11815 L F
.61871 .1195 m .6134 .12303 L .61728 .12525 L .344 .456 0 r
F
.62551 .12108 m .62044 .11835 L .61728 .12525 L .334 .438 0 r
F
.6204 .11838 m .62044 .11835 L .61871 .1195 L 0 0 0 r
F
.62047 .11833 m .62044 .11835 L .6204 .11838 L F
.62413 .11496 m .61917 .11766 L .62044 .11835 L .135 .147 0 r
F
.62436 .11595 m .62044 .11835 L .62174 .11905 L F
.62436 .11595 m .62174 .11905 L .62551 .12108 L F
.62436 .11595 m .62044 .11835 L .62944 .1119 L .184 .221 0 r
F
.62488 .11533 m .62436 .11595 L .62477 .11562 L .543 .207 0 r
F
.62491 .11531 m .62477 .11562 L .62944 .1119 L F
.62488 .11533 m .62477 .11562 L .62491 .11531 L F
.63621 .10476 m .62491 .1153 L .62944 .1119 L F
.62491 .1153 m .6249 .11532 L .62944 .1119 L F
.63346 .09466 m .62424 .11486 L .63621 .10476 L 1 1 0 r
F
.62424 .11486 m .62424 .11486 L .62491 .1153 L .196 .174 0 r
F
.62424 .11486 m .62413 .11496 L .62482 .11526 L F
.62424 .11486 m .62482 .11526 L .62491 .1153 L F
.63346 .09466 m .61999 .10947 L .62169 .11308 L 1 1 0 r
F
.6234 .11671 m .62044 .11835 L .62436 .11595 L .184 .221 0 r
F
.62434 .11588 m .62044 .11835 L .62436 .11595 L .135 .147 0 r
F
.62413 .11496 m .62044 .11835 L .62434 .11588 L F
.62413 .11496 m .61785 .11185 L .61917 .11766 L F
.61785 .11185 m .61171 .10827 L .61278 .11429 L .118 .116 0 r
F
.61785 .11185 m .61278 .11429 L .61917 .11766 L F
.61423 .11076 m .61171 .10827 L .61624 .11091 L 0 0 0 r
F
.61171 .10827 m .6063 .111 L .61278 .11429 L .164 .168 0 r
F
.61278 .11429 m .60453 .11813 L .61094 .12164 L .358 .482 0 r
F
.61278 .11429 m .6063 .111 L .60453 .11813 L F
.61917 .11766 m .61278 .11429 L .61094 .12164 L .344 .456 0 r
F
.61709 .11377 m .61582 .1132 L .61198 .11636 L .162 .189 0 r
F
.61582 .1132 m .6107 .11093 L .61149 .11428 L F
.61582 .1132 m .61149 .11428 L .61198 .11636 L F
.61094 .12164 m .60453 .11813 L .60039 .12548 L .446 .591 0 r
F
.60882 .12348 m .59578 .12781 L .60193 .13148 L 0 0 0 r
F
.58681 .12971 m .57573 .12719 L .58151 .13105 L .241 .304 0 r
F
.58662 .1296 m .57573 .12719 L .58681 .12971 L F
.58596 .1291 m .57573 .12719 L .58695 .12967 L F
.58596 .1291 m .58695 .12967 L .58695 .12967 L F
.58295 .12534 m .58208 .12476 L .58107 .12562 L .631 .731 0 r
F
.58107 .12562 m .56964 .12735 L .57573 .12719 L .625 .729 0 r
F
.57612 .12636 m .56892 .12694 L .56948 .12735 L .637 .744 0 r
F
.58208 .12476 m .57933 .12522 L .58022 .12575 L F
.58208 .12476 m .58022 .12575 L .58107 .12562 L F
.57147 .12705 m .56964 .12735 L .58107 .12562 L .625 .729 0 r
F
.58809 .12871 m .58295 .12534 L .58132 .1258 L .631 .731 0 r
F
.58809 .12871 m .58132 .1258 L .58261 .12672 L F
.58596 .1291 m .58107 .12562 L .57573 .12719 L .241 .304 0 r
F
.58295 .12534 m .58107 .12562 L .58063 .12599 L .631 .731 0 r
F
.58809 .12871 m .58063 .12599 L .58596 .1291 L F
.58809 .12871 m .58596 .1291 L .58622 .12925 L F
.58695 .12967 m .58662 .1296 L .58681 .12971 L .241 .304 0 r
F
.58809 .12871 m .57593 .13219 L .58695 .12967 L .631 .731 0 r
F
.59578 .12781 m .58889 .12923 L .58151 .13105 L .18 .171 0 r
F
.58889 .12923 m .58886 .12924 L .58884 .12924 L F
.58889 .12923 m .58884 .12924 L .58151 .13105 L F
.59404 .13277 m .58886 .12924 L .58014 .13542 L .625 .717 0 r
F
.58886 .12924 m .58809 .12871 L .58695 .12967 L F
.58886 .12924 m .58695 .12967 L .58675 .12973 L .18 .171 0 r
F
.58886 .12924 m .58675 .12973 L .58151 .13105 L F
.58886 .12924 m .58695 .12967 L .58014 .13542 L .625 .717 0 r
F
.58886 .12924 m .58785 .12945 L .58695 .12967 L .18 .171 0 r
F
.58785 .12945 m .58189 .12538 L .58107 .12562 L .241 .304 0 r
F
.58785 .12945 m .58107 .12562 L .58596 .1291 L F
.58261 .12672 m .58132 .1258 L .58063 .12599 L .631 .731 0 r
F
.57933 .12522 m .56892 .12694 L .58063 .12599 L .637 .744 0 r
F
.58189 .12538 m .57147 .12705 L .58107 .12562 L .625 .729 0 r
F
.58107 .12562 m .58022 .12575 L .58063 .12599 L .637 .744 0 r
F
.58063 .12599 m .57612 .12636 L .57456 .13113 L F
.57147 .12705 m .56948 .12735 L .56964 .12735 L .625 .729 0 r
F
.56778 .1276 m .55586 .12504 L .56118 .12907 L .363 .502 0 r
F
.56758 .12746 m .55586 .12504 L .56778 .1276 L F
.56728 .12709 m .55586 .12504 L .568 .12755 L F
.56728 .12709 m .568 .12755 L .568 .12755 L F
.56241 .12338 m .55043 .12422 L .55586 .12504 L .698 .793 0 r
F
.55611 .1238 m .54988 .12388 L .55025 .12419 L .704 .801 0 r
F
.56322 .12285 m .56084 .12303 L .56147 .12345 L F
.56322 .12285 m .56147 .12345 L .56241 .12338 L F
.55335 .12398 m .55043 .12422 L .56241 .12338 L .698 .793 0 r
F
.56892 .12694 m .56382 .12329 L .56264 .12356 L .7 .79 0 r
F
.56892 .12694 m .56264 .12356 L .5643 .12483 L F
.56728 .12709 m .56241 .12338 L .55586 .12504 L .363 .502 0 r
F
.56382 .12329 m .56241 .12338 L .56189 .12373 L .7 .79 0 r
F
.56892 .12694 m .56189 .12373 L .56728 .12709 L F
.56892 .12694 m .56728 .12709 L .56744 .1272 L F
.568 .12755 m .56758 .12746 L .56778 .1276 L .363 .502 0 r
F
.56892 .12694 m .55616 .12911 L .568 .12755 L .7 .79 0 r
F
.57573 .12719 m .56949 .12735 L .56118 .12907 L .233 .179 0 r
F
.56949 .12735 m .56948 .12735 L .56945 .12736 L F
.56949 .12735 m .56945 .12736 L .56118 .12907 L F
.57456 .13113 m .56948 .12735 L .56027 .13263 L .697 .778 0 r
F
.56948 .12735 m .56892 .12694 L .568 .12755 L F
.56948 .12735 m .568 .12755 L .56781 .12759 L .233 .179 0 r
F
.56948 .12735 m .56781 .12759 L .56118 .12907 L F
.56948 .12735 m .568 .12755 L .56027 .13263 L .697 .778 0 r
F
.56948 .12735 m .56881 .12737 L .568 .12755 L .233 .179 0 r
F
.56881 .12737 m .56313 .1232 L .56241 .12338 L .363 .502 0 r
F
.56881 .12737 m .56241 .12338 L .56728 .12709 L F
.5643 .12483 m .56264 .12356 L .56189 .12373 L .7 .79 0 r
F
.56084 .12303 m .54988 .12388 L .56189 .12373 L .704 .801 0 r
F
.56313 .1232 m .55335 .12398 L .56241 .12338 L .698 .793 0 r
F
.56241 .12338 m .56147 .12345 L .56189 .12373 L .704 .801 0 r
F
.56189 .12373 m .55611 .1238 L .55511 .12821 L F
.55335 .12398 m .55025 .12419 L .55043 .12422 L .698 .793 0 r
F
.55611 .1238 m .55025 .12419 L .55511 .12821 L .704 .801 0 r
F
.56313 .1232 m .54982 .12412 L .55025 .12419 L .698 .793 0 r
F
.56313 .1232 m .55025 .12419 L .55335 .12398 L F
.56382 .12329 m .56322 .12285 L .56241 .12338 L .7 .79 0 r
F
.56728 .12709 m .56189 .12373 L .55511 .12821 L F
.56881 .12737 m .56728 .12709 L .568 .12755 L .363 .502 0 r
F
.56744 .1272 m .55511 .12821 L .55616 .12911 L .7 .79 0 r
F
.56728 .12709 m .55511 .12821 L .56744 .1272 L F
.568 .12755 m .55616 .12911 L .56027 .13263 L F
.57611 .1264 m .56948 .12735 L .57456 .13113 L .637 .744 0 r
F
.57612 .12636 m .56948 .12735 L .57611 .1264 L F
.58189 .12538 m .56881 .12737 L .56948 .12735 L .625 .729 0 r
F
.58189 .12538 m .56948 .12735 L .57147 .12705 L F
.58596 .1291 m .58063 .12599 L .57456 .13113 L .631 .731 0 r
F
.58785 .12945 m .58596 .1291 L .58695 .12967 L .241 .304 0 r
F
.58622 .12925 m .57456 .13113 L .57593 .13219 L .631 .731 0 r
F
.58596 .1291 m .57456 .13113 L .58622 .12925 L F
.58695 .12967 m .57593 .13219 L .58014 .13542 L F
.60039 .12548 m .58809 .12871 L .58886 .12924 L .551 .672 0 r
F
.60039 .12548 m .58886 .12924 L .59469 .12786 L F
.60882 .12348 m .60139 .12607 L .59578 .12781 L 0 0 0 r
F
.60136 .12608 m .59908 .12682 L .59578 .12781 L F
.59926 .12677 m .58886 .12924 L .59578 .12781 L .526 .643 0 r
F
.60039 .12548 m .58982 .12989 L .59926 .12677 L .551 .672 0 r
F
.60139 .12607 m .60134 .12609 L .59578 .12781 L 0 0 0 r
F
.60659 .1293 m .60136 .12608 L .59404 .13277 L .541 .656 0 r
F
.60136 .12608 m .59926 .12677 L .59908 .12682 L 0 0 0 r
F
.60136 .12608 m .60039 .12548 L .59926 .12677 L .541 .656 0 r
F
.60136 .12608 m .59926 .12677 L .59404 .13277 L F
.60136 .12608 m .6 .12655 L .59926 .12677 L 0 0 0 r
F
.6 .12655 m .58785 .12945 L .58886 .12924 L .526 .643 0 r
F
.6 .12655 m .58886 .12924 L .59926 .12677 L F
.59469 .12786 m .58886 .12924 L .59448 .12794 L .551 .672 0 r
F
.59448 .12794 m .58886 .12924 L .58982 .12989 L F
.59926 .12677 m .58982 .12989 L .59404 .13277 L F
.60139 .12607 m .60136 .12608 L .60134 .12609 L 0 0 0 r
F
.61094 .12164 m .60039 .12548 L .60136 .12608 L .446 .591 0 r
F
.6062 .12451 m .60136 .12608 L .60249 .12677 L F
.61001 .12328 m .60249 .12677 L .60659 .1293 L F
.61001 .12328 m .60136 .12608 L .60882 .12348 L .407 .542 0 r
F
.62019 .11815 m .61215 .12229 L .60882 .12348 L 0 0 0 r
F
.61215 .12229 m .6121 .12231 L .60882 .12348 L F
.61212 .12231 m .60992 .1233 L .60882 .12348 L F
.61094 .12164 m .60249 .12677 L .61001 .12328 L .446 .591 0 r
F
.61728 .12525 m .61212 .12231 L .60659 .1293 L .432 .572 0 r
F
.61212 .12231 m .61001 .12328 L .60992 .1233 L 0 0 0 r
F
.61212 .12231 m .61094 .12164 L .61001 .12328 L .432 .572 0 r
F
.61212 .12231 m .61001 .12328 L .60659 .1293 L F
.61212 .12231 m .61032 .12323 L .61001 .12328 L 0 0 0 r
F
.61032 .12323 m .6 .12655 L .60136 .12608 L .407 .542 0 r
F
.61032 .12323 m .60136 .12608 L .61001 .12328 L F
.60628 .12447 m .60136 .12608 L .6062 .12451 L .446 .591 0 r
F
.61094 .12164 m .60136 .12608 L .60628 .12447 L F
.61215 .12229 m .61212 .12231 L .6121 .12231 L 0 0 0 r
F
.61917 .11766 m .61094 .12164 L .61212 .12231 L .344 .456 0 r
F
.61592 .12069 m .61212 .12231 L .6134 .12303 L F
.61871 .1195 m .61212 .12231 L .62019 .11815 L .302 .385 0 r
F
.61917 .11766 m .6134 .12303 L .61871 .1195 L .344 .456 0 r
F
.61826 .11991 m .61032 .12323 L .61212 .12231 L .302 .385 0 r
F
.61826 .11991 m .61212 .12231 L .61871 .1195 L F
.61612 .1205 m .61212 .12231 L .61592 .12069 L .344 .456 0 r
F
.61917 .11766 m .61212 .12231 L .61612 .1205 L F
.61198 .11636 m .60402 .11951 L .61032 .12323 L .315 .411 0 r
F
.61826 .11991 m .61198 .11636 L .61032 .12323 L .302 .385 0 r
F
.61709 .11377 m .61198 .11636 L .61826 .11991 L .162 .189 0 r
F
.62044 .11835 m .61871 .1195 L .61728 .12525 L .334 .438 0 r
F
.6234 .11671 m .61826 .11991 L .62044 .11835 L .184 .221 0 r
F
.62047 .11833 m .61871 .1195 L .62019 .11815 L 0 0 0 r
F
.62044 .11835 m .61917 .11766 L .61871 .1195 L .334 .438 0 r
F
.62044 .11835 m .61826 .11991 L .61871 .1195 L 0 0 0 r
F
.6234 .11671 m .62077 .11549 L .61826 .11991 L .184 .221 0 r
F
.62077 .11549 m .61709 .11377 L .61758 .11634 L F
.62077 .11549 m .61758 .11634 L .61826 .11991 L F
.6241 .11496 m .61785 .11185 L .62413 .11496 L 0 0 0 r
F
.62259 .11499 m .62066 .11371 L .6241 .11496 L F
.62066 .11371 m .61785 .11185 L .6241 .11496 L F
.62058 .11402 m .61709 .11377 L .62077 .11549 L .299 .393 0 r
F
.61782 .11268 m .61709 .11377 L .62058 .11402 L F
.61782 .11268 m .61785 .11185 L .62259 .11499 L 0 0 0 r
F
.61999 .10947 m .62077 .11549 L .62259 .11499 L .299 .393 0 r
F
.61776 .11435 m .61782 .11268 L .62259 .11499 L 0 0 0 r
F
.61999 .10947 m .61782 .11268 L .62058 .11402 L .299 .393 0 r
F
.62259 .11499 m .62077 .11549 L .6234 .11671 L F
.61774 .1151 m .61776 .11435 L .62027 .11468 L 0 0 0 r
F
.62424 .11486 m .62169 .11308 L .62259 .11499 L 1 1 0 r
F
.63346 .09466 m .62169 .11308 L .62424 .11486 L F
.62491 .1153 m .62413 .11496 L .62436 .11595 L .177 .212 0 r
F
.62424 .11486 m .6234 .11671 L .62491 .1153 L 1 1 0 r
F
.62424 .11486 m .62491 .1153 L .63621 .10476 L F
.6254 .11386 m .62424 .11486 L .62491 .1153 L .196 .174 0 r
F
.62491 .1153 m .62436 .11595 L .62551 .12108 L .177 .212 0 r
F
.62488 .11533 m .6234 .11671 L .62436 .11595 L .543 .207 0 r
F
.53965 .31728 m .53971 .31711 L .53971 .31724 L .398 0 0 r
F
.53965 .31728 m .53971 .31724 L .53971 .31725 L F
.54583 .29671 m .55155 .27869 L .54647 .29523 L 1 .875 0 r
F
.54583 .29671 m .54647 .29523 L .54492 .30031 L F
.54419 .30189 m .54583 .29671 L .54492 .30031 L F
.55155 .27869 m .55206 .27574 L .55658 .2606 L 1 .483 0 r
F
.55155 .27869 m .55658 .2606 L .55836 .25466 L F
.54492 .30031 m .55206 .27574 L .61652 .12709 L 1 .713 0 r
F
.54419 .30189 m .55286 .27111 L .55206 .27574 L 1 .875 0 r
F
.54419 .30189 m .55206 .27574 L .5474 .29175 L F
.54578 .29942 m .5468 .29576 L .61652 .12709 L 0 0 0 r
F
.54241 .29798 m .56323 .2325 L .55447 .26629 L 1 .648 0 r
F
.54419 .30189 m .54503 .28988 L .55286 .27111 L 1 .875 0 r
F
.53926 .31398 m .53831 .3073 L .54241 .29798 L 1 .713 0 r
F
.53612 .3177 m .53831 .3073 L .53926 .31398 L 1 .389 0 r
F
.53781 .31345 m .54503 .28988 L .54419 .30189 L 1 .734 0 r
F
.53843 .32019 m .53657 .31818 L .53926 .31398 L 1 .189 0 r
F
.53657 .31818 m .53612 .3177 L .53718 .31644 L F
.53657 .31818 m .53718 .31644 L .53926 .31398 L F
.53965 .31728 m .53884 .31819 L .53971 .31711 L .398 0 0 r
F
.53482 .32315 m .53503 .32254 L .53742 .31978 L F
.53742 .31978 m .53657 .31818 L .53843 .32019 L .31 0 0 r
F
.53965 .31728 m .53742 .31978 L .53843 .32019 L 1 .886 0 r
F
.53884 .31819 m .53742 .31978 L .53971 .31711 L .398 0 0 r
F
.53747 .31988 m .53742 .31978 L .53884 .31819 L F
.53482 .32315 m .53742 .31978 L .53747 .31988 L F
.53742 .31978 m .53781 .31345 L .53971 .31711 L .455 .025 0 r
F
.53442 .32325 m .53608 .31845 L .53742 .31978 L F
.53631 .31868 m .53612 .3177 L .53657 .31818 L .31 0 0 r
F
.53608 .31845 m .53612 .3177 L .53631 .31868 L F
.53608 .31845 m .53781 .31345 L .53742 .31978 L .455 .025 0 r
F
.53604 .31921 m .53608 .31845 L .53631 .31868 L .31 0 0 r
F
.53604 .31921 m .53657 .31818 L .53742 .31978 L F
.53965 .31728 m .5365 .3194 L .53742 .31978 L 1 .886 0 r
F
.53804 .32187 m .53795 .32209 L .53965 .32113 L 1 1 0 r
F
.53795 .32209 m .53068 .33875 L .53965 .32113 L F
.53965 .32113 m .53068 .33875 L .54069 .32264 L F
.54195 .31983 m .53965 .32113 L .54207 .31949 L .316 0 0 r
F
.54133 .32152 m .53965 .32113 L .54195 .31983 L F
.53927 .32131 m .5397 .318 L .53965 .32113 L .398 0 0 r
F
.53804 .32187 m .5397 .318 L .53927 .32131 L F
.53965 .32113 m .53971 .31765 L .54207 .31949 L F
.54149 .32124 m .53887 .31999 L .53965 .32113 L .016 .111 0 r
F
.54124 .3215 m .53965 .32113 L .54047 .32232 L F
.54149 .32124 m .53965 .32113 L .54124 .3215 L F
.54149 .32124 m .54047 .32232 L .54098 .32213 L F
.54114 .32203 m .53965 .32113 L .54133 .32152 L .316 0 0 r
F
.54114 .32203 m .53789 .32232 L .53965 .32113 L F
.53053 .33909 m .52889 .33974 L .53067 .33882 L .227 .295 0 r
F
.53067 .33878 m .52889 .33974 L .53067 .33882 L .121 .129 0 r
F
.53067 .33878 m .5288 .33969 L .52889 .33974 L F
.53067 .33878 m .52817 .33772 L .5288 .33969 L F
.53004 .33807 m .52817 .33772 L .53067 .33878 L .163 .161 0 r
F
.52817 .33772 m .52636 .33828 L .5288 .33969 L .037 .113 0 r
F
.53004 .33807 m .52801 .33812 L .53053 .33909 L .278 .38 0 r
F
.52919 .33632 m .52851 .33736 L .53004 .33807 L F
.52851 .33736 m .52817 .33772 L .53004 .33807 L .163 .161 0 r
F
.52851 .33736 m .52801 .33812 L .53004 .33807 L .278 .38 0 r
F
.52895 .33689 m .52851 .33736 L .53004 .33807 L .163 .161 0 r
F
.52897 .33686 m .52895 .33689 L .53004 .33807 L F
.53804 .32187 m .52919 .33632 L .53004 .33807 L 1 1 0 r
F
.53068 .33876 m .53004 .33807 L .53053 .33909 L F
.53804 .32187 m .53004 .33807 L .53068 .33875 L F
.53068 .33875 m .53072 .3388 L .53072 .33879 L F
.53068 .33875 m .53072 .33879 L .54069 .32264 L F
.53159 .33733 m .53006 .33806 L .53068 .33875 L .224 .252 0 r
F
.53006 .33806 m .53004 .33807 L .53068 .33875 L F
.53159 .33733 m .52897 .33686 L .53004 .33807 L F
.53068 .33875 m .53004 .33807 L .53067 .33878 L F
.53068 .33875 m .53004 .33807 L .53068 .33876 L 1 1 0 r
F
.53798 .32193 m .53482 .32315 L .53884 .31819 L .398 0 0 r
F
.53741 .32245 m .53482 .32315 L .53798 .32193 L F
.53741 .32245 m .52919 .33632 L .53804 .32187 L 1 1 0 r
F
.53965 .31728 m .53843 .32019 L .53979 .31719 L 1 .886 0 r
F
.53789 .32232 m .53884 .31819 L .53965 .31728 L .398 0 0 r
F
.53887 .31999 m .53741 .32245 L .53804 .32187 L 1 1 0 r
F
.53789 .32232 m .53741 .32245 L .53798 .32193 L .398 0 0 r
F
.53482 .32315 m .53442 .32325 L .53503 .32254 L F
.53971 .31711 m .53781 .31345 L .54419 .30189 L 1 .528 0 r
F
.62539 .11385 m .53604 .31921 L .5365 .3194 L 1 .886 0 r
F
.54578 .29942 m .5439 .30361 L .5468 .29576 L 0 0 0 r
F
.5439 .30361 m .54492 .30031 L .5468 .29576 L F
.62539 .11385 m .5365 .3194 L .53965 .31728 L 1 .886 0 r
F
.62655 .11111 m .62536 .11386 L .62539 .11385 L F
.62538 .11385 m .61774 .1151 L .62259 .11499 L .196 .174 0 r
F
.62536 .11386 m .61774 .1151 L .62538 .11385 L F
.6254 .11385 m .62259 .11499 L .62268 .11497 L F
.6254 .11385 m .62262 .11499 L .62474 .11442 L F
.62539 .11385 m .62413 .11496 L .6254 .11386 L F
.62536 .11386 m .53604 .31921 L .62539 .11385 L 1 .886 0 r
F
.6254 .11385 m .62536 .11386 L .62538 .11385 L .196 .174 0 r
F
.62268 .11497 m .62259 .11499 L .62262 .11499 L F
.62474 .11442 m .62262 .11499 L .62413 .11496 L F
.61546 .11256 m .6107 .11093 L .61582 .1132 L .246 .178 0 r
F
.61112 .11052 m .6107 .11093 L .61546 .11256 L F
.61112 .11052 m .61171 .10827 L .61659 .11309 L 0 0 0 r
F
.61659 .11309 m .61423 .11076 L .61785 .11185 L F
.61423 .11076 m .61624 .11091 L .61785 .11185 L F
.61318 .10851 m .61582 .1132 L .61659 .11309 L .246 .178 0 r
F
.61085 .11155 m .61112 .11052 L .61659 .11309 L 0 0 0 r
F
.61318 .10851 m .61112 .11052 L .61546 .11256 L .246 .178 0 r
F
.61659 .11309 m .61582 .1132 L .61709 .11377 L F
.61774 .1151 m .60836 .12116 L .61659 .11309 L 0 0 0 r
F
.61673 .11307 m .61659 .11309 L .61669 .11299 L F
.61774 .1151 m .61659 .11309 L .61673 .11307 L F
.61782 .11271 m .61669 .11299 L .61785 .11185 L F
.6174 .11331 m .61659 .11309 L .61709 .11377 L .299 .393 0 r
F
.61782 .11268 m .61659 .11309 L .6174 .11331 L F
.61774 .1151 m .61669 .11299 L .61782 .11271 L 0 0 0 r
F
.60556 .1045 m .59974 .10784 L .6063 .111 L .251 .307 0 r
F
.61171 .10827 m .60556 .1045 L .6063 .111 L .164 .168 0 r
F
.61063 .1109 m .60556 .1045 L .61171 .10827 L 1 .752 0 r
F
.55286 .27111 m .56582 .22067 L .56323 .2325 L .967 .323 0 r
F
.60659 .1293 m .59404 .13277 L .5999 .13692 L .541 .656 0 r
F
.6061 .13056 m .59373 .13363 L .59952 .13794 L .333 .023 0 r
F
.6061 .13056 m .56323 .2325 L .59373 .13363 L F
.56588 .21714 m .5689 .1918 L .56588 .21694 L 0 0 0 r
F
.56584 .21982 m .56653 .21344 L .56588 .21714 L F
.56653 .21344 m .5689 .1918 L .56588 .21714 L F
.5508 .26205 m .5689 .1918 L .56588 .21694 L F
.56582 .22067 m .5702 .1827 L .5689 .1918 L F
.56582 .22067 m .5689 .1918 L .56584 .21982 L F
.56582 .22067 m .57182 .18697 L .5702 .1827 L F
.55911 .24182 m .56702 .20437 L .57017 .19295 L .837 .188 0 r
F
.5693 .19784 m .57017 .19295 L .57182 .18697 L F
.55911 .24182 m .57017 .19295 L .5693 .19784 L F
.60039 .12548 m .59411 .12176 L .58809 .12871 L .551 .672 0 r
F
.6 .12655 m .5938 .12267 L .58785 .12945 L .526 .643 0 r
F
.60453 .11813 m .59411 .12176 L .60039 .12548 L .46 .611 0 r
F
.60402 .11951 m .5938 .12267 L .6 .12655 L .42 .567 0 r
F
.61032 .12323 m .60402 .11951 L .6 .12655 L .407 .542 0 r
F
.60453 .11813 m .59803 .11474 L .59411 .12176 L .46 .611 0 r
F
.60402 .11951 m .59762 .11591 L .5938 .12267 L .42 .567 0 r
F
.6063 .111 m .59803 .11474 L .60453 .11813 L .375 .515 0 r
F
.6063 .111 m .59974 .10784 L .59803 .11474 L F
.60561 .1129 m .59762 .11591 L .60402 .11951 L .33 .438 0 r
F
.59803 .11474 m .58776 .11815 L .59411 .12176 L .475 .632 0 r
F
.59803 .11474 m .59146 .11146 L .58776 .11815 L F
.59974 .10784 m .59146 .11146 L .59803 .11474 L .393 .551 0 r
F
.60561 .1129 m .59916 .10953 L .59762 .11591 L .33 .438 0 r
F
.61198 .11636 m .60561 .1129 L .60402 .11951 L .315 .411 0 r
F
.60433 .10797 m .59916 .10953 L .60561 .1129 L .101 .116 0 r
F
.55911 .24182 m .57182 .18697 L .56582 .22067 L .837 .188 0 r
F
.6107 .11093 m .61045 .11103 L .61198 .11636 L .126 .136 0 r
F
.61045 .11103 m .60561 .1129 L .60738 .11386 L F
.61045 .11103 m .60738 .11386 L .61198 .11636 L F
.60681 .11244 m .60433 .10797 L .60561 .1129 L F
.6107 .11093 m .60444 .10803 L .60681 .11244 L F
.60444 .10803 m .60433 .10797 L .60681 .11244 L F
.60556 .1045 m .59922 .10112 L .59974 .10784 L .251 .307 0 r
F
.60326 .09605 m .59922 .10112 L .60556 .1045 L .25 .285 0 r
F
.60438 .10792 m .60326 .09605 L .60556 .1045 L 1 .752 0 r
F
.59411 .12176 m .58208 .12476 L .58809 .12871 L .56 .688 0 r
F
.59411 .12176 m .58776 .11815 L .58208 .12476 L F
.59762 .11591 m .58751 .11892 L .5938 .12267 L .438 .592 0 r
F
.59762 .11591 m .59113 .11246 L .58751 .11892 L F
.59974 .10784 m .59308 .10486 L .59146 .11146 L .393 .551 0 r
F
.59916 .10953 m .59113 .11246 L .59762 .11591 L .348 .472 0 r
F
.59146 .11146 m .58133 .11466 L .58776 .11815 L .489 .651 0 r
F
.59146 .11146 m .5848 .10832 L .58133 .11466 L F
.59308 .10486 m .5848 .10832 L .59146 .11146 L .408 .582 0 r
F
.59916 .10953 m .59262 .10627 L .59113 .11246 L .348 .472 0 r
F
.59922 .10112 m .59308 .10486 L .59974 .10784 L .321 .437 0 r
F
.59805 .1046 m .59262 .10627 L .59916 .10953 L .135 .134 0 r
F
.60433 .10797 m .59805 .1046 L .59916 .10953 L .101 .116 0 r
F
.59798 .11146 m .59805 .1046 L .60433 .10797 L 0 0 0 r
F
.60436 .10799 m .60444 .10803 L .6107 .11093 L F
.55286 .27111 m .55911 .24182 L .56582 .22067 L .967 .323 0 r
F
.60836 .12116 m .56258 .22869 L .61063 .1109 L 0 0 0 r
F
.61064 .1109 m .61063 .1109 L .61066 .11084 L F
.60836 .12116 m .61063 .1109 L .61064 .1109 L F
.61054 .11085 m .60436 .10799 L .61061 .11089 L F
.60436 .10799 m .60433 .10797 L .60444 .10803 L F
.60336 .11088 m .60436 .10799 L .61063 .1109 L 1 .752 0 r
F
.60436 .10799 m .60744 .10686 L .61063 .1109 L F
.606 .10866 m .60436 .10799 L .61054 .11085 L 0 0 0 r
F
.56258 .22869 m .5986 .11124 L .60436 .10799 L 1 .752 0 r
F
.60423 .10806 m .59798 .11146 L .60419 .10805 L 0 0 0 r
F
.5986 .11124 m .59798 .11146 L .60423 .10806 L F
.60436 .10799 m .60419 .10805 L .60433 .10797 L F
.606 .10866 m .60419 .10805 L .60436 .10799 L F
.5986 .11124 m .60021 .10598 L .60436 .10799 L 1 .752 0 r
F
.606 .10866 m .5986 .11124 L .60423 .10806 L 0 0 0 r
F
.60436 .10799 m .60556 .1045 L .60744 .10686 L 1 .752 0 r
F
.61063 .1109 m .61061 .11089 L .6107 .11093 L 0 0 0 r
F
.606 .10866 m .61061 .11089 L .61063 .1109 L F
.60436 .10799 m .60135 .10227 L .60438 .10792 L 1 .752 0 r
F
.60021 .10598 m .60135 .10227 L .60436 .10799 L F
.60135 .10227 m .60326 .09605 L .60438 .10792 L F
.61116 .11038 m .61066 .11084 L .61171 .10827 L 0 0 0 r
F
.61074 .1109 m .61063 .1109 L .6107 .11093 L .246 .178 0 r
F
.61112 .11052 m .61063 .1109 L .61074 .1109 L F
.60836 .12116 m .61066 .11084 L .61116 .11038 L 0 0 0 r
F
.56258 .22869 m .60336 .11088 L .61063 .1109 L 1 .752 0 r
F
.61112 .11052 m .60962 .11041 L .61063 .1109 L .246 .178 0 r
F
.61318 .10851 m .606 .10866 L .60962 .11041 L F
.61318 .10851 m .60962 .11041 L .61112 .11052 L F
.60836 .12116 m .61085 .11155 L .61659 .11309 L 0 0 0 r
F
.61782 .11268 m .61571 .11192 L .61659 .11309 L .299 .393 0 r
F
.61999 .10947 m .61318 .10851 L .61571 .11192 L F
.61999 .10947 m .61571 .11192 L .61782 .11268 L F
.62409 .11519 m .62259 .11499 L .6234 .11671 L 1 1 0 r
F
.62424 .11486 m .62259 .11499 L .62409 .11519 L F
.62824 .11602 m .62491 .1153 L .63051 .11776 L .196 .174 0 r
F
.62551 .11393 m .6252 .11464 L .62824 .11602 L F
.6252 .11464 m .62491 .1153 L .62824 .11602 L F
.63621 .10476 m .62944 .1119 L .63624 .11467 L .543 .207 0 r
F
.63289 .11329 m .62655 .11111 L .62824 .11602 L .305 .421 0 r
F
.63051 .11776 m .62491 .1153 L .62551 .12108 L .177 .212 0 r
F
.64297 .11756 m .63624 .11467 L .6335 .12443 L .443 .611 0 r
F
.63691 .12048 m .63051 .11776 L .63179 .12454 L .214 .272 0 r
F
.63383 .11607 m .63051 .11776 L .63691 .12048 L .272 .261 0 r
F
.63348 .11556 m .63194 .11518 L .63383 .11607 L F
.63194 .11518 m .63051 .11776 L .63383 .11607 L F
.64297 .11756 m .6335 .12443 L .64007 .12772 L .443 .611 0 r
F
.63691 .12048 m .63179 .12454 L .63802 .12803 L .214 .272 0 r
F
.63348 .11556 m .62957 .11991 L .63554 .12346 L .305 .421 0 r
F
.63289 .11329 m .63194 .11518 L .63348 .11556 L F
.63194 .11518 m .62957 .11991 L .63348 .11556 L F
.63251 .11416 m .63194 .11518 L .63348 .11556 L .272 .261 0 r
F
.63289 .11329 m .63067 .11459 L .63194 .11518 L .305 .421 0 r
F
.63067 .11459 m .62824 .11602 L .63194 .11518 L F
.62655 .11111 m .62539 .11385 L .62824 .11602 L 1 .886 0 r
F
.63251 .11416 m .6254 .11385 L .63051 .11776 L .272 .261 0 r
F
.63194 .11518 m .62824 .11602 L .63091 .11723 L .305 .421 0 r
F
.63091 .11723 m .62824 .11602 L .62957 .11991 L F
.62824 .11602 m .53965 .31728 L .62957 .11991 L 1 .886 0 r
F
.6254 .11385 m .62491 .1153 L .62551 .11393 L .196 .174 0 r
F
.62491 .1153 m .62488 .11533 L .6249 .11532 L .543 .207 0 r
F
.62539 .11385 m .53965 .31728 L .62824 .11602 L 1 .886 0 r
F
.6254 .11385 m .62539 .11385 L .6254 .11386 L .196 .174 0 r
F
.53979 .31719 m .53971 .31711 L .53989 .31685 L 1 .319 0 r
F
.53979 .31719 m .53989 .31685 L .54 .3166 L 0 0 0 r
F
.53983 .31711 m .53979 .31719 L .54 .3166 L F
.53965 .31728 m .53979 .31719 L .62957 .11991 L 1 .886 0 r
F
.53804 .32187 m .53965 .31728 L .5397 .318 L .398 0 0 r
F
.53965 .31728 m .53971 .31725 L .5397 .318 L F
.53971 .31765 m .53971 .31711 L .53979 .31719 L F
.53971 .31765 m .53979 .31719 L .54207 .31949 L F
.53789 .32232 m .53804 .32187 L .53965 .32113 L F
.53887 .31999 m .53804 .32187 L .53965 .32113 L 1 1 0 r
F
.53068 .33875 m .53067 .33878 L .53072 .3388 L .224 .252 0 r
F
.53072 .3388 m .53067 .33882 L .53068 .33881 L 0 0 0 r
F
.53072 .3388 m .53067 .33878 L .53067 .33882 L .183 .222 0 r
F
.53068 .33875 m .53053 .33909 L .53072 .3388 L 1 1 0 r
F
.53159 .33733 m .53068 .33875 L .53072 .3388 L .224 .252 0 r
F
.53222 .33831 m .53072 .3388 L .53318 .33977 L F
.53159 .33733 m .53072 .3388 L .53222 .33831 L F
.53318 .33977 m .53072 .3388 L .53126 .34103 L .183 .222 0 r
F
.53072 .3388 m .53067 .33882 L .53126 .34103 L F
.54098 .32213 m .54047 .32232 L .54069 .32264 L .016 .111 0 r
F
.52889 .33974 m .52879 .33975 L .52879 .33974 L .16 0 0 r
F
.52889 .33974 m .5288 .33969 L .52879 .33975 L .223 .274 0 r
F
.55206 .27574 m .55286 .27111 L .55447 .26629 L 1 .483 0 r
F
.55206 .27574 m .55447 .26629 L .55836 .25466 L F
.61728 .12525 m .60659 .1293 L .61271 .13322 L .432 .572 0 r
F
.61652 .12709 m .6061 .13056 L .61211 .1347 L .191 0 0 r
F
.61652 .12709 m .55206 .27574 L .6061 .13056 L F
.55206 .27574 m .55447 .26629 L .6061 .13056 L F
.55447 .26629 m .56323 .2325 L .6061 .13056 L 1 .648 0 r
F
.55385 .26812 m .56323 .2325 L .55447 .26629 L .967 .323 0 r
F
.55286 .27111 m .56323 .2325 L .55385 .26812 L F
.5689 .1918 m .56772 .18416 L .57125 .17029 L .461 .044 0 r
F
.5689 .1918 m .5702 .1827 L .56772 .18416 L .114 0 0 r
F
.56122 .20978 m .56725 .17407 L .56768 .18316 L .893 .187 0 r
F
.56756 .1848 m .56768 .18316 L .56772 .18416 L F
.56122 .20978 m .56768 .18316 L .56756 .1848 L F
.5702 .1827 m .57072 .16128 L .56679 .16399 L .18 .02 0 r
F
.5702 .1827 m .56679 .16399 L .56601 .17044 L F
.56559 .18393 m .56841 .16365 L .56725 .17407 L .893 .187 0 r
F
.56573 .18089 m .56841 .16365 L .56559 .18393 L F
.56207 .20433 m .56592 .17675 L .56845 .16329 L F
.56122 .20978 m .56242 .20132 L .56207 .20433 L F
.56242 .20132 m .56592 .17675 L .56207 .20433 L F
.56841 .16365 m .56855 .16278 L .56725 .17407 L F
.56122 .20978 m .56845 .16329 L .56841 .16365 L F
.5687 .1609 m .56752 .15738 L .56716 .16061 L .257 .049 0 r
F
.56885 .159 m .56752 .15738 L .5687 .1609 L F
.56849 .16269 m .56716 .16061 L .56682 .16374 L F
.57072 .16128 m .56716 .16061 L .56849 .16269 L F
.57072 .16128 m .56682 .16374 L .56686 .16395 L F
.5702 .1827 m .56725 .17407 L .56772 .18416 L .18 .02 0 r
F
.57072 .16128 m .5687 .14681 L .56752 .15738 L .257 .049 0 r
F
.56686 .16395 m .56682 .16374 L .56679 .16399 L F
.56601 .17044 m .56679 .16399 L .56438 .16565 L .18 .02 0 r
F
.56412 .18629 m .56437 .1764 L .56437 .17643 L .774 .152 0 r
F
.56601 .17044 m .56438 .16565 L .56412 .18629 L .18 .02 0 r
F
.56716 .16061 m .56536 .15778 L .56679 .16399 L .257 .049 0 r
F
.56293 .15301 m .56125 .15203 L .56018 .13299 L .601 .055 0 r
F
.56439 .15357 m .56229 .15101 L .56347 .15441 L .257 .049 0 r
F
.56439 .15539 m .56347 .15441 L .56439 .15706 L F
.56439 .15357 m .56347 .15441 L .56439 .15539 L F
.56125 .15203 m .56041 .15154 L .56041 .15112 L .601 .055 0 r
F
.56125 .15203 m .56041 .15112 L .56018 .13299 L F
.56439 .15357 m .56439 .15706 L .56679 .16399 L .257 .049 0 r
F
.56679 .16399 m .56439 .15706 L .56438 .16565 L F
.56439 .15706 m .56347 .15441 L .56438 .16565 L F
.56293 .15301 m .56265 .15353 L .56125 .15203 L .601 .055 0 r
F
.56347 .15441 m .56229 .15101 L .56265 .15353 L .257 .049 0 r
F
.56347 .15441 m .56265 .15353 L .56438 .16565 L F
.56438 .16565 m .56265 .15353 L .55384 .15784 L .453 .106 0 r
F
.56125 .15203 m .56114 .15284 L .56041 .15154 L .601 .055 0 r
F
.56114 .15284 m .56042 .15252 L .56041 .15154 L F
.56265 .15353 m .56042 .15252 L .55384 .15784 L .453 .106 0 r
F
.56265 .15353 m .56049 .15756 L .56125 .15203 L .601 .055 0 r
F
.56265 .15353 m .56229 .15101 L .56042 .15252 L .453 .106 0 r
F
.56114 .15284 m .56049 .15756 L .56042 .15252 L .601 .055 0 r
F
.56592 .17675 m .56265 .15353 L .56855 .16278 L .151 .015 0 r
F
.56641 .18466 m .56874 .15657 L .56779 .15584 L 0 0 0 r
F
.56752 .15738 m .56862 .14627 L .56229 .15101 L .257 .049 0 r
F
.5687 .14681 m .56862 .14627 L .56752 .15738 L F
.56752 .15738 m .56439 .15357 L .56536 .15778 L F
.56752 .15738 m .56536 .15778 L .56716 .16061 L F
.56629 .16849 m .56779 .15584 L .56619 .15463 L 0 0 0 r
F
.56641 .18466 m .56779 .15584 L .56629 .16849 L F
.56632 .17219 m .56629 .16849 L .56597 .17548 L F
.56629 .16849 m .56619 .15463 L .56592 .17675 L F
.56592 .17675 m .56049 .15756 L .56265 .15353 L .151 .015 0 r
F
.56592 .17675 m .56619 .15463 L .56049 .15756 L F
.55975 .209 m .56634 .16896 L .56705 .1653 L .752 .168 0 r
F
.56674 .16827 m .56705 .1653 L .56874 .15657 L F
.55975 .209 m .56705 .1653 L .56674 .16827 L F
.56641 .18466 m .56632 .17219 L .56592 .17675 L 0 0 0 r
F
.56632 .17219 m .56597 .17548 L .56592 .17675 L F
.56122 .20978 m .56573 .18089 L .56559 .18393 L .893 .187 0 r
F
.56841 .16365 m .56845 .16329 L .56855 .16278 L F
.57072 .16128 m .56885 .159 L .5687 .1609 L .257 .049 0 r
F
.57244 .14425 m .56983 .14111 L .56997 .14556 L .083 .032 0 r
F
.57381 .16162 m .57244 .14425 L .56862 .14627 L 0 0 0 r
F
.57142 .16136 m .56862 .14627 L .57072 .16128 L F
.57381 .16162 m .57185 .15581 L .57142 .16136 L F
.57185 .15581 m .56862 .14627 L .57142 .16136 L F
.57182 .18697 m .57381 .16162 L .57072 .16128 L F
.57369 .16229 m .57244 .14425 L .57381 .16162 L F
.5722 .17069 m .57238 .15143 L .57369 .16229 L F
.57238 .15143 m .57244 .14425 L .57369 .16229 L F
.5722 .17069 m .57294 .14728 L .57265 .14548 L F
.5724 .14862 m .57265 .14548 L .57244 .14425 L F
.5722 .17069 m .57265 .14548 L .5724 .14862 L F
.57294 .14728 m .57221 .14343 L .57244 .14425 L F
.56997 .14556 m .56926 .14042 L .56876 .1462 L .083 .032 0 r
F
.56876 .1462 m .56495 .13524 L .56862 .14627 L F
.56926 .14042 m .56495 .13524 L .56876 .1462 L F
.56862 .14627 m .56495 .13524 L .56428 .13576 L .329 .076 0 r
F
.56862 .14627 m .56428 .13576 L .56434 .14357 L F
.56862 .14627 m .56434 .14357 L .5644 .14943 L F
.56434 .14357 m .56428 .13576 L .5588 .14006 L F
.56434 .14357 m .5588 .14006 L .5644 .14943 L F
.56874 .15657 m .56654 .1493 L .56619 .15463 L 0 0 0 r
F
.56654 .1493 m .56368 .1399 L .56608 .15399 L F
.56654 .1493 m .56608 .15399 L .56619 .15463 L F
.56874 .15657 m .56717 .13865 L .56368 .1399 L F
.56848 .15792 m .56717 .13865 L .56874 .15657 L F
.56634 .16896 m .56695 .14667 L .56848 .15792 L F
.56695 .14667 m .56717 .13865 L .56848 .15792 L F
.56634 .16896 m .56742 .14281 L .56732 .14119 L F
.56701 .14441 m .56732 .14119 L .56717 .13865 L F
.56634 .16896 m .56732 .14119 L .56701 .14441 L F
.56903 .13201 m .56032 .12665 L .56495 .13524 L .207 .07 0 r
F
.57599 .12091 m .56322 .12285 L .56892 .12694 L .643 .757 0 r
F
.58208 .12476 m .57599 .12091 L .56892 .12694 L .637 .744 0 r
F
.57584 .12143 m .56313 .1232 L .56881 .12737 L .633 .744 0 r
F
.57599 .12091 m .56984 .11717 L .56322 .12285 L .643 .757 0 r
F
.57584 .12143 m .56972 .1176 L .56313 .1232 L .633 .744 0 r
F
.56903 .13201 m .5644 .12286 L .56032 .12665 L .207 .07 0 r
F
.56495 .13524 m .55446 .1314 L .5588 .14006 L .389 .256 0 r
F
.56495 .13524 m .56032 .12665 L .55446 .1314 L F
.56717 .13865 m .55964 .12937 L .56368 .1399 L .078 .034 0 r
F
.56717 .13865 m .56343 .1266 L .55964 .12937 L F
.56742 .14281 m .56555 .1352 L .56717 .13865 L 0 0 0 r
F
.56555 .1352 m .56343 .1266 L .56659 .13677 L F
.56555 .1352 m .56659 .13677 L .56717 .13865 L F
.5644 .14943 m .5588 .14006 L .56229 .15101 L .329 .076 0 r
F
.55833 .14615 m .55545 .14261 L .55899 .14959 L .523 .265 0 r
F
.55899 .14959 m .55086 .14609 L .55967 .15313 L F
.55941 .15181 m .55778 .14328 L .55899 .14959 L .706 .112 0 r
F
.55881 .14873 m .55778 .14328 L .55941 .15181 L F
.55778 .14328 m .55761 .1424 L .55899 .14959 L F
.56049 .15756 m .55739 .14126 L .55778 .14328 L F
.55739 .14126 m .55736 .1411 L .55778 .14328 L F
.56229 .15101 m .5588 .14006 L .55737 .14115 L .523 .265 0 r
F
.56229 .15101 m .55737 .14115 L .55833 .14615 L F
.56049 .15756 m .55785 .14377 L .55736 .1411 L .706 .112 0 r
F
.55692 .13881 m .55446 .1314 L .55033 .13442 L .578 .409 0 r
F
.5588 .14006 m .55613 .13472 L .55692 .13881 L F
.55613 .13472 m .55446 .1314 L .55692 .13881 L F
.5588 .14006 m .55033 .13442 L .55287 .13843 L F
.5588 .14006 m .55287 .13843 L .55317 .13892 L F
.5588 .14006 m .54742 .13776 L .55737 .14115 L F
.55785 .14377 m .54938 .13842 L .55737 .14115 L .519 .3 0 r
F
.56368 .1399 m .55616 .13502 L .55785 .14377 L .329 .096 0 r
F
.55616 .13502 m .55395 .13358 L .55785 .14377 L F
.56049 .15756 m .55881 .14873 L .55941 .15181 L .706 .112 0 r
F
.56368 .1399 m .55964 .12937 L .55395 .13358 L .329 .096 0 r
F
.56229 .15101 m .55833 .14615 L .55899 .14959 L .523 .265 0 r
F
.56042 .15252 m .56026 .1521 L .56042 .15241 L .706 .112 0 r
F
.56042 .15252 m .55899 .14959 L .55967 .15313 L .523 .265 0 r
F
.56049 .15756 m .55899 .14959 L .56042 .15252 L .706 .112 0 r
F
.56229 .15101 m .55899 .14959 L .56042 .15252 L .523 .265 0 r
F
.56619 .15463 m .55785 .14377 L .56049 .15756 L .245 .049 0 r
F
.56619 .15463 m .56368 .1399 L .55785 .14377 L F
.5622 .1604 m .56287 .13378 L .56339 .13192 L .938 .187 0 r
F
.56742 .14281 m .56487 .12672 L .56422 .12667 L 0 0 0 r
F
.56518 .13373 m .56422 .12667 L .56343 .1266 L F
.56742 .14281 m .56422 .12667 L .56518 .13373 L F
.56434 .13336 m .56339 .13192 L .56487 .12672 L .938 .187 0 r
F
.5622 .1604 m .56339 .13192 L .56434 .13336 L F
.5508 .26205 m .55914 .22406 L .56122 .20978 L 0 0 0 r
F
.56013 .21726 m .56592 .17675 L .56122 .20978 L F
.55914 .22406 m .56077 .21268 L .56013 .21726 L F
.56077 .21268 m .56592 .17675 L .56013 .21726 L F
.55077 .25134 m .55975 .209 L .56288 .19756 L .882 .195 0 r
F
.55914 .22406 m .56641 .18466 L .56592 .17675 L 0 0 0 r
F
.56214 .20288 m .56288 .19756 L .56641 .18466 L .882 .195 0 r
F
.55077 .25134 m .56288 .19756 L .56214 .20288 L F
.55975 .209 m .56874 .15657 L .56641 .18466 L .752 .168 0 r
F
.56835 .1613 m .56851 .13815 L .56943 .13528 L .952 .195 0 r
F
.57232 .14402 m .56903 .13201 L .57221 .14343 L 0 0 0 r
F
.57136 .14109 m .56903 .13201 L .57232 .14402 L F
.57294 .14728 m .57057 .13173 L .57001 .13183 L F
.57061 .13678 m .57001 .13183 L .56953 .13192 L F
.57294 .14728 m .57136 .14109 L .57232 .14402 L F
.57294 .14728 m .57001 .13183 L .57061 .13678 L F
.57294 .14728 m .56953 .13192 L .56961 .13427 L F
.57014 .13742 m .56943 .13528 L .57057 .13173 L .952 .195 0 r
F
.56983 .14111 m .56926 .14042 L .56997 .14556 L .083 .032 0 r
F
.56835 .1613 m .56943 .13528 L .57014 .13742 L .952 .195 0 r
F
.56961 .13427 m .56953 .13192 L .56903 .13201 L 0 0 0 r
F
.55287 .13843 m .55033 .13442 L .54703 .13683 L .578 .409 0 r
F
.55317 .13892 m .54703 .13683 L .54742 .13776 L F
.55287 .13843 m .54703 .13683 L .55317 .13892 L F
.55785 .14377 m .54867 .13965 L .54938 .13842 L .519 .3 0 r
F
.54867 .13965 m .54661 .13873 L .54742 .13776 L F
.54742 .13776 m .54661 .13873 L .54117 .12873 L .682 .053 0 r
F
.54123 .12882 m .54115 .12867 L .54116 .1287 L 0 0 0 r
F
.54128 .12889 m .54115 .12867 L .54123 .12882 L F
.54501 .13645 m .54093 .12865 L .54106 .12853 L .738 .594 0 r
F
.54418 .13526 m .54181 .12966 L .53637 .12415 L 0 .021 0 r
F
.527 .12766 m .5269 .12758 L .52729 .12801 L .143 .08 0 r
F
.52721 .12794 m .5269 .12758 L .52719 .12792 L F
.51754 .12831 m .51422 .12372 L .50427 .12614 L .846 .936 0 r
F
.52719 .12792 m .5139 .12644 L .51713 .13147 L .847 .903 0 r
F
.52719 .12792 m .5232 .12317 L .5139 .12644 L F
.52724 .12795 m .52318 .12328 L .52713 .128 L .8 .872 0 r
F
.53637 .12415 m .52335 .12329 L .52742 .12788 L F
.53637 .12415 m .52724 .12795 L .52729 .12801 L F
.52724 .12795 m .52713 .128 L .52729 .12801 L F
.527 .12767 m .52381 .1239 L .527 .12766 L .143 .08 0 r
F
.52742 .12788 m .52331 .12329 L .52724 .12795 L .8 .872 0 r
F
.52335 .12329 m .52331 .12329 L .52742 .12788 L F
.53449 .13448 m .52392 .124 L .527 .12767 L .143 .08 0 r
F
.52392 .124 m .52381 .1239 L .527 .12767 L F
.52354 .12077 m .51088 .11919 L .51422 .12372 L .814 .92 0 r
F
.52354 .12077 m .51942 .11647 L .51088 .11919 L F
.5233 .12323 m .52039 .11993 L .5232 .12317 L .248 .206 0 r
F
.51422 .12372 m .51088 .11919 L .50175 .12144 L .845 .941 0 r
F
.5232 .12317 m .51063 .1215 L .5139 .12644 L .845 .911 0 r
F
.5232 .12317 m .51915 .1185 L .51063 .1215 L F
.5233 .12323 m .51914 .11859 L .52318 .12328 L .47 0 0 r
F
.52998 .12038 m .51927 .1186 L .5233 .12323 L F
.51995 .11866 m .51927 .1186 L .52998 .12038 L F
.52051 .12002 m .51915 .1185 L .52039 .11993 L .248 .206 0 r
F
.51927 .1186 m .51915 .1185 L .51921 .11857 L F
.51927 .1186 m .51921 .11857 L .52051 .12002 L F
.53167 .11965 m .51995 .11866 L .52998 .12038 L .47 0 0 r
F
.53167 .11965 m .5263 .12109 L .51979 .11878 L F
.53637 .12415 m .53167 .11965 L .5233 .12323 L .8 .872 0 r
F
.52392 .124 m .5232 .12317 L .5238 .12389 L .143 .08 0 r
F
.53449 .13448 m .52331 .12329 L .52392 .124 L F
.52331 .12329 m .5232 .12317 L .52392 .124 L F
.53637 .12415 m .5233 .12323 L .52335 .12329 L .8 .872 0 r
F
.53449 .13448 m .53042 .12719 L .5233 .12323 L .143 .08 0 r
F
.52331 .12329 m .5233 .12323 L .5232 .12317 L F
.52335 .12329 m .5233 .12323 L .52331 .12326 L .8 .872 0 r
F
.52335 .12329 m .52327 .12324 L .52331 .12329 L F
.53449 .13448 m .5233 .12323 L .52331 .12329 L .143 .08 0 r
F
.52331 .12326 m .5233 .12323 L .52327 .12324 L .8 .872 0 r
F
.52331 .12329 m .52327 .12324 L .52318 .12328 L F
.5233 .12323 m .52039 .11993 L .5233 .12323 L .248 .206 0 r
F
.53042 .12719 m .5204 .11994 L .5233 .12323 L F
.5204 .11994 m .52039 .11993 L .5233 .12323 L F
.53042 .12719 m .5263 .12109 L .51927 .1186 L F
.53167 .11965 m .51962 .11877 L .51927 .1186 L .47 0 0 r
F
.51927 .1186 m .52608 .12077 L .51915 .1185 L .248 .206 0 r
F
.5263 .12109 m .52608 .12077 L .51927 .1186 L F
.51979 .11878 m .52602 .12117 L .51962 .11877 L .47 0 0 r
F
.5263 .12109 m .52602 .12117 L .51979 .11878 L F
.51927 .1186 m .51962 .11877 L .51914 .11859 L F
.51927 .1186 m .51914 .11859 L .5233 .12323 L F
.52077 .12021 m .51927 .1186 L .52051 .12002 L .248 .206 0 r
F
.53042 .12719 m .51983 .11903 L .52077 .12021 L F
.51983 .11903 m .51927 .1186 L .52077 .12021 L F
.51088 .11919 m .50751 .11473 L .49921 .11679 L .843 .947 0 r
F
.51942 .11647 m .50751 .11473 L .51088 .11919 L .814 .926 0 r
F
.51915 .1185 m .50732 .11666 L .51063 .1215 L .359 0 0 r
F
.52608 .12077 m .52514 .12059 L .51907 .11851 L .837 .806 0 r
F
.51962 .11877 m .51952 .11866 L .51914 .11859 L .319 .347 0 r
F
.51952 .11866 m .51906 .11851 L .51914 .11859 L F
.52514 .12059 m .51906 .11851 L .51907 .11851 L .837 .806 0 r
F
.52608 .12077 m .51907 .11851 L .51925 .11854 L F
.52521 .12087 m .51665 .11505 L .51962 .11877 L .319 .347 0 r
F
.52212 .11089 m .51092 .10946 L .51103 .10958 L .799 .901 0 r
F
.52181 .11103 m .51103 .10958 L .51526 .11224 L .798 .899 0 r
F
.52693 .11516 m .52212 .11089 L .52181 .11103 L .8 .893 0 r
F
.52692 .11526 m .52211 .11097 L .52181 .11103 L .578 .74 0 r
F
.52625 .11509 m .52181 .11103 L .51526 .11224 L F
.52693 .11516 m .52181 .11103 L .52625 .11509 L .8 .893 0 r
F
.52692 .11526 m .52181 .11103 L .52625 .11509 L .578 .74 0 r
F
.52625 .11509 m .52181 .11103 L .51506 .11394 L .8 .893 0 r
F
.52181 .11103 m .51103 .10958 L .51506 .11394 L .799 .901 0 r
F
.52212 .11089 m .51103 .10958 L .52181 .11103 L F
.52211 .11097 m .51091 .10951 L .51103 .10958 L .798 .899 0 r
F
.52211 .11097 m .51103 .10958 L .52181 .11103 L F
.5212 .11517 m .511 .11305 L .51505 .114 L .828 .83 0 r
F
.52156 .11498 m .5186 .11463 L .5212 .11517 L .831 .839 0 r
F
.5171 .11431 m .511 .11305 L .5212 .11517 L .828 .83 0 r
F
.5171 .11431 m .51068 .11298 L .511 .11305 L F
.51925 .11854 m .51907 .11851 L .51915 .1185 L .837 .806 0 r
F
.51952 .11866 m .51951 .11866 L .51906 .11851 L .319 .347 0 r
F
.51915 .1185 m .51906 .11851 L .51898 .11848 L .359 0 0 r
F
.51951 .11866 m .51505 .114 L .51906 .11851 L .319 .347 0 r
F
.5139 .12644 m .51063 .1215 L .50152 .12419 L .891 .94 0 r
F
.51063 .1215 m .49904 .11909 L .50152 .12419 L .887 .947 0 r
F
.51063 .1215 m .50732 .11666 L .49904 .11909 L F
.51094 .12146 m .50731 .11671 L .51062 .12157 L .841 .916 0 r
F
.51914 .11859 m .50743 .11673 L .51094 .12146 L F
.50743 .11673 m .50731 .11671 L .51094 .12146 L F
.51898 .11848 m .5189 .11848 L .50732 .11666 L .359 0 0 r
F
.51914 .11859 m .51906 .11851 L .50731 .11671 L .841 .916 0 r
F
.50743 .11673 m .50739 .11668 L .50731 .11671 L F
.51906 .11851 m .50739 .11668 L .50743 .11673 L F
.51089 .11722 m .50739 .11668 L .50732 .11666 L .359 0 0 r
F
.5189 .11848 m .50739 .11668 L .51089 .11722 L F
.50739 .11668 m .50619 .11506 L .50739 .11668 L .438 .522 0 r
F
.50751 .11473 m .50411 .11033 L .49665 .1122 L .842 .952 0 r
F
.51505 .114 m .50405 .11196 L .50736 .11663 L 0 .126 0 r
F
.50627 .11509 m .5062 .11506 L .50739 .11668 L .438 .522 0 r
F
.5062 .11506 m .50619 .11506 L .50739 .11668 L F
.51505 .114 m .50736 .11663 L .50739 .11668 L 0 .126 0 r
F
.50739 .11668 m .50619 .11506 L .50732 .11666 L .438 .522 0 r
F
.50736 .11663 m .50728 .11666 L .50739 .11668 L 0 .126 0 r
F
.51829 .11433 m .51056 .11281 L .51158 .11314 L .831 .839 0 r
F
.51068 .11298 m .51056 .11281 L .50405 .11196 L .438 .522 0 r
F
.50435 .11201 m .51068 .11298 L .50426 .11199 L 0 .126 0 r
F
.51505 .114 m .51068 .11298 L .50435 .11201 L F
.50405 .11196 m .51056 .11281 L .50397 .11191 L .438 .522 0 r
F
.51505 .114 m .50426 .11199 L .50405 .11196 L 0 .126 0 r
F
.5189 .11848 m .5145 .11863 L .50739 .11668 L .359 0 0 r
F
.51906 .11851 m .51505 .114 L .50739 .11668 L .841 .916 0 r
F
.5145 .11863 m .51068 .11298 L .50405 .11196 L .438 .522 0 r
F
.51665 .11505 m .51505 .114 L .51962 .11877 L .319 .347 0 r
F
.52608 .12077 m .52181 .11529 L .52138 .11542 L .837 .806 0 r
F
.52608 .12077 m .52138 .11542 L .52415 .11923 L F
.52514 .12059 m .5212 .11517 L .51505 .114 L .319 .347 0 r
F
.52181 .11529 m .5212 .11517 L .51989 .11584 L .837 .806 0 r
F
.52608 .12077 m .51989 .11584 L .52514 .12059 L F
.52602 .12117 m .52153 .11523 L .5212 .11517 L .319 .347 0 r
F
.52602 .12117 m .5212 .11517 L .52514 .12059 L F
.52415 .11923 m .52138 .11542 L .51989 .11584 L .837 .806 0 r
F
.51831 .11435 m .51158 .11314 L .51989 .11584 L .831 .839 0 r
F
.51829 .11433 m .51158 .11314 L .51831 .11435 L F
.51068 .11298 m .51055 .11295 L .51029 .11291 L 0 .126 0 r
F
.51068 .11298 m .51029 .11291 L .50426 .11199 L F
.50405 .11196 m .50426 .11199 L .50396 .11194 L F
.50627 .11509 m .504 .11195 L .50619 .11506 L .438 .522 0 r
F
.504 .11195 m .50397 .11191 L .504 .11195 L F
.504 .11195 m .504 .11195 L .50619 .11506 L F
.5145 .11863 m .50405 .11196 L .50627 .11509 L F
.50405 .11196 m .50397 .11191 L .50627 .11509 L F
.5145 .11863 m .50627 .11509 L .50739 .11668 L F
.49921 .11678 m .49665 .11219 L .48884 .11369 L .872 .976 0 r
F
.49921 .11679 m .49665 .1122 L .48884 .11369 L .871 .975 0 r
F
.50732 .11666 m .49653 .11408 L .49904 .11909 L .882 .953 0 r
F
.50732 .11666 m .50397 .11191 L .49653 .11408 L F
.50736 .11663 m .50396 .11194 L .50728 .11666 L 0 .126 0 r
F
.50405 .11196 m .50396 .11194 L .50736 .11663 L F
.50739 .11668 m .50728 .11666 L .50731 .11671 L F
.51906 .11851 m .5145 .11863 L .51898 .11848 L .359 0 0 r
F
.52153 .11523 m .5171 .11431 L .5212 .11517 L .828 .83 0 r
F
.52156 .11498 m .51829 .11433 L .5186 .11463 L .831 .839 0 r
F
.5212 .11517 m .5186 .11463 L .51989 .11584 L F
.52444 .12014 m .51665 .11505 L .52521 .12087 L .319 .347 0 r
F
.51989 .11584 m .51179 .11321 L .5145 .11863 L .831 .839 0 r
F
.51179 .11321 m .51056 .11281 L .51068 .11298 L F
.51179 .11321 m .51068 .11298 L .5145 .11863 L F
.52153 .11523 m .51055 .11295 L .51068 .11298 L .828 .83 0 r
F
.52153 .11523 m .51068 .11298 L .5171 .11431 L F
.52181 .11529 m .52156 .11498 L .5212 .11517 L .837 .806 0 r
F
.52318 .12328 m .51914 .11859 L .51062 .12157 L .843 .908 0 r
F
.52514 .12059 m .5145 .11863 L .51906 .11851 L .837 .806 0 r
F
.52514 .12059 m .51989 .11584 L .5145 .11863 L F
.5256 .12101 m .52444 .12014 L .52521 .12087 L .319 .347 0 r
F
.52602 .12117 m .52514 .12059 L .5256 .12101 L F
.52514 .12059 m .52444 .12014 L .5256 .12101 L F
.527 .12767 m .527 .12766 L .52729 .12801 L .143 .08 0 r
F
.52381 .1239 m .5238 .12389 L .527 .12766 L F
.52699 .12766 m .5238 .12389 L .5269 .12758 L F
.52331 .12329 m .52318 .12328 L .52724 .12795 L .8 .872 0 r
F
.53449 .13448 m .527 .12767 L .52729 .12801 L .143 .08 0 r
F
.53668 .12446 m .53167 .11965 L .53637 .12415 L .002 .063 0 r
F
.54117 .12873 m .54115 .12867 L .54106 .12853 L 0 0 0 r
F
.54187 .12966 m .54168 .12978 L .54106 .12853 L .738 .594 0 r
F
.54444 .13564 m .54183 .12968 L .54181 .12966 L 0 .021 0 r
F
.54444 .13564 m .54181 .12966 L .54418 .13526 L F
.54703 .13683 m .54501 .13645 L .54377 .13397 L .738 .594 0 r
F
.54501 .13645 m .54183 .12968 L .54444 .13564 L 0 .021 0 r
F
.54703 .13683 m .54439 .13217 L .54014 .13079 L .738 .594 0 r
F
.54439 .13217 m .54267 .12914 L .54183 .12968 L F
.54126 .12834 m .53828 .12311 L .53729 .12292 L .751 .668 0 r
F
.53879 .12552 m .53729 .12292 L .53641 .12241 L .002 .063 0 r
F
.53944 .12638 m .53729 .12292 L .53879 .12552 L F
.54007 .12792 m .53641 .12241 L .53208 .11989 L F
.54077 .12862 m .53926 .12647 L .54007 .12792 L F
.53926 .12647 m .53641 .12241 L .54007 .12792 L F
.54126 .12834 m .53729 .12292 L .54035 .12783 L .751 .668 0 r
F
.54096 .12881 m .53641 .12241 L .54077 .12862 L .002 .063 0 r
F
.53697 .12237 m .53298 .11664 L .53012 .11835 L .758 .726 0 r
F
.54134 .12918 m .53259 .12056 L .53668 .12446 L .002 .063 0 r
F
.54072 .12859 m .53259 .12056 L .54134 .12918 L F
.53581 .12384 m .5263 .12109 L .53042 .12719 L .758 .726 0 r
F
.54099 .12885 m .53259 .12056 L .54101 .12887 L .002 .063 0 r
F
.53944 .12638 m .53641 .12241 L .54096 .12881 L F
.54083 .12871 m .54036 .12824 L .54183 .12968 L F
.54036 .12824 m .53259 .12056 L .54099 .12885 L F
.54036 .12824 m .54099 .12885 L .54183 .12968 L F
.53259 .12056 m .53167 .11965 L .53668 .12446 L F
.53241 .12033 m .53208 .11989 L .53182 .11974 L F
.54099 .12885 m .54101 .12887 L .54181 .12966 L F
.54267 .12914 m .54035 .12783 L .541 .12887 L .751 .668 0 r
F
.54099 .12885 m .53208 .11989 L .53241 .12033 L .002 .063 0 r
F
.541 .12887 m .53803 .1284 L .54144 .12955 L .751 .668 0 r
F
.541 .12887 m .54144 .12955 L .54183 .12968 L F
.541 .12887 m .53182 .11974 L .53207 .12005 L .002 .063 0 r
F
.54243 .13029 m .541 .12887 L .54183 .12968 L F
.541 .12887 m .54083 .12871 L .54183 .12968 L F
.54243 .13029 m .54098 .12885 L .541 .12887 L F
.54098 .12885 m .53182 .11974 L .541 .12887 L F
.54178 .12963 m .54099 .12885 L .54181 .12966 L F
.54181 .12966 m .54072 .12859 L .54134 .12918 L F
.54183 .12968 m .54178 .12963 L .54181 .12966 L F
.54152 .12896 m .541 .12887 L .54183 .12968 L .751 .668 0 r
F
.54243 .13029 m .54096 .12881 L .54099 .12885 L .002 .063 0 r
F
.54096 .12881 m .53208 .11989 L .54099 .12885 L F
.53207 .12005 m .53182 .11974 L .53167 .11965 L F
.53727 .12291 m .52671 .12099 L .53167 .11965 L .748 .703 0 r
F
.53168 .12199 m .5263 .12109 L .52671 .12099 L F
.53729 .12292 m .53435 .12243 L .53581 .12384 L .758 .726 0 r
F
.53435 .12243 m .5263 .12109 L .53581 .12384 L F
.54035 .12783 m .53729 .12292 L .53461 .12459 L .751 .668 0 r
F
.54267 .12914 m .54152 .12896 L .54183 .12968 L F
.54243 .13029 m .53782 .12323 L .53729 .12292 L .002 .063 0 r
F
.54243 .13029 m .53729 .12292 L .53944 .12638 L F
.53782 .12323 m .52671 .12099 L .53729 .12292 L .748 .703 0 r
F
.53435 .12243 m .52608 .12077 L .5263 .12109 L .758 .726 0 r
F
.53729 .12292 m .53425 .12234 L .53435 .12243 L F
.53691 .12285 m .52671 .12099 L .53727 .12291 L .748 .703 0 r
F
.53425 .12234 m .52608 .12077 L .53435 .12243 L .758 .726 0 r
F
.53729 .12292 m .53691 .12285 L .53727 .12291 L .748 .703 0 r
F
.5338 .1219 m .53012 .11835 L .52608 .12077 L .758 .726 0 r
F
.53697 .12237 m .53012 .11835 L .5338 .1219 L F
.54035 .12783 m .53932 .12725 L .541 .12887 L .751 .668 0 r
F
.53932 .12725 m .53461 .12459 L .541 .12887 L F
.54243 .13029 m .53944 .12638 L .54096 .12881 L .002 .063 0 r
F
.541 .12887 m .53461 .12459 L .53803 .1284 L .751 .668 0 r
F
.53795 .12251 m .53531 .11939 L .53697 .12237 L .758 .726 0 r
F
.53531 .11939 m .53298 .11664 L .53697 .12237 L F
.53782 .12323 m .52602 .12117 L .5263 .12109 L .748 .703 0 r
F
.53782 .12323 m .5263 .12109 L .53168 .12199 L F
.53795 .12251 m .53697 .12237 L .53729 .12292 L .758 .726 0 r
F
.53697 .12237 m .52608 .12077 L .53729 .12292 L F
.53828 .12311 m .53795 .12251 L .53729 .12292 L .751 .668 0 r
F
.54439 .13217 m .54183 .12968 L .54162 .12983 L .738 .594 0 r
F
.54293 .1317 m .54162 .12983 L .54014 .13079 L F
.54439 .13217 m .54162 .12983 L .54293 .1317 L F
.54501 .13645 m .54014 .13079 L .53449 .13448 L F
.54703 .13683 m .54014 .13079 L .54501 .13645 L F
.54267 .12914 m .54003 .12543 L .54126 .12834 L .751 .668 0 r
F
.54003 .12543 m .53795 .12251 L .54126 .12834 L F
.53803 .1284 m .53461 .12459 L .53042 .12719 L F
.54183 .12968 m .53803 .1284 L .54014 .13079 L F
.54501 .13645 m .54243 .13029 L .54183 .12968 L 0 .021 0 r
F
.54504 .13648 m .54503 .13647 L .54501 .13645 L F
.54503 .13647 m .54243 .13029 L .54501 .13645 L F
.54014 .13079 m .53042 .12719 L .53449 .13448 L .751 .668 0 r
F
.53803 .1284 m .53042 .12719 L .54014 .13079 L F
.54661 .13873 m .54604 .13757 L .54504 .13648 L 0 .021 0 r
F
.54604 .13757 m .54243 .13029 L .54504 .13648 L F
.52734 .12807 m .52734 .12807 L .52717 .12806 L .8 .863 0 r
F
.52729 .12801 m .52713 .128 L .52717 .12806 L .8 .872 0 r
F
.5486 .13568 m .54267 .12914 L .54703 .13683 L .619 .523 0 r
F
.54586 .13369 m .54243 .13029 L .54553 .13654 L .58 .449 0 r
F
.54586 .13369 m .54553 .13654 L .54661 .13873 L F
.54915 .13695 m .54586 .13369 L .54661 .13873 L F
.55446 .1314 m .54753 .13007 L .5486 .13568 L .619 .523 0 r
F
.55395 .13358 m .54814 .13192 L .54915 .13695 L .58 .449 0 r
F
.54753 .13007 m .54267 .12914 L .5486 .13568 L .619 .523 0 r
F
.54814 .13192 m .54243 .13029 L .54915 .13695 L .58 .449 0 r
F
.55384 .15784 m .55142 .15053 L .55142 .15053 L 0 0 0 r
F
.55384 .15784 m .55086 .14609 L .55059 .14803 L F
.14757 .40435 m .15011 .39797 L .12535 .381 L 1 1 0 r
F
.23743 .25928 m .22706 .2428 L .22173 .24714 L F
.23743 .25928 m .24214 .25442 L .22706 .2428 L F
.37965 .14729 m .37399 .1387 L .36852 .14227 L .989 1 0 r
F
.46655 .65836 m .43202 .65821 L .43152 .6652 L .936 .65 0 r
F
.46647 .66477 m .46655 .65836 L .43152 .6652 L .93 .629 0 r
F
.66331 .19411 m .64518 .19934 L .64952 .20484 L .54 .517 0 r
F
.6679 .19947 m .66331 .19411 L .64952 .20484 L .532 .498 0 r
F
.23777 .2596 m .36092 .37307 L .35895 .37539 L .672 .182 0 r
F
.35695 .37774 m .35017 .36623 L .34802 .36856 L 1 1 0 r
F
.35696 .37775 m .35695 .37774 L .35695 .37774 L F
.35695 .37774 m .35017 .36623 L .35695 .37774 L F
.35895 .37539 m .36123 .374 L .35928 .37571 L .672 .182 0 r
F
.36092 .37307 m .36166 .37374 L .35895 .37539 L F
.35695 .37774 m .35928 .37571 L .35017 .36623 L 1 1 0 r
F
.35696 .37775 m .35928 .37571 L .35695 .37774 L F
.36123 .374 m .36166 .37374 L .35928 .37571 L .672 .182 0 r
F
.23777 .2596 m .24267 .25494 L .36166 .37374 L F
.46621 .69016 m .43005 .69222 L .42981 .69869 L .912 .544 0 r
F
.46621 .69016 m .46627 .68389 L .43005 .69222 L F
.65814 .39183 m .6364 .39493 L .63545 .40085 L .422 .049 0 r
F
.65814 .39183 m .65935 .38573 L .6364 .39493 L F
.72472 .42047 m .6982 .42714 L .69852 .43261 L .468 .082 0 r
F
.72472 .42047 m .72428 .41494 L .6982 .42714 L F
.58772 .82025 m .54843 .81917 L .54752 .82353 L .698 .057 0 r
F
.58772 .82025 m .5891 .81585 L .54843 .81917 L F
.37981 .14787 m .37425 .13962 L .36879 .14313 L .988 1 0 r
F
.37981 .14787 m .38464 .14387 L .37425 .13962 L F
.27613 .19902 m .27013 .1865 L .26635 .19332 L 1 1 0 r
F
.27613 .19902 m .2814 .19445 L .27013 .1865 L F
.28022 .19268 m .27228 .17699 L .26655 .18128 L F
.28022 .19268 m .28551 .18806 L .27228 .17699 L F
.5621 .57165 m .52748 .56522 L .52775 .56943 L 1 .669 0 r
F
.56236 .57596 m .5621 .57165 L .52775 .56943 L 1 .663 0 r
F
.59798 .57588 m .5621 .57165 L .56236 .57596 L .98 .539 0 r
F
.59798 .57588 m .59783 .57152 L .5621 .57165 L F
.72392 .30091 m .70401 .30707 L .70601 .31333 L .351 .099 0 r
F
.72392 .30091 m .72183 .29465 L .70401 .30707 L F
.14757 .40435 m .12535 .381 L .12255 .38732 L 1 1 0 r
F
.14511 .41076 m .14757 .40435 L .12255 .38732 L F
.52518 .52537 m .52499 .52153 L .49468 .51989 L 1 .785 0 r
F
.68318 .34301 m .66436 .34614 L .66392 .35302 L .322 .042 0 r
F
.68318 .34301 m .68374 .33602 L .66436 .34614 L F
.46456 .83952 m .46453 .8352 L .42271 .83445 L .894 .089 0 r
F
.50588 .83897 m .46453 .8352 L .46456 .83952 L .834 .071 0 r
F
.50588 .83897 m .50634 .83465 L .46453 .8352 L F
.12405 .44211 m .09814 .41745 L .09598 .42421 L 1 1 0 r
F
.12219 .44887 m .12405 .44211 L .09598 .42421 L F
.32583 .20205 m .32255 .19935 L .31661 .20153 L .626 .433 0 r
F
.32583 .20205 m .33092 .19853 L .32255 .19935 L F
.24214 .25442 m .23252 .23863 L .22706 .2428 L 1 1 0 r
F
.24214 .25442 m .24693 .24967 L .23252 .23863 L F
.46662 .65194 m .43258 .65115 L .43202 .65821 L .944 .671 0 r
F
.46655 .65836 m .46662 .65194 L .43202 .65821 L .936 .65 0 r
F
.52031 .13659 m .51713 .13147 L .50638 .13468 L .899 .927 0 r
F
.85232 .51511 m .82138 .52477 L .82205 .53151 L .333 .059 0 r
F
.85232 .51511 m .85158 .50829 L .82138 .52477 L F
.63002 .80659 m .59175 .8068 L .59044 .81136 L .626 .05 0 r
F
.63002 .80659 m .63176 .80197 L .59175 .8068 L F
.5203 .13672 m .51711 .13158 L .50637 .13474 L .897 .923 0 r
F
.53112 .13294 m .51711 .13158 L .5203 .13672 L .847 .892 0 r
F
.53501 .13791 m .53112 .13294 L .5203 .13672 L .849 .883 0 r
F
.84757 .508 m .81746 .51768 L .81813 .52435 L .326 .058 0 r
F
.84757 .508 m .84685 .50126 L .81746 .51768 L F
.31328 .22918 m .33149 .26038 L .32636 .26214 L .39 .034 0 r
F
.76924 .70316 m .73438 .70803 L .73295 .71378 L .398 .04 0 r
F
.76924 .70316 m .7709 .6973 L .73438 .70803 L F
.54898 .48025 m .52161 .47927 L .52161 .48305 L .936 .438 0 r
F
.54898 .48025 m .54909 .47637 L .52161 .47927 L F
.36463 .19193 m .3642 .20212 L .35858 .20298 L .014 0 0 r
F
.36463 .19193 m .36922 .18862 L .3642 .20212 L F
.63336 .56879 m .59768 .56718 L .59783 .57152 L .881 .412 0 r
F
.63336 .56879 m .63338 .56438 L .59768 .56718 L F
.3462 .72996 m .30178 .72871 L .30276 .73379 L 1 .454 0 r
F
.34673 .73522 m .3462 .72996 L .30276 .73379 L 1 .442 0 r
F
.38932 .72733 m .3462 .72996 L .34673 .73522 L .968 .464 0 r
F
.65859 .18884 m .64074 .19392 L .64518 .19934 L .548 .536 0 r
F
.66331 .19411 m .65859 .18884 L .64518 .19934 L .54 .517 0 r
F
.46616 .69638 m .42981 .69869 L .42961 .70505 L .908 .523 0 r
F
.46616 .69638 m .46621 .69016 L .42981 .69869 L F
.52518 .52537 m .49468 .51989 L .49476 .52346 L 1 .785 0 r
F
.52537 .52923 m .52518 .52537 L .49476 .52346 L 1 .786 0 r
F
.34711 .15776 m .34141 .1469 L .33558 .15052 L 1 1 0 r
F
.34711 .15776 m .3524 .15372 L .34141 .1469 L F
.66788 .54085 m .63326 .54222 L .6333 .54667 L .778 .303 0 r
F
.66788 .54085 m .66798 .53628 L .63326 .54222 L F
.63053 .42796 m .60632 .43054 L .60566 .43546 L .587 .067 0 r
F
.63053 .42796 m .63149 .42286 L .60632 .43054 L F
.24035 .73586 m .20012 .72082 L .2017 .72657 L 1 .51 0 r
F
.24176 .74143 m .24035 .73586 L .2017 .72657 L 1 .492 0 r
F
.72079 .75249 m .68466 .75556 L .68301 .76082 L .475 .041 0 r
F
.72079 .75249 m .72276 .74713 L .68466 .75556 L F
.24267 .25494 m .36326 .37105 L .36128 .37336 L .675 .184 0 r
F
.35927 .3757 m .35233 .36391 L .35017 .36623 L 1 1 0 r
F
.35928 .37571 m .35927 .37569 L .35927 .3757 L F
.35927 .37569 m .35233 .36391 L .35927 .3757 L F
.36128 .37336 m .36369 .37207 L .36166 .37374 L .675 .184 0 r
F
.36326 .37105 m .3641 .37186 L .36128 .37336 L F
.35927 .37569 m .36166 .37374 L .35233 .36391 L 1 1 0 r
F
.35928 .37571 m .36166 .37374 L .35927 .37569 L F
.36369 .37207 m .3641 .37186 L .36166 .37374 L .675 .184 0 r
F
.24267 .25494 m .24777 .25053 L .3641 .37186 L F
.56236 .57596 m .52775 .56943 L .52802 .5737 L 1 .663 0 r
F
.56262 .58031 m .56236 .57596 L .52802 .5737 L 1 .657 0 r
F
.59811 .58025 m .56236 .57596 L .56262 .58031 L .974 .532 0 r
F
.59811 .58025 m .59798 .57588 L .56236 .57596 L F
.81567 .62922 m .78263 .63628 L .78185 .64255 L .352 .043 0 r
F
.81567 .62922 m .81655 .62284 L .78263 .63628 L F
.70009 .49439 m .66815 .49888 L .66818 .50365 L .649 .194 0 r
F
.70009 .49439 m .70009 .48947 L .66815 .49888 L F
.20204 .64608 m .1625 .63006 L .16337 .63606 L 1 .657 0 r
F
.20291 .65185 m .20204 .64608 L .16337 .63606 L 1 .645 0 r
F
.57612 .47211 m .54919 .47243 L .54909 .47637 L .841 .314 0 r
F
.57612 .47211 m .5764 .46807 L .54919 .47243 L F
.60324 .45389 m .57731 .45546 L .57699 .45975 L .729 .175 0 r
F
.60324 .45389 m .60381 .44946 L .57731 .45546 L F
.23771 .74603 m .19655 .73126 L .19827 .73704 L 1 .488 0 r
F
.23922 .75162 m .23771 .74603 L .19827 .73704 L 1 .47 0 r
F
.72588 .30716 m .70601 .31333 L .70788 .31959 L .343 .079 0 r
F
.72588 .30716 m .72392 .30091 L .70601 .31333 L F
.37939 .82341 m .33667 .81527 L .33807 .81995 L 1 .215 0 r
F
.38036 .82795 m .37939 .82341 L .33807 .81995 L 1 .195 0 r
F
.14511 .41076 m .12255 .38732 L .11985 .39368 L 1 1 0 r
F
.14274 .41721 m .14511 .41076 L .11985 .39368 L F
.51713 .13147 m .50397 .12939 L .50638 .13468 L .895 .933 0 r
F
.52537 .52923 m .49476 .52346 L .49485 .52705 L 1 .786 0 r
F
.52558 .5331 m .52537 .52923 L .49485 .52705 L 1 .787 0 r
F
.51711 .13158 m .50396 .12944 L .50637 .13474 L .893 .93 0 r
F
.43758 .60233 m .40248 .6071 L .40071 .61459 L .841 .704 0 r
F
.4368 .60901 m .43758 .60233 L .40071 .61459 L .84 .693 0 r
F
.81955 .63777 m .78564 .64453 L .78484 .65089 L .361 .045 0 r
F
.81955 .63777 m .82045 .63128 L .78564 .64453 L F
.47805 .30943 m .47845 .28528 L .4721 .14519 L .022 0 0 r
F
.18678 .68943 m .14776 .67151 L .14899 .6778 L 1 .629 0 r
F
.18794 .69555 m .18678 .68943 L .14899 .6778 L 1 .613 0 r
F
.3474 .15851 m .34175 .14778 L .33594 .15139 L 1 1 0 r
F
.3474 .15851 m .35267 .15447 L .34175 .14778 L F
.2814 .19445 m .27484 .18088 L .27013 .1865 L F
.2814 .19445 m .28664 .18982 L .27484 .18088 L F
.42289 .82511 m .38073 .81844 L .38169 .82287 L .962 .157 0 r
F
.4234 .82941 m .42289 .82511 L .38169 .82287 L .953 .137 0 r
F
.46463 .83024 m .42289 .82511 L .4234 .82941 L .899 .097 0 r
F
.46888 .43972 m .46892 .43574 L .44606 .43698 L 1 .83 0 r
F
.14034 .60008 m .10546 .5785 L .10559 .58527 L 1 .813 0 r
F
.14055 .60671 m .14034 .60008 L .10559 .58527 L 1 .8 0 r
F
.28551 .18806 m .27807 .17277 L .27228 .17699 L 1 1 0 r
F
.28551 .18806 m .29086 .18352 L .27807 .17277 L F
.77195 .7124 m .73643 .71688 L .73496 .72271 L .411 .041 0 r
F
.77195 .7124 m .77364 .70644 L .73643 .71688 L F
.14785 .5843 m .1147 .56281 L .11456 .56945 L 1 .849 0 r
F
.14782 .59084 m .14785 .5843 L .11456 .56945 L 1 .836 0 r
F
.72511 .42596 m .69852 .43261 L .69881 .43803 L .467 .078 0 r
F
.72511 .42596 m .72472 .42047 L .69852 .43261 L F
.15832 .56204 m .12425 .54134 L .12404 .5478 L 1 .844 0 r
F
.15828 .56835 m .15832 .56204 L .12404 .5478 L 1 .832 0 r
F
.24693 .24967 m .23812 .23467 L .23252 .23863 L 1 1 0 r
F
.24693 .24967 m .25181 .24505 L .23812 .23467 L F
.65376 .18366 m .63619 .18858 L .64074 .19392 L .556 .553 0 r
F
.65859 .18884 m .65376 .18366 L .64074 .19392 L .548 .536 0 r
F
.15108 .40518 m .15341 .39881 L .12741 .3816 L 1 1 0 r
F
.4667 .64556 m .43318 .64406 L .43258 .65115 L .952 .693 0 r
F
.46662 .65194 m .4667 .64556 L .43258 .65115 L .944 .671 0 r
F
.38945 .73296 m .38932 .72733 L .34673 .73522 L .97 .449 0 r
F
.42931 .72339 m .38932 .72733 L .38945 .73296 L .922 .463 0 r
F
.42931 .72339 m .42937 .7174 L .38932 .72733 L F
.52558 .5331 m .49485 .52705 L .49494 .53066 L 1 .787 0 r
F
.52579 .537 m .52558 .5331 L .49494 .53066 L 1 .788 0 r
F
.5467 .83714 m .50634 .83465 L .50588 .83897 L .767 .063 0 r
F
.5467 .83714 m .54766 .8328 L .50634 .83465 L F
.56262 .58031 m .52802 .5737 L .5283 .57802 L 1 .657 0 r
F
.56288 .58468 m .56262 .58031 L .5283 .57802 L 1 .65 0 r
F
.59824 .58463 m .56262 .58031 L .56288 .58468 L .968 .524 0 r
F
.59824 .58463 m .59811 .58025 L .56262 .58031 L F
.46888 .43972 m .44606 .43698 L .44585 .44069 L 1 .83 0 r
F
.46885 .44366 m .46888 .43972 L .44585 .44069 L 1 .823 0 r
F
.12219 .44887 m .09598 .42421 L .09393 .43099 L 1 1 0 r
F
.12042 .45565 m .12219 .44887 L .09393 .43099 L F
.63333 .57321 m .59783 .57152 L .59798 .57588 L .875 .404 0 r
F
.63333 .57321 m .63336 .56879 L .59783 .57152 L F
.46611 .70252 m .42961 .70505 L .42947 .71128 L .905 .502 0 r
F
.46611 .70252 m .46616 .69638 L .42961 .70505 L F
.54888 .48407 m .52161 .48305 L .5216 .48679 L .93 .432 0 r
F
.54888 .48407 m .54898 .48025 L .52161 .48305 L F
.6738 .78611 m .63666 .78767 L .63508 .79251 L .55 .045 0 r
F
.6738 .78611 m .67577 .78119 L .63666 .78767 L F
.67178 .21692 m .65458 .2207 L .65809 .22688 L .408 .307 0 r
F
.6753 .22314 m .65809 .22688 L .66142 .23315 L .39 .271 0 r
F
.6753 .22314 m .67178 .21692 L .65809 .22688 L F
.67861 .22946 m .66142 .23315 L .66457 .23952 L .377 .234 0 r
F
.67861 .22946 m .6753 .22314 L .66142 .23315 L F
.2895 .77552 m .24808 .76312 L .24983 .7684 L 1 .389 0 r
F
.29098 .78062 m .2895 .77552 L .24983 .7684 L 1 .37 0 r
F
.66806 .21082 m .6509 .21463 L .65458 .2207 L .426 .341 0 r
F
.67178 .21692 m .66806 .21082 L .65458 .2207 L .408 .307 0 r
F
.52579 .537 m .49494 .53066 L .49504 .53431 L 1 .788 0 r
F
.52601 .54092 m .52579 .537 L .49504 .53431 L 1 .789 0 r
F
.6817 .23589 m .66457 .23952 L .66751 .24599 L .365 .195 0 r
F
.6817 .23589 m .67861 .22946 L .66457 .23952 L F
.2521 .69662 m .20947 .68572 L .21079 .69123 L 1 .53 0 r
F
.25321 .70193 m .2521 .69662 L .21079 .69123 L 1 .52 0 r
F
.7277 .31339 m .70788 .31959 L .70962 .32583 L .336 .074 0 r
F
.7277 .31339 m .72588 .30716 L .70788 .31959 L F
.14274 .41721 m .11985 .39368 L .11725 .40008 L 1 1 0 r
F
.14047 .42368 m .14274 .41721 L .11725 .40008 L F
.1913 .67931 m .15351 .66125 L .15458 .66748 L 1 .653 0 r
F
.19232 .68537 m .1913 .67931 L .15458 .66748 L 1 .637 0 r
F
.46885 .44366 m .44585 .44069 L .44564 .44437 L 1 .823 0 r
F
.46881 .44755 m .46885 .44366 L .44564 .44437 L 1 .816 0 r
F
.33609 .8008 m .2941 .79061 L .29575 .79551 L 1 .294 0 r
F
.33738 .80553 m .33609 .8008 L .29575 .79551 L 1 .274 0 r
F
.66415 .20484 m .64706 .20865 L .6509 .21463 L .444 .374 0 r
F
.66806 .21082 m .66415 .20484 L .6509 .21463 L .426 .341 0 r
F
.72252 .762 m .68593 .76469 L .68424 .77002 L .485 .042 0 r
F
.72252 .762 m .72453 .75656 L .68593 .76469 L F
.24777 .25053 m .36563 .36909 L .36365 .3714 L .678 .186 0 r
F
.36164 .37373 m .35449 .36158 L .35233 .36391 L 1 1 0 r
F
.36166 .37374 m .36165 .37373 L .36164 .37373 L F
.36165 .37373 m .35449 .36158 L .36164 .37373 L F
.36365 .3714 m .36622 .37023 L .3641 .37186 L .678 .186 0 r
F
.36563 .36909 m .3666 .37006 L .36365 .3714 L F
.36165 .37373 m .3641 .37186 L .35449 .36158 L 1 1 0 r
F
.36166 .37374 m .3641 .37186 L .36165 .37373 L F
.36622 .37023 m .3666 .37006 L .3641 .37186 L .678 .186 0 r
F
.24777 .25053 m .25314 .24647 L .3666 .37006 L F
.588 .82966 m .54859 .82838 L .54766 .8328 L .7 .057 0 r
F
.588 .82966 m .58941 .8252 L .54859 .82838 L F
.66777 .54541 m .6333 .54667 L .63334 .5511 L .774 .296 0 r
F
.66777 .54541 m .66788 .54085 L .6333 .54667 L F
.37139 .17808 m .36943 .18381 L .36347 .18413 L 0 0 0 r
F
.37139 .17808 m .37615 .175 L .36943 .18381 L F
.52601 .54092 m .49504 .53431 L .49515 .53799 L 1 .789 0 r
F
.52623 .54487 m .52601 .54092 L .49515 .53799 L F
.85297 .52193 m .82205 .53151 L .82263 .53826 L .329 .057 0 r
F
.85297 .52193 m .85232 .51511 L .82205 .53151 L F
.84818 .51474 m .81813 .52435 L .8187 .53103 L .321 .056 0 r
F
.84818 .51474 m .84757 .508 L .81813 .52435 L F
.68455 .24242 m .66751 .24599 L .67025 .25254 L .352 .155 0 r
F
.68455 .24242 m .6817 .23589 L .66751 .24599 L F
.56288 .58468 m .5283 .57802 L .52859 .5824 L 1 .65 0 r
F
.56313 .58909 m .56288 .58468 L .52859 .5824 L 1 .642 0 r
F
.59835 .58902 m .56288 .58468 L .56313 .58909 L .961 .515 0 r
F
.59835 .58902 m .59824 .58463 L .56288 .58468 L F
.70006 .49927 m .66818 .50365 L .66819 .50839 L .647 .189 0 r
F
.70006 .49927 m .70009 .49439 L .66818 .50365 L F
.15108 .40518 m .12741 .3816 L .12484 .38794 L 1 1 0 r
F
.14883 .41156 m .15108 .40518 L .12484 .38794 L F
.25181 .24505 m .24386 .23094 L .23812 .23467 L F
.25181 .24505 m .25678 .24054 L .24386 .23094 L F
.46881 .44755 m .44564 .44437 L .44545 .44804 L 1 .816 0 r
F
.46877 .45141 m .46881 .44755 L .44545 .44804 L 1 .808 0 r
F
.63059 .8161 m .59212 .81603 L .59079 .82065 L .63 .051 0 r
F
.63059 .8161 m .63236 .81141 L .59212 .81603 L F
.66006 .19897 m .64306 .20278 L .64706 .20865 L .461 .405 0 r
F
.66415 .20484 m .66006 .19897 L .64706 .20865 L .444 .374 0 r
F
.28664 .18982 m .27998 .17582 L .27484 .18088 L 1 1 0 r
F
.28664 .18982 m .29188 .1852 L .27998 .17582 L F
.65376 .18366 m .64882 .17857 L .63619 .18858 L .556 .553 0 r
F
.57585 .47608 m .54909 .47637 L .54898 .48025 L .835 .31 0 r
F
.57585 .47608 m .57612 .47211 L .54909 .47637 L F
.52623 .54487 m .49515 .53799 L .49526 .54172 L 1 .789 0 r
F
.52647 .54886 m .52623 .54487 L .49526 .54172 L F
.29086 .18352 m .2839 .16865 L .27807 .17277 L 1 1 0 r
F
.29086 .18352 m .29626 .17906 L .2839 .16865 L F
.30084 .7236 m .25683 .71765 L .25814 .72282 L 1 .465 0 r
F
.30178 .72871 m .30084 .7236 L .25814 .72282 L 1 .455 0 r
F
.65689 .39775 m .63545 .40085 L .63446 .4066 L .411 .047 0 r
F
.65689 .39775 m .65814 .39183 L .63545 .40085 L F
.68717 .24905 m .67025 .25254 L .67277 .25919 L .338 .114 0 r
F
.68717 .24905 m .68455 .24242 L .67025 .25254 L F
.63329 .57762 m .59798 .57588 L .59811 .58025 L .869 .395 0 r
F
.63329 .57762 m .63333 .57321 L .59798 .57588 L F
.33092 .19853 m .32863 .1976 L .32255 .19935 L .507 .216 0 r
F
.33092 .19853 m .33608 .19523 L .32863 .1976 L F
.28805 .78548 m .24597 .77341 L .24783 .7787 L 1 .369 0 r
F
.28961 .7906 m .28805 .78548 L .24783 .7787 L 1 .35 0 r
F
.46877 .45141 m .44545 .44804 L .44525 .45168 L 1 .808 0 r
F
.46874 .45523 m .46877 .45141 L .44525 .45168 L 1 .801 0 r
F
.54878 .48784 m .5216 .48679 L .52159 .49049 L .925 .427 0 r
F
.54878 .48784 m .54888 .48407 L .5216 .48679 L F
.52647 .54886 m .49526 .54172 L .49538 .54549 L 1 .789 0 r
F
.52671 .55289 m .52647 .54886 L .49538 .54549 L 1 .788 0 r
F
.72546 .43139 m .69881 .43803 L .69906 .44339 L .466 .074 0 r
F
.72546 .43139 m .72511 .42596 L .69881 .43803 L F
.46678 .63922 m .43384 .63694 L .43318 .64406 L .962 .715 0 r
F
.4667 .64556 m .46678 .63922 L .43318 .64406 L .952 .693 0 r
F
.68241 .34992 m .66392 .35302 L .66329 .35981 L .31 .037 0 r
F
.68241 .34992 m .68318 .34301 L .66392 .35302 L F
.14047 .42368 m .11725 .40008 L .11475 .40651 L 1 1 0 r
F
.13828 .43017 m .14047 .42368 L .11475 .40651 L F
.65579 .19321 m .63891 .19701 L .64306 .20278 L .476 .434 0 r
F
.66006 .19897 m .65579 .19321 L .64306 .20278 L .461 .405 0 r
F
.7294 .31961 m .70962 .32583 L .71125 .33206 L .328 .072 0 r
F
.7294 .31961 m .7277 .31339 L .70962 .32583 L F
.12042 .45565 m .09393 .43099 L .09199 .43779 L 1 1 0 r
F
.11874 .46245 m .12042 .45565 L .09199 .43779 L F
.6027 .45821 m .57699 .45975 L .57669 .46395 L .724 .172 0 r
F
.6027 .45821 m .60324 .45389 L .57699 .45975 L F
.46606 .70857 m .42947 .71128 L .42937 .7174 L .901 .48 0 r
F
.46606 .70857 m .46611 .70252 L .42947 .71128 L F
.56313 .58909 m .52859 .5824 L .52888 .58684 L 1 .642 0 r
F
.56338 .59353 m .56313 .58909 L .52888 .58684 L 1 .634 0 r
F
.59845 .59343 m .56313 .58909 L .56338 .59353 L .954 .506 0 r
F
.59845 .59343 m .59835 .58902 L .56313 .58909 L F
.38464 .14387 m .37975 .13625 L .37425 .13962 L .97 1 0 r
F
.46466 .83444 m .46463 .83024 L .4234 .82941 L .89 .079 0 r
F
.50539 .8339 m .46463 .83024 L .46466 .83444 L .828 .069 0 r
F
.50539 .8339 m .50585 .82971 L .46463 .83024 L F
.3524 .15372 m .3473 .14342 L .34141 .1469 L 1 1 0 r
F
.3524 .15372 m .35773 .14978 L .3473 .14342 L F
.52671 .55289 m .49538 .54549 L .4955 .54933 L 1 .788 0 r
F
.52696 .55695 m .52671 .55289 L .4955 .54933 L 1 .787 0 r
F
.3185 .22619 m .33465 .25554 L .33149 .26038 L .379 .031 0 r
F
.46874 .45523 m .44525 .45168 L .44506 .45531 L 1 .801 0 r
F
.4687 .45902 m .46874 .45523 L .44506 .45531 L 1 .793 0 r
F
.77199 .25394 m .7506 .2644 L .75489 .2701 L .41 .372 0 r
F
.77652 .25953 m .75489 .2701 L .75911 .27587 L .403 .358 0 r
F
.77652 .25953 m .77199 .25394 L .75489 .2701 L F
.6296 .43291 m .60566 .43546 L .60501 .44026 L .581 .066 0 r
F
.6296 .43291 m .63053 .42796 L .60566 .43546 L F
.76738 .24842 m .74622 .25874 L .7506 .2644 L .417 .386 0 r
F
.77199 .25394 m .76738 .24842 L .7506 .2644 L .41 .372 0 r
F
.78096 .26518 m .75911 .27587 L .76325 .28168 L .396 .344 0 r
F
.78096 .26518 m .77652 .25953 L .75911 .27587 L F
.14883 .41156 m .12484 .38794 L .12237 .39431 L 1 1 0 r
F
.14669 .41797 m .14883 .41156 L .12237 .39431 L F
.67482 .79569 m .63738 .7969 L .63576 .80181 L .557 .045 0 r
F
.67482 .79569 m .67683 .79069 L .63738 .7969 L F
.76269 .24295 m .74177 .25314 L .74622 .25874 L .423 .4 0 r
F
.76738 .24842 m .76269 .24295 L .74622 .25874 L .417 .386 0 r
F
.78533 .27088 m .76325 .28168 L .76731 .28755 L .39 .33 0 r
F
.78533 .27088 m .78096 .26518 L .76325 .28168 L F
.68953 .25578 m .67277 .25919 L .67506 .26591 L .324 .077 0 r
F
.68953 .25578 m .68717 .24905 L .67277 .25919 L F
.15828 .56835 m .12404 .5478 L .12393 .55425 L 1 .832 0 r
F
.15832 .57464 m .15828 .56835 L .12393 .55425 L 1 .82 0 r
F
.52696 .55695 m .4955 .54933 L .49564 .55322 L 1 .787 0 r
F
.52721 .56106 m .52696 .55695 L .49564 .55322 L 1 .785 0 r
F
.42271 .83445 m .38036 .82795 L .38136 .83241 L .955 .146 0 r
F
.42324 .83879 m .42271 .83445 L .38136 .83241 L .946 .126 0 r
F
.46456 .83952 m .42271 .83445 L .42324 .83879 L .894 .089 0 r
F
.14782 .59084 m .11456 .56945 L .11452 .57608 L 1 .836 0 r
F
.14788 .59736 m .14782 .59084 L .11452 .57608 L 1 .823 0 r
F
.81468 .63557 m .78185 .64255 L .78098 .64879 L .348 .041 0 r
F
.81468 .63557 m .81567 .62922 L .78185 .64255 L F
.34673 .73522 m .30276 .73379 L .30379 .73883 L 1 .442 0 r
F
.34731 .74042 m .34673 .73522 L .30379 .73883 L 1 .429 0 r
F
.38945 .73296 m .34673 .73522 L .34731 .74042 L .97 .449 0 r
F
.75791 .23755 m .73724 .2476 L .74177 .25314 L .43 .413 0 r
F
.76269 .24295 m .75791 .23755 L .74177 .25314 L .423 .4 0 r
F
.25678 .24054 m .24975 .22745 L .24386 .23094 L 1 1 0 r
F
.25678 .24054 m .26183 .23617 L .24975 .22745 L F
.7896 .27664 m .76731 .28755 L .77129 .29347 L .386 .316 0 r
F
.7896 .27664 m .78533 .27088 L .76731 .28755 L F
.66764 .54995 m .63334 .5511 L .63336 .55553 L .769 .289 0 r
F
.66764 .54995 m .66777 .54541 L .63334 .5511 L F
.65136 .18758 m .63463 .19134 L .63891 .19701 L .491 .463 0 r
F
.65579 .19321 m .65136 .18758 L .63891 .19701 L .476 .434 0 r
F
.25314 .24647 m .36916 .36837 L .3666 .37006 L .682 .188 0 r
F
.25314 .24647 m .25888 .24289 L .36916 .36837 L F
.35267 .15447 m .34765 .14437 L .34175 .14778 L 1 1 0 r
F
.35267 .15447 m .35799 .15056 L .34765 .14437 L F
.14055 .60671 m .10559 .58527 L .10583 .59201 L 1 .8 0 r
F
.14085 .61332 m .14055 .60671 L .10583 .59201 L 1 .786 0 r
F
.20291 .65185 m .16337 .63606 L .16433 .64204 L 1 .645 0 r
F
.20385 .65758 m .20291 .65185 L .16433 .64204 L 1 .633 0 r
F
.33533 .81052 m .29289 .80063 L .29462 .80554 L 1 .277 0 r
F
.33667 .81527 m .33533 .81052 L .29462 .80554 L 1 .257 0 r
F
.29188 .1852 m .28537 .17109 L .27998 .17582 L 1 1 0 r
F
.29188 .1852 m .29717 .18062 L .28537 .17109 L F
.36922 .18862 m .37019 .20256 L .3642 .20212 L .155 0 0 r
F
.36922 .18862 m .37388 .18562 L .37019 .20256 L F
.4687 .45902 m .44506 .45531 L .44488 .45892 L 1 .793 0 r
F
.46867 .46277 m .4687 .45902 L .44488 .45892 L 1 .785 0 r
F
.52721 .56106 m .49564 .55322 L .49578 .55718 L F
.52748 .56522 m .52721 .56106 L .49578 .55718 L 1 .782 0 r
F
.75306 .23222 m .73264 .24212 L .73724 .2476 L .437 .427 0 r
F
.75791 .23755 m .75306 .23222 L .73724 .2476 L .43 .413 0 r
F
.79379 .28246 m .77129 .29347 L .77518 .29943 L .382 .302 0 r
F
.79379 .28246 m .7896 .27664 L .77129 .29347 L F
.7712 .25454 m .74988 .26495 L .75415 .27066 L .408 .369 0 r
F
.7757 .26013 m .75415 .27066 L .75833 .27642 L .402 .355 0 r
F
.7757 .26013 m .7712 .25454 L .75415 .27066 L F
.76661 .24902 m .74554 .25929 L .74988 .26495 L .415 .383 0 r
F
.7712 .25454 m .76661 .24902 L .74988 .26495 L .408 .369 0 r
F
.78011 .26577 m .75833 .27642 L .76243 .28224 L .395 .341 0 r
F
.78011 .26577 m .7757 .26013 L .75833 .27642 L F
.7675 .70897 m .73295 .71378 L .73144 .71947 L .392 .038 0 r
F
.7675 .70897 m .76924 .70316 L .73295 .71378 L F
.81855 .64422 m .78484 .65089 L .78395 .65722 L .357 .043 0 r
F
.81855 .64422 m .81955 .63777 L .78484 .65089 L F
.56338 .59353 m .52888 .58684 L .52917 .59134 L 1 .634 0 r
F
.56362 .598 m .56338 .59353 L .52917 .59134 L 1 .625 0 r
F
.59854 .59785 m .56338 .59353 L .56362 .598 L .947 .496 0 r
F
.59854 .59785 m .59845 .59343 L .56338 .59353 L F
.76195 .24356 m .74111 .25369 L .74554 .25929 L .422 .397 0 r
F
.76661 .24902 m .76195 .24356 L .74554 .25929 L .415 .383 0 r
F
.70001 .50412 m .66819 .50839 L .66819 .5131 L .644 .184 0 r
F
.70001 .50412 m .70006 .49927 L .66819 .50839 L F
.38073 .81844 m .33872 .81019 L .3401 .81478 L 1 .21 0 r
F
.38169 .82287 m .38073 .81844 L .3401 .81478 L 1 .19 0 r
F
.13828 .43017 m .11475 .40651 L .11235 .41298 L 1 1 0 r
F
.13619 .43669 m .13828 .43017 L .11235 .41298 L F
.63322 .58203 m .59811 .58025 L .59824 .58463 L .863 .386 0 r
F
.63322 .58203 m .63329 .57762 L .59811 .58025 L F
.78444 .27147 m .76243 .28224 L .76645 .28811 L .389 .327 0 r
F
.78444 .27147 m .78011 .26577 L .76243 .28224 L F
.74813 .22694 m .72796 .2367 L .73264 .24212 L .444 .441 0 r
F
.75306 .23222 m .74813 .22694 L .73264 .24212 L .437 .427 0 r
F
.38965 .73849 m .38945 .73296 L .34731 .74042 L .972 .433 0 r
F
.42928 .72927 m .38945 .73296 L .38965 .73849 L .923 .444 0 r
F
.42928 .72927 m .42931 .72339 L .38945 .73296 L F
.52748 .56522 m .49578 .55718 L .49593 .56122 L 1 .782 0 r
F
.52775 .56943 m .52748 .56522 L .49593 .56122 L 1 .779 0 r
F
.7979 .28833 m .77518 .29943 L .77899 .30545 L .378 .288 0 r
F
.7979 .28833 m .79379 .28246 L .77518 .29943 L F
.29626 .17906 m .28979 .16461 L .2839 .16865 L 1 1 0 r
F
.29626 .17906 m .30172 .17469 L .28979 .16461 L F
.57559 .47999 m .54898 .48025 L .54888 .48407 L .83 .306 0 r
F
.57559 .47999 m .57585 .47608 L .54898 .48025 L F
.73098 .32579 m .71125 .33206 L .71276 .33826 L .322 .069 0 r
F
.73098 .32579 m .7294 .31961 L .71125 .33206 L F
.75719 .23816 m .73661 .24815 L .74111 .25369 L .428 .411 0 r
F
.76195 .24356 m .75719 .23816 L .74111 .25369 L .422 .397 0 r
F
.54868 .49156 m .52159 .49049 L .52158 .49415 L .92 .421 0 r
F
.54868 .49156 m .54878 .48784 L .52159 .49049 L F
.78867 .27724 m .76645 .28811 L .77039 .29403 L .385 .312 0 r
F
.78867 .27724 m .78444 .27147 L .76645 .28811 L F
.8535 .52875 m .82263 .53826 L .82311 .545 L .325 .056 0 r
F
.8535 .52875 m .85297 .52193 L .82263 .53826 L F
.84869 .52147 m .8187 .53103 L .81918 .53769 L .316 .054 0 r
F
.84869 .52147 m .84818 .51474 L .8187 .53103 L F
.46867 .46277 m .44488 .45892 L .4447 .46251 L 1 .785 0 r
F
.46864 .4665 m .46867 .46277 L .4447 .46251 L 1 .777 0 r
F
.75236 .23283 m .73203 .24267 L .73661 .24815 L .435 .425 0 r
F
.75719 .23816 m .75236 .23283 L .73661 .24815 L .428 .411 0 r
F
.52775 .56943 m .49593 .56122 L .49609 .56533 L 1 .779 0 r
F
.52802 .5737 m .52775 .56943 L .49609 .56533 L 1 .775 0 r
F
.74312 .22174 m .72321 .23134 L .72796 .2367 L .451 .454 0 r
F
.74813 .22694 m .74312 .22174 L .72796 .2367 L .444 .441 0 r
F
.80191 .29425 m .77899 .30545 L .78272 .31151 L .374 .274 0 r
F
.80191 .29425 m .7979 .28833 L .77899 .30545 L F
.69164 .26259 m .67506 .26591 L .67711 .27272 L .308 .071 0 r
F
.69164 .26259 m .68953 .25578 L .67506 .26591 L F
.54562 .83203 m .50585 .82971 L .50539 .8339 L .758 .061 0 r
F
.54562 .83203 m .54658 .82782 L .50585 .82971 L F
.79282 .28306 m .77039 .29403 L .77424 .3 L .381 .298 0 r
F
.79282 .28306 m .78867 .27724 L .77039 .29403 L F
.64676 .18207 m .63021 .18578 L .63463 .19134 L .506 .489 0 r
F
.65136 .18758 m .64676 .18207 L .63463 .19134 L .491 .463 0 r
F
.18794 .69555 m .14899 .6778 L .15031 .68405 L 1 .613 0 r
F
.18917 .70162 m .18794 .69555 L .15031 .68405 L 1 .596 0 r
F
.14669 .41797 m .12237 .39431 L .12001 .40071 L 1 1 0 r
F
.14464 .42439 m .14669 .41797 L .12001 .40071 L F
.11874 .46245 m .09199 .43779 L .09015 .44461 L F
.11716 .46926 m .11874 .46245 L .09015 .44461 L F
.74745 .22757 m .72738 .23725 L .73203 .24267 L .441 .438 0 r
F
.75236 .23283 m .74745 .22757 L .73203 .24267 L .435 .425 0 r
F
.52802 .5737 m .49609 .56533 L .49626 .56954 L 1 .775 0 r
F
.5283 .57802 m .52802 .5737 L .49626 .56954 L 1 .771 0 r
F
.24176 .74143 m .2017 .72657 L .20337 .73225 L 1 .492 0 r
F
.24323 .74694 m .24176 .74143 L .20337 .73225 L 1 .474 0 r
F
.72577 .43678 m .69906 .44339 L .69928 .4487 L .465 .073 0 r
F
.72577 .43678 m .72546 .43139 L .69906 .44339 L F
.51713 .13147 m .5139 .12644 L .50397 .12939 L .895 .933 0 r
F
.51711 .13158 m .51389 .12653 L .50396 .12944 L .893 .93 0 r
F
.52717 .12806 m .51389 .12653 L .51711 .13158 L .845 .9 0 r
F
.53112 .13294 m .52717 .12806 L .51711 .13158 L .847 .892 0 r
F
.79687 .28893 m .77424 .3 L .778 .30601 L .377 .283 0 r
F
.79687 .28893 m .79282 .28306 L .77424 .3 L F
.73804 .2166 m .71838 .22604 L .72321 .23134 L .458 .468 0 r
F
.74312 .22174 m .73804 .2166 L .72321 .23134 L .451 .454 0 r
F
.80584 .30023 m .78272 .31151 L .78636 .31761 L .37 .26 0 r
F
.80584 .30023 m .80191 .29425 L .78272 .31151 L F
.46602 .71454 m .42937 .7174 L .42931 .72339 L .898 .459 0 r
F
.46602 .71454 m .46606 .70857 L .42937 .7174 L F
.43837 .59586 m .40437 .59964 L .40248 .6071 L .846 .716 0 r
F
.43758 .60233 m .43837 .59586 L .40248 .6071 L .841 .704 0 r
F
.46864 .4665 m .4447 .46251 L .44453 .46609 L 1 .777 0 r
F
.4686 .47019 m .46864 .4665 L .44453 .46609 L 1 .769 0 r
F
.46687 .63294 m .43453 .62985 L .43384 .63694 L .973 .737 0 r
F
.46678 .63922 m .46687 .63294 L .43384 .63694 L .962 .715 0 r
F
.5283 .57802 m .49626 .56954 L .49643 .57383 L 1 .771 0 r
F
.52859 .5824 m .5283 .57802 L .49643 .57383 L 1 .765 0 r
F
.56362 .598 m .52917 .59134 L .52946 .59591 L 1 .625 0 r
F
.56385 .60251 m .56362 .598 L .52946 .59591 L 1 .615 0 r
F
.59861 .60228 m .56362 .598 L .56385 .60251 L .94 .486 0 r
F
.59861 .60228 m .59854 .59785 L .56362 .598 L F
.74246 .22237 m .72265 .23189 L .72738 .23725 L .448 .452 0 r
F
.74745 .22757 m .74246 .22237 L .72738 .23725 L .441 .438 0 r
F
.77017 .7183 m .73496 .72271 L .73341 .72849 L .404 .039 0 r
F
.77017 .7183 m .77195 .7124 L .73496 .72271 L F
.71876 .75778 m .68301 .76082 L .68129 .76601 L .466 .039 0 r
F
.71876 .75778 m .72079 .75249 L .68301 .76082 L F
.26183 .23617 m .2558 .22423 L .24975 .22745 L 1 1 0 r
F
.26183 .23617 m .26696 .23194 L .2558 .22423 L F
.23922 .75162 m .19827 .73704 L .20007 .74276 L 1 .47 0 r
F
.24081 .75716 m .23922 .75162 L .20007 .74276 L 1 .452 0 r
F
.58631 .82458 m .54752 .82353 L .54658 .82782 L .688 .054 0 r
F
.58631 .82458 m .58772 .82025 L .54752 .82353 L F
.60218 .46244 m .57669 .46395 L .5764 .46807 L .719 .169 0 r
F
.60218 .46244 m .6027 .45821 L .57669 .46395 L F
.80083 .29486 m .778 .30601 L .78168 .31207 L .372 .268 0 r
F
.80083 .29486 m .79687 .28893 L .778 .30601 L F
.52859 .5824 m .49643 .57383 L .49662 .57823 L 1 .765 0 r
F
.52888 .58684 m .52859 .5824 L .49662 .57823 L 1 .758 0 r
F
.66749 .55447 m .63336 .55553 L .63338 .55996 L .764 .281 0 r
F
.66749 .55447 m .66764 .54995 L .63336 .55553 L F
.29717 .18062 m .29093 .16659 L .28537 .17109 L 1 1 0 r
F
.29717 .18062 m .30251 .17612 L .29093 .16659 L F
.73288 .21153 m .71349 .22081 L .71838 .22604 L .465 .482 0 r
F
.73804 .2166 m .73288 .21153 L .71838 .22604 L .458 .468 0 r
F
.80967 .30626 m .78636 .31761 L .78992 .32376 L .365 .245 0 r
F
.80967 .30626 m .80584 .30023 L .78636 .31761 L F
.13619 .43669 m .11235 .41298 L .11005 .41947 L 1 1 0 r
F
.1342 .44323 m .13619 .43669 L .11005 .41947 L F
.73739 .21724 m .71785 .22659 L .72265 .23189 L .454 .465 0 r
F
.74246 .22237 m .73739 .21724 L .72265 .23189 L .448 .452 0 r
F
.19232 .68537 m .15458 .66748 L .15574 .67367 L 1 .637 0 r
F
.19342 .69139 m .19232 .68537 L .15574 .67367 L 1 .62 0 r
F
.4686 .47019 m .44453 .46609 L .44437 .46965 L 1 .769 0 r
F
.46857 .47386 m .4686 .47019 L .44437 .46965 L 1 .761 0 r
F
.52888 .58684 m .49662 .57823 L .49681 .58272 L 1 .758 0 r
F
.52917 .59134 m .52888 .58684 L .49681 .58272 L 1 .751 0 r
F
.25321 .70193 m .21079 .69123 L .21217 .69671 L 1 .52 0 r
F
.25437 .70721 m .25321 .70193 L .21217 .69671 L 1 .509 0 r
F
.73245 .33195 m .71276 .33826 L .71416 .34443 L .315 .067 0 r
F
.73245 .33195 m .73098 .32579 L .71276 .33826 L F
.63313 .58643 m .59824 .58463 L .59835 .58902 L .856 .377 0 r
F
.63313 .58643 m .63322 .58203 L .59824 .58463 L F
.47845 .28528 m .47947 .2388 L .47223 .13875 L .431 .058 0 r
F
.64676 .18207 m .64202 .17668 L .63021 .18578 L .506 .489 0 r
F
.62823 .81114 m .59044 .81136 L .5891 .81585 L .617 .048 0 r
F
.62823 .81114 m .63002 .80659 L .59044 .81136 L F
.49988 .66757 m .46647 .66477 L .4664 .67118 L .95 .59 0 r
F
.49999 .67335 m .4664 .67118 L .46634 .67755 L .939 .568 0 r
F
.49999 .67335 m .49988 .66757 L .4664 .67118 L F
.49975 .66179 m .46655 .65836 L .46647 .66477 L .962 .613 0 r
F
.49988 .66757 m .49975 .66179 L .46647 .66477 L .95 .59 0 r
F
.54857 .49523 m .52158 .49415 L .52156 .49777 L .915 .416 0 r
F
.54857 .49523 m .54868 .49156 L .52158 .49415 L F
.8047 .30084 m .78168 .31207 L .78527 .31818 L .368 .253 0 r
F
.8047 .30084 m .80083 .29486 L .78168 .31207 L F
.69347 .26949 m .67711 .27272 L .67891 .2796 L .292 .065 0 r
F
.69347 .26949 m .69164 .26259 L .67711 .27272 L F
.52917 .59134 m .49681 .58272 L .497 .58732 L 1 .751 0 r
F
.52946 .59591 m .52917 .59134 L .497 .58732 L 1 .742 0 r
F
.50008 .67913 m .46634 .67755 L .46627 .68389 L .929 .545 0 r
F
.50008 .67913 m .49999 .67335 L .46634 .67755 L F
.14464 .42439 m .12001 .40071 L .11774 .40713 L 1 1 0 r
F
.14268 .43084 m .14464 .42439 L .11774 .40713 L F
.73225 .21218 m .71298 .22135 L .71785 .22659 L .461 .478 0 r
F
.73739 .21724 m .73225 .21218 L .71785 .22659 L .454 .465 0 r
F
.30172 .17469 m .29573 .16066 L .28979 .16461 L 1 1 0 r
F
.30172 .17469 m .30723 .17041 L .29573 .16066 L F
.33608 .19523 m .33489 .19642 L .32863 .1976 L 0 0 0 r
F
.33608 .19523 m .34133 .19219 L .33489 .19642 L F
.72764 .20653 m .70852 .21564 L .71349 .22081 L .472 .495 0 r
F
.73288 .21153 m .72764 .20653 L .71349 .22081 L .465 .482 0 r
F
.4996 .65603 m .46662 .65194 L .46655 .65836 L .973 .635 0 r
F
.49975 .66179 m .4996 .65603 L .46655 .65836 L .962 .613 0 r
F
.81342 .31233 m .78992 .32376 L .79339 .32995 L .361 .231 0 r
F
.81342 .31233 m .80967 .30626 L .78992 .32376 L F
.25888 .24289 m .37178 .36676 L .36916 .36837 L .688 .19 0 r
F
.25888 .24289 m .26515 .24004 L .37178 .36676 L F
.69993 .50894 m .66819 .5131 L .66818 .51778 L .641 .178 0 r
F
.69993 .50894 m .70001 .50412 L .66819 .5131 L F
.57534 .48382 m .54888 .48407 L .54878 .48784 L .825 .302 0 r
F
.57534 .48382 m .57559 .47999 L .54888 .48407 L F
.5139 .12644 m .50152 .12419 L .50397 .12939 L .891 .94 0 r
F
.51389 .12653 m .50151 .12423 L .50396 .12944 L .889 .938 0 r
F
.4646 .84375 m .46456 .83952 L .42324 .83879 L .884 .075 0 r
F
.5054 .8432 m .46456 .83952 L .4646 .84375 L .825 .069 0 r
F
.5054 .8432 m .50588 .83897 L .46456 .83952 L F
.56385 .60251 m .52946 .59591 L .52976 .60053 L 1 .615 0 r
F
.56408 .60705 m .56385 .60251 L .52976 .60053 L 1 .604 0 r
F
.59866 .60673 m .56385 .60251 L .56408 .60705 L .932 .475 0 r
F
.59866 .60673 m .59861 .60228 L .56385 .60251 L F
.15832 .57464 m .12393 .55425 L .12391 .56068 L 1 .82 0 r
F
.15845 .5809 m .15832 .57464 L .12391 .56068 L 1 .807 0 r
F
.52946 .59591 m .497 .58732 L .49721 .59203 L 1 .742 0 r
F
.52976 .60053 m .52946 .59591 L .49721 .59203 L 1 .732 0 r
F
.37388 .18562 m .37864 .183 L .37663 .20476 L .264 0 0 r
F
.37615 .175 m .37563 .18466 L .36943 .18381 L .085 0 0 r
F
.37615 .175 m .38097 .17224 L .37563 .18466 L F
.46857 .47386 m .44437 .46965 L .44421 .4732 L 1 .761 0 r
F
.46854 .47751 m .46857 .47386 L .44421 .4732 L 1 .753 0 r
F
.65562 .4035 m .63446 .4066 L .63347 .41219 L .401 .045 0 r
F
.65562 .4035 m .65689 .39775 L .63446 .4066 L F
.35773 .14978 m .35324 .1401 L .3473 .14342 L .994 1 0 r
F
.35773 .14978 m .3631 .14597 L .35324 .1401 L F
.68144 .35673 m .66329 .35981 L .66249 .3665 L .298 .032 0 r
F
.68144 .35673 m .68241 .34992 L .66329 .35981 L F
.80847 .30687 m .78527 .31818 L .78877 .32433 L .364 .238 0 r
F
.80847 .30687 m .8047 .30084 L .78527 .31818 L F
.62871 .43772 m .60501 .44026 L .6044 .44492 L .575 .066 0 r
F
.62871 .43772 m .6296 .43291 L .60501 .44026 L F
.14788 .59736 m .11452 .57608 L .11458 .5827 L 1 .823 0 r
F
.14803 .60386 m .14788 .59736 L .11458 .5827 L 1 .809 0 r
F
.11716 .46926 m .09015 .44461 L .08842 .45144 L 1 1 0 r
F
.11568 .47607 m .11716 .46926 L .08842 .45144 L F
.50016 .6849 m .46627 .68389 L .46621 .69016 L .919 .522 0 r
F
.50016 .6849 m .50008 .67913 L .46627 .68389 L F
.32358 .22308 m .33718 .24947 L .33465 .25554 L .36 .026 0 r
F
.72703 .20719 m .70803 .21618 L .71298 .22135 L .467 .491 0 r
F
.73225 .21218 m .72703 .20719 L .71298 .22135 L .461 .478 0 r
F
.30178 .72871 m .25814 .72282 L .2595 .72795 L 1 .455 0 r
F
.30276 .73379 m .30178 .72871 L .2595 .72795 L 1 .444 0 r
F
.49944 .65031 m .4667 .64556 L .46662 .65194 L .986 .657 0 r
F
.4996 .65603 m .49944 .65031 L .46662 .65194 L .973 .635 0 r
F
.52976 .60053 m .49721 .59203 L .49742 .59684 L 1 .732 0 r
F
.53005 .60523 m .52976 .60053 L .49742 .59684 L 1 .722 0 r
F
.56408 .60705 m .52976 .60053 L .53005 .60523 L 1 .604 0 r
F
.72233 .20161 m .70348 .21054 L .70852 .21564 L .479 .508 0 r
F
.72764 .20653 m .72233 .20161 L .70852 .21564 L .472 .495 0 r
F
.81707 .31846 m .79339 .32995 L .79678 .33619 L .357 .216 0 r
F
.81707 .31846 m .81342 .31233 L .79339 .32995 L F
.29098 .78062 m .24983 .7684 L .25165 .77361 L 1 .37 0 r
F
.29251 .78565 m .29098 .78062 L .25165 .77361 L 1 .35 0 r
F
.38036 .82795 m .33807 .81995 L .3395 .82455 L 1 .195 0 r
F
.38136 .83241 m .38036 .82795 L .3395 .82455 L 1 .175 0 r
F
.72605 .44212 m .69928 .4487 L .69948 .45395 L .464 .073 0 r
F
.72605 .44212 m .72577 .43678 L .69928 .4487 L F
.84909 .52819 m .81918 .53769 L .81956 .54434 L .312 .052 0 r
F
.84909 .52819 m .84869 .52147 L .81918 .53769 L F
.85393 .53556 m .82311 .545 L .82349 .55172 L .321 .054 0 r
F
.85393 .53556 m .8535 .52875 L .82311 .545 L F
.14085 .61332 m .10583 .59201 L .10617 .59874 L 1 .786 0 r
F
.14125 .6199 m .14085 .61332 L .10617 .59874 L 1 .772 0 r
F
.72044 .76738 m .68424 .77002 L .68248 .77528 L .477 .04 0 r
F
.72044 .76738 m .72252 .762 L .68424 .77002 L F
.26696 .23194 m .26199 .22129 L .2558 .22423 L 1 1 0 r
F
.26696 .23194 m .27218 .22785 L .26199 .22129 L F
.67177 .79096 m .63508 .79251 L .63344 .79728 L .54 .042 0 r
F
.67177 .79096 m .6738 .78611 L .63508 .79251 L F
.35799 .15056 m .35362 .1412 L .34765 .14437 L .988 1 0 r
F
.35799 .15056 m .36337 .14678 L .35362 .1412 L F
.81215 .31296 m .78877 .32433 L .79218 .33052 L .359 .223 0 r
F
.81215 .31296 m .80847 .30687 L .78877 .32433 L F
.1342 .44323 m .11005 .41947 L .10786 .42599 L 1 1 0 r
F
.13229 .44979 m .1342 .44323 L .10786 .42599 L F
.46854 .47751 m .44421 .4732 L .44405 .47673 L 1 .753 0 r
F
.46851 .48113 m .46854 .47751 L .44405 .47673 L 1 .745 0 r
F
.53005 .60523 m .49742 .59684 L .49763 .60176 L 1 .722 0 r
F
.53034 .60998 m .53005 .60523 L .49763 .60176 L 1 .71 0 r
F
.56429 .61163 m .53005 .60523 L .53034 .60998 L 1 .593 0 r
F
.56429 .61163 m .56408 .60705 L .53005 .60523 L F
.81361 .64188 m .78098 .64879 L .78002 .655 L .343 .039 0 r
F
.81361 .64188 m .81468 .63557 L .78098 .64879 L F
.4234 .82941 m .38169 .82287 L .38269 .82723 L .953 .137 0 r
F
.42393 .83364 m .4234 .82941 L .38269 .82723 L .944 .118 0 r
F
.46466 .83444 m .4234 .82941 L .42393 .83364 L .89 .079 0 r
F
.73381 .33807 m .71416 .34443 L .71545 .35056 L .31 .065 0 r
F
.73381 .33807 m .73245 .33195 L .71416 .34443 L F
.30251 .17612 m .29661 .16227 L .29093 .16659 L 1 1 0 r
F
.30251 .17612 m .30791 .17171 L .29661 .16227 L F
.72174 .20227 m .70302 .21107 L .70803 .21618 L .474 .504 0 r
F
.72703 .20719 m .72174 .20227 L .70803 .21618 L .467 .491 0 r
F
.63303 .59084 m .59835 .58902 L .59845 .59343 L .85 .367 0 r
F
.63303 .59084 m .63313 .58643 L .59835 .58902 L F
.66732 .55898 m .63338 .55996 L .63338 .56438 L .759 .273 0 r
F
.66732 .55898 m .66749 .55447 L .63338 .55996 L F
.59869 .61119 m .56408 .60705 L .56429 .61163 L .924 .463 0 r
F
.59869 .61119 m .59866 .60673 L .56408 .60705 L F
.69502 .27646 m .67891 .2796 L .68046 .28655 L .275 .059 0 r
F
.69502 .27646 m .69347 .26949 L .67891 .2796 L F
.46598 .72042 m .42931 .72339 L .42928 .72927 L .894 .437 0 r
F
.46598 .72042 m .46602 .71454 L .42931 .72339 L F
.54846 .49886 m .52156 .49777 L .52154 .50135 L .91 .41 0 r
F
.54846 .49886 m .54857 .49523 L .52156 .49777 L F
.20385 .65758 m .16433 .64204 L .16537 .64798 L 1 .633 0 r
F
.20485 .66328 m .20385 .65758 L .16537 .64798 L 1 .62 0 r
F
.82063 .32463 m .79678 .33619 L .80007 .34246 L .353 .202 0 r
F
.82063 .32463 m .81707 .31846 L .79678 .33619 L F
.71695 .19675 m .69837 .2055 L .70348 .21054 L .486 .522 0 r
F
.72233 .20161 m .71695 .19675 L .70348 .21054 L .479 .508 0 r
F
.50021 .69064 m .46621 .69016 L .46616 .69638 L .909 .498 0 r
F
.50021 .69064 m .50016 .6849 L .46621 .69016 L F
.49927 .64462 m .46678 .63922 L .4667 .64556 L .999 .679 0 r
F
.49944 .65031 m .49927 .64462 L .4667 .64556 L .986 .657 0 r
F
.14268 .43084 m .11774 .40713 L .11557 .41358 L 1 1 0 r
F
.14082 .43729 m .14268 .43084 L .11557 .41358 L F
.53034 .60998 m .49763 .60176 L .49784 .60679 L 1 .71 0 r
F
.53062 .6148 m .53034 .60998 L .49784 .60679 L 1 .698 0 r
F
.56449 .61623 m .53034 .60998 L .53062 .6148 L .998 .581 0 r
F
.56449 .61623 m .56429 .61163 L .53034 .60998 L F
.38965 .73849 m .34731 .74042 L .34794 .74556 L .972 .433 0 r
F
.38991 .74393 m .38965 .73849 L .34794 .74556 L .973 .416 0 r
F
.4293 .73503 m .38965 .73849 L .38991 .74393 L .923 .424 0 r
F
.4293 .73503 m .42928 .72927 L .38965 .73849 L F
.33738 .80553 m .29575 .79551 L .29745 .80034 L 1 .274 0 r
F
.33872 .81019 m .33738 .80553 L .29745 .80034 L 1 .254 0 r
F
.34731 .74042 m .30379 .73883 L .30487 .74382 L 1 .429 0 r
F
.34794 .74556 m .34731 .74042 L .30487 .74382 L 1 .416 0 r
F
.81745 .65063 m .78395 .65722 L .78297 .66351 L .353 .041 0 r
F
.81745 .65063 m .81855 .64422 L .78395 .65722 L F
.81573 .31909 m .79218 .33052 L .7955 .33675 L .355 .208 0 r
F
.81573 .31909 m .81215 .31296 L .79218 .33052 L F
.46695 .62675 m .43526 .6228 L .43453 .62985 L .986 .76 0 r
F
.46687 .63294 m .46695 .62675 L .43453 .62985 L .973 .737 0 r
F
.60169 .46658 m .5764 .46807 L .57612 .47211 L .714 .166 0 r
F
.60169 .46658 m .60218 .46244 L .5764 .46807 L F
.46851 .48113 m .44405 .47673 L .4439 .48024 L 1 .745 0 r
F
.46848 .48472 m .46851 .48113 L .4439 .48024 L 1 .737 0 r
F
.54571 .8414 m .50588 .83897 L .5054 .8432 L .757 .061 0 r
F
.54571 .8414 m .5467 .83714 L .50588 .83897 L F
.71637 .19742 m .69793 .20603 L .70302 .21107 L .48 .517 0 r
F
.72174 .20227 m .71637 .19742 L .70302 .21107 L .474 .504 0 r
F
.53062 .6148 m .49784 .60679 L .49806 .61193 L 1 .698 0 r
F
.5309 .61968 m .53062 .6148 L .49806 .61193 L 1 .684 0 r
F
.56468 .62087 m .53062 .6148 L .5309 .61968 L .988 .568 0 r
F
.56468 .62087 m .56449 .61623 L .53062 .6148 L F
.57509 .4876 m .54878 .48784 L .54868 .49156 L .82 .297 0 r
F
.57509 .4876 m .57534 .48382 L .54878 .48784 L F
.30723 .17041 m .30172 .15681 L .29573 .16066 L 1 1 0 r
F
.30723 .17041 m .31279 .16622 L .30172 .15681 L F
.69983 .51373 m .66818 .51778 L .66815 .52244 L .638 .173 0 r
F
.69983 .51373 m .69993 .50894 L .66818 .51778 L F
.37388 .18562 m .37663 .20476 L .37019 .20256 L .264 0 0 r
F
.82409 .33085 m .80007 .34246 L .80328 .34877 L .349 .187 0 r
F
.82409 .33085 m .82063 .32463 L .80007 .34246 L F
.71149 .19198 m .6932 .20053 L .69837 .2055 L .493 .535 0 r
F
.71695 .19675 m .71149 .19198 L .69837 .2055 L .486 .522 0 r
F
.28961 .7906 m .24783 .7787 L .24976 .78392 L 1 .35 0 r
F
.29122 .79565 m .28961 .7906 L .24976 .78392 L 1 .33 0 r
F
.494 .48443 m .49395 .48083 L .46871 .48109 L 1 .809 0 r
F
.58655 .83405 m .54766 .8328 L .5467 .83714 L .69 .054 0 r
F
.58655 .83405 m .588 .82966 L .54766 .8328 L F
.81921 .32527 m .7955 .33675 L .79873 .34302 L .35 .193 0 r
F
.81921 .32527 m .81573 .31909 L .7955 .33675 L F
.62876 .82071 m .59079 .82065 L .58941 .8252 L .621 .048 0 r
F
.62876 .82071 m .63059 .8161 L .59079 .82065 L F
.76568 .71473 m .73144 .71947 L .72985 .72512 L .388 .035 0 r
F
.76568 .71473 m .7675 .70897 L .73144 .71947 L F
.11568 .47607 m .08842 .45144 L .08679 .4583 L 1 1 0 r
F
.1143 .4829 m .11568 .47607 L .08679 .4583 L F
.5309 .61968 m .49806 .61193 L .49827 .61716 L 1 .684 0 r
F
.53117 .62461 m .5309 .61968 L .49827 .61716 L 1 .669 0 r
F
.56485 .62554 m .5309 .61968 L .53117 .62461 L .979 .555 0 r
F
.56485 .62554 m .56468 .62087 L .5309 .61968 L F
.46848 .48472 m .4439 .48024 L .44376 .48374 L 1 .737 0 r
F
.46845 .48829 m .46848 .48472 L .44376 .48374 L 1 .729 0 r
F
.49909 .63899 m .46687 .63294 L .46678 .63922 L 1 .7 0 r
F
.49927 .64462 m .49909 .63899 L .46678 .63922 L .999 .679 0 r
F
.59871 .61566 m .56429 .61163 L .56449 .61623 L .916 .451 0 r
F
.59871 .61566 m .59869 .61119 L .56429 .61163 L F
.13229 .44979 m .10786 .42599 L .10576 .43254 L 1 1 0 r
F
.13049 .45637 m .13229 .44979 L .10576 .43254 L F
.50024 .69636 m .46616 .69638 L .46611 .70252 L .9 .475 0 r
F
.50024 .69636 m .50021 .69064 L .46616 .69638 L F
.71094 .19265 m .69278 .20106 L .69793 .20603 L .487 .53 0 r
F
.71637 .19742 m .71094 .19265 L .69793 .20603 L .48 .517 0 r
F
.27218 .22785 m .26832 .21866 L .26199 .22129 L .923 1 0 r
F
.27218 .22785 m .27747 .22392 L .26832 .21866 L F
.73508 .34415 m .71545 .35056 L .71665 .35666 L .304 .063 0 r
F
.73508 .34415 m .73381 .33807 L .71545 .35056 L F
.18917 .70162 m .15031 .68405 L .15173 .69026 L 1 .596 0 r
F
.19048 .70765 m .18917 .70162 L .15173 .69026 L 1 .579 0 r
F
.72629 .44741 m .69948 .45395 L .69964 .45916 L .463 .072 0 r
F
.72629 .44741 m .72605 .44212 L .69948 .45395 L F
.6329 .59524 m .59845 .59343 L .59854 .59785 L .843 .357 0 r
F
.6329 .59524 m .63303 .59084 L .59845 .59343 L F
.54835 .50244 m .52154 .50135 L .52151 .50489 L .906 .403 0 r
F
.54835 .50244 m .54846 .49886 L .52154 .50135 L F
.494 .48443 m .46871 .48109 L .46868 .48444 L 1 .809 0 r
F
.49406 .48801 m .494 .48443 L .46868 .48444 L 1 .81 0 r
F
.14082 .43729 m .11557 .41358 L .11351 .42005 L 1 1 0 r
F
.13906 .44377 m .14082 .43729 L .11351 .42005 L F
.30791 .17171 m .30241 .15812 L .29661 .16227 L F
.30791 .17171 m .31338 .1674 L .30241 .15812 L F
.82746 .33712 m .80328 .34877 L .8064 .35512 L .344 .173 0 r
F
.82746 .33712 m .82409 .33085 L .80328 .34877 L F
.70597 .18728 m .68796 .19564 L .6932 .20053 L .5 .548 0 r
F
.71149 .19198 m .70597 .18728 L .6932 .20053 L .493 .535 0 r
F
.69628 .2835 m .68046 .28655 L .68174 .29355 L .258 .052 0 r
F
.69628 .2835 m .69502 .27646 L .68046 .28655 L F
.53117 .62461 m .49827 .61716 L .49848 .6225 L 1 .669 0 r
F
.53143 .6296 m .53117 .62461 L .49848 .6225 L 1 .654 0 r
F
.565 .63024 m .53117 .62461 L .53143 .6296 L .969 .54 0 r
F
.565 .63024 m .56485 .62554 L .53117 .62461 L F
.15845 .5809 m .12391 .56068 L .12399 .5671 L 1 .807 0 r
F
.15867 .58714 m .15845 .5809 L .12399 .5671 L 1 .794 0 r
F
.66713 .56348 m .63338 .56438 L .63336 .56879 L .753 .265 0 r
F
.66713 .56348 m .66732 .55898 L .63338 .56438 L F
.26515 .24004 m .37443 .36524 L .37178 .36676 L .697 .193 0 r
F
.26515 .24004 m .27228 .2384 L .37443 .36524 L F
.67274 .80062 m .63576 .80181 L .63409 .80665 L .548 .043 0 r
F
.67274 .80062 m .67482 .79569 L .63576 .80181 L F
.82259 .33149 m .79873 .34302 L .80187 .34933 L .346 .177 0 r
F
.82259 .33149 m .81921 .32527 L .79873 .34302 L F
.46845 .48829 m .44376 .48374 L .44363 .48723 L 1 .729 0 r
F
.46842 .49184 m .46845 .48829 L .44363 .48723 L 1 .72 0 r
F
.84938 .53491 m .81956 .54434 L .81984 .55099 L .307 .049 0 r
F
.84938 .53491 m .84909 .52819 L .81956 .54434 L F
.85425 .54237 m .82349 .55172 L .82378 .55844 L .317 .051 0 r
F
.85425 .54237 m .85393 .53556 L .82349 .55172 L F
.14803 .60386 m .11458 .5827 L .11474 .5893 L 1 .809 0 r
F
.14828 .61034 m .14803 .60386 L .11474 .5893 L 1 .795 0 r
F
.49909 .63899 m .49889 .63341 L .46687 .63294 L 1 .7 0 r
F
.53191 .63972 m .49889 .63341 L .49909 .63899 L .999 .62 0 r
F
.53213 .64484 m .49909 .63899 L .49927 .64462 L .987 .602 0 r
F
.53213 .64484 m .53191 .63972 L .49909 .63899 L F
.62784 .44239 m .6044 .44492 L .60381 .44946 L .57 .065 0 r
F
.62784 .44239 m .62871 .43772 L .6044 .44492 L F
.53232 .65 m .49927 .64462 L .49944 .65031 L .975 .583 0 r
F
.53232 .65 m .53213 .64484 L .49927 .64462 L F
.19342 .69139 m .15574 .67367 L .157 .67981 L 1 .62 0 r
F
.1946 .69737 m .19342 .69139 L .157 .67981 L 1 .603 0 r
F
.70543 .18794 m .68756 .19616 L .69278 .20106 L .493 .542 0 r
F
.71094 .19265 m .70543 .18794 L .69278 .20106 L .487 .53 0 r
F
.24323 .74694 m .20337 .73225 L .20511 .73789 L 1 .474 0 r
F
.24478 .75239 m .24323 .74694 L .20511 .73789 L 1 .456 0 r
F
.49889 .63341 m .46695 .62675 L .46687 .63294 L 1 .72 0 r
F
.49889 .63341 m .49869 .62791 L .46695 .62675 L F
.53168 .63463 m .49869 .62791 L .49889 .63341 L 1 .637 0 r
F
.53191 .63972 m .53168 .63463 L .49889 .63341 L .999 .62 0 r
F
.34133 .19219 m .34139 .19602 L .33489 .19642 L 0 0 0 r
F
.34133 .19219 m .34668 .18947 L .34139 .19602 L F
.7683 .72415 m .73341 .72849 L .73179 .73421 L .396 .037 0 r
F
.7683 .72415 m .77017 .7183 L .73341 .72849 L F
.49406 .48801 m .46868 .48444 L .46865 .48777 L 1 .81 0 r
F
.49412 .49158 m .49406 .48801 L .46865 .48777 L 1 .811 0 r
F
.5325 .65519 m .49944 .65031 L .4996 .65603 L .963 .564 0 r
F
.5325 .65519 m .53232 .65 L .49944 .65031 L F
.3631 .14597 m .35923 .13694 L .35324 .1401 L .974 1 0 r
F
.3631 .14597 m .36852 .14227 L .35923 .13694 L F
.4647 .83855 m .46466 .83444 L .42393 .83364 L .88 .074 0 r
F
.50491 .83801 m .46466 .83444 L .4647 .83855 L .818 .067 0 r
F
.50491 .83801 m .50539 .8339 L .46466 .83444 L F
.53143 .6296 m .49848 .6225 L .49869 .62791 L 1 .654 0 r
F
.53168 .63463 m .53143 .6296 L .49869 .62791 L 1 .637 0 r
F
.56513 .63496 m .53143 .6296 L .53168 .63463 L .958 .526 0 r
F
.56513 .63496 m .565 .63024 L .53143 .6296 L F
.5987 .62015 m .56449 .61623 L .56468 .62087 L .907 .439 0 r
F
.5987 .62015 m .59871 .61566 L .56449 .61623 L F
.32854 .21985 m .3398 .24331 L .33718 .24947 L .338 .019 0 r
F
.49869 .62791 m .46704 .62066 L .46695 .62675 L 1 .74 0 r
F
.49869 .62791 m .49848 .6225 L .46704 .62066 L F
.25437 .70721 m .21217 .69671 L .21361 .70215 L 1 .509 0 r
F
.25557 .71245 m .25437 .70721 L .21361 .70215 L 1 .497 0 r
F
.57485 .49133 m .54868 .49156 L .54857 .49523 L .816 .292 0 r
F
.57485 .49133 m .57509 .4876 L .54868 .49156 L F
.33667 .81527 m .29462 .80554 L .2964 .81037 L 1 .257 0 r
F
.33807 .81995 m .33667 .81527 L .2964 .81037 L 1 .236 0 r
F
.46595 .72621 m .42928 .72927 L .4293 .73503 L .89 .415 0 r
F
.46595 .72621 m .46598 .72042 L .42928 .72927 L F
.83073 .34343 m .8064 .35512 L .80942 .36151 L .34 .158 0 r
F
.83073 .34343 m .82746 .33712 L .8064 .35512 L F
.70037 .18265 m .68265 .19081 L .68796 .19564 L .507 .561 0 r
F
.70597 .18728 m .70037 .18265 L .68796 .19564 L .5 .548 0 r
F
.53265 .66041 m .4996 .65603 L .49975 .66179 L .95 .543 0 r
F
.53265 .66041 m .5325 .65519 L .4996 .65603 L F
.31279 .16622 m .30777 .15308 L .30172 .15681 L 1 1 0 r
F
.31279 .16622 m .31841 .16213 L .30777 .15308 L F
.65435 .40908 m .63347 .41219 L .63247 .41761 L .392 .043 0 r
F
.65435 .40908 m .65562 .4035 L .63347 .41219 L F
.68032 .36341 m .66249 .3665 L .66155 .37306 L .286 .027 0 r
F
.68032 .36341 m .68144 .35673 L .66249 .3665 L F
.60122 .47063 m .57612 .47211 L .57585 .47608 L .709 .164 0 r
F
.60122 .47063 m .60169 .46658 L .57612 .47211 L F
.50026 .70203 m .46611 .70252 L .46606 .70857 L .89 .451 0 r
F
.50026 .70203 m .50024 .69636 L .46611 .70252 L F
.43915 .58961 m .40636 .59224 L .40437 .59964 L .854 .731 0 r
F
.43837 .59586 m .43915 .58961 L .40437 .59964 L .846 .716 0 r
F
.69971 .5185 m .66815 .52244 L .66811 .52707 L .634 .166 0 r
F
.69971 .5185 m .69983 .51373 L .66815 .52244 L F
.49848 .6225 m .46712 .6147 L .46704 .62066 L 1 .758 0 r
F
.49848 .6225 m .49827 .61716 L .46712 .6147 L F
.46842 .49184 m .44363 .48723 L .4435 .4907 L 1 .72 0 r
F
.46839 .49537 m .46842 .49184 L .4435 .4907 L 1 .712 0 r
F
.82587 .33776 m .80187 .34933 L .80491 .35568 L .341 .162 0 r
F
.82587 .33776 m .82259 .33149 L .80187 .34933 L F
.13049 .45637 m .10576 .43254 L .10377 .43911 L 1 1 0 r
F
.12877 .46296 m .13049 .45637 L .10377 .43911 L F
.14125 .6199 m .10617 .59874 L .10661 .60545 L 1 .772 0 r
F
.14173 .62646 m .14125 .6199 L .10661 .60545 L 1 .757 0 r
F
.24081 .75716 m .20007 .74276 L .20195 .74842 L 1 .452 0 r
F
.24246 .76264 m .24081 .75716 L .20195 .74842 L 1 .433 0 r
F
.42324 .83879 m .38136 .83241 L .38239 .83679 L .946 .126 0 r
F
.42379 .84305 m .42324 .83879 L .38239 .83679 L .937 .106 0 r
F
.4646 .84375 m .42324 .83879 L .42379 .84305 L .884 .075 0 r
F
.51389 .12653 m .51062 .12157 L .50151 .12423 L .889 .938 0 r
F
.52318 .12328 m .51062 .12157 L .51389 .12653 L .843 .908 0 r
F
.52717 .12806 m .52318 .12328 L .51389 .12653 L .845 .9 0 r
F
.49412 .49158 m .46865 .48777 L .46862 .49109 L 1 .811 0 r
F
.49419 .49513 m .49412 .49158 L .46862 .49109 L 1 .813 0 r
F
.36337 .14678 m .35967 .13827 L .35362 .1412 L .962 1 0 r
F
.36337 .14678 m .36879 .14313 L .35967 .13827 L F
.71664 .76301 m .68129 .76601 L .67951 .77114 L .457 .036 0 r
F
.71664 .76301 m .71876 .75778 L .68129 .76601 L F
.73625 .35019 m .71665 .35666 L .71775 .36271 L .3 .061 0 r
F
.73625 .35019 m .73508 .34415 L .71665 .35666 L F
.54823 .50598 m .52151 .50489 L .52148 .5084 L .901 .397 0 r
F
.54823 .50598 m .54835 .50244 L .52151 .50489 L F
.69986 .18331 m .68228 .19132 L .68756 .19616 L .5 .555 0 r
F
.70543 .18794 m .69986 .18331 L .68756 .19616 L .493 .542 0 r
F
.38169 .82287 m .3401 .81478 L .34152 .81929 L 1 .19 0 r
F
.38269 .82723 m .38169 .82287 L .34152 .81929 L 1 .169 0 r
F
.1143 .4829 m .08679 .4583 L .08528 .46517 L 1 1 0 r
F
.11302 .48974 m .1143 .4829 L .08528 .46517 L 1 .991 0 r
F
.49827 .61716 m .46721 .60888 L .46712 .6147 L 1 .776 0 r
F
.49827 .61716 m .49806 .61193 L .46721 .60888 L F
.63275 .59965 m .59854 .59785 L .59861 .60228 L .835 .346 0 r
F
.63275 .59965 m .6329 .59524 L .59854 .59785 L F
.56524 .63971 m .53168 .63463 L .53191 .63972 L .948 .51 0 r
F
.56524 .63971 m .56513 .63496 L .53168 .63463 L F
.53278 .66564 m .49975 .66179 L .49988 .66757 L .938 .523 0 r
F
.53278 .66564 m .53265 .66041 L .49975 .66179 L F
.13906 .44377 m .11351 .42005 L .11155 .42655 L 1 1 0 r
F
.13739 .45025 m .13906 .44377 L .11155 .42655 L F
.46704 .62066 m .43602 .61584 L .43526 .6228 L 1 .783 0 r
F
.46695 .62675 m .46704 .62066 L .43526 .6228 L .986 .76 0 r
F
.27747 .22392 m .27477 .21632 L .26832 .21866 L .811 .87 0 r
F
.27747 .22392 m .28188 .22082 L .27608 .22001 L F
.26834 .21893 m .27831 .22282 L .26844 .22019 L .159 0 0 r
F
.26832 .21866 m .26931 .21907 L .26834 .21893 L F
.26931 .21907 m .27831 .22282 L .26834 .21893 L F
.27608 .22001 m .28284 .22015 L .27477 .21632 L .811 .87 0 r
F
.28188 .22082 m .28284 .22015 L .27608 .22001 L F
.81243 .64816 m .78002 .655 L .77898 .66117 L .339 .036 0 r
F
.81243 .64816 m .81361 .64188 L .78002 .655 L F
.72649 .45266 m .69964 .45916 L .69977 .46432 L .462 .072 0 r
F
.72649 .45266 m .72629 .44741 L .69964 .45916 L F
.49419 .49513 m .46862 .49109 L .46859 .49439 L 1 .813 0 r
F
.49425 .49867 m .49419 .49513 L .46859 .49439 L 1 .815 0 r
F
.49806 .61193 m .46729 .60321 L .46721 .60888 L 1 .793 0 r
F
.49806 .61193 m .49784 .60679 L .46729 .60321 L F
.31338 .1674 m .3083 .15413 L .30241 .15812 L 1 1 0 r
F
.31338 .1674 m .31892 .1632 L .3083 .15413 L F
.30276 .73379 m .2595 .72795 L .26092 .73304 L 1 .444 0 r
F
.30379 .73883 m .30276 .73379 L .26092 .73304 L 1 .432 0 r
F
.8339 .34978 m .80942 .36151 L .81236 .36793 L .336 .144 0 r
F
.8339 .34978 m .83073 .34343 L .80942 .36151 L F
.37864 .183 m .38362 .20931 L .37663 .20476 L .341 .023 0 r
F
.37864 .183 m .3835 .18085 L .38362 .20931 L F
.38097 .17224 m .38217 .18712 L .37563 .18466 L .241 0 0 r
F
.3835 .18085 m .39118 .21673 L .38362 .20931 L .39 .04 0 r
F
.3835 .18085 m .38846 .17928 L .39118 .21673 L F
.38097 .17224 m .38587 .16985 L .38217 .18712 L .241 0 0 r
F
.46839 .49537 m .4435 .4907 L .44338 .49416 L 1 .712 0 r
F
.46836 .49887 m .46839 .49537 L .44338 .49416 L 1 .704 0 r
F
.69471 .1781 m .67728 .18605 L .68265 .19081 L .514 .574 0 r
F
.70037 .18265 m .69471 .1781 L .68265 .19081 L .507 .561 0 r
F
.66691 .56796 m .63336 .56879 L .63333 .57321 L .748 .256 0 r
F
.66691 .56796 m .66713 .56348 L .63336 .56879 L F
.69726 .29059 m .68174 .29355 L .68275 .3006 L .239 .045 0 r
F
.69726 .29059 m .69628 .2835 L .68174 .29355 L F
.59867 .62464 m .56468 .62087 L .56485 .62554 L .898 .425 0 r
F
.59867 .62464 m .5987 .62015 L .56468 .62087 L F
.82905 .34407 m .80491 .35568 L .80786 .36206 L .336 .147 0 r
F
.82905 .34407 m .82587 .33776 L .80491 .35568 L F
.47947 .2388 m .48051 .18444 L .47237 .13248 L .673 .166 0 r
F
.20485 .66328 m .16537 .64798 L .16648 .65388 L 1 .62 0 r
F
.20591 .66895 m .20485 .66328 L .16648 .65388 L 1 .607 0 r
F
.38991 .74393 m .34794 .74556 L .34863 .75064 L .973 .416 0 r
F
.39021 .74927 m .38991 .74393 L .34863 .75064 L .973 .399 0 r
F
.42935 .74068 m .38991 .74393 L .39021 .74927 L .922 .405 0 r
F
.42935 .74068 m .4293 .73503 L .38991 .74393 L F
.53289 .67089 m .49988 .66757 L .49999 .67335 L .926 .501 0 r
F
.53289 .67089 m .53278 .66564 L .49988 .66757 L F
.54463 .83615 m .50539 .8339 L .50491 .83801 L .748 .059 0 r
F
.54463 .83615 m .54562 .83203 L .50539 .8339 L F
.81625 .65702 m .78297 .66351 L .78191 .66977 L .349 .039 0 r
F
.81625 .65702 m .81745 .65063 L .78297 .66351 L F
.56533 .64448 m .53191 .63972 L .53213 .64484 L .937 .493 0 r
F
.56533 .64448 m .56524 .63971 L .53191 .63972 L F
.49784 .60679 m .46737 .5977 L .46729 .60321 L 1 .808 0 r
F
.49784 .60679 m .49763 .60176 L .46737 .5977 L F
.69422 .17876 m .67693 .18656 L .68228 .19132 L .506 .567 0 r
F
.69986 .18331 m .69422 .17876 L .68228 .19132 L .5 .555 0 r
F
.49425 .49867 m .46859 .49439 L .46856 .49767 L 1 .815 0 r
F
.49431 .5022 m .49425 .49867 L .46856 .49767 L 1 .817 0 r
F
.5746 .495 m .54857 .49523 L .54846 .49886 L .811 .287 0 r
F
.5746 .495 m .57485 .49133 L .54857 .49523 L F
.50025 .70766 m .46606 .70857 L .46602 .71454 L .881 .428 0 r
F
.50025 .70766 m .50026 .70203 L .46606 .70857 L F
.34794 .74556 m .30487 .74382 L .306 .74878 L 1 .416 0 r
F
.34863 .75064 m .34794 .74556 L .306 .74878 L 1 .402 0 r
F
.58485 .82882 m .54658 .82782 L .54562 .83203 L .678 .052 0 r
F
.58485 .82882 m .58631 .82458 L .54658 .82782 L F
.12877 .46296 m .10377 .43911 L .10188 .44571 L 1 1 0 r
F
.12715 .46958 m .12877 .46296 L .10188 .44571 L F
.46836 .49887 m .44338 .49416 L .44326 .4976 L 1 .704 0 r
F
.46834 .50235 m .46836 .49887 L .44326 .4976 L 1 .695 0 r
F
.6264 .81561 m .5891 .81585 L .58772 .82025 L .606 .045 0 r
F
.6264 .81561 m .62823 .81114 L .5891 .81585 L F
.49763 .60176 m .46745 .59237 L .46737 .5977 L 1 .822 0 r
F
.49763 .60176 m .49742 .59684 L .46745 .59237 L F
.51062 .12157 m .49904 .11912 L .50151 .12423 L .885 .944 0 r
F
.84957 .54162 m .81984 .55099 L .82003 .55762 L .302 .047 0 r
F
.84957 .54162 m .84938 .53491 L .81984 .55099 L F
.54811 .50949 m .52148 .5084 L .52144 .51188 L .896 .39 0 r
F
.54811 .50949 m .54823 .50598 L .52148 .5084 L F
.83698 .35617 m .81236 .36793 L .8152 .37439 L .331 .129 0 r
F
.83698 .35617 m .8339 .34978 L .81236 .36793 L F
.15867 .58714 m .12399 .5671 L .12417 .5735 L 1 .794 0 r
F
.15897 .59336 m .15867 .58714 L .12417 .5735 L 1 .781 0 r
F
.85446 .54918 m .82378 .55844 L .82397 .56515 L .313 .049 0 r
F
.85446 .54918 m .85425 .54237 L .82378 .55844 L F
.68897 .17364 m .67184 .18137 L .67728 .18605 L .521 .587 0 r
F
.69471 .1781 m .68897 .17364 L .67728 .18605 L .514 .574 0 r
F
.49431 .5022 m .46856 .49767 L .46854 .50095 L 1 .817 0 r
F
.49438 .50573 m .49431 .5022 L .46854 .50095 L 1 .82 0 r
F
.53296 .67614 m .49999 .67335 L .50008 .67913 L .913 .48 0 r
F
.53296 .67614 m .53289 .67089 L .49999 .67335 L F
.69956 .52324 m .66811 .52707 L .66805 .53168 L .631 .16 0 r
F
.69956 .52324 m .69971 .5185 L .66811 .52707 L F
.83213 .35042 m .80786 .36206 L .81071 .36847 L .332 .131 0 r
F
.83213 .35042 m .82905 .34407 L .80786 .36206 L F
.31841 .16213 m .31388 .14946 L .30777 .15308 L 1 1 0 r
F
.31841 .16213 m .32408 .15815 L .31388 .14946 L F
.73734 .35617 m .71775 .36271 L .71876 .36872 L .295 .059 0 r
F
.73734 .35617 m .73625 .35019 L .71775 .36271 L F
.71827 .77269 m .68248 .77528 L .68067 .78049 L .468 .038 0 r
F
.71827 .77269 m .72044 .76738 L .68248 .77528 L F
.63258 .60405 m .59861 .60228 L .59866 .60673 L .828 .334 0 r
F
.63258 .60405 m .63275 .59965 L .59861 .60228 L F
.29251 .78565 m .25165 .77361 L .25354 .77875 L 1 .35 0 r
F
.2941 .79061 m .29251 .78565 L .25354 .77875 L 1 .33 0 r
F
.13739 .45025 m .11155 .42655 L .1097 .43306 L 1 1 0 r
F
.13582 .45675 m .13739 .45025 L .1097 .43306 L F
.5654 .64927 m .53213 .64484 L .53232 .65 L .925 .476 0 r
F
.5654 .64927 m .56533 .64448 L .53213 .64484 L F
.60076 .4746 m .57585 .47608 L .57559 .47999 L .704 .161 0 r
F
.60076 .4746 m .60122 .47063 L .57585 .47608 L F
.62702 .44694 m .60381 .44946 L .60324 .45389 L .565 .065 0 r
F
.62702 .44694 m .62784 .44239 L .60381 .44946 L F
.59861 .62915 m .56485 .62554 L .565 .63024 L .889 .412 0 r
F
.59861 .62915 m .59867 .62464 L .56485 .62554 L F
.68852 .17428 m .67151 .18186 L .67693 .18656 L .513 .58 0 r
F
.69422 .17876 m .68852 .17428 L .67693 .18656 L .506 .567 0 r
F
.49742 .59684 m .46753 .58721 L .46745 .59237 L 1 .835 0 r
F
.49742 .59684 m .49721 .59203 L .46753 .58721 L F
.14828 .61034 m .11474 .5893 L .115 .59589 L 1 .795 0 r
F
.14861 .6168 m .14828 .61034 L .115 .59589 L 1 .781 0 r
F
.11302 .48974 m .08528 .46517 L .08387 .47205 L 1 .991 0 r
F
.11183 .49658 m .11302 .48974 L .08387 .47205 L 1 .98 0 r
F
.49438 .50573 m .46854 .50095 L .46851 .50422 L 1 .82 0 r
F
.49445 .50926 m .49438 .50573 L .46851 .50422 L 1 .823 0 r
F
.66968 .79574 m .63344 .79728 L .63176 .80197 L .531 .04 0 r
F
.66968 .79574 m .67177 .79096 L .63344 .79728 L F
.28284 .22015 m .28131 .21427 L .27477 .21632 L .669 .626 0 r
F
.28284 .22015 m .28828 .21654 L .28131 .21427 L F
.46704 .62066 m .46712 .6147 L .43602 .61584 L 1 .783 0 r
F
.46834 .50235 m .44326 .4976 L .44315 .50103 L 1 .695 0 r
F
.46831 .50581 m .46834 .50235 L .44315 .50103 L 1 .687 0 r
F
.33341 .21655 m .34284 .23766 L .3398 .24331 L .321 .013 0 r
F
.46592 .73189 m .4293 .73503 L .42935 .74068 L .886 .392 0 r
F
.46592 .73189 m .46595 .72621 L .4293 .73503 L F
.72666 .45786 m .69977 .46432 L .69989 .46943 L .461 .071 0 r
F
.72666 .45786 m .72649 .45266 L .69977 .46432 L F
.31892 .1632 m .31428 .15029 L .3083 .15413 L 1 1 0 r
F
.31892 .1632 m .32452 .15912 L .31428 .15029 L F
.66667 .57243 m .63333 .57321 L .63329 .57762 L .742 .247 0 r
F
.66667 .57243 m .66691 .56796 L .63333 .57321 L F
.76377 .72043 m .72985 .72512 L .72819 .73071 L .384 .033 0 r
F
.76377 .72043 m .76568 .71473 L .72985 .72512 L F
.46463 .84791 m .4646 .84375 L .42379 .84305 L .874 .073 0 r
F
.50491 .84736 m .4646 .84375 L .46463 .84791 L .815 .066 0 r
F
.50491 .84736 m .5054 .8432 L .4646 .84375 L F
.49721 .59203 m .4676 .58223 L .46753 .58721 L 1 .845 0 r
F
.49721 .59203 m .497 .58732 L .4676 .58223 L F
.19048 .70765 m .15173 .69026 L .15325 .69642 L 1 .579 0 r
F
.19188 .71363 m .19048 .70765 L .15325 .69642 L 1 .562 0 r
F
.36852 .14227 m .36527 .13396 L .35923 .13694 L .95 1 0 r
F
.36852 .14227 m .37399 .1387 L .36527 .13396 L F
.49445 .50926 m .46851 .50422 L .46848 .50748 L 1 .823 0 r
F
.49452 .5128 m .49445 .50926 L .46848 .50748 L 1 .827 0 r
F
.83995 .3626 m .8152 .37439 L .81795 .38087 L .327 .115 0 r
F
.83995 .3626 m .83698 .35617 L .8152 .37439 L F
.53301 .6814 m .50008 .67913 L .50016 .6849 L .901 .457 0 r
F
.53301 .6814 m .53296 .67614 L .50008 .67913 L F
.68317 .16925 m .66634 .17677 L .67184 .18137 L .528 .6 0 r
F
.68897 .17364 m .68317 .16925 L .67184 .18137 L .521 .587 0 r
F
.8351 .35681 m .81071 .36847 L .81347 .37492 L .327 .116 0 r
F
.8351 .35681 m .83213 .35042 L .81071 .36847 L F
.69794 .29772 m .68275 .3006 L .68349 .30769 L .22 .038 0 r
F
.69794 .29772 m .69726 .29059 L .68275 .3006 L F
.38136 .83241 m .3395 .82455 L .34098 .82907 L 1 .175 0 r
F
.38239 .83679 m .38136 .83241 L .34098 .82907 L .992 .154 0 r
F
.56543 .65407 m .53232 .65 L .5325 .65519 L .914 .458 0 r
F
.56543 .65407 m .5654 .64927 L .53232 .65 L F
.27228 .2384 m .37704 .3637 L .37443 .36524 L .711 .197 0 r
F
.27228 .2384 m .28083 .23883 L .37704 .3637 L F
.34668 .18947 m .34822 .1967 L .34139 .19602 L .129 0 0 r
F
.34668 .18947 m .35213 .18714 L .34822 .1967 L F
.14173 .62646 m .10661 .60545 L .10716 .61213 L 1 .757 0 r
F
.14232 .63299 m .14173 .62646 L .10716 .61213 L 1 .742 0 r
F
.497 .58732 m .46767 .57743 L .4676 .58223 L 1 .855 0 r
F
.497 .58732 m .49681 .58272 L .46767 .57743 L F
.57436 .49862 m .54846 .49886 L .54835 .50244 L .806 .282 0 r
F
.57436 .49862 m .5746 .495 L .54846 .49886 L F
.1946 .69737 m .157 .67981 L .15834 .68592 L 1 .603 0 r
F
.19586 .7033 m .1946 .69737 L .15834 .68592 L 1 .586 0 r
F
.12715 .46958 m .10188 .44571 L .1001 .45233 L 1 1 0 r
F
.12563 .4762 m .12715 .46958 L .1001 .45233 L F
.68275 .16988 m .66604 .17724 L .67151 .18186 L .519 .592 0 r
F
.68852 .17428 m .68275 .16988 L .67151 .18186 L .513 .58 0 r
F
.54799 .51295 m .52144 .51188 L .5214 .51533 L .892 .383 0 r
F
.54799 .51295 m .54811 .50949 L .52144 .51188 L F
.33872 .81019 m .29745 .80034 L .2992 .80509 L 1 .254 0 r
F
.3401 .81478 m .33872 .81019 L .2992 .80509 L 1 .233 0 r
F
.49452 .5128 m .46848 .50748 L .46845 .51074 L 1 .827 0 r
F
.4946 .51634 m .49452 .5128 L .46845 .51074 L 1 .831 0 r
F
.65309 .41448 m .63247 .41761 L .63149 .42286 L .387 .042 0 r
F
.65309 .41448 m .65435 .40908 L .63247 .41761 L F
.36879 .14313 m .36576 .13554 L .35967 .13827 L .929 1 0 r
F
.36879 .14313 m .37425 .13962 L .36576 .13554 L F
.67906 .36995 m .66155 .37306 L .66049 .37947 L .275 .023 0 r
F
.67906 .36995 m .68032 .36341 L .66155 .37306 L F
.42393 .83364 m .38269 .82723 L .38371 .83151 L .944 .118 0 r
F
.42448 .83778 m .42393 .83364 L .38371 .83151 L .934 .098 0 r
F
.4647 .83855 m .42393 .83364 L .42448 .83778 L .88 .074 0 r
F
.50022 .71324 m .46602 .71454 L .46598 .72042 L .872 .404 0 r
F
.50022 .71324 m .50025 .70766 L .46602 .71454 L F
.46831 .50581 m .44315 .50103 L .44305 .50444 L 1 .687 0 r
F
.46828 .50925 m .46831 .50581 L .44305 .50444 L 1 .678 0 r
F
.46712 .6147 m .4368 .60901 L .43602 .61584 L 1 .806 0 r
F
.59853 .63366 m .565 .63024 L .56513 .63496 L .879 .397 0 r
F
.59853 .63366 m .59861 .62915 L .565 .63024 L F
.63237 .60845 m .59866 .60673 L .59869 .61119 L .82 .322 0 r
F
.63237 .60845 m .63258 .60405 L .59866 .60673 L F
.29122 .79565 m .24976 .78392 L .25176 .78907 L 1 .33 0 r
F
.29289 .80063 m .29122 .79565 L .25176 .78907 L 1 .31 0 r
F
.73836 .36211 m .71876 .36872 L .71969 .37468 L .292 .057 0 r
F
.73836 .36211 m .73734 .35617 L .71876 .36872 L F
.13582 .45675 m .1097 .43306 L .10794 .43959 L 1 1 0 r
F
.13435 .46325 m .13582 .45675 L .10794 .43959 L F
.49681 .58272 m .46774 .5728 L .46767 .57743 L 1 .862 0 r
F
.49681 .58272 m .49662 .57823 L .46774 .5728 L F
.25557 .71245 m .21361 .70215 L .21512 .70754 L 1 .497 0 r
F
.25683 .71765 m .25557 .71245 L .21512 .70754 L 1 .486 0 r
F
.4946 .51634 m .46845 .51074 L .46842 .51401 L 1 .831 0 r
F
.69939 .52795 m .66805 .53168 L .66798 .53628 L .627 .153 0 r
F
.69939 .52795 m .69956 .52324 L .66805 .53168 L F
.76634 .72995 m .73179 .73421 L .73009 .73989 L .392 .035 0 r
F
.76634 .72995 m .7683 .72415 L .73179 .73421 L F
.32408 .15815 m .32005 .14597 L .31388 .14946 L 1 1 0 r
F
.32408 .15815 m .3298 .15428 L .32005 .14597 L F
.84283 .36907 m .81795 .38087 L .8206 .38739 L .322 .101 0 r
F
.84283 .36907 m .83995 .3626 L .81795 .38087 L F
.83797 .36323 m .81347 .37492 L .81613 .38139 L F
.83797 .36323 m .8351 .35681 L .81347 .37492 L F
.68317 .16925 m .67731 .16495 L .66634 .17677 L .528 .6 0 r
F
.24478 .75239 m .20511 .73789 L .20693 .74347 L 1 .456 0 r
F
.2464 .75779 m .24478 .75239 L .20693 .74347 L 1 .436 0 r
F
.46712 .6147 m .46721 .60888 L .4368 .60901 L 1 .806 0 r
F
.81115 .65441 m .77898 .66117 L .77785 .6673 L .334 .034 0 r
F
.81115 .65441 m .81243 .64816 L .77898 .66117 L F
.53302 .68664 m .50016 .6849 L .50021 .69064 L .889 .434 0 r
F
.53302 .68664 m .53301 .6814 L .50016 .6849 L F
.49662 .57823 m .4678 .56834 L .46774 .5728 L 1 .868 0 r
F
.49662 .57823 m .49643 .57383 L .4678 .56834 L F
.56544 .65889 m .5325 .65519 L .53265 .66041 L .902 .44 0 r
F
.56544 .65889 m .56543 .65407 L .5325 .65519 L F
.60032 .47851 m .57559 .47999 L .57534 .48382 L .7 .158 0 r
F
.60032 .47851 m .60076 .4746 L .57559 .47999 L F
.5447 .84558 m .5054 .8432 L .50491 .84736 L .747 .058 0 r
F
.5447 .84558 m .54571 .8414 L .5054 .8432 L F
.84965 .54831 m .82003 .55762 L .82012 .56423 L .297 .045 0 r
F
.84965 .54831 m .84957 .54162 L .82003 .55762 L F
.46932 .41555 m .46935 .41144 L .44952 .41583 L 1 .895 0 r
F
.11183 .49658 m .08387 .47205 L .08256 .47895 L 1 .98 0 r
F
.11074 .50342 m .11183 .49658 L .08256 .47895 L 1 .97 0 r
F
.85457 .55597 m .82397 .56515 L .82406 .57185 L .308 .047 0 r
F
.85457 .55597 m .85446 .54918 L .82397 .56515 L F
.67691 .16556 m .6605 .17269 L .66604 .17724 L .526 .605 0 r
F
.68275 .16988 m .67691 .16556 L .66604 .17724 L .519 .592 0 r
F
.62688 .82525 m .58941 .8252 L .588 .82966 L .611 .046 0 r
F
.62688 .82525 m .62876 .82071 L .58941 .8252 L F
.46828 .50925 m .44305 .50444 L .44295 .50784 L 1 .678 0 r
F
.46826 .51267 m .46828 .50925 L .44295 .50784 L 1 .669 0 r
F
.6664 .57689 m .63329 .57762 L .63322 .58203 L .736 .237 0 r
F
.6664 .57689 m .66667 .57243 L .63329 .57762 L F
.20591 .66895 m .16648 .65388 L .16768 .65975 L 1 .607 0 r
F
.20703 .67457 m .20591 .66895 L .16768 .65975 L 1 .594 0 r
F
.44506 .45531 m .44525 .45168 L .42375 .45079 L 1 .885 0 r
F
.58506 .83835 m .5467 .83714 L .54571 .8414 L .679 .052 0 r
F
.58506 .83835 m .58655 .83405 L .5467 .83714 L F
.28828 .21654 m .28792 .21249 L .28131 .21427 L .577 .294 0 r
F
.28828 .21654 m .2938 .21312 L .28792 .21249 L F
.7268 .46303 m .69989 .46943 L .69997 .4745 L .46 .07 0 r
F
.7268 .46303 m .72666 .45786 L .69989 .46943 L F
.39021 .74927 m .34863 .75064 L .34937 .75566 L .973 .399 0 r
F
.39058 .75452 m .39021 .74927 L .34937 .75566 L .973 .382 0 r
F
.42944 .74621 m .39021 .74927 L .39058 .75452 L .921 .385 0 r
F
.42944 .74621 m .42935 .74068 L .39021 .74927 L F
.15897 .59336 m .12417 .5735 L .12445 .57987 L 1 .781 0 r
F
.15935 .59954 m .15897 .59336 L .12445 .57987 L 1 .768 0 r
F
.32452 .15912 m .32035 .14663 L .31428 .15029 L 1 1 0 r
F
.32452 .15912 m .33019 .15518 L .32035 .14663 L F
.44506 .45531 m .42375 .45079 L .42335 .45424 L 1 .885 0 r
F
.44488 .45892 m .44506 .45531 L .42335 .45424 L 1 .876 0 r
F
.81495 .66337 m .78191 .66977 L .78075 .67598 L .345 .036 0 r
F
.81495 .66337 m .81625 .65702 L .78191 .66977 L F
.6706 .80547 m .63409 .80665 L .63236 .81141 L .538 .04 0 r
F
.6706 .80547 m .67274 .80062 L .63409 .80665 L F
.44488 .45892 m .42335 .45424 L .42297 .45769 L 1 .876 0 r
F
.4447 .46251 m .44488 .45892 L .42297 .45769 L 1 .867 0 r
F
.54785 .51638 m .5214 .51533 L .52134 .51874 L .887 .376 0 r
F
.54785 .51638 m .54799 .51295 L .5214 .51533 L F
.24246 .76264 m .20195 .74842 L .20392 .75402 L 1 .433 0 r
F
.24418 .76805 m .24246 .76264 L .20392 .75402 L 1 .413 0 r
F
.62623 .45137 m .60324 .45389 L .6027 .45821 L .56 .065 0 r
F
.62623 .45137 m .62702 .44694 L .60324 .45389 L F
.46932 .41555 m .44952 .41583 L .44931 .41946 L 1 .895 0 r
F
.46928 .41958 m .46932 .41555 L .44931 .41946 L 1 .891 0 r
F
.30379 .73883 m .26092 .73304 L .26239 .73809 L 1 .432 0 r
F
.30487 .74382 m .30379 .73883 L .26239 .73809 L 1 .42 0 r
F
.59842 .63818 m .56513 .63496 L .56524 .63971 L .869 .382 0 r
F
.59842 .63818 m .59853 .63366 L .56513 .63496 L F
.57412 .50219 m .54835 .50244 L .54823 .50598 L .801 .277 0 r
F
.57412 .50219 m .57436 .49862 L .54835 .50244 L F
.4447 .46251 m .42297 .45769 L .4226 .46114 L 1 .867 0 r
F
.44453 .46609 m .4447 .46251 L .4226 .46114 L 1 .859 0 r
F
.12563 .4762 m .1001 .45233 L .09842 .45897 L 1 1 0 r
F
.1242 .48284 m .12563 .4762 L .09842 .45897 L F
.52129 .52212 m .49459 .51974 L .49457 .52311 L .966 .471 0 r
F
.52129 .52212 m .52134 .51874 L .49459 .51974 L F
.8456 .37557 m .8206 .38739 L .82317 .39394 L .318 .087 0 r
F
.8456 .37557 m .84283 .36907 L .8206 .38739 L F
.84073 .3697 m .81613 .38139 L .8187 .3879 L .317 .086 0 r
F
.84073 .3697 m .83797 .36323 L .81613 .38139 L F
.71446 .76818 m .67951 .77114 L .67767 .7762 L .448 .034 0 r
F
.71446 .76818 m .71664 .76301 L .67951 .77114 L F
.44453 .46609 m .4226 .46114 L .42225 .46458 L 1 .859 0 r
F
.44437 .46965 m .44453 .46609 L .42225 .46458 L 1 .85 0 r
F
.14861 .6168 m .115 .59589 L .11537 .60245 L 1 .781 0 r
F
.14903 .62323 m .14861 .6168 L .11537 .60245 L 1 .766 0 r
F
.4399 .58361 m .40844 .58495 L .40636 .59224 L .868 .749 0 r
F
.43915 .58961 m .4399 .58361 L .40636 .59224 L .854 .731 0 r
F
.63215 .61285 m .59869 .61119 L .59871 .61566 L .812 .31 0 r
F
.63215 .61285 m .63237 .60845 L .59869 .61119 L F
.69832 .30488 m .68349 .30769 L .68395 .31479 L .201 .031 0 r
F
.69832 .30488 m .69794 .29772 L .68349 .30769 L F
.7393 .368 m .71969 .37468 L .72054 .38059 L .288 .056 0 r
F
.7393 .368 m .73836 .36211 L .71969 .37468 L F
.51062 .12157 m .50731 .11671 L .49904 .11912 L .885 .944 0 r
F
.13435 .46325 m .10794 .43959 L .1063 .44613 L 1 1 0 r
F
.13297 .46976 m .13435 .46325 L .1063 .44613 L F
.49593 .56122 m .49578 .55718 L .46802 .55197 L 1 .877 0 r
F
.46928 .41958 m .44931 .41946 L .4491 .42306 L 1 .891 0 r
F
.46924 .42355 m .46928 .41958 L .4491 .42306 L 1 .887 0 r
F
.56542 .66371 m .53265 .66041 L .53278 .66564 L .89 .421 0 r
F
.56542 .66371 m .56544 .65889 L .53265 .66041 L F
.44437 .46965 m .42225 .46458 L .4219 .46801 L 1 .85 0 r
F
.44421 .4732 m .44437 .46965 L .4219 .46801 L 1 .841 0 r
F
.38587 .16985 m .38914 .19186 L .38217 .18712 L .338 .018 0 r
F
.38846 .17928 m .39921 .22718 L .39118 .21673 L .445 .052 0 r
F
.38587 .16985 m .39085 .16795 L .38914 .19186 L .338 .018 0 r
F
.33826 .21325 m .34646 .23293 L .34284 .23766 L .316 .01 0 r
F
.33826 .21325 m .34314 .21009 L .34646 .23293 L F
.53301 .69187 m .50021 .69064 L .50024 .69636 L .877 .411 0 r
F
.53301 .69187 m .53302 .68664 L .50021 .69064 L F
.67691 .16556 m .67102 .16131 L .6605 .17269 L .526 .605 0 r
F
.33807 .81995 m .2964 .81037 L .29823 .81513 L 1 .236 0 r
F
.3395 .82455 m .33807 .81995 L .29823 .81513 L 1 .215 0 r
F
.4659 .73748 m .42935 .74068 L .42944 .74621 L .881 .37 0 r
F
.4659 .73748 m .46592 .73189 L .42935 .74068 L F
.34863 .75064 m .306 .74878 L .30718 .75368 L 1 .402 0 r
F
.34937 .75566 m .34863 .75064 L .30718 .75368 L 1 .387 0 r
F
.50017 .71875 m .46598 .72042 L .46595 .72621 L .864 .38 0 r
F
.50017 .71875 m .50022 .71324 L .46598 .72042 L F
.69919 .53264 m .66798 .53628 L .66788 .54085 L .623 .146 0 r
F
.69919 .53264 m .69939 .52795 L .66798 .53628 L F
.46721 .60888 m .43758 .60233 L .4368 .60901 L 1 .829 0 r
F
.46721 .60888 m .46729 .60321 L .43758 .60233 L F
.44421 .4732 m .4219 .46801 L .42157 .47144 L 1 .841 0 r
F
.44405 .47673 m .44421 .4732 L .42157 .47144 L 1 .832 0 r
F
.46924 .42355 m .4491 .42306 L .4489 .42662 L 1 .887 0 r
F
.4692 .42746 m .46924 .42355 L .4489 .42662 L 1 .883 0 r
F
.46473 .84258 m .4647 .83855 L .42448 .83778 L .87 .072 0 r
F
.50442 .84203 m .4647 .83855 L .46473 .84258 L .808 .065 0 r
F
.50442 .84203 m .50491 .83801 L .4647 .83855 L F
.3298 .15428 m .32629 .14265 L .32005 .14597 L 1 1 0 r
F
.3298 .15428 m .33558 .15052 L .32629 .14265 L F
.44405 .47673 m .42157 .47144 L .42125 .47487 L 1 .832 0 r
F
.4439 .48024 m .44405 .47673 L .42125 .47487 L 1 .823 0 r
F
.37399 .1387 m .37136 .13116 L .36527 .13396 L .92 1 0 r
F
.5999 .48234 m .57534 .48382 L .57509 .4876 L .695 .154 0 r
F
.5999 .48234 m .60032 .47851 L .57534 .48382 L F
.4725 .12637 m .47264 .12041 L .46473 .1246 L 1 1 0 r
F
.48066 .15202 m .47264 .12041 L .4725 .12637 L 1 .553 0 r
F
.48051 .18444 m .48066 .15202 L .4725 .12637 L .653 .199 0 r
F
.14232 .63299 m .10716 .61213 L .10782 .61879 L 1 .742 0 r
F
.14299 .63949 m .14232 .63299 L .10782 .61879 L 1 .727 0 r
F
.54771 .51978 m .52134 .51874 L .52129 .52212 L .883 .368 0 r
F
.54771 .51978 m .54785 .51638 L .52134 .51874 L F
.6661 .58134 m .63322 .58203 L .63313 .58643 L .729 .227 0 r
F
.6661 .58134 m .6664 .57689 L .63322 .58203 L F
.4692 .42746 m .4489 .42662 L .44871 .43015 L 1 .883 0 r
F
.46917 .4313 m .4692 .42746 L .44871 .43015 L 1 .879 0 r
F
.52122 .52548 m .49457 .52311 L .49455 .52645 L .962 .463 0 r
F
.52122 .52548 m .52129 .52212 L .49457 .52311 L F
.38269 .82723 m .34152 .81929 L .34298 .82372 L 1 .169 0 r
F
.38371 .83151 m .38269 .82723 L .34298 .82372 L .992 .148 0 r
F
.84339 .37619 m .8187 .3879 L .82117 .39443 L .312 .077 0 r
F
.84339 .37619 m .84073 .3697 L .8187 .3879 L F
.84828 .38211 m .82317 .39394 L .82563 .40051 L .313 .077 0 r
F
.84828 .38211 m .8456 .37557 L .82317 .39394 L F
.11074 .50342 m .08256 .47895 L .08137 .48585 L 1 .97 0 r
F
.10976 .51027 m .11074 .50342 L .08137 .48585 L 1 .958 0 r
F
.59828 .64271 m .56524 .63971 L .56533 .64448 L .859 .366 0 r
F
.59828 .64271 m .59842 .63818 L .56524 .63971 L F
.4439 .48024 m .42125 .47487 L .42095 .47828 L 1 .823 0 r
F
.44376 .48374 m .4439 .48024 L .42095 .47828 L 1 .815 0 r
F
.42379 .84305 m .38239 .83679 L .38344 .84109 L .937 .106 0 r
F
.42435 .84722 m .42379 .84305 L .38344 .84109 L .927 .087 0 r
F
.46463 .84791 m .42379 .84305 L .42435 .84722 L .874 .073 0 r
F
.72691 .46815 m .69997 .4745 L .70004 .47953 L .458 .07 0 r
F
.72691 .46815 m .7268 .46303 L .69997 .4745 L F
.65186 .41972 m .63149 .42286 L .63053 .42796 L .383 .041 0 r
F
.65186 .41972 m .65309 .41448 L .63149 .42286 L F
.52519 .14061 m .51248 .13831 L .51487 .1487 L .942 .741 0 r
F
.52805 .15078 m .51487 .1487 L .51666 .16234 L .951 .674 0 r
F
.52805 .15078 m .52519 .14061 L .51487 .1487 L F
.57388 .50572 m .54823 .50598 L .54811 .50949 L .797 .271 0 r
F
.57388 .50572 m .57412 .50219 L .54823 .50598 L F
.33019 .15518 m .32651 .14316 L .32035 .14663 L 1 1 0 r
F
.33019 .15518 m .33594 .15139 L .32651 .14316 L F
.2938 .21312 m .29457 .21095 L .28792 .21249 L .448 .207 0 r
F
.2938 .21312 m .29939 .20988 L .29457 .21095 L F
.37425 .13962 m .37187 .13292 L .36576 .13554 L .887 1 0 r
F
.37425 .13962 m .37975 .13625 L .37187 .13292 L F
.1242 .48284 m .09842 .45897 L .09684 .46563 L 1 1 0 r
F
.12287 .48948 m .1242 .48284 L .09684 .46563 L F
.56537 .66854 m .53278 .66564 L .53289 .67089 L .878 .401 0 r
F
.56537 .66854 m .56542 .66371 L .53278 .66564 L F
.19188 .71363 m .15325 .69642 L .15485 .70254 L 1 .562 0 r
F
.19335 .71956 m .19188 .71363 L .15485 .70254 L 1 .544 0 r
F
.46917 .4313 m .44871 .43015 L .44852 .43366 L 1 .879 0 r
F
.46913 .4351 m .46917 .4313 L .44852 .43366 L 1 .874 0 r
F
.84963 .555 m .82012 .56423 L .82011 .57083 L .292 .043 0 r
F
.84963 .555 m .84965 .54831 L .82012 .56423 L F
.35213 .18714 m .35551 .19894 L .34822 .1967 L .298 0 0 r
F
.35213 .18714 m .35772 .18531 L .35551 .19894 L F
.44376 .48374 m .42095 .47828 L .42066 .48169 L 1 .815 0 r
F
.44363 .48723 m .44376 .48374 L .42066 .48169 L 1 .806 0 r
F
.63189 .61725 m .59871 .61566 L .5987 .62015 L .803 .297 0 r
F
.63189 .61725 m .63215 .61285 L .59871 .61566 L F
.85456 .56276 m .82406 .57185 L .82405 .57853 L .304 .045 0 r
F
.85456 .56276 m .85457 .55597 L .82406 .57185 L F
.71603 .77794 m .68067 .78049 L .67878 .78562 L .459 .035 0 r
F
.71603 .77794 m .71827 .77269 L .68067 .78049 L F
.76177 .72609 m .72819 .73071 L .72646 .73624 L .379 .031 0 r
F
.76177 .72609 m .76377 .72043 L .72819 .73071 L F
.74017 .37384 m .72054 .38059 L .72131 .38645 L .286 .054 0 r
F
.74017 .37384 m .7393 .368 L .72054 .38059 L F
.6777 .37634 m .66049 .37947 L .65935 .38573 L .265 .019 0 r
F
.6777 .37634 m .67906 .36995 L .66049 .37947 L F
.13297 .46976 m .1063 .44613 L .10475 .45269 L 1 1 0 r
F
.13169 .47628 m .13297 .46976 L .10475 .45269 L 1 .995 0 r
F
.19586 .7033 m .15834 .68592 L .15978 .69199 L 1 .586 0 r
F
.1972 .70919 m .19586 .7033 L .15978 .69199 L 1 .568 0 r
F
.53296 .69708 m .50024 .69636 L .50026 .70203 L .865 .388 0 r
F
.53296 .69708 m .53301 .69187 L .50024 .69636 L F
.2941 .79061 m .25354 .77875 L .25549 .78383 L 1 .33 0 r
F
.29575 .79551 m .2941 .79061 L .25549 .78383 L 1 .31 0 r
F
.46913 .4351 m .44852 .43366 L .44834 .43714 L 1 .874 0 r
F
.4691 .43885 m .46913 .4351 L .44834 .43714 L 1 .87 0 r
F
.49904 .11909 m .49653 .11408 L .48873 .11605 L .931 .986 0 r
F
.49904 .11912 m .49652 .1141 L .48873 .11605 L .929 .984 0 r
F
.50731 .11671 m .49652 .1141 L .49904 .11912 L .881 .951 0 r
F
.46729 .60321 m .43837 .59586 L .43758 .60233 L 1 .851 0 r
F
.46729 .60321 m .46737 .5977 L .43837 .59586 L F
.44363 .48723 m .42066 .48169 L .42038 .48509 L 1 .806 0 r
F
.4435 .4907 m .44363 .48723 L .42038 .48509 L 1 .797 0 r
F
.51473 .14979 m .50225 .1479 L .50343 .1639 L 1 .746 0 r
F
.52502 .14166 m .5124 .1389 L .51473 .14979 L .932 .717 0 r
F
.52774 .15264 m .51473 .14979 L .51636 .16443 L .937 .64 0 r
F
.52774 .15264 m .52502 .14166 L .51473 .14979 L F
.62548 .45569 m .6027 .45821 L .60218 .46244 L .556 .064 0 r
F
.62548 .45569 m .62623 .45137 L .6027 .45821 L F
.54362 .84019 m .50491 .83801 L .50442 .84203 L .737 .056 0 r
F
.54362 .84019 m .54463 .83615 L .50491 .83801 L F
.15935 .59954 m .12445 .57987 L .12482 .58623 L 1 .768 0 r
F
.15981 .60571 m .15935 .59954 L .12482 .58623 L 1 .754 0 r
F
.62451 .82 m .58772 .82025 L .58631 .82458 L .596 .043 0 r
F
.62451 .82 m .6264 .81561 L .58772 .82025 L F
.69896 .53731 m .66788 .54085 L .66777 .54541 L .618 .139 0 r
F
.69896 .53731 m .69919 .53264 L .66788 .54085 L F
.80978 .66061 m .77785 .6673 L .77664 .67338 L .329 .032 0 r
F
.80978 .66061 m .81115 .65441 L .77785 .6673 L F
.84594 .38272 m .82117 .39443 L .82354 .40099 L .307 .075 0 r
F
.84594 .38272 m .84339 .37619 L .82117 .39443 L F
.85084 .38868 m .82563 .40051 L .828 .40711 L .308 .075 0 r
F
.85084 .38868 m .84828 .38211 L .82563 .40051 L F
.52115 .5288 m .49455 .52645 L .49452 .52977 L .958 .454 0 r
F
.52115 .5288 m .52122 .52548 L .49455 .52645 L F
.4691 .43885 m .44834 .43714 L .44816 .44059 L 1 .87 0 r
F
.46906 .44255 m .4691 .43885 L .44816 .44059 L 1 .865 0 r
F
.69842 .31204 m .68395 .31479 L .68414 .32189 L .181 .024 0 r
F
.69842 .31204 m .69832 .30488 L .68395 .31479 L F
.25683 .71765 m .21512 .70754 L .21669 .7129 L 1 .486 0 r
F
.25814 .72282 m .25683 .71765 L .21669 .7129 L 1 .473 0 r
F
.58336 .83298 m .54562 .83203 L .54463 .83615 L .667 .049 0 r
F
.58336 .83298 m .58485 .82882 L .54562 .83203 L F
.51248 .13831 m .50051 .1361 L .5023 .14736 L 1 .823 0 r
F
.51248 .13831 m .50972 .1298 L .50051 .1361 L F
.52188 .13224 m .50972 .1298 L .51248 .13831 L .929 .795 0 r
F
.52519 .14061 m .52188 .13224 L .51248 .13831 L .942 .741 0 r
F
.54756 .52314 m .52129 .52212 L .52122 .52548 L .878 .361 0 r
F
.54756 .52314 m .54771 .51978 L .52129 .52212 L F
.4435 .4907 m .42038 .48509 L .42011 .48849 L 1 .797 0 r
F
.44338 .49416 m .4435 .4907 L .42011 .48849 L 1 .788 0 r
F
.66752 .80045 m .63176 .80197 L .63002 .80659 L .521 .037 0 r
F
.66752 .80045 m .66968 .79574 L .63176 .80197 L F
.59811 .64724 m .56533 .64448 L .5654 .64927 L .848 .349 0 r
F
.59811 .64724 m .59828 .64271 L .56533 .64448 L F
.50009 .7242 m .46595 .72621 L .46592 .73189 L .855 .356 0 r
F
.50009 .7242 m .50017 .71875 L .46595 .72621 L F
.20703 .67457 m .16768 .65975 L .16896 .66558 L 1 .594 0 r
F
.20822 .68016 m .20703 .67457 L .16896 .66558 L 1 .58 0 r
F
.14903 .62323 m .11537 .60245 L .11583 .609 L 1 .766 0 r
F
.14955 .62964 m .14903 .62323 L .11583 .609 L 1 .751 0 r
F
.46906 .44255 m .44816 .44059 L .44799 .44402 L 1 .865 0 r
F
.46903 .44622 m .46906 .44255 L .44799 .44402 L 1 .86 0 r
F
.66578 .58578 m .63313 .58643 L .63303 .59084 L .722 .216 0 r
F
.66578 .58578 m .6661 .58134 L .63313 .58643 L F
.5124 .1389 m .50049 .13638 L .50225 .1479 L 1 .808 0 r
F
.5124 .1389 m .50968 .13014 L .50049 .13638 L F
.52179 .13286 m .50968 .13014 L .5124 .1389 L .923 .779 0 r
F
.52304 .14122 m .52179 .13286 L .5124 .1389 L .932 .717 0 r
F
.52183 .13294 m .52179 .13286 L .52304 .14122 L F
.52954 .1674 m .52774 .15264 L .51636 .16443 L .935 .551 0 r
F
.52954 .1674 m .51636 .16443 L .51667 .18601 L F
.53819 .14305 m .52519 .14061 L .52805 .15078 L .896 .316 0 r
F
.52505 .14164 m .52188 .13224 L .52519 .14061 L 1 .701 0 r
F
.52505 .14164 m .52181 .13286 L .52502 .14166 L .834 .681 0 r
F
.52181 .13286 m .52179 .13286 L .52183 .13294 L F
.52181 .13286 m .52183 .13294 L .52502 .14166 L F
.52502 .14166 m .52183 .13294 L .52304 .14122 L .932 .717 0 r
F
.53783 .14485 m .53755 .14478 L .52774 .15264 L .827 .599 0 r
F
.53755 .14478 m .52502 .14166 L .52556 .14384 L F
.53755 .14478 m .52556 .14384 L .52774 .15264 L F
.53813 .14304 m .53782 .14481 L .52519 .14061 L .896 .316 0 r
F
.53755 .14478 m .53754 .14474 L .52502 .14166 L .827 .599 0 r
F
.53754 .14474 m .52505 .14164 L .52502 .14166 L F
.53783 .14485 m .53782 .14481 L .53755 .14478 L F
.53782 .14481 m .52505 .14164 L .52519 .14061 L .896 .316 0 r
F
.53782 .14481 m .5343 .13555 L .53755 .14478 L .827 .599 0 r
F
.52967 .18894 m .52954 .1674 L .51667 .18601 L .928 .463 0 r
F
.52967 .18894 m .51667 .18601 L .51468 .21895 L F
.49889 .26506 m .49702 .26867 L .49597 .27547 L 1 .635 0 r
F
.49666 .29598 m .49889 .26506 L .48621 .3103 L 1 .607 0 r
F
.51468 .21895 m .50364 .2256 L .49832 .26952 L 1 .55 0 r
F
.50364 .2256 m .50147 .22691 L .49965 .25154 L F
.50364 .2256 m .49965 .25154 L .49832 .26952 L F
.49597 .27547 m .48699 .28799 L .48621 .3103 L 1 .635 0 r
F
.49702 .26867 m .48699 .28799 L .49597 .27547 L F
.51065 .25942 m .51468 .21895 L .49832 .26952 L 1 .506 0 r
F
.49569 .31455 m .49666 .29598 L .48604 .3234 L 1 .618 0 r
F
.51065 .25942 m .50595 .26327 L .49624 .29903 L 1 .506 0 r
F
.50595 .26327 m .49832 .26952 L .49672 .29217 L F
.49666 .29598 m .49461 .29878 L .49009 .31293 L 1 .607 0 r
F
.50595 .26327 m .49672 .29217 L .49624 .29903 L 1 .506 0 r
F
.49009 .31293 m .48621 .3103 L .48604 .3234 L 1 .607 0 r
F
.49461 .29878 m .48621 .3103 L .49009 .31293 L F
.50727 .29161 m .51065 .25942 L .49624 .29903 L 1 .484 0 r
F
.50727 .29161 m .50452 .29346 L .4954 .31655 L F
.50452 .29346 m .49624 .29903 L .49561 .31206 L F
.49569 .31455 m .49343 .31662 L .48618 .33206 L 1 .618 0 r
F
.50452 .29346 m .49561 .31206 L .4954 .31655 L 1 .484 0 r
F
.49343 .31662 m .48604 .3234 L .48617 .33178 L 1 .618 0 r
F
.49343 .31662 m .48617 .33178 L .48618 .33206 L F
.50559 .31173 m .50727 .29161 L .4954 .31655 L 1 .493 0 r
F
.50503 .32448 m .50559 .31173 L .49526 .32768 L 1 .522 0 r
F
.53782 .14481 m .50061 .32049 L .52505 .14164 L .896 .316 0 r
F
.53754 .14474 m .5343 .13555 L .52505 .14164 L .827 .599 0 r
F
.50516 .32684 m .50516 .32647 L .53782 .14481 L 1 .827 0 r
F
.50475 .32914 m .50516 .32647 L .50516 .32684 L F
.50475 .32914 m .53782 .14481 L .53615 .15423 L F
.5053 .32665 m .50516 .32647 L .53782 .14481 L .669 .212 0 r
F
.50516 .32647 m .50286 .32345 L .53596 .15359 L F
.50516 .32647 m .53596 .15359 L .53782 .14481 L F
.50286 .32345 m .50107 .31832 L .53596 .15359 L F
.50511 .3193 m .50508 .31381 L .50498 .31396 L F
.50286 .32345 m .50061 .32049 L .50107 .31832 L F
.50453 .32564 m .50498 .31396 L .50289 .31709 L F
.50516 .32647 m .50499 .31478 L .50453 .32564 L F
.50499 .31478 m .50498 .31396 L .50453 .32564 L F
.50516 .32647 m .50508 .31381 L .5343 .13555 L 1 .827 0 r
F
.50516 .32647 m .5343 .13555 L .53782 .14481 L F
.50529 .32664 m .50498 .31396 L .50516 .32647 L .669 .212 0 r
F
.5053 .32665 m .50527 .32553 L .50529 .32664 L F
.50527 .32553 m .50498 .31396 L .50529 .32664 L F
.52181 .13286 m .52188 .13224 L .52278 .13491 L 1 .701 0 r
F
.52181 .13286 m .52181 .13284 L .52181 .13286 L F
.52181 .13285 m .52181 .13284 L .52181 .13286 L F
.5343 .13555 m .52181 .13285 L .52181 .13286 L .834 .681 0 r
F
.52181 .13285 m .52181 .13285 L .52181 .13286 L F
.51667 .18601 m .50344 .18859 L .50147 .22691 L 1 .605 0 r
F
.50061 .32049 m .52181 .13285 L .52181 .13286 L 1 .701 0 r
F
.50061 .32049 m .50227 .29588 L .52181 .13285 L F
.5343 .13555 m .53031 .12784 L .52181 .13285 L .834 .681 0 r
F
.52181 .13285 m .52181 .13285 L .52181 .13285 L F
.5343 .13555 m .52181 .13285 L .52181 .13285 L F
.52181 .13286 m .52181 .13285 L .52179 .13286 L F
.52181 .13286 m .52181 .13286 L .52182 .13287 L 1 .701 0 r
F
.52181 .13286 m .52182 .13287 L .52505 .14164 L F
.52181 .13286 m .52278 .13491 L .52505 .14164 L F
.52188 .13224 m .51829 .12504 L .50972 .1298 L .929 .795 0 r
F
.52181 .13285 m .51825 .12542 L .52179 .13286 L .94 .37 0 r
F
.52153 .13226 m .51824 .12541 L .52181 .13285 L F
.51825 .12541 m .51829 .12504 L .5183 .12505 L .053 0 0 r
F
.51825 .12541 m .5183 .12505 L .52181 .13285 L F
.5183 .12542 m .51825 .12541 L .52153 .13226 L .94 .37 0 r
F
.5183 .12542 m .51829 .12542 L .5183 .12542 L F
.51829 .12542 m .51825 .12541 L .5183 .12542 L F
.51825 .12541 m .51824 .12541 L .52153 .13226 L F
.52181 .13285 m .51829 .12504 L .52188 .13224 L .053 0 0 r
F
.51636 .16443 m .50343 .1639 L .50344 .18859 L 1 .674 0 r
F
.52179 .13286 m .51824 .12541 L .50968 .13014 L .923 .779 0 r
F
.51482 .19115 m .51821 .12585 L .52181 .13285 L .053 0 0 r
F
.51407 .18294 m .51821 .12585 L .51482 .19115 L F
.51106 .20391 m .51278 .18508 L .51142 .21956 L F
.51278 .18508 m .51821 .12585 L .51333 .19315 L F
.51278 .18508 m .51333 .19315 L .51142 .21956 L F
.50454 .2717 m .50626 .25332 L .50379 .28323 L F
.50626 .25332 m .51821 .12585 L .50602 .25892 L F
.50626 .25332 m .50602 .25892 L .50379 .28323 L F
.51142 .21956 m .51407 .18294 L .51482 .19115 L F
.50379 .28323 m .51106 .20391 L .51142 .21956 L F
.51821 .12585 m .51825 .12541 L .51905 .12708 L F
.51821 .12585 m .51905 .12708 L .52181 .13285 L F
.52181 .13286 m .52181 .13284 L .52188 .13224 L 1 .701 0 r
F
.53031 .12784 m .5183 .12542 L .52181 .13285 L .94 .37 0 r
F
.5343 .13555 m .52898 .1344 L .5279 .13976 L .834 .681 0 r
F
.52898 .1344 m .52181 .13286 L .5279 .13976 L F
.5279 .13976 m .52181 .13286 L .52505 .14164 L F
.50061 .32049 m .52181 .13286 L .52505 .14164 L 1 .701 0 r
F
.53031 .12784 m .51084 .22439 L .51785 .13053 L .94 .37 0 r
F
.53031 .12784 m .51785 .13053 L .51822 .12584 L F
.53031 .12784 m .51822 .12584 L .51825 .12541 L F
.51822 .12584 m .5182 .12584 L .51825 .12541 L F
.50227 .29588 m .50454 .2717 L .50379 .28323 L .053 0 0 r
F
.50227 .29588 m .51822 .12586 L .51825 .12541 L F
.51822 .12586 m .51826 .12539 L .51825 .12541 L F
.51822 .12586 m .51143 .21728 L .51826 .12539 L F
.5038 .27963 m .51027 .22721 L .51822 .12586 L F
.50639 .26054 m .51027 .22721 L .5038 .27963 L F
.51019 .22101 m .50885 .23426 L .51006 .22031 L .94 .37 0 r
F
.51084 .22439 m .51027 .22721 L .51019 .22101 L F
.51027 .22721 m .50885 .23426 L .51019 .22101 L F
.50515 .31246 m .50696 .29351 L .53031 .12784 L 1 .81 0 r
F
.50515 .31246 m .50821 .28037 L .50546 .28756 L .652 .138 0 r
F
.50309 .30059 m .50546 .28756 L .50227 .29588 L F
.50515 .31246 m .50546 .28756 L .50309 .30059 L F
.50605 .29994 m .50822 .2803 L .53031 .12784 L 1 .81 0 r
F
.50821 .28037 m .50945 .24844 L .50227 .29588 L .556 .069 0 r
F
.50821 .28037 m .51027 .22721 L .53031 .12784 L .561 .069 0 r
F
.51047 .24171 m .51027 .22721 L .50227 .29588 L .556 .069 0 r
F
.50672 .29069 m .50885 .23426 L .51027 .22721 L .561 .069 0 r
F
.50672 .29069 m .51027 .22721 L .50821 .28037 L F
.50821 .28037 m .51047 .24171 L .50945 .24844 L .556 .069 0 r
F
.50903 .27824 m .52121 .18627 L .51723 .19889 L F
.50935 .27011 m .51723 .19889 L .51143 .21728 L F
.50903 .27824 m .51723 .19889 L .50935 .27011 L F
.50602 .30017 m .50821 .28037 L .50822 .2803 L 1 .81 0 r
F
.50602 .30017 m .50822 .2803 L .50605 .29994 L F
.50508 .31381 m .53031 .12784 L .5343 .13555 L F
.50515 .31246 m .50227 .29588 L .50505 .31363 L .652 .138 0 r
F
.50515 .31246 m .50505 .31363 L .50508 .31381 L F
.50507 .31303 m .50602 .30017 L .5063 .29819 L 1 .81 0 r
F
.50526 .31104 m .5063 .29819 L .50696 .29351 L F
.50507 .31303 m .5063 .29819 L .50526 .31104 L F
.50507 .31303 m .50515 .31246 L .50508 .31381 L F
.50515 .31246 m .53031 .12784 L .50508 .31381 L F
.50508 .31381 m .50227 .29588 L .50061 .32049 L .652 .138 0 r
F
.50532 .31345 m .50515 .31246 L .50508 .31381 L F
.50532 .31345 m .50903 .27824 L .50821 .28037 L F
.50532 .31345 m .50821 .28037 L .50515 .31246 L F
.50903 .27824 m .50935 .27011 L .50821 .28037 L .556 .069 0 r
F
.51415 .26823 m .52121 .18627 L .50903 .27824 L .317 .036 0 r
F
.51561 .23213 m .51568 .2314 L .50804 .28197 L .31 .034 0 r
F
.50602 .30017 m .50672 .29069 L .50821 .28037 L 1 .81 0 r
F
.51561 .23213 m .50804 .28197 L .50672 .29069 L .31 .034 0 r
F
.5053 .32665 m .53782 .14481 L .53782 .14481 L .669 .212 0 r
F
.53615 .15423 m .53782 .14481 L .53783 .14485 L 1 .827 0 r
F
.5053 .32665 m .53782 .1448 L .53787 .14481 L .669 .212 0 r
F
.50907 .30901 m .50903 .27824 L .50532 .31345 L .37 .048 0 r
F
.50907 .30901 m .51415 .26823 L .51088 .27461 L F
.50904 .28544 m .51088 .27461 L .50903 .27824 L F
.50907 .30901 m .51088 .27461 L .50904 .28544 L F
.51415 .26823 m .52749 .17457 L .52121 .18627 L .317 .036 0 r
F
.51601 .27104 m .52749 .17457 L .51415 .26823 L .088 0 0 r
F
.51132 .30857 m .51285 .28668 L .50955 .30891 L .038 0 0 r
F
.51601 .27104 m .53028 .17703 L .52749 .17457 L .088 0 0 r
F
.55161 .11497 m .53925 .11551 L .54459 .11965 L .71 .823 0 r
F
.55745 .11886 m .54459 .11965 L .54988 .12388 L .707 .812 0 r
F
.55745 .11886 m .55161 .11497 L .54459 .11965 L F
.55156 .1152 m .53922 .11567 L .54455 .11984 L .706 .817 0 r
F
.54572 .11118 m .53385 .11148 L .53925 .11551 L .713 .834 0 r
F
.55161 .11497 m .54572 .11118 L .53925 .11551 L .71 .823 0 r
F
.53925 .11551 m .53385 .11148 L .52693 .11516 L .758 .859 0 r
F
.54568 .11136 m .53383 .1116 L .53922 .11567 L .71 .829 0 r
F
.55156 .1152 m .54568 .11136 L .53922 .11567 L .706 .817 0 r
F
.54959 .12421 m .53795 .12251 L .54267 .12914 L .649 .611 0 r
F
.55446 .1314 m .54959 .12421 L .54267 .12914 L .619 .523 0 r
F
.5493 .12553 m .53782 .12323 L .54243 .13029 L .623 .563 0 r
F
.54572 .11118 m .53977 .1075 L .53385 .11148 L .713 .834 0 r
F
.54568 .11136 m .53974 .10764 L .53383 .1116 L .71 .829 0 r
F
.54434 .11802 m .53298 .11664 L .53795 .12251 L .67 .677 0 r
F
.56322 .12285 m .55745 .11886 L .54988 .12388 L .704 .801 0 r
F
.55738 .11915 m .54455 .11984 L .54982 .12412 L .702 .805 0 r
F
.55738 .11915 m .55156 .1152 L .54455 .11984 L F
.54959 .12421 m .54434 .11802 L .53795 .12251 L .649 .611 0 r
F
.54418 .11884 m .5329 .11709 L .53782 .12323 L .653 .647 0 r
F
.5493 .12553 m .54418 .11884 L .53782 .12323 L .623 .563 0 r
F
.53922 .11567 m .53383 .1116 L .52692 .11526 L .755 .855 0 r
F
.54434 .11802 m .53884 .11255 L .53298 .11664 L .67 .677 0 r
F
.54418 .11884 m .53875 .11307 L .5329 .11709 L .653 .647 0 r
F
.55098 .10658 m .53977 .1075 L .54572 .11118 L .665 .806 0 r
F
.55733 .11 m .54572 .11118 L .55161 .11497 L .66 .794 0 r
F
.55733 .11 m .55098 .10658 L .54572 .11118 L F
.55094 .1068 m .53974 .10764 L .54568 .11136 L .66 .8 0 r
F
.55098 .10658 m .54458 .10327 L .53977 .1075 L .665 .806 0 r
F
.55094 .1068 m .54455 .10344 L .53974 .10764 L .66 .8 0 r
F
.56362 .11353 m .55161 .11497 L .55745 .11886 L .654 .782 0 r
F
.56362 .11353 m .55733 .11 L .55161 .11497 L F
.55727 .11028 m .54568 .11136 L .55156 .1152 L .654 .787 0 r
F
.54947 .11369 m .53884 .11255 L .54434 .11802 L .563 .608 0 r
F
.5551 .11964 m .54434 .11802 L .54959 .12421 L .521 .523 0 r
F
.5551 .11964 m .54947 .11369 L .54434 .11802 L F
.54926 .11471 m .53875 .11307 L .54418 .11884 L .535 .564 0 r
F
.55727 .11028 m .55094 .1068 L .54568 .11136 L .654 .787 0 r
F
.54947 .11369 m .54356 .10852 L .53884 .11255 L .563 .608 0 r
F
.54926 .11471 m .54344 .10915 L .53875 .11307 L .535 .564 0 r
F
.55494 .10181 m .54458 .10327 L .55098 .10658 L .612 .775 0 r
F
.56164 .10485 m .55098 .10658 L .55733 .11 L .604 .761 0 r
F
.56164 .10485 m .55494 .10181 L .55098 .10658 L F
.55488 .10208 m .54455 .10344 L .55094 .1068 L .604 .766 0 r
F
.54819 .09888 m .53812 .10007 L .54458 .10327 L .62 .789 0 r
F
.55494 .10181 m .54819 .09888 L .54458 .10327 L .612 .775 0 r
F
.54458 .10327 m .53376 .10392 L .53977 .1075 L .671 .818 0 r
F
.54458 .10327 m .53812 .10007 L .53376 .10392 L F
.54815 .09909 m .53809 .1002 L .54455 .10344 L .614 .782 0 r
F
.55488 .10208 m .54815 .09909 L .54455 .10344 L .604 .766 0 r
F
.5532 .1097 m .54356 .10852 L .54947 .11369 L .419 .498 0 r
F
.56984 .11717 m .55745 .11886 L .56322 .12285 L .649 .77 0 r
F
.56984 .11717 m .56362 .11353 L .55745 .11886 L F
.56353 .11388 m .55156 .1152 L .55738 .11915 L .647 .773 0 r
F
.56353 .11388 m .55727 .11028 L .55156 .1152 L F
.55904 .11564 m .54947 .11369 L .5551 .11964 L .365 .374 0 r
F
.55904 .11564 m .5532 .1097 L .54947 .11369 L F
.55291 .11104 m .54344 .10915 L .54926 .11471 L .381 .424 0 r
F
.54819 .09888 m .54138 .09607 L .53812 .10007 L .62 .789 0 r
F
.54815 .09909 m .54136 .09623 L .53809 .1002 L .614 .782 0 r
F
.53977 .1075 m .5284 .10754 L .53385 .11148 L .716 .844 0 r
F
.53977 .1075 m .53376 .10392 L .5284 .10754 L F
.54455 .10344 m .53374 .10403 L .53974 .10764 L .666 .813 0 r
F
.54703 .10466 m .53744 .10391 L .54356 .10852 L .477 .589 0 r
F
.5532 .1097 m .54703 .10466 L .54356 .10852 L .419 .498 0 r
F
.53385 .11148 m .52212 .11089 L .52693 .11516 L .759 .869 0 r
F
.53385 .11148 m .5284 .10754 L .52212 .11089 L F
.53974 .10764 m .52838 .10764 L .53383 .1116 L .713 .84 0 r
F
.53974 .10764 m .53374 .10403 L .52838 .10764 L F
.54356 .10852 m .53315 .10763 L .53884 .11255 L .595 .673 0 r
F
.54356 .10852 m .53744 .10391 L .53315 .10763 L F
.54687 .10548 m .53737 .10431 L .54344 .10915 L .444 .544 0 r
F
.55291 .11104 m .54687 .10548 L .54344 .10915 L .381 .424 0 r
F
.54455 .10344 m .53809 .1002 L .53374 .10403 L .666 .813 0 r
F
.54703 .10466 m .54062 .10028 L .53744 .10391 L .477 .589 0 r
F
.54687 .10548 m .54053 .10079 L .53737 .10431 L .444 .544 0 r
F
.56827 .10801 m .55733 .11 L .56362 .11353 L .595 .747 0 r
F
.56827 .10801 m .56164 .10485 L .55733 .11 L F
.56155 .10519 m .55094 .1068 L .55727 .11028 L .594 .751 0 r
F
.56155 .10519 m .55488 .10208 L .55094 .1068 L F
.55539 .10639 m .54809 .10488 L .5532 .1097 L .279 .293 0 r
F
.54809 .10488 m .54703 .10466 L .54795 .10541 L F
.54809 .10488 m .54795 .10541 L .5532 .1097 L F
.55751 .09696 m .54819 .09888 L .55494 .10181 L .551 .737 0 r
F
.56443 .09962 m .55494 .10181 L .56164 .10485 L .539 .721 0 r
F
.56443 .09962 m .55751 .09696 L .55494 .10181 L F
.55743 .0973 m .54815 .09909 L .55488 .10208 L .538 .724 0 r
F
.55751 .09696 m .55053 .09442 L .54819 .09888 L .551 .737 0 r
F
.55743 .0973 m .55047 .09468 L .54815 .09909 L .538 .724 0 r
F
.54913 .10123 m .54062 .10028 L .54703 .10466 L .512 .058 0 r
F
.55539 .10639 m .54913 .10123 L .54703 .10466 L .279 .293 0 r
F
.53383 .1116 m .52211 .11097 L .52692 .11526 L .757 .865 0 r
F
.53298 .11664 m .52156 .11498 L .52608 .12077 L .763 .771 0 r
F
.5329 .11709 m .52153 .11523 L .52602 .12117 L .756 .756 0 r
F
.53782 .12323 m .5329 .11709 L .52602 .12117 L .748 .703 0 r
F
.53383 .1116 m .52838 .10764 L .52211 .11097 L .757 .865 0 r
F
.53298 .11664 m .52782 .11133 L .52156 .11498 L .763 .771 0 r
F
.5329 .11709 m .52777 .11161 L .52153 .11523 L .756 .756 0 r
F
.53884 .11255 m .52782 .11133 L .53298 .11664 L .685 .729 0 r
F
.53875 .11307 m .52777 .11161 L .5329 .11709 L .675 .709 0 r
F
.53884 .11255 m .53315 .10763 L .52782 .11133 L .685 .729 0 r
F
.53875 .11307 m .53309 .10796 L .52777 .11161 L .675 .709 0 r
F
.54344 .10915 m .53309 .10796 L .53875 .11307 L .577 .645 0 r
F
.53376 .10392 m .52289 .10371 L .5284 .10754 L .719 .854 0 r
F
.5284 .10754 m .51726 .10673 L .52212 .11089 L .76 .878 0 r
F
.5284 .10754 m .52289 .10371 L .51726 .10673 L F
.53374 .10403 m .52288 .10378 L .52838 .10764 L .717 .851 0 r
F
.53376 .10392 m .5277 .10044 L .52289 .10371 L .719 .854 0 r
F
.53374 .10403 m .52769 .10053 L .52288 .10378 L .717 .851 0 r
F
.53812 .10007 m .5277 .10044 L .53376 .10392 L .676 .83 0 r
F
.53809 .1002 m .52769 .10053 L .53374 .10403 L .673 .825 0 r
F
.53744 .10391 m .5273 .10314 L .53315 .10763 L .62 .723 0 r
F
.52212 .11089 m .51726 .10673 L .51092 .10946 L .799 .901 0 r
F
.52838 .10764 m .51726 .10678 L .52211 .11097 L .758 .875 0 r
F
.52838 .10764 m .52288 .10378 L .51726 .10678 L F
.53315 .10763 m .52252 .10645 L .52782 .11133 L .697 .769 0 r
F
.53315 .10763 m .5273 .10314 L .52252 .10645 L F
.53737 .10431 m .52727 .10334 L .53309 .10796 L .608 .705 0 r
F
.54344 .10915 m .53737 .10431 L .53309 .10796 L .577 .645 0 r
F
.53812 .10007 m .5316 .09698 L .5277 .10044 L .676 .83 0 r
F
.53809 .1002 m .53159 .09708 L .52769 .10053 L .673 .825 0 r
F
.53744 .10391 m .53117 .09976 L .5273 .10314 L .62 .723 0 r
F
.53737 .10431 m .53113 .10001 L .52727 .10334 L .608 .705 0 r
F
.53323 .12796 m .52577 .11349 L .52945 .12997 L .28 .059 0 r
F
.53323 .12796 m .52945 .11071 L .52577 .11349 L F
.54138 .09607 m .5316 .09698 L .53812 .10007 L .154 .167 0 r
F
.54136 .09623 m .53159 .09708 L .53809 .1002 L .099 .157 0 r
F
.54062 .10028 m .53117 .09976 L .53744 .10391 L .616 .051 0 r
F
.53877 .10275 m .53113 .10001 L .53737 .10431 L .639 .057 0 r
F
.54053 .10079 m .53141 .10003 L .53877 .10275 L F
.53141 .10003 m .53113 .10001 L .53877 .10275 L F
.52211 .11097 m .51726 .10678 L .51091 .10951 L .798 .899 0 r
F
.52782 .11133 m .5169 .10967 L .52156 .11498 L .765 .806 0 r
F
.52782 .11133 m .52252 .10645 L .5169 .10967 L F
.53309 .10796 m .52249 .10663 L .52777 .11161 L .69 .756 0 r
F
.5277 .10044 m .51734 .09998 L .52289 .10371 L .722 .864 0 r
F
.52289 .10371 m .51236 .10266 L .51726 .10673 L .76 .887 0 r
F
.52289 .10371 m .51734 .09998 L .51236 .10266 L F
.52769 .10053 m .51733 .10003 L .52288 .10378 L .72 .862 0 r
F
.51726 .10673 m .50674 .10508 L .51092 .10946 L .798 .909 0 r
F
.51726 .10673 m .51236 .10266 L .50674 .10508 L F
.52288 .10378 m .51235 .1027 L .51726 .10678 L .759 .884 0 r
F
.52288 .10378 m .51733 .10003 L .51235 .1027 L F
.5273 .10314 m .5171 .10193 L .52252 .10645 L .706 .802 0 r
F
.51092 .10946 m .50068 .10598 L .50411 .11031 L .657 .808 0 r
F
.51092 .10946 m .50674 .10508 L .50068 .10598 L F
.51726 .10678 m .50674 .10512 L .51091 .10951 L .797 .907 0 r
F
.51726 .10678 m .51235 .1027 L .50674 .10512 L F
.52252 .10645 m .51213 .10474 L .5169 .10967 L .767 .834 0 r
F
.52252 .10645 m .5171 .10193 L .51213 .10474 L F
.52727 .10334 m .51709 .10204 L .52249 .10663 L .702 .793 0 r
F
.53309 .10796 m .52727 .10334 L .52249 .10663 L .69 .756 0 r
F
.5277 .10044 m .52159 .09708 L .51734 .09998 L .722 .864 0 r
F
.52769 .10053 m .52158 .09714 L .51733 .10003 L .72 .862 0 r
F
.5273 .10314 m .52134 .09899 L .5171 .10193 L .706 .802 0 r
F
.52727 .10334 m .52132 .09912 L .51709 .10204 L .702 .793 0 r
F
.5316 .09698 m .52159 .09708 L .5277 .10044 L .328 .368 0 r
F
.53159 .09708 m .52158 .09714 L .52769 .10053 L .305 .312 0 r
F
.53117 .09976 m .52134 .09899 L .5273 .10314 L .483 0 0 r
F
.52937 .10152 m .52132 .09912 L .52727 .10334 L .541 .012 0 r
F
.53113 .10001 m .52174 .09916 L .52937 .10152 L F
.52174 .09916 m .52132 .09912 L .52937 .10152 L F
.52159 .09708 m .51173 .09636 L .51734 .09998 L .431 .644 0 r
F
.51734 .09998 m .50741 .09869 L .51236 .10266 L .761 .895 0 r
F
.51734 .09998 m .51173 .09636 L .50741 .09869 L F
.52158 .09714 m .51173 .09639 L .51733 .10003 L .423 .627 0 r
F
.51236 .10266 m .50252 .10081 L .50674 .10508 L .797 .916 0 r
F
.51236 .10266 m .50741 .09869 L .50252 .10081 L F
.51733 .10003 m .5074 .09872 L .51235 .1027 L .76 .894 0 r
F
.51733 .10003 m .51173 .09639 L .5074 .09872 L F
.52134 .09899 m .51159 .0977 L .5171 .10193 L 0 .122 0 r
F
.50411 .11031 m .50068 .10598 L .49407 .10767 L .841 .958 0 r
F
.50068 .10598 m .49147 .1032 L .49407 .10767 L .601 .834 0 r
F
.50063 .10594 m .49722 .10173 L .49205 .10306 L .839 .962 0 r
F
.50129 .10583 m .50063 .10594 L .50073 .10597 L .833 .939 0 r
F
.5064 .105 m .50545 .10466 L .50126 .10583 L .674 .829 0 r
F
.50548 .10477 m .50063 .10594 L .50129 .10583 L .833 .939 0 r
F
.50674 .10508 m .5064 .105 L .50068 .10598 L F
.5064 .105 m .50548 .10477 L .50376 .1052 L F
.5064 .105 m .50376 .1052 L .50068 .10598 L F
.50674 .10508 m .50252 .10081 L .50239 .10085 L F
.50543 .10465 m .50239 .10085 L .49722 .10173 L .674 .829 0 r
F
.5064 .105 m .50239 .10085 L .50543 .10465 L F
.50545 .10466 m .49722 .10173 L .50063 .10594 L F
.49151 .1032 m .48885 .09879 L .49147 .1032 L .721 .865 0 r
F
.49151 .1032 m .48885 .0988 L .49147 .10321 L .651 .868 0 r
F
.49722 .10173 m .48888 .09881 L .49151 .1032 L F
.48888 .09881 m .48885 .09879 L .49151 .1032 L .721 .865 0 r
F
.48888 .09881 m .48885 .0988 L .49151 .1032 L .651 .868 0 r
F
.50063 .10594 m .49205 .10306 L .49151 .1032 L .839 .962 0 r
F
.49716 .10269 m .48888 .09881 L .49151 .1032 L .721 .865 0 r
F
.48888 .09881 m .4937 .09823 L .48885 .09879 L F
.49722 .10173 m .49374 .09828 L .48888 .09881 L .651 .868 0 r
F
.49716 .10269 m .49374 .09828 L .48888 .09881 L .721 .865 0 r
F
.49374 .09828 m .4937 .09823 L .48888 .09881 L F
.48888 .09881 m .49374 .09828 L .48885 .0988 L .651 .868 0 r
F
.49374 .09828 m .4937 .09824 L .49361 .09825 L F
.49374 .09828 m .49361 .09825 L .48885 .0988 L F
.49435 .09842 m .4937 .09823 L .49374 .09828 L .83 .945 0 r
F
.50239 .10085 m .49374 .09828 L .49722 .10173 L .829 .945 0 r
F
.49435 .09842 m .49374 .09828 L .49716 .10269 L .83 .945 0 r
F
.5023 .10074 m .4937 .09823 L .50239 .10085 L F
.50252 .10083 m .4937 .09824 L .49374 .09828 L .829 .945 0 r
F
.50239 .10085 m .49435 .09842 L .49438 .09847 L .83 .945 0 r
F
.50252 .10081 m .5023 .10074 L .50239 .10085 L F
.50252 .10083 m .49374 .09828 L .50239 .10085 L .829 .945 0 r
F
.50239 .10085 m .49438 .09847 L .49716 .10269 L .83 .945 0 r
F
.50073 .10597 m .50063 .10594 L .50068 .10598 L .833 .939 0 r
F
.50545 .10466 m .50063 .10594 L .50068 .106 L .674 .829 0 r
F
.5064 .105 m .50239 .10085 L .49716 .10269 L .833 .939 0 r
F
.50674 .10508 m .50239 .10085 L .5064 .105 L F
.5064 .105 m .50252 .10083 L .50239 .10085 L .674 .829 0 r
F
.50674 .10512 m .5066 .10499 L .5064 .105 L F
.5066 .10499 m .50252 .10083 L .5064 .105 L F
.50674 .10512 m .5064 .105 L .50068 .106 L F
.5064 .105 m .50126 .10583 L .50068 .106 L F
.50057 .10595 m .50063 .10594 L .49147 .1032 L .601 .834 0 r
F
.50068 .10598 m .50063 .10594 L .50057 .10595 L F
.50063 .10594 m .49716 .10269 L .49151 .1032 L F
.50063 .10594 m .49151 .1032 L .49147 .1032 L F
.50063 .10594 m .49151 .1032 L .49147 .10321 L .839 .962 0 r
F
.50068 .106 m .50063 .10594 L .49147 .10321 L F
.50548 .10477 m .49781 .1033 L .50063 .10594 L .833 .939 0 r
F
.51235 .1027 m .50252 .10083 L .5066 .10499 L .796 .915 0 r
F
.50691 .10504 m .5066 .10499 L .50674 .10512 L F
.51235 .1027 m .5066 .10499 L .50691 .10504 L F
.50548 .10477 m .49716 .10269 L .49781 .1033 L .833 .939 0 r
F
.51235 .1027 m .5074 .09872 L .50252 .10083 L .796 .915 0 r
F
.5171 .10193 m .50727 .10012 L .51213 .10474 L .767 .858 0 r
F
.5171 .10193 m .51159 .0977 L .50727 .10012 L F
.52132 .09912 m .51159 .09777 L .51709 .10204 L .13 0 0 r
F
.52134 .09899 m .51494 .09811 L .51159 .0977 L 0 .122 0 r
F
.52132 .09912 m .51514 .09834 L .51159 .09777 L .13 0 0 r
F
.51514 .09834 m .51492 .09831 L .51463 .09827 L F
.51514 .09834 m .51463 .09827 L .51159 .09777 L F
.52389 .10222 m .51492 .09831 L .52132 .09912 L .509 .514 0 r
F
.53113 .10001 m .52423 .10212 L .52132 .09912 L .541 .012 0 r
F
.52423 .10212 m .52389 .10222 L .52352 .10177 L F
.52423 .10212 m .52352 .10177 L .52132 .09912 L F
.53154 .11168 m .52389 .10222 L .53113 .10001 L .181 .063 0 r
F
.54053 .10079 m .53195 .11118 L .53113 .10001 L .639 .057 0 r
F
.53195 .11118 m .53154 .11168 L .53132 .10545 L F
.53195 .11118 m .53132 .10545 L .53113 .10001 L F
.53028 .17703 m .53323 .12796 L .52945 .12997 L .153 .011 0 r
F
.53508 .13075 m .53149 .118 L .53323 .12796 L .696 .168 0 r
F
.53149 .118 m .52945 .11071 L .53113 .11838 L F
.53149 .118 m .53113 .11838 L .53323 .12796 L F
.51568 .2314 m .51816 .20431 L .51161 .25375 L .31 .034 0 r
F
.50935 .27011 m .51047 .24171 L .50821 .28037 L .556 .069 0 r
F
.51084 .22439 m .51006 .22031 L .5182 .12584 L .94 .37 0 r
F
.51047 .24171 m .51143 .21728 L .51027 .22721 L .556 .069 0 r
F
.52121 .18627 m .51735 .14576 L .51143 .21728 L .525 .071 0 r
F
.51816 .20431 m .51748 .17892 L .51082 .22792 L .491 .065 0 r
F
.50227 .29588 m .50639 .26054 L .5038 .27963 L .053 0 0 r
F
.52945 .12997 m .52103 .11733 L .52414 .1354 L .459 .158 0 r
F
.52945 .12997 m .52577 .11349 L .52103 .11733 L F
.51027 .22721 m .51143 .21728 L .51492 .17032 L .053 0 0 r
F
.51466 .17127 m .51492 .17032 L .51822 .12586 L F
.51027 .22721 m .51492 .17032 L .51466 .17127 L F
.51822 .12584 m .51785 .13053 L .5182 .12584 L .94 .37 0 r
F
.51424 .17174 m .51427 .164 L .5182 .12584 L .313 .037 0 r
F
.51046 .20126 m .5085 .16904 L .51133 .15633 L .702 .191 0 r
F
.50972 .1298 m .49842 .12713 L .50051 .1361 L 1 .868 0 r
F
.50972 .1298 m .50674 .12249 L .49842 .12713 L F
.51829 .12504 m .50674 .12249 L .50972 .1298 L 1 .429 0 r
F
.50986 .13005 m .50672 .1227 L .50968 .13014 L .912 .826 0 r
F
.51824 .12541 m .50676 .1227 L .50986 .13005 L F
.50676 .1227 m .50672 .1227 L .50986 .13005 L F
.50968 .13014 m .49841 .12728 L .50049 .13638 L 1 .858 0 r
F
.50968 .13014 m .50672 .1227 L .49841 .12728 L F
.50674 .12249 m .49615 .11954 L .49842 .12713 L .984 .902 0 r
F
.50672 .1227 m .49615 .11963 L .49841 .12728 L .981 .895 0 r
F
.50674 .12249 m .50361 .116 L .49615 .11954 L .984 .902 0 r
F
.50037 .12085 m .5036 .11611 L .49615 .11963 L .981 .895 0 r
F
.50672 .1227 m .5036 .11613 L .50037 .12085 L F
.5036 .11613 m .5036 .11611 L .50037 .12085 L F
.50618 .1215 m .50362 .11603 L .50617 .12132 L .36 .056 0 r
F
.50362 .11603 m .50362 .11603 L .50617 .12132 L F
.50675 .12268 m .5036 .11613 L .50672 .1227 L 1 .341 0 r
F
.5036 .11613 m .5036 .11611 L .5036 .11613 L F
.5036 .11613 m .5036 .11613 L .50672 .1227 L F
.50362 .11612 m .50361 .116 L .50618 .1215 L .36 .056 0 r
F
.50362 .11612 m .50364 .11609 L .50362 .11612 L F
.50362 .11612 m .5036 .11611 L .50675 .12268 L 1 .341 0 r
F
.50731 .11671 m .50396 .11194 L .49652 .1141 L .881 .951 0 r
F
.50411 .11031 m .49407 .10767 L .49665 .11219 L .841 .958 0 r
F
.50411 .11033 m .49407 .10768 L .49665 .1122 L .841 .957 0 r
F
.49665 .11219 m .48714 .10902 L .48884 .11369 L .871 .981 0 r
F
.49665 .1122 m .48714 .10902 L .48884 .11369 L .87 .98 0 r
F
.49665 .11219 m .49407 .10767 L .48714 .10902 L .871 .981 0 r
F
.49665 .1122 m .49407 .10768 L .48714 .10902 L .87 .98 0 r
F
.50397 .11191 m .49398 .10917 L .49653 .11408 L .877 .959 0 r
F
.48884 .11369 m .48714 .10902 L .48003 .10889 L .767 .895 0 r
F
.48884 .11369 m .48714 .10902 L .48003 .1089 L .768 .896 0 r
F
.49653 .11408 m .48706 .1109 L .48873 .11605 L .924 .99 0 r
F
.49653 .11408 m .49398 .10917 L .48706 .1109 L F
.50396 .11194 m .49398 .10918 L .49652 .1141 L .876 .957 0 r
F
.50411 .11033 m .50068 .106 L .49407 .10768 L .841 .957 0 r
F
.50397 .11191 m .50058 .10725 L .49398 .10917 L .877 .959 0 r
F
.50396 .11194 m .50058 .10728 L .49398 .10918 L .876 .957 0 r
F
.49652 .1141 m .48706 .1109 L .48873 .11605 L .923 .989 0 r
F
.49652 .1141 m .49398 .10918 L .48706 .1109 L F
.50361 .116 m .49376 .11285 L .49615 .11954 L .962 .927 0 r
F
.49615 .11954 m .48684 .11627 L .48833 .12437 L 1 .965 0 r
F
.48873 .11605 m .48706 .1109 L .48001 .11006 L .717 .81 0 r
F
.48873 .11605 m .48706 .1109 L .48001 .11007 L .718 .811 0 r
F
.49615 .11954 m .49376 .11285 L .48684 .11627 L 1 .965 0 r
F
.5036 .11611 m .49376 .1129 L .49615 .11963 L .96 .923 0 r
F
.50361 .116 m .50036 .11008 L .49376 .11285 L .962 .927 0 r
F
.49896 .1146 m .50035 .11015 L .49376 .1129 L .96 .923 0 r
F
.5036 .11611 m .50038 .11019 L .49896 .1146 L F
.50038 .11019 m .50035 .11015 L .49896 .1146 L F
.50361 .11617 m .50035 .11015 L .5036 .11611 L .326 .071 0 r
F
.50704 .13914 m .50365 .11624 L .50618 .1215 L .36 .056 0 r
F
.5085 .16904 m .50488 .12964 L .50704 .13914 L F
.50488 .12964 m .50365 .11624 L .50704 .13914 L F
.5085 .16904 m .50365 .11622 L .50362 .11612 L F
.50675 .12268 m .50617 .12132 L .50674 .12249 L F
.51824 .12541 m .51822 .12536 L .50675 .12268 L .912 .826 0 r
F
.51824 .12541 m .50675 .12268 L .50676 .1227 L F
.51427 .164 m .51817 .12579 L .5182 .12584 L .313 .037 0 r
F
.51046 .20126 m .51133 .15633 L .51822 .12536 L .702 .191 0 r
F
.51006 .22031 m .51275 .15826 L .51424 .17174 L .313 .037 0 r
F
.51047 .12332 m .5085 .16904 L .50674 .12249 L 1 .429 0 r
F
.51826 .12503 m .51133 .15629 L .51047 .12332 L F
.51133 .15629 m .5085 .16904 L .51047 .12332 L F
.51822 .12536 m .5085 .16904 L .51826 .12503 L F
.51822 .12536 m .51447 .11886 L .51043 .12086 L .912 .826 0 r
F
.51428 .12309 m .5144 .12029 L .51439 .12315 L .313 .037 0 r
F
.51822 .12536 m .51043 .12086 L .50675 .12268 L .912 .826 0 r
F
.51447 .11886 m .50611 .11675 L .50761 .12226 L 1 .341 0 r
F
.50676 .1227 m .50675 .12268 L .50672 .1227 L .912 .826 0 r
F
.50744 .14087 m .50618 .12143 L .50675 .12268 L .36 .056 0 r
F
.50704 .13914 m .50617 .12132 L .50744 .14087 L F
.50675 .12268 m .50617 .12132 L .50675 .12268 L F
.50618 .12143 m .50617 .12132 L .50675 .12268 L F
.50761 .12226 m .50362 .11612 L .50675 .12268 L 1 .341 0 r
F
.5085 .16904 m .50704 .13914 L .50744 .14087 L .36 .056 0 r
F
.50611 .11675 m .50366 .11613 L .50761 .12226 L 1 .341 0 r
F
.50366 .11613 m .50382 .11643 L .50761 .12226 L F
.51447 .11886 m .50364 .11618 L .50362 .11612 L F
.50364 .11618 m .50361 .11617 L .50362 .11612 L F
.50366 .11613 m .50362 .11612 L .50382 .11643 L F
.50365 .11624 m .50365 .11618 L .50382 .11654 L .36 .056 0 r
F
.50365 .11624 m .50382 .11654 L .50618 .1215 L F
.51447 .11886 m .50875 .13137 L .50364 .11618 L 1 .341 0 r
F
.50875 .13137 m .50868 .13153 L .50856 .13117 L F
.50875 .13137 m .50856 .13117 L .50364 .11618 L F
.51428 .12309 m .51439 .12315 L .51431 .1502 L .313 .037 0 r
F
.51428 .12309 m .51431 .1502 L .51429 .15013 L F
.51275 .15826 m .51319 .14819 L .5143 .15501 L F
.51319 .14819 m .51428 .12309 L .51429 .15342 L F
.51319 .14819 m .51429 .15342 L .5143 .15501 L F
.50365 .11622 m .50869 .13047 L .50364 .11609 L .36 .056 0 r
F
.50599 .14166 m .50868 .13153 L .50365 .11622 L F
.5085 .16904 m .50868 .1326 L .50599 .14166 L F
.50868 .1326 m .50868 .13153 L .50599 .14166 L F
.50868 .13153 m .50869 .13047 L .50365 .11622 L F
.50623 .12445 m .50854 .13183 L .50618 .12435 L 1 .341 0 r
F
.50623 .12445 m .50618 .12435 L .50361 .11617 L F
.50364 .11618 m .50623 .12445 L .50361 .11617 L F
.50868 .13153 m .50854 .13183 L .50364 .11618 L F
.50786 .12968 m .50058 .11072 L .50361 .11617 L .326 .071 0 r
F
.50055 .11066 m .50035 .11015 L .50361 .11617 L F
.50068 .106 m .49147 .10321 L .49407 .10768 L .839 .962 0 r
F
.49407 .10767 m .48544 .1044 L .48714 .10902 L .869 .985 0 r
F
.49407 .10768 m .48544 .1044 L .48714 .10902 L .868 .985 0 r
F
.49407 .10767 m .49147 .1032 L .48544 .1044 L .869 .985 0 r
F
.49407 .10768 m .49147 .10321 L .48544 .1044 L .868 .985 0 r
F
.50058 .10725 m .49141 .10435 L .49398 .10917 L .378 .555 0 r
F
.48714 .10902 m .47924 .10436 L .48003 .10889 L .772 .905 0 r
F
.48714 .10902 m .47924 .10437 L .48003 .1089 L .773 .906 0 r
F
.48714 .10902 m .48544 .1044 L .47924 .10436 L .772 .905 0 r
F
.48714 .10902 m .48544 .1044 L .47924 .10437 L .773 .906 0 r
F
.49398 .10917 m .48538 .10584 L .48706 .1109 L .917 .995 0 r
F
.49398 .10917 m .49141 .10435 L .48538 .10584 L F
.50058 .10728 m .49141 .10436 L .49398 .10918 L .872 .963 0 r
F
.49398 .10918 m .48538 .10584 L .48706 .1109 L .916 .994 0 r
F
.49398 .10918 m .49141 .10436 L .48538 .10584 L F
.50036 .11008 m .49128 .1068 L .49376 .11285 L .608 .011 0 r
F
.51091 .10951 m .50068 .106 L .50411 .11033 L .654 .805 0 r
F
.51056 .11281 m .50092 .10744 L .50397 .11191 L .522 .63 0 r
F
.50092 .10744 m .50058 .10725 L .50131 .10825 L F
.50092 .10744 m .50131 .10825 L .50397 .11191 L F
.51091 .10951 m .50674 .10512 L .50068 .106 L .654 .805 0 r
F
.50652 .10743 m .50611 .10731 L .50058 .10725 L .876 .914 0 r
F
.50611 .10731 m .5051 .10679 L .50108 .10722 L .586 .708 0 r
F
.5051 .10679 m .49715 .10271 L .50053 .10721 L F
.51056 .11281 m .50652 .10743 L .50058 .10725 L .522 .63 0 r
F
.5051 .10679 m .50053 .10721 L .50058 .10728 L .586 .708 0 r
F
.50053 .10721 m .49715 .10271 L .49144 .10435 L .872 .963 0 r
F
.50611 .10731 m .49703 .1046 L .50053 .10721 L .876 .914 0 r
F
.50611 .10731 m .50053 .10721 L .50058 .10725 L F
.50651 .10752 m .50611 .10731 L .50083 .10725 L .586 .708 0 r
F
.50611 .10731 m .50108 .10722 L .50083 .10725 L F
.50084 .10729 m .50083 .10725 L .50058 .10728 L F
.50651 .10752 m .50083 .10725 L .50084 .10729 L F
.50048 .10722 m .50053 .10721 L .49141 .10435 L .378 .555 0 r
F
.50058 .10725 m .50053 .10721 L .50048 .10722 L F
.50053 .10721 m .49703 .1046 L .49144 .10435 L F
.49147 .1032 m .48371 .09983 L .48544 .1044 L .867 .99 0 r
F
.49147 .10321 m .48371 .09983 L .48544 .1044 L .867 .989 0 r
F
.49147 .1032 m .48885 .09879 L .48371 .09983 L .867 .99 0 r
F
.49147 .10321 m .48885 .0988 L .48371 .09983 L .867 .989 0 r
F
.49144 .10435 m .48881 .09964 L .49141 .10435 L .678 .785 0 r
F
.49715 .10271 m .48884 .09965 L .49143 .10433 L .514 .758 0 r
F
.48884 .09965 m .48881 .09964 L .49144 .10435 L .678 .785 0 r
F
.49715 .10271 m .4914 .10434 L .49144 .10435 L .514 .758 0 r
F
.49703 .1046 m .48884 .09965 L .49144 .10435 L .678 .785 0 r
F
.49143 .10433 m .48881 .09964 L .4914 .10434 L .514 .758 0 r
F
.48884 .09965 m .48881 .09964 L .49143 .10433 L F
.49144 .10435 m .4914 .10434 L .49141 .10436 L F
.49219 .1046 m .49144 .10435 L .49141 .10435 L .378 .555 0 r
F
.50053 .10721 m .49144 .10435 L .49219 .1046 L F
.50058 .10728 m .50053 .10721 L .49141 .10436 L .872 .963 0 r
F
.50053 .10721 m .49144 .10435 L .49141 .10436 L F
.48706 .1109 m .47922 .10534 L .48001 .11006 L .74 .842 0 r
F
.48706 .1109 m .47922 .10535 L .48001 .11007 L .741 .843 0 r
F
.48706 .1109 m .48538 .10584 L .47922 .10534 L .74 .842 0 r
F
.48706 .1109 m .48538 .10584 L .47922 .10535 L .741 .843 0 r
F
.49376 .11285 m .48525 .10928 L .48684 .11627 L 1 .985 0 r
F
.49376 .11285 m .49128 .1068 L .48525 .10928 L F
.49435 .11265 m .49128 .10682 L .49376 .1129 L .939 .943 0 r
F
.50035 .11015 m .49132 .10684 L .49435 .11265 L F
.49132 .10684 m .49128 .10682 L .49435 .11265 L F
.50028 .11005 m .50023 .11005 L .49128 .1068 L .608 .011 0 r
F
.50035 .11015 m .50031 .11008 L .49128 .10682 L .939 .943 0 r
F
.49132 .10684 m .49131 .10681 L .49128 .10682 L F
.50031 .11008 m .49131 .10681 L .49132 .10684 L F
.49131 .10681 m .49116 .10653 L .49131 .10681 L .591 .545 0 r
F
.50023 .11005 m .49665 .11007 L .49131 .10681 L .608 .011 0 r
F
.49211 .1071 m .49131 .10681 L .49128 .1068 L F
.50023 .11005 m .49131 .10681 L .49211 .1071 L F
.48544 .1044 m .47843 .09988 L .47924 .10436 L .779 .918 0 r
F
.48544 .1044 m .47843 .09988 L .47924 .10437 L .78 .918 0 r
F
.48544 .1044 m .48371 .09983 L .47843 .09988 L .779 .918 0 r
F
.48544 .1044 m .48371 .09983 L .47843 .09988 L .78 .918 0 r
F
.49141 .10435 m .48368 .10089 L .48538 .10584 L .91 .999 0 r
F
.49141 .10436 m .48368 .10089 L .48538 .10584 L .909 .998 0 r
F
.49141 .10435 m .48881 .09964 L .48368 .10089 L .91 .999 0 r
F
.49141 .10436 m .48881 .09964 L .48368 .10089 L .909 .998 0 r
F
.49702 .10464 m .48876 .10122 L .4913 .10679 L .15 .152 0 r
F
.49702 .10464 m .4913 .10679 L .49131 .10681 L F
.49131 .10681 m .49116 .10653 L .49128 .1068 L .591 .545 0 r
F
.4913 .10679 m .49127 .1068 L .49131 .10681 L .15 .152 0 r
F
.49119 .10655 m .48874 .1012 L .49116 .10653 L .591 .545 0 r
F
.50031 .11008 m .49702 .10464 L .49131 .10681 L .939 .943 0 r
F
.49665 .11007 m .48876 .10122 L .49119 .10655 L .591 .545 0 r
F
.48876 .10122 m .48874 .1012 L .49119 .10655 L F
.49665 .11007 m .49119 .10655 L .49131 .10681 L F
.49119 .10655 m .49118 .10654 L .49131 .10681 L F
.49118 .10654 m .49116 .10653 L .49131 .10681 L F
.48538 .10584 m .47842 .10066 L .47922 .10534 L .763 .874 0 r
F
.48538 .10584 m .47842 .10067 L .47922 .10535 L .764 .875 0 r
F
.48538 .10584 m .48368 .10089 L .47842 .10066 L .763 .874 0 r
F
.48538 .10584 m .48368 .10089 L .47842 .10067 L .764 .875 0 r
F
.49128 .1068 m .48361 .10304 L .48525 .10928 L .993 .997 0 r
F
.49128 .1068 m .48874 .1012 L .48361 .10304 L F
.4913 .10679 m .48874 .10122 L .49127 .1068 L .15 .152 0 r
F
.48876 .10122 m .48874 .10122 L .4913 .10679 L F
.49131 .10681 m .49127 .1068 L .49128 .10682 L F
.50036 .11008 m .50031 .11008 L .50028 .11005 L .608 .011 0 r
F
.50031 .11008 m .49665 .11007 L .50028 .11005 L F
.50678 .12522 m .50042 .11024 L .50311 .11509 L .324 .073 0 r
F
.50869 .13047 m .50531 .12221 L .50678 .12522 L F
.50531 .12221 m .50042 .11024 L .50678 .12522 L F
.50042 .11024 m .50082 .11093 L .50311 .11509 L F
.50364 .11609 m .50311 .11509 L .50361 .116 L F
.50365 .11622 m .50364 .11609 L .50362 .11612 L .36 .056 0 r
F
.50364 .11609 m .50364 .11609 L .50362 .11612 L F
.50362 .11612 m .50361 .11617 L .5036 .11611 L 1 .341 0 r
F
.50362 .11612 m .50364 .11609 L .50361 .116 L .36 .056 0 r
F
.50869 .13047 m .50311 .11509 L .50364 .11609 L .324 .073 0 r
F
.50362 .11603 m .50361 .116 L .50362 .11603 L .36 .056 0 r
F
.50531 .12216 m .50576 .11547 L .50046 .11017 L .324 .073 0 r
F
.50576 .11547 m .50511 .11508 L .50036 .11008 L .93 .745 0 r
F
.5004 .1102 m .50036 .11013 L .50035 .11015 L .391 .304 0 r
F
.50036 .11013 m .50035 .11012 L .50035 .11015 L F
.50035 .11011 m .50031 .11008 L .50035 .11015 L F
.51055 .11295 m .50058 .10728 L .50396 .11194 L .515 .621 0 r
F
.51055 .11295 m .50651 .10752 L .50058 .10728 L F
.50652 .10743 m .50239 .10241 L .50225 .10247 L .876 .914 0 r
F
.50509 .10679 m .50225 .10247 L .49715 .10271 L .586 .708 0 r
F
.50611 .10731 m .50225 .10247 L .50509 .10679 L F
.48884 .09965 m .49363 .09947 L .48881 .09964 L .678 .785 0 r
F
.49715 .10271 m .49366 .09953 L .48884 .09965 L .514 .758 0 r
F
.49703 .1046 m .49366 .09953 L .48884 .09965 L .678 .785 0 r
F
.49366 .09953 m .49363 .09947 L .48884 .09965 L F
.48884 .09965 m .49366 .09953 L .48881 .09964 L .514 .758 0 r
F
.49366 .09953 m .49362 .09949 L .49354 .0995 L F
.49366 .09953 m .49354 .0995 L .48881 .09964 L F
.50225 .10247 m .49424 .09968 L .49427 .09974 L .864 .929 0 r
F
.50225 .10247 m .49366 .09953 L .49715 .10271 L .863 .927 0 r
F
.49424 .09968 m .49366 .09953 L .49703 .1046 L .864 .929 0 r
F
.50238 .10246 m .49362 .09949 L .49366 .09953 L .863 .927 0 r
F
.50217 .10234 m .49363 .09947 L .50225 .10247 L .864 .929 0 r
F
.50238 .10246 m .49366 .09953 L .50225 .10247 L .863 .927 0 r
F
.50225 .10247 m .49427 .09974 L .49703 .1046 L .864 .929 0 r
F
.49424 .09968 m .49363 .09947 L .49366 .09953 L F
.50239 .10241 m .50217 .10234 L .50225 .10247 L F
.50611 .10731 m .50225 .10247 L .49703 .1046 L .876 .914 0 r
F
.50652 .10743 m .50225 .10247 L .50611 .10731 L F
.50651 .10752 m .50238 .10246 L .50225 .10247 L .586 .708 0 r
F
.50651 .10752 m .50225 .10247 L .50611 .10731 L F
.48876 .10122 m .4935 .10227 L .48874 .1012 L .591 .545 0 r
F
.48876 .10122 m .49346 .10225 L .48874 .10122 L .15 .152 0 r
F
.49702 .10464 m .4935 .10227 L .48876 .10122 L F
.4935 .10227 m .49346 .10225 L .48876 .10122 L F
.49665 .11007 m .4935 .10227 L .48876 .10122 L .591 .545 0 r
F
.4935 .10227 m .49347 .10219 L .49319 .10213 L F
.4935 .10227 m .49319 .10213 L .48874 .1012 L F
.50205 .10648 m .49347 .10219 L .4.09947 L .50225 .10247 L .864 .929 0 r
F
.50238 .10246 m .49366 .09953 L .50225 .10247 L .863 .927 0 r
F
.50225 .10247 m .49427 .09974 L .49703 .1046 L .864 .929 0 r
F
.49424 .09968 m .49363 .09947 L .49366 .09953 L F
.50239 .10241 m .50217 .10234 L .50225 .10247 L F
.50611 .10731 m .50225 .10247 L .49703 .1046 L .876 .914 0 r
F
.50652 .10743 m .50225 .10247 L .50611 .10731 L F
.50651 .10752 m .50238 .10246 L .50225 .10247 L .586 .708 0 r
F
.50651 .10752 m .50225 .10247 L .50611 .10731 L F
.48876 .10122 m .4935 .10227 L .48874 .1012 L .591 .545 0 r
F
.48876 .10122 m .49346 .10225 L .48874 .10122 L .15 .152 0 r
F
.49702 .10464 m .4935 .10227 L .48876 .10122 L F
.4935 .10227 m .49346 .10225 L .48876 .10122 L F
.49665 .11007 m .4935 .10227 L .48876 .10122 L .591 .545 0 r
F
.4935 .10227 m .49347 .10219 L .49319 .10213 L F
.4935 .10227 m .49319 .10213 L .48874 .1012 L F
.50205 .10648 m .49347 .10219 L .4935 .10227 L .915 .842 0 r
F
.50126 .10625 m .49362 .10234 L .49437 .10286 L .913 .837 0 r
F
.49359 .10231 m .4935 .10227 L .49437 .10286 L F
.5019 .10658 m .49437 .10286 L .49702 .10464 L F
.50204 .10664 m .49437 .10286 L .5019 .10658 L F
.5005 .11036 m .50046 .11017 L .5004 .11012 L .324 .073 0 r
F
.50042 .11024 m .50036 .11008 L .50082 .11093 L F
.50869 .13047 m .50046 .11017 L .5005 .11036 L F
.50039 .11015 m .5004 .11012 L .50036 .11008 L F
.50511 .11508 m .50031 .11008 L .50036 .11008 L .93 .745 0 r
F
.5055 .11564 m .49762 .10541 L .5004 .1102 L .391 .304 0 r
F
.50511 .11508 m .49762 .10541 L .5055 .11564 L F
.50035 .11011 m .49702 .10464 L .50031 .11008 L F
.49762 .10541 m .49702 .10464 L .5004 .1102 L F
.50576 .11547 m .50214 .1067 L .50198 .10679 L .93 .745 0 r
F
.50576 .11547 m .50198 .10679 L .50475 .11412 L F
.50511 .11508 m .5019 .10658 L .49702 .10464 L .391 .304 0 r
F
.50214 .1067 m .5019 .10658 L .50001 .10784 L .93 .745 0 r
F
.50576 .11547 m .50001 .10784 L .50458 .11433 L F
.5005 .11235 m .49665 .11007 L .49939 .11008 L F
.50053 .1105 m .5004 .11012 L .50039 .11015 L .324 .073 0 r
F
.50869 .13047 m .5005 .11036 L .50053 .1105 L F
.5005 .11036 m .5004 .11012 L .50053 .1105 L F
.50543 .12245 m .50576 .11547 L .50531 .12216 L F
.50869 .13047 m .50596 .11645 L .50543 .12245 L F
.50596 .11645 m .50576 .11547 L .50543 .12245 L F
.50854 .13183 m .50573 .11587 L .5055 .11564 L .326 .071 0 r
F
.50854 .13183 m .50055 .11066 L .50058 .11072 L F
.50854 .13183 m .50058 .11072 L .50786 .12968 L F
.50482 .12197 m .5055 .11564 L .50035 .11015 L F
.50854 .13183 m .5055 .11564 L .50482 .12197 L F
.50554 .11533 m .49872 .1087 L .5005 .11235 L .93 .745 0 r
F
.50576 .11547 m .50554 .11525 L .50554 .11533 L F
.50554 .11525 m .49872 .1087 L .50554 .11533 L F
.50215 .112 m .50015 .11008 L .50031 .11008 L F
.50573 .11587 m .50204 .10664 L .5019 .10658 L .391 .304 0 r
F
.50573 .11587 m .5019 .10658 L .50511 .11508 L F
.50475 .11412 m .50198 .10679 L .50001 .10784 L .93 .745 0 r
F
.5019 .10658 m .4935 .10227 L .49665 .11007 L .915 .842 0 r
F
.50205 .10648 m .4935 .10227 L .5019 .10658 L F
.50204 .10664 m .49359 .10231 L .49362 .10234 L .913 .837 0 r
F
.50204 .10664 m .49362 .10234 L .50126 .10625 L F
.49359 .10231 m .49346 .10225 L .4935 .10227 L F
.50214 .1067 m .50205 .10648 L .5019 .10658 L .93 .745 0 r
F
.50036 .11013 m .50035 .11011 L .50035 .11012 L .391 .304 0 r
F
.50458 .11433 m .50001 .10784 L .49872 .1087 L .93 .745 0 r
F
.50573 .11587 m .50511 .11508 L .5055 .11564 L .391 .304 0 r
F
.5169 .10967 m .50652 .10743 L .51056 .11281 L .825 .864 0 r
F
.52156 .11498 m .5169 .10967 L .51056 .11281 L .831 .839 0 r
F
.51688 .10982 m .50651 .10752 L .51055 .11295 L .823 .859 0 r
F
.51144 .1111 m .50205 .10648 L .50576 .11547 L .84 .723 0 r
F
.51597 .14735 m .5144 .12029 L .51817 .12579 L .313 .037 0 r
F
.51433 .14195 m .5144 .12029 L .51597 .14735 L F
.51046 .20126 m .51232 .16303 L .51006 .22031 L F
.51261 .15701 m .51339 .14108 L .51275 .15826 L F
.51339 .14108 m .5144 .12029 L .51348 .14141 L F
.51339 .14108 m .51348 .14141 L .51275 .15826 L F
.51232 .16303 m .51261 .15701 L .51247 .16474 L F
.51261 .15701 m .51275 .15826 L .51247 .16474 L F
.51232 .16303 m .51247 .16474 L .51006 .22031 L F
.51184 .17298 m .5135 .13911 L .51348 .13913 L F
.51179 .17398 m .51184 .17298 L .51184 .17298 L F
.51184 .17298 m .5135 .13911 L .51184 .17298 L F
.51427 .164 m .51433 .14195 L .51597 .14735 L F
.51429 .15013 m .51431 .1502 L .5143 .15501 L F
.51179 .17413 m .51263 .15697 L .51179 .17398 L F
.5144 .12029 m .51447 .11886 L .5182 .12584 L F
.51263 .15697 m .51448 .11903 L .51262 .15699 L F
.51263 .15697 m .51262 .15699 L .51179 .17398 L F
.51326 .16285 m .5143 .15501 L .51424 .17174 L F
.5182 .12584 m .51447 .11886 L .51824 .12541 L F
.51143 .21728 m .51046 .20126 L .51822 .12537 L .702 .191 0 r
F
.51046 .20126 m .51822 .12536 L .51822 .12536 L F
.51263 .15697 m .51647 .14675 L .51448 .11903 L .313 .037 0 r
F
.51358 .14172 m .51339 .14132 L .5134 .14121 L .745 .322 0 r
F
.51339 .14132 m .50868 .13153 L .5134 .14121 L F
.5134 .14121 m .50868 .13153 L .50934 .13008 L F
.51275 .15826 m .5143 .15501 L .51326 .16285 L .313 .037 0 r
F
.51143 .21728 m .51654 .14787 L .51094 .19705 L .702 .191 0 r
F
.51047 .20117 m .51647 .14675 L .51263 .15697 L .313 .037 0 r
F
.51143 .21728 m .51094 .19705 L .51046 .20126 L .702 .191 0 r
F
.51046 .20147 m .51096 .19684 L .51047 .20117 L .313 .037 0 r
F
.51096 .19684 m .51647 .14675 L .51047 .20117 L F
.51046 .20126 m .51015 .1647 L .50935 .18299 L .702 .191 0 r
F
.50885 .23426 m .51046 .20126 L .51006 .22031 L .313 .037 0 r
F
.50885 .23426 m .51179 .17413 L .51179 .17398 L F
.51094 .19705 m .51015 .1647 L .51046 .20126 L .702 .191 0 r
F
.5101 .21996 m .51647 .14675 L .51046 .20147 L .313 .037 0 r
F
.5158 .15441 m .51654 .14787 L .51647 .14675 L F
.51654 .14787 m .50942 .13307 L .51015 .1647 L .768 .363 0 r
F
.51348 .13913 m .51448 .11903 L .5144 .12029 L .313 .037 0 r
F
.5135 .13911 m .51448 .11903 L .51348 .13913 L F
.51654 .14787 m .50934 .13008 L .5158 .1374 L .745 .322 0 r
F
.51094 .19705 m .51654 .14787 L .5113 .16168 L .702 .191 0 r
F
.51825 .12541 m .5182 .12584 L .51824 .12541 L .94 .37 0 r
F
.51143 .21728 m .51822 .12536 L .51826 .12539 L .702 .191 0 r
F
.51143 .21728 m .51735 .14576 L .51654 .14787 L F
.50885 .23426 m .51672 .15032 L .51654 .14787 L .313 .037 0 r
F
.50885 .23426 m .51654 .14787 L .5158 .15441 L F
.51672 .15032 m .51358 .14172 L .51654 .14787 L .745 .322 0 r
F
.51358 .14172 m .50934 .13008 L .51654 .14787 L F
.51704 .14522 m .50971 .13078 L .50991 .13264 L .768 .363 0 r
F
.51735 .14576 m .51705 .14519 L .51704 .14522 L F
.51705 .14519 m .50971 .13078 L .51704 .14522 L F
.51015 .1647 m .50869 .13047 L .5085 .16904 L F
.50939 .13172 m .50869 .13047 L .51015 .1647 L F
.51672 .15032 m .50854 .13183 L .50868 .13153 L .745 .322 0 r
F
.51672 .15032 m .50868 .13153 L .51358 .14172 L F
.51654 .14787 m .50939 .13172 L .50942 .13307 L .768 .363 0 r
F
.51735 .14576 m .51704 .14522 L .51654 .14787 L F
.51704 .14522 m .50939 .13172 L .51654 .14787 L F
.5144 .12029 m .51448 .11903 L .51447 .11886 L .313 .037 0 r
F
.5158 .1374 m .50934 .13008 L .51447 .11886 L .745 .322 0 r
F
.52153 .11523 m .51688 .10982 L .51055 .11295 L .828 .83 0 r
F
.51533 .12251 m .51144 .1111 L .50622 .11511 L .822 .572 0 r
F
.51533 .12251 m .50622 .11511 L .50649 .116 L F
.51244 .13549 m .51533 .12251 L .50956 .12942 L .768 .363 0 r
F
.51668 .1402 m .51533 .12251 L .51244 .13549 L F
.51533 .12251 m .50649 .116 L .50956 .12942 L .822 .572 0 r
F
.51519 .12365 m .5114 .1115 L .5062 .11551 L .81 .545 0 r
F
.50956 .12942 m .50576 .11547 L .50869 .13047 L .822 .572 0 r
F
.50649 .116 m .50576 .11547 L .50956 .12942 L F
.50648 .11649 m .5062 .11551 L .50573 .11587 L .81 .545 0 r
F
.51519 .12365 m .5062 .11551 L .50648 .11649 L F
.50991 .13264 m .50922 .12983 L .50939 .13172 L .768 .363 0 r
F
.50971 .13078 m .50922 .12983 L .50991 .13264 L F
.51705 .14519 m .51668 .1402 L .51244 .13549 L F
.50971 .13078 m .50956 .12942 L .50922 .12983 L F
.51705 .14519 m .50956 .12942 L .50971 .13078 L F
.51672 .15032 m .51519 .12365 L .50948 .13068 L .745 .322 0 r
F
.50964 .13245 m .50948 .13068 L .50911 .13113 L F
.51672 .15032 m .50948 .13068 L .50964 .13245 L F
.50649 .116 m .50622 .11511 L .50576 .11547 L .822 .572 0 r
F
.50603 .11564 m .50204 .10664 L .50573 .11587 L .835 .709 0 r
F
.5114 .1115 m .5066 .10901 L .50603 .11564 L F
.5066 .10901 m .50204 .10664 L .50603 .11564 L F
.5005 .11235 m .49872 .1087 L .49665 .11007 L .93 .745 0 r
F
.50939 .13172 m .50922 .12983 L .50869 .13047 L .768 .363 0 r
F
.50911 .13113 m .50573 .11587 L .50854 .13183 L .81 .545 0 r
F
.50948 .13068 m .50937 .13025 L .50911 .13113 L F
.50937 .13025 m .50573 .11587 L .50911 .13113 L F
.51519 .12365 m .50648 .11649 L .50948 .13068 L F
.50648 .11649 m .50573 .11587 L .50948 .13068 L F
.51829 .12504 m .51822 .12536 L .51826 .12503 L 1 .429 0 r
F
.50885 .23426 m .5101 .21996 L .51046 .20147 L .313 .037 0 r
F
.51073 .18845 m .5113 .16168 L .51015 .1647 L .702 .191 0 r
F
.51094 .19705 m .5113 .16168 L .51073 .18845 L F
.52414 .1354 m .51533 .12251 L .51735 .14576 L .635 .288 0 r
F
.51825 .12541 m .51826 .12539 L .51829 .12504 L .053 0 0 r
F
.51826 .12539 m .51822 .12536 L .51829 .12504 L .702 .191 0 r
F
.52414 .1354 m .52103 .11733 L .51533 .12251 L .635 .288 0 r
F
.52121 .18627 m .52414 .1354 L .51735 .14576 L .525 .071 0 r
F
.52749 .17457 m .52414 .1354 L .52121 .18627 L .341 .049 0 r
F
.52749 .17457 m .52945 .12997 L .52414 .1354 L F
.52875 .13422 m .52088 .11845 L .52354 .13935 L .416 .088 0 r
F
.52875 .13422 m .52558 .11474 L .52088 .11845 L F
.51816 .20431 m .52354 .13935 L .51672 .15032 L .491 .065 0 r
F
.5239 .19416 m .52354 .13935 L .51816 .20431 L .317 .041 0 r
F
.5239 .19416 m .52875 .13422 L .52354 .13935 L F
.53028 .17703 m .52981 .15018 L .52749 .17457 L .153 .011 0 r
F
.52981 .15018 m .52945 .12997 L .52827 .1568 L F
.52981 .15018 m .52827 .1568 L .52749 .17457 L F
.51153 .3065 m .51601 .27104 L .51535 .27004 L .038 0 0 r
F
.51132 .30857 m .51176 .30501 L .51153 .3065 L F
.51176 .30501 m .51601 .27104 L .51153 .3065 L F
.51132 .30857 m .51535 .27004 L .51285 .28668 L F
.51479 .28396 m .52571 .2086 L .51601 .27104 L 0 0 0 r
F
.52571 .2086 m .53028 .17703 L .52489 .21254 L F
.52571 .2086 m .52489 .21254 L .51601 .27104 L F
.54736 .10472 m .54053 .10079 L .54687 .10548 L .309 .359 0 r
F
.54862 .1028 m .54064 .10081 L .54736 .10472 L F
.54064 .10081 m .54053 .10079 L .54736 .10472 L F
.54875 .10234 m .54053 .10079 L .54862 .1028 L F
.54777 .1058 m .54687 .10548 L .54766 .10621 L .207 .156 0 r
F
.57483 .11128 m .56362 .11353 L .56984 .11717 L .587 .733 0 r
F
.57483 .11128 m .56827 .10801 L .56362 .11353 L F
.56815 .10843 m .55727 .11028 L .56353 .11388 L .584 .734 0 r
F
.56815 .10843 m .56155 .10519 L .55727 .11028 L F
.56122 .11274 m .55539 .10639 L .5532 .1097 L .174 .092 0 r
F
.55496 .10831 m .5489 .10237 L .54687 .10548 L .207 .156 0 r
F
.5489 .10237 m .54877 .10227 L .54053 .10079 L .309 .359 0 r
F
.54618 .10107 m .54877 .10227 L .54054 .10076 L .512 .058 0 r
F
.54913 .10123 m .54877 .10227 L .54618 .10107 L F
.54913 .10123 m .54054 .10076 L .5409 .10031 L F
.54974 .09872 m .54947 .09951 L .54877 .10226 L .187 .004 0 r
F
.54916 .10038 m .54246 .0976 L .54478 .09932 L .382 .047 0 r
F
.54916 .10038 m .54478 .09932 L .54877 .10227 L F
.54891 .10234 m .54877 .10227 L .5489 .10237 L F
.55584 .10451 m .54913 .10123 L .55539 .10639 L 0 .074 0 r
F
.55584 .10451 m .54975 .09869 L .54913 .10123 L F
.54938 .10047 m .54877 .10227 L .54891 .10234 L .382 .047 0 r
F
.56122 .11274 m .5532 .1097 L .55904 .11564 L .174 .092 0 r
F
.55496 .10831 m .54777 .1058 L .55291 .11104 L .207 .156 0 r
F
.54777 .1058 m .54766 .10621 L .55291 .11104 L F
.5253 .21143 m .52838 .19644 L .53028 .17703 L 0 0 0 r
F
.52952 .18477 m .53163 .15094 L .53028 .17703 L F
.53163 .15094 m .5317 .15038 L .53028 .17703 L F
.51554 .27104 m .52134 .23244 L .52417 .21129 L F
.5226 .22176 m .52417 .21129 L .52524 .20338 L F
.51554 .27104 m .52417 .21129 L .5226 .22176 L F
.51173 .29806 m .51192 .29481 L .51117 .30194 L .739 .151 0 r
F
.5112 .3223 m .50907 .30901 L .50877 .3236 L .116 .009 0 r
F
.51068 .31838 m .51119 .30859 L .50944 .30893 L F
.51192 .29481 m .51143 .29773 L .51187 .29526 L .739 .151 0 r
F
.5112 .3223 m .50944 .30893 L .50924 .31006 L .116 .009 0 r
F
.51187 .29526 m .51141 .29786 L .50979 .31517 L .739 .151 0 r
F
.50955 .30891 m .51386 .2723 L .50907 .30901 L .038 0 0 r
F
.51285 .28668 m .51386 .2723 L .50955 .30891 L F
.51386 .2723 m .51297 .2777 L .50907 .30901 L F
.50979 .31517 m .51227 .28863 L .51076 .28507 L 0 0 0 r
F
.5101 .30832 m .51157 .29835 L .51166 .29819 L 1 .806 0 r
F
.51171 .29809 m .51166 .29819 L .51209 .29144 L .739 .151 0 r
F
.51061 .31742 m .51173 .29806 L .50979 .31517 L F
.51173 .29806 m .51117 .30194 L .50979 .31517 L F
.51192 .29481 m .51227 .28863 L .51141 .29786 L F
.51061 .31742 m .51209 .29144 L .5119 .29508 L F
.51172 .29771 m .51352 .2852 L .51351 .28525 L 0 0 0 r
F
.51166 .29819 m .51173 .29771 L .51172 .29771 L F
.51173 .29771 m .52524 .20338 L .51172 .29771 L F
.51166 .29819 m .51674 .26369 L .51554 .27104 L F
.5119 .29508 m .51209 .29144 L .51227 .28863 L .739 .151 0 r
F
.51285 .28668 m .51535 .27004 L .51448 .26873 L .038 0 0 r
F
.51285 .28668 m .51448 .26873 L .51386 .2723 L F
.51166 .29819 m .52245 .22275 L .51227 .28863 L 0 0 0 r
F
.52245 .22275 m .525 .20494 L .52115 .23025 L F
.52245 .22275 m .52115 .23025 L .51227 .28863 L F
.51386 .2723 m .51448 .26873 L .51415 .26823 L .038 0 0 r
F
.51157 .29835 m .5155 .27185 L .51166 .29819 L 1 .806 0 r
F
.51061 .31742 m .51166 .29819 L .51171 .29809 L .739 .151 0 r
F
.51115 .32196 m .51132 .30857 L .51119 .30859 L .116 .009 0 r
F
.51115 .32196 m .51119 .30859 L .51068 .31838 L F
.5112 .3223 m .5112 .32144 L .51115 .32196 L F
.5112 .32144 m .51132 .30857 L .51115 .32196 L F
.51674 .26369 m .52134 .23244 L .51554 .27104 L 0 0 0 r
F
.5155 .27185 m .52134 .23244 L .51398 .28245 L 1 .806 0 r
F
.5155 .27185 m .51398 .28245 L .51166 .29819 L F
.51143 .29773 m .51141 .29786 L .51187 .29526 L .739 .151 0 r
F
.51351 .28525 m .52524 .20338 L .525 .20494 L 0 0 0 r
F
.51352 .2852 m .52524 .20338 L .51351 .28525 L F
.525 .20494 m .52473 .20657 L .51227 .28863 L F
.51386 .2723 m .51415 .26823 L .51297 .2777 L .038 0 0 r
F
.51227 .28863 m .52211 .2087 L .51076 .28507 L F
.51227 .28863 m .52536 .20243 L .5239 .19416 L F
.5101 .30832 m .51401 .27275 L .52134 .23244 L 1 .806 0 r
F
.50924 .31006 m .50944 .30893 L .50907 .30901 L .116 .009 0 r
F
.50877 .3236 m .50907 .30901 L .50675 .31176 L .403 .061 0 r
F
.50979 .31517 m .51046 .2943 L .50772 .31515 L 0 0 0 r
F
.51046 .2943 m .51076 .28507 L .50926 .29997 L F
.51046 .2943 m .50926 .29997 L .50772 .31515 L F
.50598 .31538 m .50675 .31176 L .50532 .31345 L .403 .061 0 r
F
.50877 .3236 m .50675 .31176 L .50598 .31538 L F
.51236 .32947 m .5112 .3223 L .50877 .3236 L .213 .043 0 r
F
.51031 .32582 m .50979 .31517 L .50772 .31515 L .09 .01 0 r
F
.50836 .31611 m .51143 .29258 L .5101 .30832 L 1 .83 0 r
F
.51143 .29258 m .51401 .27275 L .51179 .29291 L F
.51143 .29258 m .51179 .29291 L .5101 .30832 L F
.50507 .31303 m .50696 .29351 L .50515 .31246 L 1 .81 0 r
F
.50438 .31811 m .50507 .31303 L .50508 .31381 L F
.5051 .31747 m .50438 .31811 L .50508 .31381 L 1 .827 0 r
F
.50516 .32647 m .50438 .31811 L .5051 .31747 L F
.5053 .32665 m .50532 .31345 L .50508 .31381 L .669 .212 0 r
F
.5053 .32665 m .50508 .31381 L .50511 .3193 L F
.50877 .3236 m .50532 .31345 L .5053 .32665 L .403 .061 0 r
F
.50772 .31515 m .50709 .29963 L .50438 .31811 L .348 .045 0 r
F
.50438 .31811 m .50533 .30692 L .50507 .31303 L 1 .81 0 r
F
.50533 .30692 m .50672 .29069 L .50507 .31303 L F
.50709 .29963 m .50533 .30692 L .50438 .31811 L .348 .045 0 r
F
.52536 .20243 m .52727 .16397 L .5239 .19416 L .124 .002 0 r
F
.52727 .16397 m .52875 .13422 L .52609 .16704 L F
.52727 .16397 m .52609 .16704 L .5239 .19416 L F
.53163 .15094 m .53192 .1462 L .5317 .15038 L 0 0 0 r
F
.52983 .17539 m .53192 .1462 L .52952 .18477 L F
.53192 .1462 m .53265 .13613 L .5318 .15179 L F
.53265 .13613 m .53323 .12796 L .53271 .1367 L F
.53265 .13613 m .53271 .1367 L .5318 .15179 L F
.53225 .13354 m .52558 .11474 L .52875 .13422 L .241 .046 0 r
F
.51082 .22792 m .51672 .15032 L .50885 .23426 L .491 .065 0 r
F
.51748 .17892 m .51672 .15032 L .51082 .22792 L F
.51735 .14576 m .51725 .14466 L .51705 .14519 L .768 .363 0 r
F
.51725 .14466 m .51533 .12251 L .51705 .14519 L F
.52354 .13935 m .51519 .12365 L .51672 .15032 L .604 .233 0 r
F
.52354 .13935 m .52088 .11845 L .51519 .12365 L F
.51672 .15032 m .50911 .13113 L .50927 .13349 L .745 .322 0 r
F
.52777 .11161 m .51688 .10982 L .52153 .11523 L .761 .796 0 r
F
.5169 .10967 m .51213 .10474 L .50652 .10743 L .825 .864 0 r
F
.52249 .10663 m .51212 .10483 L .51688 .10982 L .764 .828 0 r
F
.52777 .11161 m .52249 .10663 L .51688 .10982 L .761 .796 0 r
F
.52249 .10663 m .51709 .10204 L .51212 .10483 L .764 .828 0 r
F
.52103 .11733 m .51144 .1111 L .51533 .12251 L .714 .526 0 r
F
.51688 .10982 m .51212 .10483 L .50651 .10752 L .823 .859 0 r
F
.52103 .11733 m .51643 .10754 L .51144 .1111 L .714 .526 0 r
F
.52088 .11845 m .5114 .1115 L .51519 .12365 L .698 .492 0 r
F
.52088 .11845 m .51638 .10795 L .5114 .1115 L F
.52577 .11349 m .51643 .10754 L .52103 .11733 L .583 .445 0 r
F
.52577 .11349 m .52063 .1044 L .51643 .10754 L F
.52558 .11474 m .51638 .10795 L .52088 .11845 L .559 .398 0 r
F
.52558 .11474 m .52057 .10488 L .51638 .10795 L F
.52945 .11071 m .52063 .1044 L .52577 .11349 L .826 .286 0 r
F
.52608 .11441 m .52057 .10488 L .52558 .11474 L .825 .29 0 r
F
.5292 .11229 m .52061 .10491 L .52608 .11441 L F
.52061 .10491 m .52057 .10488 L .52608 .11441 L F
.52061 .10491 m .50867 .2121 L .52057 .10488 L F
.53225 .13354 m .5292 .11229 L .52558 .11474 L .241 .046 0 r
F
.5292 .11229 m .51346 .18877 L .52061 .10491 L .825 .29 0 r
F
.51346 .18877 m .51028 .20425 L .52011 .11079 L F
.50672 .29069 m .51816 .20431 L .50885 .23426 L .561 .069 0 r
F
.49802 .31751 m .50867 .2121 L .5292 .11229 L .863 .178 0 r
F
.53253 .13516 m .5292 .11229 L .53225 .13354 L .703 .175 0 r
F
.53256 .13528 m .52974 .11597 L .53253 .13516 L F
.52974 .11597 m .5292 .11229 L .53253 .13516 L F
.53245 .13882 m .53452 .12992 L .53323 .12796 L 0 0 0 r
F
.52838 .19644 m .52983 .17539 L .52952 .18477 L F
.51838 .2592 m .52818 .1984 L .52838 .19644 L F
.52818 .1984 m .52833 .19637 L .52838 .19644 L F
.52833 .19637 m .52983 .17539 L .52838 .19644 L F
.53192 .1462 m .5318 .15179 L .53028 .17703 L F
.52833 .19637 m .53401 .13548 L .53245 .13882 L F
.53401 .13548 m .53452 .12992 L .53306 .13619 L F
.53401 .13548 m .53306 .13619 L .53245 .13882 L F
.52841 .19596 m .53452 .12992 L .52833 .19637 L F
.52536 .20243 m .53225 .13354 L .52875 .13422 L .124 .002 0 r
F
.525 .20494 m .52524 .20338 L .52536 .20243 L 0 0 0 r
F
.525 .20494 m .52536 .20243 L .52473 .20657 L F
.52268 .22245 m .52626 .18789 L .52536 .20243 L F
.52134 .23244 m .52236 .22319 L .52268 .22245 L F
.52236 .22319 m .52626 .18789 L .52268 .22245 L F
.52626 .18789 m .52805 .17509 L .52536 .20243 L F
.53108 .14419 m .53148 .14129 L .52536 .20243 L F
.52626 .18789 m .53108 .14419 L .52805 .17509 L F
.52279 .21933 m .53181 .15216 L .52955 .15803 L F
.51543 .263 m .51595 .25949 L .51593 .2622 L F
.51595 .25949 m .5303 .16118 L .51749 .25125 L F
.51595 .25949 m .51749 .25125 L .51593 .2622 L F
.52134 .23244 m .52351 .21583 L .52279 .21933 L F
.52351 .21583 m .53181 .15216 L .52279 .21933 L F
.51715 .25551 m .52886 .17263 L .52134 .23244 L F
.51593 .2622 m .52886 .17263 L .51715 .25551 L F
.51593 .2622 m .5303 .16118 L .52886 .17263 L F
.52847 .19527 m .53508 .13075 L .53452 .12992 L F
.53181 .15216 m .53339 .14004 L .52955 .15803 L F
.5303 .16118 m .53267 .14495 L .53019 .16457 L F
.53267 .14495 m .53339 .14004 L .53266 .14562 L F
.53267 .14495 m .53266 .14562 L .53019 .16457 L F
.53108 .14419 m .53225 .13354 L .53148 .14129 L F
.53339 .14004 m .53275 .13585 L .53256 .13528 L .703 .175 0 r
F
.53275 .13585 m .53229 .13276 L .53229 .13282 L F
.53275 .13585 m .53229 .13282 L .53256 .13528 L F
.53229 .13276 m .5292 .11229 L .53256 .13528 L F
.52955 .15803 m .53339 .14004 L .53225 .13354 L 0 0 0 r
F
.51076 .28507 m .5239 .19416 L .51816 .20431 L .31 .034 0 r
F
.53339 .14004 m .49802 .31751 L .5292 .11229 L .703 .175 0 r
F
.51076 .28507 m .51561 .23213 L .50672 .29069 L .31 .034 0 r
F
.51568 .2314 m .51161 .25375 L .50672 .29069 L F
.50172 .32194 m .50289 .31709 L .50061 .32049 L .669 .212 0 r
F
.53267 .14495 m .53268 .14492 L .53339 .14004 L 0 0 0 r
F
.53027 .16144 m .5333 .14069 L .53339 .14004 L F
.5333 .14069 m .52304 .19211 L .53339 .14004 L F
.49867 .31439 m .49802 .31751 L .5333 .14069 L F
.49972 .32813 m .49834 .3195 L .49867 .31439 L 1 .471 0 r
F
.49867 .31439 m .49784 .32178 L .49802 .31751 L 0 0 0 r
F
.49834 .3195 m .49833 .31941 L .49867 .31439 L 1 .471 0 r
F
.49972 .32813 m .49867 .31439 L .53164 .149 L F
.52019 .21174 m .49833 .31941 L .49867 .31439 L 0 0 0 r
F
.51968 .21527 m .49833 .31941 L .52019 .21174 L F
.52304 .19211 m .49869 .31416 L .52311 .19162 L F
.49869 .31416 m .49869 .31415 L .52311 .19162 L F
.52304 .19211 m .52311 .19162 L .53339 .14004 L F
.52025 .21346 m .53332 .13958 L .53339 .14005 L 1 .471 0 r
F
.49972 .32813 m .52051 .21148 L .52025 .21346 L F
.52051 .21148 m .53332 .13958 L .52025 .21346 L F
.49972 .32813 m .53339 .14005 L .5333 .14069 L F
.5303 .16118 m .53027 .16144 L .53268 .14492 L 0 0 0 r
F
.5303 .16118 m .53268 .14492 L .53267 .14495 L F
.5303 .16118 m .53019 .16457 L .52134 .23244 L F
.51561 .26191 m .5333 .14069 L .5345 .13463 L .705 .177 0 r
F
.53027 .16144 m .5297 .16642 L .5333 .14069 L 0 0 0 r
F
.51595 .25949 m .51708 .25182 L .52124 .22323 L F
.51708 .25182 m .52136 .22252 L .52124 .22323 L F
.51401 .27275 m .51543 .263 L .51593 .2622 L F
.51401 .27275 m .51561 .26191 L .51595 .25949 L F
.51567 .26147 m .52202 .21848 L .51595 .25949 L F
.51561 .26191 m .51575 .26098 L .51567 .26147 L F
.51575 .26098 m .52202 .21848 L .51567 .26147 L F
.51984 .24429 m .51561 .26191 L .53508 .13075 L .705 .177 0 r
F
.52301 .21114 m .52337 .20871 L .5303 .16118 L 0 0 0 r
F
.52337 .20871 m .52642 .18845 L .53007 .16284 L F
.52337 .20871 m .53007 .16284 L .5303 .16118 L F
.52124 .22323 m .52247 .21501 L .52301 .21114 L F
.52247 .21501 m .52642 .18845 L .52301 .21114 L F
.52642 .18845 m .52907 .17065 L .5303 .16118 L F
.52202 .21848 m .52881 .17246 L .52124 .22323 L F
.52881 .17246 m .52907 .17065 L .52885 .17215 L F
.52881 .17246 m .52885 .17215 L .52124 .22323 L F
.52907 .17065 m .5297 .16642 L .5303 .16118 L F
.52211 .2087 m .5239 .19416 L .52005 .22079 L .038 0 0 r
F
.52211 .2087 m .52005 .22079 L .51076 .28507 L F
.50709 .29963 m .50672 .29069 L .50533 .30692 L .348 .045 0 r
F
.50772 .31515 m .51076 .28507 L .50672 .29069 L F
.51561 .26191 m .49972 .32813 L .5333 .14069 L .705 .177 0 r
F
.51708 .25182 m .52202 .21848 L .52136 .22252 L 0 0 0 r
F
.52853 .19499 m .53508 .13075 L .52847 .19527 L F
.5489 .10237 m .54875 .10234 L .54862 .1028 L .309 .359 0 r
F
.53819 .14305 m .53782 .14481 L .53813 .14304 L .896 .316 0 r
F
.53782 .14481 m .53782 .14481 L .53782 .1448 L .669 .212 0 r
F
.53787 .14481 m .53782 .1448 L .53819 .14305 L F
.56313 .1232 m .55738 .11915 L .54982 .12412 L .698 .793 0 r
F
.56032 .12665 m .54959 .12421 L .55446 .1314 L .464 .408 0 r
F
.56032 .12665 m .5551 .11964 L .54959 .12421 L F
.55472 .12128 m .54418 .11884 L .5493 .12553 L .476 .452 0 r
F
.55472 .12128 m .54926 .11471 L .54418 .11884 L F
.54978 .10312 m .5489 .10237 L .5499 .10336 L 0 .031 0 r
F
.55512 .1077 m .54938 .10047 L .5489 .10237 L F
.52818 .1984 m .52841 .19596 L .52833 .19637 L 0 0 0 r
F
.51838 .2592 m .52838 .19644 L .5253 .21143 L F
.52818 .1984 m .52853 .19499 L .52847 .19527 L F
.52015 .24258 m .53281 .14769 L .52818 .1984 L .705 .177 0 r
F
.53281 .14769 m .53404 .13851 L .53281 .15105 L F
.53281 .14769 m .53281 .15105 L .52818 .1984 L F
.53508 .13075 m .53261 .14314 L .53149 .118 L .696 .168 0 r
F
.52003 .2429 m .53281 .14764 L .52015 .24258 L .705 .177 0 r
F
.53281 .14764 m .53404 .13851 L .53281 .14769 L F
.53281 .14764 m .53281 .14769 L .52015 .24258 L F
.53404 .13851 m .53508 .13075 L .53465 .13499 L F
.53404 .13851 m .53465 .13499 L .52818 .1984 L F
.5345 .13463 m .5333 .14069 L .53508 .13075 L F
.53261 .14314 m .49862 .31378 L .53149 .118 L .696 .168 0 r
F
.53149 .118 m .53074 .12249 L .52945 .11071 L F
.53192 .10937 m .52938 .1069 L .53087 .09984 L .229 .077 0 r
F
.52912 .10523 m .52398 .10164 L .52839 .10049 L F
.52521 .10284 m .52398 .10164 L .52912 .10523 L F
.53117 .09976 m .52398 .10164 L .52134 .09899 L .483 0 0 r
F
.52473 .10237 m .52637 .09941 L .52398 .10164 L .229 .077 0 r
F
.52938 .1069 m .52839 .10049 L .53087 .09984 L F
.52928 .10463 m .52637 .09941 L .52473 .10237 L F
.52398 .10164 m .52103 .10049 L .52109 .09896 L .529 .548 0 r
F
.5191 .0996 m .51494 .09811 L .51631 .0983 L F
.51624 .09862 m .51494 .09811 L .5191 .0996 L F
.52159 .09708 m .51528 .09515 L .51173 .09636 L .431 .644 0 r
F
.52158 .09714 m .51527 .09522 L .51173 .09639 L .423 .627 0 r
F
.52448 .09607 m .51528 .09515 L .52159 .09708 L .655 .794 0 r
F
.52476 .09598 m .51822 .0954 L .52448 .09607 L F
.51822 .0954 m .51528 .09515 L .52448 .09607 L F
.51528 .09515 m .50913 .09156 L .50601 .09373 L .72 .85 0 r
F
.51825 .0925 m .50913 .09156 L .51528 .09515 L .669 .821 0 r
F
.52476 .09598 m .51825 .0925 L .51528 .09515 L .655 .794 0 r
F
.51824 .09259 m .50913 .0916 L .51499 .09506 L .665 .816 0 r
F
.5154 .0951 m .51499 .09506 L .51527 .09522 L F
.51824 .09259 m .51499 .09506 L .5154 .0951 L F
.5316 .09698 m .52476 .09598 L .52159 .09708 L .328 .368 0 r
F
.52474 .09613 m .51527 .09522 L .52158 .09714 L .65 .787 0 r
F
.51577 .09843 m .51788 .09558 L .51494 .09811 L .529 .548 0 r
F
.52103 .10049 m .51631 .0983 L .52109 .09896 L F
.5214 .09905 m .52109 .09896 L .52134 .09899 L F
.52398 .10164 m .52109 .09896 L .5214 .09905 L F
.52162 .0993 m .51788 .09558 L .51577 .09843 L F
.51479 .09531 m .50601 .09373 L .51173 .09636 L .72 .85 0 r
F
.51528 .09515 m .50758 .09397 L .51479 .09531 L F
.50758 .09397 m .50601 .09373 L .51479 .09531 L F
.50601 .09373 m .50035 .08998 L .49733 .09166 L .767 .893 0 r
F
.50913 .09156 m .50035 .08998 L .50601 .09373 L .452 .695 0 r
F
.50913 .0916 m .50035 .09 L .50581 .09364 L .448 .687 0 r
F
.50611 .09369 m .50581 .09364 L .506 .09377 L F
.50913 .0916 m .50581 .09364 L .50611 .09369 L F
.51173 .09636 m .50241 .09483 L .50741 .09869 L .523 .772 0 r
F
.51173 .09636 m .50601 .09373 L .50241 .09483 L F
.51527 .09522 m .506 .09377 L .51173 .09639 L .718 .847 0 r
F
.50741 .09869 m .49826 .09663 L .50252 .10081 L .795 .924 0 r
F
.50741 .09869 m .50241 .09483 L .49826 .09663 L F
.51173 .09639 m .50241 .09485 L .5074 .09872 L .517 .766 0 r
F
.51173 .09639 m .506 .09377 L .50241 .09485 L F
.51418 .09802 m .50586 .0954 L .51159 .0977 L .689 .745 0 r
F
.51494 .09811 m .50678 .09568 L .51418 .09802 L F
.50678 .09568 m .50586 .0954 L .51418 .09802 L F
.50601 .09373 m .49733 .09166 L .50241 .09483 L .767 .893 0 r
F
.50241 .09483 m .49396 .09255 L .49826 .09663 L .62 .843 0 r
F
.50241 .09483 m .49733 .09166 L .49396 .09255 L F
.506 .09377 m .49733 .09167 L .50241 .09485 L .766 .891 0 r
F
.506 .09377 m .50035 .09 L .49733 .09167 L F
.51527 .09522 m .50913 .0916 L .506 .09377 L .718 .847 0 r
F
.50241 .09485 m .49733 .09167 L .49396 .09256 L .618 .841 0 r
F
.50586 .0954 m .50029 .09088 L .49727 .09262 L .769 .844 0 r
F
.50897 .09319 m .50029 .09088 L .50586 .0954 L .231 .278 0 r
F
.51494 .09811 m .50897 .09319 L .50586 .0954 L .689 .745 0 r
F
.50897 .09328 m .50028 .09091 L .50566 .09532 L .213 .247 0 r
F
.50252 .10081 m .49826 .09663 L .4937 .09823 L .83 .945 0 r
F
.5074 .09872 m .50241 .09485 L .49826 .09664 L .795 .923 0 r
F
.49826 .09663 m .49021 .09387 L .4937 .09823 L .826 .951 0 r
F
.50241 .09485 m .49396 .09256 L .49826 .09664 L .618 .841 0 r
F
.50586 .0954 m .49727 .09262 L .50233 .09577 L .769 .844 0 r
F
.50594 .09541 m .50566 .09532 L .50585 .09548 L .213 .247 0 r
F
.50897 .09328 m .50566 .09532 L .50594 .09541 L F
.52474 .09613 m .51824 .09259 L .51527 .09522 L .65 .787 0 r
F
.51788 .09558 m .50897 .09319 L .51494 .09811 L .6 .688 0 r
F
.51785 .09583 m .50897 .09328 L .51463 .09807 L .59 .674 0 r
F
.51504 .09821 m .51463 .09807 L .51492 .09831 L F
.51785 .09583 m .51463 .09807 L .51504 .09821 L F
.52103 .10049 m .51624 .09862 L .5191 .0996 L .529 .548 0 r
F
.52398 .10164 m .52162 .0993 L .51577 .09843 L F
.52637 .09941 m .524 .09834 L .52553 .10019 L .371 .395 0 r
F
.53159 .09708 m .52474 .09613 L .52158 .09714 L .305 .312 0 r
F
.5273 .09294 m .51825 .0925 L .52476 .09598 L .586 .75 0 r
F
.53403 .0964 m .5273 .09294 L .52476 .09598 L .558 .709 0 r
F
.52727 .09313 m .51824 .09259 L .52435 .09591 L .578 .74 0 r
F
.52489 .09594 m .52435 .09591 L .52474 .09613 L F
.52727 .09313 m .52435 .09591 L .52489 .09594 L F
.53391 .09643 m .52476 .09598 L .5316 .09698 L .558 .709 0 r
F
.53403 .0964 m .52961 .0962 L .53391 .09643 L F
.52961 .0962 m .52476 .09598 L .53391 .09643 L F
.52637 .09941 m .52003 .09326 L .51788 .09558 L .371 .395 0 r
F
.5273 .09294 m .52046 .08981 L .51825 .0925 L .586 .75 0 r
F
.52727 .09313 m .52045 .08993 L .51824 .09259 L .578 .74 0 r
F
.52891 .08999 m .52046 .08981 L .5273 .09294 L .497 .687 0 r
F
.53582 .0932 m .5273 .09294 L .53403 .0964 L .448 .628 0 r
F
.53582 .0932 m .52891 .08999 L .5273 .09294 L F
.52887 .09024 m .52045 .08993 L .52727 .09313 L .481 .67 0 r
F
.54138 .09607 m .53403 .0964 L .5316 .09698 L .154 .167 0 r
F
.53398 .09672 m .52474 .09613 L .53159 .09708 L .544 .692 0 r
F
.53398 .09672 m .52727 .09313 L .52474 .09613 L F
.5277 .09819 m .52133 .09135 L .52003 .09326 L .179 .1 0 r
F
.52733 .09853 m .52348 .09547 L .52637 .09941 L F
.5277 .09819 m .52599 .09709 L .52733 .09853 L F
.52599 .09709 m .52348 .09547 L .52733 .09853 L F
.52348 .09547 m .52397 .09704 L .52637 .09941 L F
.52035 .09346 m .52033 .09354 L .52637 .09941 L F
.52348 .09547 m .52035 .09346 L .52397 .09704 L F
.53345 .10933 m .53192 .10937 L .5337 .1075 L 0 0 0 r
F
.54044 .10088 m .53253 .11048 L .54042 .10091 L .003 0 0 r
F
.53253 .11048 m .53195 .11118 L .53253 .11048 L F
.53195 .11118 m .53195 .11118 L .53253 .11048 L F
.53253 .11048 m .53253 .11048 L .54042 .10091 L F
.532 .11109 m .53154 .11168 L .54044 .10088 L F
.5323 .1176 m .532 .11109 L .53345 .10933 L 0 0 0 r
F
.532 .11109 m .53192 .10937 L .53292 .10935 L F
.532 .11109 m .53292 .10935 L .53345 .10933 L F
.5333 .14069 m .53339 .14005 L .5334 .14011 L 1 .471 0 r
F
.5334 .14011 m .53332 .13958 L .53508 .13075 L F
.5336 .14538 m .5323 .1176 L .5403 .10061 L 0 0 0 r
F
.5323 .1176 m .5337 .1075 L .5403 .10061 L F
.5409 .10031 m .54054 .10076 L .54062 .10028 L .512 .058 0 r
F
.54054 .10076 m .5403 .10061 L .54062 .10028 L 0 0 0 r
F
.54877 .10227 m .54054 .10076 L .54053 .10079 L .309 .359 0 r
F
.54054 .10076 m .54042 .10091 L .54053 .10079 L .003 0 0 r
F
.5336 .14538 m .5403 .10061 L .54054 .10076 L 0 0 0 r
F
.54062 .10028 m .53192 .10937 L .53117 .09976 L .616 .051 0 r
F
.54246 .0976 m .53429 .10831 L .54044 .10088 L .003 0 0 r
F
.54246 .0976 m .532 .11109 L .53429 .10831 L F
.54877 .10227 m .54246 .0976 L .54054 .10076 L .309 .359 0 r
F
.54877 .10227 m .5336 .14538 L .54054 .10076 L .512 .058 0 r
F
.54246 .0976 m .54042 .10091 L .54054 .10076 L .003 0 0 r
F
.5268 .15714 m .5314 .12012 L .5315 .12046 L .826 .175 0 r
F
.55184 .10489 m .54978 .10312 L .55316 .10651 L 0 .031 0 r
F
.54978 .10312 m .5499 .10336 L .55496 .10831 L F
.55395 .13358 m .5493 .12553 L .54243 .13029 L .58 .449 0 r
F
.55964 .12937 m .5493 .12553 L .55395 .13358 L .396 .297 0 r
F
.55964 .12937 m .55472 .12128 L .5493 .12553 L F
.56972 .1176 m .55738 .11915 L .56313 .1232 L .64 .759 0 r
F
.5644 .12286 m .5551 .11964 L .56032 .12665 L .3 .204 0 r
F
.56972 .1176 m .56353 .11388 L .55738 .11915 L .64 .759 0 r
F
.5644 .12286 m .55904 .11564 L .5551 .11964 L .3 .204 0 r
F
.55852 .11784 m .54926 .11471 L .55472 .12128 L .314 .254 0 r
F
.55852 .11784 m .55291 .11104 L .54926 .11471 L F
.5525 .11289 m .5294 .21032 L .5494 .10058 L .232 .016 0 r
F
.54877 .10227 m .54877 .10226 L .54876 .10228 L .187 .004 0 r
F
.5336 .14538 m .5331 .1215 L .53281 .11889 L 0 0 0 r
F
.53281 .12324 m .53281 .11889 L .53258 .11684 L F
.5336 .14538 m .53281 .11889 L .53281 .12324 L F
.53281 .12333 m .53258 .11684 L .53258 .11685 L F
.5336 .14538 m .53281 .12324 L .53281 .12333 L F
.53281 .12324 m .53258 .11684 L .53281 .12333 L F
.5334 .14116 m .53294 .12712 L .5329 .13033 L F
.53344 .14096 m .53294 .12712 L .5334 .14116 L F
.5329 .13033 m .53258 .11685 L .53248 .12138 L F
.53294 .12712 m .53258 .11685 L .5329 .13033 L F
.53248 .12138 m .53258 .11685 L .53228 .11716 L F
.53228 .11716 m .53258 .11684 L .53204 .11191 L F
.5331 .1215 m .550453 .32564 m .50289 .31709 L .50172 .32194 L .669 .212 0 r
F
.50856 .29961 m .49959 .32915 L .50987 .29132 L .803 .286 0 r
F
.50987 .29132 m .49983 .32826 L .49983 .32826 L 0 0 0 r
F
.50987 .29132 m .49983 .32826 L .49972 .32813 L F
.50856 .29961 m .4994 .33018 L .49959 .32915 L .803 .286 0 r
F
.49983 .32826 m .49959 .32915 L .49972 .32813 L 0 0 0 r
F
.50987 .29132 m .49972 .32813 L .51288 .2759 L F
.50987 .29132 m .49959 .32915 L .5297 .16642 L .803 .286 0 r
F
.49959 .32915 m .49784 .32178 L .49833 .31941 L 1 .487 0 r
F
.49958 .32916 m .49828 .31913 L .49833 .31941 L 1 .567 0 r
F
.49959 .32915 m .49833 .31941 L .49972 .32813 L F
.49958 .32916 m .49833 .31941 L .49959 .32915 L F
.49959 .32915 m .49833 .31941 L .5297 .16642 L 1 .487 0 r
F
.4994 .33018 m .49936 .32998 L .49959 .32915 L F
.49936 .32998 m .49784 .32178 L .49959 .32915 L F
.49983 .32826 m .49958 .32916 L .49959 .32915 L 0 0 0 r
F
.50836 .31611 m .50856 .29961 L .51401 .27275 L 1 .83 0 r
F
.51137 .28591 m .50956 .29254 L .50987 .29132 L 0 0 0 r
F
.50956 .29254 m .49958 .32916 L .50987 .29132 L F
.50987 .29132 m .51561 .26191 L .51401 .27275 L .803 .286 0 r
F
.51026 .2899 m .50987 .29132 L .51288 .2759 L 0 0 0 r
F
.52079 .22254 m .52828 .17537 L .52192 .2188 L .803 .286 0 r
F
.52828 .17537 m .52881 .17246 L .51575 .26098 L F
.52828 .17537 m .5297 .16642 L .52881 .17246 L F
.54917 .10119 m .52223 .21433 L .52934 .1686 L .382 .047 0 r
F
.54904 .10189 m .52223 .21433 L .54917 .10119 L F
.52223 .21433 m .5163 .23921 L .52411 .19689 L F
.52223 .21433 m .52411 .19689 L .52934 .1686 L F
.54866 .1025 m .5336 .14538 L .54858 .10281 L .187 .004 0 r
F
.54938 .10047 m .52934 .1686 L .54799 .10442 L .382 .047 0 r
F
.54938 .10047 m .54904 .10189 L .54917 .10119 L F
.54936 .09989 m .53671 .13641 L .54866 .1025 L .187 .004 0 r
F
.54927 .10008 m .5336 .14538 L .54936 .09989 L F
.53671 .13641 m .5336 .14538 L .54866 .1025 L F
.53639 .13731 m .52934 .1686 L .5336 .14538 L F
.5297 .16642 m .51968 .21527 L .52019 .21174 L 0 0 0 r
F
.5336 .14538 m .53344 .14096 L .5334 .14116 L F
.52934 .1686 m .53294 .11381 L .5336 .14538 L .819 .171 0 r
F
.52934 .1686 m .52532 .1687 L .53025 .15472 L .826 .175 0 r
F
.52934 .1686 m .53025 .15472 L .53372 .14488 L F
.5163 .23921 m .52007 .20976 L .52934 .1686 L F
.52007 .20976 m .52532 .1687 L .52934 .1686 L F
.54916 .10038 m .52934 .1686 L .53639 .13731 L .187 .004 0 r
F
.54975 .09869 m .54877 .10226 L .54877 .10227 L F
.54947 .0995 m .54858 .10281 L .54876 .10228 L F
.54959 .0993 m .54876 .10228 L .54901 .10158 L F
.54975 .09869 m .54876 .10228 L .54959 .0993 L F
.54931 .10051 m .54901 .10158 L .54913 .10123 L F
.54938 .10047 m .54916 .10038 L .54877 .10227 L .382 .047 0 r
F
.54975 .09869 m .54901 .10158 L .54931 .10051 L .187 .004 0 r
F
.54938 .10047 m .53372 .14488 L .54916 .10038 L .382 .047 0 r
F
.5197 .2244 m .5237 .19935 L .54938 .10047 L 1 .74 0 r
F
.50883 .27992 m .50802 .28317 L .50895 .27847 L F
.51331 .25866 m .50895 .27847 L .51432 .25147 L F
.50475 .32914 m .50474 .32882 L .50516 .32647 L 1 .827 0 r
F
.50474 .32882 m .50438 .31811 L .50516 .32647 L F
.50979 .33114 m .50877 .3236 L .50632 .32576 L .459 .106 0 r
F
.50607 .32743 m .50632 .32576 L .5053 .32665 L F
.50979 .33114 m .50632 .32576 L .50607 .32743 L F
.51236 .32947 m .50877 .3236 L .50979 .33114 L .213 .043 0 r
F
.51031 .32582 m .50781 .31552 L .50801 .3268 L .09 .01 0 r
F
.50781 .31552 m .50772 .31515 L .50774 .31598 L F
.50781 .31552 m .50774 .31598 L .50801 .3268 L F
.50801 .3268 m .50438 .31811 L .50474 .32882 L .377 .061 0 r
F
.50801 .3268 m .50772 .31515 L .50438 .31811 L F
.50742 .30422 m .50599 .30885 L .50856 .29961 L .81 .201 0 r
F
.49969 .32932 m .4994 .33018 L .50742 .30422 L F
.4994 .33018 m .49733 .3253 L .49784 .32178 L 1 .487 0 r
F
.49888 .3308 m .49865 .32998 L .4994 .33018 L 1 .317 0 r
F
.49865 .32998 m .49733 .3253 L .49869 .32849 L F
.49865 .32998 m .49869 .32849 L .4994 .33018 L F
.49968 .32926 m .4994 .33018 L .49968 .32923 L .81 .201 0 r
F
.49969 .32932 m .4992 .33022 L .4994 .33018 L F
.4992 .33022 m .49888 .3308 L .4993 .33029 L F
.4992 .33022 m .4993 .33029 L .4994 .33018 L F
.49911 .33016 m .49901 .33008 L .49969 .32932 L .831 .055 0 r
F
.49969 .32932 m .49901 .33008 L .49958 .32916 L F
.50599 .30885 m .49968 .32926 L .50626 .30728 L .81 .201 0 r
F
.49968 .32926 m .49968 .32923 L .50626 .30728 L F
.50146 .33196 m .49969 .32932 L .50598 .3089 L .831 .055 0 r
F
.50597 .31096 m .50598 .3089 L .50742 .30422 L F
.50146 .33196 m .50598 .3089 L .50597 .31096 L F
.50739 .31902 m .50856 .29961 L .50836 .31611 L 1 .717 0 r
F
.50659 .32143 m .50678 .31931 L .50739 .31902 L F
.50678 .31931 m .50856 .29961 L .50739 .31902 L F
.50638 .31996 m .50623 .32031 L .50597 .31096 L .631 .09 0 r
F
.50623 .32031 m .50146 .33196 L .50523 .31443 L F
.50623 .32031 m .50523 .31443 L .50597 .31096 L F
.50421 .32346 m .50146 .33196 L .50638 .31996 L 1 .769 0 r
F
.50801 .3268 m .50474 .32882 L .50483 .32908 L .377 .061 0 r
F
.50926 .33321 m .50801 .3268 L .50475 .32914 L .435 .121 0 r
F
.50673 .32835 m .50512 .32294 L .50645 .32157 L 1 .477 0 r
F
.50661 .32251 m .50645 .32157 L .50659 .32143 L F
.50673 .32835 m .50645 .32157 L .50661 .32251 L F
.50638 .31996 m .50597 .31096 L .50742 .30422 L .631 .09 0 r
F
.50678 .31931 m .5065 .31805 L .50856 .29961 L 1 .717 0 r
F
.5065 .31805 m .50742 .30422 L .50856 .29961 L F
.50638 .31996 m .50534 .31271 L .50678 .31931 L F
.50599 .30885 m .50626 .30728 L .50856 .29961 L .81 .201 0 r
F
.50638 .31996 m .50742 .30422 L .51137 .28591 L .631 .09 0 r
F
.5065 .31805 m .50534 .31271 L .50742 .30422 L 1 .717 0 r
F
.50659 .32143 m .50638 .31996 L .50678 .31931 L F
.50661 .31939 m .50638 .31996 L .50641 .31973 L .631 .09 0 r
F
.50661 .31939 m .50641 .31973 L .51137 .28591 L F
.50754 .31713 m .50661 .31939 L .51137 .28591 L F
.50518 .32047 m .50421 .32346 L .50624 .32002 L 1 .769 0 r
F
.50593 .32015 m .50595 .31694 L .50638 .31996 L 1 .585 0 r
F
.50624 .32002 m .50638 .31996 L .50661 .31939 L 1 .769 0 r
F
.50421 .32346 m .50638 .31996 L .50624 .32002 L F
.50548 .32034 m .50534 .31271 L .50595 .31694 L 1 .585 0 r
F
.50512 .32294 m .50518 .32047 L .50548 .32034 L F
.50146 .33196 m .49983 .33071 L .49969 .32932 L .831 .055 0 r
F
.50518 .32047 m .50063 .33133 L .50146 .33196 L 1 .769 0 r
F
.50518 .32047 m .50534 .31271 L .50548 .32032 L 1 .585 0 r
F
.50512 .32294 m .50595 .31694 L .50592 .32212 L F
.50518 .32047 m .50445 .31801 L .50534 .31271 L F
.50481 .32066 m .50063 .33133 L .50518 .32047 L 1 .769 0 r
F
.50512 .32294 m .50481 .32066 L .50518 .32047 L 1 .585 0 r
F
.50481 .32066 m .50445 .31801 L .50518 .32047 L F
.50481 .32065 m .50481 .32066 L .50518 .32047 L 1 .769 0 r
F
.50657 .31617 m .50481 .32065 L .50518 .32047 L F
.50518 .32047 m .50548 .32032 L .50548 .32034 L 1 .585 0 r
F
.50592 .32212 m .50593 .32015 L .50638 .31996 L F
.50533 .31999 m .50518 .32047 L .50661 .31939 L 1 .769 0 r
F
.50518 .32047 m .50624 .32002 L .50661 .31939 L F
.50657 .31617 m .50533 .31999 L .50754 .31713 L F
.50533 .31999 m .50661 .31939 L .50754 .31713 L F
.50645 .32157 m .50638 .31996 L .50659 .32143 L 1 .585 0 r
F
.50592 .32212 m .50638 .31996 L .50645 .32157 L F
.49969 .32932 m .49958 .32916 L .50742 .30422 L .831 .055 0 r
F
.50534 .31271 m .49969 .32932 L .50742 .30422 L .81 .201 0 r
F
.49916 .33002 m .49888 .3308 L .50011 .32809 L F
.50742 .30422 m .49958 .32916 L .51137 .28591 L .831 .055 0 r
F
.49958 .32916 m .49763 .32352 L .49828 .31913 L 1 .567 0 r
F
.49901 .33008 m .49763 .32352 L .49958 .32916 L 1 .411 0 r
F
.50395 .31435 m .49888 .3308 L .50534 .31271 L 1 .538 0 r
F
.50063 .33133 m .4991 .33015 L .50146 .33196 L .362 0 0 r
F
.49888 .3308 m .49658 .32774 L .49733 .3253 L 1 .317 0 r
F
.49908 .33014 m .49845 .33107 L .49888 .3308 L 1 .538 0 r
F
.4991 .33015 m .49892 .33051 L .49896 .33032 L .362 0 0 r
F
.49908 .33014 m .49896 .33032 L .49901 .33008 L F
.4991 .33015 m .49896 .33032 L .49908 .33014 L F
.49658 .32774 m .49654 .32485 L .49733 .3253 L 1 .619 0 r
F
.49654 .32485 m .49637 .31185 L .49733 .32525 L F
.49654 .32485 m .49733 .32525 L .49733 .3253 L F
.49526 .32768 m .4954 .31655 L .48618 .33206 L 1 .641 0 r
F
.49658 .32774 m .49467 .32136 L .49637 .31185 L 1 .619 0 r
F
.49586 .3276 m .49467 .32136 L .49658 .32774 L .868 .19 0 r
F
.49601 .32663 m .49572 .32443 L .49679 .32647 L .707 .103 0 r
F
.4954 .31655 m .49624 .29903 L .48604 .3234 L 1 .609 0 r
F
.4954 .31655 m .48604 .3234 L .48618 .33206 L F
.49624 .29903 m .49832 .26952 L .48621 .3103 L 1 .594 0 r
F
.49624 .29903 m .48621 .3103 L .48604 .3234 L F
.49832 .26952 m .50147 .22691 L .48699 .28799 L 1 .615 0 r
F
.49832 .26952 m .48699 .28799 L .48621 .3103 L F
.52011 .11079 m .50867 .2121 L .52061 .10491 L .825 .29 0 r
F
.51028 .20425 m .50867 .2121 L .52011 .11079 L F
.51213 .10474 m .50239 .10241 L .50652 .10743 L .82 .885 0 r
F
.51213 .10474 m .50727 .10012 L .50239 .10241 L F
.51709 .10204 m .50727 .10018 L .51212 .10483 L .765 .853 0 r
F
.51212 .10483 m .50238 .10246 L .50651 .10752 L .818 .882 0 r
F
.51212 .10483 m .50727 .10018 L .50238 .10246 L F
.51643 .10754 m .50695 .1035 L .51144 .1111 L .751 .688 0 r
F
.51709 .10204 m .51159 .09777 L .50727 .10018 L .765 .853 0 r
F
.51643 .10754 m .51127 .10075 L .50695 .1035 L .751 .688 0 r
F
.52063 .1044 m .51127 .10075 L .51643 .10754 L .942 .214 0 r
F
.51814 .10666 m .51125 .10093 L .51638 .10795 L .95 .245 0 r
F
.52057 .10488 m .51144 .10101 L .51814 .10666 L F
.51144 .10101 m .51125 .10093 L .51814 .10666 L F
.50252 .10083 m .49826 .09664 L .4937 .09824 L .829 .945 0 r
F
.5074 .09872 m .49826 .09664 L .50252 .10083 L .795 .923 0 r
F
.50727 .10012 m .49818 .09768 L .50239 .10241 L .814 .902 0 r
F
.50239 .10241 m .49818 .09768 L .49363 .09947 L .864 .929 0 r
F
.50727 .10018 m .49818 .09771 L .50238 .10246 L .813 .9 0 r
F
.51144 .1111 m .50695 .1035 L .50205 .10648 L .84 .723 0 r
F
.51638 .10795 m .50694 .10366 L .5114 .1115 L .744 .671 0 r
F
.50727 .10012 m .50233 .09577 L .49818 .09768 L .814 .902 0 r
F
.51159 .0977 m .50233 .09577 L .50727 .10012 L .328 .45 0 r
F
.50727 .10018 m .50233 .09581 L .49818 .09771 L .813 .9 0 r
F
.51159 .09777 m .50233 .09581 L .50727 .10018 L .315 .424 0 r
F
.51127 .10075 m .50219 .0976 L .50695 .1035 L .541 0 0 r
F
.50238 .10246 m .49818 .09771 L .49362 .09949 L .863 .927 0 r
F
.50695 .1035 m .49803 .09982 L .50205 .10648 L .838 .817 0 r
F
.50695 .1035 m .50219 .0976 L .49803 .09982 L F
.50941 .1021 m .50218 .09767 L .50694 .10366 L .573 .002 0 r
F
.51125 .10093 m .50246 .09777 L .50941 .1021 L F
.50246 .09777 m .50218 .09767 L .50941 .1021 L F
.49826 .09664 m .49021 .09387 L .4937 .09824 L .826 .951 0 r
F
.49826 .09663 m .49396 .09255 L .49021 .09387 L F
.49826 .09664 m .49396 .09256 L .49021 .09387 L F
.50233 .09577 m .49392 .0932 L .49818 .09768 L .51 .75 0 r
F
.4937 .09823 m .4862 .09444 L .48885 .09879 L .741 .889 0 r
F
.4937 .09824 m .4862 .09444 L .48885 .0988 L .74 .888 0 r
F
.4937 .09823 m .49021 .09387 L .4862 .09444 L .741 .889 0 r
F
.4937 .09824 m .49021 .09387 L .4862 .09444 L .74 .888 0 r
F
.49818 .09768 m .49017 .09463 L .49363 .09947 L .853 .941 0 r
F
.49818 .09768 m .49392 .0932 L .49017 .09463 L F
.50233 .09581 m .49392 .09322 L .49818 .09771 L .505 .745 0 r
F
.48885 .09879 m .48197 .09532 L .48371 .09983 L .866 .994 0 r
F
.48885 .0988 m .48197 .09532 L .48371 .09983 L F
.48885 .09879 m .4862 .09444 L .48197 .09532 L F
.48885 .0988 m .4862 .09444 L .48197 .09532 L F
.49363 .09947 m .48618 .09502 L .48881 .09964 L .722 .842 0 r
F
.49363 .09947 m .49017 .09463 L .48618 .09502 L F
.49818 .09771 m .49017 .09464 L .49362 .09949 L .852 .94 0 r
F
.49818 .09771 m .49392 .09322 L .49017 .09464 L F
.50219 .0976 m .49386 .09431 L .49803 .09982 L .291 .405 0 r
F
.50219 .0976 m .49715 .09449 L .49386 .09431 L F
.51125 .10093 m .50556 .09997 L .50218 .09767 L .573 .002 0 r
F
.50556 .09997 m .50545 .09995 L .50521 .09978 L F
.50556 .09997 m .50521 .09978 L .50218 .09767 L F
.51638 .10795 m .51125 .10093 L .50694 .10366 L .744 .671 0 r
F
.51336 .11199 m .50545 .09995 L .51125 .10093 L .489 .248 0 r
F
.51126 .10093 m .51336 .11199 L .51125 .10093 L .95 .245 0 r
F
.52057 .10488 m .51346 .1119 L .51126 .10093 L F
.51346 .1119 m .51336 .11199 L .51126 .10093 L F
.50867 .2121 m .51336 .11199 L .52057 .10488 L .152 .01 0 r
F
.51837 .12495 m .51352 .11058 L .52042 .10458 L .163 .014 0 r
F
.51349 .11221 m .51352 .11058 L .51837 .12495 L F
.51349 .11209 m .51626 .10905 L .51352 .11058 L F
.5121 .1873 m .51247 .16732 L .51837 .12495 L F
.51247 .16732 m .51282 .14844 L .51715 .12175 L F
.51282 .14844 m .51322 .12663 L .51495 .12448 L F
.51282 .14844 m .51397 .1355 L .51715 .12175 L F
.51397 .1355 m .515 .12442 L .51715 .12175 L F
.51397 .1355 m .51495 .12448 L .515 .12442 L F
.51322 .12663 m .51349 .11221 L .5141 .11379 L F
.51322 .12663 m .5141 .11379 L .51715 .12175 L F
.51529 .1211 m .51372 .11185 L .51349 .11209 L F
.51555 .12238 m .51372 .11185 L .51529 .1211 L F
.51555 .12238 m .51626 .10905 L .51372 .11185 L F
.51247 .16732 m .51715 .12175 L .51837 .12495 L F
.5121 .1873 m .51555 .12238 L .51349 .11209 L F
.50867 .2121 m .51603 .11089 L .51336 .11199 L .152 .01 0 r
F
.50651 .22544 m .511 .17149 L .51059 .18566 L 0 0 0 r
F
.511 .17149 m .51603 .11089 L .51366 .14355 L F
.511 .17149 m .51366 .14355 L .51059 .18566 L F
.50744 .25526 m .5121 .1873 L .52879 .1136 L F
.49862 .31378 m .5121 .1873 L .50744 .25526 L F
.5091 .21544 m .50801 .22682 L .5121 .1873 L F
.50009 .29998 m .50397 .26426 L .5091 .21544 L F
.49862 .31378 m .49986 .30233 L .50009 .29998 L F
.49986 .30233 m .50397 .26426 L .50009 .29998 L F
.49869 .31416 m .49802 .31751 L .49869 .31415 L F
.49862 .31378 m .52879 .1136 L .52887 .11393 L F
.49862 .31378 m .52916 .11199 L .5292 .11232 L F
.50119 .28606 m .50419 .25337 L .50867 .2121 L .863 .178 0 r
F
.49733 .3253 m .49637 .31185 L .4992 .29197 L 1 .762 0 r
F
.49679 .32647 m .49714 .30659 L .49755 .32059 L 1 .633 0 r
F
.49714 .32524 m .49755 .32059 L .49763 .32352 L F
.49679 .32647 m .49755 .32059 L .49714 .32524 L F
.49901 .33008 m .49693 .32671 L .49763 .32352 L 1 .411 0 r
F
.49693 .32671 m .49679 .32647 L .49714 .32524 L F
.49693 .32671 m .49714 .32524 L .49763 .32352 L F
.49733 .3253 m .49746 .32296 L .49784 .32178 L 1 .762 0 r
F
.49746 .32296 m .49769 .31891 L .49779 .3207 L F
.49746 .32296 m .49779 .3207 L .49784 .32178 L F
.49769 .31891 m .49814 .31084 L .49803 .31504 L F
.49769 .31891 m .49803 .31504 L .49784 .32178 L F
.49881 .29899 m .4992 .29197 L .49875 .30176 L F
.50397 .26426 m .50801 .22682 L .5091 .21544 L 0 0 0 r
F
.51191 .18917 m .51362 .14665 L .5121 .1873 L F
.51126 .19339 m .51362 .14665 L .51191 .18917 L F
.51006 .19759 m .51362 .14665 L .51105 .19748 L F
.50651 .22544 m .51027 .18714 L .50994 .18422 L F
.50419 .25337 m .50651 .22544 L .50867 .2121 L F
.50419 .25337 m .50568 .23775 L .50651 .22544 L F
.51362 .14665 m .51382 .14447 L .5121 .1873 L F
.51387 .14308 m .51524 .12822 L .5152 .12892 L F
.51382 .14447 m .5152 .12892 L .5121 .1873 L F
.51387 .14308 m .5152 .12892 L .51382 .14447 L F
.50651 .22544 m .51059 .18566 L .50867 .2121 L F
.50801 .22682 m .51006 .19759 L .51105 .19748 L F
.51362 .14665 m .51387 .14308 L .51382 .14447 L F
.51387 .14308 m .51611 .11111 L .51524 .12822 L F
.51611 .11111 m .51626 .10905 L .51614 .11122 L F
.51611 .11111 m .51614 .11122 L .51524 .12822 L F
.51159 .0977 m .50586 .0954 L .50233 .09577 L .328 .45 0 r
F
.51492 .09831 m .50585 .09548 L .51159 .09777 L .684 .734 0 r
F
.52063 .1044 m .51352 .11058 L .51127 .10075 L .942 .214 0 r
F
.51492 .09831 m .50897 .09328 L .50585 .09548 L .684 .734 0 r
F
.51352 .11058 m .51061 .10664 L .50659 .09995 L .51 .287 0 r
F
.51352 .11058 m .50656 .0999 L .5111 .10072 L F
.51352 .11058 m .5111 .10072 L .5113 .10089 L F
.51127 .10075 m .50547 .0997 L .50219 .0976 L .541 0 0 r
F
.5154 .10953 m .50875 .09761 L .51352 .11058 L .336 .104 0 r
F
.50875 .09761 m .50858 .0973 L .50871 .09765 L F
.50875 .09761 m .50871 .09765 L .51352 .11058 L F
.51431 .10608 m .50858 .0973 L .5154 .10953 L F
.50574 .10006 m .50858 .0973 L .50547 .0997 L .51 .287 0 r
F
.50659 .09995 m .50547 .0997 L .50656 .0999 L F
.50763 .10168 m .50547 .0997 L .50659 .09995 L F
.51061 .10664 m .50578 .10011 L .50763 .10168 L F
.50578 .10011 m .50547 .0997 L .50763 .10168 L F
.5058 .1001 m .50858 .0973 L .50574 .10006 L F
.51056 .10263 m .50879 .09786 L .5058 .1001 L F
.50879 .09786 m .50858 .0973 L .5058 .1001 L F
.50394 .09872 m .49715 .09449 L .50207 .09753 L .744 .677 0 r
F
.50547 .0997 m .49741 .09466 L .50394 .09872 L F
.49741 .09466 m .49715 .09449 L .50394 .09872 L F
.50233 .09577 m .49727 .09262 L .49392 .0932 L .51 .75 0 r
F
.50233 .09581 m .49727 .09265 L .49392 .09322 L .505 .745 0 r
F
.50585 .09548 m .49727 .09265 L .50233 .09581 L .768 .84 0 r
F
.49733 .09166 m .49635 .09131 L .49396 .09255 L .803 .928 0 r
F
.49635 .09131 m .4896 .08894 L .49045 .08964 L F
.49635 .09131 m .49045 .08964 L .49396 .09255 L F
.49733 .09166 m .49228 .08775 L .4896 .08894 L F
.50035 .08998 m .49228 .08775 L .49733 .09166 L .609 .827 0 r
F
.50035 .09 m .49228 .08775 L .49716 .09154 L .607 .825 0 r
F
.49743 .09162 m .49716 .09154 L .49733 .09167 L F
.50035 .09 m .49716 .09154 L .49743 .09162 L F
.49733 .09167 m .4896 .08895 L .49396 .09256 L .803 .928 0 r
F
.49396 .09255 m .48668 .08961 L .49021 .09387 L .698 .892 0 r
F
.49396 .09256 m .48668 .08961 L .49021 .09387 L .697 .891 0 r
F
.49396 .09255 m .4896 .08894 L .48668 .08961 L .698 .892 0 r
F
.49396 .09256 m .4896 .08895 L .48668 .08961 L .697 .891 0 r
F
.49727 .09262 m .49598 .0921 L .49392 .0932 L .818 .906 0 r
F
.49598 .0921 m .48958 .08948 L .49023 .09004 L F
.49598 .0921 m .49023 .09004 L .49392 .0932 L F
.49733 .09167 m .49228 .08775 L .4896 .08895 L .803 .928 0 r
F
.49727 .09262 m .49225 .08822 L .48958 .08948 L .818 .906 0 r
F
.50029 .09088 m .49225 .08822 L .49727 .09262 L .527 .752 0 r
F
.50028 .09091 m .49225 .08824 L .49709 .09249 L .523 .748 0 r
F
.49737 .09259 m .49709 .09249 L .49727 .09265 L F
.50028 .09091 m .49709 .09249 L .49737 .09259 L F
.49727 .09265 m .48958 .08949 L .49392 .09322 L .817 .904 0 r
F
.50585 .09548 m .50028 .09091 L .49727 .09265 L .768 .84 0 r
F
.49727 .09265 m .49225 .08824 L .48958 .08949 L .817 .904 0 r
F
.49021 .09387 m .48668 .08961 L .48354 .09015 L .76 .912 0 r
F
.49021 .09387 m .48668 .08961 L .48354 .09015 L .76 .911 0 r
F
.49392 .0932 m .48958 .08948 L .48667 .09004 L .665 .861 0 r
F
.49392 .09322 m .48958 .08949 L .48666 .09004 L .664 .859 0 r
F
.49715 .09449 m .49221 .08896 L .48954 .09034 L .832 .844 0 r
F
.50016 .09256 m .49221 .08896 L .49715 .09449 L .387 .566 0 r
F
.50224 .09763 m .50207 .09753 L .50219 .0976 L .744 .677 0 r
F
.50547 .0997 m .50207 .09753 L .50224 .09763 L F
.51159 .09777 m .50585 .09548 L .50233 .09581 L .315 .424 0 r
F
.50547 .0997 m .50016 .09256 L .49715 .09449 L .744 .677 0 r
F
.50016 .09263 m .49221 .08898 L .49701 .09441 L .381 .556 0 r
F
.49719 .09452 m .49701 .09441 L .49714 .09456 L F
.50016 .09263 m .49701 .09441 L .49719 .09452 L F
.50858 .0973 m .50016 .09256 L .50547 .0997 L .64 .019 0 r
F
.50758 .09819 m .50016 .09263 L .50524 .09966 L .676 .029 0 r
F
.50205 .10648 m .49803 .09982 L .49347 .10219 L .915 .842 0 r
F
.50694 .10366 m .50218 .09767 L .49803 .09988 L .835 .81 0 r
F
.49362 .09949 m .48618 .09503 L .48881 .09964 L .721 .84 0 r
F
.49362 .09949 m .49017 .09464 L .48618 .09503 L F
.49803 .09982 m .4901 .09599 L .49347 .10219 L .892 .899 0 r
F
.49803 .09982 m .49386 .09431 L .4901 .09599 L F
.50218 .09767 m .49385 .09434 L .49803 .09988 L .28 .384 0 r
F
.50218 .09767 m .49714 .09456 L .49385 .09434 L F
.50545 .09995 m .49714 .09456 L .50218 .09767 L .739 .666 0 r
F
.50545 .09995 m .50016 .09263 L .49714 .09456 L F
.50035 .08998 m .49461 .08689 L .49228 .08775 L .609 .827 0 r
F
.50035 .09 m .49461 .0869 L .49228 .08775 L .607 .825 0 r
F
.50029 .09088 m .49457 .08756 L .49225 .08822 L .527 .752 0 r
F
.50028 .09091 m .49457 .08759 L .49225 .08824 L .523 .748 0 r
F
.50016 .09256 m .49451 .08872 L .49221 .08896 L .387 .566 0 r
F
.50016 .09263 m .49456 .0888 L .49221 .08898 L .381 .556 0 r
F
.49456 .0888 m .4945 .08876 L .49438 .08877 L F
.49456 .0888 m .49438 .08877 L .49221 .08898 L F
.50285 .08907 m .50129 .08866 L .50035 .08998 L .721 .854 0 r
F
.50129 .08866 m .49461 .08689 L .49575 .0875 L F
.50129 .08866 m .49575 .0875 L .50035 .08998 L F
.50285 .08907 m .49662 .08548 L .49461 .08689 L F
.50492 .08722 m .49662 .08548 L .50285 .08907 L .423 .643 0 r
F
.51166 .08929 m .50492 .08722 L .50481 .08732 L .708 .91 0 r
F
.50826 .08921 m .50481 .08732 L .50285 .08907 L F
.51166 .08929 m .50481 .08732 L .50826 .08921 L F
.50492 .08722 m .49819 .0847 L .49662 .08548 L .423 .643 0 r
F
.50457 .0872 m .49819 .08473 L .49662 .08549 L .418 .634 0 r
F
.50491 .08727 m .50424 .08701 L .50457 .0872 L F
.50424 .08701 m .49819 .08473 L .50457 .0872 L F
.50491 .08727 m .49662 .08549 L .5025 .08891 L F
.50296 .08901 m .5025 .08891 L .50285 .08911 L F
.50491 .08727 m .5025 .08891 L .50296 .08901 L F
.50285 .08911 m .49461 .0869 L .50035 .09 L .72 .852 0 r
F
.50913 .09156 m .50285 .08907 L .50035 .08998 L .452 .695 0 r
F
.50913 .0916 m .50285 .08911 L .50035 .09 L .448 .687 0 r
F
.50272 .0907 m .49457 .08756 L .50029 .09088 L .699 .78 0 r
F
.50897 .09319 m .50272 .0907 L .50029 .09088 L .231 .278 0 r
F
.50271 .09078 m .49457 .08759 L .50028 .09091 L .697 .775 0 r
F
.50285 .08911 m .49662 .08549 L .49461 .0869 L .72 .852 0 r
F
.50272 .0907 m .49658 .08614 L .49457 .08756 L .699 .78 0 r
F
.50271 .09078 m .49658 .08616 L .49457 .08759 L .697 .775 0 r
F
.49462 .08881 m .49651 .08725 L .49451 .08872 L .624 .571 0 r
F
.50237 .09501 m .4945 .08876 L .50016 .09263 L .618 .557 0 r
F
.50855 .09758 m .50794 .09722 L .50758 .09819 L .676 .029 0 r
F
.50794 .09722 m .50055 .09286 L .50682 .09761 L F
.50794 .09722 m .50682 .09761 L .50758 .09819 L F
.50055 .09286 m .50016 .09263 L .50758 .09819 L F
.50855 .09758 m .50237 .09501 L .50223 .09486 L F
.50794 .09722 m .50223 .09486 L .50016 .09263 L F
.50855 .09758 m .50223 .09486 L .50794 .09722 L F
.50858 .0973 m .50239 .09476 L .50016 .09256 L .64 .019 0 r
F
.51104 .09531 m .50239 .09476 L .50817 .09714 L .616 .847 0 r
F
.50925 .09676 m .50817 .09714 L .50858 .0973 L F
.51104 .09531 m .50817 .09714 L .50925 .09676 L F
.50036 .09278 m .49451 .08872 L .50005 .09248 L .624 .571 0 r
F
.50239 .09476 m .49459 .08879 L .50036 .09278 L F
.49459 .08879 m .49451 .08872 L .50036 .09278 L F
.49461 .08689 m .48717 .08423 L .49228 .08775 L .656 .849 0 r
F
.49461 .0869 m .48717 .08424 L .49228 .08775 L .655 .848 0 r
F
.49228 .08775 m .48524 .08488 L .4896 .08894 L .708 .892 0 r
F
.49228 .08775 m .48524 .08489 L .4896 .08895 L .707 .891 0 r
F
.49228 .08775 m .48717 .08423 L .48524 .08488 L .708 .892 0 r
F
.49228 .08775 m .48717 .08424 L .48524 .08489 L .707 .891 0 r
F
.49457 .08756 m .48715 .0845 L .49225 .08822 L .624 .808 0 r
F
.49457 .08759 m .48715 .08451 L .49225 .08824 L .622 .806 0 r
F
.49461 .08689 m .48886 .08353 L .48717 .08423 L .656 .849 0 r
F
.49662 .08548 m .48886 .08353 L .49461 .08689 L .567 .802 0 r
F
.49461 .0869 m .48886 .08354 L .48717 .08424 L .655 .848 0 r
F
.49662 .08549 m .48886 .08354 L .49461 .0869 L .565 .8 0 r
F
.49457 .08756 m .48884 .08387 L .48715 .0845 L .624 .808 0 r
F
.49658 .08614 m .48884 .08387 L .49457 .08756 L .482 .724 0 r
F
.49457 .08759 m .48884 .08388 L .48715 .08451 L .622 .806 0 r
F
.49658 .08616 m .48884 .08388 L .49457 .08759 L .479 .72 0 r
F
.4896 .08894 m .48524 .08488 L .48312 .08566 L .832 .959 0 r
F
.4896 .08895 m .48524 .08489 L .48312 .08566 L F
.49225 .08822 m .48715 .0845 L .48524 .08511 L .694 .871 0 r
F
.49225 .08824 m .48715 .08451 L .48524 .08512 L .693 .87 0 r
F
.49451 .08872 m .48882 .08436 L .48714 .08487 L .57 .731 0 r
F
.49651 .08725 m .48882 .08436 L .49451 .08872 L .373 .552 0 r
F
.49651 .0873 m .48882 .08437 L .49406 .08841 L .368 .543 0 r
F
.49453 .08874 m .49406 .08841 L .4945 .08876 L F
.49651 .0873 m .49406 .08841 L .49453 .08874 L F
.5002 .09259 m .50005 .09248 L .50016 .09256 L .624 .571 0 r
F
.50239 .09476 m .50005 .09248 L .5002 .09259 L F
.50239 .09476 m .49813 .08932 L .49462 .08881 L F
.49813 .08932 m .49651 .08725 L .49462 .08881 L F
.50552 .0999 m .50524 .09966 L .50545 .09995 L .676 .029 0 r
F
.50855 .09758 m .50524 .09966 L .50552 .0999 L F
.5113 .10089 m .5111 .10072 L .51127 .10075 L .51 .287 0 r
F
.51626 .10905 m .51104 .09531 L .50858 .0973 L .336 .104 0 r
F
.50971 .09667 m .50237 .09501 L .50855 .09758 L .594 .829 0 r
F
.51101 .09566 m .51077 .09564 L .50971 .09667 L F
.51077 .09564 m .50237 .09501 L .50971 .09667 L F
.51352 .11058 m .51056 .10263 L .50574 .10006 L .51 .287 0 r
F
.51603 .11089 m .50855 .09758 L .51279 .11027 L .318 .074 0 r
F
.51322 .111 m .51279 .11027 L .51303 .11101 L F
.51603 .11089 m .51279 .11027 L .51322 .111 L F
.51626 .10905 m .51431 .10608 L .5154 .10953 L .336 .104 0 r
F
.51608 .11097 m .51167 .09768 L .51603 .11089 L .885 .36 0 r
F
.51167 .09768 m .51101 .09566 L .51172 .09783 L F
.51167 .09768 m .51172 .09783 L .51603 .11089 L F
.51611 .11111 m .51787 .1105 L .51626 .10905 L 0 0 0 r
F
.50801 .22682 m .51759 .11384 L .51611 .11111 L F
.51759 .11384 m .51787 .1105 L .51611 .11111 L F
.51749 .11354 m .51713 .11256 L .51608 .11097 L .885 .36 0 r
F
.51657 .12323 m .51749 .11354 L .51627 .12597 L 0 0 0 r
F
.50568 .23775 m .51657 .12323 L .50651 .22544 L F
.51657 .12323 m .51627 .12597 L .50651 .22544 L F
.51027 .18714 m .51627 .12597 L .5153 .13485 L F
.51027 .18714 m .5153 .13485 L .50994 .18422 L F
.51627 .12597 m .51749 .11354 L .50994 .18422 L F
.50886 .19773 m .51749 .11354 L .50949 .19766 L F
.50886 .19773 m .50949 .19766 L .50419 .25337 L F
.50194 .27073 m .50701 .2198 L .50419 .25337 L F
.4992 .29197 m .50701 .2198 L .50194 .27073 L F
.4992 .29197 m .50886 .19773 L .50701 .2198 L F
.50099 .28658 m .50419 .25337 L .50119 .28606 L .863 .178 0 r
F
.49883 .30949 m .50099 .28658 L .50119 .28606 L F
.49802 .31751 m .49878 .30958 L .49883 .30949 L F
.49878 .30958 m .50099 .28658 L .49883 .30949 L F
.49785 .32165 m .49944 .30448 L .49802 .31751 L 1 .862 0 r
F
.49944 .30448 m .50099 .28658 L .49802 .31751 L F
.49813 .31868 m .49937 .30532 L .49785 .32165 L F
.49937 .30532 m .50419 .25337 L .49944 .30448 L F
.49937 .30532 m .49944 .30448 L .49785 .32165 L F
.49944 .30448 m .50419 .25337 L .50099 .28658 L F
.49784 .32178 m .49813 .31868 L .49785 .32165 L F
.49784 .32178 m .4992 .29197 L .50419 .25337 L F
.50042 .28809 m .5005 .28786 L .49878 .31212 L 1 .774 0 r
F
.49833 .31941 m .49784 .32178 L .49867 .31439 L 0 0 0 r
F
.49833 .31941 m .49828 .31913 L .49867 .31439 L 1 .471 0 r
F
.49867 .31439 m .49828 .31913 L .49862 .31378 L F
.49828 .31913 m .50801 .22682 L .49862 .31378 L 1 .871 0 r
F
.49874 .31263 m .49878 .31212 L .49852 .31574 L 1 .774 0 r
F
.50042 .28809 m .49878 .31212 L .49874 .31263 L F
.49814 .31084 m .49836 .31041 L .49784 .32178 L 1 .762 0 r
F
.49763 .32352 m .50042 .28809 L .49874 .31263 L 1 .774 0 r
F
.49829 .31774 m .49874 .31263 L .49852 .31574 L F
.49763 .32352 m .49874 .31263 L .49829 .31774 L F
.50116 .27864 m .50469 .24307 L .50587 .23731 L 0 0 0 r
F
.50394 .25764 m .50587 .23731 L .50801 .22682 L F
.50116 .27864 m .50587 .23731 L .50394 .25764 L F
.50469 .24307 m .5176 .11319 L .51076 .19428 L F
.50469 .24307 m .51076 .19428 L .50801 .22682 L F
.49637 .31185 m .49815 .29572 L .4992 .29197 L 1 .648 0 r
F
.5176 .11319 m .51768 .11278 L .50879 .2177 L 0 0 0 r
F
.50878 .21777 m .50879 .2177 L .50801 .22682 L F
.5176 .11319 m .50879 .2177 L .50878 .21777 L F
.50809 .20894 m .51223 .16752 L .51196 .17001 L F
.51223 .16752 m .51785 .1114 L .51196 .17001 L F
.51196 .17001 m .51785 .1114 L .51701 .11918 L F
.50786 .21154 m .51785 .1114 L .50809 .20894 L F
.50786 .21154 m .5177 .11969 L .51785 .1114 L F
.50886 .19773 m .51675 .12708 L .51323 .15512 L F
.5176 .11319 m .51787 .1105 L .51768 .11278 L F
.51701 .11918 m .51785 .1114 L .51787 .1105 L F
.51323 .15512 m .51675 .12708 L .51749 .11354 L F
.5038 .24703 m .50734 .2143 L .50886 .19773 L F
.50734 .2143 m .51675 .12708 L .50886 .19773 L F
.50994 .18422 m .51749 .11354 L .51603 .11089 L F
.49815 .29572 m .50799 .19679 L .51675 .12708 L 1 .648 0 r
F
.49637 .31185 m .49757 .29998 L .49815 .29572 L F
.49757 .29998 m .50799 .19679 L .49815 .29572 L F
.50204 .26425 m .50316 .25381 L .5038 .24703 L 0 0 0 r
F
.50316 .25381 m .51675 .12708 L .5038 .24703 L F
.4992 .29197 m .5013 .2722 L .50204 .26425 L F
.5013 .2722 m .51675 .12708 L .50204 .26425 L F
.49815 .29572 m .51675 .12708 L .50268 .2593 L 1 .648 0 r
F
.49815 .29572 m .50268 .2593 L .4992 .29197 L F
.50727 .15488 m .50553 .16183 L .50733 .15457 L .66 .154 0 r
F
.51299 .13872 m .51021 .14735 L .51747 .11394 L F
.51021 .14735 m .50553 .16183 L .5114 .13831 L F
.51021 .14735 m .5114 .13831 L .51747 .11394 L F
.51747 .11394 m .50727 .15488 L .51749 .11354 L F
.50727 .15488 m .50733 .15457 L .51749 .11354 L F
.51675 .12708 m .51563 .13054 L .51747 .11394 L F
.51563 .13054 m .51299 .13872 L .51462 .12972 L F
.51563 .13054 m .51462 .12972 L .51747 .11394 L F
.50935 .18299 m .51015 .1647 L .5085 .16904 L .702 .191 0 r
F
.50344 .18859 m .49077 .20088 L .48879 .24886 L 1 .724 0 r
F
.50147 .22691 m .48879 .24886 L .48699 .28799 L 1 .671 0 r
F
.51675 .12708 m .49638 .25255 L .50553 .16183 L .66 .154 0 r
F
.50465 .20105 m .49911 .22756 L .5064 .18524 L .462 .062 0 r
F
.50799 .19679 m .50269 .22224 L .51675 .12708 L .41 .055 0 r
F
.49739 .24771 m .49638 .25255 L .49843 .23994 L F
.50694 .10366 m .49803 .09988 L .50204 .10664 L .835 .81 0 r
F
.5114 .1115 m .50694 .10366 L .50204 .10664 L .835 .709 0 r
F
.51336 .11199 m .50855 .09758 L .50545 .09995 L .489 .248 0 r
F
.51104 .09531 m .50441 .09323 L .50419 .0934 L .616 .847 0 r
F
.50616 .095 m .50419 .0934 L .50239 .09476 L F
.51104 .09531 m .50419 .0934 L .50616 .095 L F
.50897 .09328 m .50271 .09078 L .50028 .09091 L .213 .247 0 r
F
.50441 .09323 m .49651 .08725 L .50239 .09476 L 0 .034 0 r
F
.49662 .08548 m .49029 .08284 L .48886 .08353 L .567 .802 0 r
F
.49819 .0847 m .4968 .08437 L .49662 .08548 L .677 .847 0 r
F
.4968 .08437 m .49029 .08284 L .49172 .08344 L F
.4968 .08437 m .49172 .08344 L .49662 .08548 L F
.49819 .0847 m .49145 .08179 L .49029 .08284 L F
.49939 .08328 m .49145 .08179 L .49819 .0847 L .348 .494 0 r
F
.49938 .08331 m .49145 .0818 L .49778 .08455 L .342 .482 0 r
F
.49827 .08464 m .49778 .08455 L .49819 .08473 L F
.49938 .08331 m .49778 .08455 L .49827 .08464 L F
.49662 .08549 m .49029 .08285 L .48886 .08354 L .565 .8 0 r
F
.49819 .08473 m .49029 .08285 L .49662 .08549 L .675 .845 0 r
F
.49658 .08614 m .49027 .08331 L .48884 .08387 L .482 .724 0 r
F
.49811 .08586 m .49027 .08331 L .49658 .08614 L .643 .787 0 r
F
.49658 .08616 m .49027 .08333 L .48884 .08388 L .479 .72 0 r
F
.49811 .08591 m .49027 .08333 L .49658 .08616 L .64 .783 0 r
F
.49819 .08473 m .49145 .0818 L .49029 .08285 L .675 .845 0 r
F
.49811 .08586 m .49143 .08228 L .49027 .08331 L .643 .787 0 r
F
.49811 .08591 m .49143 .0823 L .49027 .08333 L .64 .783 0 r
F
.49795 .08827 m .49139 .08304 L .49131 .08311 L .564 .638 0 r
F
.50391 .09317 m .49787 .08834 L .49651 .0873 L 0 .026 0 r
F
.50237 .09501 m .49651 .0873 L .4945 .08876 L .618 .557 0 r
F
.50438 .09355 m .49651 .0873 L .50237 .09501 L 0 .026 0 r
F
.49651 .08725 m .49023 .08404 L .48882 .08436 L .373 .552 0 r
F
.50441 .09323 m .49795 .08827 L .49651 .08725 L 0 .034 0 r
F
.49651 .0873 m .49029 .0841 L .48882 .08437 L .368 .543 0 r
F
.49029 .0841 m .49023 .08406 L .49015 .08408 L F
.49029 .0841 m .49015 .08408 L .48882 .08437 L F
.49034 .0841 m .49131 .08311 L .49023 .08404 L .564 .638 0 r
F
.49034 .0841 m .49023 .08404 L .49035 .0841 L F
.49034 .0841 m .49035 .0841 L .49651 .08725 L F
.49794 .0884 m .49023 .08406 L .49651 .0873 L .558 .628 0 r
F
.49795 .08827 m .49034 .0841 L .49651 .08725 L .564 .638 0 r
F
.49739 .08796 m .49292 .08439 L .49034 .0841 L F
.49292 .08439 m .49131 .08311 L .49034 .0841 L F
.49795 .08827 m .49131 .08311 L .49739 .08796 L F
.50392 .09318 m .49794 .0884 L .49787 .08834 L 0 .026 0 r
F
.50392 .09318 m .49787 .08834 L .50391 .09317 L F
.50438 .09355 m .50372 .09302 L .50392 .09318 L F
.50372 .09302 m .49794 .0884 L .50392 .09318 L F
.50315 .09507 m .50438 .09355 L .50237 .09501 L .594 .829 0 r
F
.51101 .09566 m .50441 .09356 L .50315 .09507 L F
.50441 .09356 m .50438 .09355 L .50315 .09507 L F
.51603 .11089 m .51101 .09566 L .50855 .09758 L .318 .074 0 r
F
.50553 .16183 m .50456 .1039 L .51101 .09566 L 0 0 0 r
F
.50456 .1039 m .50438 .09355 L .50498 .09374 L F
.50456 .1039 m .50498 .09374 L .51101 .09566 L F
.51575 .10971 m .51101 .09566 L .51608 .11097 L .885 .36 0 r
F
.5149 .1064 m .51105 .09578 L .51575 .10971 L F
.51105 .09578 m .51101 .09566 L .51575 .10971 L F
.51713 .11256 m .5149 .1064 L .51582 .10998 L F
.51713 .11256 m .51582 .10998 L .51608 .11097 L F
.5134 .11198 m .51303 .11101 L .51336 .11199 L .318 .074 0 r
F
.51603 .11089 m .51303 .11101 L .5134 .11198 L F
.50927 .13349 m .50911 .13113 L .50854 .13183 L .745 .322 0 r
F
.51749 .11354 m .50553 .16183 L .51101 .09566 L .885 .36 0 r
F
.50343 .1639 m .49133 .16745 L .49077 .20088 L 1 .777 0 r
F
.49638 .25255 m .50241 .15021 L .50553 .16183 L 0 0 0 r
F
.50765 .13979 m .50475 .09994 L .51087 .09526 L F
.50686 .14135 m .50475 .09994 L .50765 .13979 L F
.50475 .09994 m .50499 .09342 L .51087 .09526 L F
.50714 .14679 m .50686 .14135 L .50765 .13979 L F
.50497 .094 m .50441 .09323 L .50499 .09342 L F
.50475 .09994 m .50442 .09357 L .50497 .094 L F
.50442 .09357 m .50441 .09323 L .50497 .094 L F
.50493 .09336 m .50582 .09248 L .50491 .09296 L F
.50714 .14679 m .50583 .09297 L .50493 .09336 L F
.50583 .09297 m .50582 .09248 L .50493 .09336 L F
.50582 .09248 m .49795 .08827 L .50441 .09323 L .303 .369 0 r
F
.50578 .09293 m .49794 .0884 L .50372 .09302 L .28 .325 0 r
F
.50439 .09354 m .50372 .09302 L .50438 .09355 L F
.50442 .09355 m .50491 .09296 L .50441 .09323 L 0 0 0 r
F
.50714 .14679 m .50491 .09296 L .50442 .09355 L F
.50578 .09293 m .50372 .09302 L .50439 .09354 L .28 .325 0 r
F
.50456 .1039 m .50578 .09293 L .50438 .09355 L 0 0 0 r
F
.50553 .16183 m .50578 .09324 L .50456 .1039 L F
.50578 .09324 m .50578 .09293 L .50456 .1039 L F
.50241 .15021 m .50572 .09393 L .5056 .14387 L F
.50572 .09393 m .50578 .09293 L .50578 .09398 L F
.50572 .09393 m .50578 .09398 L .5056 .14387 L F
.50241 .15021 m .5056 .14387 L .50553 .16183 L F
.50582 .09342 m .50582 .09248 L .50583 .09306 L F
.50582 .09342 m .50583 .09306 L .50714 .14679 L F
.50551 .16325 m .50582 .09342 L .50714 .14679 L F
.50132 .18317 m .5058 .09295 L .50551 .16325 L F
.5058 .09295 m .50582 .09248 L .50582 .09296 L F
.5058 .09295 m .50582 .09296 L .50551 .16325 L F
.51166 .08929 m .50285 .08907 L .50913 .09156 L .708 .91 0 r
F
.51825 .0925 m .51166 .08929 L .50913 .09156 L .669 .821 0 r
F
.51165 .08934 m .50285 .08911 L .50913 .0916 L .706 .909 0 r
F
.51824 .09259 m .51165 .08934 L .50913 .0916 L .665 .816 0 r
F
.51149 .09098 m .50272 .0907 L .50897 .09319 L .691 .9 0 r
F
.51788 .09558 m .51149 .09098 L .50897 .09319 L .6 .688 0 r
F
.51147 .09109 m .50271 .09078 L .50897 .09328 L .686 .896 0 r
F
.51165 .08934 m .50491 .08727 L .50285 .08911 L .706 .909 0 r
F
.50477 .08892 m .49658 .08614 L .50272 .0907 L .232 .3 0 r
F
.51149 .09098 m .50477 .08892 L .50464 .08904 L .691 .9 0 r
F
.50752 .09085 m .50464 .08904 L .50272 .0907 L F
.51149 .09098 m .50464 .08904 L .50752 .09085 L F
.50477 .08892 m .49811 .08586 L .49658 .08614 L .232 .3 0 r
F
.5044 .08889 m .49811 .08591 L .49658 .08616 L .219 .277 0 r
F
.50477 .08902 m .50413 .08872 L .5044 .08889 L F
.50413 .08872 m .49811 .08591 L .5044 .08889 L F
.50477 .08902 m .49658 .08616 L .50271 .09078 L F
.50392 .09082 m .50477 .08902 L .50271 .09078 L .686 .896 0 r
F
.51147 .09109 m .5049 .08906 L .50392 .09082 L F
.5049 .08906 m .50477 .08902 L .50392 .09082 L F
.51785 .09583 m .51147 .09109 L .50897 .09328 L .59 .674 0 r
F
.51334 .08884 m .50492 .08722 L .51166 .08929 L .558 .714 0 r
F
.51332 .08898 m .50491 .08727 L .51165 .08934 L .55 .704 0 r
F
.51275 .09437 m .50477 .08902 L .51147 .09109 L .35 .337 0 r
F
.52003 .09326 m .51149 .09098 L .51788 .09558 L .678 .031 0 r
F
.5189 .09472 m .51147 .09109 L .51785 .09583 L .724 .04 0 r
F
.51965 .09394 m .5119 .09124 L .5189 .09472 L F
.5119 .09124 m .51147 .09109 L .5189 .09472 L F
.51976 .09351 m .51942 .09341 L .51965 .09394 L F
.51942 .09341 m .51147 .09109 L .51903 .09373 L F
.51942 .09341 m .51903 .09373 L .51965 .09394 L F
.51999 .09358 m .51275 .09437 L .51262 .09405 L F
.51942 .09341 m .51262 .09405 L .51147 .09109 L F
.51999 .09358 m .51262 .09405 L .51942 .09341 L F
.52046 .08981 m .51166 .08929 L .51825 .0925 L .171 .163 0 r
F
.52045 .08993 m .51165 .08934 L .51824 .09259 L .139 .159 0 r
F
.52003 .09326 m .5128 .09389 L .51149 .09098 L .678 .031 0 r
F
.52133 .09135 m .5128 .09389 L .51957 .0933 L .219 .176 0 r
F
.52054 .09252 m .51957 .0933 L .52003 .09326 L F
.52133 .09135 m .51957 .0933 L .52054 .09252 L F
.50645 .08538 m .49819 .0847 L .50492 .08722 L .626 .838 0 r
F
.51334 .08884 m .50645 .08538 L .50492 .08722 L .558 .714 0 r
F
.50644 .08544 m .49819 .08473 L .50491 .08727 L .622 .834 0 r
F
.52046 .08981 m .51334 .08884 L .51166 .08929 L .171 .163 0 r
F
.51332 .08898 m .50644 .08544 L .50491 .08727 L .55 .704 0 r
F
.50628 .08728 m .49811 .08586 L .50477 .08892 L .537 .747 0 r
F
.50627 .08741 m .49811 .08591 L .50413 .08872 L .527 .737 0 r
F
.5048 .08898 m .50413 .08872 L .50477 .08902 L F
.51157 .09157 m .50477 .08892 L .51122 .0909 L .364 .373 0 r
F
.50498 .08904 m .50477 .08892 L .51157 .09157 L F
.5128 .09389 m .51125 .09293 L .51157 .09157 L F
.51125 .09293 m .50498 .08904 L .50816 .09026 L F
.51125 .09293 m .50816 .09026 L .51157 .09157 L F
.5128 .09389 m .50628 .08728 L .50619 .08737 L F
.51076 .09239 m .50619 .08737 L .50529 .08836 L F
.5128 .09389 m .50619 .08737 L .51076 .09239 L F
.5128 .09389 m .51122 .0909 L .51152 .09105 L F
.5128 .09389 m .50529 .08836 L .50492 .08901 L F
.52056 .09279 m .51275 .09437 L .51999 .09358 L 0 0 0 r
F
.52083 .09194 m .51275 .09437 L .52056 .09279 L F
.51359 .09361 m .50647 .08743 L .5128 .09389 L .164 .087 0 r
F
.51267 .09264 m .50647 .08743 L .51359 .09361 L F
.50647 .08743 m .50649 .08749 L .5128 .09389 L F
.52133 .09135 m .51376 .09355 L .51359 .09361 L .219 .176 0 r
F
.51491 .09326 m .51359 .09361 L .5128 .09389 L F
.52133 .09135 m .51359 .09361 L .51491 .09326 L F
.51275 .09437 m .50627 .08741 L .50477 .08902 L .35 .337 0 r
F
.51513 .09365 m .51367 .09434 L .51275 .09437 L 0 0 0 r
F
.51529 .0936 m .51367 .09434 L .51513 .09365 L F
.51426 .09414 m .51367 .09434 L .51529 .0936 L F
.51376 .09355 m .51267 .09264 L .51359 .09361 L .164 .087 0 r
F
.51152 .09105 m .51122 .0909 L .51149 .09098 L .364 .373 0 r
F
.51376 .09355 m .5072 .08593 L .50628 .08728 L .164 .087 0 r
F
.52127 .09181 m .51426 .09414 L .51529 .0936 L 0 0 0 r
F
.52169 .09032 m .52013 .09095 L .52133 .09135 L .225 0 0 r
F
.52013 .09095 m .51376 .09355 L .52045 .09161 L F
.52013 .09095 m .52045 .09161 L .52133 .09135 L F
.52045 .08993 m .51332 .08898 L .51165 .08934 L .139 .159 0 r
F
.52187 .08717 m .51334 .08884 L .52046 .08981 L .612 .866 0 r
F
.52891 .08999 m .52187 .08717 L .52046 .08981 L .497 .687 0 r
F
.52185 .08731 m .51332 .08898 L .52045 .08993 L .6 .854 0 r
F
.52187 .08717 m .51449 .08687 L .51334 .08884 L .612 .866 0 r
F
.52185 .08731 m .51447 .08706 L .51332 .08898 L .6 .854 0 r
F
.52242 .08469 m .51449 .08687 L .52187 .08717 L .527 .753 0 r
F
.52239 .08489 m .51447 .08706 L .52185 .08731 L .515 .712 0 r
F
.52201 .0848 m .5149 .08529 L .51449 .08687 L .527 .753 0 r
F
.52242 .08469 m .52202 .08472 L .52201 .0848 L F
.52202 .08472 m .5149 .08529 L .52201 .0848 L F
.52952 .08729 m .52242 .08469 L .52187 .08717 L .397 .581 0 r
F
.54246 .0976 m .53205 .11125 L .532 .11109 L .003 0 0 r
F
.53205 .11125 m .53158 .11188 L .532 .11109 L F
.53204 .11191 m .53213 .11149 L .532 .11109 L 0 0 0 r
F
.53213 .11149 m .53243 .11021 L .532 .11109 L F
.53192 .10937 m .53087 .09984 L .53118 .09995 L .229 .077 0 r
F
.53288 .11094 m .5277 .09819 L .52637 .09941 L 0 .009 0 r
F
.52775 .09928 m .52722 .09863 L .5277 .09819 L 0 .012 0 r
F
.52669 .09994 m .52011 .09367 L .52626 .10021 L .127 .08 0 r
F
.52561 .09795 m .52011 .09367 L .52669 .09994 L F
.52011 .09367 m .52034 .09395 L .52626 .10021 L F
.52553 .10019 m .51909 .09613 L .52398 .10164 L .371 .395 0 r
F
.524 .09834 m .51909 .09613 L .52553 .10019 L F
.51909 .09613 m .51895 .09665 L .52398 .10164 L F
.51909 .09613 m .51788 .09558 L .51895 .09665 L F
.52626 .10021 m .51785 .09583 L .52321 .1015 L .349 .34 0 r
F
.52362 .10169 m .52321 .1015 L .52347 .10177 L F
.52626 .10021 m .52321 .1015 L .52362 .10169 L F
.52402 .10211 m .52347 .10177 L .52389 .10222 L F
.52626 .10021 m .52347 .10177 L .52402 .10211 L F
.52938 .1069 m .52521 .10284 L .52912 .10523 L .229 .077 0 r
F
.53192 .10937 m .52928 .10463 L .52473 .10237 L F
.52945 .11071 m .5121 .1873 L .52063 .1044 L .826 .286 0 r
F
.52389 .10222 m .51785 .09583 L .51492 .09831 L .509 .514 0 r
F
.53154 .11168 m .52626 .10021 L .52389 .10222 L .181 .063 0 r
F
.52626 .10021 m .51999 .09358 L .51785 .09583 L .349 .34 0 r
F
.52035 .09346 m .52003 .09326 L .52033 .09354 L .179 .1 0 r
F
.52752 .09942 m .52127 .09181 L .51999 .09358 L .127 .08 0 r
F
.53219 .11509 m .52949 .10833 L .53154 .11168 L 0 0 0 r
F
.52949 .10833 m .52626 .10021 L .52933 .10687 L F
.52949 .10833 m .52933 .10687 L .53154 .11168 L F
.53243 .11021 m .52723 .10093 L .53192 .10937 L 0 .009 0 r
F
.5287 .10354 m .52723 .10093 L .52873 .10361 L F
.52723 .10093 m .52761 .10164 L .53192 .10937 L F
.53074 .12249 m .5292 .11232 L .52945 .11071 L .696 .168 0 r
F
.52887 .11393 m .52879 .1136 L .52916 .11199 L 0 0 0 r
F
.5292 .11232 m .52916 .11199 L .52945 .11071 L F
.53238 .11008 m .5287 .10354 L .53243 .11021 L 0 .009 0 r
F
.53167 .1088 m .5287 .10354 L .53238 .11008 L F
.5287 .10354 m .52873 .10361 L .53243 .11021 L F
.52723 .10093 m .52637 .09941 L .52761 .10164 L F
.52949 .10833 m .52752 .09942 L .52626 .10021 L 0 0 0 r
F
.53219 .11509 m .52844 .1025 L .52949 .10833 L F
.52844 .1025 m .52752 .09942 L .52949 .10833 L F
.5285 .10305 m .52775 .09928 L .52772 .09853 L .733 .12 0 r
F
.52814 .10088 m .52772 .09853 L .5277 .09819 L F
.5285 .10305 m .52772 .09853 L .52814 .10088 L F
.52961 .13163 m .52766 .10157 L .53219 .11509 L .778 .141 0 r
F
.52766 .10157 m .52752 .09942 L .52874 .10351 L F
.52766 .10157 m .52874 .10351 L .53219 .11509 L F
.53236 .11001 m .53167 .1088 L .53238 .11008 L 0 .009 0 r
F
.52978 .11086 m .52835 .10269 L .5285 .10305 L .733 .12 0 r
F
.52835 .10269 m .52775 .09928 L .5285 .10305 L F
.53117 .11929 m .52989 .11182 L .52978 .11086 L F
.52989 .11182 m .52775 .09928 L .52978 .11086 L F
.50185 .27165 m .50786 .21154 L .50809 .20894 L 0 0 0 r
F
.50549 .23066 m .51191 .16632 L .5177 .11969 L .936 .222 0 r
F
.49714 .30659 m .50437 .23791 L .50549 .23066 L F
.50437 .23791 m .51191 .16632 L .50549 .23066 L F
.51105 .19748 m .51126 .19339 L .51191 .18917 L 0 0 0 r
F
.50185 .27165 m .50631 .22889 L .50786 .21154 L F
.50631 .22889 m .5177 .11969 L .50786 .21154 L F
.50116 .27864 m .50166 .27382 L .50185 .27165 L F
.50166 .27382 m .5177 .11969 L .50185 .27165 L F
.49889 .29442 m .5177 .11969 L .50116 .27864 L .936 .222 0 r
F
.49898 .28993 m .5177 .11969 L .49889 .29442 L F
.50799 .19679 m .49152 .30045 L .49638 .25255 L .41 .055 0 r
F
.49152 .30045 m .49066 .30583 L .49213 .29217 L F
.49152 .30045 m .49213 .29217 L .49638 .25255 L F
.50265 .1564 m .50653 .09331 L .50586 .09253 L 0 0 0 r
F
.50265 .1564 m .50586 .09253 L .50578 .09319 L F
.49638 .25255 m .50646 .09412 L .50578 .09293 L F
.49066 .30583 m .49115 .2993 L .49199 .29345 L .988 .502 0 r
F
.50225 .1479 m .49077 .14754 L .49133 .16745 L 1 .836 0 r
F
.49066 .30583 m .48668 .31351 L .50646 .09412 L .988 .502 0 r
F
.48876 .32141 m .48668 .31351 L .48825 .31048 L .823 .278 0 r
F
.48904 .31912 m .48825 .31048 L .49066 .30583 L F
.48876 .32141 m .48825 .31048 L .48904 .31912 L F
.49526 .32768 m .48618 .33206 L .48647 .33843 L 1 .641 0 r
F
.49068 .32947 m .48976 .32416 L .4904 .31551 L 1 .613 0 r
F
.49087 .31378 m .4904 .31551 L .49093 .30831 L F
.49068 .32947 m .4904 .31551 L .49087 .31378 L F
.49068 .32947 m .49093 .30831 L .49117 .30682 L F
.49068 .32947 m .49122 .30441 L .49123 .30435 L F
.48996 .33094 m .48909 .32095 L .4892 .32088 L 1 .489 0 r
F
.48909 .32095 m .48908 .32055 L .4892 .32088 L F
.48908 .32055 m .48907 .32011 L .48911 .32033 L F
.48908 .32055 m .48911 .32033 L .4892 .32088 L F
.48906 .32067 m .48859 .32225 L .48892 .32101 L 0 0 0 r
F
.49123 .30435 m .48907 .32011 L .49066 .30583 L .304 .032 0 r
F
.48907 .32011 m .48904 .31912 L .49066 .30583 L F
.49068 .32947 m .49598 .28739 L .49586 .28968 L 1 .613 0 r
F
.49586 .3276 m .49491 .32741 L .49467 .32136 L .868 .19 0 r
F
.49467 .32136 m .4949 .31918 L .49637 .31185 L 1 .654 0 r
F
.49601 .32663 m .49491 .32741 L .495 .31908 L .707 .103 0 r
F
.49491 .32741 m .49295 .32878 L .49385 .32453 L F
.49491 .32741 m .49404 .32507 L .49467 .32136 L .868 .19 0 r
F
.49369 .32716 m .49385 .32453 L .49467 .32136 L F
.4941 .32356 m .49413 .32296 L .49467 .32136 L 1 .671 0 r
F
.49295 .32878 m .49165 .32918 L .49399 .32205 L .112 0 0 r
F
.49388 .32402 m .49399 .32205 L .49465 .32004 L F
.49295 .32878 m .49399 .32205 L .49388 .32402 L F
.49295 .32878 m .49465 .32004 L .49408 .32321 L F
.49165 .32918 m .49068 .32947 L .4947 .31981 L F
.49165 .32918 m .4947 .31981 L .49465 .32004 L F
.50423 .22533 m .49066 .30583 L .50799 .19679 L .304 .032 0 r
F
.4949 .31918 m .49492 .31761 L .50799 .19679 L 1 .654 0 r
F
.4947 .31981 m .49068 .32947 L .50423 .22533 L .89 .399 0 r
F
.4947 .31981 m .49517 .29415 L .4949 .31918 L 1 .654 0 r
F
.4949 .31918 m .5035 .23873 L .49655 .30998 L F
.4949 .31918 m .49655 .30998 L .49637 .31185 L F
.5035 .23873 m .50483 .22802 L .49637 .31185 L F
.495 .31908 m .4947 .31981 L .51191 .16632 L .89 .399 0 r
F
.49492 .31761 m .50189 .24855 L .50799 .19679 L 1 .654 0 r
F
.49504 .30668 m .50423 .22533 L .50799 .19679 L F
.5035 .23873 m .50799 .19679 L .50483 .22802 L F
.4947 .31981 m .50423 .22533 L .51191 .16632 L .89 .399 0 r
F
.49492 .31761 m .49504 .30668 L .50189 .24855 L 1 .654 0 r
F
.49319 .32706 m .49492 .30771 L .49413 .32296 L 1 .671 0 r
F
.49385 .32453 m .49413 .32296 L .4941 .32356 L F
.49319 .32706 m .49413 .32296 L .49385 .32453 L F
.49467 .32136 m .4947 .31981 L .4949 .31918 L 1 .654 0 r
F
.49465 .32004 m .4947 .31981 L .49486 .31942 L .112 0 0 r
F
.49491 .32741 m .49385 .32453 L .495 .31908 L .707 .103 0 r
F
.49491 .32741 m .49369 .32716 L .49404 .32507 L .868 .19 0 r
F
.49413 .32296 m .4947 .31981 L .49467 .32136 L 1 .671 0 r
F
.49295 .32878 m .49486 .31942 L .49446 .32161 L .112 0 0 r
F
.49369 .32716 m .49319 .32706 L .49385 .32453 L .868 .19 0 r
F
.49408 .32321 m .49465 .32004 L .49486 .31942 L .112 0 0 r
F
.49413 .32296 m .49492 .30771 L .4947 .31981 L 1 .671 0 r
F
.49319 .32706 m .49517 .29415 L .49492 .30771 L F
.49586 .28968 m .50234 .23681 L .50423 .22533 L 1 .613 0 r
F
.49598 .28739 m .50234 .23681 L .49586 .28968 L F
.49123 .30435 m .49066 .30583 L .50423 .22533 L .304 .032 0 r
F
.50234 .23681 m .50813 .19079 L .50423 .22533 L 1 .613 0 r
F
.49068 .32947 m .49133 .29972 L .50813 .19079 L F
.49517 .29415 m .49123 .30435 L .50423 .22533 L .304 .032 0 r
F
.48976 .32416 m .48896 .31952 L .49123 .30429 L 1 .613 0 r
F
.48909 .32095 m .48906 .32067 L .48907 .32011 L 1 .489 0 r
F
.48892 .32101 m .48907 .32011 L .48914 .31978 L 0 0 0 r
F
.4891 .32024 m .48914 .31978 L .49517 .29415 L F
.48892 .32101 m .48914 .31978 L .4891 .32024 L F
.48906 .32063 m .48892 .32101 L .48907 .3204 L F
.48843 .32784 m .48776 .32648 L .48906 .32067 L 1 .489 0 r
F
.489 .3212 m .48885 .32157 L .48906 .32067 L 0 0 0 r
F
.48885 .32157 m .48859 .32225 L .48906 .32067 L F
.48906 .32067 m .48776 .32648 L .4879 .32568 L 1 .489 0 r
F
.48996 .33094 m .48843 .32784 L .48906 .32067 L F
.49009 .33067 m .4892 .32088 L .49068 .32947 L F
.48996 .33094 m .4892 .32088 L .49009 .33067 L F
.48567 .32334 m .48783 .25458 L .48668 .31351 L .978 .492 0 r
F
.48546 .32534 m .48551 .32398 L .48567 .32334 L F
.48551 .32398 m .48783 .25458 L .48567 .32334 L F
.48546 .32534 m .48305 .3191 L .48783 .25458 L F
.48448 .33241 m .48305 .3191 L .48546 .32534 L 1 .475 0 r
F
.4848 .32875 m .48462 .32747 L .48556 .32428 L .923 .387 0 r
F
.50049 .13638 m .48968 .1343 L .49077 .14754 L 1 .89 0 r
F
.49841 .12728 m .48833 .12437 L .48968 .1343 L 1 .931 0 r
F
.49077 .14754 m .48066 .15202 L .48051 .18444 L 1 .923 0 r
F
.49077 .14754 m .48968 .1343 L .48066 .15202 L F
.49615 .11963 m .48684 .11627 L .48833 .12437 L 1 .961 0 r
F
.49615 .11963 m .49376 .1129 L .48684 .11627 L F
.49376 .1129 m .48525 .10928 L .48684 .11627 L 1 .982 0 r
F
.49376 .1129 m .49128 .10682 L .48525 .10928 L F
.48323 .31667 m .4913 .11159 L .48783 .25458 L .971 .492 0 r
F
.48305 .3191 m .48314 .3167 L .48323 .31667 L F
.48314 .3167 m .4913 .11159 L .48323 .31667 L F
.48305 .3191 m .48072 .307 L .4913 .11159 L F
.48218 .32738 m .48072 .307 L .48305 .3191 L .874 .379 0 r
F
.48223 .32673 m .4817 .31711 L .48318 .31724 L .874 .382 0 r
F
.48968 .1343 m .48071 .11801 L .48066 .15202 L .523 .342 0 r
F
.48968 .1343 m .48833 .12437 L .48071 .11801 L F
.48833 .12437 m .48684 .11627 L .47995 .11256 L .593 .496 0 r
F
.48833 .12437 m .48684 .11627 L .47995 .11259 L .596 .499 0 r
F
.48684 .11627 m .47918 .10726 L .47995 .11256 L .667 .637 0 r
F
.48684 .11627 m .47918 .10728 L .47995 .11259 L .669 .639 0 r
F
.48684 .11627 m .48525 .10928 L .47918 .10726 L .667 .637 0 r
F
.48684 .11627 m .48525 .10928 L .47918 .10728 L .669 .639 0 r
F
.48525 .10928 m .47839 .10207 L .47918 .10726 L .732 .751 0 r
F
.48525 .10928 m .47839 .10208 L .47918 .10728 L .733 .753 0 r
F
.48525 .10928 m .48361 .10304 L .47839 .10207 L .732 .751 0 r
F
.49128 .10682 m .48361 .10304 L .48525 .10928 L .992 .996 0 r
F
.48525 .10928 m .48361 .10304 L .47839 .10208 L .733 .753 0 r
F
.49128 .10682 m .48874 .10122 L .48361 .10304 L .992 .996 0 r
F
.48371 .09983 m .47762 .09543 L .47843 .09988 L .79 .932 0 r
F
.48371 .09983 m .47762 .09544 L .47843 .09988 L .79 .933 0 r
F
.48371 .09983 m .48197 .09532 L .47762 .09543 L .79 .932 0 r
F
.48371 .09983 m .48197 .09532 L .47762 .09544 L .79 .933 0 r
F
.48881 .09964 m .48195 .09604 L .48368 .10089 L .903 1 0 r
F
.48881 .09964 m .48195 .09604 L .48368 .10089 L .902 1 0 r
F
.47843 .09988 m .47762 .09543 L .4732 .09584 L .892 1 0 r
F
.47843 .09988 m .47762 .09544 L .4732 .09584 L F
.48368 .10089 m .47761 .09602 L .47842 .10066 L .787 .906 0 r
F
.48368 .10089 m .47761 .09603 L .47842 .10067 L .788 .907 0 r
F
.48368 .10089 m .48195 .09604 L .47761 .09602 L .787 .906 0 r
F
.48368 .10089 m .48195 .09604 L .47761 .09603 L .788 .907 0 r
F
.48874 .1012 m .48192 .09732 L .48361 .10304 L .966 1 0 r
F
.48874 .10122 m .48192 .09732 L .48361 .10304 L .965 1 0 r
F
.48881 .09964 m .48618 .09502 L .48195 .09604 L .903 1 0 r
F
.48881 .09964 m .48618 .09503 L .48195 .09604 L .902 1 0 r
F
.48874 .1012 m .48615 .09597 L .48192 .09732 L .966 1 0 r
F
.49347 .10219 m .48615 .09597 L .48874 .1012 L .687 .726 0 r
F
.48874 .10122 m .48614 .09598 L .48192 .09732 L .965 1 0 r
F
.49346 .10225 m .48614 .09598 L .48874 .10122 L .685 .722 0 r
F
.49204 .10098 m .4901 .09599 L .48615 .09597 L .687 .726 0 r
F
.49347 .10219 m .49033 .09641 L .49204 .10098 L F
.49033 .09641 m .4901 .09599 L .49204 .10098 L F
.49803 .09988 m .49385 .09434 L .49017 .09598 L .891 .896 0 r
F
.4902 .09606 m .49017 .09598 L .4901 .09601 L F
.49803 .09988 m .49017 .09598 L .4902 .09606 L F
.49346 .10225 m .4901 .09601 L .48614 .09598 L .685 .722 0 r
F
.4862 .09444 m .48022 .09085 L .48197 .09532 L .865 .999 0 r
F
.4862 .09444 m .48022 .09085 L .48197 .09532 L .864 .999 0 r
F
.48197 .09532 m .4768 .09102 L .47762 .09543 L .804 .95 0 r
F
.48197 .09532 m .4768 .09102 L .47762 .09544 L F
.48197 .09532 m .48022 .09085 L .4768 .09102 L F
.48197 .09532 m .48022 .09085 L .4768 .09102 L F
.48618 .09502 m .48021 .0913 L .48195 .09604 L .895 1 0 r
F
.48618 .09503 m .48021 .0913 L .48195 .09604 L .894 1 0 r
F
.47762 .09543 m .47334 .09101 L .4732 .09584 L .815 .968 0 r
F
.47762 .09543 m .4768 .09102 L .47334 .09101 L F
.47762 .09544 m .47334 .09101 L .4732 .09584 L .816 .968 0 r
F
.47762 .09544 m .4768 .09102 L .47334 .09101 L F
.48195 .09604 m .4768 .09143 L .47761 .09602 L .811 .937 0 r
F
.48195 .09604 m .4768 .09143 L .47761 .09603 L .812 .938 0 r
F
.48195 .09604 m .48021 .0913 L .4768 .09143 L .811 .937 0 r
F
.48195 .09604 m .48021 .0913 L .4768 .09143 L .812 .938 0 r
F
.48615 .09597 m .4802 .092 L .48192 .09732 L .941 1 0 r
F
.48614 .09598 m .4802 .092 L .48192 .09732 L .94 1 0 r
F
.4862 .09444 m .48354 .09015 L .48022 .09085 L .865 .999 0 r
F
.49021 .09387 m .48354 .09015 L .4862 .09444 L .76 .912 0 r
F
.4862 .09444 m .48354 .09015 L .48022 .09085 L .864 .999 0 r
F
.49021 .09387 m .48354 .09015 L .4862 .09444 L .76 .911 0 r
F
.48618 .09502 m .48353 .09051 L .48021 .0913 L .895 1 0 r
F
.49017 .09463 m .48353 .09051 L .48618 .09502 L .757 .888 0 r
F
.48618 .09503 m .48353 .09051 L .48021 .0913 L .894 1 0 r
F
.49017 .09464 m .48353 .09051 L .48618 .09503 L .756 .887 0 r
F
.48615 .09597 m .48351 .09104 L .4802 .092 L .941 1 0 r
F
.4901 .09599 m .48351 .09104 L .48615 .09597 L .751 .837 0 r
F
.48614 .09598 m .48351 .09104 L .4802 .092 L .94 1 0 r
F
.4901 .09601 m .48351 .09104 L .48614 .09598 L .75 .835 0 r
F
.49017 .09463 m .48667 .09004 L .48353 .09051 L .757 .888 0 r
F
.49392 .0932 m .48667 .09004 L .49017 .09463 L .665 .861 0 r
F
.49017 .09464 m .48666 .09004 L .48353 .09051 L .756 .887 0 r
F
.49392 .09322 m .48666 .09004 L .49017 .09464 L .664 .859 0 r
F
.4901 .09599 m .48664 .09068 L .48351 .09104 L .751 .837 0 r
F
.49386 .09431 m .48664 .09068 L .4901 .09599 L .601 .795 0 r
F
.4901 .09601 m .48664 .09069 L .48351 .09104 L .75 .835 0 r
F
.49385 .09434 m .48664 .09069 L .4901 .09601 L .598 .792 0 r
F
.49386 .09431 m .48954 .09034 L .48664 .09068 L .601 .795 0 r
F
.49385 .09434 m .48954 .09036 L .48664 .09069 L .598 .792 0 r
F
.48668 .08961 m .48085 .0861 L .48354 .09015 L .765 .935 0 r
F
.48668 .08961 m .48085 .0861 L .48354 .09015 L F
.48354 .09015 m .47845 .08643 L .48022 .09085 L .785 .956 0 r
F
.48354 .09015 m .47845 .08643 L .48022 .09085 L .784 .955 0 r
F
.48354 .09015 m .48085 .0861 L .47845 .08643 L .785 .956 0 r
F
.48354 .09015 m .48085 .0861 L .47845 .08643 L .784 .955 0 r
F
.48667 .09004 m .48084 .08635 L .48353 .09051 L .765 .926 0 r
F
.48666 .09004 m .48084 .08635 L .48353 .09051 L F
.48022 .09085 m .47598 .08662 L .4768 .09102 L .822 .971 0 r
F
.48022 .09085 m .47598 .08662 L .4768 .09102 L .823 .971 0 r
F
.48022 .09085 m .47845 .08643 L .47598 .08662 L .822 .971 0 r
F
.48022 .09085 m .47845 .08643 L .47598 .08662 L .823 .971 0 r
F
.48353 .09051 m .47845 .08667 L .48021 .0913 L .789 .952 0 r
F
.48353 .09051 m .47845 .08667 L .48021 .0913 L F
.48353 .09051 m .48084 .08635 L .47845 .08667 L F
.48353 .09051 m .48084 .08635 L .47845 .08667 L F
.48664 .09068 m .48083 .08669 L .48351 .09104 L .766 .909 0 r
F
.48664 .09069 m .48083 .08669 L .48351 .09104 L .765 .909 0 r
F
.48668 .08961 m .48312 .08566 L .48085 .0861 L .765 .935 0 r
F
.4896 .08894 m .48312 .08566 L .48668 .08961 L .832 .959 0 r
F
.48668 .08961 m .48312 .08566 L .48085 .0861 L .765 .935 0 r
F
.4896 .08895 m .48312 .08566 L .48668 .08961 L .832 .959 0 r
F
.48667 .09004 m .48311 .08593 L .48084 .08635 L .765 .926 0 r
F
.48958 .08948 m .48311 .08593 L .48667 .09004 L .85 .951 0 r
F
.48666 .09004 m .48311 .08593 L .48084 .08635 L .765 .926 0 r
F
.48958 .08949 m .48311 .08593 L .48666 .09004 L .849 .95 0 r
F
.48664 .09068 m .4831 .0863 L .48083 .08669 L .766 .909 0 r
F
.48954 .09034 m .4831 .0863 L .48664 .09068 L .871 .929 0 r
F
.48664 .09069 m .4831 .0863 L .48083 .08669 L .765 .909 0 r
F
.48954 .09036 m .4831 .0863 L .48664 .09069 L .871 .928 0 r
F
.48958 .08948 m .48524 .08511 L .48311 .08593 L .85 .951 0 r
F
.49225 .08822 m .48524 .08511 L .48958 .08948 L .694 .871 0 r
F
.48958 .08949 m .48524 .08512 L .48311 .08593 L .849 .95 0 r
F
.49225 .08824 m .48524 .08512 L .48958 .08949 L .693 .87 0 r
F
.48954 .09034 m .48522 .08542 L .4831 .0863 L .871 .929 0 r
F
.49221 .08896 m .48522 .08542 L .48954 .09034 L .672 .834 0 r
F
.48954 .09036 m .48522 .08542 L .4831 .0863 L .871 .928 0 r
F
.49221 .08898 m .48522 .08542 L .48954 .09036 L .671 .833 0 r
F
.49221 .08896 m .48714 .08487 L .48522 .08542 L .672 .834 0 r
F
.49221 .08898 m .48714 .08488 L .48522 .08542 L .671 .833 0 r
F
.48717 .08423 m .48084 .08116 L .48524 .08488 L .658 .863 0 r
F
.48717 .08424 m .48084 .08116 L .48524 .08489 L .658 .862 0 r
F
.48524 .08488 m .47954 .08155 L .48312 .08566 L .773 .942 0 r
F
.48524 .08489 m .47954 .08155 L .48312 .08566 L .772 .941 0 r
F
.48524 .08488 m .48084 .08116 L .47954 .08155 L .773 .942 0 r
F
.48524 .08489 m .48084 .08116 L .47954 .08155 L .772 .941 0 r
F
.48715 .0845 m .48084 .08126 L .48524 .08511 L .64 .842 0 r
F
.48715 .08451 m .48084 .08126 L .48524 .08512 L .639 .841 0 r
F
.48312 .08566 m .47814 .0818 L .48085 .0861 L .751 .918 0 r
F
.48312 .08566 m .47814 .0818 L .48085 .0861 L F
.48312 .08566 m .47954 .08155 L .47814 .0818 L F
.48312 .08566 m .47954 .08155 L .47814 .0818 L F
.48524 .08511 m .47954 .08165 L .48311 .08593 L .776 .937 0 r
F
.48524 .08512 m .47954 .08165 L .48311 .08593 L .776 .936 0 r
F
.48524 .08511 m .48084 .08126 L .47954 .08165 L .776 .937 0 r
F
.48524 .08512 m .48084 .08126 L .47954 .08165 L .776 .936 0 r
F
.48714 .08487 m .48083 .08138 L .48522 .08542 L .616 .813 0 r
F
.48714 .08488 m .48083 .08138 L .48522 .08542 L .615 .812 0 r
F
.48717 .08423 m .48202 .08082 L .48084 .08116 L .658 .863 0 r
F
.48886 .08353 m .48202 .08082 L .48717 .08423 L .694 .885 0 r
F
.48717 .08424 m .48202 .08082 L .48084 .08116 L .658 .862 0 r
F
.48886 .08354 m .48202 .08082 L .48717 .08424 L .693 .884 0 r
F
.48715 .0845 m .48201 .08094 L .48084 .08126 L .64 .842 0 r
F
.48884 .08387 m .48201 .08094 L .48715 .0845 L .682 .867 0 r
F
.48715 .08451 m .48201 .08094 L .48084 .08126 L .639 .841 0 r
F
.48884 .08388 m .48201 .08094 L .48715 .08451 L .682 .866 0 r
F
.48714 .08487 m .48201 .0811 L .48083 .08138 L .616 .813 0 r
F
.48882 .08436 m .48201 .0811 L .48714 .08487 L .666 .839 0 r
F
.48714 .08488 m .48201 .0811 L .48083 .08138 L .615 .812 0 r
F
.48882 .08437 m .48201 .0811 L .48714 .08488 L .666 .838 0 r
F
.48886 .08353 m .48306 .08034 L .48202 .08082 L .694 .885 0 r
F
.48886 .08354 m .48306 .08034 L .48202 .08082 L .693 .884 0 r
F
.48884 .08387 m .48305 .08048 L .48201 .08094 L .682 .867 0 r
F
.48884 .08388 m .48305 .08048 L .48201 .08094 L .682 .866 0 r
F
.48882 .08436 m .48305 .08066 L .48201 .0811 L .666 .839 0 r
F
.48882 .08437 m .48305 .08066 L .48201 .0811 L .666 .838 0 r
F
.48072 .307 m .48546 .08246 L .4913 .11159 L .993 .251 0 r
F
.4817 .31711 m .48092 .3032 L .4831 .31671 L .874 .382 0 r
F
.4817 .31711 m .4831 .31671 L .48318 .31724 L F
.48462 .32747 m .48318 .31724 L .48549 .32406 L .923 .387 0 r
F
.48462 .32747 m .48549 .32406 L .48556 .32428 L F
.48876 .32141 m .48546 .32534 L .48668 .31351 L .823 .278 0 r
F
.48776 .32648 m .48771 .32643 L .4879 .32568 L .649 .067 0 r
F
.48807 .32484 m .48546 .32534 L .48876 .32141 L .516 .059 0 r
F
.48761 .32564 m .48546 .32534 L .48807 .32484 L F
.48736 .32608 m .48546 .32534 L .4879 .32568 L F
.48736 .32608 m .48448 .33241 L .48546 .32534 L F
.48776 .32648 m .48759 .32661 L .48736 .32608 L .649 .067 0 r
F
.48778 .32624 m .48759 .32661 L .48736 .32608 L .516 .059 0 r
F
.48759 .32661 m .48448 .33241 L .48736 .32608 L F
.48759 .32661 m .48663 .32735 L .48736 .32608 L .649 .067 0 r
F
.48736 .32608 m .4848 .32875 L .48556 .32428 L F
.48663 .32735 m .4848 .32875 L .48736 .32608 L F
.4879 .32568 m .48761 .32564 L .48807 .32484 L .516 .059 0 r
F
.48771 .32643 m .48736 .32608 L .4879 .32568 L .649 .067 0 r
F
.48778 .32624 m .48736 .32608 L .4879 .32568 L .516 .059 0 r
F
.48736 .32608 m .48556 .32428 L .4879 .32568 L .649 .067 0 r
F
.4879 .32568 m .48556 .32428 L .48896 .31952 L F
.49213 .31318 m .48778 .32624 L .4879 .32568 L 0 0 0 r
F
.48905 .32106 m .4879 .32568 L .48859 .32225 L F
.49213 .31318 m .4879 .32568 L .48905 .32106 L F
.49206 .31401 m .49214 .31317 L .49223 .31279 L 1 .862 0 r
F
.49217 .31309 m .49211 .31326 L .49213 .31318 L 0 0 0 r
F
.49211 .31326 m .48778 .32624 L .49213 .31318 L F
.49242 .31152 m .48906 .32063 L .49517 .29415 L F
.48906 .32063 m .48907 .3204 L .49517 .29415 L F
.49214 .31317 m .48892 .32101 L .49242 .31152 L F
.49117 .30682 m .49093 .30831 L .49122 .30441 L 1 .613 0 r
F
.49517 .29415 m .48907 .32011 L .49123 .30435 L .304 .032 0 r
F
.49911 .22756 m .50132 .18317 L .50551 .16325 L 0 0 0 r
F
.49911 .22756 m .50044 .20351 L .50111 .18738 L F
.49199 .29345 m .50631 .09604 L .49638 .25255 L .988 .502 0 r
F
.50631 .09604 m .50634 .09605 L .49638 .25255 L F
.50111 .18738 m .50219 .16855 L .50265 .1564 L 0 0 0 r
F
.50219 .16855 m .50653 .09331 L .50265 .1564 L F
.50044 .20351 m .50653 .09331 L .50111 .18738 L F
.49508 .26497 m .50653 .09331 L .49911 .22756 L .98 .494 0 r
F
.50269 .22224 m .49739 .24771 L .50526 .19785 L .41 .055 0 r
F
.49739 .24771 m .49843 .23994 L .50526 .19785 L F
.51125 .13624 m .50714 .14679 L .51221 .12966 L .663 .154 0 r
F
.51787 .1105 m .51104 .09531 L .51626 .10905 L .892 .358 0 r
F
.51787 .1105 m .50714 .14679 L .51104 .09531 L F
.50714 .14679 m .51087 .09526 L .51101 .09567 L 0 0 0 r
F
.51115 .1154 m .50603 .10115 L .51354 .09761 L .685 .176 0 r
F
.5177 .11969 m .49911 .22756 L .50714 .14679 L .663 .154 0 r
F
.50269 .22224 m .50526 .19785 L .51675 .12708 L .41 .055 0 r
F
.51191 .16632 m .49133 .29972 L .49911 .22756 L .462 .062 0 r
F
.49242 .31152 m .51124 .11538 L .49672 .28198 L 1 .862 0 r
F
.51357 .09759 m .51115 .1154 L .51354 .09761 L .394 .043 0 r
F
.51219 .11278 m .51147 .11387 L .51357 .09759 L .92 .187 0 r
F
.50799 .15871 m .5114 .11481 L .51219 .11278 L F
.5114 .11481 m .51147 .11387 L .51219 .11278 L F
.51124 .11538 m .51132 .115 L .49672 .28198 L 1 .862 0 r
F
.51142 .11424 m .51115 .1154 L .51357 .09759 L .394 .043 0 r
F
.50757 .16159 m .51142 .11424 L .50799 .15871 L .92 .187 0 r
F
.51142 .11424 m .51185 .10903 L .51147 .11387 L F
.51142 .11424 m .51147 .11387 L .50799 .15871 L F
.5114 .11443 m .51115 .1154 L .51142 .11424 L .394 .043 0 r
F
.50508 .18645 m .51132 .115 L .50632 .17699 L .92 .187 0 r
F
.51132 .115 m .51185 .10903 L .51142 .11424 L F
.51132 .115 m .51142 .11424 L .50632 .17699 L F
.52726 .09859 m .52295 .09333 L .5277 .09819 L 0 .012 0 r
F
.52295 .09333 m .52133 .09135 L .52329 .09345 L F
.52295 .09333 m .52329 .09345 L .5277 .09819 L F
.5268 .0981 m .52133 .09135 L .52726 .09859 L F
.52272 .09307 m .52169 .09032 L .52133 .09135 L F
.5216 .09106 m .52155 .09108 L .52127 .09181 L .291 0 0 r
F
.52155 .09108 m .51413 .09415 L .51605 .09352 L F
.52155 .09108 m .51605 .09352 L .52127 .09181 L F
.51413 .09415 m .51426 .09414 L .52127 .09181 L F
.51191 .16632 m .50465 .20105 L .5158 .13068 L .462 .062 0 r
F
.50465 .20105 m .5064 .18524 L .5158 .13068 L F
.51628 .13107 m .5158 .13068 L .5177 .11969 L F
.51191 .16632 m .5158 .13068 L .51628 .13107 L F
.5177 .11969 m .51125 .13624 L .51721 .11272 L .663 .154 0 r
F
.51125 .13624 m .51221 .12966 L .51721 .11272 L F
.51781 .11389 m .51721 .11272 L .51787 .1105 L F
.5177 .11969 m .51721 .11272 L .51781 .11389 L F
.50423 .22533 m .50813 .19079 L .51191 .16632 L 1 .613 0 r
F
.52169 .09247 m .52127 .09181 L .52278 .09364 L 0 0 0 r
F
.52127 .09181 m .52083 .09194 L .52056 .09279 L F
.52011 .09367 m .51999 .09358 L .52034 .09395 L .127 .08 0 r
F
.51999 .09358 m .51976 .09351 L .51965 .09394 L .724 .04 0 r
F
.52752 .09942 m .52561 .09795 L .52669 .09994 L .127 .08 0 r
F
.52741 .10163 m .52169 .09247 L .52752 .09942 L 0 0 0 r
F
.52169 .09247 m .52278 .09364 L .52752 .09942 L F
.52741 .10163 m .5216 .09106 L .52127 .09181 L F
.51413 .09415 m .51367 .09434 L .51426 .09414 L .291 0 0 r
F
.51457 .09397 m .51354 .09761 L .51367 .09434 L F
.5216 .09108 m .49672 .28198 L .52159 .09107 L .463 .062 0 r
F
.49504 .30668 m .49517 .29415 L .50423 .22533 L 1 .654 0 r
F
.52058 .10487 m .52042 .10458 L .52063 .1044 L .163 .014 0 r
F
.5121 .1873 m .52042 .10458 L .52058 .10487 L F
.495 .31908 m .50399 .23787 L .49714 .30659 L .89 .399 0 r
F
.50399 .23787 m .51191 .16632 L .50609 .22163 L F
.50399 .23787 m .50609 .22163 L .49714 .30659 L F
.49803 .28401 m .49627 .2969 L .4979 .28381 L .359 .045 0 r
F
.49906 .2856 m .49646 .29615 L .49803 .28401 L F
.49646 .29615 m .49627 .2969 L .49803 .28401 L F
.52476 .11401 m .49672 .28198 L .5216 .09108 L .463 .062 0 r
F
.52155 .09108 m .51358 .09758 L .51457 .09397 L .291 0 0 r
F
.52158 .09107 m .51358 .09758 L .52155 .09108 L F
.51358 .09758 m .51354 .09761 L .51457 .09397 L F
.52138 .09124 m .51372 .09595 L .52148 .09046 L .92 .187 0 r
F
.49672 .28198 m .51357 .09759 L .52138 .09124 L F
.5216 .09106 m .51354 .09761 L .52158 .09107 L .394 .043 0 r
F
.5216 .09106 m .52158 .09107 L .5216 .09106 L F
.52461 .11276 m .52185 .09291 L .52301 .09473 L .991 .158 0 r
F
.52461 .11276 m .52301 .09473 L .52741 .10163 L F
.52185 .09291 m .5216 .09106 L .52365 .0948 L F
.52185 .09291 m .52365 .0948 L .52741 .10163 L F
.5258 .10781 m .5216 .09106 L .52184 .09095 L .463 .062 0 r
F
.5216 .09106 m .5216 .09106 L .52162 .09105 L F
.5216 .09106 m .52162 .09105 L .52184 .09095 L F
.51357 .09759 m .51354 .09761 L .5216 .09106 L .394 .043 0 r
F
.51357 .09759 m .51372 .09595 L .52138 .09124 L .92 .187 0 r
F
.5216 .09106 m .52158 .09107 L .52155 .09108 L .291 0 0 r
F
.49672 .28198 m .52148 .09046 L .5216 .09106 L .92 .187 0 r
F
.51904 .094 m .51357 .09759 L .51992 .09243 L .394 .043 0 r
F
.52078 .09286 m .51134 .11495 L .51606 .09596 L F
.51449 .08687 m .50645 .08538 L .51334 .08884 L .441 .623 0 r
F
.51447 .08706 m .50644 .08544 L .51332 .08898 L .427 .606 0 r
F
.51449 .08687 m .50741 .0836 L .50645 .08538 L .441 .623 0 r
F
.51447 .08706 m .5074 .08368 L .50644 .08544 L .427 .606 0 r
F
.5149 .08529 m .50741 .0836 L .51449 .08687 L .487 0 0 r
F
.51487 .08557 m .514 .08535 L .51447 .08706 L .524 .004 0 r
F
.514 .08535 m .5074 .08368 L .51215 .08595 L F
.514 .08535 m .51215 .08595 L .51447 .08706 L F
.51487 .08557 m .50746 .08547 L .5074 .08368 L F
.5149 .08529 m .50749 .08518 L .50741 .0836 L .487 0 0 r
F
.51451 .08454 m .50749 .08518 L .51421 .08528 L .136 0 0 r
F
.51479 .08509 m .51421 .08528 L .5149 .08529 L F
.51451 .08454 m .51421 .08528 L .51479 .08509 L F
.51592 .08666 m .51487 .08557 L .51447 .08706 L .515 .712 0 r
F
.52239 .08489 m .52217 .08491 L .51592 .08666 L F
.5216 .09106 m .52148 .09046 L .52169 .09032 L .92 .187 0 r
F
.52184 .09095 m .5216 .09106 L .52169 .09032 L .463 .062 0 r
F
.5291 .08516 m .52242 .08469 L .52952 .08729 L .396 .017 0 r
F
.52078 .09286 m .51904 .094 L .5216 .09106 L .394 .043 0 r
F
.51904 .094 m .51992 .09243 L .5216 .09106 L F
.52185 .09291 m .52185 .09291 L .5216 .09106 L .991 .158 0 r
F
.5216 .09107 m .52159 .09107 L .5216 .09106 L .463 .062 0 r
F
.52185 .09291 m .52092 .09256 L .5216 .09106 L .991 .158 0 r
F
.52185 .09291 m .5216 .09106 L .5216 .09106 L F
.5216 .09107 m .5216 .09107 L .5216 .09106 L .463 .062 0 r
F
.5216 .09107 m .5216 .09106 L .5216 .09106 L F
.52461 .11276 m .52092 .09256 L .52185 .09291 L .991 .158 0 r
F
.52484 .11441 m .52475 .11395 L .52461 .11276 L F
.52475 .11395 m .52092 .09256 L .52461 .11276 L F
.49906 .2856 m .49672 .28198 L .52473 .11419 L .359 .045 0 r
F
.52367 .12195 m .52476 .11401 L .52484 .11441 L 1 .544 0 r
F
.49906 .2856 m .52473 .11419 L .52473 .11419 L .359 .045 0 r
F
.52367 .12195 m .52473 .11419 L .52477 .11463 L F
.49906 .2856 m .52473 .11419 L .52367 .12195 L F
.50816 .25044 m .50753 .24481 L .52484 .11441 L .985 .499 0 r
F
.52484 .11441 m .52461 .11276 L .52741 .10163 L .991 .158 0 r
F
.5162 .20841 m .52484 .11441 L .52741 .10163 L 1 .389 0 r
F
.50816 .25044 m .52484 .11441 L .5162 .20841 L .985 .499 0 r
F
.51416 .21286 m .50753 .24481 L .5258 .10781 L .498 .066 0 r
F
.49828 .31913 m .50116 .27864 L .50801 .22682 L 1 .871 0 r
F
.50753 .24481 m .49906 .2856 L .52367 .12195 L .498 .066 0 r
F
.50753 .24481 m .52125 .14036 L .52484 .11441 L .985 .499 0 r
F
.50721 .24203 m .52367 .12195 L .52484 .11441 L F
.50753 .24481 m .52367 .12195 L .5258 .10781 L .498 .066 0 r
F
.50753 .24481 m .50721 .24203 L .52125 .14036 L .985 .499 0 r
F
.50721 .24203 m .50633 .23424 L .52367 .12195 L F
.50633 .23424 m .52078 .09286 L .52476 .11401 L 1 .544 0 r
F
.52474 .11421 m .52473 .11419 L .52476 .11401 L .359 .045 0 r
F
.50633 .23424 m .52476 .11401 L .52367 .12195 L 1 .544 0 r
F
.52477 .11463 m .52474 .11421 L .52476 .11401 L .359 .045 0 r
F
.52484 .11441 m .52476 .11401 L .52475 .11393 L .991 .158 0 r
F
.52481 .11439 m .52476 .11401 L .5258 .10781 L .359 .045 0 r
F
.52477 .11463 m .52476 .11401 L .52481 .11439 L F
.5258 .10781 m .52476 .11401 L .5216 .09108 L .463 .062 0 r
F
.5258 .10781 m .52159 .09107 L .5216 .09107 L F
.5271 .08545 m .52239 .08484 L .5226 .08491 L .223 .287 0 r
F
.52902 .08568 m .52721 .08545 L .5271 .08545 L F
.52721 .08545 m .52239 .08484 L .5271 .08545 L F
.52952 .08729 m .52187 .08717 L .52891 .08999 L .397 .581 0 r
F
.53648 .09039 m .52952 .08729 L .52891 .08999 L .343 .48 0 r
F
.52947 .08764 m .52185 .08731 L .52887 .09024 L .38 .549 0 r
F
.53648 .09039 m .52891 .08999 L .53582 .0932 L .343 .48 0 r
F
.55053 .09442 m .54138 .09607 L .54819 .09888 L .05 0 0 r
F
.54142 .0961 m .53449 .09668 L .54136 .09623 L .72 .93 0 r
F
.53449 .09668 m .53448 .09668 L .54136 .09623 L F
.54142 .0961 m .53403 .0964 L .54138 .09607 L .401 .549 0 r
F
.53457 .09644 m .53403 .0964 L .5368 .09629 L F
.53457 .09644 m .5368 .09629 L .54142 .0961 L F
.53606 .09402 m .53582 .0932 L .53551 .09377 L F
.53639 .09327 m .53648 .09039 L .53582 .0932 L .267 .338 0 r
F
.53638 .09359 m .53638 .09351 L .53632 .0936 L .72 .93 0 r
F
.54346 .0922 m .53638 .09351 L .53638 .09359 L F
.54346 .0922 m .53632 .0936 L .53593 .09564 L F
.53457 .09644 m .53551 .09377 L .53403 .0964 L .401 .549 0 r
F
.54346 .0922 m .53472 .09619 L .53457 .09644 L .72 .93 0 r
F
.53472 .09619 m .53412 .09646 L .53457 .09644 L F
.53593 .09564 m .53632 .0936 L .53472 .09619 L F
.54961 .09632 m .54136 .09623 L .54815 .09909 L .552 .743 0 r
F
.55003 .09476 m .54203 .09611 L .54944 .09631 L F
.54203 .09611 m .54136 .09623 L .54961 .09632 L F
.55092 .09048 m .54346 .0922 L .54874 .09407 L .134 0 0 r
F
.55092 .09048 m .54874 .09407 L .5501 .09455 L F
.54437 .09553 m .5443 .09559 L .54138 .09607 L .05 0 0 r
F
.55047 .09468 m .5501 .09455 L .54136 .09623 L .552 .743 0 r
F
.5501 .09455 m .54142 .0961 L .54136 .09623 L F
.5443 .09559 m .54258 .0969 L .54142 .0961 L .05 0 0 r
F
.5443 .09559 m .54142 .0961 L .54138 .09607 L F
.5501 .09455 m .54346 .0922 L .54142 .0961 L .552 .743 0 r
F
.54346 .0922 m .53457 .09644 L .54142 .0961 L .72 .93 0 r
F
.54313 .09462 m .53638 .09351 L .54346 .0922 L .209 .238 0 r
F
.54738 .09321 m .54313 .09462 L .54258 .0969 L .742 .791 0 r
F
.55092 .09048 m .54313 .09462 L .54738 .09321 L F
.55146 .09022 m .55092 .09048 L .55011 .09454 L F
.55092 .09048 m .54258 .0969 L .55011 .09454 L F
.55146 .09036 m .55092 .09048 L .5501 .09455 L .134 0 0 r
F
.55153 .09002 m .5501 .09455 L .5511 .0919 L .742 .791 0 r
F
.55861 .09218 m .55153 .09002 L .55053 .09442 L .477 .687 0 r
F
.55861 .09218 m .55053 .09442 L .55751 .09696 L F
.55851 .09263 m .55146 .09036 L .55047 .09468 L .455 .665 0 r
F
.55821 .08758 m .55153 .09002 L .55861 .09218 L .073 0 0 r
F
.55816 .0894 m .55146 .09036 L .55851 .09263 L .38 .559 0 r
F
.55804 .08832 m .55773 .08842 L .55816 .0894 L F
.55773 .08842 m .55146 .09036 L .55816 .0894 L F
.5565 .08236 m .55574 .08389 L .55821 .08758 L .927 .571 0 r
F
.55821 .08758 m .55764 .0882 L .55265 .08961 L .073 0 0 r
F
.55557 .08422 m .55106 .08624 L .55554 .08757 L .322 .45 0 r
F
.55557 .08422 m .55554 .08757 L .55764 .0882 L F
.55265 .08961 m .55764 .0882 L .55153 .09002 L .073 0 0 r
F
.55804 .08832 m .55764 .0882 L .55146 .09036 L .38 .559 0 r
F
.55764 .0882 m .55144 .09024 L .55146 .09036 L F
.55764 .0882 m .55427 .09188 L .55172 .09015 L .073 0 0 r
F
.55764 .0882 m .55172 .09015 L .55153 .09002 L F
.55053 .09442 m .5501 .09455 L .55012 .09449 L .05 0 0 r
F
.5511 .0919 m .5501 .09455 L .55053 .09442 L .742 .791 0 r
F
.55146 .09036 m .5501 .09455 L .55052 .09449 L .134 0 0 r
F
.55427 .09188 m .55128 .09072 L .55153 .09002 L .073 0 0 r
F
.55095 .09059 m .54389 .09467 L .54318 .09422 L .134 0 0 r
F
.54389 .09467 m .54306 .09515 L .54318 .09427 L F
.54389 .09467 m .54318 .09427 L .54318 .09422 L F
.55146 .09036 m .55101 .09061 L .55095 .09059 L F
.55101 .09061 m .54306 .09515 L .55095 .09059 L F
.55092 .09048 m .54318 .09422 L .54346 .0922 L F
.55146 .09036 m .54318 .09422 L .55092 .09048 L F
.55153 .09002 m .55092 .09048 L .55146 .09022 L .742 .791 0 r
F
.55092 .09048 m .54325 .09413 L .54313 .09462 L F
.55153 .09002 m .55107 .09024 L .55092 .09048 L F
.55107 .09024 m .54325 .09413 L .55092 .09048 L F
.55011 .09454 m .54258 .0969 L .5501 .09455 L F
.55144 .09024 m .54389 .09466 L .55146 .09036 L .704 .308 0 r
F
.54389 .09466 m .5439 .09467 L .55146 .09036 L F
.55144 .09024 m .54325 .09413 L .55153 .09002 L 0 .037 0 r
F
.54369 .09444 m .54325 .09413 L .54522 .09319 L F
.54369 .09444 m .54522 .09319 L .55144 .09024 L F
.54356 .09415 m .54246 .09279 L .5429 .09354 L F
.54479 .09304 m .54324 .09344 L .54363 .0943 L .704 .308 0 r
F
.55106 .08624 m .54324 .09344 L .54479 .09304 L F
.54369 .09444 m .5429 .09354 L .54325 .09413 L 0 .037 0 r
F
.55106 .08624 m .54363 .0943 L .54369 .09444 L .704 .308 0 r
F
.54363 .0943 m .54294 .09506 L .54369 .09444 L F
.55106 .08624 m .54369 .09444 L .55144 .09024 L F
.54369 .09444 m .54306 .09515 L .55144 .09024 L F
.54869 .09797 m .54369 .09444 L .55144 .09024 L 0 .037 0 r
F
.54448 .095 m .54356 .09415 L .54369 .09444 L F
.54356 .09415 m .5429 .09354 L .54369 .09444 L F
.54448 .095 m .54342 .09384 L .54356 .09415 L F
.53457 .09644 m .53398 .09672 L .54142 .0961 L .72 .93 0 r
F
.54136 .09623 m .53398 .09672 L .53159 .09708 L .099 .157 0 r
F
.54258 .0969 m .53457 .09644 L .54142 .0961 L .401 .549 0 r
F
.54313 .09462 m .53695 .0936 L .54258 .0969 L .267 .338 0 r
F
.54306 .09515 m .54214 .09496 L .54313 .09462 L .209 .238 0 r
F
.53639 .09327 m .53638 .09351 L .54258 .0969 L .267 .338 0 r
F
.54258 .0969 m .53638 .09351 L .53606 .09402 L .401 .549 0 r
F
.53606 .09402 m .53551 .09377 L .53457 .09644 L F
.53638 .09351 m .53582 .0932 L .53606 .09402 L F
.53638 .09351 m .53575 .09362 L .53472 .09619 L .72 .93 0 r
F
.54214 .09496 m .53575 .09362 L .54313 .09462 L .209 .238 0 r
F
.54363 .0943 m .54216 .09444 L .54294 .09506 L .704 .308 0 r
F
.54342 .09384 m .54246 .09279 L .54356 .09415 L 0 .037 0 r
F
.54488 .09522 m .54246 .09279 L .54448 .095 L F
.5464 .09606 m .54324 .09344 L .54488 .09522 L F
.54324 .09344 m .54246 .09279 L .54488 .09522 L F
.54943 .0817 m .54292 .0931 L .55106 .08624 L 0 0 0 r
F
.54325 .09413 m .53639 .09327 L .53695 .0936 L .267 .338 0 r
F
.54325 .09413 m .53695 .0936 L .54313 .09462 L F
.54325 .09413 m .5369 .09062 L .53639 .09327 L F
.54246 .09279 m .53648 .09039 L .54325 .09413 L 0 .086 0 r
F
.54279 .09332 m .54216 .09444 L .54324 .09344 L 0 0 0 r
F
.54292 .09352 m .54279 .09332 L .54324 .09344 L .272 .008 0 r
F
.54324 .09344 m .54216 .09444 L .54363 .0943 L .704 .308 0 r
F
.54258 .0969 m .53606 .09402 L .53457 .09644 L .401 .549 0 r
F
.5338 .14446 m .53294 .11381 L .54246 .0976 L .826 .175 0 r
F
.54246 .0976 m .53359 .1127 L .53505 .10732 L .003 0 0 r
F
.54916 .10038 m .53372 .14488 L .54246 .0976 L .382 .047 0 r
F
.54614 .09855 m .53637 .11478 L .54183 .09504 L .272 .008 0 r
F
.54279 .09332 m .54236 .0941 L .54216 .09444 L 0 0 0 r
F
.54313 .09462 m .53575 .09362 L .53638 .09351 L .209 .238 0 r
F
.53639 .09327 m .53582 .0932 L .53638 .09351 L .267 .338 0 r
F
.5369 .09062 m .53648 .09039 L .53639 .09327 L F
.54306 .09515 m .53638 .09099 L .53575 .09362 L .209 .238 0 r
F
.54216 .09444 m .54203 .09447 L .54306 .09515 L 0 .057 0 r
F
.54037 .09337 m .53732 .09157 L .54306 .09515 L F
.54369 .09444 m .54294 .09506 L .54306 .09515 L .704 .308 0 r
F
.54389 .09466 m .54306 .09515 L .5439 .09467 L F
.54614 .09855 m .54183 .09504 L .54279 .09332 L .272 .008 0 r
F
.5425 .09387 m .5422 .09443 L .54216 .09444 L 0 0 0 r
F
.54216 .09444 m .54037 .09337 L .54203 .09447 L 0 .057 0 r
F
.54246 .09279 m .53594 .08832 L .53648 .09039 L 0 .086 0 r
F
.53594 .08832 m .52952 .08729 L .53648 .09039 L .148 .167 0 r
F
.53726 .09152 m .53578 .08934 L .53638 .09099 L 0 .057 0 r
F
.54216 .09444 m .53603 .08954 L .53726 .09152 L F
.53603 .08954 m .53578 .08934 L .53726 .09152 L F
.53594 .08832 m .5291 .08516 L .52952 .08729 L .148 .167 0 r
F
.53446 .08559 m .5291 .08516 L .53594 .08832 L .231 0 0 r
F
.53596 .08944 m .53446 .08559 L .53594 .08832 L .956 .168 0 r
F
.53472 .09619 m .53575 .09362 L .53412 .09646 L .72 .93 0 r
F
.53638 .09099 m .53598 .0908 L .53599 .09095 L .312 .422 0 r
F
.53598 .0908 m .52947 .08764 L .53599 .09095 L F
.53599 .09095 m .52947 .08764 L .52887 .09024 L F
.53575 .09362 m .52727 .09313 L .53398 .09672 L .424 .599 0 r
F
.53575 .09362 m .52887 .09024 L .52727 .09313 L F
.53638 .09099 m .52887 .09024 L .53575 .09362 L .312 .422 0 r
F
.53578 .08934 m .52947 .08764 L .53638 .09099 L .058 .112 0 r
F
.53578 .08934 m .52902 .08568 L .52947 .08764 L F
.53428 .08673 m .52902 .08568 L .53578 .08934 L .194 0 0 r
F
.53637 .11478 m .53622 .10526 L .53913 .09996 L .956 .168 0 r
F
.53985 .10222 m .53913 .09996 L .54183 .09504 L F
.53637 .11478 m .53913 .09996 L .53985 .10222 L F
.53637 .11478 m .53521 .09712 L .53597 .09004 L F
.53521 .09712 m .53459 .08769 L .53597 .09004 L F
.53459 .08769 m .53428 .08673 L .53591 .08994 L .792 .109 0 r
F
.54037 .09337 m .53638 .09099 L .53732 .09157 L 0 .057 0 r
F
.53622 .10526 m .53597 .09004 L .54183 .09504 L .956 .168 0 r
F
.54183 .09504 m .53597 .09004 L .54216 .09444 L .792 .109 0 r
F
.53597 .09004 m .53603 .08954 L .54216 .09444 L F
.53597 .09004 m .53594 .08832 L .54183 .09504 L .956 .168 0 r
F
.5389 .10056 m .53597 .09004 L .54183 .09504 L .792 .109 0 r
F
.5389 .10056 m .53571 .08923 L .53597 .09004 L F
.53459 .08769 m .53456 .0872 L .53597 .09004 L .956 .168 0 r
F
.53591 .08994 m .53428 .08673 L .53571 .08923 L .792 .109 0 r
F
.5389 .10056 m .53459 .08769 L .53591 .08994 L F
.53597 .09004 m .53571 .08923 L .53578 .08934 L F
.53597 .09004 m .53578 .08934 L .53603 .08954 L F
.53597 .09004 m .53456 .0872 L .53596 .08944 L .956 .168 0 r
F
.53456 .0872 m .53446 .08559 L .53596 .08944 L F
.54183 .09504 m .53594 .08832 L .54246 .09279 L F
.5422 .09443 m .5389 .10056 L .54183 .09504 L 0 0 0 r
F
.54217 .09444 m .54183 .09504 L .54216 .09444 L F
.5422 .09443 m .54183 .09504 L .54217 .09444 L F
.54279 .09332 m .54217 .09443 L .54246 .09279 L .272 .008 0 r
F
.54217 .09443 m .54183 .09504 L .54203 .09435 L F
.54217 .09443 m .54203 .09435 L .54246 .09279 L F
.54279 .09332 m .5425 .09387 L .54236 .0941 L 0 0 0 r
F
.54279 .09332 m .54288 .09314 L .54324 .09344 L .272 .008 0 r
F
.54292 .0931 m .54279 .09332 L .54324 .09344 L 0 0 0 r
F
.54292 .0931 m .54324 .09344 L .55106 .08624 L F
.54943 .0817 m .54201 .09498 L .54279 .09332 L F
.54201 .09498 m .5389 .10056 L .54279 .09332 L F
.54279 .09332 m .54246 .09279 L .54288 .09314 L .272 .008 0 r
F
.54869 .09797 m .5464 .09606 L .54448 .095 L 0 .037 0 r
F
.54614 .09855 m .54292 .09352 L .54869 .09797 L .272 .008 0 r
F
.54292 .09352 m .54324 .09344 L .54869 .09797 L F
.55764 .0882 m .55106 .08624 L .55144 .09024 L .38 .559 0 r
F
.55052 .09449 m .5501 .09455 L .55047 .09468 L .134 0 0 r
F
.55047 .09468 m .55003 .09476 L .54961 .09632 L .552 .743 0 r
F
.55003 .09476 m .54944 .09631 L .54961 .09632 L F
.55851 .09263 m .55047 .09468 L .55743 .0973 L .455 .665 0 r
F
.55427 .09188 m .54869 .09797 L .55128 .09072 L .073 0 0 r
F
.55557 .08422 m .54614 .09855 L .54869 .09797 L .927 .571 0 r
F
.55557 .08422 m .54943 .0817 L .55106 .08624 L .322 .45 0 r
F
.55574 .08389 m .55763 .08821 L .55821 .08758 L .927 .571 0 r
F
.55616 .08395 m .5556 .08376 L .55557 .08422 L .322 .45 0 r
F
.5556 .08376 m .54943 .0817 L .55557 .08422 L F
.5565 .08236 m .5556 .08376 L .55557 .08422 L .927 .571 0 r
F
.5556 .08376 m .55558 .0838 L .55557 .08422 L F
.55558 .0838 m .54614 .09855 L .55557 .08422 L F
.55757 .08806 m .54869 .09797 L .55763 .08821 L F
.55574 .08389 m .55557 .08422 L .55757 .08806 L F
.55557 .08422 m .54869 .09797 L .55757 .08806 L F
.55616 .08395 m .55557 .08422 L .55764 .0882 L .322 .45 0 r
F
.55796 .08811 m .55764 .0882 L .55804 .08832 L F
.55616 .08395 m .55764 .0882 L .55796 .08811 L F
.53457 .09644 m .53412 .09646 L .53398 .09672 L .72 .93 0 r
F
.53449 .09668 m .53398 .09672 L .53448 .09668 L F
.52947 .08764 m .52239 .08489 L .52185 .08731 L .38 .549 0 r
F
.52902 .08568 m .52826 .08559 L .52947 .08764 L .223 .287 0 r
F
.52799 .08511 m .52863 .08552 L .52249 .08485 L .396 .017 0 r
F
.5291 .08516 m .52863 .08552 L .52799 .08511 L F
.52285 .08472 m .52238 .08485 L .52242 .08469 L F
.5291 .08516 m .52238 .08485 L .52285 .08472 L F
.52593 .08523 m .52213 .0829 L .52239 .08484 L .223 .287 0 r
F
.52826 .08559 m .5239 .08507 L .5254 .08606 L F
.52826 .08559 m .5254 .08606 L .52947 .08764 L F
.52828 .08559 m .52863 .08552 L .52239 .08484 L F
.52863 .08552 m .52239 .08484 L .52239 .08484 L F
.5239 .08507 m .52239 .08489 L .52427 .08562 L F
.5239 .08507 m .52427 .08562 L .5254 .08606 L F
.522 .09076 m .52169 .09032 L .52272 .09307 L 0 .012 0 r
F
.52887 .09024 m .52185 .08731 L .52045 .08993 L .481 .67 0 r
F
.52169 .09032 m .51372 .09595 L .51376 .09355 L .225 0 0 r
F
.52722 .09863 m .5268 .0981 L .52726 .09859 L 0 .012 0 r
F
.52775 .09928 m .522 .09076 L .52272 .09307 L F
.52826 .11079 m .52741 .10163 L .52752 .09942 L .778 .141 0 r
F
.52961 .13163 m .52755 .1036 L .52826 .11079 L F
.52755 .1036 m .52741 .10163 L .52826 .11079 L F
.5162 .20841 m .52741 .10163 L .52961 .13163 L 1 .389 0 r
F
.52314 .16623 m .5258 .10781 L .52731 .1012 L 1 .431 0 r
F
.52749 .10303 m .52731 .1012 L .52775 .09928 L F
.52314 .16623 m .52731 .1012 L .52749 .10303 L F
.5258 .10781 m .52169 .09032 L .52775 .09928 L .463 .062 0 r
F
.52603 .08524 m .52097 .09139 L .52249 .08485 L .396 .017 0 r
F
.52863 .08552 m .52848 .08564 L .52603 .08524 L F
.52848 .08564 m .52097 .09139 L .52603 .08524 L F
.52691 .0889 m .52097 .09139 L .52848 .08564 L .177 0 0 r
F
.52902 .08568 m .52863 .08552 L .52828 .08559 L .223 .287 0 r
F
.52855 .08566 m .52848 .08564 L .52861 .08554 L .177 0 0 r
F
.52691 .0889 m .52848 .08564 L .52855 .08566 L F
.53428 .08673 m .53229 .08654 L .52891 .08571 L .194 0 0 r
F
.53428 .08673 m .52891 .08571 L .53018 .08591 L F
.53446 .08559 m .53229 .08654 L .52892 .08547 L .231 0 0 r
F
.53229 .08654 m .52691 .0889 L .52876 .08574 L F
.53229 .08654 m .52924 .08585 L .52891 .08571 L .194 0 0 r
F
.53018 .08591 m .52891 .08571 L .52902 .08568 L F
.52891 .08571 m .52863 .08552 L .52902 .08568 L 0 .056 0 r
F
.53229 .08654 m .52876 .08574 L .52892 .08547 L .231 0 0 r
F
.53229 .08654 m .53039 .08636 L .52924 .08585 L .194 0 0 r
F
.52691 .0889 m .52861 .08554 L .52862 .08553 L .177 0 0 r
F
.52876 .08574 m .52863 .08552 L .52891 .08571 L 0 .056 0 r
F
.52876 .08574 m .52863 .08552 L .52892 .08547 L .177 0 0 r
F
.52691 .0889 m .52863 .08552 L .52876 .08574 L F
.52862 .08553 m .52861 .08554 L .52863 .08552 L F
.52731 .08607 m .52863 .08552 L .52876 .08574 L 0 .056 0 r
F
.53039 .08636 m .52731 .08607 L .52876 .08574 L .194 0 0 r
F
.53039 .08636 m .52876 .08574 L .52891 .08571 L F
.52731 .08607 m .52205 .08285 L .52863 .08552 L 0 .056 0 r
F
.52264 .08321 m .52088 .08096 L .52205 .08285 L F
.52731 .08607 m .5214 .08138 L .52264 .08321 L F
.5214 .08138 m .52088 .08096 L .52264 .08321 L F
.53335 .0855 m .52892 .08547 L .5291 .08516 L .231 0 0 r
F
.53446 .08559 m .52892 .08547 L .53335 .0855 L F
.52892 .08547 m .52863 .08552 L .5291 .08516 L .177 0 0 r
F
.5226 .08491 m .52239 .08484 L .52239 .08489 L .223 .287 0 r
F
.52238 .08484 m .51487 .08557 L .52239 .08489 L .42 .21 0 r
F
.52199 .08488 m .5149 .08529 L .52202 .08472 L 0 .009 0 r
F
.51509 .08548 m .5149 .08529 L .51617 .08522 L F
.51509 .08548 m .51617 .08522 L .52199 .08488 L F
.51499 .08524 m .51451 .08454 L .51474 .08498 L F
.51829 .08426 m .51485 .0849 L .51508 .08546 L .42 .21 0 r
F
.52205 .08285 m .51485 .0849 L .51829 .08426 L F
.51508 .08546 m .51446 .08501 L .51485 .08554 L F
.5151 .08549 m .51474 .08498 L .5149 .08529 L 0 .009 0 r
F
.51487 .08496 m .51446 .08501 L .51508 .08546 L .42 .21 0 r
F
.51485 .08491 m .51451 .08454 L .51499 .08524 L 0 .009 0 r
F
.51485 .0849 m .51469 .08495 L .51487 .08496 L .42 .21 0 r
F
.51469 .08495 m .51446 .08501 L .51487 .08496 L F
.51446 .08501 m .50746 .08547 L .51402 .08556 L .216 0 0 r
F
.51446 .08501 m .51402 .08556 L .51487 .08557 L F
.51462 .08491 m .51478 .08483 L .51485 .0849 L 1 .228 0 r
F
.52088 .08096 m .51478 .08481 L .52205 .08285 L .45 .207 0 r
F
.51478 .08481 m .51446 .08501 L .51485 .0849 L F
.51478 .08481 m .51485 .0849 L .52205 .08285 L F
.52205 .08285 m .51508 .08546 L .51509 .08548 L .42 .21 0 r
F
.51508 .08546 m .51485 .08554 L .51509 .08548 L F
.52238 .08484 m .52202 .08472 L .52242 .08469 L 0 .009 0 r
F
.51509 .08548 m .51487 .08557 L .52238 .08484 L .42 .21 0 r
F
.52217 .08491 m .51513 .08554 L .51591 .08664 L .515 .712 0 r
F
.52217 .08491 m .51591 .08664 L .51592 .08666 L F
.52097 .09139 m .52202 .08472 L .52238 .08484 L 0 .009 0 r
F
.52205 .08285 m .51509 .08548 L .52238 .08484 L .42 .21 0 r
F
.52097 .09139 m .51509 .08548 L .52199 .08488 L 0 .009 0 r
F
.51977 .09018 m .51499 .08524 L .5151 .08549 L F
.51499 .08524 m .51474 .08498 L .51509 .08548 L F
.51499 .08524 m .51509 .08548 L .5151 .08549 L F
.5197 .09005 m .51485 .0849 L .51977 .09018 L F
.51485 .0849 m .51451 .08454 L .51486 .08492 L F
.51485 .0849 m .51486 .08492 L .51977 .09018 L F
.51463 .08494 m .51462 .08491 L .51485 .0849 L 1 .228 0 r
F
.51462 .08491 m .51451 .08454 L .51478 .08483 L F
.52088 .08096 m .51491 .08444 L .51448 .08498 L .45 .207 0 r
F
.51462 .08491 m .51448 .08498 L .51446 .08501 L F
.52088 .08096 m .51448 .08498 L .51462 .08491 L F
.5179 .09605 m .51324 .08563 L .51366 .08527 L 1 .228 0 r
F
.51375 .09417 m .5072 .08593 L .51376 .09355 L .905 .283 0 r
F
.51357 .09418 m .5072 .08593 L .51375 .09417 L F
.51354 .09761 m .51213 .09506 L .51367 .09434 L .91 .306 0 r
F
.51213 .09506 m .51162 .09414 L .51367 .09434 L F
.51367 .09434 m .50627 .08741 L .51203 .0936 L .132 .079 0 r
F
.50647 .08743 m .50628 .08728 L .50649 .08749 L .164 .087 0 r
F
.51367 .09434 m .50718 .08611 L .50627 .08741 L .132 .079 0 r
F
.51312 .09373 m .50816 .08786 L .51315 .09373 L .91 .306 0 r
F
.51162 .09414 m .50874 .08892 L .51312 .09373 L F
.50874 .08892 m .50816 .08786 L .51312 .09373 L F
.51292 .09436 m .51203 .0936 L .51275 .09437 L .132 .079 0 r
F
.51367 .09434 m .51203 .0936 L .51292 .09436 L F
.51162 .09414 m .51315 .09373 L .51367 .09434 L .91 .306 0 r
F
.50827 .08798 m .50718 .08611 L .51065 .0905 L F
.50816 .08786 m .50758 .08682 L .50827 .08798 L F
.50758 .08682 m .50718 .08611 L .50827 .08798 L F
.49115 .2993 m .50631 .09604 L .49199 .29345 L .988 .502 0 r
F
.50631 .09604 m .50646 .09412 L .50634 .09605 L F
.50645 .08538 m .49939 .08328 L .49819 .0847 L .626 .838 0 r
F
.50644 .08544 m .49938 .08331 L .49819 .08473 L .622 .834 0 r
F
.50628 .08728 m .49929 .08458 L .49811 .08586 L .537 .747 0 r
F
.50638 .08725 m .49929 .08466 L .50627 .08741 L .377 .56 0 r
F
.5072 .08593 m .49929 .08458 L .50628 .08728 L .76 .055 0 r
F
.50718 .08611 m .50575 .08584 L .50638 .08725 L .377 .56 0 r
F
.50575 .08584 m .49929 .08466 L .50638 .08725 L F
.50492 .08901 m .50529 .08836 L .50477 .08892 L .364 .373 0 r
F
.50627 .08741 m .50413 .08872 L .5048 .08898 L .527 .737 0 r
F
.50582 .09248 m .49909 .08746 L .49795 .08827 L .303 .369 0 r
F
.50578 .09293 m .49908 .08764 L .49794 .0884 L .28 .325 0 r
F
.50578 .09294 m .49908 .08764 L .50578 .09293 L 0 .038 0 r
F
.50646 .09412 m .50156 .08982 L .50578 .09294 L F
.50515 .09247 m .49908 .08764 L .50578 .09294 L F
.50156 .08982 m .49913 .08768 L .50515 .09247 L F
.49913 .08768 m .49908 .08764 L .50515 .09247 L F
.50204 .10664 m .49803 .09988 L .49346 .10225 L .913 .837 0 r
F
.49803 .09988 m .4901 .09601 L .49346 .10225 L .891 .896 0 r
F
.49715 .09449 m .48954 .09034 L .49386 .09431 L .832 .844 0 r
F
.49714 .09456 m .48954 .09036 L .49385 .09434 L .831 .84 0 r
F
.49714 .09456 m .49221 .08898 L .48954 .09036 L F
.49451 .08872 m .48714 .08487 L .49221 .08896 L .57 .731 0 r
F
.4945 .08876 m .48714 .08488 L .49221 .08898 L .568 .728 0 r
F
.4945 .08876 m .48882 .08437 L .48714 .08488 L F
.49794 .0884 m .49139 .08307 L .49023 .08406 L .558 .628 0 r
F
.49909 .08746 m .49139 .08304 L .49795 .08827 L .519 0 0 r
F
.49908 .08764 m .49139 .08307 L .49794 .0884 L .543 0 0 r
F
.49157 .08318 m .49215 .08383 L .49139 .08307 L F
.49908 .08764 m .49217 .08384 L .49157 .08318 L F
.49217 .08384 m .49215 .08383 L .49157 .08318 L F
.49156 .08314 m .49216 .08375 L .49139 .08304 L .519 0 0 r
F
.49909 .08746 m .49216 .08375 L .49156 .08314 L F
.49832 .08723 m .49216 .08375 L .49832 .08705 L 0 0 0 r
F
.49908 .08764 m .49215 .08383 L .49908 .08764 L 0 .085 0 r
F
.49217 .08384 m .49215 .08383 L .49908 .08764 L F
.49319 .0887 m .49217 .08384 L .49345 .08455 L 0 0 0 r
F
.49217 .08384 m .49216 .08375 L .49832 .08723 L F
.49908 .08765 m .49832 .08705 L .49909 .08746 L F
.49908 .08782 m .49832 .08705 L .49908 .08765 L F
.498 .1116 m .49832 .08738 L .49908 .08782 L F
.49832 .08738 m .49832 .08705 L .49908 .08782 L F
.49267 .08387 m .49264 .08373 L .49218 .08384 L F
.49218 .08384 m .49263 .08386 L .49215 .08383 L 0 .085 0 r
F
.49329 .08443 m .49265 .08387 L .49218 .08384 L F
.49265 .08387 m .49263 .08386 L .49218 .08384 L F
.49279 .08453 m .49267 .08387 L .49217 .08385 L 0 0 0 r
F
.49267 .08387 m .49218 .08384 L .49217 .08385 L F
.49843 .08716 m .49264 .08386 L .49329 .08443 L 0 .085 0 r
F
.50578 .09319 m .50586 .09253 L .50582 .09248 L 0 0 0 r
F
.48729 .30674 m .48969 .26143 L .50646 .09412 L 1 .693 0 r
F
.48668 .31351 m .48969 .26143 L .48729 .30674 L F
.49971 .08784 m .49806 .08691 L .49843 .08716 L 0 .085 0 r
F
.49836 .08711 m .49264 .08386 L .49843 .08716 L F
.49806 .08691 m .49267 .08387 L .49836 .08711 L F
.49267 .08387 m .49264 .08386 L .49836 .08711 L F
.50652 .0933 m .50625 .09393 L .50391 .09181 L .895 .354 0 r
F
.50403 .09135 m .50391 .09181 L .49909 .08746 L F
.50652 .0933 m .50391 .09181 L .50403 .09135 L F
.49863 .08727 m .49215 .08383 L .49217 .08384 L 0 .085 0 r
F
.49971 .08784 m .49863 .08727 L .49863 .08727 L F
.49863 .08727 m .49215 .08383 L .49863 .08727 L F
.49329 .08443 m .49217 .08384 L .49345 .08455 L F
.498 .1116 m .49319 .0887 L .49832 .08723 L 0 0 0 r
F
.49319 .0887 m .49345 .08455 L .49832 .08723 L F
.498 .1116 m .49279 .08453 L .49217 .08385 L F
.48783 .25458 m .49263 .08386 L .49267 .08387 L 1 .514 0 r
F
.48783 .25458 m .49267 .08387 L .49444 .15472 L F
.49266 .08478 m .49264 .08387 L .49267 .08404 L 1 .576 0 r
F
.48997 .20547 m .49262 .08475 L .49266 .08478 L F
.49262 .08475 m .49264 .08387 L .49266 .08478 L F
.48996 .20556 m .49264 .08386 L .48997 .20547 L F
.48668 .31351 m .48783 .25458 L .48954 .23057 L 1 .693 0 r
F
.48885 .27122 m .48954 .23057 L .49457 .15996 L F
.48668 .31351 m .48954 .23057 L .48885 .27122 L F
.49457 .15996 m .49267 .08404 L .498 .1116 L 1 .576 0 r
F
.48783 .25458 m .49444 .15472 L .49457 .15996 L 1 .514 0 r
F
.49267 .08404 m .49267 .08387 L .498 .1116 L 1 .576 0 r
F
.50625 .09393 m .49908 .08764 L .49909 .08746 L .895 .354 0 r
F
.49971 .08784 m .49329 .08443 L .49908 .08764 L 0 .085 0 r
F
.49329 .08443 m .49345 .08455 L .49908 .08764 L F
.49444 .15472 m .4989 .08738 L .49457 .15996 L 1 .514 0 r
F
.49264 .08386 m .49267 .08387 L .49267 .08404 L 1 .576 0 r
F
.48556 .32428 m .48318 .31724 L .48769 .25608 L .977 .493 0 r
F
.48783 .25458 m .48825 .23711 L .48832 .23486 L 1 .514 0 r
F
.48783 .25458 m .49148 .10786 L .49193 .10835 L F
.48783 .25458 m .49259 .08475 L .49261 .08475 L F
.49261 .08475 m .49263 .08386 L .49263 .08386 L F
.48783 .25458 m .49261 .08475 L .49261 .08475 L F
.49261 .08475 m .49263 .08386 L .49261 .08475 L F
.49193 .10835 m .49148 .10786 L .49259 .08475 L F
.48934 .23372 m .49267 .08404 L .49457 .15996 L 1 .576 0 r
F
.4927 .08556 m .49264 .08551 L .49264 .0855 L 1 .085 0 r
F
.49261 .08475 m .49259 .08475 L .49263 .08386 L 1 .514 0 r
F
.49218 .1048 m .49148 .10816 L .49259 .08475 L 1 .576 0 r
F
.49261 .08475 m .49259 .08475 L .49263 .08398 L F
.49218 .1048 m .49259 .08475 L .49261 .08475 L F
.49029 .08284 m .48306 .08034 L .48886 .08353 L .631 .835 0 r
F
.49029 .08285 m .48306 .08034 L .48886 .08354 L .63 .834 0 r
F
.49027 .08331 m .48305 .08048 L .48884 .08387 L .602 .8 0 r
F
.49027 .08333 m .48305 .08048 L .48884 .08388 L .6 .798 0 r
F
.49029 .08284 m .48394 .07984 L .48306 .08034 L .631 .835 0 r
F
.49145 .08179 m .48394 .07984 L .49029 .08284 L .533 .772 0 r
F
.49029 .08285 m .48394 .07985 L .48306 .08034 L .63 .834 0 r
F
.49145 .0818 m .48394 .07985 L .49029 .08285 L .531 .77 0 r
F
.49027 .08331 m .48393 .08002 L .48305 .08048 L .602 .8 0 r
F
.49143 .08228 m .48393 .08002 L .49027 .08331 L .466 .706 0 r
F
.49027 .08333 m .48393 .08002 L .48305 .08048 L .6 .798 0 r
F
.49143 .0823 m .48393 .08002 L .49027 .08333 L .464 .703 0 r
F
.49139 .08304 m .48393 .08024 L .49023 .08404 L .398 .595 0 r
F
.49139 .08307 m .48392 .08025 L .49023 .08406 L .395 .59 0 r
F
.49145 .08179 m .48464 .07938 L .48394 .07984 L .533 .772 0 r
F
.49228 .0813 m .48464 .07938 L .49145 .08179 L .382 .568 0 r
F
.49145 .0818 m .48464 .07939 L .48394 .07985 L .531 .77 0 r
F
.49228 .08132 m .48464 .07939 L .49145 .0818 L .38 .563 0 r
F
.49143 .08228 m .48464 .07961 L .48393 .08002 L .466 .706 0 r
F
.49224 .08216 m .48464 .07961 L .49143 .08228 L .264 .355 0 r
F
.49143 .0823 m .48464 .07962 L .48393 .08002 L .464 .703 0 r
F
.49224 .0822 m .48464 .07962 L .49143 .0823 L .259 .346 0 r
F
.49139 .08304 m .48463 .07992 L .48393 .08024 L .398 .595 0 r
F
.48652 .08123 m .48463 .07993 L .48392 .08025 L .395 .59 0 r
F
.49139 .08307 m .4847 .07997 L .48652 .08123 L F
.4847 .07997 m .48463 .07993 L .48652 .08123 L F
.49215 .08383 m .48463 .07993 L .49139 .08307 L .025 .114 0 r
F
.49216 .08375 m .48463 .07992 L .48476 .07999 L .034 .116 0 r
F
.49216 .08375 m .4881 .08152 L .49139 .08304 L F
.49216 .08375 m .48513 .07989 L .48464 .07992 L F
.48467 .07995 m .48464 .07992 L .48463 .07992 L F
.49216 .08375 m .48464 .07992 L .48467 .07995 L F
.49228 .0813 m .48516 .07903 L .48464 .07938 L .382 .568 0 r
F
.49228 .08132 m .48516 .07903 L .48464 .07939 L .38 .563 0 r
F
.49224 .08216 m .48515 .07938 L .48464 .07961 L .264 .355 0 r
F
.49224 .0822 m .48515 .07939 L .48464 .07962 L .259 .346 0 r
F
.49215 .08383 m .48513 .07991 L .48463 .07993 L .025 .114 0 r
F
.49939 .08328 m .49228 .0813 L .49145 .08179 L .348 .494 0 r
F
.49938 .08331 m .49239 .08135 L .49145 .0818 L .342 .482 0 r
F
.49239 .08135 m .49228 .08132 L .4922 .08136 L F
.49239 .08135 m .4922 .08136 L .49145 .0818 L F
.49239 .08133 m .49282 .08041 L .49228 .0813 L .404 .588 0 r
F
.49239 .08133 m .49282 .08045 L .49228 .08132 L .496 .746 0 r
F
.50013 .08199 m .49296 .08048 L .49464 .08152 L F
.50741 .0836 m .49939 .08328 L .50645 .08538 L .164 0 0 r
F
.5074 .08368 m .49938 .08331 L .50644 .08544 L .536 .775 0 r
F
.4994 .08328 m .49228 .08132 L .49938 .08331 L .496 .746 0 r
F
.4994 .08328 m .49228 .0813 L .49939 .08328 L .404 .588 0 r
F
.49239 .08133 m .49228 .0813 L .4994 .08328 L F
.50013 .08199 m .49239 .08133 L .4994 .08328 L .496 .746 0 r
F
.49239 .08133 m .49228 .08132 L .4994 .08328 L F
.50002 .08356 m .49239 .08133 L .4994 .08328 L .404 .588 0 r
F
.5074 .08368 m .50706 .0836 L .49938 .08331 L .536 .775 0 r
F
.5072 .08359 m .50706 .0836 L .49939 .08328 L .164 0 0 r
F
.50741 .0836 m .50706 .0836 L .5072 .08359 L F
.50746 .08526 m .50631 .08492 L .5074 .08368 L .633 .017 0 r
F
.50746 .08547 m .50631 .08492 L .50746 .08526 L F
.50749 .08518 m .50631 .08492 L .50741 .0836 L .122 .143 0 r
F
.50631 .08492 m .50002 .08356 L .50613 .0836 L F
.50631 .08492 m .50613 .0836 L .50706 .0836 L F
.50706 .0836 m .4994 .08328 L .49939 .08328 L .164 0 0 r
F
.50706 .0836 m .50013 .08199 L .4994 .08328 L .536 .775 0 r
F
.50706 .0836 m .4994 .08328 L .49938 .08331 L F
.50642 .08357 m .50002 .08356 L .4994 .08328 L .164 0 0 r
F
.50613 .0836 m .50002 .08356 L .50642 .08357 L F
.50385 .08376 m .50023 .08309 L .50013 .08199 L .633 .017 0 r
F
.50631 .08492 m .50271 .08384 L .50385 .08376 L F
.50271 .08384 m .50023 .08309 L .50385 .08376 L F
.50706 .0836 m .50613 .0836 L .50642 .08357 L .164 0 0 r
F
.50631 .08492 m .50701 .08369 L .5074 .08368 L .633 .017 0 r
F
.50631 .08492 m .50706 .0836 L .50741 .0836 L .122 .143 0 r
F
.50631 .08492 m .50385 .08376 L .50701 .08369 L .633 .017 0 r
F
.50749 .08518 m .50025 .08304 L .50023 .08309 L .122 .143 0 r
F
.50275 .08385 m .50023 .08309 L .50021 .08314 L F
.50749 .08518 m .50023 .08309 L .50275 .08385 L F
.50631 .08492 m .50021 .08314 L .50002 .08356 L F
.50631 .08492 m .50024 .08321 L .50023 .08309 L .633 .017 0 r
F
.50746 .08547 m .50633 .08512 L .50631 .08492 L F
.50633 .08512 m .50024 .08321 L .50631 .08492 L F
.50749 .08518 m .50021 .08314 L .50631 .08492 L .122 .143 0 r
F
.50385 .08376 m .50013 .08199 L .50706 .0836 L .633 .017 0 r
F
.50385 .08376 m .50706 .0836 L .5074 .08368 L F
.50023 .08309 m .49306 .08051 L .50002 .08356 L .617 .015 0 r
F
.50023 .08309 m .49296 .08048 L .50013 .08199 L .651 .021 0 r
F
.50024 .08321 m .49296 .08048 L .50023 .08309 L F
.50025 .08304 m .49306 .08051 L .50023 .08309 L .617 .015 0 r
F
.49291 .08045 m .49296 .08048 L .50002 .08356 L F
.50002 .08356 m .49456 .08117 L .49245 .08134 L .404 .588 0 r
F
.49929 .08458 m .49224 .08216 L .49143 .08228 L .09 .139 0 r
F
.4993 .08464 m .49231 .08223 L .49929 .08466 L .356 .52 0 r
F
.49231 .08223 m .49231 .08223 L .49929 .08466 L F
.4993 .08464 m .49224 .08216 L .49929 .08458 L .186 .16 0 r
F
.49231 .08222 m .49224 .08216 L .49394 .08276 L F
.49231 .08222 m .49394 .08276 L .4993 .08464 L F
.4926 .08189 m .49276 .08151 L .49252 .08182 L F
.49546 .0828 m .49286 .0816 L .49232 .08221 L .356 .52 0 r
F
.50001 .08366 m .49286 .0816 L .49546 .0828 L F
.50001 .08366 m .49232 .08221 L .49231 .08222 L F
.49232 .08221 m .49224 .08219 L .49231 .08222 L F
.50001 .08366 m .49231 .08222 L .4993 .08464 L F
.49231 .08222 m .49224 .0822 L .4993 .08464 L F
.49929 .08458 m .49143 .08228 L .49811 .08586 L .09 .139 0 r
F
.49929 .08466 m .49143 .0823 L .49811 .08591 L .074 .136 0 r
F
.50627 .08741 m .49929 .08466 L .49811 .08591 L .527 .737 0 r
F
.49929 .08466 m .49224 .0822 L .49143 .0823 L .074 .136 0 r
F
.49973 .08753 m .49231 .08222 L .4993 .08464 L .186 .16 0 r
F
.49973 .08753 m .4926 .08189 L .49231 .08222 L F
.4926 .08189 m .49252 .08182 L .49231 .08222 L F
.49973 .08753 m .49286 .0816 L .4926 .08189 L F
.48969 .26143 m .49647 .13309 L .498 .1116 L 1 .771 0 r
F
.48969 .26143 m .498 .1116 L .49915 .10914 L F
.50366 .09167 m .49949 .08777 L .5016 .08986 L 0 .038 0 r
F
.50646 .09412 m .50231 .09034 L .50366 .09167 L F
.50231 .09034 m .49949 .08777 L .50366 .09167 L F
.48969 .26143 m .49915 .10914 L .50625 .09393 L 1 .771 0 r
F
.50383 .0918 m .498 .1116 L .49908 .08764 L .895 .354 0 r
F
.50625 .09393 m .50336 .10011 L .50383 .0918 L F
.50336 .10011 m .498 .1116 L .50383 .0918 L F
.50612 .09382 m .49971 .08784 L .49949 .08777 L 0 .038 0 r
F
.50625 .09393 m .49971 .08784 L .50612 .09382 L F
.50048 .08855 m .49909 .08746 L .5013 .08911 L .895 .354 0 r
F
.5016 .08986 m .49949 .08777 L .49908 .08764 L 0 .038 0 r
F
.4983 .11223 m .49971 .08784 L .50272 .09064 L 1 .693 0 r
F
.50333 .10064 m .50272 .09064 L .50625 .09393 L F
.4983 .11223 m .50272 .09064 L .50333 .10064 L F
.49923 .09606 m .49859 .10352 L .49971 .08784 L F
.4983 .11223 m .49859 .10352 L .49923 .09606 L F
.4983 .11223 m .49785 .11386 L .49859 .10352 L F
.48668 .31351 m .48876 .27631 L .48969 .26143 L F
.49049 .24477 m .49373 .17732 L .49647 .13309 L 1 .771 0 r
F
.49373 .17732 m .49457 .15996 L .49647 .13309 L F
.48668 .31351 m .49457 .15996 L .49025 .24973 L 1 .693 0 r
F
.48876 .27631 m .49025 .24973 L .48969 .26143 L F
.48698 .31022 m .49647 .13309 L .48969 .26143 L 1 .771 0 r
F
.49025 .24973 m .49457 .15996 L .49615 .14434 L 1 .693 0 r
F
.48845 .26263 m .49457 .15996 L .49373 .17732 L 1 .771 0 r
F
.48698 .31022 m .48845 .26263 L .49373 .17732 L F
.48698 .31022 m .49373 .17732 L .49049 .24477 L F
.49025 .24973 m .49785 .11386 L .48969 .26143 L 1 .693 0 r
F
.49457 .15996 m .4989 .08738 L .49971 .08784 L 1 .514 0 r
F
.48969 .26143 m .4983 .11223 L .50616 .09478 L 1 .693 0 r
F
.50646 .09412 m .50625 .09393 L .50612 .09382 L 0 .038 0 r
F
.4983 .11223 m .50625 .09393 L .50646 .09412 L 1 .693 0 r
F
.48969 .26143 m .49785 .11386 L .4983 .11223 L F
.49615 .14434 m .49457 .15996 L .49785 .11386 L F
.48845 .26263 m .48934 .23372 L .49457 .15996 L 1 .771 0 r
F
.48969 .26143 m .50616 .09478 L .50646 .09412 L 1 .693 0 r
F
.48698 .31022 m .48969 .26143 L .50653 .09331 L 1 .771 0 r
F
.48969 .26143 m .50625 .09393 L .50653 .09331 L F
.48832 .23486 m .4913 .11159 L .49148 .10786 L 1 .514 0 r
F
.48825 .23711 m .4913 .11159 L .48832 .23486 L F
.48934 .23372 m .49131 .11859 L .49146 .11617 L 1 .576 0 r
F
.48996 .20556 m .49146 .11617 L .49218 .1048 L F
.48934 .23372 m .49146 .11617 L .48996 .20556 L F
.48934 .23372 m .48996 .20556 L .48997 .20547 L F
.49264 .08386 m .49263 .08386 L .49329 .08443 L 0 .085 0 r
F
.49444 .15472 m .49267 .08387 L .4989 .08738 L 1 .514 0 r
F
.49218 .1048 m .49263 .08398 L .49263 .08399 L 1 .576 0 r
F
.49131 .11859 m .49148 .10816 L .49218 .1048 L F
.49217 .08384 m .49215 .08383 L .49215 .08383 L 0 .085 0 r
F
.49217 .08385 m .49223 .08383 L .49216 .08375 L 0 0 0 r
F
.49223 .08383 m .49264 .08373 L .49216 .08375 L F
.49023 .08404 m .48305 .08066 L .48882 .08436 L .56 .743 0 r
F
.49023 .08406 m .48305 .08066 L .48882 .08437 L .558 .74 0 r
F
.49023 .08404 m .48393 .08024 L .48305 .08066 L .56 .743 0 r
F
.49023 .08406 m .48392 .08025 L .48305 .08066 L .558 .74 0 r
F
.48609 .08038 m .48513 .07989 L .48625 .08051 L .878 .059 0 r
F
.49259 .0837 m .48513 .07989 L .49264 .08373 L F
.48548 .08235 m .48546 .08246 L .48545 .0822 L 1 .481 0 r
F
.48318 .31724 m .48092 .3032 L .4913 .11161 L .975 .496 0 r
F
.49134 .11182 m .4913 .11161 L .49148 .10816 L F
.48318 .31724 m .4913 .11161 L .49134 .11182 L F
.49111 .11061 m .48546 .08246 L .48548 .08235 L 1 .481 0 r
F
.4913 .11159 m .49114 .1108 L .49111 .11061 L F
.49114 .1108 m .48546 .08246 L .49111 .11061 L F
.48546 .08246 m .48546 .08246 L .48548 .08235 L F
.48085 .0861 m .47667 .08205 L .47845 .08643 L .829 .975 0 r
F
.48085 .0861 m .47667 .08205 L .47845 .08643 L F
.48085 .0861 m .47814 .0818 L .47667 .08205 L F
.48085 .0861 m .47814 .0818 L .47667 .08205 L F
.48311 .08593 m .47814 .08188 L .48084 .08635 L .752 .908 0 r
F
.48311 .08593 m .47814 .08188 L .48084 .08635 L .751 .908 0 r
F
.47845 .08643 m .47515 .08214 L .47598 .08662 L .801 .958 0 r
F
.47845 .08643 m .47515 .08214 L .47598 .08662 L F
.47845 .08643 m .47667 .08205 L .47515 .08214 L F
.47845 .08643 m .47667 .08205 L .47515 .08214 L F
.48084 .08635 m .47667 .08214 L .47845 .08667 L .84 .974 0 r
F
.48084 .08635 m .47667 .08214 L .47845 .08667 L F
.48084 .08635 m .47814 .08188 L .47667 .08214 L F
.48084 .08635 m .47814 .08188 L .47667 .08214 L F
.4831 .0863 m .47814 .08198 L .48083 .08669 L .753 .894 0 r
F
.4831 .0863 m .47814 .08198 L .48083 .08669 L .752 .893 0 r
F
.48311 .08593 m .47954 .08165 L .47814 .08188 L .752 .908 0 r
F
.48311 .08593 m .47954 .08165 L .47814 .08188 L .751 .908 0 r
F
.4831 .0863 m .47953 .08177 L .47814 .08198 L .753 .894 0 r
F
.48522 .08542 m .47953 .08177 L .4831 .0863 L .781 .929 0 r
F
.4831 .0863 m .47953 .08177 L .47814 .08198 L .752 .893 0 r
F
.48522 .08542 m .47953 .08177 L .4831 .0863 L .78 .929 0 r
F
.48522 .08542 m .48083 .08138 L .47953 .08177 L .781 .929 0 r
F
.48522 .08542 m .48083 .08138 L .47953 .08177 L .78 .929 0 r
F
.48084 .08116 m .47593 .07753 L .47954 .08155 L .741 .919 0 r
F
.48084 .08116 m .47593 .07753 L .47954 .08155 L F
.48084 .08126 m .47593 .07754 L .47954 .08165 L .741 .915 0 r
F
.48084 .08126 m .47593 .07754 L .47954 .08165 L F
.47954 .08155 m .47541 .07763 L .47814 .0818 L .774 .941 0 r
F
.47954 .08155 m .47541 .07763 L .47814 .0818 L F
.47954 .08155 m .47593 .07753 L .47541 .07763 L F
.47954 .08155 m .47593 .07753 L .47541 .07763 L F
.48083 .08138 m .47593 .07755 L .47953 .08177 L .742 .91 0 r
F
.48083 .08138 m .47593 .07755 L .47953 .08177 L F
.48084 .08116 m .4764 .0774 L .47593 .07753 L .741 .919 0 r
F
.48202 .08082 m .4764 .0774 L .48084 .08116 L .7 .887 0 r
F
.48084 .08116 m .4764 .0774 L .47593 .07753 L .741 .919 0 r
F
.48202 .08082 m .4764 .0774 L .48084 .08116 L .7 .887 0 r
F
.48084 .08126 m .4764 .07741 L .47593 .07754 L .741 .915 0 r
F
.48201 .08094 m .4764 .07741 L .48084 .08126 L .698 .88 0 r
F
.48084 .08126 m .4764 .07741 L .47593 .07754 L .741 .915 0 r
F
.48201 .08094 m .4764 .07741 L .48084 .08126 L .698 .88 0 r
F
.48083 .08138 m .4764 .07743 L .47593 .07755 L .742 .91 0 r
F
.48201 .0811 m .4764 .07743 L .48083 .08138 L .696 .871 0 r
F
.48083 .08138 m .4764 .07743 L .47593 .07755 L .742 .91 0 r
F
.48201 .0811 m .4764 .07743 L .48083 .08138 L .696 .871 0 r
F
.48202 .08082 m .47684 .07725 L .4764 .0774 L .7 .887 0 r
F
.48306 .08034 m .47684 .07725 L .48202 .08082 L .681 .874 0 r
F
.48202 .08082 m .47684 .07725 L .4764 .0774 L .7 .887 0 r
F
.48306 .08034 m .47684 .07725 L .48202 .08082 L .681 .874 0 r
F
.48201 .08094 m .47684 .07727 L .4764 .07741 L .698 .88 0 r
F
.48305 .08048 m .47684 .07727 L .48201 .08094 L .676 .864 0 r
F
.48201 .08094 m .47684 .07727 L .4764 .07741 L .698 .88 0 r
F
.48305 .08048 m .47684 .07727 L .48201 .08094 L .676 .864 0 r
F
.48201 .0811 m .47684 .07729 L .4764 .07743 L .696 .871 0 r
F
.48305 .08066 m .47684 .07729 L .48201 .0811 L .671 .853 0 r
F
.48201 .0811 m .47684 .07729 L .4764 .07743 L .696 .871 0 r
F
.48305 .08066 m .47684 .07729 L .48201 .0811 L .671 .852 0 r
F
.48306 .08034 m .47722 .07708 L .47684 .07725 L .681 .874 0 r
F
.48394 .07984 m .47722 .07708 L .48306 .08034 L .608 .823 0 r
F
.48306 .08034 m .47722 .07708 L .47684 .07725 L .681 .874 0 r
F
.48394 .07985 m .47722 .07708 L .48306 .08034 L .608 .823 0 r
F
.48305 .08048 m .47722 .0771 L .47684 .07727 L .676 .864 0 r
F
.48393 .08002 m .47722 .0771 L .48305 .08048 L .596 .807 0 r
F
.48305 .08048 m .47722 .0771 L .47684 .07727 L .676 .864 0 r
F
.48393 .08002 m .47722 .0771 L .48305 .08048 L .596 .807 0 r
F
.48305 .08066 m .47722 .07713 L .47684 .07729 L .671 .853 0 r
F
.48393 .08024 m .47722 .07713 L .48305 .08066 L .582 .787 0 r
F
.48305 .08066 m .47722 .07713 L .47684 .07729 L .671 .852 0 r
F
.48392 .08025 m .47722 .07713 L .48305 .08066 L .582 .787 0 r
F
.48394 .07984 m .47754 .07691 L .47722 .07708 L .608 .823 0 r
F
.48464 .07938 m .47754 .07691 L .48394 .07984 L .481 .721 0 r
F
.48394 .07985 m .47754 .07691 L .47722 .07708 L .608 .823 0 r
F
.48464 .07939 m .47754 .07691 L .48394 .07985 L .48 .721 0 r
F
.48393 .08002 m .47754 .07694 L .47722 .0771 L .596 .807 0 r
F
.48464 .07961 m .47754 .07694 L .48393 .08002 L .452 .688 0 r
F
.48393 .08002 m .47754 .07694 L .47722 .0771 L .596 .807 0 r
F
.48464 .07962 m .47754 .07694 L .48393 .08002 L .451 .688 0 r
F
.48393 .08024 m .47754 .07696 L .47722 .07713 L .582 .787 0 r
F
.48463 .07992 m .47754 .07696 L .48393 .08024 L .428 .647 0 r
F
.48392 .08025 m .47754 .07696 L .47722 .07713 L .582 .787 0 r
F
.48463 .07993 m .47754 .07696 L .48392 .08025 L .428 .646 0 r
F
.48464 .07938 m .4778 .07676 L .47754 .07691 L .481 .721 0 r
F
.48464 .07939 m .4778 .07676 L .47754 .07691 L .48 .721 0 r
F
.48464 .07961 m .4778 .07679 L .47754 .07694 L .452 .688 0 r
F
.48464 .07962 m .4778 .07679 L .47754 .07694 L .451 .688 0 r
F
.48463 .07992 m .4778 .07683 L .47754 .07696 L .428 .647 0 r
F
.48463 .07993 m .4778 .07683 L .47754 .07696 L .428 .646 0 r
F
.48504 .09215 m .47962 .0806 L .48546 .08246 L 1 .55 0 r
F
.48071 .11801 m .47277 .11461 L .47264 .12041 L 1 1 0 r
F
.48071 .11801 m .47995 .11259 L .47277 .11461 L F
.48066 .15202 m .48071 .11801 L .47264 .12041 L 1 .553 0 r
F
.47995 .11256 m .47291 .10889 L .47277 .11451 L 1 1 0 r
F
.47995 .11256 m .47918 .10726 L .47291 .10889 L F
.47995 .11259 m .47291 .10895 L .47277 .11461 L F
.47995 .11259 m .47918 .10728 L .47291 .10895 L F
.47918 .10726 m .47305 .1034 L .47291 .10889 L F
.47918 .10726 m .47839 .10207 L .47305 .1034 L F
.47918 .10728 m .47305 .10344 L .47291 .10895 L F
.47918 .10728 m .47839 .10208 L .47305 .10344 L F
.47842 .10066 m .47761 .09602 L .47319 .09662 L .936 1 0 r
F
.47842 .10067 m .47761 .09603 L .47319 .09664 L .937 1 0 r
F
.47839 .10207 m .47319 .09805 L .47305 .1034 L 1 1 0 r
F
.47839 .10207 m .4776 .09699 L .47319 .09805 L F
.48361 .10304 m .4776 .09699 L .47839 .10207 L .784 .84 0 r
F
.47839 .10208 m .47319 .09807 L .47305 .10344 L 1 1 0 r
F
.47839 .10208 m .4776 .097 L .47319 .09807 L F
.48361 .10304 m .4776 .097 L .47839 .10208 L .785 .841 0 r
F
.48361 .10304 m .48192 .09732 L .4776 .09699 L .784 .84 0 r
F
.48361 .10304 m .48192 .09732 L .4776 .097 L .785 .841 0 r
F
.47761 .09602 m .47333 .09138 L .47319 .09662 L .824 .962 0 r
F
.47761 .09602 m .4768 .09143 L .47333 .09138 L F
.47761 .09603 m .47333 .09139 L .47319 .09664 L .825 .963 0 r
F
.47761 .09603 m .4768 .09143 L .47333 .09139 L F
.48192 .09732 m .47679 .09203 L .4776 .09699 L .825 .908 0 r
F
.48192 .09732 m .47679 .09204 L .4776 .097 L .826 .908 0 r
F
.48192 .09732 m .4802 .092 L .47679 .09203 L .825 .908 0 r
F
.48192 .09732 m .4802 .092 L .47679 .09204 L .826 .908 0 r
F
.4768 .09102 m .47347 .08668 L .47334 .09101 L .833 .987 0 r
F
.4768 .09102 m .47347 .08669 L .47334 .09101 L .833 .988 0 r
F
.4768 .09102 m .47598 .08662 L .47347 .08668 L .833 .987 0 r
F
.4768 .09102 m .47598 .08662 L .47347 .08669 L .833 .988 0 r
F
.48021 .0913 m .47598 .08686 L .4768 .09143 L .836 .968 0 r
F
.48021 .0913 m .47598 .08686 L .4768 .09143 L .837 .968 0 r
F
.4768 .09143 m .47347 .08693 L .47333 .09138 L .848 .989 0 r
F
.4768 .09143 m .47347 .08693 L .47333 .09139 L .849 .989 0 r
F
.4768 .09143 m .47598 .08686 L .47347 .08693 L .848 .989 0 r
F
.4768 .09143 m .47598 .08686 L .47347 .08693 L .849 .989 0 r
F
.4802 .092 m .47598 .08719 L .47679 .09203 L .857 .959 0 r
F
.4802 .092 m .47598 .08719 L .47679 .09204 L .857 .96 0 r
F
.48021 .0913 m .47845 .08667 L .47598 .08686 L .836 .968 0 r
F
.48021 .0913 m .47845 .08667 L .47598 .08686 L .837 .968 0 r
F
.4802 .092 m .47844 .08699 L .47598 .08719 L .857 .959 0 r
F
.48351 .09104 m .47844 .08699 L .4802 .092 L .796 .945 0 r
F
.48351 .09104 m .47844 .08699 L .4802 .092 L .795 .945 0 r
F
.4802 .092 m .47844 .08699 L .47598 .08719 L .857 .96 0 r
F
.48351 .09104 m .48083 .08669 L .47844 .08699 L .796 .945 0 r
F
.48351 .09104 m .48083 .08669 L .47844 .08699 L .795 .945 0 r
F
.47598 .08662 m .47361 .08223 L .47347 .08668 L .863 1 0 r
F
.47598 .08662 m .47361 .08223 L .47347 .08669 L .864 1 0 r
F
.47598 .08662 m .47515 .08214 L .47361 .08223 L .863 1 0 r
F
.47598 .08662 m .47515 .08214 L .47361 .08223 L .864 1 0 r
F
.47845 .08667 m .47515 .08223 L .47598 .08686 L .808 .954 0 r
F
.47845 .08667 m .47515 .08223 L .47598 .08686 L F
.47598 .08686 m .47361 .08233 L .47347 .08693 L .88 1 0 r
F
.47598 .08686 m .47361 .08233 L .47347 .08693 L .881 1 0 r
F
.47598 .08686 m .47515 .08223 L .47361 .08233 L .88 1 0 r
F
.47598 .08686 m .47515 .08223 L .47361 .08233 L .881 1 0 r
F
.47844 .08699 m .47515 .08233 L .47598 .08719 L .818 .948 0 r
F
.47844 .08699 m .47515 .08233 L .47598 .08719 L .819 .949 0 r
F
.47845 .08667 m .47667 .08214 L .47515 .08223 L .808 .954 0 r
F
.47845 .08667 m .47667 .08214 L .47515 .08223 L F
.47844 .08699 m .47667 .08225 L .47515 .08233 L .818 .948 0 r
F
.48083 .08669 m .47667 .08225 L .47844 .08699 L .855 .97 0 r
F
.48083 .08669 m .47667 .08225 L .47844 .08699 L F
.47844 .08699 m .47667 .08225 L .47515 .08233 L .819 .949 0 r
F
.48083 .08669 m .47814 .08198 L .47667 .08225 L .855 .97 0 r
F
.48083 .08669 m .47814 .08198 L .47667 .08225 L F
.47814 .0818 m .47487 .07771 L .47667 .08205 L .797 .961 0 r
F
.47814 .0818 m .47487 .07771 L .47667 .08205 L F
.47814 .08188 m .47487 .07772 L .47667 .08214 L .801 .96 0 r
F
.47814 .08188 m .47487 .07772 L .47667 .08214 L F
.47667 .08205 m .47432 .07776 L .47515 .08214 L .82 .979 0 r
F
.47667 .08205 m .47432 .07776 L .47515 .08214 L F
.47814 .08198 m .47487 .07774 L .47667 .08225 L .806 .959 0 r
F
.47814 .08198 m .47487 .07774 L .47667 .08225 L F
.47814 .0818 m .47541 .07763 L .47487 .07771 L .797 .961 0 r
F
.47814 .0818 m .47541 .07763 L .47487 .07771 L F
.47814 .08188 m .47541 .07764 L .47487 .07772 L .801 .96 0 r
F
.47954 .08165 m .47541 .07764 L .47814 .08188 L .777 .938 0 r
F
.47814 .08188 m .47541 .07764 L .47487 .07772 L .801 .96 0 r
F
.47954 .08165 m .47541 .07764 L .47814 .08188 L .777 .938 0 r
F
.47814 .08198 m .47541 .07766 L .47487 .07774 L .806 .959 0 r
F
.47953 .08177 m .47541 .07766 L .47814 .08198 L .781 .935 0 r
F
.47814 .08198 m .47541 .07766 L .47487 .07774 L .806 .959 0 r
F
.47953 .08177 m .47541 .07766 L .47814 .08198 L .781 .935 0 r
F
.47954 .08165 m .47593 .07754 L .47541 .07764 L .777 .938 0 r
F
.47954 .08165 m .47593 .07754 L .47541 .07764 L F
.47953 .08177 m .47593 .07755 L .47541 .07766 L .781 .935 0 r
F
.47953 .08177 m .47593 .07755 L .47541 .07766 L F
.47708 .31617 m .47808 .07893 L .48497 .09357 L .874 .402 0 r
F
.47943 .32757 m .48497 .09357 L .48072 .307 L .894 .42 0 r
F
.47943 .32757 m .47708 .31617 L .48497 .09357 L F
.47946 .32696 m .47713 .31484 L .48497 .09359 L .895 .421 0 r
F
.4808 .30297 m .48497 .09357 L .48546 .08246 L .993 .251 0 r
F
.48072 .307 m .48079 .30358 L .4808 .30297 L F
.48079 .30358 m .48497 .09357 L .4808 .30297 L F
.48218 .32738 m .47943 .32757 L .48072 .307 L .874 .379 0 r
F
.48223 .32673 m .48014 .3269 L .48092 .3032 L .874 .382 0 r
F
.48014 .3269 m .47946 .32696 L .4807 .30688 L F
.48014 .3269 m .4807 .30688 L .48092 .3032 L F
.48498 .09362 m .48497 .09359 L .485 .09269 L .895 .421 0 r
F
.47946 .32696 m .48497 .09359 L .48498 .09362 L F
.48497 .09357 m .48491 .09341 L .48504 .09215 L 1 .55 0 r
F
.48491 .09341 m .47962 .0806 L .48237 .08647 L F
.48491 .09341 m .48237 .08647 L .48504 .09215 L F
.48497 .09357 m .47808 .07893 L .47809 .07876 L F
.47949 .08044 m .47809 .07876 L .47813 .07743 L 1 .539 0 r
F
.47962 .0806 m .47813 .07743 L .47814 .07727 L F
.48497 .09357 m .47809 .07876 L .47962 .0806 L 1 .55 0 r
F
.485 .09269 m .47813 .07743 L .47962 .0806 L 1 .539 0 r
F
.47962 .0806 m .47814 .07727 L .48315 .08074 L F
.48516 .07903 m .4778 .07676 L .48464 .07938 L .402 .606 0 r
F
.48516 .07903 m .4778 .07676 L .48464 .07939 L .402 .604 0 r
F
.48515 .07938 m .4778 .07679 L .48464 .07961 L .366 .541 0 r
F
.48515 .07939 m .4778 .07679 L .48464 .07962 L .365 .539 0 r
F
.48513 .07989 m .4778 .07683 L .48463 .07992 L .32 .457 0 r
F
.48513 .07991 m .4778 .07683 L .48463 .07993 L .319 .454 0 r
F
.48516 .07903 m .47799 .07662 L .4778 .07676 L .402 .606 0 r
F
.48516 .07903 m .47799 .07662 L .4778 .07676 L .402 .604 0 r
F
.48515 .07938 m .47799 .07667 L .4778 .07679 L .366 .541 0 r
F
.48009 .07761 m .47799 .07667 L .4778 .07679 L .365 .539 0 r
F
.48515 .07939 m .47801 .07667 L .48009 .07761 L F
.47801 .07667 m .47799 .07667 L .48009 .07761 L F
.48545 .07967 m .47799 .07667 L .48515 .07938 L 0 .112 0 r
F
.48516 .07903 m .47799 .07662 L .48516 .07903 L .081 .137 0 r
F
.48548 .07854 m .478 .07662 L .48516 .07903 L .097 .144 0 r
F
.48547 .07898 m .478 .07662 L .48516 .07903 L .081 .137 0 r
F
.478 .07662 m .47799 .07662 L .48516 .07903 L F
.48516 .07903 m .47799 .07662 L .48516 .07903 L .097 .144 0 r
F
.478 .07662 m .47799 .07662 L .48516 .07903 L F
.48547 .079 m .478 .07667 L .48515 .07939 L 0 .121 0 r
F
.478 .07667 m .47799 .07667 L .47801 .07667 L F
.478 .07667 m .47801 .07667 L .48515 .07939 L F
.478 .07667 m .47811 .07665 L .47799 .07667 L 0 .112 0 r
F
.478 .07667 m .47799 .07667 L .47799 .07667 L F
.478 .07667 m .47811 .07665 L .47799 .07667 L 0 .121 0 r
F
.48545 .07967 m .47812 .07666 L .478 .07667 L 0 .112 0 r
F
.48545 .07967 m .47799 .07667 L .478 .07667 L F
.48675 .08697 m .48545 .0822 L .48541 .08094 L .989 .147 0 r
F
.48683 .08726 m .48541 .08094 L .4854 .08084 L F
.4861 .08042 m .48513 .07991 L .48626 .08054 L .107 .119 0 r
F
.48609 .08038 m .4854 .08084 L .48513 .07989 L .878 .059 0 r
F
.49264 .08373 m .48609 .08038 L .49216 .08375 L F
.48609 .08038 m .48625 .08051 L .49216 .08375 L F
.49263 .08386 m .4861 .08042 L .49215 .08383 L .107 .119 0 r
F
.4861 .08042 m .48626 .08054 L .49215 .08383 L F
.49264 .08373 m .49259 .0837 L .49264 .08373 L .878 .059 0 r
F
.49148 .10786 m .48703 .08711 L .49263 .08386 L 1 .481 0 r
F
.48683 .08726 m .4854 .08084 L .48571 .08096 L .989 .147 0 r
F
.49263 .08386 m .49191 .08344 L .48513 .07991 L .107 .119 0 r
F
.49191 .08344 m .48544 .07969 L .48542 .07971 L F
.48837 .0816 m .48542 .07971 L .48513 .07991 L F
.49191 .08344 m .48598 .08003 L .48837 .0816 L F
.48598 .08003 m .48542 .07971 L .48837 .0816 L F
.48549 .07991 m .48544 .07969 L .48971 .08216 L 1 .481 0 r
F
.48652 .0805 m .48547 .07977 L .48545 .07968 L .638 .019 0 r
F
.48554 .07974 m .48545 .07968 L .48545 .07967 L F
.48652 .0805 m .48545 .07968 L .48554 .07974 L F
.48683 .08726 m .48571 .08096 L .49191 .08344 L .989 .147 0 r
F
.48573 .08102 m .49179 .08339 L .4919 .08345 L 1 .481 0 r
F
.49181 .08352 m .4919 .08345 L .49263 .08386 L F
.48573 .08102 m .4919 .08345 L .49181 .08352 L F
.48703 .08711 m .49181 .08352 L .49263 .08386 L F
.49259 .0837 m .48571 .08096 L .48609 .08038 L .878 .059 0 r
F
.49191 .08344 m .48571 .08096 L .49259 .0837 L F
.48549 .07991 m .48971 .08216 L .49263 .08386 L 1 .481 0 r
F
.4913 .11159 m .48683 .08726 L .49148 .10786 L F
.48571 .08096 m .4854 .08084 L .48609 .08038 L .878 .059 0 r
F
.48683 .08726 m .48544 .07969 L .49148 .10786 L 1 .481 0 r
F
.49148 .10816 m .48683 .08726 L .49253 .08379 L .989 .147 0 r
F
.49263 .08385 m .49253 .08379 L .49264 .08373 L F
.49263 .08386 m .49263 .08386 L .49263 .08386 L 1 .514 0 r
F
.49148 .10816 m .49253 .08379 L .49263 .08385 L .989 .147 0 r
F
.48683 .08726 m .48545 .07987 L .48548 .0799 L 1 .481 0 r
F
.4913 .11159 m .48751 .09109 L .48683 .08726 L F
.4914 .10777 m .48675 .08697 L .48683 .08726 L .989 .147 0 r
F
.48675 .08697 m .48541 .08094 L .48683 .08726 L F
.48751 .09109 m .48676 .08698 L .48683 .08726 L 1 .481 0 r
F
.48676 .08698 m .48545 .07987 L .48683 .08726 L F
.48683 .08726 m .49191 .08344 L .49264 .08373 L .989 .147 0 r
F
.48703 .08711 m .48573 .08102 L .49181 .08352 L 1 .481 0 r
F
.48573 .08102 m .48549 .07991 L .49179 .08339 L F
.49264 .08373 m .49191 .08344 L .49259 .0837 L .878 .059 0 r
F
.48676 .08698 m .48545 .0822 L .48545 .08136 L 1 .481 0 r
F
.48565 .08105 m .48545 .08136 L .48545 .07992 L F
.48676 .08698 m .48545 .08136 L .48565 .08105 L F
.48546 .07993 m .48545 .07992 L .48545 .07987 L F
.48676 .08698 m .48545 .07992 L .48546 .07993 L F
.48548 .0799 m .48545 .07987 L .48544 .07969 L F
.48544 .07969 m .47799 .07672 L .48513 .07991 L 0 .089 0 r
F
.48048 .07771 m .47811 .07675 L .47799 .07672 L F
.48544 .07969 m .47812 .07675 L .48048 .07771 L F
.47812 .07675 m .47811 .07675 L .48048 .07771 L F
.48513 .07989 m .47799 .07672 L .4778 .07683 L .32 .457 0 r
F
.47906 .07736 m .47799 .07672 L .4778 .07683 L .319 .454 0 r
F
.48513 .07991 m .478 .07672 L .47906 .07736 L F
.478 .07672 m .47799 .07672 L .47906 .07736 L F
.48025 .07841 m .47999 .07824 L .47811 .07675 L .888 .064 0 r
F
.4798 .07773 m .47799 .07672 L .47799 .07672 L 0 .075 0 r
F
.4854 .08084 m .4798 .07773 L .4798 .07773 L F
.4798 .07773 m .47799 .07672 L .4798 .07773 L F
.4854 .08084 m .47831 .07686 L .48513 .07989 L F
.4854 .08084 m .47812 .07675 L .47799 .07672 L F
.4854 .08084 m .47799 .07672 L .47799 .07672 L F
.48546 .08246 m .47811 .07675 L .47812 .07675 L .888 .064 0 r
F
.48545 .08082 m .47812 .07675 L .48544 .07969 L F
.48546 .08246 m .47812 .07675 L .48545 .0822 L F
.48546 .08234 m .47811 .07675 L .47812 .07676 L 1 .165 0 r
F
.48545 .0822 m .47812 .07676 L .4854 .08084 L F
.48546 .08234 m .47812 .07676 L .48545 .0822 L F
.47811 .07675 m .47812 .07675 L .4854 .08084 L F
.48545 .0822 m .47812 .07675 L .48545 .08082 L .888 .064 0 r
F
.47812 .07675 m .47811 .07675 L .4781 .07675 L 0 .075 0 r
F
.47812 .07675 m .4781 .07675 L .47799 .07672 L F
.47966 .07793 m .47952 .07787 L .47811 .07675 L 1 .165 0 r
F
.47952 .07787 m .47814 .07727 L .47811 .07675 L F
.47999 .07824 m .47811 .07675 L .47811 .07675 L .888 .064 0 r
F
.47952 .07787 m .47811 .07675 L .47811 .07675 L 1 .165 0 r
F
.47999 .07824 m .47814 .07702 L .47811 .07675 L .888 .064 0 r
F
.48546 .08246 m .48315 .08074 L .48025 .07841 L F
.48526 .08219 m .48305 .08066 L .47966 .07793 L 1 .165 0 r
F
.48305 .08066 m .47841 .07746 L .47954 .07788 L F
.48315 .08074 m .48029 .07848 L .48025 .07841 L .888 .064 0 r
F
.48305 .08066 m .47954 .07788 L .47966 .07793 L 1 .165 0 r
F
.48315 .08074 m .48046 .07874 L .48029 .07848 L .888 .064 0 r
F
.48046 .07874 m .47814 .07702 L .48025 .07841 L F
.47799 .07672 m .47799 .07672 L .47799 .07672 L 0 .075 0 r
F
.47811 .07675 m .47811 .07675 L .47812 .07675 L 1 .165 0 r
F
.48554 .08007 m .47811 .07665 L .47812 .07666 L .611 .012 0 r
F
.48553 .07999 m .47813 .07666 L .48545 .07967 L .893 .063 0 r
F
.47812 .07666 m .47812 .07666 L .48545 .07967 L F
.47953 .07715 m .47812 .07666 L .478 .07667 L 0 .121 0 r
F
.48547 .079 m .47812 .07666 L .47953 .07715 L F
.4855 .07948 m .48515 .07938 L .4855 .07952 L .408 0 0 r
F
.4855 .07948 m .4855 .07952 L .49224 .08216 L F
.49276 .08151 m .4855 .07948 L .49224 .08216 L F
.49282 .08041 m .48516 .07903 L .49228 .0813 L .01 .135 0 r
F
.49282 .08045 m .48516 .07903 L .49228 .08132 L .441 .676 0 r
F
.49276 .08157 m .48515 .07939 L .49224 .0822 L .341 .495 0 r
F
.49262 .08038 m .49233 .08032 L .48516 .07903 L .01 .135 0 r
F
.49233 .08032 m .48548 .07854 L .48536 .07873 L .441 .676 0 r
F
.49233 .08032 m .48536 .07873 L .48516 .07903 L F
.4862 .07921 m .48547 .07898 L .48516 .07903 L .01 .135 0 r
F
.49255 .0811 m .49282 .08041 L .49239 .08133 L .404 .588 0 r
F
.49464 .08152 m .49296 .08048 L .49239 .08133 L .496 .746 0 r
F
.49456 .08117 m .49282 .08041 L .49245 .08134 L .404 .588 0 r
F
.49296 .08048 m .49282 .08045 L .49239 .08133 L .496 .746 0 r
F
.49245 .08134 m .49255 .0811 L .49239 .08133 L .404 .588 0 r
F
.49292 .08146 m .4916 .08094 L .49282 .08045 L .536 0 0 r
F
.49233 .08032 m .48516 .07903 L .48516 .07903 L .01 .135 0 r
F
.49282 .08045 m .49233 .08032 L .48516 .07903 L .441 .676 0 r
F
.49233 .08032 m .48516 .07903 L .48516 .07903 L F
.49154 .08091 m .48547 .07898 L .48911 .07969 L 0 .117 0 r
F
.49151 .08091 m .48547 .07898 L .49154 .08091 L F
.49286 .0816 m .49276 .08151 L .4926 .08189 L .186 .16 0 r
F
.49231 .08222 m .49252 .08182 L .49224 .08216 L F
.49232 .08221 m .49276 .08157 L .49224 .08219 L .356 .52 0 r
F
.49286 .0816 m .49276 .08157 L .49232 .08221 L F
.49231 .08222 m .49224 .08219 L .49224 .0822 L F
.49231 .08223 m .49224 .0822 L .49231 .08223 L F
.4927 .08556 m .48998 .08319 L .49054 .08359 L 1 .085 0 r
F
.48999 .0832 m .48997 .08319 L .48998 .08319 L F
.49192 .08467 m .48697 .0809 L .49193 .08467 L .638 .019 0 r
F
.48697 .0809 m .48547 .07977 L .48734 .08118 L F
.48697 .0809 m .48734 .08118 L .49193 .08467 L F
.49264 .08387 m .49264 .08386 L .49264 .08387 L 1 .576 0 r
F
.49264 .08387 m .49264 .08387 L .49267 .08404 L F
.49264 .08386 m .49264 .08373 L .49267 .08387 L F
.49263 .08399 m .49263 .08398 L .49263 .08385 L F
.49264 .08386 m .49263 .08385 L .49264 .08373 L F
.49263 .08399 m .49263 .08385 L .49264 .08386 L F
.4927 .08523 m .49063 .08346 L .49276 .08157 L 1 .085 0 r
F
.49276 .08157 m .4922 .08137 L .48515 .07939 L .341 .495 0 r
F
.49054 .08359 m .48545 .07967 L .4922 .08137 L .638 .019 0 r
F
.49054 .08359 m .48659 .08001 L .4927 .08523 L 1 .085 0 r
F
.48659 .08001 m .4922 .08137 L .49276 .08157 L F
.49271 .08527 m .49054 .08359 L .49276 .08151 L .638 .019 0 r
F
.49063 .08346 m .49216 .08142 L .49276 .08157 L 1 .085 0 r
F
.49054 .08359 m .4922 .08137 L .49276 .08151 L .638 .019 0 r
F
.49063 .08346 m .48659 .08001 L .49216 .08142 L 1 .085 0 r
F
.4927 .08556 m .49054 .08359 L .4927 .08523 L F
.49262 .08147 m .4922 .08137 L .48515 .07938 L .408 0 0 r
F
.4922 .08137 m .48515 .07939 L .48515 .07939 L .341 .495 0 r
F
.4922 .08137 m .48545 .07967 L .48515 .07939 L .408 0 0 r
F
.4922 .08137 m .48515 .07939 L .48515 .07938 L F
.4922 .08137 m .48547 .079 L .48515 .07939 L .341 .495 0 r
F
.48659 .08001 m .48547 .079 L .4922 .08137 L 1 .085 0 r
F
.49276 .08151 m .4922 .08137 L .49262 .08147 L .408 0 0 r
F
.49054 .08359 m .48549 .07929 L .48652 .07995 L 1 .085 0 r
F
.48998 .08319 m .48549 .07929 L .49054 .08359 L F
.49054 .08359 m .48547 .07977 L .48652 .0805 L .638 .019 0 r
F
.49011 .08329 m .48547 .07977 L .49054 .08359 L F
.48997 .08319 m .48553 .07999 L .48547 .07977 L F
.48998 .08319 m .48553 .07999 L .48549 .07929 L 1 .085 0 r
F
.48652 .07995 m .48549 .07929 L .48547 .079 L F
.4916 .08094 m .49151 .08091 L .49154 .08091 L 0 .117 0 r
F
.49293 .08136 m .48558 .07888 L .48547 .07898 L F
.48947 .08102 m .48546 .07965 L .48558 .07891 L .817 .049 0 r
F
.4997 .0907 m .49286 .0816 L .49974 .08959 L 1 .35 0 r
F
.49244 .2847 m .50653 .09331 L .49508 .26497 L .98 .494 0 r
F
.49133 .29972 m .48698 .31022 L .50653 .09331 L F
.50046 .13691 m .49819 .10813 L .4997 .0907 L 1 .797 0 r
F
.49819 .10813 m .4927 .08556 L .4997 .0907 L 1 .534 0 r
F
.50077 .15573 m .50057 .14391 L .50603 .10115 L 1 .797 0 r
F
.50057 .14391 m .4997 .0907 L .50132 .09338 L F
.50057 .14391 m .50132 .09338 L .50603 .10115 L F
.51115 .1154 m .50077 .15573 L .50603 .10115 L .685 .176 0 r
F
.49214 .31317 m .4997 .21358 L .50775 .14433 L 1 .862 0 r
F
.49214 .31317 m .50775 .14433 L .5104 .12255 L F
.51895 .0973 m .5113 .11506 L .51947 .09594 L .338 .043 0 r
F
.51857 .0983 m .5113 .11506 L .51958 .09584 L F
.5113 .11506 m .51132 .115 L .52078 .09286 L F
.51857 .0983 m .51772 .09638 L .5179 .09605 L 1 .228 0 r
F
.5104 .12255 m .50775 .14433 L .51054 .12108 L 1 .862 0 r
F
.51125 .11517 m .50775 .14433 L .51115 .1154 L .338 .043 0 r
F
.50775 .14433 m .50077 .15573 L .51115 .1154 L .553 .081 0 r
F
.49214 .31317 m .51099 .11636 L .51123 .11541 L 1 .862 0 r
F
.49228 .31236 m .51126 .11508 L .49242 .31152 L F
.51126 .11508 m .51185 .10903 L .51127 .115 L F
.51126 .11508 m .51127 .115 L .49242 .31152 L F
.49223 .31279 m .49228 .31236 L .49242 .31152 L F
.49319 .32706 m .4922 .31344 L .49242 .31152 L 1 .671 0 r
F
.49484 .29969 m .49242 .31152 L .49517 .29415 L F
.49319 .32706 m .49242 .31152 L .49484 .29969 L F
.4979 .28381 m .49224 .31305 L .49672 .28198 L .359 .045 0 r
F
.49224 .31305 m .49206 .31401 L .49242 .31152 L F
.49224 .31305 m .49242 .31152 L .49672 .28198 L F
.4922 .31344 m .49217 .31309 L .49242 .31152 L 1 .671 0 r
F
.49214 .31317 m .49219 .31265 L .49223 .31279 L 1 .862 0 r
F
.49219 .31265 m .51125 .11517 L .4923 .3121 L F
.49219 .31265 m .4923 .3121 L .49223 .31279 L F
.51125 .11517 m .51185 .10903 L .51126 .11508 L F
.51125 .11517 m .51126 .11508 L .49223 .31279 L F
.51862 .09851 m .50791 .14362 L .51857 .0983 L .338 .043 0 r
F
.50791 .14362 m .50775 .14433 L .50791 .14361 L F
.50791 .14362 m .50791 .14361 L .51857 .0983 L F
.51857 .0983 m .50791 .14361 L .51125 .11517 L F
.50791 .14361 m .50775 .14433 L .51125 .11517 L F
.51868 .0987 m .51857 .0983 L .51958 .09584 L 1 .228 0 r
F
.5188 .09776 m .51862 .09851 L .51857 .0983 L .338 .043 0 r
F
.51868 .0987 m .51865 .09863 L .51857 .0983 L 1 .228 0 r
F
.51865 .09863 m .51854 .09836 L .51857 .0983 L F
.51854 .09836 m .51772 .09638 L .51857 .0983 L F
.51958 .09584 m .51895 .0973 L .52078 .09286 L .338 .043 0 r
F
.51895 .0973 m .51947 .09594 L .52078 .09286 L F
.5188 .09776 m .51857 .0983 L .51958 .09584 L F
.51958 .09584 m .51857 .0983 L .52097 .09139 L 1 .228 0 r
F
.51509 .08548 m .51485 .08554 L .51487 .08557 L .42 .21 0 r
F
.51513 .08554 m .51487 .08557 L .51592 .08666 L .515 .712 0 r
F
.51857 .0983 m .51463 .08494 L .51573 .08607 L 1 .228 0 r
F
.51857 .0983 m .51573 .08607 L .52097 .09139 L F
.50632 .17699 m .50757 .16159 L .50799 .15871 L .92 .187 0 r
F
.50775 .14433 m .50239 .13779 L .51185 .10903 L .642 .16 0 r
F
.4997 .21358 m .50073 .18459 L .50775 .14433 L F
.50108 .1826 m .50077 .15573 L .50775 .14433 L .553 .081 0 r
F
.50073 .18459 m .50077 .15573 L .50127 .19933 L F
.50073 .18459 m .50239 .13779 L .50775 .14433 L .642 .16 0 r
F
.50125 .19762 m .50108 .1826 L .50775 .14433 L .553 .081 0 r
F
.51862 .09853 m .5007 .20413 L .50775 .14433 L .338 .043 0 r
F
.5188 .09776 m .51865 .09865 L .51862 .09853 L F
.51865 .09865 m .5007 .20413 L .51862 .09853 L F
.51054 .12108 m .50775 .14433 L .51099 .11636 L 1 .862 0 r
F
.50127 .19933 m .50125 .19762 L .50775 .14433 L .553 .081 0 r
F
.5007 .20413 m .50073 .18459 L .50127 .19933 L F
.48556 .32428 m .48769 .25608 L .48594 .31513 L .977 .493 0 r
F
.48556 .32428 m .48934 .23372 L .48698 .31022 L F
.50073 .18459 m .48531 .32303 L .50077 .15573 L .553 .081 0 r
F
.4997 .21358 m .49953 .21472 L .50053 .18768 L .642 .16 0 r
F
.4997 .21358 m .50053 .18768 L .50057 .18708 L F
.4983 .22265 m .48531 .32303 L .50073 .18459 L .553 .081 0 r
F
.4997 .21358 m .50069 .18349 L .50073 .18459 L .642 .16 0 r
F
.48594 .31513 m .48769 .25608 L .48934 .23372 L .977 .493 0 r
F
.48531 .32303 m .49819 .10813 L .50077 .15573 L 1 .676 0 r
F
.49953 .21472 m .4886 .2856 L .50034 .15974 L .642 .16 0 r
F
.49953 .21472 m .50034 .15974 L .50062 .15671 L F
.50077 .15573 m .50061 .15275 L .50065 .14861 L 1 .797 0 r
F
.50072 .18259 m .50062 .15671 L .50239 .13779 L .642 .16 0 r
F
.49953 .21472 m .50062 .15671 L .50072 .18259 L F
.50061 .15275 m .50051 .15105 L .5006 .14961 L 1 .797 0 r
F
.50061 .15275 m .5006 .14961 L .50065 .14861 L F
.5007 .20413 m .4983 .22265 L .50073 .18459 L .553 .081 0 r
F
.50057 .18708 m .50053 .18768 L .50069 .18349 L .642 .16 0 r
F
.50073 .18459 m .50069 .18349 L .50239 .13779 L F
.50239 .13779 m .49847 .10434 L .49964 .09121 L 1 .749 0 r
F
.49988 .09101 m .4997 .0907 L .50032 .09065 L 1 .522 0 r
F
.49981 .09107 m .49964 .09121 L .49975 .08998 L 1 .749 0 r
F
.50239 .13779 m .49964 .09121 L .49981 .09107 L F
.50032 .09065 m .4997 .0907 L .49974 .08959 L 1 .522 0 r
F
.50206 .09385 m .49988 .09101 L .50032 .09065 L F
.502 .09449 m .49988 .09101 L .50206 .09385 L F
.50381 .0947 m .50374 .09462 L .49973 .08782 L 1 .191 0 r
F
.50558 .09984 m .49974 .08959 L .50382 .09472 L 1 .522 0 r
F
.50603 .10115 m .50576 .10064 L .50558 .09984 L F
.51101 .09567 m .51087 .09526 L .51104 .09531 L 0 0 0 r
F
.51204 .09489 m .50603 .10115 L .50718 .08611 L .91 .306 0 r
F
.51354 .09761 m .50736 .10053 L .51204 .09489 L F
.50736 .10053 m .50603 .10115 L .51204 .09489 L F
.50576 .10064 m .50125 .09236 L .50558 .09984 L 1 .522 0 r
F
.50125 .09236 m .49974 .08959 L .50122 .09219 L F
.50125 .09236 m .50122 .09219 L .50558 .09984 L F
.50603 .10115 m .502 .09449 L .50206 .09385 L F
.50653 .09331 m .50625 .09393 L .50652 .0933 L .895 .354 0 r
F
.50653 .09331 m .50048 .08855 L .50582 .09248 L F
.50048 .08855 m .5013 .08911 L .50582 .09248 L F
.50603 .10115 m .50382 .09472 L .50624 .09841 L 1 .522 0 r
F
.50623 .09897 m .50274 .09413 L .5038 .0947 L 1 .191 0 r
F
.50382 .09472 m .5038 .0947 L .50381 .0947 L F
.50623 .09897 m .5038 .0947 L .50382 .09472 L F
.50624 .09841 m .50382 .09472 L .50718 .08611 L 1 .522 0 r
F
.50718 .08611 m .50686 .086 L .49929 .08466 L .377 .56 0 r
F
.50382 .09472 m .49973 .08753 L .50686 .086 L 1 .191 0 r
F
.50382 .09472 m .50153 .08808 L .50686 .086 L 1 .522 0 r
F
.5071 .08591 m .50686 .086 L .49929 .08458 L .76 .055 0 r
F
.50686 .086 m .4993 .08464 L .49929 .08466 L .377 .56 0 r
F
.50365 .08542 m .49973 .08753 L .4993 .08464 L .76 .055 0 r
F
.50243 .08695 m .49973 .08753 L .50365 .08542 L F
.50686 .086 m .4993 .08464 L .49929 .08458 L F
.50686 .086 m .49977 .084 L .4993 .08464 L .377 .56 0 r
F
.50686 .086 m .50001 .08366 L .49977 .084 L F
.50374 .09462 m .49974 .08959 L .49973 .08782 L 1 .191 0 r
F
.5001 .08817 m .49973 .08782 L .49973 .08753 L F
.50381 .0947 m .49973 .08782 L .5001 .08817 L F
.50153 .08808 m .49974 .08959 L .50001 .08366 L 1 .522 0 r
F
.50268 .09142 m .50013 .08983 L .50153 .08808 L F
.50013 .08983 m .49974 .08959 L .50153 .08808 L F
.50686 .086 m .50243 .08695 L .50365 .08542 L .76 .055 0 r
F
.50153 .08808 m .50001 .08366 L .50686 .086 L 1 .522 0 r
F
.5072 .08593 m .50686 .086 L .5071 .08591 L .76 .055 0 r
F
.50382 .09472 m .50686 .086 L .50718 .08611 L 1 .522 0 r
F
.50623 .09897 m .50382 .09472 L .50703 .08604 L 1 .191 0 r
F
.50706 .08605 m .50703 .08604 L .50706 .08595 L F
.50623 .09897 m .50703 .08604 L .50706 .08605 L F
.50382 .09472 m .50686 .086 L .50706 .08595 L F
.50591 .10227 m .49975 .08998 L .50623 .09897 L 1 .749 0 r
F
.50239 .13779 m .50077 .10846 L .50591 .10227 L F
.50077 .10846 m .49975 .08998 L .50591 .10227 L F
.51185 .10903 m .5093 .11678 L .50623 .09897 L .685 .163 0 r
F
.5093 .11678 m .50239 .13779 L .50597 .10161 L F
.5093 .11678 m .50597 .10161 L .50623 .09897 L F
.50623 .09897 m .50706 .08595 L .50718 .08615 L 1 .191 0 r
F
.50816 .08786 m .51065 .0905 L .51367 .09434 L .91 .306 0 r
F
.51298 .09481 m .5072 .08593 L .51375 .09441 L .905 .283 0 r
F
.51372 .09595 m .50623 .09897 L .5072 .08593 L F
.51446 .08501 m .51381 .08514 L .51392 .08505 L .216 0 0 r
F
.51381 .08514 m .50702 .08649 L .51392 .08505 L F
.51392 .08505 m .50702 .08649 L .50746 .08547 L F
.51366 .08527 m .50702 .08649 L .51446 .08501 L .465 .061 0 r
F
.51324 .08563 m .5115 .08571 L .51366 .08527 L .355 0 0 r
F
.51326 .0854 m .5115 .08571 L .51366 .08527 L .465 .061 0 r
F
.5115 .08571 m .50702 .08649 L .51366 .08527 L F
.51366 .08527 m .5115 .08571 L .51451 .08454 L .355 0 0 r
F
.5115 .08571 m .50707 .08591 L .50714 .08589 L F
.5115 .08571 m .50714 .08589 L .51451 .08454 L F
.5115 .08571 m .51051 .09654 L .50702 .08649 L .465 .061 0 r
F
.51326 .0854 m .5132 .08564 L .5115 .08571 L F
.51051 .09654 m .50683 .08971 L .50702 .08649 L F
.51185 .10903 m .50623 .09897 L .51372 .09595 L .685 .163 0 r
F
.50517 .11813 m .50423 .11199 L .50702 .08649 L .465 .061 0 r
F
.50718 .08615 m .50706 .08595 L .5072 .08593 L 1 .191 0 r
F
.50702 .08649 m .50627 .08613 L .50746 .08547 L .574 .006 0 r
F
.50627 .08613 m .50024 .08321 L .50488 .08467 L F
.50627 .08613 m .50488 .08467 L .50746 .08547 L F
.5115 .08571 m .50797 .08793 L .50707 .08591 L .355 0 0 r
F
.50374 .09462 m .49975 .08998 L .49974 .08959 L 1 .191 0 r
F
.50382 .09472 m .49974 .08959 L .50268 .09142 L 1 .522 0 r
F
.49974 .08959 m .49292 .08167 L .49973 .08753 L 1 .323 0 r
F
.4997 .0907 m .49276 .08157 L .49286 .0816 L 1 .35 0 r
F
.49281 .08158 m .49286 .0816 L .49973 .08753 L 1 .323 0 r
F
.49974 .08959 m .49286 .0816 L .50001 .08366 L 1 .35 0 r
F
.50274 .09413 m .49975 .08998 L .50381 .0947 L 1 .191 0 r
F
.5023 .12973 m .49991 .08416 L .50702 .08649 L 1 .581 0 r
F
.50797 .08793 m .50586 .08925 L .50679 .08668 L .355 0 0 r
F
.50797 .08793 m .50679 .08668 L .50707 .08591 L F
.51324 .08563 m .5132 .08565 L .5115 .08571 L F
.5132 .08565 m .51051 .09654 L .5115 .08571 L .465 .061 0 r
F
.5132 .08565 m .50586 .08925 L .5115 .08571 L .355 0 0 r
F
.5132 .08564 m .5132 .08565 L .5115 .08571 L .465 .061 0 r
F
.51051 .09654 m .50517 .11813 L .50683 .08971 L F
.50517 .11813 m .5023 .12973 L .50423 .11199 L F
.49975 .08998 m .49909 .08919 L .4991 .08919 L 1 .323 0 r
F
.49975 .08998 m .49292 .08167 L .49974 .08959 L F
.49816 .08868 m .4927 .08556 L .49276 .08157 L 1 .35 0 r
F
.4997 .0907 m .4937 .08629 L .49816 .08868 L F
.4937 .08629 m .4927 .08556 L .49816 .08868 L F
.49199 .09568 m .48554 .08007 L .4927 .08556 L 1 .509 0 r
F
.49819 .10813 m .49199 .09568 L .4927 .08556 L 1 .534 0 r
F
.49847 .10434 m .49207 .0943 L .49268 .08575 L 1 .5 0 r
F
.49289 .08586 m .49268 .08575 L .49271 .08527 L F
.49847 .10434 m .49268 .08575 L .49289 .08586 L F
.49975 .08998 m .49271 .08527 L .49276 .08151 L 1 .323 0 r
F
.49847 .10434 m .49271 .08527 L .49975 .08998 L 1 .5 0 r
F
.50098 .10444 m .49901 .08712 L .49991 .08416 L 1 .581 0 r
F
.5023 .12973 m .50062 .10794 L .50098 .10444 L F
.50062 .10794 m .49901 .08712 L .50098 .10444 L F
.4991 .08919 m .49281 .08158 L .49292 .08167 L 1 .323 0 r
F
.49909 .08919 m .49281 .08158 L .4991 .08919 L F
.49991 .08416 m .49268 .08276 L .49292 .08146 L .711 .035 0 r
F
.49901 .08712 m .49268 .08276 L .49991 .08416 L .796 .12 0 r
F
.49271 .08527 m .49192 .08467 L .49193 .08467 L .638 .019 0 r
F
.49264 .08551 m .48553 .07999 L .49264 .0855 L 1 .085 0 r
F
.49264 .0855 m .48553 .07999 L .49039 .08355 L F
.49271 .08527 m .49196 .08472 L .49198 .08472 L .638 .019 0 r
F
.49271 .08527 m .49195 .08472 L .49196 .08472 L F
.4927 .08556 m .49195 .08498 L .49195 .08497 L 1 .085 0 r
F
.48574 .08016 m .48554 .08007 L .48553 .07999 L F
.49195 .08497 m .48561 .08012 L .48574 .08016 L F
.48561 .08012 m .48554 .08007 L .48574 .08016 L F
.47962 .0806 m .48301 .08073 L .48546 .08246 L 1 .55 0 r
F
.47831 .07742 m .48315 .08074 L .48546 .08246 L F
.485 .09269 m .47962 .0806 L .48546 .08234 L 1 .539 0 r
F
.47962 .0806 m .48315 .08074 L .48546 .08234 L F
.48092 .3032 m .485 .09269 L .48545 .08248 L .983 .238 0 r
F
.48546 .08246 m .48545 .08248 L .48546 .08234 L F
.48092 .3032 m .48545 .08248 L .48546 .08246 L F
.4913 .11159 m .48545 .0822 L .48676 .08698 L 1 .481 0 r
F
.4914 .10777 m .48546 .08234 L .48545 .0822 L .989 .147 0 r
F
.4914 .10777 m .48545 .0822 L .48675 .08697 L F
.49139 .10777 m .48546 .08234 L .4914 .10777 L F
.48092 .3032 m .48546 .08234 L .49148 .10816 L .983 .238 0 r
F
.48629 .08189 m .48536 .08252 L .48554 .08007 L 1 .509 0 r
F
.48318 .31724 m .49148 .10816 L .48934 .23372 L .975 .496 0 r
F
.48796 .24492 m .49199 .09568 L .49819 .10813 L .874 .396 0 r
F
.49148 .10816 m .49139 .10777 L .4914 .10777 L .989 .147 0 r
F
.48362 .24722 m .48536 .08252 L .49199 .09568 L 1 .835 0 r
F
.48796 .24492 m .48362 .24722 L .49199 .09568 L .874 .396 0 r
F
.48975 .21929 m .48627 .22258 L .49199 .0957 L .868 .389 0 r
F
.48627 .22258 m .48483 .22393 L .49153 .10388 L F
.48627 .22258 m .49153 .10388 L .49199 .0957 L F
.49204 .09582 m .49199 .0957 L .49207 .0943 L F
.48975 .21929 m .49199 .0957 L .49204 .09582 L F
.49199 .09568 m .4919 .0955 L .48629 .08189 L 1 .509 0 r
F
.4919 .0955 m .48537 .08253 L .48616 .08198 L F
.4919 .0955 m .48616 .08198 L .48629 .08189 L F
.48537 .08253 m .48536 .08252 L .48629 .08189 L F
.485 .09269 m .47808 .0789 L .47809 .07876 L 1 .539 0 r
F
.485 .09269 m .47809 .07876 L .47949 .08044 L F
.47962 .0806 m .47809 .07876 L .47813 .07736 L 1 .55 0 r
F
.47962 .0806 m .47813 .07736 L .47831 .07742 L F
.47962 .0806 m .47831 .07742 L .48301 .08073 L F
.47713 .31484 m .47808 .0789 L .485 .09269 L .873 .401 0 r
F
.48439 .10249 m .4781 .07803 L .48536 .08252 L .839 .369 0 r
F
.47946 .32696 m .485 .09269 L .48092 .3032 L .895 .421 0 r
F
.48362 .24722 m .48439 .10249 L .48536 .08252 L 1 .835 0 r
F
.48483 .22393 m .48445 .10077 L .48536 .08254 L 1 .833 0 r
F
.47841 .07746 m .47814 .07727 L .47966 .07793 L 1 .165 0 r
F
.48546 .08234 m .48315 .08074 L .48526 .08219 L F
.48315 .08074 m .47814 .07727 L .48526 .08219 L F
.48536 .08252 m .48213 .07997 L .48554 .08007 L 1 .34 0 r
F
.48554 .08007 m .47812 .07666 L .48553 .07999 L .611 .012 0 r
F
.48554 .08007 m .48403 .0794 L .47811 .07665 L F
.48509 .07982 m .48374 .07927 L .47811 .07665 L .893 .063 0 r
F
.48374 .07927 m .47814 .07702 L .47811 .07665 L F
.48403 .0794 m .47811 .07665 L .47811 .07665 L .611 .012 0 r
F
.48374 .07927 m .47811 .07665 L .47811 .07665 L .893 .063 0 r
F
.48403 .0794 m .47814 .07678 L .47811 .07665 L .611 .012 0 r
F
.48403 .0794 m .47815 .07682 L .47814 .07678 L F
.48537 .08237 m .48213 .07997 L .4854 .08001 L 1 .304 0 r
F
.48554 .08008 m .4854 .08001 L .48554 .08002 L F
.48537 .08237 m .4854 .08001 L .48554 .08008 L F
.48213 .07997 m .47814 .07702 L .48403 .0794 L F
.48213 .07997 m .48394 .07943 L .48554 .08007 L 1 .34 0 r
F
.47892 .07743 m .48403 .0794 L .48554 .08007 L F
.48213 .07997 m .48403 .0794 L .48554 .08002 L 1 .304 0 r
F
.48213 .07997 m .47892 .07743 L .48394 .07943 L 1 .34 0 r
F
.48403 .0794 m .47814 .07702 L .48509 .07982 L .893 .063 0 r
F
.47892 .07743 m .47815 .07682 L .48403 .0794 L 1 .34 0 r
F
.48554 .08002 m .48403 .0794 L .48509 .07982 L .893 .063 0 r
F
.48536 .08253 m .48536 .08254 L .48537 .08237 L 1 .833 0 r
F
.48483 .22393 m .48536 .08254 L .48536 .08253 L F
.49207 .0943 m .48537 .08237 L .48553 .0801 L 1 .481 0 r
F
.48558 .08011 m .48553 .0801 L .48554 .08002 L F
.49207 .0943 m .48553 .0801 L .48558 .08011 L F
.49195 .08498 m .48554 .08007 L .49195 .08497 L 1 .085 0 r
F
.49207 .0943 m .48554 .08002 L .49271 .08527 L 1 .481 0 r
F
.49901 .08712 m .49194 .08765 L .49268 .08276 L .796 .12 0 r
F
.49906 .08635 m .49749 .08648 L .49269 .08254 L .782 .089 0 r
F
.49193 .08467 m .49011 .08329 L .49054 .08359 L .638 .019 0 r
F
.49198 .08472 m .48553 .07999 L .48997 .08319 L F
.49196 .08472 m .48553 .07999 L .49198 .08472 L F
.49196 .08472 m .48554 .08002 L .48553 .07999 L F
.49195 .08472 m .48554 .08002 L .49196 .08472 L F
.49194 .08765 m .48546 .07965 L .49268 .08276 L .964 .305 0 r
F
.49749 .08648 m .49198 .08693 L .49265 .08283 L .782 .089 0 r
F
.49749 .08648 m .49265 .08283 L .49269 .08254 L F
.49224 .08252 m .48873 .08106 L .48947 .08102 L .817 .049 0 r
F
.49268 .08276 m .4924 .08264 L .49224 .08252 L F
.4924 .08264 m .48873 .08106 L .49224 .08252 L F
.48873 .08106 m .48546 .07965 L .48947 .08102 L F
.4916 .08094 m .48911 .07969 L .49233 .08032 L 0 .117 0 r
F
.4916 .08094 m .48558 .07891 L .48548 .07854 L .536 0 0 r
F
.49292 .08146 m .49199 .08113 L .4916 .08094 L F
.49199 .08113 m .48558 .07891 L .4916 .08094 L F
.4916 .08094 m .48751 .07933 L .49231 .08034 L F
.4916 .08094 m .49231 .08034 L .49282 .08045 L F
.49293 .08136 m .4916 .08094 L .49233 .08032 L 0 .117 0 r
F
.49282 .08041 m .49233 .08032 L .49262 .08038 L .01 .135 0 r
F
.49282 .08043 m .49233 .08032 L .49282 .08041 L 0 .117 0 r
F
.49293 .08136 m .49233 .08032 L .49282 .08043 L F
.48751 .07933 m .48548 .07854 L .49233 .08032 L .536 0 0 r
F
.48751 .07933 m .49233 .08032 L .49282 .08045 L F
.48553 .07999 m .47812 .07666 L .48547 .079 L .611 .012 0 r
F
.48554 .08002 m .47812 .07666 L .47813 .07666 L .893 .063 0 r
F
.48554 .08002 m .47813 .07666 L .48553 .07999 L F
.47812 .07666 m .47811 .07665 L .478 .07667 L 0 .112 0 r
F
.478 .07662 m .47811 .07657 L .47799 .07662 L .081 .137 0 r
F
.47854 .07676 m .47813 .07658 L .478 .07662 L .097 .144 0 r
F
.48548 .07854 m .47813 .07658 L .47854 .07676 L F
.48558 .07888 m .47813 .07658 L .48547 .07898 L .698 .029 0 r
F
.47813 .07658 m .47811 .07657 L .47813 .07658 L F
.47813 .07658 m .47813 .07658 L .48547 .07898 L F
.48547 .07898 m .47813 .07658 L .478 .07662 L .081 .137 0 r
F
.47813 .07658 m .47811 .07657 L .478 .07662 L F
.478 .07662 m .47811 .07657 L .47799 .07662 L .097 .144 0 r
F
.47813 .07658 m .47811 .07657 L .478 .07662 L F
.47812 .07666 m .47811 .07665 L .47812 .07666 L .893 .063 0 r
F
.47812 .07666 m .47811 .07665 L .478 .07667 L 0 .121 0 r
F
.47831 .07742 m .47813 .07736 L .47814 .07702 L 1 .55 0 r
F
.47831 .07742 m .47814 .07702 L .48315 .08074 L F
.48531 .32303 m .48796 .24492 L .49819 .10813 L 1 .676 0 r
F
.4886 .2856 m .48975 .21929 L .49815 .10846 L 1 .636 0 r
F
.49839 .11145 m .49819 .10813 L .50046 .13691 L 1 .797 0 r
F
.50051 .15105 m .49819 .10813 L .50065 .14861 L F
.49821 .10911 m .49815 .10846 L .49847 .10434 L 1 .636 0 r
F
.4886 .2856 m .49815 .10846 L .49821 .10911 L F
.50065 .14861 m .49839 .11145 L .50046 .13691 L 1 .797 0 r
F
.49281 .08158 m .49276 .08151 L .49286 .0816 L 1 .323 0 r
F
.50024 .08321 m .49292 .08146 L .49282 .08045 L .651 .021 0 r
F
.49991 .08416 m .49292 .08146 L .50024 .08321 L .711 .035 0 r
F
.49994 .08381 m .49324 .08147 L .50025 .08304 L .666 .027 0 r
F
.49324 .08147 m .49293 .08136 L .49382 .08157 L F
.49324 .08147 m .49382 .08157 L .50025 .08304 L F
.49745 .08216 m .49282 .08045 L .49296 .08048 L .651 .021 0 r
F
.50024 .08321 m .49741 .08216 L .49745 .08216 L F
.49741 .08216 m .49282 .08045 L .49745 .08216 L F
.50025 .08304 m .49291 .08045 L .49306 .08051 L .617 .015 0 r
F
.49291 .08045 m .49282 .08041 L .49296 .08048 L F
.51416 .08509 m .51366 .08527 L .51409 .0849 L 1 .228 0 r
F
.5179 .09605 m .51366 .08527 L .51416 .08509 L F
.5145 .08495 m .51366 .08527 L .51446 .08501 L .45 .207 0 r
F
.5179 .09605 m .51409 .0849 L .51463 .08494 L 1 .228 0 r
F
.51491 .08444 m .51326 .0854 L .51366 .08527 L .45 .207 0 r
F
.51463 .08494 m .51409 .0849 L .51451 .08454 L 1 .228 0 r
F
.51491 .08444 m .51366 .08527 L .5145 .08495 L .45 .207 0 r
F
.51977 .09018 m .51485 .08491 L .51499 .08524 L 0 .009 0 r
F
.52097 .09139 m .5197 .09005 L .51977 .09018 L F
.51463 .08494 m .51485 .0849 L .52097 .09139 L 1 .228 0 r
F
.52249 .08485 m .52097 .09139 L .52238 .08485 L .396 .017 0 r
F
.51772 .09638 m .51324 .08563 L .5179 .09605 L 1 .228 0 r
F
.52475 .11393 m .52078 .09286 L .52092 .09256 L .991 .158 0 r
F
.52476 .11401 m .52078 .09286 L .52475 .11393 L F
.51357 .09759 m .51357 .09761 L .51372 .09595 L .92 .187 0 r
F
.51357 .09761 m .51185 .10903 L .51339 .09827 L F
.51357 .09761 m .51339 .09827 L .51372 .09595 L F
.51134 .11495 m .51132 .115 L .51606 .09596 L .394 .043 0 r
F
.51132 .115 m .51115 .1154 L .5114 .11443 L F
.51132 .115 m .5114 .11443 L .51606 .09596 L F
.51198 .11214 m .5114 .11443 L .51559 .09627 L F
.5114 .11443 m .51142 .11424 L .51559 .09627 L F
.51124 .11538 m .51126 .11516 L .51132 .115 L 1 .862 0 r
F
.51126 .11516 m .51185 .10903 L .51132 .115 L F
.5113 .11506 m .51125 .11517 L .51132 .115 L .338 .043 0 r
F
.51125 .11517 m .51115 .1154 L .51132 .115 L F
.51559 .09627 m .51142 .11424 L .51357 .09759 L .394 .043 0 r
F
.51147 .11387 m .51185 .10903 L .51357 .09759 L .92 .187 0 r
F
.51606 .09596 m .51198 .11214 L .51559 .09627 L .394 .043 0 r
F
.51123 .11541 m .51099 .11636 L .51185 .10903 L 1 .862 0 r
F
.49206 .31401 m .49211 .31326 L .49214 .31317 L F
.49214 .31317 m .489 .3212 L .48906 .32067 L 0 0 0 r
F
.49213 .31318 m .489 .3212 L .49214 .31317 L F
.49211 .31326 m .4997 .21358 L .49214 .31317 L 1 .862 0 r
F
.48892 .32101 m .48859 .32225 L .48876 .32141 L 0 0 0 r
F
.48892 .32101 m .48876 .32141 L .48907 .32011 L F
.48907 .32011 m .48876 .32141 L .48904 .31912 L .304 .032 0 r
F
.48906 .32067 m .4879 .32568 L .48896 .31952 L 1 .489 0 r
F
.48906 .32067 m .48896 .31952 L .48907 .32011 L F
.49217 .31309 m .49214 .31317 L .49242 .31152 L 0 0 0 r
F
.49217 .31309 m .49213 .31318 L .49214 .31317 L F
.49123 .30435 m .49122 .30441 L .49123 .30429 L 1 .613 0 r
F
.48896 .31952 m .48853 .31748 L .49133 .29972 L .822 .286 0 r
F
.48853 .31748 m .48698 .31022 L .49096 .30062 L F
.48853 .31748 m .49096 .30062 L .49133 .29972 L F
.49123 .30429 m .48896 .31952 L .49133 .29972 L 1 .613 0 r
F
.52213 .08288 m .52205 .08285 L .52211 .08318 L .223 .287 0 r
F
.52213 .08288 m .52211 .08318 L .52239 .08489 L F
.51375 .09441 m .51357 .09418 L .51375 .09417 L .905 .283 0 r
F
.51372 .09595 m .51298 .09481 L .51375 .09441 L F
.49133 .29972 m .49244 .2847 L .49508 .26497 L .98 .494 0 r
F
.50161 .22853 m .50508 .18645 L .50632 .17699 L .92 .187 0 r
F
.49672 .28198 m .50061 .23757 L .50161 .22853 L F
.50061 .23757 m .50508 .18645 L .50161 .22853 L F
.49714 .30659 m .49898 .28993 L .49889 .29442 L .936 .222 0 r
F
.49814 .31084 m .49881 .29899 L .49836 .31041 L 1 .762 0 r
F
.49881 .29899 m .49875 .30176 L .49836 .31041 L F
.50042 .28809 m .50116 .27864 L .5005 .28786 L 1 .774 0 r
F
.49799 .32112 m .49852 .31574 L .49828 .31913 L F
.49763 .32352 m .49852 .31574 L .49799 .32112 L F
.49446 .32161 m .49486 .31942 L .495 .31908 L .112 0 0 r
F
.49627 .2969 m .49206 .31401 L .4979 .28381 L .359 .045 0 r
F
.49572 .32443 m .495 .31908 L .49638 .32477 L .707 .103 0 r
F
.49572 .32443 m .49638 .32477 L .49679 .32647 L F
.49845 .33107 m .49755 .32946 L .49888 .3308 L .865 .099 0 r
F
.49755 .32946 m .49658 .32774 L .49767 .32919 L F
.49755 .32946 m .49767 .32919 L .49888 .3308 L F
.49737 .32988 m .49658 .32774 L .49845 .33107 L F
.49737 .32988 m .49601 .32663 L .49679 .32647 L 1 .215 0 r
F
.49777 .33228 m .49717 .33034 L .49737 .32988 L F
.49737 .32988 m .49586 .3276 L .49658 .32774 L .865 .099 0 r
F
.49717 .33034 m .49693 .32957 L .49737 .32988 L 1 .215 0 r
F
.49793 .33141 m .49693 .32957 L .49737 .32988 L .865 .099 0 r
F
.49693 .32957 m .49586 .3276 L .49737 .32988 L F
.49693 .32957 m .49601 .32663 L .49737 .32988 L 1 .215 0 r
F
.49845 .33107 m .49679 .32647 L .49901 .33008 L F
.49777 .33228 m .49737 .32988 L .49845 .33107 L F
.49737 .32988 m .49679 .32647 L .49845 .33107 L F
.49793 .33141 m .49737 .32988 L .49845 .33107 L .865 .099 0 r
F
.49908 .33014 m .49793 .33141 L .49845 .33107 L 1 .538 0 r
F
.49911 .33015 m .49901 .33008 L .49911 .33016 L .362 0 0 r
F
.49908 .33014 m .49901 .33008 L .49911 .33015 L F
.50395 .31435 m .49853 .32972 L .49908 .33014 L 1 .538 0 r
F
.49853 .32972 m .49793 .33141 L .49908 .33014 L F
.4991 .33015 m .49908 .33014 L .49911 .33015 L .362 0 0 r
F
.4991 .33015 m .49911 .33016 L .50146 .33196 L F
.49929 .3299 m .49888 .3308 L .49969 .32932 L .81 .201 0 r
F
.49983 .33071 m .49911 .33016 L .49969 .32932 L .831 .055 0 r
F
.50011 .32809 m .49929 .3299 L .49969 .32932 L .81 .201 0 r
F
.50534 .31271 m .49916 .33002 L .50011 .32809 L F
.50063 .33133 m .4986 .33201 L .49892 .33051 L .362 0 0 r
F
.50063 .33133 m .49892 .33051 L .4991 .33015 L F
.4986 .33201 m .49777 .33228 L .49863 .33076 L F
.4986 .33201 m .49863 .33076 L .49901 .33008 L F
.50445 .31801 m .50395 .31435 L .50534 .31271 L 1 .585 0 r
F
.50658 .30657 m .50895 .27847 L .51331 .25866 L 1 .74 0 r
F
.51175 .26619 m .50802 .28317 L .512 .26481 L 0 0 0 r
F
.50802 .28317 m .50822 .28214 L .512 .26481 L F
.50802 .28317 m .50553 .29446 L .50808 .28279 L F
.50802 .28317 m .50808 .28279 L .50822 .28214 L F
.50407 .31375 m .50724 .28785 L .50658 .30657 L .702 .169 0 r
F
.51494 .24836 m .50553 .29446 L .51165 .26305 L 0 0 0 r
F
.5197 .2244 m .51804 .23163 L .52235 .21375 L F
.51804 .23163 m .51834 .23062 L .52371 .20814 L F
.50658 .30657 m .51432 .25147 L .5197 .2244 L 1 .74 0 r
F
.51441 .26272 m .52079 .22254 L .51575 .26098 L .803 .286 0 r
F
.52079 .22254 m .52192 .2188 L .51575 .26098 L F
.51603 .24737 m .5197 .2244 L .53093 .18186 L 1 .74 0 r
F
.51959 .22755 m .51795 .23535 L .51822 .2337 L 0 0 0 r
F
.51795 .23535 m .50997 .27336 L .51822 .2337 L F
.51822 .2337 m .50997 .27336 L .51494 .24836 L F
.50997 .27336 m .50553 .29446 L .51494 .24836 L F
.51804 .23163 m .5163 .23921 L .51834 .23062 L F
.51527 .24685 m .51165 .26305 L .51651 .23975 L F
.51527 .24685 m .51651 .23975 L .5197 .2244 L F
.5163 .23921 m .51676 .23547 L .5169 .23452 L .826 .175 0 r
F
.5197 .2244 m .51165 .26305 L .5163 .23921 L 0 0 0 r
F
.50553 .29446 m .52961 .13163 L .5163 .23921 L 1 .909 0 r
F
.51432 .25147 m .51607 .23898 L .5197 .2244 L 1 .74 0 r
F
.51867 .23425 m .5097 .27536 L .51959 .22755 L 0 0 0 r
F
.5097 .27536 m .50553 .29446 L .51208 .26331 L F
.5097 .27536 m .51208 .26331 L .51959 .22755 L F
.50771 .28395 m .50718 .28652 L .50783 .28365 L .842 .189 0 r
F
.50718 .28652 m .50553 .29446 L .50802 .28317 L F
.50802 .28317 m .50822 .27976 L .51432 .25147 L 1 .74 0 r
F
.50718 .28652 m .50802 .28317 L .50941 .27685 L .842 .189 0 r
F
.50865 .28003 m .50941 .27685 L .51079 .27056 L F
.50771 .28395 m .50805 .28254 L .50802 .28317 L .702 .169 0 r
F
.50718 .28652 m .50941 .27685 L .50865 .28003 L .842 .189 0 r
F
.50553 .29446 m .50589 .29156 L .50621 .28988 L 1 .909 0 r
F
.5056 .28484 m .5162 .20841 L .50869 .26903 L 1 .919 0 r
F
.50394 .29337 m .5162 .20841 L .50229 .30874 L F
.51057 .26039 m .5162 .20841 L .52961 .13163 L 1 .909 0 r
F
.50621 .28988 m .50887 .26818 L .51057 .26039 L F
.50887 .26818 m .5162 .20841 L .51057 .26039 L F
.50589 .29156 m .5162 .20841 L .50621 .28988 L F
.50394 .29337 m .50816 .25044 L .5162 .20841 L 1 .919 0 r
F
.49974 .32119 m .50222 .30256 L .50394 .29337 L 1 .876 0 r
F
.49974 .32119 m .50394 .29337 L .50229 .30874 L F
.50074 .31559 m .50222 .30256 L .50394 .29337 L 1 .919 0 r
F
.50222 .30256 m .50816 .25044 L .50394 .29337 L F
.50222 .30256 m .50237 .30142 L .50394 .29337 L 1 .876 0 r
F
.50522 .28492 m .51416 .21286 L .52314 .16623 L F
.50394 .29337 m .50473 .28715 L .50522 .28492 L F
.50473 .28715 m .51416 .21286 L .50522 .28492 L F
.50237 .30142 m .51416 .21286 L .50394 .29337 L F
.50229 .30874 m .5056 .28484 L .50553 .29446 L 1 .919 0 r
F
.5056 .28484 m .50869 .26903 L .50553 .29446 L F
.50074 .31559 m .50394 .29337 L .50229 .30874 L F
.50229 .30874 m .52314 .16623 L .50822 .27976 L 1 .876 0 r
F
.50394 .29337 m .52314 .16623 L .50229 .30874 L F
.50718 .28652 m .50267 .30702 L .50553 .29446 L .842 .189 0 r
F
.50597 .29191 m .50229 .30874 L .50529 .29411 L .702 .169 0 r
F
.50267 .30702 m .50221 .3091 L .50229 .30874 L .842 .189 0 r
F
.50267 .30702 m .50229 .30874 L .50553 .29446 L F
.50724 .28785 m .49974 .32119 L .50229 .30874 L .702 .169 0 r
F
.50771 .28395 m .50529 .29411 L .50822 .27976 L F
.50597 .29191 m .50529 .29411 L .50771 .28395 L F
.50771 .28395 m .50822 .27976 L .50805 .28254 L F
.52435 .20417 m .5197 .2244 L .52371 .20814 L 0 0 0 r
F
.5197 .2244 m .52235 .21375 L .52371 .20814 L F
.52279 .21269 m .5197 .2244 L .52324 .20963 L 1 .74 0 r
F
.54905 .10184 m .53999 .13985 L .54906 .10182 L 0 0 0 r
F
.54316 .12443 m .52986 .17564 L .54339 .12327 L 1 .74 0 r
F
.54316 .12443 m .54339 .12327 L .54975 .09869 L F
.54938 .10047 m .54316 .12443 L .54975 .09869 L F
.52986 .17564 m .52995 .17521 L .54975 .09869 L F
.54799 .10442 m .52934 .1686 L .53372 .14488 L .382 .047 0 r
F
.54025 .13859 m .53999 .13985 L .54905 .10184 L 0 0 0 r
F
.5493 .10041 m .52995 .17521 L .54916 .10038 L .187 .004 0 r
F
.52995 .17521 m .5237 .19935 L .53002 .17478 L F
.52995 .17521 m .53002 .17478 L .54916 .10038 L F
.54937 .10049 m .54906 .10182 L .54938 .10047 L 0 0 0 r
F
.5489 .10153 m .54906 .10181 L .54937 .10049 L F
.54906 .10181 m .54906 .10182 L .54937 .10049 L F
.54916 .10038 m .53002 .17478 L .53375 .15343 L .187 .004 0 r
F
.547 .10568 m .54906 .10182 L .5489 .10153 L 0 0 0 r
F
.53432 .16317 m .53365 .16643 L .53999 .13985 L F
.53727 .15105 m .53718 .1514 L .53726 .1511 L F
.52671 .19393 m .52681 .19408 L .53726 .1511 L F
.547 .10568 m .54145 .12983 L .53999 .13985 L F
.54145 .12983 m .53726 .1511 L .53999 .13985 L F
.54809 .10096 m .547 .10568 L .54938 .10047 L F
.5329 .17002 m .5349 .16093 L .54938 .10047 L 1 .74 0 r
F
.52435 .20417 m .52371 .20814 L .53365 .16643 L 0 0 0 r
F
.52435 .20417 m .53365 .16643 L .53432 .16317 L F
.52279 .21269 m .5349 .16093 L .5329 .17002 L 1 .74 0 r
F
.52279 .21269 m .52324 .20963 L .5349 .16093 L F
.53819 .15435 m .52279 .21269 L .54938 .10047 L F
.54145 .12983 m .52671 .19393 L .53718 .1514 L 0 0 0 r
F
.54145 .12983 m .53718 .1514 L .53727 .15105 L F
.5418 .12956 m .52297 .21516 L .54145 .12983 L F
.52297 .21516 m .51175 .26619 L .52341 .21265 L F
.52297 .21516 m .52341 .21265 L .54145 .12983 L F
.52671 .19393 m .52435 .20417 L .52681 .19408 L F
.52659 .19447 m .51527 .24685 L .5197 .2244 L F
.54145 .12983 m .52514 .20275 L .52659 .19447 L F
.52514 .20275 m .51527 .24685 L .52659 .19447 L F
.53375 .15343 m .5237 .19935 L .52934 .1686 L .187 .004 0 r
F
.53002 .17478 m .5237 .19935 L .53375 .15343 L F
.547 .10568 m .54025 .13859 L .54905 .10184 L 0 0 0 r
F
.51835 .23261 m .50221 .3091 L .50267 .30702 L .842 .189 0 r
F
.50771 .28395 m .50267 .30702 L .50718 .28652 L F
.51835 .23261 m .50267 .30702 L .50771 .28395 L F
.50724 .28785 m .50597 .29191 L .50771 .28395 L .702 .169 0 r
F
.50724 .28785 m .50229 .30874 L .50597 .29191 L F
.50407 .31375 m .50112 .31881 L .50724 .28785 L F
.50112 .31881 m .49974 .32119 L .50724 .28785 L F
.50626 .2899 m .50074 .31559 L .50221 .3091 L .842 .189 0 r
F
.51835 .23261 m .50571 .29218 L .50626 .2899 L F
.50571 .29218 m .50074 .31559 L .50626 .2899 L F
.51033 .2713 m .50771 .28395 L .51079 .27056 L F
.50771 .28395 m .50783 .28365 L .51079 .27056 L F
.50724 .28785 m .50771 .28395 L .50802 .28317 L .702 .169 0 r
F
.50724 .28785 m .50802 .28317 L .50658 .30657 L F
.50658 .30657 m .50802 .28317 L .50883 .27992 L 1 .74 0 r
F
.51432 .25147 m .50822 .27976 L .51607 .23898 L F
.51676 .23547 m .52761 .1478 L .5169 .23452 L .826 .175 0 r
F
.52761 .1478 m .52961 .13163 L .52782 .14614 L F
.52761 .1478 m .52782 .14614 L .5169 .23452 L F
.5197 .2244 m .51627 .2382 L .5237 .19935 L 1 .74 0 r
F
.51627 .2382 m .51607 .23898 L .51635 .23755 L F
.51627 .2382 m .51635 .23755 L .5237 .19935 L F
.51175 .26619 m .512 .26481 L .54145 .12983 L 0 0 0 r
F
.52356 .20979 m .51867 .23425 L .51959 .22755 L F
.54145 .12983 m .52277 .21546 L .52356 .20979 L F
.52277 .21546 m .51867 .23425 L .52356 .20979 L F
.5254 .19862 m .51126 .26682 L .52276 .21567 L .842 .189 0 r
F
.51126 .26682 m .51033 .2713 L .51136 .26669 L F
.51126 .26682 m .51136 .26669 L .52276 .21567 L F
.51026 .2899 m .51509 .26407 L .51984 .24429 L 0 0 0 r
F
.50987 .29132 m .51441 .26272 L .51561 .26191 L .803 .286 0 r
F
.51441 .26272 m .51575 .26098 L .51561 .26191 L F
.52532 .1687 m .53219 .11509 L .53372 .14488 L .826 .175 0 r
F
.53204 .11191 m .53221 .11171 L .53213 .11149 L 0 0 0 r
F
.53294 .11381 m .53219 .11509 L .53205 .11125 L .003 0 0 r
F
.5237 .19935 m .53288 .11094 L .53294 .11381 L .819 .171 0 r
F
.5237 .19935 m .53294 .11381 L .52934 .1686 L F
.53372 .14488 m .53248 .12078 L .53294 .11381 L .826 .175 0 r
F
.53372 .14488 m .53294 .11381 L .5338 .14446 L F
.54947 .0995 m .54927 .10008 L .54936 .09989 L .187 .004 0 r
F
.5294 .21032 m .54878 .10336 L .54938 .10047 L .232 .016 0 r
F
.5294 .21032 m .54938 .10047 L .5494 .10058 L F
.54989 .10249 m .54874 .1011 L .54938 .10047 L .865 .119 0 r
F
.54874 .1011 m .5485 .1008 L .54899 .10062 L F
.54874 .1011 m .54899 .10062 L .54938 .10047 L F
.5494 .10058 m .54938 .10047 L .54975 .09869 L .232 .016 0 r
F
.5499 .10251 m .54989 .10249 L .54938 .10047 L .865 .119 0 r
F
.54989 .10249 m .54938 .10047 L .54938 .10047 L F
.55247 .11279 m .54809 .10096 L .5485 .1008 L F
.5525 .11289 m .54809 .10096 L .55247 .11279 L F
.55251 .1129 m .5525 .11289 L .55247 .11279 L F
.55257 .1131 m .5485 .1008 L .5499 .10251 L F
.55512 .1077 m .55184 .10489 L .55496 .10831 L 0 .031 0 r
F
.55184 .10489 m .55316 .10651 L .55496 .10831 L F
.56499 .12228 m .55904 .11564 L .5644 .12286 L .019 .054 0 r
F
.56641 .12085 m .56369 .11893 L .56499 .12228 L F
.56369 .11893 m .55904 .11564 L .56499 .12228 L F
.56641 .12085 m .56122 .11274 L .55904 .11564 L F
.58189 .12538 m .57584 .12143 L .56881 .12737 L .625 .729 0 r
F
.57057 .13173 m .56641 .12085 L .5644 .12286 L 0 0 0 r
F
.56572 .12294 m .56361 .11814 L .56641 .12085 L F
.56361 .11814 m .56122 .11274 L .56609 .12034 L F
.56361 .11814 m .56609 .12034 L .56641 .12085 L F
.56042 .11603 m .56003 .11577 L .56002 .11641 L .049 .063 0 r
F
.56003 .11577 m .5574 .11402 L .56002 .11641 L F
.5574 .11402 m .55763 .11461 L .56002 .11641 L F
.56002 .11641 m .55291 .11104 L .55852 .11784 L F
.56042 .11603 m .55496 .10831 L .55291 .11104 L F
.56487 .12672 m .56042 .11603 L .55852 .11784 L 0 .003 0 r
F
.56008 .11729 m .55496 .10831 L .56042 .11603 L 0 0 0 r
F
.55988 .11802 m .5595 .11727 L .56008 .11729 L F
.5574 .11402 m .55291 .11104 L .55763 .11461 L .049 .063 0 r
F
.5539 .11357 m .55257 .1131 L .55379 .11052 L 1 .482 0 r
F
.5527 .11437 m .55257 .1131 L .5539 .11357 L F
.55257 .1131 m .54938 .10047 L .55512 .1077 L .865 .119 0 r
F
.55428 .10537 m .5525 .11289 L .54975 .09869 L .232 .016 0 r
F
.5525 .11289 m .5494 .10058 L .54975 .09869 L F
.55428 .10537 m .54975 .09869 L .55584 .10451 L F
.51984 .24429 m .52003 .2429 L .52015 .24258 L .705 .177 0 r
F
.51137 .28591 m .51026 .2899 L .51457 .2694 L 0 0 0 r
F
.51423 .27186 m .51457 .2694 L .51984 .24429 L F
.51137 .28591 m .51457 .2694 L .51423 .27186 L F
.51689 .26345 m .51984 .24429 L .51624 .27007 L 1 .866 0 r
F
.52016 .24965 m .52818 .1984 L .51838 .2592 L 0 0 0 r
F
.51479 .28396 m .52016 .24965 L .51838 .2592 L F
.51437 .28776 m .51601 .27104 L .51176 .30501 L F
.51437 .28776 m .51479 .28396 L .51601 .27104 L F
.51203 .31152 m .51479 .28396 L .51437 .28776 L F
.51327 .29279 m .51512 .28107 L .51479 .28396 L 1 .543 0 r
F
.51512 .28107 m .52122 .24242 L .51479 .28396 L F
.52122 .24242 m .52657 .20858 L .51943 .25426 L F
.52122 .24242 m .51943 .25426 L .51479 .28396 L F
.51203 .31152 m .51437 .28776 L .51132 .30857 L 0 0 0 r
F
.51437 .28776 m .51176 .30501 L .51132 .30857 L F
.51379 .28893 m .52657 .20858 L .51327 .29279 L 1 .543 0 r
F
.52657 .20858 m .52818 .1984 L .52528 .21695 L F
.52657 .20858 m .52528 .21695 L .51479 .28396 L F
.51514 .28045 m .51984 .24429 L .52818 .1984 L F
.51489 .28082 m .51984 .24429 L .51514 .28045 L F
.51363 .28877 m .5147 .28111 L .51379 .28893 L F
.5147 .28111 m .51984 .24429 L .51489 .28082 L F
.5147 .28111 m .51489 .28082 L .51379 .28893 L F
.51163 .32597 m .51047 .31918 L .51031 .32582 L 0 0 0 r
F
.51047 .31918 m .50979 .31517 L .5102 .32359 L F
.51047 .31918 m .5102 .32359 L .51031 .32582 L F
.51047 .31918 m .51061 .31742 L .50979 .31517 L F
.51163 .32597 m .51061 .31742 L .51047 .31918 L F
.51251 .32258 m .51176 .31382 L .5112 .3223 L F
.51176 .31382 m .51132 .30857 L .51123 .31897 L F
.51176 .31382 m .51123 .31897 L .5112 .3223 L F
.51176 .31382 m .51203 .31152 L .51132 .30857 L F
.51251 .32258 m .51203 .31152 L .51176 .31382 L F
.51424 .32863 m .51251 .32258 L .51397 .3287 L .699 .087 0 r
F
.51465 .32853 m .51364 .32571 L .51424 .32863 L F
.51364 .32571 m .51251 .32258 L .51424 .32863 L F
.51345 .32518 m .51285 .32378 L .51251 .32258 L F
.51465 .32853 m .51285 .32378 L .51345 .32518 L F
.51397 .3287 m .5112 .3223 L .51236 .32947 L 0 0 0 r
F
.51397 .3287 m .51251 .32258 L .5112 .3223 L F
.5124 .32522 m .51216 .32217 L .51285 .32378 L 1 .477 0 r
F
.51264 .32304 m .51228 .31625 L .51251 .32258 L 1 .185 0 r
F
.51228 .31625 m .51203 .31152 L .51218 .31484 L F
.51228 .31625 m .51218 .31484 L .51251 .32258 L F
.51285 .32378 m .51247 .31816 L .51264 .32304 L F
.51247 .31816 m .51203 .31152 L .51264 .32304 L F
.51216 .32217 m .51165 .31587 L .51285 .32378 L 1 .477 0 r
F
.51266 .32096 m .51165 .31587 L .51203 .31152 L 1 .185 0 r
F
.51285 .32378 m .51176 .3166 L .51266 .32096 L F
.51176 .3166 m .51165 .31587 L .51266 .32096 L F
.51235 .30882 m .5133 .29912 L .51203 .31152 L 1 .671 0 r
F
.5133 .29912 m .51479 .28396 L .51266 .30524 L F
.5133 .29912 m .51266 .30524 L .51203 .31152 L F
.51221 .31024 m .51221 .29889 L .51479 .28396 L F
.51165 .31587 m .51235 .30882 L .51203 .31152 L F
.51165 .31587 m .51202 .30473 L .51221 .31024 L F
.51202 .30473 m .51221 .29889 L .51221 .31024 L F
.51182 .32629 m .51061 .31742 L .51163 .32597 L .911 .141 0 r
F
.51207 .32671 m .51143 .32259 L .51182 .32629 L F
.51143 .32259 m .51061 .31742 L .51182 .32629 L F
.51078 .31538 m .51119 .30744 L .51061 .31742 L 1 .612 0 r
F
.51119 .30744 m .51166 .29819 L .51091 .31196 L F
.51119 .30744 m .51091 .31196 L .51061 .31742 L F
.51074 .31617 m .5101 .30832 L .51166 .29819 L F
.51207 .32671 m .51052 .3205 L .51061 .31742 L .911 .141 0 r
F
.51052 .3205 m .51078 .31538 L .51061 .31742 L 1 .612 0 r
F
.51052 .3205 m .51019 .31094 L .51074 .31617 L F
.51019 .31094 m .5101 .30832 L .51074 .31617 L F
.50981 .32334 m .50836 .31611 L .5101 .30832 L 1 .688 0 r
F
.50967 .31029 m .51137 .28591 L .51984 .24429 L 1 .866 0 r
F
.50754 .31713 m .51024 .29511 L .50967 .31029 L .631 .09 0 r
F
.51024 .29511 m .51137 .28591 L .51077 .29443 L F
.51024 .29511 m .51077 .29443 L .50967 .31029 L F
.53025 .20564 m .50658 .30657 L .54878 .10336 L .232 .016 0 r
F
.5294 .21032 m .50658 .30657 L .53025 .20564 L F
.5111 .28638 m .50871 .29706 L .51132 .28659 L 1 .448 0 r
F
.50871 .29706 m .50658 .30657 L .50889 .29682 L F
.50871 .29706 m .50889 .29682 L .51132 .28659 L F
.50658 .30657 m .51439 .25764 L .53819 .15435 L 1 .74 0 r
F
.52299 .2307 m .50991 .28812 L .52131 .24068 L 1 .448 0 r
F
.50991 .28812 m .50407 .31375 L .51023 .28765 L F
.50991 .28812 m .51023 .28765 L .52131 .24068 L F
.5111 .28638 m .50948 .29082 L .51 .29129 L F
.52131 .24068 m .51023 .28765 L .5111 .28638 L F
.51023 .28765 m .50948 .29082 L .5111 .28638 L F
.51379 .28893 m .51489 .28082 L .51514 .28045 L 1 .543 0 r
F
.51221 .29889 m .51363 .28877 L .51379 .28893 L F
.51895 .25124 m .5111 .28638 L .51792 .25873 L 1 .448 0 r
F
.5111 .28638 m .51132 .28659 L .51792 .25873 L F
.535 .17943 m .51895 .25124 L .53096 .20169 L F
.535 .17943 m .53096 .20169 L .5525 .11289 L F
.54809 .10096 m .5418 .12956 L .54145 .12983 L 0 0 0 r
F
.53418 .15628 m .52925 .1866 L .54698 .10599 L .842 .189 0 r
F
.54744 .10354 m .54698 .10599 L .54809 .10096 L F
.53418 .15628 m .54698 .10599 L .54744 .10354 L F
.54602 .09916 m .53418 .15628 L .54809 .10096 L F
.54776 .12233 m .54602 .09916 L .54809 .10096 L 1 .28 0 r
F
.54776 .12233 m .535 .17943 L .54956 .12405 L 1 .448 0 r
F
.54776 .12233 m .52299 .2307 L .52131 .24068 L F
.54767 .12233 m .54766 .12224 L .54776 .12233 L 1 .28 0 r
F
.54766 .12224 m .54602 .09916 L .54776 .12233 L F
.54776 .12233 m .54809 .10096 L .5525 .11289 L F
.55241 .1015 m .54767 .12233 L .54776 .12233 L 1 .448 0 r
F
.54767 .12233 m .52299 .2307 L .54776 .12233 L F
.54774 .12337 m .54767 .12233 L .54776 .12233 L 1 .28 0 r
F
.54776 .12233 m .54956 .12405 L .5525 .11289 L 1 .448 0 r
F
.51895 .25124 m .51792 .25873 L .5525 .11289 L F
.51221 .29889 m .51379 .28893 L .51327 .29279 L 1 .543 0 r
F
.54774 .12337 m .54776 .12233 L .55257 .1131 L 1 .28 0 r
F
.54776 .12233 m .5525 .11289 L .55257 .1131 L F
.55029 .11099 m .54776 .12233 L .5525 .11289 L 1 .448 0 r
F
.55241 .1015 m .55029 .11099 L .55428 .10537 L F
.55029 .11099 m .5525 .11289 L .55428 .10537 L F
.55257 .1131 m .5525 .11289 L .55251 .1129 L .865 .119 0 r
F
.55785 .14377 m .55395 .13358 L .54661 .13873 L .519 .3 0 r
F
.52538 .24785 m .55257 .1131 L .55463 .13361 L 1 .704 0 r
F
.52538 .24785 m .54774 .12337 L .55257 .1131 L F
.55251 .1145 m .55241 .1015 L .55428 .10537 L 1 .565 0 r
F
.53344 .21305 m .54991 .11624 L .55251 .1145 L F
.54991 .11624 m .55241 .1015 L .55251 .1145 L F
.55463 .13361 m .5527 .11437 L .5539 .11357 L 1 .482 0 r
F
.55734 .113 m .55496 .10831 L .55783 .11335 L 0 0 0 r
F
.5595 .11727 m .55734 .113 L .56008 .11729 L F
.55734 .113 m .55783 .11335 L .56008 .11729 L F
.55939 .117 m .55512 .1077 L .55504 .10803 L F
.55988 .11802 m .5591 .11632 L .55939 .117 L F
.5591 .11632 m .55512 .1077 L .55939 .117 L F
.5558 .10997 m .55504 .10803 L .55496 .10831 L F
.55988 .11802 m .55504 .10803 L .5558 .10997 L F
.55505 .11141 m .55379 .11052 L .55512 .1077 L 1 .482 0 r
F
.56343 .1266 m .55472 .12128 L .55964 .12937 L .216 .076 0 r
F
.56343 .1266 m .55852 .11784 L .55472 .12128 L F
.56344 .12661 m .55852 .11784 L .56343 .1266 L 0 .003 0 r
F
.56487 .12672 m .56214 .12291 L .56344 .12661 L F
.56214 .12291 m .55852 .11784 L .56344 .12661 L F
.56287 .13378 m .55988 .11802 L .56012 .11715 L .828 .134 0 r
F
.56087 .11928 m .56012 .11715 L .56042 .11603 L F
.56287 .13378 m .56012 .11715 L .56087 .11928 L F
.55463 .13361 m .55512 .1077 L .55988 .11802 L 1 .482 0 r
F
.55773 .11721 m .55428 .10537 L .55442 .10529 L .92 .138 0 r
F
.56128 .11228 m .5581 .10909 L .56122 .11274 L 0 .013 0 r
F
.5581 .10909 m .55539 .10639 L .55953 .1109 L F
.5581 .10909 m .55953 .1109 L .56122 .11274 L F
.55679 .11089 m .55442 .10529 L .55488 .10504 L .92 .138 0 r
F
.56128 .11228 m .55584 .10451 L .55539 .10639 L 0 .013 0 r
F
.55616 .10666 m .55488 .10504 L .55584 .10451 L .92 .138 0 r
F
.55679 .11089 m .55488 .10504 L .55616 .10666 L F
.55773 .11721 m .55442 .10529 L .55679 .11089 L F
.55463 .13361 m .55379 .11052 L .55505 .11141 L 1 .482 0 r
F
.55805 .11934 m .55747 .1172 L .55773 .11721 L .92 .138 0 r
F
.55747 .1172 m .55428 .10537 L .55773 .11721 L F
.55426 .16066 m .55988 .11802 L .56287 .13378 L 1 .785 0 r
F
.5548 .15653 m .55463 .13361 L .55988 .11802 L F
.55172 .14796 m .55463 .13361 L .55445 .14671 L .378 .044 0 r
F
.55172 .14796 m .52538 .24785 L .55463 .13361 L F
.52959 .24799 m .54692 .16762 L .55172 .14796 L 1 .777 0 r
F
.53148 .23087 m .52538 .24785 L .55172 .14796 L .378 .044 0 r
F
.52959 .24799 m .53344 .21305 L .55402 .1347 L 1 .777 0 r
F
.55056 .1689 m .55172 .14796 L .55433 .15541 L .378 .044 0 r
F
.55172 .14796 m .55445 .14671 L .55433 .15541 L F
.5503 .17347 m .55433 .15541 L .55426 .16066 L F
.52959 .24799 m .54451 .18053 L .5503 .17347 L 1 .777 0 r
F
.54451 .18053 m .55172 .14796 L .5503 .17347 L F
.55202 .17138 m .5503 .17347 L .55426 .16066 L .924 .368 0 r
F
.54332 .21271 m .53917 .22336 L .54882 .18207 L .366 .041 0 r
F
.54418 .20884 m .5503 .17347 L .55202 .17138 L .924 .368 0 r
F
.54474 .20565 m .54882 .18207 L .55356 .16177 L .366 .041 0 r
F
.54332 .21271 m .54882 .18207 L .54474 .20565 L F
.53917 .22336 m .5503 .17347 L .55356 .16177 L F
.54374 .21143 m .55294 .17108 L .54908 .2014 L .924 .368 0 r
F
.54908 .2014 m .56287 .13378 L .5622 .1604 L 1 .872 0 r
F
.54908 .2014 m .55426 .16066 L .56287 .13378 L F
.53936 .25229 m .54908 .2014 L .5622 .1604 L 1 .923 0 r
F
.53986 .242 m .54908 .2014 L .53936 .25229 L 1 .869 0 r
F
.53986 .242 m .54358 .21173 L .54908 .2014 L F
.54958 .20809 m .54347 .2126 L .55972 .16315 L .73 .143 0 r
F
.54347 .2126 m .54332 .21271 L .54374 .21143 L F
.54347 .2126 m .54374 .21143 L .55972 .16315 L F
.54374 .21143 m .55426 .16066 L .55294 .17108 L .924 .368 0 r
F
.54332 .21271 m .54418 .20884 L .54374 .21143 L .366 .041 0 r
F
.54363 .21163 m .54404 .20967 L .54374 .21143 L .924 .368 0 r
F
.54404 .20967 m .55426 .16066 L .54374 .21143 L F
.54374 .21143 m .55961 .13999 L .55972 .16315 L .366 .041 0 r
F
.54418 .20884 m .55426 .16066 L .54363 .21163 L .924 .368 0 r
F
.54418 .20884 m .55961 .13999 L .54374 .21143 L .366 .041 0 r
F
.54418 .20884 m .55356 .16177 L .55215 .17329 L F
.54332 .21271 m .54912 .18383 L .54418 .20884 L F
.54912 .18383 m .55356 .16177 L .54418 .20884 L F
.54358 .21173 m .54418 .20884 L .54363 .21163 L .924 .368 0 r
F
.54358 .21173 m .5503 .17347 L .54418 .20884 L F
.53917 .22336 m .52959 .24799 L .5503 .17347 L .366 .041 0 r
F
.54358 .21173 m .53935 .20894 L .5503 .17347 L .924 .368 0 r
F
.53935 .20894 m .55433 .15541 L .5503 .17347 L .378 .044 0 r
F
.55426 .16066 m .55433 .15541 L .5548 .15653 L 1 .785 0 r
F
.55433 .15541 m .55445 .14671 L .55467 .15268 L F
.55433 .15541 m .55467 .15268 L .5548 .15653 L F
.55445 .14671 m .55463 .13361 L .5548 .15653 L F
.5503 .17347 m .55805 .11934 L .55961 .13999 L 1 .777 0 r
F
.55172 .14796 m .55805 .11934 L .5503 .17347 L F
.53935 .20894 m .55172 .14796 L .55056 .1689 L .378 .044 0 r
F
.53935 .20894 m .53148 .23087 L .55172 .14796 L F
.54692 .16762 m .5511 .14825 L .55172 .14796 L 1 .777 0 r
F
.55172 .14796 m .55402 .1347 L .55411 .13717 L F
.5511 .14825 m .55402 .1347 L .55172 .14796 L F
.55215 .17329 m .55356 .16177 L .55961 .13999 L .366 .041 0 r
F
.55411 .13717 m .55402 .1347 L .55805 .11934 L 1 .777 0 r
F
.55961 .13999 m .55805 .11934 L .56004 .11499 L 1 .573 0 r
F
.56107 .11589 m .56004 .11499 L .56128 .11228 L F
.56287 .13378 m .56042 .11603 L .56487 .12672 L .828 .134 0 r
F
.55961 .13999 m .56004 .11499 L .56107 .11589 L 1 .573 0 r
F
.56572 .12294 m .56128 .11228 L .56125 .11257 L 0 0 0 r
F
.56192 .11433 m .56125 .11257 L .56122 .11274 L F
.56572 .12294 m .56125 .11257 L .56192 .11433 L F
.5237 .19935 m .53142 .12079 L .53144 .12062 L .819 .171 0 r
F
.53248 .11475 m .53144 .12062 L .53288 .11094 L F
.5237 .19935 m .53144 .12062 L .53248 .11475 L F
.53359 .1127 m .53294 .11381 L .53505 .10732 L .003 0 0 r
F
.53213 .11149 m .53288 .11094 L .53243 .11021 L 0 0 0 r
F
.53221 .11171 m .53288 .11094 L .53213 .11149 L F
.53205 .11125 m .53219 .11509 L .53158 .11188 L .003 0 0 r
F
.53195 .11118 m .53154 .11168 L .53195 .11118 L F
.532 .11109 m .53158 .11188 L .53154 .11168 L F
.532 .11109 m .53243 .11021 L .53192 .10937 L 0 0 0 r
F
.53288 .11094 m .53236 .11001 L .53243 .11021 L 0 .009 0 r
F
.5268 .15714 m .52961 .13163 L .5314 .12012 L .826 .175 0 r
F
.5315 .12046 m .5314 .12012 L .53219 .11509 L F
.53144 .12062 m .5277 .09819 L .53288 .11094 L .733 .12 0 r
F
.53142 .12079 m .53141 .12075 L .53144 .12062 L F
.53141 .12075 m .5277 .09819 L .53144 .12062 L F
.53142 .12079 m .53115 .11921 L .53117 .11929 L F
.53115 .11921 m .52775 .09928 L .53117 .11929 L F
.51701 .23363 m .52371 .17937 L .5268 .15714 L .826 .175 0 r
F
.50822 .27976 m .52314 .16623 L .52967 .13036 L 1 .7 0 r
F
.52421 .17578 m .52961 .13163 L .5268 .15714 L .826 .175 0 r
F
.52624 .1589 m .52961 .13163 L .52421 .17578 L F
.51698 .23381 m .52961 .13163 L .51701 .23363 L F
.52804 .14391 m .52967 .13036 L .53142 .12079 L 1 .7 0 r
F
.50822 .27976 m .52967 .13036 L .52804 .14391 L F
.52371 .17937 m .52624 .1589 L .52421 .17578 L .826 .175 0 r
F
.51033 .2713 m .51043 .27114 L .51072 .26977 L .842 .189 0 r
F
.51043 .27114 m .51079 .27056 L .51072 .26977 L F
.51072 .26977 m .51079 .27056 L .51258 .26243 L F
.51195 .26409 m .51258 .26243 L .52925 .1866 L F
.51033 .2713 m .51258 .26243 L .51195 .26409 L F
.51439 .25764 m .51603 .24737 L .53819 .15435 L 1 .74 0 r
F
.51603 .24737 m .53093 .18186 L .53819 .15435 L F
.53418 .15628 m .5254 .19862 L .52925 .1866 L .842 .189 0 r
F
.5254 .19862 m .52276 .21567 L .52925 .1866 L F
.5169 .23452 m .51698 .23381 L .51701 .23363 L .826 .175 0 r
F
.54602 .09916 m .51785 .23379 L .51835 .23261 L .842 .189 0 r
F
.51785 .23379 m .50074 .31559 L .51835 .23261 L F
.52986 .17564 m .5237 .19935 L .52995 .17521 L 1 .74 0 r
F
.51 .29129 m .50407 .31375 L .50658 .30657 L 1 .448 0 r
F
.50948 .29082 m .50407 .31375 L .51 .29129 L F
.50981 .32334 m .5101 .30832 L .51052 .3205 L 1 .688 0 r
F
.50967 .31029 m .51689 .26345 L .51221 .29889 L 1 .866 0 r
F
.51689 .26345 m .51624 .27007 L .51221 .29889 L F
.54975 .09869 m .54947 .0995 L .54947 .09951 L .187 .004 0 r
F
.54975 .09869 m .54947 .09951 L .54974 .09872 L F
.54975 .09869 m .5493 .10041 L .54916 .10038 L F
.53118 .09995 m .53087 .09984 L .53117 .09976 L .229 .077 0 r
F
.50483 .32908 m .50474 .32882 L .50475 .32914 L .377 .061 0 r
F
.56528 .67337 m .53289 .67089 L .53296 .67614 L .866 .38 0 r
F
.56528 .67337 m .56537 .66854 L .53289 .67089 L F
.59948 .48611 m .57509 .4876 L .57485 .49133 L .691 .151 0 r
F
.59948 .48611 m .5999 .48234 L .57509 .4876 L F
.76429 .7357 m .73009 .73989 L .72832 .7455 L .387 .032 0 r
F
.76429 .7357 m .76634 .72995 L .73009 .73989 L F
.81355 .66968 m .78075 .67598 L .77951 .68216 L .34 .034 0 r
F
.81355 .66968 m .81495 .66337 L .78075 .67598 L F
.33558 .15052 m .3326 .13951 L .32629 .14265 L 1 1 0 r
F
.33558 .15052 m .34141 .1469 L .3326 .13951 L F
.39058 .75452 m .34937 .75566 L .35017 .76061 L .973 .382 0 r
F
.39099 .75968 m .39058 .75452 L .35017 .76061 L .971 .364 0 r
F
.42956 .75163 m .39058 .75452 L .39099 .75968 L .919 .364 0 r
F
.42956 .75163 m .42944 .74621 L .39058 .75452 L F
.57363 .50921 m .54811 .50949 L .54799 .51295 L .792 .265 0 r
F
.57363 .50921 m .57388 .50572 L .54811 .50949 L F
.34314 .21009 m .35075 .22943 L .34646 .23293 L .329 .011 0 r
F
.34314 .21009 m .34811 .20721 L .35075 .22943 L F
.72698 .47324 m .70004 .47953 L .70008 .48452 L .457 .069 0 r
F
.72698 .47324 m .72691 .46815 L .70004 .47953 L F
.10976 .51027 m .08137 .48585 L .08029 .49277 L 1 .958 0 r
F
.10887 .51711 m .10976 .51027 L .08029 .49277 L 1 .947 0 r
F
.12287 .48948 m .09684 .46563 L .09538 .47231 L 1 1 0 r
F
.12163 .49614 m .12287 .48948 L .09538 .47231 L 1 .99 0 r
F
.46903 .44622 m .44799 .44402 L .44782 .44743 L 1 .86 0 r
F
.46899 .44984 m .46903 .44622 L .44782 .44743 L 1 .856 0 r
F
.2464 .75779 m .20693 .74347 L .20884 .749 L 1 .436 0 r
F
.24808 .76312 m .2464 .75779 L .20884 .749 L 1 .417 0 r
F
.6316 .62164 m .5987 .62015 L .59867 .62464 L .795 .283 0 r
F
.6316 .62164 m .63189 .61725 L .5987 .62015 L F
.74098 .37962 m .72131 .38645 L .72202 .39225 L .284 .053 0 r
F
.74098 .37962 m .74017 .37384 L .72131 .38645 L F
.28083 .23883 m .37932 .36176 L .37704 .3637 L .736 .203 0 r
F
.28083 .23883 m .29162 .24264 L .37932 .36176 L F
.46588 .74296 m .42944 .74621 L .42956 .75163 L .876 .347 0 r
F
.46588 .74296 m .4659 .73748 L .42944 .74621 L F
.33594 .15139 m .33277 .13994 L .32651 .14316 L 1 1 0 r
F
.33594 .15139 m .34175 .14778 L .33277 .13994 L F
.13169 .47628 m .10475 .45269 L .10332 .45926 L 1 .995 0 r
F
.13051 .4828 m .13169 .47628 L .10332 .45926 L 1 .985 0 r
F
.53288 .70227 m .50026 .70203 L .50025 .70766 L .852 .364 0 r
F
.53288 .70227 m .53296 .69708 L .50026 .70203 L F
.29289 .80063 m .25176 .78907 L .25383 .79416 L 1 .31 0 r
F
.29462 .80554 m .29289 .80063 L .25383 .79416 L 1 .289 0 r
F
.84838 .38928 m .82354 .40099 L .8258 .40757 L .301 .073 0 r
F
.84838 .38928 m .84594 .38272 L .82354 .40099 L F
.29939 .20988 m .30123 .20964 L .29457 .21095 L 0 0 0 r
F
.29939 .20988 m .30505 .20685 L .30123 .20964 L F
.3401 .81478 m .2992 .80509 L .30101 .80977 L 1 .233 0 r
F
.34152 .81929 m .3401 .81478 L .30101 .80977 L 1 .212 0 r
F
.46737 .5977 m .43915 .58961 L .43837 .59586 L 1 .873 0 r
F
.46737 .5977 m .46745 .59237 L .43915 .58961 L F
.85331 .39529 m .828 .40711 L .83027 .41374 L .304 .074 0 r
F
.85331 .39529 m .85084 .38868 L .828 .40711 L F
.46899 .44984 m .44782 .44743 L .44766 .45081 L 1 .856 0 r
F
.46896 .45343 m .46899 .44984 L .44766 .45081 L 1 .851 0 r
F
.52107 .53209 m .49452 .52977 L .49449 .53306 L .953 .446 0 r
F
.52107 .53209 m .52115 .5288 L .49452 .52977 L F
.30487 .74382 m .26239 .73809 L .26391 .7431 L 1 .42 0 r
F
.306 .74878 m .30487 .74382 L .26391 .7431 L 1 .407 0 r
F
.38239 .83679 m .34098 .82907 L .3425 .83351 L .992 .154 0 r
F
.38344 .84109 m .38239 .83679 L .3425 .83351 L .982 .133 0 r
F
.46467 .85197 m .46463 .84791 L .42435 .84722 L .864 .07 0 r
F
.50441 .85142 m .46463 .84791 L .46467 .85197 L .804 .064 0 r
F
.50441 .85142 m .50491 .84736 L .46463 .84791 L F
.5474 .52647 m .52122 .52548 L .52115 .5288 L .874 .353 0 r
F
.5474 .52647 m .54756 .52314 L .52122 .52548 L F
.8495 .56167 m .82011 .57083 L .82001 .57741 L .287 .04 0 r
F
.8495 .56167 m .84963 .555 L .82011 .57083 L F
.14299 .63949 m .10782 .61879 L .10857 .62543 L 1 .727 0 r
F
.14376 .64596 m .14299 .63949 L .10857 .62543 L 1 .711 0 r
F
.6987 .54195 m .66777 .54541 L .66764 .54995 L .613 .131 0 r
F
.6987 .54195 m .69896 .53731 L .66777 .54541 L F
.46896 .45343 m .44766 .45081 L .44751 .45417 L 1 .851 0 r
F
.46893 .45699 m .46896 .45343 L .44751 .45417 L 1 .847 0 r
F
.24418 .76805 m .20392 .75402 L .20596 .75957 L 1 .413 0 r
F
.24597 .77341 m .24418 .76805 L .20596 .75957 L 1 .393 0 r
F
.85445 .56953 m .82405 .57853 L .82395 .5852 L .299 .043 0 r
F
.85445 .56953 m .85456 .56276 L .82405 .57853 L F
.59791 .65178 m .5654 .64927 L .56543 .65407 L .837 .332 0 r
F
.59791 .65178 m .59811 .64724 L .5654 .64927 L F
.42448 .83778 m .38371 .83151 L .38476 .83571 L .934 .098 0 r
F
.42504 .84185 m .42448 .83778 L .38476 .83571 L .924 .079 0 r
F
.46473 .84258 m .42448 .83778 L .42504 .84185 L .87 .072 0 r
F
.34937 .75566 m .30718 .75368 L .30841 .75854 L 1 .387 0 r
F
.35017 .76061 m .34937 .75566 L .30841 .75854 L 1 .372 0 r
F
.56516 .6782 m .53296 .67614 L .53301 .6814 L .853 .359 0 r
F
.56516 .6782 m .56528 .67337 L .53296 .67614 L F
.65066 .42479 m .63053 .42796 L .6296 .43291 L .38 .04 0 r
F
.65066 .42479 m .65186 .41972 L .63053 .42796 L F
.62476 .4599 m .60218 .46244 L .60169 .46658 L .551 .064 0 r
F
.62476 .4599 m .62548 .45569 L .60218 .46244 L F
.46893 .45699 m .44751 .45417 L .44736 .45751 L 1 .847 0 r
F
.46889 .46051 m .46893 .45699 L .44736 .45751 L 1 .843 0 r
F
.66542 .5902 m .63303 .59084 L .6329 .59524 L .715 .205 0 r
F
.66542 .5902 m .66578 .58578 L .63303 .59084 L F
.57338 .51265 m .54799 .51295 L .54785 .51638 L .787 .258 0 r
F
.57338 .51265 m .57363 .50921 L .54799 .51295 L F
.37975 .13625 m .37799 .13044 L .37187 .13292 L .832 1 0 r
F
.71219 .77327 m .67767 .7762 L .67577 .78119 L .438 .032 0 r
F
.71219 .77327 m .71446 .76818 L .67767 .7762 L F
.59908 .48982 m .57485 .49133 L .5746 .495 L .686 .147 0 r
F
.59908 .48982 m .59948 .48611 L .57485 .49133 L F
.66839 .81025 m .63236 .81141 L .63059 .8161 L .528 .038 0 r
F
.66839 .81025 m .6706 .80547 L .63236 .81141 L F
.39085 .16795 m .39669 .19983 L .38914 .19186 L .397 .04 0 r
F
.62495 .8297 m .588 .82966 L .58655 .83405 L .6 .043 0 r
F
.62495 .8297 m .62688 .82525 L .588 .82966 L F
.72703 .47829 m .70008 .48452 L .70009 .48947 L .455 .069 0 r
F
.72703 .47829 m .72698 .47324 L .70008 .48452 L F
.15981 .60571 m .12482 .58623 L .12528 .59256 L 1 .754 0 r
F
.16036 .61184 m .15981 .60571 L .12528 .59256 L 1 .741 0 r
F
.85071 .39587 m .8258 .40757 L .82797 .41417 L .296 .071 0 r
F
.85071 .39587 m .84838 .38928 L .8258 .40757 L F
.69824 .31918 m .68414 .32189 L .68407 .32898 L .161 .016 0 r
F
.69824 .31918 m .69842 .31204 L .68414 .32189 L F
.19787 .24459 m .18791 .22327 L .18272 .22838 L 1 1 0 r
F
.19787 .24459 m .20272 .23924 L .18791 .22327 L F
.1931 .25001 m .19787 .24459 L .18272 .22838 L F
.20272 .23924 m .19318 .21825 L .18791 .22327 L F
.20272 .23924 m .20764 .23397 L .19318 .21825 L F
.1931 .25001 m .18272 .22838 L .17762 .23357 L F
.18842 .2555 m .1931 .25001 L .17762 .23357 L F
.85567 .40192 m .83027 .41374 L .83245 .42039 L .299 .072 0 r
F
.85567 .40192 m .85331 .39529 L .83027 .41374 L F
.12163 .49614 m .09538 .47231 L .09401 .479 L 1 .99 0 r
F
.1205 .5028 m .12163 .49614 L .09401 .479 L 1 .979 0 r
F
.46889 .46051 m .44736 .45751 L .44722 .46082 L 1 .843 0 r
F
.46886 .464 m .46889 .46051 L .44722 .46082 L 1 .839 0 r
F
.63129 .62604 m .59867 .62464 L .59861 .62915 L .785 .269 0 r
F
.63129 .62604 m .6316 .62164 L .59867 .62464 L F
.20764 .23397 m .19853 .21331 L .19318 .21825 L 1 1 0 r
F
.20764 .23397 m .21264 .22877 L .19853 .21331 L F
.74174 .38535 m .72202 .39225 L .72267 .39801 L .282 .052 0 r
F
.74174 .38535 m .74098 .37962 L .72202 .39225 L F
.18842 .2555 m .17762 .23357 L .17261 .23885 L 1 1 0 r
F
.18381 .26106 m .18842 .2555 L .17261 .23885 L F
.52098 .53536 m .49449 .53306 L .49446 .53632 L .949 .437 0 r
F
.52098 .53536 m .52107 .53209 L .49449 .53306 L F
.33032 .13665 m .33208 .12722 L .32552 .13023 L .973 1 0 r
F
.34141 .1469 m .33911 .13711 L .3326 .13951 L .978 1 0 r
F
.33911 .13711 m .33801 .13706 L .3326 .13951 L F
.31402 .13852 m .31903 .1334 L .31261 .13671 L 1 1 0 r
F
.32005 .14597 m .32629 .14265 L .32364 .13935 L F
.32005 .14597 m .32364 .13935 L .32232 .13924 L F
.31959 .139 m .32268 .13816 L .32264 .13811 L F
.3195 .13806 m .32264 .13811 L .31903 .1334 L F
.32268 .13816 m .32552 .13023 L .31903 .1334 L F
.32294 .13812 m .32552 .13023 L .32268 .13816 L F
.32615 .1385 m .32552 .13023 L .32292 .13818 L F
.32629 .14265 m .32615 .1385 L .32268 .13816 L .975 1 0 r
F
.32615 .1385 m .32292 .13818 L .32285 .13839 L 1 1 0 r
F
.32629 .14265 m .3326 .13951 L .33195 .1387 L .975 1 0 r
F
.32919 .13861 m .33195 .1387 L .33046 .13684 L F
.32629 .14265 m .33195 .1387 L .32919 .13861 L F
.32651 .14316 m .33277 .13994 L .33046 .13684 L 1 1 0 r
F
.32601 .13661 m .33046 .13684 L .32552 .13023 L F
.3326 .13677 m .33208 .12722 L .33032 .13665 L .973 1 0 r
F
.33911 .13711 m .33899 .13661 L .33801 .13706 L .978 1 0 r
F
.34141 .1469 m .3473 .14342 L .33899 .13661 L F
.33149 .13724 m .3326 .13677 L .33124 .1367 L .973 1 0 r
F
.3326 .13951 m .33801 .13706 L .33504 .13714 L .941 1 0 r
F
.3326 .13951 m .33749 .13475 L .33263 .13721 L F
.33112 .13767 m .33223 .13714 L .33046 .13684 L F
.33263 .13721 m .3326 .13677 L .33187 .13708 L .973 1 0 r
F
.33245 .13403 m .33749 .13475 L .33208 .12722 L F
.33263 .13721 m .33749 .13475 L .33245 .13403 L F
.33749 .13475 m .33868 .1243 L .33208 .12722 L .91 1 0 r
F
.33899 .13661 m .33911 .13523 L .33749 .13475 L .88 1 0 r
F
.33504 .13714 m .33899 .13661 L .33749 .13475 L .941 1 0 r
F
.33801 .13706 m .33899 .13661 L .33504 .13714 L F
.3473 .14342 m .34562 .13477 L .33899 .13661 L .948 1 0 r
F
.34562 .13477 m .34547 .13397 L .34349 .13478 L F
.34562 .13477 m .34349 .13478 L .33899 .13661 L F
.33911 .13523 m .34547 .13397 L .34404 .13228 L .88 1 0 r
F
.33899 .13661 m .34349 .13478 L .33911 .13523 L F
.34349 .13478 m .34547 .13397 L .33911 .13523 L F
.3473 .14342 m .35324 .1401 L .34547 .13397 L .948 1 0 r
F
.33918 .1371 m .34582 .13494 L .34404 .13228 L .91 1 0 r
F
.33893 .13069 m .34404 .13228 L .33868 .1243 L F
.34404 .13228 m .34517 .12109 L .33868 .1243 L .791 .862 0 r
F
.34547 .13397 m .34574 .13308 L .34404 .13228 L .694 .899 0 r
F
.35324 .1401 m .35203 .13163 L .34547 .13397 L .908 1 0 r
F
.34574 .13308 m .35203 .13163 L .35065 .13038 L .694 .899 0 r
F
.34547 .13397 m .35026 .13226 L .34574 .13308 L F
.35026 .13226 m .35203 .13163 L .34574 .13308 L F
.35324 .1401 m .35923 .13694 L .35203 .13163 L .908 1 0 r
F
.34582 .13494 m .35291 .13421 L .35065 .13038 L .791 .862 0 r
F
.34555 .12921 m .35065 .13038 L .34517 .12109 L F
.35065 .13038 m .3514 .11699 L .34517 .12109 L .76 .727 0 r
F
.35203 .13163 m .35264 .1311 L .35065 .13038 L .39 .204 0 r
F
.35923 .13694 m .35864 .12952 L .35203 .13163 L .855 1 0 r
F
.35203 .13163 m .35864 .12952 L .35862 .12952 L .39 .204 0 r
F
.35264 .1311 m .35862 .12952 L .35763 .1293 L F
.35203 .13163 m .35862 .12952 L .35264 .1311 L F
.35923 .13694 m .36527 .13396 L .35864 .12952 L .855 1 0 r
F
.35291 .13421 m .36018 .13433 L .35763 .1293 L .76 .727 0 r
F
.35262 .13083 m .35763 .1293 L .3514 .11699 L F
.35763 .1293 m .3578 .11324 L .3514 .11699 L .927 .799 0 r
F
.35864 .12952 m .35956 .12885 L .35763 .1293 L .355 .199 0 r
F
.36527 .13396 m .36526 .12757 L .35864 .12952 L .784 .994 0 r
F
.35864 .12952 m .36526 .12757 L .3648 .12749 L .355 .199 0 r
F
.35956 .12885 m .3648 .12749 L .36443 .12743 L F
.35864 .12952 m .3648 .12749 L .35956 .12885 L F
.36527 .13396 m .37136 .13116 L .36526 .12757 L .784 .994 0 r
F
.36018 .13433 m .36665 .1322 L .36443 .12743 L .927 .799 0 r
F
.35956 .12885 m .36443 .12743 L .3578 .11324 L F
.36018 .13433 m .36443 .12743 L .35956 .12885 L F
.35956 .12885 m .36443 .12743 L .36207 .12704 L .355 .199 0 r
F
.35766 .12934 m .35956 .12885 L .35763 .1293 L .927 .799 0 r
F
.36018 .13433 m .35956 .12885 L .35766 .12934 L F
.35956 .12885 m .3578 .11324 L .35763 .1293 L F
.35956 .12885 m .35989 .12861 L .35763 .1293 L .355 .199 0 r
F
.35763 .1293 m .36207 .12704 L .3553 .12879 L F
.35989 .12861 m .36207 .12704 L .35763 .1293 L F
.35264 .1311 m .35763 .1293 L .35262 .13083 L .76 .727 0 r
F
.35291 .13421 m .35763 .1293 L .35264 .1311 L F
.35264 .1311 m .35763 .1293 L .3553 .12879 L .39 .204 0 r
F
.35129 .13145 m .35264 .1311 L .35065 .13038 L .76 .727 0 r
F
.35291 .13421 m .35264 .1311 L .35129 .13145 L F
.35264 .1311 m .3514 .11699 L .35065 .13038 L F
.35264 .1311 m .35287 .13089 L .35065 .13038 L .39 .204 0 r
F
.35065 .13038 m .3553 .12879 L .3474 .12743 L F
.35287 .13089 m .3553 .12879 L .35065 .13038 L F
.34574 .13308 m .35065 .13038 L .34555 .12921 L .791 .862 0 r
F
.34582 .13494 m .35065 .13038 L .34574 .13308 L F
.34574 .13308 m .35065 .13038 L .3474 .12743 L .694 .899 0 r
F
.3447 .13326 m .34574 .13308 L .34404 .13228 L .791 .862 0 r
F
.34582 .13494 m .34574 .13308 L .3447 .13326 L F
.34574 .13308 m .34517 .12109 L .34404 .13228 L F
.34574 .13308 m .34581 .13283 L .34404 .13228 L .694 .899 0 r
F
.34404 .13228 m .3474 .12743 L .33978 .12726 L F
.34581 .13283 m .3474 .12743 L .34404 .13228 L F
.33911 .13523 m .34404 .13228 L .33893 .13069 L .91 1 0 r
F
.33918 .1371 m .34404 .13228 L .33911 .13523 L F
.33911 .13523 m .34404 .13228 L .33978 .12726 L .88 1 0 r
F
.33805 .13534 m .33911 .13523 L .33772 .13482 L .91 1 0 r
F
.33918 .1371 m .33911 .13523 L .33805 .13534 L F
.33754 .13482 m .33772 .13482 L .33749 .13475 L F
.33918 .1371 m .33772 .13482 L .33754 .13482 L F
.33911 .13523 m .33868 .1243 L .33749 .13475 L F
.33911 .13523 m .33913 .13498 L .33749 .13475 L .88 1 0 r
F
.33749 .13475 m .33978 .12726 L .33272 .12884 L F
.33913 .13498 m .33978 .12726 L .33749 .13475 L F
.3326 .13951 m .33263 .13721 L .33112 .13767 L .941 1 0 r
F
.33263 .13721 m .33223 .13714 L .33112 .13767 L F
.33277 .13994 m .33138 .137 L .33046 .13684 L .973 1 0 r
F
.33138 .137 m .33124 .1367 L .33046 .13684 L F
.33263 .13721 m .33263 .13695 L .33223 .13714 L .941 1 0 r
F
.33223 .13714 m .33263 .13695 L .33046 .13684 L F
.33263 .13721 m .33187 .13708 L .33149 .13724 L .973 1 0 r
F
.33277 .13994 m .33263 .13721 L .33149 .13724 L F
.33263 .13721 m .33749 .13475 L .33272 .12884 L .941 1 0 r
F
.33263 .13721 m .33808 .13556 L .33749 .13475 L .973 1 0 r
F
.33277 .13994 m .33918 .1371 L .33808 .13556 L F
.33277 .13994 m .33808 .13556 L .33263 .13721 L F
.33046 .13684 m .33272 .12884 L .32591 .13117 L .941 1 0 r
F
.33046 .13684 m .33124 .1367 L .33032 .13665 L .973 1 0 r
F
.33263 .13695 m .33272 .12884 L .33046 .13684 L .941 1 0 r
F
.32615 .1385 m .33046 .13684 L .32601 .13661 L 1 1 0 r
F
.32629 .14265 m .33046 .13684 L .32615 .1385 L .975 1 0 r
F
.32651 .14316 m .33046 .13684 L .32615 .1385 L 1 1 0 r
F
.32615 .1385 m .33046 .13684 L .32612 .1376 L .975 1 0 r
F
.32615 .1385 m .32615 .13826 L .32268 .13816 L F
.32268 .13816 m .32591 .13117 L .31925 .1339 L F
.32615 .13826 m .32591 .13117 L .32268 .13816 L F
.31959 .139 m .32248 .13815 L .3195 .13806 L 1 1 0 r
F
.32248 .13815 m .32264 .13811 L .3195 .13806 L F
.31412 .13864 m .31959 .139 L .31402 .13852 L F
.3154 .14023 m .31628 .13878 L .31412 .13864 L F
.32005 .14597 m .31959 .139 L .3154 .14023 L F
.31959 .139 m .31903 .1334 L .31402 .13852 L F
.31959 .139 m .31925 .1339 L .3154 .14023 L F
.32005 .14597 m .32268 .13816 L .31959 .139 L F
.31388 .14946 m .32005 .14597 L .31446 .13906 L F
.31288 .13885 m .31446 .13906 L .31412 .13864 L F
.31388 .14946 m .31446 .13906 L .31288 .13885 L F
.31428 .15029 m .32035 .14663 L .31412 .13864 L F
.31288 .13885 m .31406 .13856 L .31261 .13671 L F
.31288 .13885 m .31261 .13671 L .30953 .1384 L F
.31288 .13885 m .30953 .1384 L .30916 .1386 L F
.30649 .14039 m .30959 .13863 L .30621 .14005 L F
.30959 .13863 m .30916 .1386 L .30621 .14005 L F
.31288 .13885 m .31269 .13688 L .30649 .14039 L F
.30777 .15308 m .31388 .14946 L .30621 .14005 L F
.31288 .13885 m .30916 .1386 L .30627 .14018 L F
.30959 .13863 m .31269 .13688 L .30916 .1386 L F
.31388 .14946 m .31288 .13885 L .30649 .14039 L F
.31288 .13885 m .31412 .13864 L .31406 .13856 L F
.31428 .15029 m .31412 .13864 L .31288 .13885 L F
.31288 .13885 m .31412 .13864 L .31269 .13688 L F
.31428 .15029 m .31288 .13885 L .30627 .14018 L F
.32035 .14663 m .31959 .139 L .31412 .13864 L F
.31412 .13864 m .31925 .1339 L .31269 .13688 L F
.31628 .13878 m .31925 .1339 L .31412 .13864 L F
.31959 .139 m .32268 .13816 L .31957 .13868 L F
.32232 .13924 m .32364 .13935 L .32268 .13816 L F
.32035 .14663 m .32651 .14316 L .32268 .13816 L F
.32035 .14663 m .32268 .13816 L .31959 .139 L F
.31957 .13868 m .32268 .13816 L .31925 .1339 L F
.32285 .13839 m .32294 .13812 L .32268 .13816 L F
.32651 .14316 m .32615 .1385 L .32285 .13839 L F
.32612 .1376 m .33046 .13684 L .32591 .13117 L .975 1 0 r
F
.67627 .38256 m .65935 .38573 L .65814 .39183 L .255 .015 0 r
F
.67627 .38256 m .6777 .37634 L .65935 .38573 L F
.5 .72958 m .46592 .73189 L .4659 .73748 L .846 .331 0 r
F
.5 .72958 m .50009 .7242 L .46592 .73189 L F
.54366 .84967 m .50491 .84736 L .50441 .85142 L .736 .056 0 r
F
.54366 .84967 m .5447 .84558 L .50491 .84736 L F
.46745 .59237 m .4399 .58361 L .43915 .58961 L 1 .895 0 r
F
.46745 .59237 m .46753 .58721 L .4399 .58361 L F
.21264 .22877 m .20397 .20847 L .19853 .21331 L 1 1 0 r
F
.21264 .22877 m .21772 .22365 L .20397 .20847 L F
.18381 .26106 m .17261 .23885 L .16768 .2442 L F
.17929 .26669 m .18381 .26106 L .16768 .2442 L F
.10887 .51711 m .08029 .49277 L .07931 .49968 L 1 .947 0 r
F
.10809 .52396 m .10887 .51711 L .07931 .49968 L 1 .935 0 r
F
.44063 .57788 m .41059 .57781 L .40844 .58495 L .888 .772 0 r
F
.4399 .58361 m .44063 .57788 L .40844 .58495 L .868 .749 0 r
F
.13051 .4828 m .10332 .45926 L .10198 .46584 L 1 .985 0 r
F
.12942 .48932 m .13051 .4828 L .10198 .46584 L 1 .974 0 r
F
.58354 .84257 m .54571 .8414 L .5447 .84558 L .669 .049 0 r
F
.58354 .84257 m .58506 .83835 L .54571 .8414 L F
.19335 .71956 m .15485 .70254 L .15655 .70861 L 1 .544 0 r
F
.19491 .72544 m .19335 .71956 L .15655 .70861 L 1 .525 0 r
F
.53276 .70743 m .50025 .70766 L .50022 .71324 L .84 .339 0 r
F
.53276 .70743 m .53288 .70227 L .50025 .70766 L F
.17929 .26669 m .16768 .2442 L .16284 .24962 L 1 1 0 r
F
.17484 .27238 m .17929 .26669 L .16284 .24962 L F
.21772 .22365 m .20949 .20373 L .20397 .20847 L F
.21772 .22365 m .22287 .21861 L .20949 .20373 L F
.35858 .20298 m .3642 .20212 L .36873 .23105 L .505 .046 0 r
F
.35772 .18531 m .36344 .20342 L .35551 .19894 L .408 .021 0 r
F
.35772 .18531 m .36347 .18413 L .36344 .20342 L F
.46886 .464 m .44722 .46082 L .44708 .46412 L 1 .839 0 r
F
.46883 .46747 m .46886 .464 L .44708 .46412 L 1 .835 0 r
F
.54724 .52976 m .52115 .5288 L .52107 .53209 L .87 .345 0 r
F
.54724 .52976 m .5474 .52647 L .52115 .5288 L F
.1972 .70919 m .15978 .69199 L .16131 .69801 L 1 .568 0 r
F
.19862 .71503 m .1972 .70919 L .16131 .69801 L 1 .55 0 r
F
.34175 .14778 m .33918 .1371 L .33277 .13994 L .977 1 0 r
F
.34175 .14778 m .34765 .14437 L .33918 .1371 L F
.80831 .66678 m .77664 .67338 L .77533 .67943 L .325 .03 0 r
F
.80831 .66678 m .80978 .66061 L .77664 .67338 L F
.14955 .62964 m .11583 .609 L .1164 .61553 L 1 .751 0 r
F
.15016 .63603 m .14955 .62964 L .1164 .61553 L 1 .735 0 r
F
.17484 .27238 m .16284 .24962 L .15809 .25513 L 1 1 0 r
F
.17049 .27813 m .17484 .27238 L .15809 .25513 L F
.22287 .21861 m .2151 .19909 L .20949 .20373 L F
.22287 .21861 m .2281 .21365 L .2151 .19909 L F
.75968 .73168 m .72646 .73624 L .72464 .74172 L .374 .028 0 r
F
.75968 .73168 m .76177 .72609 L .72646 .73624 L F
.59768 .65631 m .56543 .65407 L .56544 .65889 L .826 .315 0 r
F
.59768 .65631 m .59791 .65178 L .56543 .65407 L F
.30505 .20685 m .30791 .20858 L .30123 .20964 L 0 0 0 r
F
.30505 .20685 m .31078 .20405 L .30791 .20858 L F
.3395 .82455 m .29823 .81513 L .30013 .81982 L 1 .215 0 r
F
.34098 .82907 m .3395 .82455 L .30013 .81982 L 1 .194 0 r
F
.69841 .54658 m .66764 .54995 L .66749 .55447 L .608 .123 0 r
F
.69841 .54658 m .6987 .54195 L .66764 .54995 L F
.46883 .46747 m .44708 .46412 L .44695 .46739 L 1 .835 0 r
F
.4688 .47091 m .46883 .46747 L .44695 .46739 L 1 .832 0 r
F
.565 .68303 m .53301 .6814 L .53302 .68664 L .84 .337 0 r
F
.565 .68303 m .56516 .6782 L .53301 .6814 L F
.34811 .20721 m .3558 .22754 L .35075 .22943 L .361 .019 0 r
F
.34811 .20721 m .35324 .20477 L .3558 .22754 L F
.17049 .27813 m .15809 .25513 L .15343 .2607 L 1 1 0 r
F
.16621 .28394 m .17049 .27813 L .15343 .2607 L F
.2281 .21365 m .2208 .19455 L .2151 .19909 L F
.2281 .21365 m .2334 .20878 L .2208 .19455 L F
.20822 .68016 m .16896 .66558 L .17032 .67138 L 1 .58 0 r
F
.20947 .68572 m .20822 .68016 L .17032 .67138 L 1 .567 0 r
F
.25814 .72282 m .21669 .7129 L .21833 .71821 L 1 .473 0 r
F
.2595 .72795 m .25814 .72282 L .21833 .71821 L 1 .46 0 r
F
.47264 .12041 m .46572 .11802 L .46473 .1246 L 1 1 0 r
F
.47264 .12041 m .47277 .11461 L .46572 .11802 L F
.57312 .51606 m .54785 .51638 L .54771 .51978 L .783 .252 0 r
F
.57312 .51606 m .57338 .51265 L .54785 .51638 L F
.69237 .20428 m .6767 .21046 L .6809 .21607 L .376 .327 0 r
F
.69661 .20987 m .6809 .21607 L .68495 .22177 L .365 .295 0 r
F
.69661 .20987 m .69237 .20428 L .6809 .21607 L F
.85293 .40249 m .82797 .41417 L .83004 .42079 L .291 .069 0 r
F
.85293 .40249 m .85071 .39587 L .82797 .41417 L F
.68797 .19879 m .67236 .20492 L .6767 .21046 L .387 .357 0 r
F
.69237 .20428 m .68797 .19879 L .6767 .21046 L .376 .327 0 r
F
.81205 .67595 m .77951 .68216 L .77817 .6883 L .336 .032 0 r
F
.81205 .67595 m .81355 .66968 L .77951 .68216 L F
.85792 .40859 m .83245 .42039 L .83453 .42706 L .294 .07 0 r
F
.85792 .40859 m .85567 .40192 L .83245 .42039 L F
.70068 .21556 m .68495 .22177 L .68887 .22754 L .353 .261 0 r
F
.70068 .21556 m .69661 .20987 L .68495 .22177 L F
.16621 .28394 m .15343 .2607 L .14885 .26634 L 1 1 0 r
F
.16203 .28982 m .16621 .28394 L .14885 .26634 L F
.6834 .19342 m .6679 .19947 L .67236 .20492 L .398 .386 0 r
F
.68797 .19879 m .6834 .19342 L .67236 .20492 L .387 .357 0 r
F
.2334 .20878 m .22657 .19012 L .2208 .19455 L 1 1 0 r
F
.2334 .20878 m .23876 .20398 L .22657 .19012 L F
.52088 .53859 m .49446 .53632 L .49442 .53956 L .945 .428 0 r
F
.52088 .53859 m .52098 .53536 L .49446 .53632 L F
.66504 .59462 m .6329 .59524 L .63275 .59965 L .708 .194 0 r
F
.66504 .59462 m .66542 .5902 L .6329 .59524 L F
.4688 .47091 m .44695 .46739 L .44683 .47064 L 1 .832 0 r
F
.46877 .47433 m .4688 .47091 L .44683 .47064 L 1 .829 0 r
F
.71372 .78312 m .67878 .78562 L .67683 .79069 L .45 .033 0 r
F
.71372 .78312 m .71603 .77794 L .67878 .78562 L F
.84926 .56832 m .82001 .57741 L .81981 .58397 L .282 .038 0 r
F
.84926 .56832 m .8495 .56167 L .82001 .57741 L F
.70457 .22136 m .68887 .22754 L .69264 .23339 L .339 .226 0 r
F
.70457 .22136 m .70068 .21556 L .68887 .22754 L F
.59868 .49348 m .5746 .495 L .57436 .49862 L .681 .143 0 r
F
.59868 .49348 m .59908 .48982 L .5746 .495 L F
.42971 .75694 m .42956 .75163 L .39099 .75968 L .916 .343 0 r
F
.46586 .74835 m .42956 .75163 L .42971 .75694 L .87 .324 0 r
F
.46586 .74835 m .46588 .74296 L .42956 .75163 L F
.67869 .18815 m .66331 .19411 L .6679 .19947 L .412 .412 0 r
F
.6834 .19342 m .67869 .18815 L .6679 .19947 L .398 .386 0 r
F
.46753 .58721 m .44063 .57788 L .4399 .58361 L 1 .914 0 r
F
.46753 .58721 m .4676 .58223 L .44063 .57788 L F
.39099 .75968 m .35017 .76061 L .35101 .7655 L .971 .364 0 r
F
.39145 .76474 m .39099 .75968 L .35101 .7655 L .969 .345 0 r
F
.42971 .75694 m .39099 .75968 L .39145 .76474 L .916 .343 0 r
F
.72704 .48331 m .70009 .48947 L .70009 .49439 L .453 .068 0 r
F
.72704 .48331 m .72703 .47829 L .70009 .48947 L F
.62407 .46403 m .60169 .46658 L .60122 .47063 L .547 .064 0 r
F
.62407 .46403 m .62476 .4599 L .60169 .46658 L F
.85423 .57629 m .82395 .5852 L .82375 .59185 L .295 .041 0 r
F
.85423 .57629 m .85445 .56953 L .82395 .5852 L F
.74244 .39103 m .72267 .39801 L .72326 .4037 L .28 .051 0 r
F
.74244 .39103 m .74174 .38535 L .72267 .39801 L F
.63094 .63042 m .59861 .62915 L .59853 .63366 L .776 .255 0 r
F
.63094 .63042 m .63129 .62604 L .59861 .62915 L F
.46477 .84653 m .46473 .84258 L .42504 .84185 L .859 .069 0 r
F
.50392 .84597 m .46473 .84258 L .46477 .84653 L .797 .062 0 r
F
.50392 .84597 m .50442 .84203 L .46473 .84258 L F
.1205 .5028 m .09401 .479 L .09275 .4857 L 1 .979 0 r
F
.11946 .50947 m .1205 .5028 L .09275 .4857 L 1 .968 0 r
F
.38371 .83151 m .34298 .82372 L .34448 .82808 L .992 .148 0 r
F
.38476 .83571 m .38371 .83151 L .34448 .82808 L .981 .127 0 r
F
.70827 .22725 m .69264 .23339 L .69625 .2393 L .325 .189 0 r
F
.70827 .22725 m .70457 .22136 L .69264 .23339 L F
.16203 .28982 m .14885 .26634 L .14437 .27205 L 1 1 0 r
F
.15793 .29575 m .16203 .28982 L .14437 .27205 L F
.29575 .79551 m .25549 .78383 L .25752 .78884 L 1 .31 0 r
F
.29745 .80034 m .29575 .79551 L .25752 .78884 L 1 .288 0 r
F
.23876 .20398 m .23242 .18581 L .22657 .19012 L 1 1 0 r
F
.23876 .20398 m .2442 .19927 L .23242 .18581 L F
.67383 .183 m .65859 .18884 L .66331 .19411 L .425 .437 0 r
F
.67869 .18815 m .67383 .183 L .66331 .19411 L .412 .412 0 r
F
.46877 .47433 m .44683 .47064 L .44671 .47387 L 1 .829 0 r
F
.46874 .47772 m .46877 .47433 L .44671 .47387 L 1 .826 0 r
F
.54706 .53302 m .52107 .53209 L .52098 .53536 L .865 .336 0 r
F
.54706 .53302 m .54724 .52976 L .52107 .53209 L F
.76216 .74139 m .72832 .7455 L .72646 .75106 L .383 .03 0 r
F
.76216 .74139 m .76429 .7357 L .72832 .7455 L F
.12942 .48932 m .10198 .46584 L .10075 .47242 L 1 .974 0 r
F
.12844 .49584 m .12942 .48932 L .10075 .47242 L 1 .963 0 r
F
.14376 .64596 m .10857 .62543 L .10943 .63204 L 1 .711 0 r
F
.14462 .6524 m .14376 .64596 L .10943 .63204 L 1 .694 0 r
F
.71179 .23324 m .69625 .2393 L .69972 .24528 L .31 .151 0 r
F
.71179 .23324 m .70827 .22725 L .69625 .2393 L F
.42435 .84722 m .38344 .84109 L .38453 .8453 L .927 .087 0 r
F
.42493 .85131 m .42435 .84722 L .38453 .8453 L .916 .076 0 r
F
.46467 .85197 m .42435 .84722 L .42493 .85131 L .864 .07 0 r
F
.6495 .42971 m .6296 .43291 L .62871 .43772 L .376 .039 0 r
F
.6495 .42971 m .65066 .42479 L .6296 .43291 L F
.66883 .17796 m .65376 .18366 L .65859 .18884 L .438 .461 0 r
F
.67383 .183 m .66883 .17796 L .65859 .18884 L .425 .437 0 r
F
.15793 .29575 m .14437 .27205 L .13998 .27783 L 1 1 0 r
F
.15392 .30174 m .15793 .29575 L .13998 .27783 L F
.10809 .52396 m .07931 .49968 L .07845 .50661 L 1 .935 0 r
F
.1074 .5308 m .10809 .52396 L .07845 .50661 L 1 .923 0 r
F
.2442 .19927 m .23835 .1816 L .23242 .18581 L 1 1 0 r
F
.2442 .19927 m .2497 .19465 L .23835 .1816 L F
.46874 .47772 m .44671 .47387 L .4466 .47708 L 1 .826 0 r
F
.46871 .48109 m .46874 .47772 L .4466 .47708 L 1 .824 0 r
F
.53261 .71255 m .50022 .71324 L .50017 .71875 L .828 .315 0 r
F
.53261 .71255 m .53276 .70743 L .50022 .71324 L F
.59741 .66084 m .56544 .65889 L .56542 .66371 L .814 .296 0 r
F
.59741 .66084 m .59768 .65631 L .56544 .65889 L F
.6978 .32629 m .68407 .32898 L .68374 .33602 L .142 .009 0 r
F
.6978 .32629 m .69824 .31918 L .68407 .32898 L F
.16036 .61184 m .12528 .59256 L .12585 .59887 L 1 .741 0 r
F
.16099 .61794 m .16036 .61184 L .12585 .59887 L 1 .726 0 r
F
.24808 .76312 m .20884 .749 L .21082 .75446 L 1 .417 0 r
F
.24983 .7684 m .24808 .76312 L .21082 .75446 L 1 .396 0 r
F
.85504 .40913 m .83004 .42079 L .83201 .42743 L .285 .067 0 r
F
.85504 .40913 m .85293 .40249 L .83004 .42079 L F
.71511 .2393 m .69972 .24528 L .70302 .25132 L .293 .113 0 r
F
.71511 .2393 m .71179 .23324 L .69972 .24528 L F
.306 .74878 m .26391 .7431 L .26549 .74806 L 1 .407 0 r
F
.30718 .75368 m .306 .74878 L .26549 .74806 L 1 .393 0 r
F
.56481 .68784 m .53302 .68664 L .53301 .69187 L .827 .315 0 r
F
.56481 .68784 m .565 .68303 L .53302 .68664 L F
.6981 .55118 m .66749 .55447 L .66732 .55898 L .603 .114 0 r
F
.6981 .55118 m .69841 .54658 L .66749 .55447 L F
.49988 .73488 m .4659 .73748 L .46588 .74296 L .836 .306 0 r
F
.49988 .73488 m .5 .72958 L .4659 .73748 L F
.6653 .80508 m .63002 .80659 L .62823 .81114 L .51 .034 0 r
F
.6653 .80508 m .66752 .80045 L .63002 .80659 L F
.86007 .41528 m .83453 .42706 L .83651 .43375 L .289 .067 0 r
F
.86007 .41528 m .85792 .40859 L .83453 .42706 L F
.6637 .17302 m .64882 .17857 L .65376 .18366 L .449 .483 0 r
F
.66883 .17796 m .6637 .17302 L .65376 .18366 L .438 .461 0 r
F
.52078 .5418 m .49442 .53956 L .49438 .54278 L .941 .419 0 r
F
.52078 .5418 m .52088 .53859 L .49442 .53956 L F
.57286 .51943 m .54771 .51978 L .54756 .52314 L .778 .245 0 r
F
.57286 .51943 m .57312 .51606 L .54771 .51978 L F
.62257 .8243 m .58631 .82458 L .58485 .82882 L .585 .04 0 r
F
.62257 .8243 m .62451 .82 L .58631 .82458 L F
.34765 .14437 m .34582 .13494 L .33918 .1371 L .931 1 0 r
F
.34765 .14437 m .35362 .1412 L .34582 .13494 L F
.15392 .30174 m .13998 .27783 L .13568 .28367 L 1 1 0 r
F
.2497 .19465 m .24433 .17748 L .23835 .1816 L F
.2497 .19465 m .25526 .19011 L .24433 .17748 L F
.46871 .48109 m .4466 .47708 L .4465 .48027 L 1 .824 0 r
F
.46868 .48444 m .46871 .48109 L .4465 .48027 L 1 .822 0 r
F
.4676 .58223 m .44132 .57242 L .44063 .57788 L 1 .932 0 r
F
.4676 .58223 m .46767 .57743 L .44132 .57242 L F
.54258 .84415 m .50442 .84203 L .50392 .84597 L .726 .054 0 r
F
.54258 .84415 m .54362 .84019 L .50442 .84203 L F
.31078 .20405 m .31465 .20785 L .30791 .20858 L .034 0 0 r
F
.31078 .20405 m .31661 .20153 L .31465 .20785 L F
.35017 .76061 m .30841 .75854 L .3097 .76335 L 1 .372 0 r
F
.35101 .7655 m .35017 .76061 L .3097 .76335 L 1 .356 0 r
F
.66462 .59902 m .63275 .59965 L .63258 .60405 L .7 .182 0 r
F
.66462 .59902 m .66504 .59462 L .63275 .59965 L F
.58183 .83706 m .54463 .83615 L .54362 .84019 L .656 .047 0 r
F
.58183 .83706 m .58336 .83298 L .54463 .83615 L F
.71825 .24543 m .70302 .25132 L .70617 .25741 L .276 .08 0 r
F
.71825 .24543 m .71511 .2393 L .70302 .25132 L F
.59829 .49708 m .57436 .49862 L .57412 .50219 L .677 .139 0 r
F
.59829 .49708 m .59868 .49348 L .57436 .49862 L F
.6637 .17302 m .65845 .16819 L .64882 .17857 L .449 .483 0 r
F
.67479 .38861 m .65814 .39183 L .65689 .39775 L .247 .012 0 r
F
.67479 .38861 m .67627 .38256 L .65814 .39183 L F
.74309 .39666 m .72326 .4037 L .72379 .40935 L .279 .05 0 r
F
.74309 .39666 m .74244 .39103 L .72326 .4037 L F
.46868 .48444 m .4465 .48027 L .4464 .48344 L 1 .822 0 r
F
.46865 .48777 m .46868 .48444 L .4464 .48344 L 1 .821 0 r
F
.54687 .53625 m .52098 .53536 L .52088 .53859 L .861 .328 0 r
F
.54687 .53625 m .54706 .53302 L .52098 .53536 L F
.72702 .48829 m .70009 .49439 L .70006 .49927 L .451 .067 0 r
F
.72702 .48829 m .72704 .48331 L .70009 .49439 L F
.63055 .63481 m .59853 .63366 L .59842 .63818 L .766 .239 0 r
F
.63055 .63481 m .63094 .63042 L .59853 .63366 L F
.15016 .63603 m .1164 .61553 L .11708 .62203 L 1 .735 0 r
F
.15086 .64238 m .15016 .63603 L .11708 .62203 L 1 .719 0 r
F
.25526 .19011 m .25035 .17343 L .24433 .17748 L 1 1 0 r
F
.25526 .19011 m .26088 .18565 L .25035 .17343 L F
.29462 .80554 m .25383 .79416 L .25596 .79918 L 1 .289 0 r
F
.2964 .81037 m .29462 .80554 L .25596 .79918 L 1 .267 0 r
F
.24597 .77341 m .20596 .75957 L .20809 .76505 L 1 .393 0 r
F
.24783 .7787 m .24597 .77341 L .20809 .76505 L 1 .373 0 r
F
.11946 .50947 m .09275 .4857 L .0916 .49241 L 1 .968 0 r
F
.11852 .51614 m .11946 .50947 L .0916 .49241 L 1 .956 0 r
F
.62341 .46807 m .60122 .47063 L .60076 .4746 L .543 .064 0 r
F
.62341 .46807 m .62407 .46403 L .60122 .47063 L F
.12844 .49584 m .10075 .47242 L .09963 .47902 L 1 .963 0 r
F
.12755 .50235 m .12844 .49584 L .09963 .47902 L 1 .952 0 r
F
.7212 .25163 m .70617 .25741 L .70917 .26355 L .257 .075 0 r
F
.7212 .25163 m .71825 .24543 L .70617 .25741 L F
.34152 .81929 m .30101 .80977 L .30287 .81438 L 1 .212 0 r
F
.34298 .82372 m .34152 .81929 L .30287 .81438 L 1 .191 0 r
F
.46865 .48777 m .4464 .48344 L .4463 .48659 L 1 .821 0 r
F
.46862 .49109 m .46865 .48777 L .4463 .48659 L 1 .82 0 r
F
.80675 .6729 m .77533 .67943 L .77394 .68543 L .32 .027 0 r
F
.80675 .6729 m .80831 .66678 L .77533 .67943 L F
.84891 .57496 m .81981 .58397 L .81951 .59051 L .277 .036 0 r
F
.84891 .57496 m .84926 .56832 L .81981 .58397 L F
.85704 .41579 m .83201 .42743 L .83388 .43409 L .28 .064 0 r
F
.85704 .41579 m .85504 .40913 L .83201 .42743 L F
.35324 .20477 m .36172 .22781 L .3558 .22754 L .411 .031 0 r
F
.35324 .20477 m .35858 .20298 L .36172 .22781 L F
.19862 .71503 m .16131 .69801 L .16293 .70399 L 1 .55 0 r
F
.20012 .72082 m .19862 .71503 L .16293 .70399 L 1 .531 0 r
F
.19491 .72544 m .15655 .70861 L .15835 .71464 L 1 .525 0 r
F
.19655 .73126 m .19491 .72544 L .15835 .71464 L 1 .506 0 r
F
.52066 .54497 m .49438 .54278 L .49433 .54596 L .937 .41 0 r
F
.52066 .54497 m .52078 .5418 L .49438 .54278 L F
.86211 .422 m .83651 .43375 L .83839 .44046 L .284 .065 0 r
F
.86211 .422 m .86007 .41528 L .83651 .43375 L F
.26088 .18565 m .25641 .16945 L .25035 .17343 L 1 1 0 r
F
.26088 .18565 m .26655 .18128 L .25641 .16945 L F
.5971 .66537 m .56542 .66371 L .56537 .66854 L .802 .277 0 r
F
.5971 .66537 m .59741 .66084 L .56542 .66371 L F
.8539 .58303 m .82375 .59185 L .82344 .59848 L .29 .039 0 r
F
.8539 .58303 m .85423 .57629 L .82375 .59185 L F
.46767 .57743 m .44197 .56726 L .44132 .57242 L 1 .947 0 r
F
.46767 .57743 m .46774 .5728 L .44197 .56726 L F
.70986 .7783 m .67577 .78119 L .6738 .78611 L .429 .029 0 r
F
.70986 .7783 m .71219 .77327 L .67577 .78119 L F
.57259 .52276 m .54756 .52314 L .5474 .52647 L .773 .237 0 r
F
.57259 .52276 m .57286 .51943 L .54756 .52314 L F
.41349 .11704 m .41214 .11102 L .4064 .11393 L .887 1 0 r
F
.1074 .5308 m .07845 .50661 L .0777 .51354 L 1 .923 0 r
F
.10682 .53764 m .1074 .5308 L .0777 .51354 L 1 .91 0 r
F
.20947 .68572 m .17032 .67138 L .17175 .67713 L 1 .567 0 r
F
.21079 .69123 m .20947 .68572 L .17175 .67713 L 1 .553 0 r
F
.46862 .49109 m .4463 .48659 L .44622 .48972 L 1 .82 0 r
F
.46859 .49439 m .46862 .49109 L .44622 .48972 L F
.38344 .84109 m .3425 .83351 L .34406 .83787 L .982 .133 0 r
F
.38453 .8453 m .38344 .84109 L .34406 .83787 L .972 .112 0 r
F
.69775 .55577 m .66732 .55898 L .66713 .56348 L .598 .105 0 r
F
.69775 .55577 m .6981 .55118 L .66732 .55898 L F
.56457 .69264 m .53301 .69187 L .53296 .69708 L .813 .292 0 r
F
.56457 .69264 m .56481 .68784 L .53301 .69187 L F
.3642 .20212 m .37706 .23837 L .36873 .23105 L .591 .06 0 r
F
.3642 .20212 m .37019 .20256 L .37706 .23837 L F
.37019 .20256 m .38676 .25058 L .37706 .23837 L .653 .071 0 r
F
.36347 .18413 m .37219 .21101 L .36344 .20342 L .532 .047 0 r
F
.37019 .20256 m .37663 .20476 L .38676 .25058 L .653 .071 0 r
F
.36347 .18413 m .36943 .18381 L .37219 .21101 L .532 .047 0 r
F
.53242 .71763 m .50017 .71875 L .50009 .7242 L .815 .29 0 r
F
.53242 .71763 m .53261 .71255 L .50017 .71875 L F
.72396 .25788 m .70917 .26355 L .71201 .26972 L .238 .07 0 r
F
.72396 .25788 m .7212 .25163 L .70917 .26355 L F
.81045 .68218 m .77817 .6883 L .77675 .69439 L .331 .03 0 r
F
.81045 .68218 m .81205 .67595 L .77817 .6883 L F
.75751 .73722 m .72464 .74172 L .72276 .74713 L .369 .026 0 r
F
.75751 .73722 m .75968 .73168 L .72464 .74172 L F
.46471 .85595 m .46467 .85197 L .42493 .85131 L .853 .068 0 r
F
.5039 .8554 m .46467 .85197 L .46471 .85595 L .793 .061 0 r
F
.5039 .8554 m .50441 .85142 L .46467 .85197 L F
.42989 .76214 m .42971 .75694 L .39145 .76474 L .913 .322 0 r
F
.46585 .75362 m .42971 .75694 L .42989 .76214 L .864 .301 0 r
F
.46585 .75362 m .46586 .74835 L .42971 .75694 L F
.26655 .18128 m .26249 .16551 L .25641 .16945 L 1 1 0 r
F
.26655 .18128 m .27228 .17699 L .26249 .16551 L F
.2595 .72795 m .21833 .71821 L .22003 .72347 L 1 .46 0 r
F
.26092 .73304 m .2595 .72795 L .22003 .72347 L 1 .447 0 r
F
.54668 .53945 m .52088 .53859 L .52078 .5418 L .857 .319 0 r
F
.54668 .53945 m .54687 .53625 L .52088 .53859 L F
.66612 .81495 m .63059 .8161 L .62876 .82071 L .518 .035 0 r
F
.66612 .81495 m .66839 .81025 L .63059 .8161 L F
.64839 .43449 m .62871 .43772 L .62784 .44239 L .373 .039 0 r
F
.64839 .43449 m .6495 .42971 L .62871 .43772 L F
.5979 .50063 m .57412 .50219 L .57388 .50572 L .672 .134 0 r
F
.5979 .50063 m .59829 .49708 L .57412 .50219 L F
.66417 .60341 m .63258 .60405 L .63237 .60845 L .692 .169 0 r
F
.66417 .60341 m .66462 .59902 L .63258 .60405 L F
.46859 .49439 m .44622 .48972 L .44613 .49283 L 1 .82 0 r
F
.46856 .49767 m .46859 .49439 L .44613 .49283 L 1 .821 0 r
F
.74369 .40224 m .72379 .40935 L .72428 .41494 L .279 .05 0 r
F
.74369 .40224 m .74309 .39666 L .72379 .40935 L F
.42504 .84185 m .38476 .83571 L .38584 .83982 L .924 .079 0 r
F
.42562 .84582 m .42504 .84185 L .38584 .83982 L .912 .075 0 r
F
.46477 .84653 m .42504 .84185 L .42562 .84582 L .859 .069 0 r
F
.35362 .1412 m .35291 .13421 L .34582 .13494 L .812 1 0 r
F
.35362 .1412 m .35967 .13827 L .35291 .13421 L F
.14462 .6524 m .10943 .63204 L .1104 .63861 L 1 .694 0 r
F
.14557 .65881 m .14462 .6524 L .1104 .63861 L 1 .677 0 r
F
.66495 .18389 m .65136 .18758 L .65579 .19321 L .339 .284 0 r
F
.66932 .18962 m .65579 .19321 L .66006 .19897 L .321 .24 0 r
F
.66932 .18962 m .66495 .18389 L .65579 .19321 L F
.72697 .49325 m .70006 .49927 L .70001 .50412 L .449 .067 0 r
F
.72697 .49325 m .72702 .48829 L .70006 .49927 L F
.67348 .19549 m .66006 .19897 L .66415 .20484 L .302 .194 0 r
F
.67348 .19549 m .66932 .18962 L .66006 .19897 L F
.69711 .33335 m .68374 .33602 L .68318 .34301 L .122 .001 0 r
F
.69711 .33335 m .6978 .32629 L .68374 .33602 L F
.63013 .63918 m .59842 .63818 L .59828 .64271 L .756 .224 0 r
F
.63013 .63918 m .63055 .63481 L .59842 .63818 L F
.39145 .76474 m .35101 .7655 L .35191 .77032 L .969 .345 0 r
F
.39195 .76971 m .39145 .76474 L .35191 .77032 L .966 .327 0 r
F
.42989 .76214 m .39145 .76474 L .39195 .76971 L .913 .322 0 r
F
.6604 .1783 m .64676 .18207 L .65136 .18758 L .356 .326 0 r
F
.66495 .18389 m .6604 .1783 L .65136 .18758 L .339 .284 0 r
F
.67744 .2015 m .66415 .20484 L .66806 .21082 L .282 .147 0 r
F
.67744 .2015 m .67348 .19549 L .66415 .20484 L F
.16099 .61794 m .12585 .59887 L .12651 .60515 L 1 .726 0 r
F
.1617 .62401 m .16099 .61794 L .12651 .60515 L 1 .712 0 r
F
.62297 .83408 m .58655 .83405 L .58506 .83835 L .589 .041 0 r
F
.62297 .83408 m .62495 .8297 L .58655 .83405 L F
.72654 .26417 m .71201 .26972 L .71469 .27593 L .218 .064 0 r
F
.72654 .26417 m .72396 .25788 L .71201 .26972 L F
.49975 .74011 m .46588 .74296 L .46586 .74835 L .827 .281 0 r
F
.49975 .74011 m .49988 .73488 L .46588 .74296 L F
.11852 .51614 m .0916 .49241 L .09056 .49914 L 1 .956 0 r
F
.11767 .52281 m .11852 .51614 L .09056 .49914 L 1 .944 0 r
F
.46856 .49767 m .44613 .49283 L .44606 .49591 L 1 .821 0 r
F
.46854 .50095 m .46856 .49767 L .44606 .49591 L 1 .823 0 r
F
.65565 .17286 m .64202 .17668 L .64676 .18207 L .372 .366 0 r
F
.6604 .1783 m .65565 .17286 L .64676 .18207 L .356 .326 0 r
F
.85893 .42248 m .83388 .43409 L .83564 .44076 L .274 .062 0 r
F
.85893 .42248 m .85704 .41579 L .83388 .43409 L F
.52054 .54812 m .49433 .54596 L .49427 .54912 L .933 .4 0 r
F
.52054 .54812 m .52066 .54497 L .49433 .54596 L F
.68118 .20763 m .66806 .21082 L .67178 .21692 L .26 .1 0 r
F
.68118 .20763 m .67744 .2015 L .66806 .21082 L F
.44132 .57242 m .41279 .57085 L .41059 .57781 L .917 .8 0 r
F
.44063 .57788 m .44132 .57242 L .41059 .57781 L .888 .772 0 r
F
.31661 .20153 m .32149 .20755 L .31465 .20785 L .173 0 0 r
F
.31661 .20153 m .32255 .19935 L .32149 .20755 L F
.86404 .42874 m .83839 .44046 L .84017 .44719 L .279 .063 0 r
F
.86404 .42874 m .86211 .422 L .83839 .44046 L F
.27228 .17699 m .2686 .16163 L .26249 .16551 L 1 1 0 r
F
.27228 .17699 m .27807 .17277 L .2686 .16163 L F
.12755 .50235 m .09963 .47902 L .09862 .48562 L 1 .952 0 r
F
.12675 .50887 m .12755 .50235 L .09862 .48562 L 1 .94 0 r
F
.62278 .47202 m .60076 .4746 L .60032 .47851 L .539 .064 0 r
F
.62278 .47202 m .62341 .46807 L .60076 .4746 L F
.65565 .17286 m .65073 .16757 L .64202 .17668 L .372 .366 0 r
F
.57231 .52606 m .5474 .52647 L .54724 .52976 L .769 .23 0 r
F
.57231 .52606 m .57259 .52276 L .5474 .52647 L F
.68469 .21389 m .67178 .21692 L .6753 .22314 L .237 .079 0 r
F
.68469 .21389 m .68118 .20763 L .67178 .21692 L F
.59675 .6699 m .56537 .66854 L .56528 .67337 L .789 .257 0 r
F
.59675 .6699 m .5971 .66537 L .56537 .66854 L F
.75993 .74702 m .72646 .75106 L .72453 .75656 L .378 .028 0 r
F
.75993 .74702 m .76216 .74139 L .72646 .75106 L F
.42225 .46458 m .40237 .45875 L .40181 .46206 L 1 .929 0 r
F
.42225 .46458 m .4226 .46114 L .40237 .45875 L F
.4219 .46801 m .42225 .46458 L .40181 .46206 L 1 .92 0 r
F
.5426 .85367 m .50441 .85142 L .5039 .8554 L .724 .053 0 r
F
.5426 .85367 m .54366 .84967 L .50441 .85142 L F
.71132 .78823 m .67683 .79069 L .67482 .79569 L .44 .03 0 r
F
.71132 .78823 m .71372 .78312 L .67683 .79069 L F
.46854 .50095 m .44606 .49591 L .44598 .49898 L 1 .823 0 r
F
.46851 .50422 m .46854 .50095 L .44598 .49898 L 1 .826 0 r
F
.4219 .46801 m .40181 .46206 L .40126 .46538 L 1 .92 0 r
F
.42157 .47144 m .4219 .46801 L .40126 .46538 L 1 .911 0 r
F
.58197 .84671 m .5447 .84558 L .54366 .84967 L .657 .046 0 r
F
.58197 .84671 m .58354 .84257 L .5447 .84558 L F
.29162 .24264 m .38012 .35786 L .37932 .36176 L .772 .208 0 r
F
.29162 .24264 m .30476 .25041 L .38012 .35786 L F
.42157 .47144 m .40126 .46538 L .40074 .4687 L 1 .911 0 r
F
.42125 .47487 m .42157 .47144 L .40074 .4687 L 1 .901 0 r
F
.34098 .82907 m .30013 .81982 L .30208 .82443 L 1 .194 0 r
F
.3425 .83351 m .34098 .82907 L .30208 .82443 L 1 .172 0 r
F
.42125 .47487 m .40074 .4687 L .40023 .47202 L 1 .901 0 r
F
.42095 .47828 m .42125 .47487 L .40023 .47202 L 1 .893 0 r
F
.69737 .56033 m .66713 .56348 L .66691 .56796 L .592 .096 0 r
F
.69737 .56033 m .69775 .55577 L .66713 .56348 L F
.15086 .64238 m .11708 .62203 L .11785 .62851 L 1 .719 0 r
F
.15165 .6487 m .15086 .64238 L .11785 .62851 L 1 .702 0 r
F
.47277 .11461 m .46673 .11169 L .46572 .11802 L 1 1 0 r
F
.47277 .11461 m .47291 .10895 L .46673 .11169 L F
.72894 .27048 m .71469 .27593 L .71722 .28216 L .198 .059 0 r
F
.72894 .27048 m .72654 .26417 L .71469 .27593 L F
.42095 .47828 m .40023 .47202 L .39975 .47534 L 1 .893 0 r
F
.42066 .48169 m .42095 .47828 L .39975 .47534 L 1 .884 0 r
F
.54647 .54262 m .52078 .5418 L .52066 .54497 L .852 .31 0 r
F
.54647 .54262 m .54668 .53945 L .52078 .5418 L F
.5643 .69741 m .53296 .69708 L .53288 .70227 L .799 .269 0 r
F
.5643 .69741 m .56457 .69264 L .53296 .69708 L F
.68797 .22026 m .6753 .22314 L .67861 .22946 L .213 .072 0 r
F
.68797 .22026 m .68469 .21389 L .6753 .22314 L F
.27807 .17277 m .27474 .1578 L .2686 .16163 L 1 1 0 r
F
.27807 .17277 m .2839 .16865 L .27474 .1578 L F
.84846 .58158 m .81951 .59051 L .81911 .59703 L .271 .033 0 r
F
.84846 .58158 m .84891 .57496 L .81951 .59051 L F
.67328 .39447 m .65689 .39775 L .65562 .4035 L .239 .01 0 r
F
.67328 .39447 m .67479 .38861 L .65689 .39775 L F
.10682 .53764 m .0777 .51354 L .07705 .52046 L 1 .91 0 r
F
.10634 .54448 m .10682 .53764 L .07705 .52046 L 1 .897 0 r
F
.46851 .50422 m .44598 .49898 L .44592 .50203 L 1 .826 0 r
F
.46848 .50748 m .46851 .50422 L .44592 .50203 L 1 .83 0 r
F
.30718 .75368 m .26549 .74806 L .26713 .75297 L 1 .393 0 r
F
.30841 .75854 m .30718 .75368 L .26713 .75297 L 1 .378 0 r
F
.42066 .48169 m .39975 .47534 L .39928 .47866 L 1 .884 0 r
F
.42038 .48509 m .42066 .48169 L .39928 .47866 L 1 .875 0 r
F
.29745 .80034 m .25752 .78884 L .25961 .79379 L 1 .288 0 r
F
.2992 .80509 m .29745 .80034 L .25961 .79379 L 1 .267 0 r
F
.74425 .40777 m .72428 .41494 L .72472 .42047 L .278 .049 0 r
F
.74425 .40777 m .74369 .40224 L .72428 .41494 L F
.59752 .50414 m .57388 .50572 L .57363 .50921 L .668 .129 0 r
F
.59752 .50414 m .5979 .50063 L .57388 .50572 L F
.85346 .58976 m .82344 .59848 L .82304 .60509 L .285 .036 0 r
F
.85346 .58976 m .8539 .58303 L .82344 .59848 L F
.66369 .60779 m .63237 .60845 L .63215 .61285 L .684 .157 0 r
F
.66369 .60779 m .66417 .60341 L .63237 .60845 L F
.42038 .48509 m .39928 .47866 L .39884 .48198 L 1 .875 0 r
F
.42011 .48849 m .42038 .48509 L .39884 .48198 L 1 .866 0 r
F
.24983 .7684 m .21082 .75446 L .21289 .75987 L 1 .396 0 r
F
.25165 .77361 m .24983 .7684 L .21289 .75987 L 1 .375 0 r
F
.5322 .72266 m .50009 .7242 L .5 .72958 L .803 .264 0 r
F
.5322 .72266 m .53242 .71763 L .50009 .7242 L F
.72688 .49817 m .70001 .50412 L .69993 .50894 L .446 .066 0 r
F
.72688 .49817 m .72697 .49325 L .70001 .50412 L F
.52041 .55124 m .49427 .54912 L .49422 .55226 L .929 .391 0 r
F
.52041 .55124 m .52054 .54812 L .49427 .54912 L F
.8607 .42918 m .83564 .44076 L .8373 .44745 L .268 .06 0 r
F
.8607 .42918 m .85893 .42248 L .83564 .44076 L F
.35101 .7655 m .3097 .76335 L .31104 .7681 L 1 .356 0 r
F
.35191 .77032 m .35101 .7655 L .31104 .7681 L 1 .339 0 r
F
.46848 .50748 m .44592 .50203 L .44585 .50507 L 1 .83 0 r
F
.46845 .51074 m .46848 .50748 L .44585 .50507 L 1 .835 0 r
F
.62968 .64355 m .59828 .64271 L .59811 .64724 L .745 .207 0 r
F
.62968 .64355 m .63013 .63918 L .59828 .64271 L F
.69101 .22674 m .67861 .22946 L .6817 .23589 L .188 .065 0 r
F
.69101 .22674 m .68797 .22026 L .67861 .22946 L F
.86587 .43551 m .84017 .44719 L .84184 .45394 L .274 .061 0 r
F
.86587 .43551 m .86404 .42874 L .84017 .44719 L F
.80508 .67898 m .77394 .68543 L .77246 .69139 L .315 .025 0 r
F
.80508 .67898 m .80675 .6729 L .77394 .68543 L F
.38476 .83571 m .34448 .82808 L .34603 .83235 L .981 .127 0 r
F
.38584 .83982 m .38476 .83571 L .34603 .83235 L .97 .106 0 r
F
.2839 .16865 m .28093 .15405 L .27474 .1578 L 1 1 0 r
F
.2839 .16865 m .28979 .16461 L .28093 .15405 L F
.73118 .27681 m .71722 .28216 L .7196 .2884 L .177 .053 0 r
F
.73118 .27681 m .72894 .27048 L .71722 .28216 L F
.11767 .52281 m .09056 .49914 L .08963 .50587 L 1 .944 0 r
F
.11693 .52949 m .11767 .52281 L .08963 .50587 L 1 .932 0 r
F
.57202 .52932 m .54724 .52976 L .54706 .53302 L .764 .222 0 r
F
.57202 .52932 m .57231 .52606 L .54724 .52976 L F
.35967 .13827 m .36018 .13433 L .35291 .13421 L .567 .56 0 r
F
.35967 .13827 m .36576 .13554 L .36018 .13433 L F
.2038 .25887 m .19186 .23636 L .18702 .24147 L 1 1 0 r
F
.2038 .25887 m .20849 .25375 L .19186 .23636 L F
.19921 .26408 m .2038 .25887 L .18702 .24147 L F
.64733 .43913 m .62784 .44239 L .62702 .44694 L .371 .038 0 r
F
.64733 .43913 m .64839 .43449 L .62784 .44239 L F
.19921 .26408 m .18702 .24147 L .18227 .24666 L 1 1 0 r
F
.19471 .26938 m .19921 .26408 L .18227 .24666 L F
.46481 .85039 m .46477 .84653 L .42562 .84582 L .847 .066 0 r
F
.50341 .84983 m .46477 .84653 L .46481 .85039 L .785 .059 0 r
F
.50341 .84983 m .50392 .84597 L .46477 .84653 L F
.35858 .20298 m .36873 .23105 L .36172 .22781 L .505 .046 0 r
F
.46845 .51074 m .44585 .50507 L .44579 .50808 L 1 .835 0 r
F
.46842 .51401 m .46845 .51074 L .44579 .50808 L 1 .841 0 r
F
.20849 .25375 m .19677 .23131 L .19186 .23636 L 1 1 0 r
F
.20849 .25375 m .21328 .24873 L .19677 .23131 L F
.12675 .50887 m .09862 .48562 L .09771 .49222 L 1 .94 0 r
F
.12606 .51538 m .12675 .50887 L .09771 .49222 L 1 .928 0 r
F
.19471 .26938 m .18227 .24666 L .17759 .25191 L 1 1 0 r
F
.19032 .27476 m .19471 .26938 L .17759 .25191 L F
.21328 .24873 m .20175 .22633 L .19677 .23131 L F
.21328 .24873 m .21817 .24382 L .20175 .22633 L F
.20012 .72082 m .16293 .70399 L .16465 .70993 L 1 .531 0 r
F
.2017 .72657 m .20012 .72082 L .16465 .70993 L 1 .512 0 r
F
.66302 .80963 m .62823 .81114 L .6264 .81561 L .499 .032 0 r
F
.66302 .80963 m .6653 .80508 L .62823 .81114 L F
.21079 .69123 m .17175 .67713 L .17327 .68284 L 1 .553 0 r
F
.21217 .69671 m .21079 .69123 L .17327 .68284 L 1 .538 0 r
F
.19032 .27476 m .17759 .25191 L .17299 .25722 L 1 1 0 r
F
.18602 .28022 m .19032 .27476 L .17299 .25722 L F
.62217 .4759 m .60032 .47851 L .5999 .48234 L .535 .063 0 r
F
.62217 .4759 m .62278 .47202 L .60032 .47851 L F
.59637 .67441 m .56528 .67337 L .56516 .6782 L .776 .236 0 r
F
.59637 .67441 m .59675 .6699 L .56528 .67337 L F
.21817 .24382 m .20679 .2214 L .20175 .22633 L 1 1 0 r
F
.21817 .24382 m .22319 .23903 L .20679 .2214 L F
.19655 .73126 m .15835 .71464 L .16023 .72061 L 1 .506 0 r
F
.19827 .73704 m .19655 .73126 L .16023 .72061 L 1 .486 0 r
F
.6938 .23333 m .6817 .23589 L .68455 .24242 L .162 .057 0 r
F
.6938 .23333 m .69101 .22674 L .6817 .23589 L F
.54625 .54576 m .52066 .54497 L .52054 .54812 L .848 .301 0 r
F
.54625 .54576 m .54647 .54262 L .52066 .54497 L F
.24783 .7787 m .20809 .76505 L .2103 .77047 L 1 .373 0 r
F
.24976 .78392 m .24783 .7787 L .2103 .77047 L 1 .351 0 r
F
.80875 .68837 m .77675 .69439 L .77524 .70044 L .327 .027 0 r
F
.80875 .68837 m .81045 .68218 L .77675 .69439 L F
.42493 .85131 m .38453 .8453 L .38565 .84943 L .916 .076 0 r
F
.42552 .85531 m .42493 .85131 L .38565 .84943 L .904 .073 0 r
F
.46471 .85595 m .42493 .85131 L .42552 .85531 L .853 .068 0 r
F
.46842 .51401 m .44579 .50808 L .44573 .51108 L 1 .841 0 r
F
.46839 .51728 m .46842 .51401 L .44573 .51108 L 1 .849 0 r
F
.18602 .28022 m .17299 .25722 L .16849 .26261 L 1 1 0 r
F
.18181 .28575 m .18602 .28022 L .16849 .26261 L F
.1617 .62401 m .12651 .60515 L .12726 .6114 L 1 .712 0 r
F
.1625 .63006 m .1617 .62401 L .12726 .6114 L 1 .698 0 r
F
.27484 .18088 m .27014 .16406 L .26452 .16857 L 1 1 0 r
F
.27484 .18088 m .27998 .17582 L .27014 .16406 L F
.27013 .1865 m .27484 .18088 L .26452 .16857 L F
.6962 .34032 m .68318 .34301 L .68241 .34992 L .104 0 0 r
F
.6962 .34032 m .69711 .33335 L .68318 .34301 L F
.69695 .56488 m .66691 .56796 L .66667 .57243 L .586 .087 0 r
F
.69695 .56488 m .69737 .56033 L .66691 .56796 L F
.62059 .82853 m .58485 .82882 L .58336 .83298 L .573 .037 0 r
F
.62059 .82853 m .62257 .8243 L .58485 .82882 L F
.43011 .76724 m .42989 .76214 L .39195 .76971 L .909 .301 0 r
F
.46584 .7588 m .42989 .76214 L .43011 .76724 L .858 .277 0 r
F
.46584 .7588 m .46585 .75362 L .42989 .76214 L F
.22319 .23903 m .21189 .21653 L .20679 .2214 L 1 1 0 r
F
.22319 .23903 m .22832 .23438 L .21189 .21653 L F
.14557 .65881 m .1104 .63861 L .11147 .64516 L 1 .677 0 r
F
.14662 .66517 m .14557 .65881 L .11147 .64516 L 1 .66 0 r
F
.27013 .1865 m .26452 .16857 L .25902 .17323 L 1 1 0 r
F
.26635 .19332 m .27013 .1865 L .25902 .17323 L F
.32255 .19935 m .32852 .20793 L .32149 .20755 L .292 0 0 r
F
.32255 .19935 m .32863 .1976 L .32852 .20793 L F
.28979 .16461 m .28716 .15039 L .28093 .15405 L 1 1 0 r
F
.28979 .16461 m .29573 .16066 L .28716 .15039 L F
.74476 .41325 m .72472 .42047 L .72511 .42596 L .278 .048 0 r
F
.74476 .41325 m .74425 .40777 L .72472 .42047 L F
.27998 .17582 m .27589 .1597 L .27014 .16406 L 1 1 0 r
F
.27998 .17582 m .28537 .17109 L .27589 .1597 L F
.18181 .28575 m .16849 .26261 L .16406 .26805 L F
.1777 .29134 m .18181 .28575 L .16406 .26805 L F
.59713 .5076 m .57363 .50921 L .57338 .51265 L .663 .124 0 r
F
.59713 .5076 m .59752 .50414 L .57363 .50921 L F
.49959 .74525 m .46586 .74835 L .46585 .75362 L .817 .256 0 r
F
.49959 .74525 m .49975 .74011 L .46586 .74835 L F
.2964 .81037 m .25596 .79918 L .25817 .80412 L 1 .267 0 r
F
.29823 .81513 m .2964 .81037 L .25817 .80412 L 1 .245 0 r
F
.73327 .28314 m .7196 .2884 L .72183 .29465 L .156 .048 0 r
F
.73327 .28314 m .73118 .27681 L .7196 .2884 L F
.46839 .51728 m .44573 .51108 L .44567 .51408 L 1 .849 0 r
F
.46836 .52056 m .46839 .51728 L .44567 .51408 L 1 .858 0 r
F
.49415 .55536 m .49422 .55226 L .46802 .55195 L 1 .469 0 r
F
.52027 .55433 m .49422 .55226 L .49415 .55536 L .925 .381 0 r
F
.52027 .55433 m .52041 .55124 L .49422 .55226 L F
.56398 .70217 m .53288 .70227 L .53276 .70743 L .785 .244 0 r
F
.56398 .70217 m .5643 .69741 L .53288 .70227 L F
.22832 .23438 m .21704 .21171 L .21189 .21653 L 1 1 0 r
F
.22832 .23438 m .23358 .22989 L .21704 .21171 L F
.26092 .73304 m .22003 .72347 L .2218 .72869 L 1 .447 0 r
F
.26239 .73809 m .26092 .73304 L .2218 .72869 L 1 .433 0 r
F
.86236 .43591 m .8373 .44745 L .83886 .45415 L .262 .057 0 r
F
.86236 .43591 m .8607 .42918 L .8373 .44745 L F
.66317 .61216 m .63215 .61285 L .63189 .61725 L .675 .143 0 r
F
.66317 .61216 m .66369 .60779 L .63215 .61285 L F
.1777 .29134 m .16406 .26805 L .15973 .27356 L 1 1 0 r
F
.17368 .297 m .1777 .29134 L .15973 .27356 L F
.72676 .50306 m .69993 .50894 L .69983 .51373 L .443 .065 0 r
F
.72676 .50306 m .72688 .49817 L .69993 .50894 L F
.10634 .54448 m .07705 .52046 L .07652 .52739 L 1 .897 0 r
F
.10596 .5513 m .10634 .54448 L .07652 .52739 L 1 .883 0 r
F
.75525 .7427 m .72276 .74713 L .72079 .75249 L .364 .023 0 r
F
.75525 .7427 m .75751 .73722 L .72276 .74713 L F
.86758 .44229 m .84184 .45394 L .84342 .4607 L .269 .059 0 r
F
.86758 .44229 m .86587 .43551 L .84184 .45394 L F
.40065 .11673 m .40041 .11026 L .39415 .11279 L .872 1 0 r
F
.40065 .11673 m .40635 .11363 L .40041 .11026 L F
.28537 .17109 m .28177 .15549 L .27589 .1597 L 1 1 0 r
F
.28537 .17109 m .29093 .16659 L .28177 .15549 L F
.54152 .84802 m .50392 .84597 L .50341 .84983 L .714 .051 0 r
F
.54152 .84802 m .54258 .84415 L .50392 .84597 L F
.70745 .78326 m .6738 .78611 L .67177 .79096 L .419 .026 0 r
F
.70745 .78326 m .70986 .7783 L .6738 .78611 L F
.58026 .84106 m .54362 .84019 L .54258 .84415 L .643 .044 0 r
F
.58026 .84106 m .58183 .83706 L .54362 .84019 L F
.46836 .52056 m .44567 .51408 L .44562 .51706 L 1 .858 0 r
F
.46833 .52386 m .46836 .52056 L .44562 .51706 L 1 .868 0 r
F
.69634 .24001 m .68455 .24242 L .68717 .24905 L .135 .049 0 r
F
.69634 .24001 m .6938 .23333 L .68455 .24242 L F
.4007 .11701 m .4005 .11071 L .39423 .1132 L .865 1 0 r
F
.4007 .11701 m .4064 .11393 L .4005 .11071 L F
.37663 .20476 m .39718 .26666 L .38676 .25058 L .694 .12 0 r
F
.36943 .18381 m .38187 .22256 L .37219 .21101 L .609 .064 0 r
F
.37663 .20476 m .38362 .20931 L .39718 .26666 L .694 .12 0 r
F
.36943 .18381 m .37563 .18466 L .38187 .22256 L .609 .064 0 r
F
.62918 .64791 m .59811 .64724 L .59791 .65178 L .734 .19 0 r
F
.62918 .64791 m .62968 .64355 L .59811 .64724 L F
.39195 .76971 m .35191 .77032 L .35287 .77506 L .966 .327 0 r
F
.3925 .7746 m .39195 .76971 L .35287 .77506 L .963 .307 0 r
F
.43011 .76724 m .39195 .76971 L .3925 .7746 L .909 .301 0 r
F
.8479 .58817 m .81911 .59703 L .81862 .60352 L .266 .031 0 r
F
.8479 .58817 m .84846 .58158 L .81911 .59703 L F
.57172 .53255 m .54706 .53302 L .54687 .53625 L .76 .214 0 r
F
.57172 .53255 m .57202 .52932 L .54706 .53302 L F
.19225 .27617 m .18239 .25564 L .17739 .26051 L 1 1 0 r
F
.19225 .27617 m .19689 .27104 L .18239 .25564 L F
.18771 .2814 m .19225 .27617 L .17739 .26051 L F
.23358 .22989 m .22223 .20691 L .21704 .21171 L F
.23358 .22989 m .23899 .22559 L .22223 .20691 L F
.34298 .82372 m .30287 .81438 L .30479 .81891 L 1 .191 0 r
F
.34448 .82808 m .34298 .82372 L .30479 .81891 L 1 .168 0 r
F
.17368 .297 m .15973 .27356 L .15549 .27914 L 1 1 0 r
F
.16975 .30272 m .17368 .297 L .15549 .27914 L F
.19689 .27104 m .18752 .25091 L .18239 .25564 L F
.19689 .27104 m .20163 .26601 L .18752 .25091 L F
.26635 .19332 m .25902 .17323 L .25365 .178 L F
.26416 .20207 m .26635 .19332 L .25365 .178 L F
.18771 .2814 m .17739 .26051 L .17251 .2655 L F
.18327 .28673 m .18771 .2814 L .17251 .2655 L F
.20163 .26601 m .19278 .24632 L .18752 .25091 L F
.20163 .26601 m .20649 .2611 L .19278 .24632 L F
.29573 .16066 m .29345 .14682 L .28716 .15039 L F
.29573 .16066 m .30172 .15681 L .29345 .14682 L F
.15165 .6487 m .11785 .62851 L .11873 .63497 L 1 .702 0 r
F
.15254 .655 m .15165 .6487 L .11873 .63497 L 1 .685 0 r
F
.46833 .52386 m .44562 .51706 L .44555 .52004 L 1 .868 0 r
F
.4683 .52719 m .46833 .52386 L .44555 .52004 L 1 .879 0 r
F
.49415 .55536 m .46802 .55195 L .46801 .55508 L 1 .469 0 r
F
.18327 .28673 m .17251 .2655 L .16774 .27059 L 1 1 0 r
F
.17893 .29213 m .18327 .28673 L .16774 .27059 L F
.85291 .59647 m .82304 .60509 L .82254 .61167 L .281 .034 0 r
F
.85291 .59647 m .85346 .58976 L .82304 .60509 L F
.11693 .52949 m .08963 .50587 L .0888 .51261 L 1 .932 0 r
F
.11628 .53616 m .11693 .52949 L .0888 .51261 L 1 .919 0 r
F
.53194 .72764 m .5 .72958 L .49988 .73488 L .79 .238 0 r
F
.53194 .72764 m .5322 .72266 L .5 .72958 L F
.20649 .2611 m .19819 .24189 L .19278 .24632 L 1 1 0 r
F
.20649 .2611 m .21145 .25631 L .19819 .24189 L F
.29093 .16659 m .28775 .15144 L .28177 .15549 L F
.29093 .16659 m .29661 .16227 L .28775 .15144 L F
.17893 .29213 m .16774 .27059 L .16308 .27579 L F
.17468 .29762 m .17893 .29213 L .16308 .27579 L F
.54602 .54887 m .52054 .54812 L .52041 .55124 L .843 .291 0 r
F
.54602 .54887 m .54625 .54576 L .52054 .54812 L F
.12606 .51538 m .09771 .49222 L .0969 .49883 L 1 .928 0 r
F
.12546 .52188 m .12606 .51538 L .0969 .49883 L 1 .916 0 r
F
.4683 .52719 m .44555 .52004 L .44548 .52304 L 1 .879 0 r
F
.46827 .53055 m .4683 .52719 L .44548 .52304 L 1 .892 0 r
F
.16975 .30272 m .15549 .27914 L .15134 .28477 L 1 1 0 r
F
.16592 .3085 m .16975 .30272 L .15134 .28477 L F
.7352 .28947 m .72183 .29465 L .72392 .30091 L .136 .043 0 r
F
.7352 .28947 m .73327 .28314 L .72183 .29465 L F
.67178 .40016 m .65562 .4035 L .65435 .40908 L .232 .008 0 r
F
.67178 .40016 m .67328 .39447 L .65562 .4035 L F
.21145 .25631 m .20376 .23766 L .19819 .24189 L 1 1 0 r
F
.21145 .25631 m .21653 .25165 L .20376 .23766 L F
.23899 .22559 m .22744 .20214 L .22223 .20691 L F
.23899 .22559 m .24455 .22151 L .22744 .20214 L F
.17468 .29762 m .16308 .27579 L .15853 .28108 L F
.17054 .30318 m .17468 .29762 L .15853 .28108 L F
.62158 .47971 m .5999 .48234 L .59948 .48611 L .531 .063 0 r
F
.62158 .47971 m .62217 .4759 L .5999 .48234 L F
.59594 .67891 m .56516 .6782 L .565 .68303 L .763 .215 0 r
F
.59594 .67891 m .59637 .67441 L .56516 .6782 L F
.69651 .56941 m .66667 .57243 L .6664 .57689 L .579 .078 0 r
F
.69651 .56941 m .69695 .56488 L .66667 .57243 L F
.69862 .24679 m .68717 .24905 L .68953 .25578 L .107 .041 0 r
F
.69862 .24679 m .69634 .24001 L .68717 .24905 L F
.49409 .55844 m .49415 .55536 L .46801 .55508 L .996 .459 0 r
F
.52012 .55739 m .49415 .55536 L .49409 .55844 L .921 .371 0 r
F
.52012 .55739 m .52027 .55433 L .49415 .55536 L F
.36576 .13554 m .36665 .1322 L .36018 .13433 L .525 .427 0 r
F
.36576 .13554 m .37187 .13292 L .36665 .1322 L F
.74524 .41868 m .72511 .42596 L .72546 .43139 L .278 .048 0 r
F
.74524 .41868 m .74476 .41325 L .72511 .42596 L F
.59674 .51102 m .57338 .51265 L .57312 .51606 L .659 .119 0 r
F
.59674 .51102 m .59713 .5076 L .57338 .51265 L F
.66379 .81958 m .62876 .82071 L .62688 .82525 L .507 .033 0 r
F
.66379 .81958 m .66612 .81495 L .62876 .82071 L F
.21653 .25165 m .20952 .23365 L .20376 .23766 L 1 1 0 r
F
.21653 .25165 m .22173 .24714 L .20952 .23365 L F
.64631 .44364 m .62702 .44694 L .62623 .45137 L .368 .038 0 r
F
.64631 .44364 m .64733 .43913 L .62702 .44694 L F
.17054 .30318 m .15853 .28108 L .15408 .28645 L 1 1 0 r
F
.16648 .30882 m .17054 .30318 L .15408 .28645 L F
.75762 .75259 m .72453 .75656 L .72252 .762 L .373 .025 0 r
F
.75762 .75259 m .75993 .74702 L .72453 .75656 L F
.38453 .8453 m .34406 .83787 L .34567 .84215 L .972 .112 0 r
F
.38565 .84943 m .38453 .8453 L .34567 .84215 L .96 .091 0 r
F
.16592 .3085 m .15134 .28477 L .14728 .29047 L 1 1 0 r
F
.16218 .31434 m .16592 .3085 L .14728 .29047 L F
.29661 .16227 m .29383 .14754 L .28775 .15144 L F
.29661 .16227 m .30241 .15812 L .29383 .14754 L F
.30172 .15681 m .2998 .14337 L .29345 .14682 L F
.30172 .15681 m .30777 .15308 L .2998 .14337 L F
.86391 .44265 m .83886 .45415 L .84032 .46086 L .256 .055 0 r
F
.86391 .44265 m .86236 .43591 L .83886 .45415 L F
.86918 .4491 m .84342 .4607 L .8449 .46747 L .264 .057 0 r
F
.86918 .4491 m .86758 .44229 L .84342 .4607 L F
.16648 .30882 m .15408 .28645 L .14974 .29191 L 1 1 0 r
F
.16253 .31452 m .16648 .30882 L .14974 .29191 L F
.72661 .50793 m .69983 .51373 L .69971 .5185 L .44 .064 0 r
F
.72661 .50793 m .72676 .50306 L .69983 .51373 L F
.24455 .22151 m .23267 .19735 L .22744 .20214 L 1 1 0 r
F
.24455 .22151 m .25027 .21766 L .23267 .19735 L F
.30841 .75854 m .26713 .75297 L .26883 .75783 L 1 .378 0 r
F
.3097 .76335 m .30841 .75854 L .26883 .75783 L 1 .363 0 r
F
.22173 .24714 m .21548 .22991 L .20952 .23365 L 1 1 0 r
F
.22173 .24714 m .22706 .2428 L .21548 .22991 L F
.66262 .61651 m .63189 .61725 L .6316 .62164 L .666 .129 0 r
F
.66262 .61651 m .66317 .61216 L .63189 .61725 L F
.80332 .68502 m .77246 .69139 L .7709 .6973 L .309 .022 0 r
F
.80332 .68502 m .80508 .67898 L .77246 .69139 L F
.49409 .55844 m .46801 .55508 L .468 .55818 L .996 .459 0 r
F
.57141 .53575 m .54687 .53625 L .54668 .53945 L .755 .206 0 r
F
.57141 .53575 m .57172 .53255 L .54687 .53625 L F
.46476 .85984 m .46471 .85595 L .42552 .85531 L .841 .065 0 r
F
.50337 .8593 m .46471 .85595 L .46476 .85984 L .781 .059 0 r
F
.50337 .8593 m .5039 .8554 L .46471 .85595 L F
.70886 .79327 m .67482 .79569 L .67274 .80062 L .43 .028 0 r
F
.70886 .79327 m .71132 .78823 L .67482 .79569 L F
.16218 .31434 m .14728 .29047 L .14331 .29622 L 1 1 0 r
F
.56362 .7069 m .53276 .70743 L .53261 .71255 L .771 .22 0 r
F
.56362 .7069 m .56398 .70217 L .53276 .70743 L F
.42562 .84582 m .38584 .83982 L .38694 .84386 L .912 .075 0 r
F
.42621 .84972 m .42562 .84582 L .38694 .84386 L .901 .072 0 r
F
.46481 .85039 m .42562 .84582 L .42621 .84972 L .847 .066 0 r
F
.737 .29577 m .72392 .30091 L .72588 .30716 L .116 .038 0 r
F
.737 .29577 m .7352 .28947 L .72392 .30091 L F
.1625 .63006 m .12726 .6114 L .12811 .61763 L 1 .698 0 r
F
.16337 .63606 m .1625 .63006 L .12811 .61763 L 1 .683 0 r
F
.62093 .83837 m .58506 .83835 L .58354 .84257 L .578 .038 0 r
F
.62093 .83837 m .62297 .83408 L .58506 .83835 L F
.16253 .31452 m .14974 .29191 L .1455 .29745 L 1 1 0 r
F
.15867 .32029 m .16253 .31452 L .1455 .29745 L F
.62865 .65226 m .59791 .65178 L .59768 .65631 L .723 .172 0 r
F
.62865 .65226 m .62918 .64791 L .59791 .65178 L F
.10596 .5513 m .07652 .52739 L .07611 .53432 L 1 .883 0 r
F
.10568 .55812 m .10596 .5513 L .07611 .53432 L 1 .869 0 r
F
.30241 .15812 m .30001 .14379 L .29383 .14754 L 1 1 0 r
F
.30241 .15812 m .3083 .15413 L .30001 .14379 L F
.6951 .34719 m .68241 .34992 L .68144 .35673 L .086 0 0 r
F
.6951 .34719 m .6962 .34032 L .68241 .34992 L F
.35191 .77032 m .31104 .7681 L .31243 .77279 L 1 .339 0 r
F
.35287 .77506 m .35191 .77032 L .31243 .77279 L 1 .322 0 r
F
.32863 .1976 m .33588 .20932 L .32852 .20793 L .392 0 0 r
F
.32863 .1976 m .33489 .19642 L .33588 .20932 L F
.22706 .2428 m .2217 .2265 L .21548 .22991 L 1 1 0 r
F
.22706 .2428 m .23252 .23863 L .2217 .2265 L F
.54578 .55195 m .52041 .55124 L .52027 .55433 L .839 .281 0 r
F
.54578 .55195 m .54602 .54887 L .52041 .55124 L F
.44834 .43714 m .44852 .43366 L .43001 .43407 L 1 .92 0 r
F
.44197 .56726 m .41504 .56409 L .41279 .57085 L .956 .835 0 r
F
.44132 .57242 m .44197 .56726 L .41279 .57085 L .917 .8 0 r
F
.21217 .69671 m .17327 .68284 L .17487 .68851 L 1 .538 0 r
F
.21361 .70215 m .21217 .69671 L .17487 .68851 L 1 .524 0 r
F
.25165 .77361 m .21289 .75987 L .21503 .76521 L 1 .375 0 r
F
.25354 .77875 m .25165 .77361 L .21503 .76521 L 1 .354 0 r
F
.44834 .43714 m .43001 .43407 L .42965 .43733 L 1 .92 0 r
F
.44816 .44059 m .44834 .43714 L .42965 .43733 L 1 .911 0 r
F
.70062 .25365 m .68953 .25578 L .69164 .26259 L .079 .032 0 r
F
.70062 .25365 m .69862 .24679 L .68953 .25578 L F
.44816 .44059 m .42965 .43733 L .4293 .44058 L 1 .911 0 r
F
.44799 .44402 m .44816 .44059 L .4293 .44058 L 1 .903 0 r
F
.14662 .66517 m .11147 .64516 L .11265 .65167 L 1 .66 0 r
F
.14776 .67151 m .14662 .66517 L .11265 .65167 L 1 .642 0 r
F
.30777 .15308 m .30621 .14005 L .2998 .14337 L 1 1 0 r
F
.26416 .20207 m .25365 .178 L .24835 .18285 L F
.26119 .20947 m .26416 .20207 L .24835 .18285 L F
.25027 .21766 m .23789 .19255 L .23267 .19735 L F
.25027 .21766 m .25603 .21391 L .23789 .19255 L F
.11628 .53616 m .0888 .51261 L .08808 .51935 L 1 .919 0 r
F
.11574 .54283 m .11628 .53616 L .08808 .51935 L 1 .906 0 r
F
.2017 .72657 m .16465 .70993 L .16646 .71581 L 1 .512 0 r
F
.20337 .73225 m .2017 .72657 L .16646 .71581 L 1 .492 0 r
F
.44799 .44402 m .4293 .44058 L .42896 .44382 L 1 .903 0 r
F
.44782 .44743 m .44799 .44402 L .42896 .44382 L 1 .895 0 r
F
.80695 .69451 m .77524 .70044 L .77364 .70644 L .322 .025 0 r
F
.80695 .69451 m .80875 .68837 L .77524 .70044 L F
.2992 .80509 m .25961 .79379 L .26177 .79866 L 1 .267 0 r
F
.30101 .80977 m .2992 .80509 L .26177 .79866 L 1 .244 0 r
F
.15867 .32029 m .1455 .29745 L .14137 .30307 L 1 1 0 r
F
.49942 .75031 m .46585 .75362 L .46584 .7588 L .807 .231 0 r
F
.49942 .75031 m .49959 .74525 L .46585 .75362 L F
.12546 .52188 m .0969 .49883 L .09621 .50543 L 1 .916 0 r
F
.12496 .52838 m .12546 .52188 L .09621 .50543 L 1 .903 0 r
F
.49402 .5615 m .49409 .55844 L .468 .55818 L .993 .449 0 r
F
.51996 .56043 m .49409 .55844 L .49402 .5615 L .917 .36 0 r
F
.51996 .56043 m .52012 .55739 L .49409 .55844 L F
.3425 .83351 m .30208 .82443 L .30408 .82895 L 1 .172 0 r
F
.34406 .83787 m .3425 .83351 L .30408 .82895 L 1 .149 0 r
F
.44782 .44743 m .42896 .44382 L .42864 .44705 L 1 .895 0 r
F
.44766 .45081 m .44782 .44743 L .42864 .44705 L 1 .887 0 r
F
.47291 .10895 m .46777 .10559 L .46673 .11169 L 1 1 0 r
F
.47291 .10895 m .47305 .10344 L .46777 .10559 L F
.37136 .13116 m .37191 .12584 L .36526 .12757 L .688 .886 0 r
F
.37136 .13116 m .3775 .1286 L .37191 .12584 L F
.84724 .59475 m .81862 .60352 L .81803 .60999 L .261 .028 0 r
F
.84724 .59475 m .8479 .58817 L .81862 .60352 L F
.59635 .5144 m .57312 .51606 L .57286 .51943 L .654 .113 0 r
F
.59635 .5144 m .59674 .51102 L .57312 .51606 L F
.74567 .42407 m .72546 .43139 L .72577 .43678 L .278 .047 0 r
F
.74567 .42407 m .74524 .41868 L .72546 .43139 L F
.62101 .48346 m .59948 .48611 L .59908 .48982 L .527 .063 0 r
F
.62101 .48346 m .62158 .47971 L .59948 .48611 L F
.43034 .77223 m .43011 .76724 L .3925 .7746 L .904 .279 0 r
F
.46583 .76387 m .43011 .76724 L .43034 .77223 L .851 .253 0 r
F
.46583 .76387 m .46584 .7588 L .43011 .76724 L F
.19827 .73704 m .16023 .72061 L .16221 .72653 L 1 .486 0 r
F
.20007 .74276 m .19827 .73704 L .16221 .72653 L 1 .466 0 r
F
.44766 .45081 m .42864 .44705 L .42833 .45026 L 1 .887 0 r
F
.44751 .45417 m .44766 .45081 L .42833 .45026 L 1 .879 0 r
F
.69602 .57392 m .6664 .57689 L .6661 .58134 L .573 .072 0 r
F
.69602 .57392 m .69651 .56941 L .6664 .57689 L F
.58037 .85076 m .54366 .84967 L .5426 .85367 L .645 .044 0 r
F
.58037 .85076 m .58197 .84671 L .54366 .84967 L F
.23252 .23863 m .22822 .22351 L .2217 .2265 L 1 1 0 r
F
.23252 .23863 m .23812 .23467 L .22822 .22351 L F
.59547 .68339 m .565 .68303 L .56481 .68784 L .749 .193 0 r
F
.59547 .68339 m .59594 .67891 L .565 .68303 L F
.54152 .85759 m .5039 .8554 L .50337 .8593 L .712 .05 0 r
F
.54152 .85759 m .5426 .85367 L .5039 .8554 L F
.3083 .15413 m .30627 .14018 L .30001 .14379 L 1 1 0 r
F
.3083 .15413 m .31428 .15029 L .30627 .14018 L F
.86534 .4494 m .84032 .46086 L .84167 .46759 L .25 .053 0 r
F
.86534 .4494 m .86391 .44265 L .84032 .46086 L F
.85225 .60316 m .82254 .61167 L .82194 .61824 L .276 .032 0 r
F
.85225 .60316 m .85291 .59647 L .82254 .61167 L F
.44751 .45417 m .42833 .45026 L .42804 .45346 L 1 .879 0 r
F
.44736 .45751 m .44751 .45417 L .42804 .45346 L 1 .871 0 r
F
.53164 .73256 m .49988 .73488 L .49975 .74011 L .777 .212 0 r
F
.53164 .73256 m .53194 .72764 L .49988 .73488 L F
.40635 .11363 m .40671 .10797 L .40041 .11026 L .829 1 0 r
F
.49402 .5615 m .468 .55818 L .46798 .56125 L .993 .449 0 r
F
.73867 .30205 m .72588 .30716 L .7277 .31339 L .098 .033 0 r
F
.73867 .30205 m .737 .29577 L .72588 .30716 L F
.87068 .45592 m .8449 .46747 L .84627 .47426 L .259 .055 0 r
F
.87068 .45592 m .86918 .4491 L .8449 .46747 L F
.15254 .655 m .11873 .63497 L .11971 .64139 L 1 .685 0 r
F
.15351 .66125 m .15254 .655 L .11971 .64139 L 1 .668 0 r
F
.4064 .11393 m .4068 .10847 L .4005 .11071 L .817 1 0 r
F
.4064 .11393 m .41214 .11102 L .4068 .10847 L F
.72643 .51277 m .69971 .5185 L .69956 .52324 L .436 .063 0 r
F
.72643 .51277 m .72661 .50793 L .69971 .5185 L F
.40197 .12352 m .40772 .12135 L .40292 .12336 L 0 0 0 r
F
.40197 .12352 m .40292 .12336 L .39638 .12342 L F
.44736 .45751 m .42804 .45346 L .42776 .45665 L 1 .871 0 r
F
.44722 .46082 m .44736 .45751 L .42776 .45665 L 1 .864 0 r
F
.57109 .53891 m .54668 .53945 L .54647 .54262 L .75 .197 0 r
F
.57109 .53891 m .57141 .53575 L .54668 .53945 L F
.25603 .21391 m .24311 .18771 L .23789 .19255 L 1 1 0 r
F
.25603 .21391 m .26119 .20947 L .24311 .18771 L F
.26239 .73809 m .2218 .72869 L .22364 .73387 L 1 .433 0 r
F
.26391 .7431 m .26239 .73809 L .22364 .73387 L 1 .418 0 r
F
.24976 .78392 m .2103 .77047 L .21258 .77582 L 1 .351 0 r
F
.25176 .78907 m .24976 .78392 L .21258 .77582 L 1 .329 0 r
F
.64534 .44803 m .62623 .45137 L .62548 .45569 L .366 .038 0 r
F
.64534 .44803 m .64631 .44364 L .62623 .45137 L F
.66202 .62085 m .6316 .62164 L .63129 .62604 L .657 .115 0 r
F
.66202 .62085 m .66262 .61651 L .6316 .62164 L F
.37187 .13292 m .37291 .12937 L .36665 .1322 L .535 .513 0 r
F
.37187 .13292 m .37799 .13044 L .37291 .12937 L F
.44722 .46082 m .42776 .45665 L .42749 .45982 L 1 .864 0 r
F
.44708 .46412 m .44722 .46082 L .42749 .45982 L 1 .856 0 r
F
.23812 .23467 m .23511 .22106 L .22822 .22351 L .996 1 0 r
F
.23812 .23467 m .24386 .23094 L .23511 .22106 L F
.70235 .26059 m .69164 .26259 L .69347 .26949 L .05 .023 0 r
F
.70235 .26059 m .70062 .25365 L .69164 .26259 L F
.67029 .40567 m .65435 .40908 L .65309 .41448 L .226 .006 0 r
F
.67029 .40567 m .67178 .40016 L .65435 .40908 L F
.54552 .55499 m .52027 .55433 L .52012 .55739 L .834 .272 0 r
F
.54552 .55499 m .54578 .55195 L .52027 .55433 L F
.66068 .8141 m .6264 .81561 L .62451 .82 L .487 .029 0 r
F
.66068 .8141 m .66302 .80963 L .6264 .81561 L F
.75291 .74811 m .72079 .75249 L .71876 .75778 L .359 .02 0 r
F
.75291 .74811 m .75525 .7427 L .72079 .75249 L F
.26119 .20947 m .24835 .18285 L .24311 .18771 L 1 1 0 r
F
.38584 .83982 m .34603 .83235 L .34762 .83654 L .97 .106 0 r
F
.38694 .84386 m .38584 .83982 L .34762 .83654 L .959 .085 0 r
F
.44708 .46412 m .42749 .45982 L .42724 .46298 L 1 .856 0 r
F
.44695 .46739 m .44708 .46412 L .42724 .46298 L 1 .849 0 r
F
.3925 .7746 m .35287 .77506 L .35387 .77974 L .963 .307 0 r
F
.3931 .77939 m .3925 .7746 L .35387 .77974 L .959 .287 0 r
F
.43034 .77223 m .3925 .7746 L .3931 .77939 L .904 .279 0 r
F
.62808 .6566 m .59768 .65631 L .59741 .66084 L .711 .154 0 r
F
.62808 .6566 m .62865 .65226 L .59768 .65631 L F
.56322 .7116 m .53261 .71255 L .53242 .71763 L .756 .194 0 r
F
.56322 .7116 m .56362 .7069 L .53261 .71255 L F
.49394 .56452 m .49402 .5615 L .46798 .56125 L .989 .438 0 r
F
.51979 .56343 m .49402 .5615 L .49394 .56452 L .913 .35 0 r
F
.51979 .56343 m .51996 .56043 L .49402 .5615 L F
.10568 .55812 m .07611 .53432 L .0758 .54124 L 1 .869 0 r
F
.1055 .56493 m .10568 .55812 L .0758 .54124 L 1 .855 0 r
F
.44695 .46739 m .42724 .46298 L .42701 .46612 L 1 .849 0 r
F
.44683 .47064 m .44695 .46739 L .42701 .46612 L 1 .842 0 r
F
.59595 .51773 m .57286 .51943 L .57259 .52276 L .65 .107 0 r
F
.59595 .51773 m .59635 .5144 L .57286 .51943 L F
.74607 .42942 m .72577 .43678 L .72605 .44212 L .279 .047 0 r
F
.74607 .42942 m .74567 .42407 L .72577 .43678 L F
.46486 .85417 m .46481 .85039 L .42621 .84972 L .835 .064 0 r
F
.50289 .85359 m .46481 .85039 L .46486 .85417 L .773 .057 0 r
F
.50289 .85359 m .50341 .84983 L .46481 .85039 L F
.29823 .81513 m .25817 .80412 L .26044 .80899 L 1 .245 0 r
F
.30013 .81982 m .29823 .81513 L .26044 .80899 L 1 .222 0 r
F
.74024 .30828 m .7277 .31339 L .7294 .31961 L .08 .029 0 r
F
.74024 .30828 m .73867 .30205 L .7277 .31339 L F
.70496 .78815 m .67177 .79096 L .66968 .79574 L .409 .023 0 r
F
.70496 .78815 m .70745 .78326 L .67177 .79096 L F
.11574 .54283 m .08808 .51935 L .08747 .52609 L 1 .906 0 r
F
.11529 .5495 m .11574 .54283 L .08747 .52609 L 1 .892 0 r
F
.49394 .56452 m .46798 .56125 L .46797 .5643 L .989 .438 0 r
F
.12496 .52838 m .09621 .50543 L .09562 .51203 L 1 .903 0 r
F
.12455 .53487 m .12496 .52838 L .09562 .51203 L 1 .89 0 r
F
.62046 .48714 m .59908 .48982 L .59868 .49348 L .523 .062 0 r
F
.62046 .48714 m .62101 .48346 L .59908 .48982 L F
.24386 .23094 m .24249 .2193 L .23511 .22106 L .894 1 0 r
F
.24386 .23094 m .24975 .22745 L .24249 .2193 L F
.61855 .83267 m .58336 .83298 L .58183 .83706 L .561 .035 0 r
F
.61855 .83267 m .62059 .82853 L .58336 .83298 L F
.6955 .57841 m .6661 .58134 L .66578 .58578 L .566 .071 0 r
F
.6955 .57841 m .69602 .57392 L .6661 .58134 L F
.86666 .45617 m .84167 .46759 L .84291 .47431 L .244 .05 0 r
F
.86666 .45617 m .86534 .4494 L .84167 .46759 L F
.16337 .63606 m .12811 .61763 L .12905 .62383 L 1 .683 0 r
F
.16433 .64204 m .16337 .63606 L .12905 .62383 L 1 .667 0 r
F
.1132 .37751 m .09483 .35172 L .09175 .35821 L 1 1 0 r
F
.11044 .38409 m .1132 .37751 L .09175 .35821 L F
.44683 .47064 m .42701 .46612 L .42679 .46925 L 1 .842 0 r
F
.44671 .47387 m .44683 .47064 L .42679 .46925 L 1 .835 0 r
F
.87206 .46276 m .84627 .47426 L .84754 .48105 L .254 .052 0 r
F
.87206 .46276 m .87068 .45592 L .84627 .47426 L F
.42552 .85531 m .38565 .84943 L .38679 .85347 L .904 .073 0 r
F
.42613 .85922 m .42552 .85531 L .38679 .85347 L .892 .07 0 r
F
.46476 .85984 m .42552 .85531 L .42613 .85922 L .841 .065 0 r
F
.57075 .54204 m .54647 .54262 L .54625 .54576 L .746 .188 0 r
F
.57075 .54204 m .57109 .53891 L .54647 .54262 L F
.72621 .51758 m .69956 .52324 L .69939 .52795 L .433 .062 0 r
F
.72621 .51758 m .72643 .51277 L .69956 .52324 L F
.80146 .69101 m .7709 .6973 L .76924 .70316 L .304 .019 0 r
F
.80146 .69101 m .80332 .68502 L .7709 .6973 L F
.69383 .35394 m .68144 .35673 L .68032 .36341 L .07 0 0 r
F
.69383 .35394 m .6951 .34719 L .68144 .35673 L F
.59496 .68786 m .56481 .68784 L .56457 .69264 L .735 .171 0 r
F
.59496 .68786 m .59547 .68339 L .56481 .68784 L F
.38362 .20931 m .40684 .2827 L .39718 .26666 L .724 .164 0 r
F
.37563 .18466 m .39224 .23801 L .38187 .22256 L .655 .079 0 r
F
.38362 .20931 m .39118 .21673 L .40684 .2827 L .724 .164 0 r
F
.37563 .18466 m .38217 .18712 L .39224 .23801 L .655 .079 0 r
F
.44671 .47387 m .42679 .46925 L .42659 .47236 L 1 .835 0 r
F
.4466 .47708 m .44671 .47387 L .42659 .47236 L 1 .829 0 r
F
.70379 .26759 m .69347 .26949 L .69502 .27646 L .02 .014 0 r
F
.70379 .26759 m .70235 .26059 L .69347 .26949 L F
.3775 .1286 m .37866 .12461 L .37191 .12584 L .551 .656 0 r
F
.75522 .7581 m .72252 .762 L .72044 .76738 L .368 .022 0 r
F
.75522 .7581 m .75762 .75259 L .72252 .762 L F
.33489 .19642 m .34376 .21225 L .33588 .20932 L .513 .026 0 r
F
.33489 .19642 m .34139 .19602 L .34376 .21225 L F
.84646 .60129 m .81803 .60999 L .81734 .61643 L .255 .026 0 r
F
.84646 .60129 m .84724 .59475 L .81803 .60999 L F
.34448 .82808 m .30479 .81891 L .30677 .82336 L 1 .168 0 r
F
.34603 .83235 m .34448 .82808 L .30677 .82336 L 1 .146 0 r
F
.54525 .55801 m .52012 .55739 L .51996 .56043 L .83 .261 0 r
F
.54525 .55801 m .54552 .55499 L .52012 .55739 L F
.14776 .67151 m .11265 .65167 L .11393 .65815 L 1 .642 0 r
F
.14899 .6778 m .14776 .67151 L .11393 .65815 L 1 .623 0 r
F
.66139 .62518 m .63129 .62604 L .63094 .63042 L .647 .101 0 r
F
.66139 .62518 m .66202 .62085 L .63129 .62604 L F
.57866 .84497 m .54258 .84415 L .54152 .84802 L .631 .041 0 r
F
.57866 .84497 m .58026 .84106 L .54258 .84415 L F
.3097 .76335 m .26883 .75783 L .27058 .76265 L 1 .363 0 r
F
.31104 .7681 m .3097 .76335 L .27058 .76265 L 1 .347 0 r
F
.21361 .70215 m .17487 .68851 L .17654 .69414 L 1 .524 0 r
F
.21512 .70754 m .21361 .70215 L .17654 .69414 L 1 .509 0 r
F
.4466 .47708 m .42659 .47236 L .4264 .47545 L 1 .829 0 r
F
.4465 .48027 m .4466 .47708 L .4264 .47545 L 1 .822 0 r
F
.54044 .8518 m .50341 .84983 L .50289 .85359 L .701 .048 0 r
F
.54044 .8518 m .54152 .84802 L .50341 .84983 L F
.85149 .60983 m .82194 .61824 L .82124 .62477 L .271 .029 0 r
F
.85149 .60983 m .85225 .60316 L .82194 .61824 L F
.24975 .22745 m .25044 .21844 L .24249 .2193 L .707 .794 0 r
F
.24975 .22745 m .2558 .22423 L .25044 .21844 L F
.49386 .56752 m .49394 .56452 L .46797 .5643 L .985 .427 0 r
F
.51962 .5664 m .49394 .56452 L .49386 .56752 L .909 .339 0 r
F
.51962 .5664 m .51979 .56343 L .49394 .56452 L F
.49922 .75528 m .46584 .7588 L .46583 .76387 L .797 .205 0 r
F
.49922 .75528 m .49942 .75031 L .46584 .7588 L F
.7417 .31448 m .7294 .31961 L .73098 .32579 L .064 .024 0 r
F
.7417 .31448 m .74024 .30828 L .7294 .31961 L F
.64441 .45231 m .62548 .45569 L .62476 .4599 L .364 .038 0 r
F
.64441 .45231 m .64534 .44803 L .62548 .45569 L F
.53131 .73742 m .49975 .74011 L .49959 .74525 L .763 .185 0 r
F
.53131 .73742 m .53164 .73256 L .49975 .74011 L F
.80505 .70061 m .77364 .70644 L .77195 .7124 L .317 .022 0 r
F
.80505 .70061 m .80695 .69451 L .77364 .70644 L F
.11044 .38409 m .09175 .35821 L .08878 .36475 L 1 1 0 r
F
.10777 .3907 m .11044 .38409 L .08878 .36475 L F
.5938 .12267 m .58189 .12538 L .58785 .12945 L .538 .663 0 r
F
.59555 .52104 m .57259 .52276 L .57231 .52606 L .645 .1 0 r
F
.59555 .52104 m .59595 .51773 L .57259 .52276 L F
.62746 .66092 m .59741 .66084 L .5971 .66537 L .698 .135 0 r
F
.62746 .66092 m .62808 .6566 L .59741 .66084 L F
.49386 .56752 m .46797 .5643 L .46796 .56732 L .985 .427 0 r
F
.74643 .43473 m .72605 .44212 L .72629 .44741 L .279 .046 0 r
F
.74643 .43473 m .74607 .42942 L .72605 .44212 L F
.35287 .77506 m .31243 .77279 L .31388 .77743 L 1 .322 0 r
F
.35387 .77974 m .35287 .77506 L .31388 .77743 L 1 .304 0 r
F
.4465 .48027 m .4264 .47545 L .42622 .47852 L 1 .822 0 r
F
.4464 .48344 m .4465 .48027 L .42622 .47852 L 1 .816 0 r
F
.20337 .73225 m .16646 .71581 L .16836 .72164 L 1 .492 0 r
F
.20511 .73789 m .20337 .73225 L .16836 .72164 L 1 .471 0 r
F
.37799 .13044 m .37938 .12736 L .37291 .12937 L .485 .41 0 r
F
.15351 .66125 m .11971 .64139 L .1208 .64778 L 1 .668 0 r
F
.15458 .66748 m .15351 .66125 L .1208 .64778 L 1 .65 0 r
F
.66139 .82413 m .62688 .82525 L .62495 .8297 L .496 .03 0 r
F
.66139 .82413 m .66379 .81958 L .62688 .82525 L F
.70631 .79824 m .67274 .80062 L .6706 .80547 L .42 .025 0 r
F
.70631 .79824 m .70886 .79327 L .67274 .80062 L F
.43061 .77711 m .43034 .77223 L .3931 .77939 L .899 .256 0 r
F
.46583 .76883 m .43034 .77223 L .43061 .77711 L .843 .229 0 r
F
.46583 .76883 m .46583 .76387 L .43034 .77223 L F
.61992 .49077 m .59868 .49348 L .59829 .49708 L .519 .062 0 r
F
.61992 .49077 m .62046 .48714 L .59868 .49348 L F
.86787 .46295 m .84291 .47431 L .84405 .48105 L .238 .048 0 r
F
.86787 .46295 m .86666 .45617 L .84291 .47431 L F
.38793 .11553 m .38903 .10871 L .38232 .1108 L .854 1 0 r
F
.38793 .11553 m .39415 .11279 L .38903 .10871 L F
.73218 .18676 m .71695 .19675 L .72233 .20161 L .392 .443 0 r
F
.73774 .19143 m .72233 .20161 L .72764 .20653 L .386 .427 0 r
F
.73774 .19143 m .73218 .18676 L .72233 .20161 L F
.72653 .18218 m .71149 .19198 L .71695 .19675 L .398 .459 0 r
F
.73218 .18676 m .72653 .18218 L .71695 .19675 L .392 .443 0 r
F
.56278 .71626 m .53242 .71763 L .5322 .72266 L .741 .169 0 r
F
.56278 .71626 m .56322 .7116 L .53242 .71763 L F
.25354 .77875 m .21503 .76521 L .21726 .77049 L 1 .354 0 r
F
.25549 .78383 m .25354 .77875 L .21726 .77049 L 1 .332 0 r
F
.74323 .19618 m .72764 .20653 L .73288 .21153 L .38 .41 0 r
F
.74323 .19618 m .73774 .19143 L .72764 .20653 L F
.72081 .17767 m .70597 .18728 L .71149 .19198 L .404 .475 0 r
F
.72653 .18218 m .72081 .17767 L .71149 .19198 L .398 .459 0 r
F
.69495 .58289 m .66578 .58578 L .66542 .5902 L .558 .07 0 r
F
.69495 .58289 m .6955 .57841 L .66578 .58578 L F
.5704 .54514 m .54625 .54576 L .54602 .54887 L .741 .179 0 r
F
.5704 .54514 m .57075 .54204 L .54625 .54576 L F
.1055 .56493 m .0758 .54124 L .07561 .54815 L 1 .855 0 r
F
.10543 .57172 m .1055 .56493 L .07561 .54815 L 1 .84 0 r
F
.20007 .74276 m .16221 .72653 L .16428 .7324 L 1 .466 0 r
F
.20195 .74842 m .20007 .74276 L .16428 .7324 L 1 .445 0 r
F
.11529 .5495 m .08747 .52609 L .08697 .53284 L 1 .892 0 r
F
.11495 .55616 m .11529 .5495 L .08697 .53284 L 1 .878 0 r
F
.74865 .20101 m .73288 .21153 L .73804 .2166 L .374 .394 0 r
F
.74865 .20101 m .74323 .19618 L .73288 .21153 L F
.87333 .46961 m .84754 .48105 L .84871 .48785 L .248 .05 0 r
F
.87333 .46961 m .87206 .46276 L .84754 .48105 L F
.71502 .17325 m .70037 .18265 L .70597 .18728 L .414 .491 0 r
F
.72081 .17767 m .71502 .17325 L .70597 .18728 L .404 .475 0 r
F
.66883 .411 m .65309 .41448 L .65186 .41972 L .221 .004 0 r
F
.66883 .411 m .67029 .40567 L .65309 .41448 L F
.38801 .1159 m .38916 .1093 L .38241 .11115 L .84 1 0 r
F
.38801 .1159 m .39423 .1132 L .38916 .1093 L F
.12455 .53487 m .09562 .51203 L .09513 .51863 L 1 .89 0 r
F
.12425 .54134 m .12455 .53487 L .09513 .51863 L 1 .877 0 r
F
.4464 .48344 m .42622 .47852 L .42607 .48157 L 1 .816 0 r
F
.4463 .48659 m .4464 .48344 L .42607 .48157 L 1 .811 0 r
F
.75398 .20591 m .73804 .2166 L .74312 .22174 L .368 .378 0 r
F
.75398 .20591 m .74865 .20101 L .73804 .2166 L F
.70915 .16892 m .69471 .1781 L .70037 .18265 L .423 .506 0 r
F
.71502 .17325 m .70915 .16892 L .70037 .18265 L .414 .491 0 r
F
.38565 .84943 m .34567 .84215 L .34731 .84634 L .96 .091 0 r
F
.38679 .85347 m .38565 .84943 L .34731 .84634 L .948 .077 0 r
F
.72595 .52237 m .69939 .52795 L .69919 .53264 L .429 .061 0 r
F
.72595 .52237 m .72621 .51758 L .69939 .52795 L F
.40772 .12135 m .41354 .11976 L .40971 .12523 L .223 0 0 r
F
.72579 .18304 m .71094 .19265 L .71637 .19742 L .393 .454 0 r
F
.73143 .1876 m .71637 .19742 L .72174 .20227 L .388 .439 0 r
F
.73143 .1876 m .72579 .18304 L .71637 .19742 L F
.737 .19224 m .72174 .20227 L .72703 .20719 L .383 .425 0 r
F
.737 .19224 m .73143 .1876 L .72174 .20227 L F
.70495 .27465 m .69502 .27646 L .69628 .2835 L 0 .005 0 r
F
.70495 .27465 m .70379 .26759 L .69502 .27646 L F
.72008 .17856 m .70543 .18794 L .71094 .19265 L .398 .468 0 r
F
.72579 .18304 m .72008 .17856 L .71094 .19265 L .393 .454 0 r
F
.74249 .19696 m .72703 .20719 L .73225 .21218 L .378 .41 0 r
F
.74249 .19696 m .737 .19224 L .72703 .20719 L F
.2558 .22423 m .25909 .21869 L .25044 .21844 L .505 .237 0 r
F
.2558 .22423 m .26199 .22129 L .25909 .21869 L F
.75924 .21088 m .74312 .22174 L .74813 .22694 L .362 .362 0 r
F
.75924 .21088 m .75398 .20591 L .74312 .22174 L F
.70322 .16468 m .68897 .17364 L .69471 .1781 L .432 .522 0 r
F
.70915 .16892 m .70322 .16468 L .69471 .1781 L .423 .506 0 r
F
.71431 .17415 m .69986 .18331 L .70543 .18794 L .403 .482 0 r
F
.72008 .17856 m .71431 .17415 L .70543 .18794 L .398 .468 0 r
F
.54497 .561 m .51996 .56043 L .51979 .56343 L .825 .251 0 r
F
.54497 .561 m .54525 .55801 L .51996 .56043 L F
.74791 .20175 m .73225 .21218 L .73739 .21724 L .373 .395 0 r
F
.74791 .20175 m .74249 .19696 L .73225 .21218 L F
.58776 .11815 m .57599 .12091 L .58208 .12476 L .569 .703 0 r
F
.70847 .16982 m .69422 .17876 L .69986 .18331 L .41 .496 0 r
F
.71431 .17415 m .70847 .16982 L .69986 .18331 L .403 .482 0 r
F
.75325 .20662 m .73739 .21724 L .74246 .22237 L .368 .38 0 r
F
.75325 .20662 m .74791 .20175 L .73739 .21724 L F
.76442 .21593 m .74813 .22694 L .75306 .23222 L .356 .346 0 r
F
.76442 .21593 m .75924 .21088 L .74813 .22694 L F
.69721 .16052 m .68317 .16925 L .68897 .17364 L .441 .537 0 r
F
.70322 .16468 m .69721 .16052 L .68897 .17364 L .432 .522 0 r
F
.10777 .3907 m .08878 .36475 L .08591 .37133 L 1 1 0 r
F
.10521 .39735 m .10777 .3907 L .08591 .37133 L F
.26391 .7431 m .22364 .73387 L .22554 .73899 L 1 .418 0 r
F
.26549 .74806 m .26391 .7431 L .22554 .73899 L 1 .403 0 r
F
.74307 .32062 m .73098 .32579 L .73245 .33195 L .05 .021 0 r
F
.74307 .32062 m .7417 .31448 L .73098 .32579 L F
.4463 .48659 m .42607 .48157 L .42593 .4846 L 1 .811 0 r
F
.44622 .48972 m .4463 .48659 L .42593 .4846 L 1 .805 0 r
F
.30101 .80977 m .26177 .79866 L .26399 .80346 L 1 .244 0 r
F
.30287 .81438 m .30101 .80977 L .26399 .80346 L 1 .222 0 r
F
.5944 .69231 m .56457 .69264 L .5643 .69741 L .72 .148 0 r
F
.5944 .69231 m .59496 .68786 L .56457 .69264 L F
.70256 .16557 m .68852 .17428 L .69422 .17876 L .419 .51 0 r
F
.70847 .16982 m .70256 .16557 L .69422 .17876 L .41 .496 0 r
F
.49377 .57049 m .49386 .56752 L .46796 .56732 L .981 .416 0 r
F
.51943 .56935 m .49386 .56752 L .49377 .57049 L .904 .328 0 r
F
.51943 .56935 m .51962 .5664 L .49386 .56752 L F
.61885 .84257 m .58354 .84257 L .58197 .84671 L .566 .035 0 r
F
.61885 .84257 m .62093 .83837 L .58354 .84257 L F
.58751 .11892 m .57584 .12143 L .58189 .12538 L .55 .681 0 r
F
.5938 .12267 m .58751 .11892 L .58189 .12538 L .538 .663 0 r
F
.75852 .21156 m .74246 .22237 L .74745 .22757 L .363 .365 0 r
F
.75852 .21156 m .75325 .20662 L .74246 .22237 L F
.30476 .25041 m .37803 .34972 L .38012 .35786 L .791 .203 0 r
F
.30476 .25041 m .31749 .25864 L .37803 .34972 L F
.76952 .22105 m .75306 .23222 L .75791 .23755 L .351 .33 0 r
F
.76952 .22105 m .76442 .21593 L .75306 .23222 L F
.66072 .62949 m .63094 .63042 L .63055 .63481 L .637 .086 0 r
F
.66072 .62949 m .66139 .62518 L .63094 .63042 L F
.69113 .15646 m .67731 .16495 L .68317 .16925 L .451 .552 0 r
F
.69721 .16052 m .69113 .15646 L .68317 .16925 L .441 .537 0 r
F
.16433 .64204 m .12905 .62383 L .13009 .62999 L 1 .667 0 r
F
.16537 .64798 m .16433 .64204 L .13009 .62999 L 1 .652 0 r
F
.42621 .84972 m .38694 .84386 L .38808 .84781 L .901 .072 0 r
F
.42681 .85352 m .42621 .84972 L .38808 .84781 L .888 .069 0 r
F
.46486 .85417 m .42621 .84972 L .42681 .85352 L .835 .064 0 r
F
.69659 .1614 m .68275 .16988 L .68852 .17428 L .427 .524 0 r
F
.70256 .16557 m .69659 .1614 L .68852 .17428 L .419 .51 0 r
F
.46795 .57032 m .46796 .56732 L .44244 .56588 L 1 .496 0 r
F
.49377 .57049 m .46796 .56732 L .46795 .57032 L .981 .416 0 r
F
.4648 .86364 m .46476 .85984 L .42613 .85922 L .828 .062 0 r
F
.50284 .8631 m .46476 .85984 L .4648 .86364 L .768 .056 0 r
F
.50284 .8631 m .50337 .8593 L .46476 .85984 L F
.7637 .21658 m .74745 .22757 L .75236 .23283 L .357 .349 0 r
F
.7637 .21658 m .75852 .21156 L .74745 .22757 L F
.59513 .5243 m .57231 .52606 L .57202 .52932 L .64 .094 0 r
F
.59513 .5243 m .59555 .52104 L .57231 .52606 L F
.74675 .44 m .72629 .44741 L .72649 .45266 L .279 .046 0 r
F
.74675 .44 m .74643 .43473 L .72629 .44741 L F
.77454 .22624 m .75791 .23755 L .76269 .24295 L .345 .314 0 r
F
.77454 .22624 m .76952 .22105 L .75791 .23755 L F
.68499 .15248 m .67138 .16073 L .67731 .16495 L .459 .566 0 r
F
.69113 .15646 m .68499 .15248 L .67731 .16495 L .451 .552 0 r
F
.44622 .48972 m .42593 .4846 L .4258 .48761 L 1 .805 0 r
F
.44613 .49283 m .44622 .48972 L .4258 .48761 L 1 .801 0 r
F
.69055 .15731 m .67691 .16556 L .68275 .16988 L .436 .538 0 r
F
.69659 .1614 m .69055 .15731 L .68275 .16988 L .427 .524 0 r
F
.75048 .75347 m .71876 .75778 L .71664 .76301 L .353 .018 0 r
F
.75048 .75347 m .75291 .74811 L .71876 .75778 L F
.3931 .77939 m .35387 .77974 L .35492 .78435 L .959 .287 0 r
F
.39373 .78409 m .3931 .77939 L .35492 .78435 L .954 .267 0 r
F
.43061 .77711 m .3931 .77939 L .39373 .78409 L .899 .256 0 r
F
.25176 .78907 m .21258 .77582 L .21495 .78111 L 1 .329 0 r
F
.25383 .79416 m .25176 .78907 L .21495 .78111 L 1 .307 0 r
F
.7688 .22168 m .75236 .23283 L .75719 .23816 L .352 .333 0 r
F
.7688 .22168 m .7637 .21658 L .75236 .23283 L F
.34406 .83787 m .30408 .82895 L .30614 .8334 L 1 .149 0 r
F
.34567 .84215 m .34406 .83787 L .30614 .8334 L 1 .126 0 r
F
.84559 .60782 m .81734 .61643 L .81655 .62284 L .249 .023 0 r
F
.84559 .60782 m .84646 .60129 L .81734 .61643 L F
.47305 .10344 m .4688 .09727 L .46777 .10559 L .834 .903 0 r
F
.47305 .10344 m .47319 .09807 L .4688 .09727 L F
.64353 .45649 m .62476 .4599 L .62407 .46403 L .362 .038 0 r
F
.64353 .45649 m .64441 .45231 L .62476 .4599 L F
.69242 .36055 m .68032 .36341 L .67906 .36995 L .055 0 0 r
F
.69242 .36055 m .69383 .35394 L .68032 .36341 L F
.62681 .66523 m .5971 .66537 L .59675 .6699 L .685 .116 0 r
F
.62681 .66523 m .62746 .66092 L .5971 .66537 L F
.68446 .15331 m .67102 .16131 L .67691 .16556 L .445 .552 0 r
F
.69055 .15731 m .68446 .15331 L .67691 .16556 L .436 .538 0 r
F
.61938 .49434 m .59829 .49708 L .5979 .50063 L .515 .062 0 r
F
.61938 .49434 m .61992 .49077 L .59829 .49708 L F
.77948 .2315 m .76269 .24295 L .76738 .24842 L .339 .298 0 r
F
.77948 .2315 m .77454 .22624 L .76269 .24295 L F
.57004 .54821 m .54602 .54887 L .54578 .55195 L .736 .17 0 r
F
.57004 .54821 m .5704 .54514 L .54602 .54887 L F
.68499 .15248 m .67879 .1486 L .67138 .16073 L .459 .566 0 r
F
.86896 .46973 m .84405 .48105 L .84509 .48778 L .231 .045 0 r
F
.86896 .46973 m .86787 .46295 L .84405 .48105 L F
.77382 .22684 m .75719 .23816 L .76195 .24356 L .347 .318 0 r
F
.77382 .22684 m .7688 .22168 L .75719 .23816 L F
.26199 .22129 m .26832 .21866 L .26844 .22019 L 0 0 0 r
F
.26199 .22129 m .26844 .22019 L .25909 .21869 L F
.85061 .61647 m .82124 .62477 L .82045 .63128 L .265 .027 0 r
F
.85061 .61647 m .85149 .60983 L .82124 .62477 L F
.87449 .47648 m .84871 .48785 L .84977 .49466 L .243 .048 0 r
F
.87449 .47648 m .87333 .46961 L .84871 .48785 L F
.79951 .69695 m .76924 .70316 L .7675 .70897 L .299 .017 0 r
F
.79951 .69695 m .80146 .69101 L .76924 .70316 L F
.69435 .58734 m .66542 .5902 L .66504 .59462 L .551 .068 0 r
F
.69435 .58734 m .69495 .58289 L .66542 .5902 L F
.44613 .49283 m .4258 .48761 L .42569 .4906 L 1 .801 0 r
F
.44606 .49591 m m .67879 .1486 L .67138 .16073 L .459 .566 0 r
F
.86896 .46973 m .84405 .48105 L .84509 .48778 L .231 .045 0 r
F
.86896 .46973 m .86787 .46295 L .84405 .48105 L F
.77382 .22684 m .75719 .23816 L .76195 .24356 L .347 .318 0 r
F
.77382 .22684 m .7688 .22168 L .75719 .23816 L F
.26199 .22129 m .26832 .21866 L .26844 .22019 L 0 0 0 r
F
.26199 .22129 m .26844 .22019 L .25909 .21869 L F
.85061 .61647 m .82124 .62477 L .82045 .63128 L .265 .027 0 r
F
.85061 .61647 m .85149 .60983 L .82124 .62477 L F
.87449 .47648 m .84871 .48785 L .84977 .49466 L .243 .048 0 r
F
.87449 .47648 m .87333 .46961 L .84871 .48785 L F
.79951 .69695 m .76924 .70316 L .7675 .70897 L .299 .017 0 r
F
.79951 .69695 m .80146 .69101 L .76924 .70316 L F
.69435 .58734 m .66542 .5902 L .66504 .59462 L .551 .068 0 r
F
.69435 .58734 m .69495 .58289 L .66542 .5902 L F
.44613 .49283 m .4258 .48761 L .42569 .4906 L 1 .801 0 r
F
.44606 .49591 m .44613 .49283 L .42569 .4906 L 1 .797 0 r
F
.10521 .39735 m .08591 .37133 L .08316 .37795 L 1 1 0 r
F
.10275 .40402 m .10521 .39735 L .08316 .37795 L F
.57872 .85472 m .5426 .85367 L .54152 .85759 L .632 .041 0 r
F
.57872 .85472 m .58037 .85076 L .5426 .85367 L F
.6783 .14938 m .66506 .15715 L .67102 .16131 L .454 .567 0 r
F
.68446 .15331 m .6783 .14938 L .67102 .16131 L .445 .552 0 r
F
.58133 .11466 m .56984 .11717 L .57599 .12091 L .578 .718 0 r
F
.58776 .11815 m .58133 .11466 L .57599 .12091 L .569 .703 0 r
F
.72565 .52714 m .69919 .53264 L .69896 .53731 L .425 .06 0 r
F
.72565 .52714 m .72595 .52237 L .69919 .53264 L F
.14899 .6778 m .11393 .65815 L .11531 .66459 L 1 .623 0 r
F
.15031 .68405 m .14899 .6778 L .11531 .66459 L 1 .604 0 r
F
.78433 .23682 m .76738 .24842 L .77199 .25394 L .333 .282 0 r
F
.78433 .23682 m .77948 .2315 L .76738 .24842 L F
.77876 .23208 m .76195 .24356 L .76661 .24902 L .341 .301 0 r
F
.77876 .23208 m .77382 .22684 L .76195 .24356 L F
.74435 .3267 m .73245 .33195 L .73381 .33807 L .037 .018 0 r
F
.74435 .3267 m .74307 .32062 L .73245 .33195 L F
.54468 .56396 m .51979 .56343 L .51962 .5664 L .82 .24 0 r
F
.54468 .56396 m .54497 .561 L .51979 .56343 L F
.34139 .19602 m .35243 .21752 L .34376 .21225 L .644 .049 0 r
F
.34139 .19602 m .34822 .1967 L .35243 .21752 L F
.70582 .28175 m .69628 .2835 L .69726 .29059 L 0 0 0 r
F
.70582 .28175 m .70495 .27465 L .69628 .2835 L F
.12425 .54134 m .09513 .51863 L .09475 .52523 L 1 .877 0 r
F
.12404 .5478 m .12425 .54134 L .09475 .52523 L 1 .863 0 r
F
.11495 .55616 m .08697 .53284 L .08659 .53958 L 1 .878 0 r
F
.1147 .56281 m .11495 .55616 L .08659 .53958 L 1 .863 0 r
F
.53094 .74222 m .49959 .74525 L .49942 .75031 L .749 .159 0 r
F
.53094 .74222 m .53131 .73742 L .49959 .74525 L F
.58114 .1153 m .56972 .1176 L .57584 .12143 L .562 .7 0 r
F
.58751 .11892 m .58114 .1153 L .57584 .12143 L .55 .681 0 r
F
.5404 .86141 m .50337 .8593 L .50284 .8631 L .699 .048 0 r
F
.5404 .86141 m .54152 .85759 L .50337 .8593 L F
.65828 .8185 m .62451 .82 L .62257 .8243 L .475 .026 0 r
F
.65828 .8185 m .66068 .8141 L .62451 .82 L F
.10543 .57172 m .07561 .54815 L .07553 .55506 L 1 .84 0 r
F
.10546 .5785 m .10543 .57172 L .07553 .55506 L 1 .825 0 r
F
.6783 .14938 m .67208 .14554 L .66506 .15715 L .454 .567 0 r
F
.39415 .11279 m .39578 .10691 L .38903 .10871 L .796 1 0 r
F
.39415 .11279 m .40041 .11026 L .39578 .10691 L F
.21512 .70754 m .17654 .69414 L .1783 .69972 L 1 .509 0 r
F
.21669 .7129 m .21512 .70754 L .1783 .69972 L 1 .493 0 r
F
.49368 .57343 m .49377 .57049 L .46795 .57032 L .977 .405 0 r
F
.51923 .57226 m .49377 .57049 L .49368 .57343 L .9 .317 0 r
F
.51923 .57226 m .51943 .56935 L .49377 .57049 L F
.40074 .4687 m .38245 .46184 L .38173 .46505 L 1 .971 0 r
F
.40074 .4687 m .40126 .46538 L .38245 .46184 L F
.40023 .47202 m .40074 .4687 L .38173 .46505 L 1 .963 0 r
F
.40023 .47202 m .38173 .46505 L .38103 .46827 L F
.39975 .47534 m .40023 .47202 L .38103 .46827 L 1 .954 0 r
F
.40126 .46538 m .38319 .45863 L .38245 .46184 L 1 .98 0 r
F
.39975 .47534 m .38103 .46827 L .38036 .4715 L 1 .954 0 r
F
.39928 .47866 m .39975 .47534 L .38036 .4715 L 1 .945 0 r
F
.7024 .79296 m .66968 .79574 L .66752 .80045 L .403 .021 0 r
F
.7024 .79296 m .70496 .78815 L .66968 .79574 L F
.56229 .72088 m .5322 .72266 L .53194 .72764 L .725 .142 0 r
F
.56229 .72088 m .56278 .71626 L .5322 .72266 L F
.78361 .23739 m .76661 .24902 L .7712 .25454 L .335 .285 0 r
F
.78361 .23739 m .77876 .23208 L .76661 .24902 L F
.499 .76017 m .46583 .76387 L .46583 .76883 L .786 .179 0 r
F
.499 .76017 m .49922 .75528 L .46583 .76387 L F
.78911 .24222 m .77199 .25394 L .77652 .25953 L .328 .266 0 r
F
.78911 .24222 m .78433 .23682 L .77199 .25394 L F
.46795 .57032 m .44244 .56588 L .44248 .5689 L 1 .496 0 r
F
.46794 .57329 m .46795 .57032 L .44248 .5689 L 1 .485 0 r
F
.49368 .57343 m .46795 .57032 L .46794 .57329 L .977 .405 0 r
F
.44606 .49591 m .42569 .4906 L .4256 .49356 L 1 .797 0 r
F
.44598 .49898 m .44606 .49591 L .4256 .49356 L 1 .793 0 r
F
.39928 .47866 m .38036 .4715 L .37972 .47474 L 1 .945 0 r
F
.39884 .48198 m .39928 .47866 L .37972 .47474 L 1 .936 0 r
F
.39423 .1132 m .39596 .10782 L .38916 .1093 L .753 .979 0 r
F
.39423 .1132 m .4005 .11071 L .39596 .10782 L F
.15458 .66748 m .1208 .64778 L .12199 .65415 L 1 .65 0 r
F
.15574 .67367 m .15458 .66748 L .12199 .65415 L 1 .631 0 r
F
.59471 .52753 m .57202 .52932 L .57172 .53255 L .635 .087 0 r
F
.59471 .52753 m .59513 .5243 L .57202 .52932 L F
.75273 .76355 m .72044 .76738 L .71827 .77269 L .363 .02 0 r
F
.75273 .76355 m .75522 .7581 L .72044 .76738 L F
.80305 .70666 m .77195 .7124 L .77017 .7183 L .312 .02 0 r
F
.80305 .70666 m .80505 .70061 L .77195 .7124 L F
.30013 .81982 m .26044 .80899 L .26278 .81379 L 1 .222 0 r
F
.30208 .82443 m .30013 .81982 L .26278 .81379 L 1 .199 0 r
F
.38694 .84386 m .34762 .83654 L .34924 .84065 L .959 .085 0 r
F
.38808 .84781 m .38694 .84386 L .34924 .84065 L .946 .077 0 r
F
.74703 .44523 m .72649 .45266 L .72666 .45786 L .279 .045 0 r
F
.74703 .44523 m .74675 .44 L .72649 .45266 L F
.66742 .41616 m .65186 .41972 L .65066 .42479 L .217 .003 0 r
F
.66742 .41616 m .66883 .411 L .65186 .41972 L F
.66 .63379 m .63055 .63481 L .63013 .63918 L .626 .073 0 r
F
.66 .63379 m .66072 .62949 L .63055 .63481 L F
.31104 .7681 m .27058 .76265 L .27239 .76741 L 1 .347 0 r
F
.31243 .77279 m .31104 .7681 L .27239 .76741 L 1 .33 0 r
F
.46777 .10559 m .4688 .09727 L .46452 .09827 L 1 1 0 r
F
.78837 .24277 m .7712 .25454 L .7757 .26013 L .33 .269 0 r
F
.78837 .24277 m .78361 .23739 L .7712 .25454 L F
.5938 .69673 m .5643 .69741 L .56398 .70217 L .704 .124 0 r
F
.5938 .69673 m .5944 .69231 L .5643 .69741 L F
.7938 .24767 m .77652 .25953 L .78096 .26518 L .322 .25 0 r
F
.7938 .24767 m .78911 .24222 L .77652 .25953 L F
.44598 .49898 m .4256 .49356 L .42553 .49649 L 1 .793 0 r
F
.44592 .50203 m .44598 .49898 L .42553 .49649 L 1 .791 0 r
F
.20511 .73789 m .16836 .72164 L .17035 .72742 L 1 .471 0 r
F
.20693 .74347 m .20511 .73789 L .17035 .72742 L 1 .45 0 r
F
.56967 .55125 m .54578 .55195 L .54552 .55499 L .731 .16 0 r
F
.56967 .55125 m .57004 .54821 L .54578 .55195 L F
.10275 .40402 m .08316 .37795 L .08051 .38461 L 1 1 0 r
F
.10039 .41072 m .10275 .40402 L .08051 .38461 L F
.26832 .21866 m .27477 .21632 L .27831 .22282 L .159 0 0 r
F
.61886 .49786 m .5979 .50063 L .59752 .50414 L .51 .061 0 r
F
.61886 .49786 m .61938 .49434 L .5979 .50063 L F
.61647 .83673 m .58183 .83706 L .58026 .84106 L .548 .032 0 r
F
.61647 .83673 m .61855 .83267 L .58183 .83706 L F
.79304 .24822 m .7757 .26013 L .78011 .26577 L .324 .252 0 r
F
.79304 .24822 m .78837 .24277 L .7757 .26013 L F
.86993 .47653 m .84509 .48778 L .84602 .49452 L .225 .043 0 r
F
.86993 .47653 m .86896 .46973 L .84509 .48778 L F
.58133 .11466 m .57483 .11128 L .56984 .11717 L .578 .718 0 r
F
.74557 .33273 m .73381 .33807 L .73508 .34415 L .026 .015 0 r
F
.74557 .33273 m .74435 .3267 L .73381 .33807 L F
.4309 .78189 m .43061 .77711 L .39373 .78409 L .893 .234 0 r
F
.46583 .7737 m .43061 .77711 L .4309 .78189 L .835 .204 0 r
F
.46583 .7737 m .46583 .76883 L .43061 .77711 L F
.7984 .25319 m .78096 .26518 L .78533 .27088 L .316 .235 0 r
F
.7984 .25319 m .7938 .24767 L .78096 .26518 L F
.35387 .77974 m .31388 .77743 L .31538 .78201 L 1 .304 0 r
F
.35492 .78435 m .35387 .77974 L .31538 .78201 L 1 .285 0 r
F
.64269 .46058 m .62407 .46403 L .62341 .46807 L .36 .038 0 r
F
.64269 .46058 m .64353 .45649 L .62407 .46403 L F
.4649 .85785 m .46486 .85417 L .42681 .85352 L .821 .061 0 r
F
.50236 .85727 m .46486 .85417 L .4649 .85785 L .759 .054 0 r
F
.50236 .85727 m .50289 .85359 L .46486 .85417 L F
.87553 .48336 m .84977 .49466 L .85073 .50147 L .237 .045 0 r
F
.87553 .48336 m .87449 .47648 L .84977 .49466 L F
.6261 .66952 m .59675 .6699 L .59637 .67441 L .671 .096 0 r
F
.6261 .66952 m .62681 .66523 L .59675 .6699 L F
.57468 .1118 m .56353 .11388 L .56972 .1176 L .573 .717 0 r
F
.58114 .1153 m .57468 .1118 L .56972 .1176 L .562 .7 0 r
F
.72532 .53188 m .69896 .53731 L .6987 .54195 L .42 .059 0 r
F
.72532 .53188 m .72565 .52714 L .69896 .53731 L F
.54437 .56688 m .51962 .5664 L .51943 .56935 L .816 .229 0 r
F
.54437 .56688 m .54468 .56396 L .51962 .5664 L F
.69371 .59178 m .66504 .59462 L .66462 .59902 L .543 .067 0 r
F
.69371 .59178 m .69435 .58734 L .66504 .59462 L F
.16537 .64798 m .13009 .62999 L .13122 .63613 L 1 .652 0 r
F
.16648 .65388 m .16537 .64798 L .13122 .63613 L 1 .636 0 r
F
.20195 .74842 m .16428 .7324 L .16645 .73821 L 1 .445 0 r
F
.20392 .75402 m .20195 .74842 L .16645 .73821 L 1 .423 0 r
F
.44592 .50203 m .42553 .49649 L .42547 .4994 L 1 .791 0 r
F
.44585 .50507 m .44592 .50203 L .42547 .4994 L 1 .789 0 r
F
.34603 .83235 m .30677 .82336 L .30879 .82774 L 1 .146 0 r
F
.34762 .83654 m .34603 .83235 L .30879 .82774 L 1 .123 0 r
F
.79762 .25374 m .78011 .26577 L .78444 .27147 L .318 .236 0 r
F
.79762 .25374 m .79304 .24822 L .78011 .26577 L F
.49358 .57634 m .49368 .57343 L .46794 .57329 L .973 .394 0 r
F
.51902 .57515 m .49368 .57343 L .49358 .57634 L .895 .306 0 r
F
.51902 .57515 m .51923 .57226 L .49368 .57343 L F
.12255 .38732 m .12535 .381 L .10563 .36269 L 1 1 0 r
F
.8446 .61432 m .81655 .62284 L .81567 .62922 L .243 .021 0 r
F
.8446 .61432 m .84559 .60782 L .81655 .62284 L F
.42613 .85922 m .38679 .85347 L .38797 .85742 L .892 .07 0 r
F
.42676 .86304 m .42613 .85922 L .38797 .85742 L .879 .068 0 r
F
.4648 .86364 m .42613 .85922 L .42676 .86304 L .828 .062 0 r
F
.46794 .57329 m .44248 .5689 L .44252 .5719 L 1 .485 0 r
F
.46793 .57623 m .46794 .57329 L .44252 .5719 L 1 .474 0 r
F
.49358 .57634 m .46794 .57329 L .46793 .57623 L .973 .394 0 r
F
.7064 .28888 m .69726 .29059 L .69794 .29772 L 0 0 0 r
F
.7064 .28888 m .70582 .28175 L .69726 .29059 L F
.38999 .12454 m .39308 .12699 L .38564 .12457 L .196 0 0 r
F
.38999 .12454 m .39638 .12342 L .39308 .12699 L F
.80292 .25878 m .78533 .27088 L .7896 .27664 L .31 .219 0 r
F
.80292 .25878 m .7984 .25319 L .78533 .27088 L F
.25549 .78383 m .21726 .77049 L .21956 .77571 L 1 .332 0 r
F
.25752 .78884 m .25549 .78383 L .21956 .77571 L 1 .309 0 r
F
.39118 .21673 m .41459 .29494 L .40684 .2827 L .756 .197 0 r
F
.38217 .18712 m .40253 .25555 L .39224 .23801 L .685 .131 0 r
F
.39118 .21673 m .39921 .22718 L .41459 .29494 L .756 .197 0 r
F
.38217 .18712 m .38914 .19186 L .40253 .25555 L .685 .131 0 r
F
.12404 .5478 m .09475 .52523 L .09448 .53182 L 1 .863 0 r
F
.12393 .55425 m .12404 .5478 L .09448 .53182 L 1 .849 0 r
F
.59428 .53073 m .57172 .53255 L .57141 .53575 L .631 .08 0 r
F
.59428 .53073 m .59471 .52753 L .57172 .53255 L F
.44244 .56588 m .41768 .56019 L .41773 .56326 L 1 .579 0 r
F
.44248 .5689 m .44244 .56588 L .41773 .56326 L 1 .569 0 r
F
.1147 .56281 m .08659 .53958 L .08631 .54633 L 1 .863 0 r
F
.11456 .56945 m .1147 .56281 L .08631 .54633 L 1 .848 0 r
F
.26549 .74806 m .22554 .73899 L .22751 .74407 L 1 .403 0 r
F
.26713 .75297 m .26549 .74806 L .22751 .74407 L 1 .387 0 r
F
.70369 .80314 m .6706 .80547 L .66839 .81025 L .41 .022 0 r
F
.70369 .80314 m .70631 .79824 L .6706 .80547 L F
.74728 .45042 m .72666 .45786 L .7268 .46303 L .28 .045 0 r
F
.74728 .45042 m .74703 .44523 L .72666 .45786 L F
.84962 .62309 m .82045 .63128 L .81955 .63777 L .26 .024 0 r
F
.84962 .62309 m .85061 .61647 L .82045 .63128 L F
.69091 .367 m .67906 .36995 L .6777 .37634 L .041 0 0 r
F
.69091 .367 m .69242 .36055 L .67906 .36995 L F
.57702 .84879 m .54152 .84802 L .54044 .8518 L .617 .038 0 r
F
.57702 .84879 m .57866 .84497 L .54152 .84802 L F
.44585 .50507 m .42547 .4994 L .42544 .50228 L 1 .789 0 r
F
.44579 .50808 m .44585 .50507 L .42544 .50228 L F
.8021 .25932 m .78444 .27147 L .78867 .27724 L .313 .219 0 r
F
.8021 .25932 m .79762 .25374 L .78444 .27147 L F
.10546 .5785 m .07553 .55506 L .07556 .56196 L 1 .825 0 r
F
.10559 .58527 m .10546 .5785 L .07556 .56196 L 1 .809 0 r
F
.65893 .82859 m .62495 .8297 L .62297 .83408 L .484 .027 0 r
F
.65893 .82859 m .66139 .82413 L .62495 .8297 L F
.10039 .41072 m .08051 .38461 L .07797 .3913 L 1 1 0 r
F
.09814 .41745 m .10039 .41072 L .07797 .3913 L F
.53933 .85549 m .50289 .85359 L .50236 .85727 L .687 .045 0 r
F
.53933 .85549 m .54044 .8518 L .50289 .85359 L F
.80735 .26442 m .7896 .27664 L .79379 .28246 L .305 .203 0 r
F
.80735 .26442 m .80292 .25878 L .7896 .27664 L F
.56928 .55426 m .54552 .55499 L .54525 .55801 L .726 .15 0 r
F
.56928 .55426 m .56967 .55125 L .54552 .55499 L F
.65925 .63807 m .63013 .63918 L .62968 .64355 L .615 .071 0 r
F
.65925 .63807 m .66 .63379 L .63013 .63918 L F
.27477 .21632 m .28824 .22606 L .27831 .22282 L .352 0 0 r
F
.27477 .21632 m .28131 .21427 L .28824 .22606 L F
.74672 .3387 m .73508 .34415 L .73625 .35019 L .017 .012 0 r
F
.74672 .3387 m .74557 .33273 L .73508 .34415 L F
.61834 .50134 m .59752 .50414 L .59713 .5076 L .506 .061 0 r
F
.61834 .50134 m .61886 .49786 L .59752 .50414 L F
.12741 .3816 m .10903 .35657 L .10616 .36286 L 1 1 0 r
F
.12484 .38794 m .12741 .3816 L .10616 .36286 L F
.56175 .72546 m .53194 .72764 L .53164 .73256 L .709 .116 0 r
F
.56175 .72546 m .56229 .72088 L .53194 .72764 L F
.4005 .11071 m .40271 .10616 L .39596 .10782 L .671 .896 0 r
F
.4005 .11071 m .4068 .10847 L .40271 .10616 L F
.15031 .68405 m .11531 .66459 L .1168 .671 L 1 .604 0 r
F
.15173 .69026 m .15031 .68405 L .1168 .671 L 1 .585 0 r
F
.12255 .38732 m .10563 .36269 L .10262 .36894 L 1 1 0 r
F
.11985 .39368 m .12255 .38732 L .10262 .36894 L F
.53054 .74695 m .49942 .75031 L .49922 .75528 L .735 .131 0 r
F
.53054 .74695 m .53094 .74222 L .49942 .75031 L F
.79746 .70285 m .7675 .70897 L .76568 .71473 L .293 .014 0 r
F
.79746 .70285 m .79951 .69695 L .7675 .70897 L F
.57468 .1118 m .56815 .10843 L .56353 .11388 L .573 .717 0 r
F
.39373 .78409 m .35492 .78435 L .35602 .78888 L .954 .267 0 r
F
.39441 .78871 m .39373 .78409 L .35602 .78888 L .948 .246 0 r
F
.4309 .78189 m .39373 .78409 L .39441 .78871 L .893 .234 0 r
F
.80649 .26497 m .78867 .27724 L .79282 .28306 L .307 .202 0 r
F
.80649 .26497 m .8021 .25932 L .78867 .27724 L F
.74796 .75876 m .71664 .76301 L .71446 .76818 L .348 .015 0 r
F
.74796 .75876 m .75048 .75347 L .71664 .76301 L F
.87079 .48333 m .84602 .49452 L .84685 .50126 L .218 .04 0 r
F
.87079 .48333 m .86993 .47653 L .84602 .49452 L F
.44579 .50808 m .42544 .50228 L .42542 .50513 L 1 .789 0 r
F
.44573 .51108 m .44579 .50808 L .42542 .50513 L 1 .791 0 r
F
.59315 .70113 m .56398 .70217 L .56362 .7069 L .688 .1 0 r
F
.59315 .70113 m .5938 .69673 L .56398 .70217 L F
.54405 .56978 m .51943 .56935 L .51923 .57226 L .811 .218 0 r
F
.54405 .56978 m .54437 .56688 L .51943 .56935 L F
.30287 .81438 m .26399 .80346 L .26628 .80818 L 1 .222 0 r
F
.30479 .81891 m .30287 .81438 L .26628 .80818 L 1 .198 0 r
F
.81169 .27013 m .79379 .28246 L .7979 .28833 L .299 .187 0 r
F
.81169 .27013 m .80735 .26442 L .79379 .28246 L F
.72495 .5366 m .6987 .54195 L .69841 .54658 L .415 .058 0 r
F
.72495 .5366 m .72532 .53188 L .6987 .54195 L F
.87646 .49024 m .85073 .50147 L .85158 .50829 L .232 .043 0 r
F
.87646 .49024 m .87553 .48336 L .85073 .50147 L F
.66605 .42116 m .65066 .42479 L .6495 .42971 L .214 .003 0 r
F
.66605 .42116 m .66742 .41616 L .65066 .42479 L F
.15574 .67367 m .12199 .65415 L .12328 .66048 L 1 .631 0 r
F
.157 .67981 m .15574 .67367 L .12328 .66048 L 1 .612 0 r
F
.64188 .46458 m .62341 .46807 L .62278 .47202 L .358 .038 0 r
F
.64188 .46458 m .64269 .46058 L .62341 .46807 L F
.69304 .5962 m .66462 .59902 L .66417 .60341 L .534 .065 0 r
F
.69304 .5962 m .69371 .59178 L .66462 .59902 L F
.46793 .57623 m .44252 .5719 L .44258 .57487 L 1 .474 0 r
F
.46793 .57914 m .46793 .57623 L .44258 .57487 L 1 .462 0 r
F
.49348 .57922 m .46793 .57623 L .46793 .57914 L .969 .382 0 r
F
.49348 .57922 m .49358 .57634 L .46793 .57623 L F
.25383 .79416 m .21495 .78111 L .2174 .78633 L 1 .307 0 r
F
.25596 .79918 m .25383 .79416 L .2174 .78633 L 1 .284 0 r
F
.51881 .578 m .49358 .57634 L .49348 .57922 L .891 .294 0 r
F
.51881 .578 m .51902 .57515 L .49358 .57634 L F
.44248 .5689 m .41773 .56326 L .41779 .56631 L 1 .569 0 r
F
.44252 .5719 m .44248 .5689 L .41779 .56631 L 1 .557 0 r
F
.38679 .85347 m .34731 .84634 L .349 .85044 L .948 .077 0 r
F
.38797 .85742 m .38679 .85347 L .349 .85044 L .935 .075 0 r
F
.21669 .7129 m .1783 .69972 L .18013 .70526 L 1 .493 0 r
F
.21833 .71821 m .21669 .7129 L .18013 .70526 L 1 .477 0 r
F
.4431 .55779 m .44358 .55348 L .41978 .55104 L 1 .939 0 r
F
.4732 .09584 m .47334 .09101 L .46988 .09115 L .932 1 0 r
F
.4732 .09584 m .47334 .09101 L .46988 .09116 L F
.62535 .67379 m .59637 .67441 L .59594 .67891 L .657 .077 0 r
F
.62535 .67379 m .6261 .66952 L .59637 .67441 L F
.59384 .53389 m .57141 .53575 L .57109 .53891 L .626 .073 0 r
F
.59384 .53389 m .59428 .53073 L .57141 .53575 L F
.49877 .76496 m .46583 .76883 L .46583 .7737 L .774 .152 0 r
F
.49877 .76496 m .499 .76017 L .46583 .76883 L F
.81079 .27069 m .79282 .28306 L .79687 .28893 L .301 .185 0 r
F
.81079 .27069 m .80649 .26497 L .79282 .28306 L F
.34822 .1967 m .3622 .22623 L .35243 .21752 L .743 .067 0 r
F
.34822 .1967 m .35551 .19894 L .3622 .22623 L F
.09814 .41745 m .07797 .3913 L .07554 .39803 L 1 1 0 r
F
.09598 .42421 m .09814 .41745 L .07554 .39803 L F
.74749 .45558 m .7268 .46303 L .72691 .46815 L .28 .044 0 r
F
.74749 .45558 m .74728 .45042 L .7268 .46303 L F
.47319 .09662 m .47333 .09138 L .46988 .09167 L .981 1 0 r
F
.47319 .09664 m .47333 .09139 L .46988 .09168 L .982 1 0 r
F
.61671 .84669 m .58197 .84671 L .58037 .85076 L .553 .032 0 r
F
.61671 .84669 m .61885 .84257 L .58197 .84671 L F
.80095 .71266 m .77017 .7183 L .7683 .72415 L .306 .017 0 r
F
.80095 .71266 m .80305 .70666 L .77017 .7183 L F
.7067 .29602 m .69794 .29772 L .69832 .30488 L 0 0 0 r
F
.7067 .29602 m .7064 .28888 L .69794 .29772 L F
.81595 .2759 m .7979 .28833 L .80191 .29425 L .293 .17 0 r
F
.81595 .2759 m .81169 .27013 L .7979 .28833 L F
.12484 .38794 m .10616 .36286 L .10339 .36918 L 1 1 0 r
F
.12237 .39431 m .12484 .38794 L .10339 .36918 L F
.11985 .39368 m .10262 .36894 L .09972 .37524 L F
.11725 .40008 m .11985 .39368 L .09972 .37524 L F
.12393 .55425 m .09448 .53182 L .09432 .5384 L 1 .849 0 r
F
.12391 .56068 m .12393 .55425 L .09432 .5384 L 1 .835 0 r
F
.4776 .09699 m .47333 .09194 L .47319 .09805 L .84 .949 0 r
F
.4776 .09699 m .47679 .09203 L .47333 .09194 L F
.4776 .097 m .47333 .09194 L .47319 .09807 L .841 .95 0 r
F
.4776 .097 m .47679 .09204 L .47333 .09194 L F
.74781 .34461 m .73625 .35019 L .73734 .35617 L .01 .01 0 r
F
.74781 .34461 m .74672 .3387 L .73625 .35019 L F
.11456 .56945 m .08631 .54633 L .08614 .55306 L 1 .848 0 r
F
.11452 .57608 m .11456 .56945 L .08614 .55306 L 1 .833 0 r
F
.56888 .55724 m .54525 .55801 L .54497 .561 L .721 .14 0 r
F
.56888 .55724 m .56928 .55426 L .54525 .55801 L F
.34567 .84215 m .30614 .8334 L .30825 .83776 L 1 .126 0 r
F
.34731 .84634 m .34567 .84215 L .30825 .83776 L .996 .103 0 r
F
.42681 .85352 m .38808 .84781 L .38924 .85167 L .888 .069 0 r
F
.42744 .85724 m .42681 .85352 L .38924 .85167 L .875 .067 0 r
F
.4649 .85785 m .42681 .85352 L .42744 .85724 L .821 .061 0 r
F
.16648 .65388 m .13122 .63613 L .13245 .64223 L 1 .636 0 r
F
.16768 .65975 m .16648 .65388 L .13245 .64223 L 1 .62 0 r
F
.61782 .50477 m .59713 .5076 L .59674 .51102 L .502 .06 0 r
F
.61782 .50477 m .61834 .50134 L .59713 .5076 L F
.81499 .27647 m .79687 .28893 L .80083 .29486 L .294 .168 0 r
F
.81499 .27647 m .81079 .27069 L .79687 .28893 L F
.47319 .09805 m .47333 .09194 L .46988 .09249 L 1 1 0 r
F
.84351 .62078 m .81567 .62922 L .81468 .63557 L .237 .018 0 r
F
.84351 .62078 m .8446 .61432 L .81567 .62922 L F
.47319 .09807 m .47333 .09194 L .46988 .09251 L 1 1 0 r
F
.28131 .21427 m .29764 .22909 L .28824 .22606 L .457 .019 0 r
F
.28131 .21427 m .28792 .21249 L .29764 .22909 L F
.75015 .76893 m .71827 .77269 L .71603 .77794 L .358 .017 0 r
F
.75015 .76893 m .75273 .76355 L .71827 .77269 L F
.46485 .86735 m .4648 .86364 L .42676 .86304 L .814 .059 0 r
F
.50229 .86681 m .4648 .86364 L .46485 .86735 L .755 .053 0 r
F
.50229 .86681 m .50284 .8631 L .4648 .86364 L F
.4688 .09727 m .4665 .09203 L .46452 .09827 L .871 .99 0 r
F
.31243 .77279 m .27239 .76741 L .27426 .77212 L 1 .33 0 r
F
.31388 .77743 m .31243 .77279 L .27426 .77212 L 1 .313 0 r
F
.20693 .74347 m .17035 .72742 L .17243 .73315 L 1 .45 0 r
F
.20884 .749 m .20693 .74347 L .17243 .73315 L 1 .428 0 r
F
.69977 .7977 m .66752 .80045 L .6653 .80508 L .397 .018 0 r
F
.69977 .7977 m .7024 .79296 L .66752 .80045 L F
.82011 .28172 m .80191 .29425 L .80584 .30023 L .287 .154 0 r
F
.82011 .28172 m .81595 .2759 L .80191 .29425 L F
.65844 .64233 m .62968 .64355 L .62918 .64791 L .603 .069 0 r
F
.65844 .64233 m .65925 .63807 L .62968 .64355 L F
.10559 .58527 m .07556 .56196 L .07571 .56885 L 1 .809 0 r
F
.10583 .59201 m .10559 .58527 L .07571 .56885 L 1 .793 0 r
F
.54372 .57264 m .51923 .57226 L .51902 .57515 L .806 .207 0 r
F
.54372 .57264 m .54405 .56978 L .51923 .57226 L F
.44252 .5719 m .41779 .56631 L .41787 .56934 L 1 .557 0 r
F
.44258 .57487 m .44252 .5719 L .41787 .56934 L 1 .546 0 r
F
.87154 .49013 m .84685 .50126 L .84757 .508 L .211 .037 0 r
F
.87154 .49013 m .87079 .48333 L .84685 .50126 L F
.84852 .62968 m .81955 .63777 L .81855 .64422 L .255 .022 0 r
F
.84852 .62968 m .84962 .62309 L .81955 .63777 L F
.65581 .82281 m .62257 .8243 L .62059 .82853 L .463 .023 0 r
F
.65581 .82281 m .65828 .8185 L .62257 .8243 L F
.39638 .12342 m .40292 .12336 L .40116 .13347 L .561 .035 0 r
F
.42804 .45346 m .42833 .45026 L .41035 .44844 L 1 .907 0 r
F
.72454 .5413 m .69841 .54658 L .6981 .55118 L .41 .057 0 r
F
.72454 .5413 m .72495 .5366 L .69841 .54658 L F
.46793 .57914 m .44258 .57487 L .44264 .57782 L 1 .462 0 r
F
.46792 .58203 m .46793 .57914 L .44264 .57782 L 1 .45 0 r
F
.49337 .58207 m .46793 .57914 L .46792 .58203 L .965 .371 0 r
F
.49337 .58207 m .49348 .57922 L .46793 .57914 L F
.43121 .78657 m .4309 .78189 L .39441 .78871 L .886 .211 0 r
F
.46583 .77845 m .4309 .78189 L .43121 .78657 L .826 .179 0 r
F
.46583 .77845 m .46583 .7737 L .4309 .78189 L F
.42804 .45346 m .41035 .44844 L .40989 .45153 L 1 .907 0 r
F
.42776 .45665 m .42804 .45346 L .40989 .45153 L 1 .897 0 r
F
.87727 .49714 m .85158 .50829 L .85232 .51511 L .226 .041 0 r
F
.87727 .49714 m .87646 .49024 L .85158 .50829 L F
.51858 .58083 m .49348 .57922 L .49337 .58207 L .886 .282 0 r
F
.51858 .58083 m .51881 .578 L .49348 .57922 L F
.12237 .39431 m .10339 .36918 L .10073 .37553 L 1 1 0 r
F
.12001 .40071 m .12237 .39431 L .10073 .37553 L F
.68933 .37329 m .6777 .37634 L .67627 .38256 L .029 0 0 r
F
.68933 .37329 m .69091 .367 L .6777 .37634 L F
.11725 .40008 m .09972 .37524 L .09692 .38159 L 1 1 0 r
F
.11475 .40651 m .11725 .40008 L .09692 .38159 L F
.42776 .45665 m .40989 .45153 L .40946 .45461 L 1 .897 0 r
F
.42749 .45982 m .42776 .45665 L .40946 .45461 L 1 .887 0 r
F
.81909 .2823 m .80083 .29486 L .8047 .30084 L .288 .151 0 r
F
.81909 .2823 m .81499 .27647 L .80083 .29486 L F
.59339 .53702 m .57109 .53891 L .57075 .54204 L .621 .072 0 r
F
.59339 .53702 m .59384 .53389 L .57109 .53891 L F
.57704 .85859 m .54152 .85759 L .5404 .86141 L .619 .038 0 r
F
.57704 .85859 m .57872 .85472 L .54152 .85759 L F
.09598 .42421 m .07554 .39803 L .07322 .40478 L 1 1 0 r
F
.09393 .43099 m .09598 .42421 L .07322 .40478 L F
.64111 .46849 m .62278 .47202 L .62217 .4759 L .357 .038 0 r
F
.64111 .46849 m .64188 .46458 L .62278 .47202 L F
.69232 .6006 m .66417 .60341 L .66369 .60779 L .525 .063 0 r
F
.69232 .6006 m .69304 .5962 L .66417 .60341 L F
.30208 .82443 m .26278 .81379 L .26518 .8185 L 1 .199 0 r
F
.30408 .82895 m .30208 .82443 L .26518 .8185 L 1 .175 0 r
F
.35492 .78435 m .31538 .78201 L .31694 .78653 L 1 .285 0 r
F
.35602 .78888 m .35492 .78435 L .31694 .78653 L 1 .266 0 r
F
.20392 .75402 m .16645 .73821 L .16871 .74396 L 1 .423 0 r
F
.20596 .75957 m .20392 .75402 L .16871 .74396 L 1 .401 0 r
F
.42749 .45982 m .40946 .45461 L .40906 .45768 L 1 .887 0 r
F
.42724 .46298 m .42749 .45982 L .40906 .45768 L 1 .877 0 r
F
.74766 .46071 m .72691 .46815 L .72698 .47324 L .28 .044 0 r
F
.74766 .46071 m .74749 .45558 L .72691 .46815 L F
.4068 .10847 m .4096 .10555 L .40271 .10616 L .486 .525 0 r
F
.59246 .7055 m .56362 .7069 L .56322 .7116 L .671 .077 0 r
F
.59246 .7055 m .59315 .70113 L .56362 .7069 L F
.82417 .28761 m .80584 .30023 L .80967 .30626 L .282 .138 0 r
F
.82417 .28761 m .82011 .28172 L .80584 .30023 L F
.56117 .72999 m .53164 .73256 L .53131 .73742 L .692 .09 0 r
F
.56117 .72999 m .56175 .72546 L .53164 .73256 L F
.53927 .86515 m .50284 .8631 L .50229 .86681 L .686 .045 0 r
F
.53927 .86515 m .5404 .86141 L .50284 .8631 L F
.42724 .46298 m .40906 .45768 L .40868 .46074 L 1 .877 0 r
F
.42701 .46612 m .42724 .46298 L .40868 .46074 L 1 .867 0 r
F
.74885 .35046 m .73734 .35617 L .73836 .36211 L .005 .009 0 r
F
.74885 .35046 m .74781 .34461 L .73734 .35617 L F
.66486 .15759 m .65308 .16347 L .65845 .16819 L .37 .423 0 r
F
.67034 .16213 m .65845 .16819 L .6637 .17302 L .361 .398 0 r
F
.67034 .16213 m .66486 .15759 L .65845 .16819 L F
.66474 .42601 m .6495 .42971 L .64839 .43449 L .211 .002 0 r
F
.66474 .42601 m .66605 .42116 L .6495 .42971 L F
.62456 .67804 m .59594 .67891 L .59547 .68339 L .642 .071 0 r
F
.62456 .67804 m .62535 .67379 L .59594 .67891 L F
.26713 .75297 m .22751 .74407 L .22955 .74909 L 1 .387 0 r
F
.26883 .75783 m .26713 .75297 L .22955 .74909 L 1 .371 0 r
F
.67568 .1668 m .6637 .17302 L .66883 .17796 L .351 .37 0 r
F
.67568 .1668 m .67034 .16213 L .6637 .17302 L F
.66486 .15759 m .65926 .15318 L .65308 .16347 L .37 .423 0 r
F
.38808 .84781 m .34924 .84065 L .35091 .84468 L .946 .077 0 r
F
.38924 .85167 m .38808 .84781 L .35091 .84468 L .933 .074 0 r
F
.68087 .1716 m .66883 .17796 L .67383 .183 L .339 .339 0 r
F
.68087 .1716 m .67568 .1668 L .66883 .17796 L F
.56846 .56018 m .54497 .561 L .54468 .56396 L .716 .13 0 r
F
.56846 .56018 m .56888 .55724 L .54497 .561 L F
.42701 .46612 m .40868 .46074 L .40832 .46379 L 1 .867 0 r
F
.42679 .46925 m .42701 .46612 L .40832 .46379 L 1 .857 0 r
F
.15173 .69026 m .1168 .671 L .11839 .67736 L 1 .585 0 r
F
.15325 .69642 m .15173 .69026 L .11839 .67736 L 1 .565 0 r
F
.5301 .75161 m .49922 .75528 L .499 .76017 L .72 .104 0 r
F
.5301 .75161 m .53054 .74695 L .49922 .75528 L F
.6173 .50815 m .59674 .51102 L .59635 .5144 L .498 .06 0 r
F
.6173 .50815 m .61782 .50477 L .59674 .51102 L F
.82309 .2882 m .8047 .30084 L .80847 .30687 L .282 .134 0 r
F
.82309 .2882 m .81909 .2823 L .8047 .30084 L F
.41134 .41615 m .39725 .41201 L .39615 .415 L 1 1 0 r
F
.41134 .41615 m .41215 .41293 L .39725 .41201 L F
.6859 .17656 m .67383 .183 L .67869 .18815 L .325 .304 0 r
F
.6859 .17656 m .68087 .1716 L .67383 .183 L F
.70672 .30316 m .69832 .30488 L .69842 .31204 L 0 0 0 r
F
.70672 .30316 m .7067 .29602 L .69832 .30488 L F
.25752 .78884 m .21956 .77571 L .22195 .78086 L 1 .309 0 r
F
.25961 .79379 m .25752 .78884 L .22195 .78086 L 1 .286 0 r
F
.157 .67981 m .12328 .66048 L .12467 .66677 L 1 .612 0 r
F
.15834 .68592 m .157 .67981 L .12467 .66677 L 1 .592 0 r
F
.12391 .56068 m .09432 .5384 L .09427 .54497 L 1 .835 0 r
F
.12399 .5671 m .12391 .56068 L .09427 .54497 L 1 .82 0 r
F
.42679 .46925 m .40832 .46379 L .40798 .46683 L 1 .857 0 r
F
.42659 .47236 m .42679 .46925 L .40798 .46683 L 1 .847 0 r
F
.79531 .70869 m .76568 .71473 L .76377 .72043 L .287 .011 0 r
F
.79531 .70869 m .79746 .70285 L .76568 .71473 L F
.61433 .8407 m .58026 .84106 L .57866 .84497 L .534 .028 0 r
F
.61433 .8407 m .61647 .83673 L .58026 .84106 L F
.69076 .18166 m .67869 .18815 L .6834 .19342 L .31 .266 0 r
F
.69076 .18166 m .6859 .17656 L .67869 .18815 L F
.28792 .21249 m .30606 .23119 L .29764 .22909 L .545 .036 0 r
F
.28792 .21249 m .29457 .21095 L .30606 .23119 L F
.44258 .57487 m .41787 .56934 L .41796 .57234 L 1 .546 0 r
F
.44264 .57782 m .44258 .57487 L .41796 .57234 L 1 .535 0 r
F
.82815 .29355 m .80967 .30626 L .81342 .31233 L .276 .123 0 r
F
.82815 .29355 m .82417 .28761 L .80967 .30626 L F
.11475 .40651 m .09692 .38159 L .09423 .38798 L 1 1 0 r
F
.11235 .41298 m .11475 .40651 L .09423 .38798 L F
.12001 .40071 m .10073 .37553 L .09818 .38192 L F
.11774 .40713 m .12001 .40071 L .09818 .38192 L F
.11452 .57608 m .08614 .55306 L .08608 .5598 L 1 .833 0 r
F
.11458 .5827 m .11452 .57608 L .08608 .5598 L 1 .817 0 r
F
.54337 .57548 m .51902 .57515 L .51881 .578 L .8 .195 0 r
F
.54337 .57548 m .54372 .57264 L .51902 .57515 L F
.46792 .58203 m .44264 .57782 L .44271 .58074 L 1 .45 0 r
F
.46791 .58488 m .46792 .58203 L .44271 .58074 L 1 .438 0 r
F
.49326 .58489 m .46792 .58203 L .46791 .58488 L .96 .359 0 r
F
.49326 .58489 m .49337 .58207 L .46792 .58203 L F
.70099 .80796 m .66839 .81025 L .66612 .81495 L .404 .019 0 r
F
.70099 .80796 m .70369 .80314 L .66839 .81025 L F
.69543 .18692 m .6834 .19342 L .68797 .19879 L .292 .222 0 r
F
.69543 .18692 m .69076 .18166 L .6834 .19342 L F
.42659 .47236 m .40798 .46683 L .40767 .46986 L 1 .847 0 r
F
.4264 .47545 m .42659 .47236 L .40767 .46986 L 1 .837 0 r
F
.72409 .54597 m .6981 .55118 L .69775 .55577 L .405 .056 0 r
F
.72409 .54597 m .72454 .5413 L .6981 .55118 L F
.34762 .83654 m .30879 .82774 L .31088 .83203 L 1 .123 0 r
F
.34924 .84065 m .34762 .83654 L .31088 .83203 L .996 .1 0 r
F
.09393 .43099 m .07322 .40478 L .07101 .41157 L 1 1 0 r
F
.09199 .43779 m .09393 .43099 L .07101 .41157 L F
.6576 .64657 m .62918 .64791 L .62865 .65226 L .591 .066 0 r
F
.6576 .64657 m .65844 .64233 L .62918 .64791 L F
.87217 .49693 m .84757 .508 L .84818 .51474 L .204 .035 0 r
F
.87217 .49693 m .87154 .49013 L .84757 .508 L F
.21833 .71821 m .18013 .70526 L .18205 .71075 L 1 .477 0 r
F
.22003 .72347 m .21833 .71821 L .18205 .71075 L 1 .461 0 r
F
.51834 .58362 m .49337 .58207 L .49326 .58489 L .881 .27 0 r
F
.51834 .58362 m .51858 .58083 L .49337 .58207 L F
.59292 .54012 m .57075 .54204 L .5704 .54514 L .615 .071 0 r
F
.59292 .54012 m .59339 .53702 L .57075 .54204 L F
.41768 .56019 m .39414 .55337 L .39417 .55647 L 1 .657 0 r
F
.41773 .56326 m .41768 .56019 L .39417 .55647 L 1 .646 0 r
F
.36443 .12743 m .36443 .11013 L .3578 .11324 L .962 .8 0 r
F
.36526 .12757 m .3661 .12676 L .36443 .12743 L .426 .32 0 r
F
.37191 .12584 m .3712 .10743 L .36981 .1163 L .87 .754 0 r
F
.37121 .12554 m .36981 .1163 L .36443 .11013 L .788 1 0 r
F
.3661 .12676 m .37121 .12554 L .36443 .11013 L .962 .8 0 r
F
.37121 .12554 m .36981 .1163 L .36855 .12438 L .87 .754 0 r
F
.37191 .12584 m .36981 .1163 L .37121 .12554 L F
.37191 .12584 m .37866 .12461 L .3712 .10743 L F
.37121 .12554 m .37526 .12254 L .36981 .1163 L .788 1 0 r
F
.37001 .12633 m .37191 .12584 L .37121 .12554 L .426 .32 0 r
F
.37291 .12937 m .37512 .12294 L .37121 .12554 L .788 1 0 r
F
.37512 .12294 m .37526 .12254 L .37121 .12554 L F
.36526 .12757 m .37001 .12633 L .37121 .12554 L .426 .32 0 r
F
.3661 .12676 m .37121 .12554 L .36855 .12438 L F
.36526 .12757 m .37121 .12554 L .3661 .12676 L F
.36665 .1322 m .37291 .12937 L .37121 .12554 L .962 .8 0 r
F
.36665 .1322 m .37121 .12554 L .3661 .12676 L F
.36665 .1322 m .3661 .12676 L .36443 .12743 L F
.3661 .12676 m .36443 .11013 L .36443 .12743 L F
.36443 .12743 m .36855 .12438 L .36207 .12704 L .426 .32 0 r
F
.3661 .12676 m .36855 .12438 L .36443 .12743 L F
.82699 .29416 m .80847 .30687 L .81215 .31296 L .276 .117 0 r
F
.82699 .29416 m .82309 .2882 L .80847 .30687 L F
.46495 .86145 m .4649 .85785 L .42744 .85724 L .807 .058 0 r
F
.50182 .86086 m .4649 .85785 L .46495 .86145 L .745 .051 0 r
F
.50182 .86086 m .50236 .85727 L .4649 .85785 L F
.39441 .78871 m .35602 .78888 L .35717 .79334 L .948 .246 0 r
F
.39513 .79323 m .39441 .78871 L .35717 .79334 L .942 .224 0 r
F
.43121 .78657 m .39441 .78871 L .39513 .79323 L .886 .211 0 r
F
.74536 .76398 m .71446 .76818 L .71219 .77327 L .342 .012 0 r
F
.74536 .76398 m .74796 .75876 L .71446 .76818 L F
.87797 .50404 m .85232 .51511 L .85297 .52193 L .22 .038 0 r
F
.87797 .50404 m .87727 .49714 L .85232 .51511 L F
.7478 .46581 m .72698 .47324 L .72703 .47829 L .279 .043 0 r
F
.7478 .46581 m .74766 .46071 L .72698 .47324 L F
.69989 .19234 m .68797 .19879 L .69237 .20428 L .271 .175 0 r
F
.69989 .19234 m .69543 .18692 L .68797 .19879 L F
.49851 .76965 m .46583 .7737 L .46583 .77845 L .762 .126 0 r
F
.49851 .76965 m .49877 .76496 L .46583 .7737 L F
.10583 .59201 m .07571 .56885 L .07597 .57572 L 1 .793 0 r
F
.10617 .59874 m .10583 .59201 L .07597 .57572 L 1 .776 0 r
F
.4264 .47545 m .40767 .46986 L .40738 .47288 L 1 .837 0 r
F
.42622 .47852 m .4264 .47545 L .40738 .47288 L 1 .827 0 r
F
.84231 .62722 m .81468 .63557 L .81361 .64188 L .231 .015 0 r
F
.84231 .62722 m .84351 .62078 L .81468 .63557 L F
.16768 .65975 m .13245 .64223 L .13377 .64829 L 1 .62 0 r
F
.16896 .66558 m .16768 .65975 L .13377 .64829 L 1 .604 0 r
F
.64037 .47233 m .62217 .4759 L .62158 .47971 L .355 .038 0 r
F
.64037 .47233 m .64111 .46849 L .62217 .4759 L F
.74985 .35624 m .73836 .36211 L .7393 .368 L .002 .007 0 r
F
.74985 .35624 m .74885 .35046 L .73836 .36211 L F
.69155 .60499 m .66369 .60779 L .66317 .61216 L .516 .062 0 r
F
.69155 .60499 m .69232 .6006 L .66369 .60779 L F
.83202 .29956 m .81342 .31233 L .81707 .31846 L .27 .107 0 r
F
.83202 .29956 m .82815 .29355 L .81342 .31233 L F
.79875 .71861 m .7683 .72415 L .76634 .72995 L .301 .014 0 r
F
.79875 .71861 m .80095 .71266 L .7683 .72415 L F
.6564 .83298 m .62297 .83408 L .62093 .83837 L .472 .024 0 r
F
.6564 .83298 m .65893 .82859 L .62297 .83408 L F
.42676 .86304 m .38797 .85742 L .38917 .86129 L .879 .068 0 r
F
.4274 .86677 m .42676 .86304 L .38917 .86129 L .865 .065 0 r
F
.46485 .86735 m .42676 .86304 L .4274 .86677 L .814 .059 0 r
F
.56802 .5631 m .54468 .56396 L .54437 .56688 L .71 .119 0 r
F
.56802 .5631 m .56846 .56018 L .54468 .56396 L F
.70413 .19793 m .69237 .20428 L .69661 .20987 L .247 .123 0 r
F
.70413 .19793 m .69989 .19234 L .69237 .20428 L F
.42622 .47852 m .40738 .47288 L .40711 .47588 L 1 .827 0 r
F
.42607 .48157 m .42622 .47852 L .40711 .47588 L 1 .816 0 r
F
.84731 .63624 m .81855 .64422 L .81745 .65063 L .249 .019 0 r
F
.84731 .63624 m .84852 .62968 L .81855 .64422 L F
.11235 .41298 m .09423 .38798 L .09165 .3944 L 1 1 0 r
F
.11005 .41947 m .11235 .41298 L .09165 .3944 L F
.61678 .5115 m .59635 .5144 L .59595 .51773 L .493 .059 0 r
F
.61678 .5115 m .6173 .50815 L .59635 .5144 L F
.38232 .1108 m .38539 .10458 L .37816 .10542 L .772 1 0 r
F
.38232 .1108 m .38903 .10871 L .38539 .10458 L F
.37866 .12461 m .38232 .1108 L .37816 .10542 L 1 .987 0 r
F
.65595 .15895 m .64564 .16243 L .65073 .16757 L .261 .215 0 r
F
.65595 .15895 m .65086 .15379 L .64564 .16243 L F
.57535 .85252 m .54044 .8518 L .53933 .85549 L .603 .035 0 r
F
.57535 .85252 m .57702 .84879 L .54044 .8518 L F
.11774 .40713 m .09818 .38192 L .09573 .38834 L 1 1 0 r
F
.11557 .41358 m .11774 .40713 L .09573 .38834 L F
.25596 .79918 m .2174 .78633 L .21993 .79148 L 1 .284 0 r
F
.25817 .80412 m .25596 .79918 L .21993 .79148 L 1 .26 0 r
F
.39455 .53119 m .37321 .52329 L .37298 .5265 L 1 .8 0 r
F
.83079 .30018 m .81215 .31296 L .81573 .31909 L .269 .1 0 r
F
.83079 .30018 m .82699 .29416 L .81215 .31296 L F
.38241 .11115 m .3886 .1186 L .38179 .11998 L .449 .017 0 r
F
.38241 .11115 m .38916 .1093 L .3886 .1186 L F
.30479 .81891 m .26628 .80818 L .26864 .81284 L 1 .198 0 r
F
.30677 .82336 m .30479 .81891 L .26864 .81284 L 1 .175 0 r
F
.44264 .57782 m .41796 .57234 L .41807 .57532 L 1 .535 0 r
F
.44271 .58074 m .44264 .57782 L .41807 .57532 L 1 .523 0 r
F
.66083 .16432 m .65073 .16757 L .65565 .17286 L .228 .15 0 r
F
.66083 .16432 m .65595 .15895 L .65073 .16757 L F
.63439 .1396 m .62857 .13526 L .6238 .14337 L .355 .419 0 r
F
.59171 .70983 m .56322 .7116 L .56278 .71626 L .654 .07 0 r
F
.59171 .70983 m .59246 .7055 L .56322 .7116 L F
.5382 .85909 m .50236 .85727 L .50182 .86086 L .673 .042 0 r
F
.5382 .85909 m .53933 .85549 L .50236 .85727 L F
.62372 .68227 m .59547 .68339 L .59496 .68786 L .627 .068 0 r
F
.62372 .68227 m .62456 .67804 L .59547 .68339 L F
.6877 .3794 m .67627 .38256 L .67479 .38861 L .019 0 0 r
F
.6877 .3794 m .68933 .37329 L .67627 .38256 L F
.41773 .56326 m .39417 .55647 L .39422 .55956 L 1 .646 0 r
F
.41779 .56631 m .41773 .56326 L .39422 .55956 L 1 .635 0 r
F
.66548 .16991 m .65565 .17286 L .6604 .1783 L .189 .088 0 r
F
.66548 .16991 m .66083 .16432 L .65565 .17286 L F
.42607 .48157 m .40711 .47588 L .40687 .47886 L 1 .816 0 r
F
.42593 .4846 m .42607 .48157 L .40687 .47886 L 1 .806 0 r
F
.8358 .30561 m .81707 .31846 L .82063 .32463 L .264 .092 0 r
F
.8358 .30561 m .83202 .29956 L .81707 .31846 L F
.70814 .20369 m .69661 .20987 L .70068 .21556 L .218 .083 0 r
F
.70814 .20369 m .70413 .19793 L .69661 .20987 L F
.31749 .25864 m .37421 .33852 L .37803 .34972 L .751 .175 0 r
F
.31749 .25864 m .32636 .26214 L .37421 .33852 L F
.66348 .43072 m .64839 .43449 L .64733 .43913 L .208 .002 0 r
F
.66348 .43072 m .66474 .42601 L .64839 .43449 L F
.20884 .749 m .17243 .73315 L .17461 .73883 L 1 .428 0 r
F
.21082 .75446 m .20884 .749 L .17461 .73883 L 1 .406 0 r
F
.54301 .57828 m .51881 .578 L .51858 .58083 L .795 .183 0 r
F
.54301 .57828 m .54337 .57548 L .51881 .578 L F
.46791 .58488 m .44271 .58074 L .44279 .58363 L 1 .438 0 r
F
.46791 .58771 m .46791 .58488 L .44279 .58363 L 1 .426 0 r
F
.49315 .58768 m .46791 .58488 L .46791 .58771 L .956 .346 0 r
F
.49315 .58768 m .49326 .58489 L .46791 .58488 L F
.56055 .73447 m .53131 .73742 L .53094 .74222 L .674 .072 0 r
F
.56055 .73447 m .56117 .72999 L .53131 .73742 L F
.29457 .21095 m .31341 .23207 L .30606 .23119 L .593 .045 0 r
F
.29457 .21095 m .30123 .20964 L .31341 .23207 L F
.09199 .43779 m .07101 .41157 L .06892 .41839 L 1 1 0 r
F
.09015 .44461 m .09199 .43779 L .06892 .41839 L F
.40292 .12336 m .40971 .12523 L .41037 .14788 L .737 .099 0 r
F
.70649 .31027 m .69842 .31204 L .69824 .31918 L 0 0 0 r
F
.70649 .31027 m .70672 .30316 L .69842 .31204 L F
.59244 .54319 m .5704 .54514 L .57004 .54821 L .61 .07 0 r
F
.59244 .54319 m .59292 .54012 L .5704 .54514 L F
.36172 .22781 m .36873 .23105 L .3715 .24788 L .794 .062 0 r
F
.36873 .23105 m .38033 .25674 L .3715 .24788 L .952 .113 0 r
F
.36873 .23105 m .37706 .23837 L .38033 .25674 L F
.35551 .19894 m .3733 .23948 L .3622 .22623 L .812 .134 0 r
F
.35551 .19894 m .36344 .20342 L .3733 .23948 L F
.12399 .5671 m .09427 .54497 L .09432 .55153 L 1 .82 0 r
F
.12417 .5735 m .12399 .5671 L .09432 .55153 L 1 .805 0 r
F
.74748 .77425 m .71603 .77794 L .71372 .78312 L .352 .014 0 r
F
.74748 .77425 m .75015 .76893 L .71603 .77794 L F
.7236 .55062 m .69775 .55577 L .69737 .56033 L .399 .054 0 r
F
.7236 .55062 m .72409 .54597 L .69775 .55577 L F
.66988 .1757 m .6604 .1783 L .66495 .18389 L .146 .079 0 r
F
.66988 .1757 m .66548 .16991 L .6604 .1783 L F
.31388 .77743 m .27426 .77212 L .2762 .77677 L 1 .313 0 r
F
.31538 .78201 m .31388 .77743 L .2762 .77677 L 1 .295 0 r
F
.39921 .22718 m .42056 .30289 L .41459 .29494 L .792 .228 0 r
F
.38914 .19186 m .41181 .27236 L .40253 .25555 L .715 .171 0 r
F
.38914 .19186 m .39669 .19983 L .41181 .27236 L F
.5181 .58638 m .49326 .58489 L .49315 .58768 L .876 .257 0 r
F
.5181 .58638 m .51834 .58362 L .49326 .58489 L F
.39443 .5344 m .37298 .5265 L .37279 .52969 L 1 .79 0 r
F
.11458 .5827 m .08608 .5598 L .08614 .56652 L 1 .817 0 r
F
.11474 .5893 m .11458 .5827 L .08614 .56652 L 1 .801 0 r
F
.74789 .47087 m .72703 .47829 L .72704 .48331 L .279 .042 0 r
F
.74789 .47087 m .7478 .46581 L .72703 .47829 L F
.7508 .36197 m .7393 .368 L .74017 .37384 L 0 .007 0 r
F
.7508 .36197 m .74985 .35624 L .7393 .368 L F
.42593 .4846 m .40687 .47886 L .40665 .48183 L 1 .806 0 r
F
.4258 .48761 m .42593 .4846 L .40665 .48183 L 1 .795 0 r
F
.87268 .50373 m .84818 .51474 L .84869 .52147 L .197 .032 0 r
F
.87268 .50373 m .87217 .49693 L .84818 .51474 L F
.83448 .30625 m .81573 .31909 L .81921 .32527 L .263 .085 0 r
F
.83448 .30625 m .83079 .30018 L .81573 .31909 L F
.7119 .20961 m .70068 .21556 L .70457 .22136 L .186 .075 0 r
F
.7119 .20961 m .70814 .20369 L .70068 .21556 L F
.43155 .79114 m .43121 .78657 L .39513 .79323 L .878 .187 0 r
F
.46584 .7831 m .43121 .78657 L .43155 .79114 L .817 .154 0 r
F
.46584 .7831 m .46583 .77845 L .43121 .78657 L F
.65671 .6508 m .62865 .65226 L .62808 .6566 L .578 .064 0 r
F
.65671 .6508 m .6576 .64657 L .62865 .65226 L F
.38797 .85742 m .349 .85044 L .35074 .85446 L .935 .075 0 r
F
.38917 .86129 m .38797 .85742 L .35074 .85446 L .921 .072 0 r
F
.11005 .41947 m .09165 .3944 L .08917 .40087 L 1 1 0 r
F
.10786 .42599 m .11005 .41947 L .08917 .40087 L F
.87856 .51094 m .85297 .52193 L .8535 .52875 L .215 .036 0 r
F
.87856 .51094 m .87797 .50404 L .85297 .52193 L F
.67404 .18168 m .66495 .18389 L .66932 .18962 L .098 .068 0 r
F
.67404 .18168 m .66988 .1757 L .66495 .18389 L F
.63965 .4761 m .62158 .47971 L .62101 .48346 L .353 .038 0 r
F
.63965 .4761 m .64037 .47233 L .62158 .47971 L F
.11557 .41358 m .09573 .38834 L .09339 .3948 L 1 1 0 r
F
.11351 .42005 m .11557 .41358 L .09339 .3948 L F
.47334 .09101 m .47097 .0866 L .46988 .09115 L .838 1 0 r
F
.47334 .09101 m .47347 .08668 L .47097 .0866 L F
.47334 .09101 m .47097 .08661 L .46988 .09116 L .839 1 0 r
F
.47334 .09101 m .47347 .08669 L .47097 .08661 L F
.20596 .75957 m .16871 .74396 L .17106 .74966 L 1 .401 0 r
F
.20809 .76505 m .20596 .75957 L .17106 .74966 L 1 .379 0 r
F
.15325 .69642 m .11839 .67736 L .12009 .68368 L 1 .565 0 r
F
.15485 .70254 m .15325 .69642 L .12009 .68368 L 1 .544 0 r
F
.69707 .80236 m .6653 .80508 L .66302 .80963 L .391 .015 0 r
F
.69707 .80236 m .69977 .7977 L .6653 .80508 L F
.83949 .31172 m .82063 .32463 L .82409 .33085 L .258 .081 0 r
F
.83949 .31172 m .8358 .30561 L .82063 .32463 L F
.61452 .85072 m .58037 .85076 L .57872 .85472 L .54 .029 0 r
F
.61452 .85072 m .61671 .84669 L .58037 .85076 L F
.69075 .60935 m .66317 .61216 L .66262 .61651 L .506 .06 0 r
F
.69075 .60935 m .69155 .60499 L .66317 .61216 L F
.52962 .7562 m .499 .76017 L .49877 .76496 L .704 .078 0 r
F
.52962 .7562 m .5301 .75161 L .499 .76017 L F
.47333 .09138 m .47097 .08686 L .46988 .09167 L .855 1 0 r
F
.47333 .09138 m .47347 .08693 L .47097 .08686 L F
.47333 .09139 m .47097 .08687 L .46988 .09168 L F
.47333 .09139 m .47347 .08693 L .47097 .08687 L F
.15834 .68592 m .12467 .66677 L .12617 .67302 L 1 .592 0 r
F
.15978 .69199 m .15834 .68592 L .12617 .67302 L 1 .572 0 r
F
.61626 .51481 m .59595 .51773 L .59555 .52104 L .489 .058 0 r
F
.61626 .51481 m .61678 .5115 L .59595 .51773 L F
.56757 .56598 m .54437 .56688 L .54405 .56978 L .705 .109 0 r
F
.56757 .56598 m .56802 .5631 L .54437 .56688 L F
.4258 .48761 m .40665 .48183 L .40646 .48478 L 1 .795 0 r
F
.42569 .4906 m .4258 .48761 L .40646 .48478 L 1 .784 0 r
F
.35602 .78888 m .31694 .78653 L .31855 .79098 L 1 .266 0 r
F
.35717 .79334 m .35602 .78888 L .31855 .79098 L 1 .246 0 r
F
.41779 .56631 m .39422 .55956 L .39428 .56264 L 1 .635 0 r
F
.41787 .56934 m .41779 .56631 L .39428 .56264 L 1 .624 0 r
F
.44271 .58074 m .41807 .57532 L .41819 .57828 L 1 .523 0 r
F
.44279 .58363 m .44271 .58074 L .41819 .57828 L 1 .511 0 r
F
.47333 .09194 m .47097 .08721 L .46988 .09249 L .879 1 0 r
F
.47333 .09194 m .47347 .08726 L .47097 .08721 L F
.47679 .09203 m .47347 .08726 L .47333 .09194 L .872 .989 0 r
F
.47333 .09194 m .47097 .08722 L .46988 .09251 L .88 1 0 r
F
.47333 .09194 m .47347 .08726 L .47097 .08722 L F
.47679 .09204 m .47347 .08726 L .47333 .09194 L .872 .99 0 r
F
.39425 .54078 m .39433 .53759 L .37263 .53288 L 1 .77 0 r
F
.34731 .84634 m .30825 .83776 L .31042 .84204 L .996 .103 0 r
F
.349 .85044 m .34731 .84634 L .31042 .84204 L .983 .082 0 r
F
.46988 .09115 m .46852 .08638 L .46648 .09073 L .876 1 0 r
F
.46988 .09115 m .47097 .0866 L .46852 .08638 L F
.46988 .09116 m .46852 .08639 L .46648 .09074 L .877 1 0 r
F
.46988 .09116 m .47097 .08661 L .46852 .08639 L F
.38903 .10871 m .3928 .10487 L .38539 .10458 L .527 .662 0 r
F
.38903 .10871 m .39578 .10691 L .3928 .10487 L F
.26883 .75783 m .22955 .74909 L .23166 .75407 L 1 .371 0 r
F
.27058 .76265 m .26883 .75783 L .23166 .75407 L 1 .353 0 r
F
.10617 .59874 m .07597 .57572 L .07634 .58258 L 1 .776 0 r
F
.10661 .60545 m .10617 .59874 L .07634 .58258 L 1 .758 0 r
F
.7154 .21569 m .70457 .22136 L .70827 .22725 L .148 .065 0 r
F
.7154 .21569 m .7119 .20961 L .70457 .22136 L F
.47679 .09203 m .47598 .08719 L .47347 .08726 L .872 .989 0 r
F
.47679 .09204 m .47598 .08719 L .47347 .08726 L .872 .99 0 r
F
.67795 .18783 m .66932 .18962 L .67348 .19549 L .046 .057 0 r
F
.67795 .18783 m .67404 .18168 L .66932 .18962 L F
.46988 .09167 m .46852 .08666 L .46649 .09123 L .904 1 0 r
F
.46988 .09167 m .47097 .08686 L .46852 .08666 L F
.46988 .09168 m .46852 .08667 L .46649 .09124 L .905 1 0 r
F
.46988 .09168 m .47097 .08687 L .46852 .08667 L F
.79307 .71448 m .76377 .72043 L .76177 .72609 L .281 .009 0 r
F
.79307 .71448 m .79531 .70869 L .76377 .72043 L F
.43544 .39412 m .43597 .39072 L .42231 .39308 L 1 1 0 r
F
.38916 .1093 m .39596 .10782 L .39329 .10723 L .322 .194 0 r
F
.38916 .1093 m .39329 .10723 L .3886 .1186 L F
.83807 .31237 m .81921 .32527 L .82259 .33149 L .256 .08 0 r
F
.83807 .31237 m .83448 .30625 L .81921 .32527 L F
.42744 .85724 m .38924 .85167 L .39044 .85544 L .875 .067 0 r
F
.42807 .86087 m .42744 .85724 L .39044 .85544 L .86 .064 0 r
F
.46495 .86145 m .42744 .85724 L .42807 .86087 L .807 .058 0 r
F
.65329 .82704 m .62059 .82853 L .61855 .83267 L .45 .02 0 r
F
.65329 .82704 m .65581 .82281 L .62059 .82853 L F
.84101 .63363 m .81361 .64188 L .81243 .64816 L .225 .013 0 r
F
.84101 .63363 m .84231 .62722 L .81361 .64188 L F
.09015 .44461 m .06892 .41839 L .06694 .42523 L 1 1 0 r
F
.08842 .45144 m .09015 .44461 L .06694 .42523 L F
.46791 .58771 m .44279 .58363 L .44287 .5865 L 1 .426 0 r
F
.46791 .59051 m .46791 .58771 L .44287 .5865 L 1 .414 0 r
F
.49303 .59044 m .46791 .58771 L .46791 .59051 L .951 .334 0 r
F
.49303 .59044 m .49315 .58768 L .46791 .58771 L F
.46988 .09249 m .46852 .08705 L .4665 .09201 L .946 1 0 r
F
.46988 .09249 m .47097 .08721 L .46852 .08705 L F
.46988 .09251 m .46852 .08705 L .4665 .09203 L .947 1 0 r
F
.46988 .09251 m .47097 .08722 L .46852 .08705 L F
.16896 .66558 m .13377 .64829 L .13518 .65432 L 1 .604 0 r
F
.17032 .67138 m .16896 .66558 L .13518 .65432 L 1 .587 0 r
F
.42569 .4906 m .40646 .48478 L .40629 .4877 L 1 .784 0 r
F
.4256 .49356 m .42569 .4906 L .40629 .4877 L 1 .772 0 r
F
.54263 .58105 m .51858 .58083 L .51834 .58362 L .79 .171 0 r
F
.54263 .58105 m .54301 .57828 L .51858 .58083 L F
.59194 .54622 m .57004 .54821 L .56967 .55125 L .605 .069 0 r
F
.59194 .54622 m .59244 .54319 L .57004 .54821 L F
.30408 .82895 m .26518 .8185 L .26766 .82314 L 1 .175 0 r
F
.30614 .8334 m .30408 .82895 L .26766 .82314 L 1 .151 0 r
F
.84307 .31788 m .82409 .33085 L .82746 .33712 L .251 .079 0 r
F
.84307 .31788 m .83949 .31172 L .82409 .33085 L F
.22003 .72347 m .18205 .71075 L .18404 .7162 L 1 .461 0 r
F
.2218 .72869 m .22003 .72347 L .18404 .7162 L 1 .444 0 r
F
.4649 .87097 m .46485 .86735 L .4274 .86677 L .8 .056 0 r
F
.50173 .87043 m .46485 .86735 L .4649 .87097 L .741 .05 0 r
F
.50173 .87043 m .50229 .86681 L .46485 .86735 L F
.75171 .36764 m .74017 .37384 L .74098 .37962 L 0 .006 0 r
F
.75171 .36764 m .7508 .36197 L .74017 .37384 L F
.10786 .42599 m .08917 .40087 L .08681 .40737 L 1 1 0 r
F
.10576 .43254 m .10786 .42599 L .08681 .40737 L F
.46649 .09123 m .46852 .08666 L .46616 .08633 L .903 1 0 r
F
.68162 .19412 m .67348 .19549 L .67744 .2015 L 0 .045 0 r
F
.68162 .19412 m .67795 .18783 L .67348 .19549 L F
.46649 .09124 m .46852 .08667 L .46616 .08634 L .904 1 0 r
F
.72307 .55525 m .69737 .56033 L .69695 .56488 L .393 .053 0 r
F
.72307 .55525 m .7236 .55062 L .69737 .56033 L F
.74795 .47591 m .72704 .48331 L .72702 .48829 L .279 .041 0 r
F
.74795 .47591 m .74789 .47087 L .72704 .48331 L F
.51784 .58911 m .49315 .58768 L .49303 .59044 L .871 .245 0 r
F
.51784 .58911 m .5181 .58638 L .49315 .58768 L F
.37291 .12937 m .37938 .12736 L .37526 .12254 L .788 1 0 r
F
.30123 .20964 m .3199 .23189 L .31341 .23207 L .622 .049 0 r
F
.30123 .20964 m .30791 .20858 L .3199 .23189 L F
.43597 .39072 m .42318 .39009 L .42231 .39308 L 1 1 0 r
F
.43597 .39072 m .43652 .38729 L .42318 .39009 L F
.39425 .54078 m .37263 .53288 L .37249 .53606 L 1 .77 0 r
F
.39419 .54395 m .39425 .54078 L .37249 .53606 L 1 .76 0 r
F
.25961 .79379 m .22195 .78086 L .22441 .78594 L 1 .286 0 r
F
.26177 .79866 m .25961 .79379 L .22441 .78594 L 1 .263 0 r
F
.84599 .64277 m .81745 .65063 L .81625 .65702 L .244 .017 0 r
F
.84599 .64277 m .84731 .63624 L .81745 .65063 L F
.62283 .68647 m .59496 .68786 L .5944 .69231 L .61 .065 0 r
F
.62283 .68647 m .62372 .68227 L .59496 .68786 L F
.11351 .42005 m .09339 .3948 L .09116 .40128 L 1 1 0 r
F
.11155 .42655 m .11351 .42005 L .09116 .40128 L F
.71863 .22192 m .70827 .22725 L .71179 .23324 L .105 .055 0 r
F
.71863 .22192 m .7154 .21569 L .70827 .22725 L F
.59091 .71413 m .56278 .71626 L .56229 .72088 L .635 .067 0 r
F
.59091 .71413 m .59171 .70983 L .56278 .71626 L F
.66228 .43529 m .64733 .43913 L .64631 .44364 L .206 .002 0 r
F
.66228 .43529 m .66348 .43072 L .64733 .43913 L F
.4665 .09201 m .46852 .08705 L .46616 .08676 L .947 1 0 r
F
.59113 .11246 m .58114 .1153 L .58751 .11892 L .456 .617 0 r
F
.4665 .09203 m .46852 .08705 L .46616 .08677 L .948 1 0 r
F
.12417 .5735 m .09432 .55153 L .09447 .55807 L 1 .805 0 r
F
.12445 .57987 m .12417 .5735 L .09447 .55807 L 1 .789 0 r
F
.87308 .51053 m .84869 .52147 L .84909 .52819 L .19 .029 0 r
F
.87308 .51053 m .87268 .50373 L .84869 .52147 L F
.41787 .56934 m .39428 .56264 L .39437 .56569 L 1 .624 0 r
F
.41796 .57234 m .41787 .56934 L .39437 .56569 L 1 .612 0 r
F
.79645 .7245 m .76634 .72995 L .76429 .7357 L .295 .012 0 r
F
.79645 .7245 m .79875 .71861 L .76634 .72995 L F
.49824 .77425 m .46583 .77845 L .46584 .7831 L .75 .1 0 r
F
.49824 .77425 m .49851 .76965 L .46583 .77845 L F
.57532 .86238 m .5404 .86141 L .53927 .86515 L .605 .035 0 r
F
.57532 .86238 m .57704 .85859 L .5404 .86141 L F
.84155 .31855 m .82259 .33149 L .82587 .33776 L .249 .077 0 r
F
.84155 .31855 m .83807 .31237 L .82259 .33149 L F
.63895 .47981 m .62101 .48346 L .62046 .48714 L .351 .038 0 r
F
.63895 .47981 m .63965 .4761 L .62101 .48346 L F
.706 .31735 m .69824 .31918 L .6978 .32629 L 0 0 0 r
F
.706 .31735 m .70649 .31027 L .69824 .31918 L F
.61573 .51808 m .59555 .52104 L .59513 .5243 L .484 .057 0 r
F
.61573 .51808 m .61626 .51481 L .59555 .52104 L F
.37866 .12461 m .37816 .10542 L .3712 .10743 L 1 .987 0 r
F
.68605 .38533 m .67479 .38861 L .67328 .39447 L .01 0 0 r
F
.68605 .38533 m .6877 .3794 L .67479 .38861 L F
.11474 .5893 m .08614 .56652 L .0863 .57323 L 1 .801 0 r
F
.115 .59589 m .11474 .5893 L .0863 .57323 L 1 .784 0 r
F
.74268 .76914 m .71219 .77327 L .70986 .7783 L .336 .009 0 r
F
.74268 .76914 m .74536 .76398 L .71219 .77327 L F
.44279 .58363 m .41819 .57828 L .41833 .58121 L 1 .511 0 r
F
.44287 .5865 m .44279 .58363 L .41833 .58121 L 1 .499 0 r
F
.87903 .51785 m .8535 .52875 L .85393 .53556 L .209 .033 0 r
F
.87903 .51785 m .87856 .51094 L .8535 .52875 L F
.5671 .56884 m .54405 .56978 L .54372 .57264 L .699 .098 0 r
F
.5671 .56884 m .56757 .56598 L .54405 .56978 L F
.39513 .79323 m .35717 .79334 L .35837 .79773 L .942 .224 0 r
F
.39588 .79766 m .39513 .79323 L .35837 .79773 L .935 .203 0 r
F
.43155 .79114 m .39513 .79323 L .39588 .79766 L .878 .187 0 r
F
.43652 .38729 m .42406 .38711 L .42318 .39009 L 1 1 0 r
F
.43652 .38729 m .43707 .38384 L .42406 .38711 L F
.5848 .10832 m .57483 .11128 L .58133 .11466 L .502 .67 0 r
F
.65577 .655 m .62808 .6566 L .62746 .66092 L .564 .062 0 r
F
.65577 .655 m .65671 .6508 L .62808 .6566 L F
.68504 .20053 m .67744 .2015 L .68118 .20763 L 0 .032 0 r
F
.68504 .20053 m .68162 .19412 L .67744 .2015 L F
.6899 .61369 m .66262 .61651 L .66202 .62085 L .496 .058 0 r
F
.6899 .61369 m .69075 .60935 L .66262 .61651 L F
.55988 .73889 m .53094 .74222 L .53054 .74695 L .656 .068 0 r
F
.55988 .73889 m .56055 .73447 L .53094 .74222 L F
.84655 .3241 m .82746 .33712 L .83073 .34343 L .245 .077 0 r
F
.84655 .3241 m .84307 .31788 L .82746 .33712 L F
.69822 .8127 m .66612 .81495 L .66379 .81958 L .398 .016 0 r
F
.69822 .8127 m .70099 .80796 L .66612 .81495 L F
.38924 .85167 m .35091 .84468 L .35262 .84862 L .933 .074 0 r
F
.39044 .85544 m .38924 .85167 L .35262 .84862 L .919 .071 0 r
F
.58455 .10914 m .57468 .1118 L .58114 .1153 L .475 .641 0 r
F
.59113 .11246 m .58455 .10914 L .58114 .1153 L .456 .617 0 r
F
.53811 .86879 m .50229 .86681 L .50173 .87043 L .671 .041 0 r
F
.53811 .86879 m .53927 .86515 L .50229 .86681 L F
.39419 .54395 m .37249 .53606 L .37238 .53923 L 1 .76 0 r
F
.39416 .5471 m .39419 .54395 L .37238 .53923 L 1 .75 0 r
F
.7216 .22829 m .71179 .23324 L .71511 .2393 L .057 .044 0 r
F
.7216 .22829 m .71863 .22192 L .71179 .23324 L F
.39578 .10691 m .39965 .10265 L .3928 .10487 L .591 .828 0 r
F
.08842 .45144 m .06694 .42523 L .06507 .4321 L 1 1 0 r
F
.08679 .4583 m .08842 .45144 L .06507 .4321 L F
.61215 .84458 m .57866 .84497 L .57702 .84879 L .52 .025 0 r
F
.61215 .84458 m .61433 .8407 L .57866 .84497 L F
.10576 .43254 m .08681 .40737 L .08455 .4139 L 1 1 0 r
F
.10377 .43911 m .10576 .43254 L .08455 .4139 L F
.59143 .54923 m .56967 .55125 L .56928 .55426 L .6 .067 0 r
F
.59143 .54923 m .59194 .54622 L .56967 .55125 L F
.43707 .38384 m .42496 .38414 L .42406 .38711 L 1 1 0 r
F
.43707 .38384 m .43763 .38037 L .42496 .38414 L F
.46791 .59051 m .44287 .5865 L .44296 .58934 L 1 .414 0 r
F
.4679 .59327 m .46791 .59051 L .44296 .58934 L 1 .401 0 r
F
.4929 .59317 m .46791 .59051 L .4679 .59327 L .947 .321 0 r
F
.4929 .59317 m .49303 .59044 L .46791 .59051 L F
.75259 .37325 m .74098 .37962 L .74174 .38535 L 0 .006 0 r
F
.75259 .37325 m .75171 .36764 L .74098 .37962 L F
.39596 .10782 m .39967 .10279 L .39329 .10723 L .695 .939 0 r
F
.39596 .10782 m .40271 .10616 L .39967 .10279 L F
.54224 .58379 m .51834 .58362 L .5181 .58638 L .784 .159 0 r
F
.54224 .58379 m .54263 .58105 L .51834 .58362 L F
.57808 .1053 m .56827 .10801 L .57483 .11128 L .514 .688 0 r
F
.5848 .10832 m .57808 .1053 L .57483 .11128 L .502 .67 0 r
F
.11155 .42655 m .09116 .40128 L .08904 .40779 L 1 1 0 r
F
.1097 .43306 m .11155 .42655 L .08904 .40779 L F
.34924 .84065 m .31088 .83203 L .31301 .83624 L .996 .1 0 r
F
.35091 .84468 m .34924 .84065 L .31301 .83624 L .983 .08 0 r
F
.84492 .32478 m .82587 .33776 L .82905 .34407 L .242 .075 0 r
F
.84492 .32478 m .84155 .31855 L .82587 .33776 L F
.21082 .75446 m .17461 .73883 L .17688 .74444 L 1 .406 0 r
F
.21289 .75987 m .21082 .75446 L .17688 .74444 L 1 .383 0 r
F
.74797 .48092 m .72702 .48829 L .72697 .49325 L .278 .041 0 r
F
.74797 .48092 m .74795 .47591 L .72702 .48829 L F
.68824 .20705 m .68118 .20763 L .68469 .21389 L 0 .02 0 r
F
.68824 .20705 m .68504 .20053 L .68118 .20763 L F
.10661 .60545 m .07634 .58258 L .07683 .58942 L 1 .758 0 r
F
.10716 .61213 m .10661 .60545 L .07683 .58942 L 1 .741 0 r
F
.57789 .10597 m .56815 .10843 L .57468 .1118 L .492 .664 0 r
F
.58455 .10914 m .57789 .10597 L .57468 .1118 L .475 .641 0 r
F
.41796 .57234 m .39437 .56569 L .39448 .56872 L 1 .612 0 r
F
.41807 .57532 m .41796 .57234 L .39448 .56872 L 1 .601 0 r
F
.37938 .12736 m .38179 .11998 L .37526 .12254 L 0 0 0 r
F
.25817 .80412 m .21993 .79148 L .22254 .79655 L 1 .26 0 r
F
.26044 .80899 m .25817 .80412 L .22254 .79655 L 1 .236 0 r
F
.72249 .55986 m .69695 .56488 L .69651 .56941 L .387 .051 0 r
F
.72249 .55986 m .72307 .55525 L .69695 .56488 L F
.51757 .5918 m .49303 .59044 L .4929 .59317 L .866 .232 0 r
F
.51757 .5918 m .51784 .58911 L .49303 .59044 L F
.15978 .69199 m .12617 .67302 L .12777 .67924 L 1 .572 0 r
F
.16131 .69801 m .15978 .69199 L .12777 .67924 L 1 .551 0 r
F
.39416 .5471 m .37238 .53923 L .37229 .54239 L 1 .75 0 r
F
.39414 .55024 m .39416 .5471 L .37229 .54239 L 1 .739 0 r
F
.15485 .70254 m .12009 .68368 L .12189 .68996 L 1 .544 0 r
F
.15655 .70861 m .15485 .70254 L .12189 .68996 L 1 .523 0 r
F
.84993 .33036 m .83073 .34343 L .8339 .34978 L .239 .074 0 r
F
.84993 .33036 m .84655 .3241 L .83073 .34343 L F
.65381 .83727 m .62093 .83837 L .61885 .84257 L .459 .021 0 r
F
.65381 .83727 m .6564 .83298 L .62093 .83837 L F
.72429 .23478 m .71511 .2393 L .71825 .24543 L .002 .031 0 r
F
.72429 .23478 m .7216 .22829 L .71511 .2393 L F
.43763 .38037 m .42587 .38119 L .42496 .38414 L 1 1 0 r
F
.43763 .38037 m .4382 .37687 L .42587 .38119 L F
.61519 .52131 m .59513 .5243 L .59471 .52753 L .48 .056 0 r
F
.61519 .52131 m .61573 .51808 L .59513 .5243 L F
.30791 .20858 m .32586 .23106 L .3199 .23189 L .644 .052 0 r
F
.30791 .20858 m .31465 .20785 L .32586 .23106 L F
.31538 .78201 m .2762 .77677 L .27819 .78136 L 1 .295 0 r
F
.31694 .78653 m .31538 .78201 L .27819 .78136 L 1 .276 0 r
F
.52911 .7607 m .49877 .76496 L .49851 .76965 L .688 .07 0 r
F
.52911 .7607 m .52962 .7562 L .49877 .76496 L F
.465 .86495 m .46495 .86145 L .42807 .86087 L .793 .055 0 r
F
.50126 .86435 m .46495 .86145 L .465 .86495 L .73 .048 0 r
F
.50126 .86435 m .50182 .86086 L .46495 .86145 L F
.30677 .82336 m .26864 .81284 L .27107 .81741 L 1 .175 0 r
F
.30879 .82774 m .30677 .82336 L .27107 .81741 L 1 .151 0 r
F
.74473 .7795 m .71372 .78312 L .71132 .78823 L .346 .011 0 r
F
.74473 .7795 m .74748 .77425 L .71372 .78312 L F
.63828 .48345 m .62046 .48714 L .61992 .49077 L .35 .038 0 r
F
.63828 .48345 m .63895 .47981 L .62046 .48714 L F
.44287 .5865 m .41833 .58121 L .41848 .58412 L 1 .499 0 r
F
.44296 .58934 m .44287 .5865 L .41848 .58412 L 1 .486 0 r
F
.8396 .64 m .81243 .64816 L .81115 .65441 L .219 .01 0 r
F
.8396 .64 m .84101 .63363 L .81243 .64816 L F
.56662 .57166 m .54372 .57264 L .54337 .57548 L .693 .087 0 r
F
.56662 .57166 m .5671 .56884 L .54372 .57264 L F
.57128 .1024 m .56164 .10485 L .56827 .10801 L .526 .704 0 r
F
.57808 .1053 m .57128 .1024 L .56827 .10801 L .514 .688 0 r
F
.87336 .51733 m .84909 .52819 L .84938 .53491 L .183 .026 0 r
F
.87336 .51733 m .87308 .51053 L .84909 .52819 L F
.38245 .46184 m .38319 .45863 L .36642 .45436 L 1 1 0 r
F
.43192 .79562 m .43155 .79114 L .39588 .79766 L .87 .163 0 r
F
.46585 .78765 m .43155 .79114 L .43192 .79562 L .807 .129 0 r
F
.46585 .78765 m .46584 .7831 L .43155 .79114 L F
.62188 .69065 m .5944 .69231 L .5938 .69673 L .593 .062 0 r
F
.62188 .69065 m .62283 .68647 L .5944 .69231 L F
.66114 .43973 m .64631 .44364 L .64534 .44803 L .205 .002 0 r
F
.66114 .43973 m .66228 .43529 L .64631 .44364 L F
.57114 .10294 m .56155 .10519 L .56815 .10843 L .508 .685 0 r
F
.57789 .10597 m .57114 .10294 L .56815 .10843 L .492 .664 0 r
F
.17032 .67138 m .13518 .65432 L .13669 .66031 L 1 .587 0 r
F
.17175 .67713 m .17032 .67138 L .13669 .66031 L 1 .57 0 r
F
.20809 .76505 m .17106 .74966 L .1735 .75529 L 1 .379 0 r
F
.2103 .77047 m .20809 .76505 L .1735 .75529 L 1 .355 0 r
F
.12445 .57987 m .09447 .55807 L .09474 .5646 L 1 .789 0 r
F
.12482 .58623 m .12445 .57987 L .09474 .5646 L 1 .773 0 r
F
.87938 .52475 m .85393 .53556 L .85425 .54237 L .203 .031 0 r
F
.87938 .52475 m .87903 .51785 L .85393 .53556 L F
.69099 .21406 m .68469 .21389 L .68797 .22026 L 0 .007 0 r
F
.69082 .21366 m .68469 .21389 L .69099 .21406 L F
.6912 .21365 m .68824 .20705 L .68469 .21389 L F
.6848 .2143 m .68252 .20733 L .68798 .20706 L .977 .135 0 r
F
.6881 .20734 m .68798 .20706 L .68824 .20705 L F
.6848 .2143 m .68798 .20706 L .6881 .20734 L F
.6912 .21365 m .69082 .21366 L .69099 .21406 L 0 .007 0 r
F
.84818 .33105 m .82905 .34407 L .83213 .35042 L .235 .072 0 r
F
.84818 .33105 m .84492 .32478 L .82905 .34407 L F
.4274 .86677 m .38917 .86129 L .3904 .86506 L .865 .065 0 r
F
.42806 .87041 m .4274 .86677 L .3904 .86506 L .85 .062 0 r
F
.4649 .87097 m .4274 .86677 L .42806 .87041 L .8 .056 0 r
F
.79073 .72021 m .76177 .72609 L .75968 .73168 L .275 .006 0 r
F
.79073 .72021 m .79307 .71448 L .76177 .72609 L F
.10377 .43911 m .08455 .4139 L .0824 .42047 L 1 1 0 r
F
.10188 .44571 m .10377 .43911 L .0824 .42047 L F
.4382 .37687 m .42681 .37825 L .42587 .38119 L F
.4382 .37687 m .43878 .37334 L .42681 .37825 L F
.689 .61801 m .66202 .62085 L .66139 .62518 L .486 .056 0 r
F
.689 .61801 m .6899 .61369 L .66202 .62085 L F
.57363 .85616 m .53933 .85549 L .5382 .85909 L .588 .031 0 r
F
.57363 .85616 m .57535 .85252 L .53933 .85549 L F
.08679 .4583 m .06507 .4321 L .06332 .43899 L 1 1 0 r
F
.08528 .46517 m .08679 .4583 L .06332 .43899 L 1 .996 0 r
F
.84456 .64926 m .81625 .65702 L .81495 .66337 L .238 .014 0 r
F
.84456 .64926 m .84599 .64277 L .81625 .65702 L F
.59007 .71839 m .56229 .72088 L .56175 .72546 L .616 .064 0 r
F
.59007 .71839 m .59091 .71413 L .56229 .72088 L F
.65478 .65918 m .62746 .66092 L .62681 .66523 L .55 .059 0 r
F
.65478 .65918 m .65577 .655 L .62746 .66092 L F
.115 .59589 m .0863 .57323 L .08658 .57994 L 1 .784 0 r
F
.11537 .60245 m .115 .59589 L .08658 .57994 L 1 .766 0 r
F
.27058 .76265 m .23166 .75407 L .23383 .75899 L 1 .353 0 r
F
.27239 .76741 m .27058 .76265 L .23383 .75899 L 1 .336 0 r
F
.75343 .37881 m .74174 .38535 L .74244 .39103 L .002 .005 0 r
F
.75343 .37881 m .75259 .37325 L .74174 .38535 L F
.1097 .43306 m .08904 .40779 L .08702 .41433 L 1 1 0 r
F
.10794 .43959 m .1097 .43306 L .08702 .41433 L F
.70528 .32436 m .6978 .32629 L .69711 .33335 L 0 0 0 r
F
.70528 .32436 m .706 .31735 L .6978 .32629 L F
.39414 .55024 m .37229 .54239 L .37224 .54553 L 1 .739 0 r
F
.39414 .55337 m .39414 .55024 L .37224 .54553 L 1 .728 0 r
F
.59091 .5522 m .56928 .55426 L .56888 .55724 L .594 .066 0 r
F
.59091 .5522 m .59143 .54923 L .56928 .55426 L F
.72672 .24136 m .71825 .24543 L .7212 .25163 L 0 .018 0 r
F
.72672 .24136 m .72429 .23478 L .71825 .24543 L F
.8532 .33667 m .8339 .34978 L .83698 .35617 L .233 .072 0 r
F
.8532 .33667 m .84993 .33036 L .8339 .34978 L F
.35717 .79334 m .31855 .79098 L .32021 .79537 L 1 .246 0 r
F
.35837 .79773 m .35717 .79334 L .32021 .79537 L .994 .225 0 r
F
.38564 .12457 m .39308 .12699 L .39355 .14025 L .814 .069 0 r
F
.41807 .57532 m .39448 .56872 L .39461 .57173 L 1 .601 0 r
F
.41819 .57828 m .41807 .57532 L .39461 .57173 L 1 .589 0 r
F
.4679 .59327 m .44296 .58934 L .44306 .59215 L 1 .401 0 r
F
.4679 .59601 m .4679 .59327 L .44306 .59215 L 1 .388 0 r
F
.49277 .59586 m .4679 .59327 L .4679 .59601 L .942 .307 0 r
F
.49277 .59586 m .4929 .59317 L .4679 .59327 L F
.2218 .72869 m .18404 .7162 L .18612 .7216 L 1 .444 0 r
F
.22364 .73387 m .2218 .72869 L .18612 .7216 L 1 .427 0 r
F
.74795 .48591 m .72697 .49325 L .72688 .49817 L .277 .04 0 r
F
.74795 .48591 m .74797 .48092 L .72697 .49325 L F
.54184 .5865 m .5181 .58638 L .51784 .58911 L .778 .146 0 r
F
.54184 .5865 m .54224 .58379 L .5181 .58638 L F
.57128 .1024 m .56443 .09962 L .56164 .10485 L .526 .704 0 r
F
.69429 .80694 m .66302 .80963 L .66068 .8141 L .384 .011 0 r
F
.69429 .80694 m .69707 .80236 L .66302 .80963 L F
.53704 .8626 m .50182 .86086 L .50126 .86435 L .657 .039 0 r
F
.53704 .8626 m .5382 .85909 L .50182 .86086 L F
.6844 .39107 m .67328 .39447 L .67178 .40016 L .003 0 0 r
F
.6844 .39107 m .68605 .38533 L .67328 .39447 L F
.56432 .10005 m .55488 .10208 L .56155 .10519 L .523 .705 0 r
F
.57114 .10294 m .56432 .10005 L .56155 .10519 L .508 .685 0 r
F
.72187 .56445 m .69651 .56941 L .69602 .57392 L .383 .05 0 r
F
.72187 .56445 m .72249 .55986 L .69651 .56941 L F
.51729 .59447 m .4929 .59317 L .49277 .59586 L .86 .218 0 r
F
.51729 .59447 m .51757 .5918 L .4929 .59317 L F
.32636 .26214 m .36984 .32567 L .37421 .33852 L .662 .123 0 r
F
.32636 .26214 m .33149 .26038 L .36984 .32567 L F
.61465 .52451 m .59471 .52753 L .59428 .53073 L .475 .056 0 r
F
.61465 .52451 m .61519 .52131 L .59471 .52753 L F
.37706 .23837 m .39162 .27325 L .38033 .25674 L 1 .244 0 r
F
.37706 .23837 m .38676 .25058 L .39162 .27325 L F
.36344 .20342 m .38472 .25546 L .3733 .23948 L .857 .217 0 r
F
.38472 .25546 m .38363 .25453 L .3733 .23948 L F
.3622 .22623 m .3733 .23948 L .37387 .24144 L 1 .18 0 r
F
.3622 .22623 m .37387 .24144 L .3713 .23995 L F
.3715 .24788 m .37475 .24583 L .36854 .23834 L .375 .214 0 r
F
.37475 .24583 m .37507 .24563 L .36854 .23834 L F
.3715 .24788 m .38033 .25674 L .37507 .24563 L F
.36172 .22781 m .3715 .24788 L .36492 .24514 L .794 .062 0 r
F
.36432 .23325 m .36631 .23663 L .36505 .23566 L 1 .18 0 r
F
.3622 .22623 m .36854 .23834 L .36432 .23325 L F
.3715 .24788 m .36854 .23834 L .36555 .2366 L .375 .214 0 r
F
.36854 .23834 m .36544 .23596 L .36555 .2366 L F
.36854 .23834 m .37839 .25714 L .36631 .23663 L 1 .18 0 r
F
.36854 .23834 m .36631 .23663 L .36432 .23325 L F
.3622 .22623 m .37507 .24563 L .36854 .23834 L F
.36854 .23834 m .36267 .21941 L .36544 .23596 L .375 .214 0 r
F
.3558 .22754 m .36172 .22781 L .36492 .24514 L .611 .044 0 r
F
.35243 .21752 m .3622 .22623 L .36431 .23319 L 1 .107 0 r
F
.36492 .24514 m .3715 .24788 L .3653 .23613 L .599 .486 0 r
F
.36492 .24514 m .3653 .23613 L .36505 .23594 L F
.36492 .24514 m .36505 .23566 L .36136 .2331 L F
.3558 .22754 m .36492 .24514 L .36025 .24688 L .611 .044 0 r
F
.35622 .22915 m .35891 .23265 L .35727 .23236 L 1 .107 0 r
F
.35075 .22943 m .3558 .22754 L .36025 .24688 L .464 .034 0 r
F
.35243 .21752 m .36136 .2331 L .35622 .22915 L 1 .107 0 r
F
.36492 .24514 m .36136 .2331 L .35764 .23298 L .599 .486 0 r
F
.36136 .2331 m .35768 .23243 L .35764 .23298 L F
.36136 .2331 m .36756 .24392 L .35891 .23265 L 1 .107 0 r
F
.36136 .2331 m .35891 .23265 L .35622 .22915 L F
.35243 .21752 m .36431 .23319 L .36136 .2331 L F
.36136 .2331 m .35834 .22293 L .35768 .23243 L .599 .486 0 r
F
.34376 .21225 m .35243 .21752 L .35697 .23144 L .911 .073 0 r
F
.36025 .24688 m .36492 .24514 L .35731 .23243 L .95 .86 0 r
F
.36025 .24688 m .35731 .23243 L .35728 .23242 L F
.36025 .24688 m .35727 .23236 L .35611 .23214 L F
.35075 .22943 m .36025 .24688 L .35726 .25208 L .464 .034 0 r
F
.36025 .24688 m .35611 .23214 L .35335 .23719 L .95 .86 0 r
F
.34646 .23293 m .35075 .22943 L .35726 .25208 L .39 .033 0 r
F
.35032 .23075 m .35442 .23332 L .35058 .23148 L .911 .073 0 r
F
.35442 .23332 m .35419 .23348 L .35058 .23148 L F
.34376 .21225 m .35611 .23214 L .35032 .23075 L F
.35611 .23214 m .35419 .23348 L .35412 .23377 L .95 .86 0 r
F
.35611 .23214 m .35412 .23377 L .35335 .23719 L F
.35611 .23214 m .3584 .23583 L .35032 .23075 L .911 .073 0 r
F
.34376 .21225 m .35697 .23144 L .35611 .23214 L F
.35611 .23214 m .35521 .22892 L .35419 .23348 L .95 .86 0 r
F
.35442 .23332 m .3584 .23583 L .35419 .23348 L .911 .073 0 r
F
.35728 .23242 m .35731 .23243 L .35727 .23236 L .95 .86 0 r
F
.35611 .23214 m .35697 .23144 L .35727 .23236 L .911 .073 0 r
F
.35611 .23214 m .35727 .23236 L .35521 .22892 L .95 .86 0 r
F
.35611 .23214 m .35727 .23236 L .3584 .23583 L .911 .073 0 r
F
.35727 .23236 m .35834 .22293 L .35521 .22892 L .599 .486 0 r
F
.35764 .23298 m .35768 .23243 L .35727 .23236 L F
.35768 .23243 m .35834 .22293 L .35727 .23236 L F
.35727 .23236 m .36756 .24392 L .3584 .23583 L 1 .107 0 r
F
.35891 .23265 m .36756 .24392 L .35727 .23236 L F
.36505 .23594 m .3653 .23613 L .36505 .23566 L .599 .486 0 r
F
.36136 .2331 m .36431 .23319 L .36505 .23566 L 1 .107 0 r
F
.36136 .2331 m .36505 .23566 L .35834 .22293 L .599 .486 0 r
F
.36136 .2331 m .36505 .23566 L .36756 .24392 L 1 .107 0 r
F
.36505 .23566 m .36267 .21941 L .35834 .22293 L .375 .214 0 r
F
.36555 .2366 m .36544 .23596 L .36505 .23566 L F
.36544 .23596 m .36267 .21941 L .36505 .23566 L F
.36505 .23566 m .37839 .25714 L .36756 .24392 L 1 .18 0 r
F
.36631 .23663 m .37839 .25714 L .36505 .23566 L F
.36854 .23834 m .37507 .24563 L .37044 .24197 L F
.3713 .23995 m .37387 .24144 L .37507 .24563 L F
.36854 .23834 m .37507 .24563 L .36267 .21941 L .375 .214 0 r
F
.37044 .24197 m .37507 .24563 L .37839 .25714 L 1 .18 0 r
F
.37636 .24836 m .37587 .24659 L .37507 .24563 L .304 .077 0 r
F
.38033 .25674 m .37812 .24985 L .37636 .24836 L F
.3733 .23948 m .37783 .24895 L .37507 .24563 L 1 .258 0 r
F
.37812 .24985 m .37783 .24895 L .37636 .24836 L .304 .077 0 r
F
.3733 .23948 m .38363 .25453 L .37783 .24895 L 1 .258 0 r
F
.37783 .24895 m .36797 .21822 L .37605 .24724 L .304 .077 0 r
F
.37783 .24895 m .37605 .24724 L .37636 .24836 L F
.37783 .24895 m .3854 .2571 L .3868 .26203 L 1 .258 0 r
F
.38363 .25453 m .3854 .2571 L .37783 .24895 L F
.38472 .25546 m .3854 .2571 L .38363 .25453 L .857 .217 0 r
F
.36344 .20342 m .37219 .21101 L .3854 .2571 L F
.3868 .26203 m .37314 .21677 L .36797 .21822 L .307 .072 0 r
F
.39162 .27325 m .38903 .26533 L .3868 .26203 L F
.38676 .25058 m .40422 .29559 L .39162 .27325 L 1 .327 0 r
F
.38033 .25674 m .39162 .27325 L .36797 .21822 L .304 .077 0 r
F
.38676 .25058 m .39718 .26666 L .40422 .29559 L 1 .327 0 r
F
.37219 .21101 m .39714 .2761 L .3854 .2571 L .894 .274 0 r
F
.39162 .27325 m .40422 .29559 L .39872 .28164 L .307 .072 0 r
F
.3854 .2571 m .39714 .2761 L .39872 .28164 L 1 .339 0 r
F
.3854 .2571 m .39872 .28164 L .38903 .26533 L F
.38903 .26533 m .39872 .28164 L .37314 .21677 L .307 .072 0 r
F
.39162 .27325 m .39872 .28164 L .38903 .26533 L F
.38903 .26533 m .39872 .28164 L .40334 .2978 L 1 .339 0 r
F
.3868 .26203 m .40334 .2978 L .39076 .27597 L F
.3854 .2571 m .38903 .26533 L .3868 .26203 L F
.38903 .26533 m .40334 .2978 L .3868 .26203 L F
.38903 .26533 m .38857 .26395 L .3868 .26203 L .307 .072 0 r
F
.38857 .26395 m .37314 .21677 L .3868 .26203 L F
.3812 .25599 m .3868 .26203 L .39076 .27597 L 1 .258 0 r
F
.37783 .24895 m .3868 .26203 L .3812 .25599 L F
.37507 .24563 m .39076 .27597 L .37839 .25714 L F
.37783 .24895 m .39076 .27597 L .37507 .24563 L F
.37587 .24659 m .37575 .24616 L .37507 .24563 L .304 .077 0 r
F
.37507 .24563 m .36797 .21822 L .36267 .21941 L F
.37575 .24616 m .36797 .21822 L .37507 .24563 L F
.69393 .22032 m .68797 .22026 L .69101 .22674 L 0 0 0 r
F
.69393 .22032 m .6912 .21365 L .68797 .22026 L F
.85133 .33738 m .83213 .35042 L .8351 .35681 L .228 .07 0 r
F
.85133 .33738 m .84818 .33105 L .83213 .35042 L F
.79405 .73035 m .76429 .7357 L .76216 .74139 L .29 .009 0 r
F
.79405 .73035 m .79645 .7245 L .76429 .7357 L F
.44296 .58934 m .41848 .58412 L .41864 .587 L 1 .486 0 r
F
.44306 .59215 m .44296 .58934 L .41864 .587 L 1 .474 0 r
F
.42599 .10429 m .43271 .10658 L .43265 .12779 L .746 .157 0 r
F
.55916 .74326 m .53054 .74695 L .5301 .75161 L .637 .065 0 r
F
.55916 .74326 m .55988 .73889 L .53054 .74695 L F
.63762 .48704 m .61992 .49077 L .61938 .49434 L .348 .037 0 r
F
.63762 .48704 m .63828 .48345 L .61992 .49077 L F
.38917 .86129 m .35074 .85446 L .35251 .85839 L .921 .072 0 r
F
.3904 .86506 m .38917 .86129 L .35251 .85839 L .906 .069 0 r
F
.39414 .55337 m .37224 .54553 L .37221 .54866 L 1 .728 0 r
F
.39417 .55647 m .39414 .55337 L .37221 .54866 L 1 .718 0 r
F
.56612 .57445 m .54337 .57548 L .54301 .57828 L .688 .076 0 r
F
.56612 .57445 m .56662 .57166 L .54337 .57548 L F
.49795 .77876 m .46584 .7831 L .46585 .78765 L .736 .075 0 r
F
.49795 .77876 m .49824 .77425 L .46584 .7831 L F
.61229 .85466 m .57872 .85472 L .57704 .85859 L .526 .026 0 r
F
.61229 .85466 m .61452 .85072 L .57872 .85472 L F
.10716 .61213 m .07683 .58942 L .07744 .59624 L 1 .741 0 r
F
.10782 .61879 m .10716 .61213 L .07744 .59624 L 1 .722 0 r
F
.72891 .24801 m .7212 .25163 L .72396 .25788 L 0 .003 0 r
F
.72891 .24801 m .72672 .24136 L .7212 .25163 L F
.10188 .44571 m .0824 .42047 L .08036 .42707 L 1 1 0 r
F
.1001 .45233 m .10188 .44571 L .08036 .42707 L F
.34284 .23766 m .35591 .26016 L .35619 .27073 L .376 .038 0 r
F
.34284 .23766 m .34646 .23293 L .35591 .26016 L F
.3398 .24331 m .34284 .23766 L .35619 .27073 L .386 .046 0 r
F
.85637 .34303 m .83698 .35617 L .83995 .3626 L .226 .07 0 r
F
.85637 .34303 m .8532 .33667 L .83698 .35617 L F
.26177 .79866 m .22441 .78594 L .22695 .79095 L 1 .263 0 r
F
.26399 .80346 m .26177 .79866 L .22695 .79095 L 1 .238 0 r
F
.349 .85044 m .31042 .84204 L .31265 .84624 L .983 .082 0 r
F
.35074 .85446 m .349 .85044 L .31265 .84624 L .969 .078 0 r
F
.56432 .10005 m .55743 .0973 L .55488 .10208 L .523 .705 0 r
F
.31465 .20785 m .33162 .23005 L .32586 .23106 L .667 .053 0 r
F
.31465 .20785 m .32149 .20755 L .33162 .23005 L F
.6507 .83118 m .61855 .83267 L .61647 .83673 L .436 .016 0 r
F
.6507 .83118 m .65329 .82704 L .61855 .83267 L F
.87353 .52412 m .84938 .53491 L .84957 .54162 L .176 .023 0 r
F
.87353 .52412 m .87336 .51733 L .84938 .53491 L F
.10794 .43959 m .08702 .41433 L .08512 .42089 L 1 1 0 r
F
.1063 .44613 m .10794 .43959 L .08512 .42089 L F
.75424 .38433 m .74244 .39103 L .74309 .39666 L .005 .005 0 r
F
.75424 .38433 m .75343 .37881 L .74244 .39103 L F
.47347 .08668 m .47207 .08215 L .47097 .0866 L .835 .989 0 r
F
.47347 .08668 m .47361 .08223 L .47207 .08215 L F
.47347 .08669 m .47207 .08215 L .47097 .08661 L F
.47347 .08669 m .47361 .08223 L .47207 .08215 L F
.3398 .24331 m .35619 .27073 L .35806 .28334 L .386 .046 0 r
F
.33718 .24947 m .3398 .24331 L .35806 .28334 L .426 .055 0 r
F
.08528 .46517 m .06332 .43899 L .06168 .44591 L 1 .996 0 r
F
.08387 .47205 m .08528 .46517 L .06168 .44591 L 1 .983 0 r
F
.41819 .57828 m .39461 .57173 L .39476 .57473 L 1 .589 0 r
F
.41833 .58121 m .41819 .57828 L .39476 .57473 L 1 .577 0 r
F
.47347 .08693 m .47207 .08225 L .47097 .08686 L .848 .99 0 r
F
.47347 .08693 m .47361 .08233 L .47207 .08225 L F
.47347 .08693 m .47207 .08225 L .47097 .08687 L F
.47347 .08693 m .47361 .08233 L .47207 .08225 L F
.30614 .8334 m .26766 .82314 L .2702 .8277 L 1 .151 0 r
F
.30825 .83776 m .30614 .8334 L .2702 .8277 L 1 .127 0 r
F
.34646 .23293 m .35726 .25208 L .35591 .26016 L .39 .033 0 r
F
.73991 .77423 m .70986 .7783 L .70745 .78326 L .329 .006 0 r
F
.73991 .77423 m .74268 .76914 L .70986 .7783 L F
.59036 .55514 m .56888 .55724 L .56846 .56018 L .588 .065 0 r
F
.59036 .55514 m .59091 .5522 L .56888 .55724 L F
.66005 .44406 m .64534 .44803 L .64441 .45231 L .203 .002 0 r
F
.66005 .44406 m .66114 .43973 L .64534 .44803 L F
.47097 .0866 m .47057 .08208 L .46852 .08638 L .887 1 0 r
F
.47097 .0866 m .47207 .08215 L .47057 .08208 L F
.47097 .08661 m .47057 .08208 L .46852 .08639 L .888 1 0 r
F
.47097 .08661 m .47207 .08215 L .47057 .08208 L F
.47347 .08726 m .47207 .08237 L .47097 .08721 L .865 .991 0 r
F
.47347 .08726 m .47361 .08245 L .47207 .08237 L F
.47598 .08719 m .47361 .08245 L .47347 .08726 L .902 1 0 r
F
.47347 .08726 m .47207 .08237 L .47097 .08722 L .865 .991 0 r
F
.47347 .08726 m .47361 .08245 L .47207 .08237 L F
.47598 .08719 m .47361 .08245 L .47347 .08726 L .902 1 0 r
F
.87961 .53166 m .85425 .54237 L .85446 .54918 L .197 .028 0 r
F
.87961 .53166 m .87938 .52475 L .85425 .54237 L F
.47598 .08719 m .47515 .08233 L .47361 .08245 L .902 1 0 r
F
.47598 .08719 m .47515 .08233 L .47361 .08245 L F
.39588 .79766 m .35837 .79773 L .35962 .80204 L .935 .203 0 r
F
.39668 .80201 m .39588 .79766 L .35962 .80204 L .927 .18 0 r
F
.43192 .79562 m .39588 .79766 L .39668 .80201 L .87 .163 0 r
F
.47097 .08686 m .47057 .0822 L .46852 .08666 L .91 1 0 r
F
.47097 .08686 m .47207 .08225 L .47057 .0822 L F
.47097 .08687 m .47057 .0822 L .46852 .08667 L F
.47097 .08687 m .47207 .08225 L .47057 .0822 L F
.40868 .46074 m .40906 .45768 L .39167 .4545 L 1 .91 0 r
F
.68805 .62231 m .66139 .62518 L .66072 .62949 L .475 .054 0 r
F
.68805 .62231 m .689 .61801 L .66139 .62518 L F
.12482 .58623 m .09474 .5646 L .09511 .57111 L 1 .773 0 r
F
.12528 .59256 m .12482 .58623 L .09511 .57111 L 1 .757 0 r
F
.74788 .49086 m .72688 .49817 L .72676 .50306 L .276 .039 0 r
F
.74788 .49086 m .74795 .48591 L .72688 .49817 L F
.62089 .69479 m .5938 .69673 L .59315 .70113 L .575 .059 0 r
F
.62089 .69479 m .62188 .69065 L .5938 .69673 L F
.47097 .08721 m .47057 .08235 L .46852 .08705 L .939 1 0 r
F
.47097 .08721 m .47207 .08237 L .47057 .08235 L F
.47097 .08722 m .47057 .08235 L .46852 .08705 L .94 1 0 r
F
.47097 .08722 m .47207 .08237 L .47057 .08235 L F
.4679 .59601 m .44306 .59215 L .44317 .59493 L 1 .388 0 r
F
.4679 .59871 m .4679 .59601 L .44317 .59493 L 1 .375 0 r
F
.49263 .59853 m .4679 .59601 L .4679 .59871 L .936 .294 0 r
F
.49263 .59853 m .49277 .59586 L .4679 .59601 L F
.57057 .18369 m .57072 .16128 L .5702 .1827 L 0 0 0 r
F
.57142 .17761 m .57072 .16128 L .57057 .18369 L F
.56702 .20437 m .5722 .17069 L .57309 .16569 L .729 .163 0 r
F
.57254 .16958 m .57309 .16569 L .57381 .16162 L F
.56702 .20437 m .57309 .16569 L .57254 .16958 L F
.57182 .18697 m .57142 .17761 L .57057 .18369 L 0 0 0 r
F
.69643 .22704 m .69101 .22674 L .6938 .23333 L F
.69643 .22704 m .69393 .22032 L .69101 .22674 L F
.40868 .46074 m .39167 .4545 L .39113 .45749 L 1 .91 0 r
F
.40832 .46379 m .40868 .46074 L .39113 .45749 L 1 .899 0 r
F
.42807 .86087 m .39044 .85544 L .39166 .85913 L .86 .064 0 r
F
.42873 .86441 m .42807 .86087 L .39166 .85913 L .845 .06 0 r
F
.465 .86495 m .42807 .86087 L .42873 .86441 L .793 .055 0 r
F
.39004 .43335 m .391 .43024 L .37618 .42712 L 1 1 0 r
F
.16131 .69801 m .12777 .67924 L .12948 .68542 L 1 .551 0 r
F
.16293 .70399 m .16131 .69801 L .12948 .68542 L 1 .53 0 r
F
.83808 .64633 m .81115 .65441 L .80978 .66061 L .212 .007 0 r
F
.83808 .64633 m .8396 .64 L .81115 .65441 L F
.85437 .34375 m .8351 .35681 L .83797 .36323 L .221 .067 0 r
F
.85437 .34375 m .85133 .33738 L .8351 .35681 L F
.54142 .58917 m .51784 .58911 L .51757 .5918 L .772 .133 0 r
F
.54142 .58917 m .54184 .5865 L .51784 .58911 L F
.65374 .66333 m .62681 .66523 L .6261 .66952 L .535 .056 0 r
F
.65374 .66333 m .65478 .65918 L .62681 .66523 L F
.15655 .70861 m .12189 .68996 L .1238 .6962 L 1 .523 0 r
F
.15835 .71464 m .15655 .70861 L .1238 .6962 L 1 .501 0 r
F
.39417 .55647 m .37221 .54866 L .3722 .55178 L 1 .718 0 r
F
.39422 .55956 m .39417 .55647 L .3722 .55178 L 1 .707 0 r
F
.46852 .08638 m .47057 .08208 L .46912 .08195 L .892 1 0 r
F
.46852 .08639 m .47057 .08208 L .46912 .08195 L .893 1 0 r
F
.33718 .24947 m .35806 .28334 L .36127 .29731 L .426 .055 0 r
F
.33465 .25554 m .33718 .24947 L .36127 .29731 L .488 .064 0 r
F
.37471 .50717 m .35611 .49861 L .35561 .50181 L 1 .913 0 r
F
.40832 .46379 m .39113 .45749 L .39062 .46047 L 1 .899 0 r
F
.40798 .46683 m .40832 .46379 L .39062 .46047 L 1 .888 0 r
F
.11537 .60245 m .08658 .57994 L .08697 .58662 L 1 .766 0 r
F
.11583 .609 m .11537 .60245 L .08697 .58662 L 1 .748 0 r
F
.46852 .08666 m .46912 .0821 L .46616 .08633 L .918 1 0 r
F
.46852 .08666 m .47057 .0822 L .46912 .0821 L F
.46852 .08667 m .46912 .0821 L .46616 .08634 L .919 1 0 r
F
.46852 .08667 m .47057 .0822 L .46912 .0821 L F
.6141 .52768 m .59428 .53073 L .59384 .53389 L .47 .055 0 r
F
.6141 .52768 m .61465 .52451 L .59428 .53073 L F
.21289 .75987 m .17688 .74444 L .17924 .75 L 1 .383 0 r
F
.21503 .76521 m .21289 .75987 L .17924 .75 L 1 .36 0 r
F
.7212 .56902 m .69602 .57392 L .6955 .57841 L .379 .048 0 r
F
.7212 .56902 m .72187 .56445 L .69602 .57392 L F
.46852 .08705 m .46912 .08229 L .46616 .08676 L .953 1 0 r
F
.46852 .08705 m .47057 .08235 L .46912 .08229 L F
.46852 .08705 m .46912 .08229 L .46616 .08677 L .954 1 0 r
F
.46852 .08705 m .47057 .08235 L .46912 .08229 L F
.51701 .5971 m .49277 .59586 L .49263 .59853 L .854 .205 0 r
F
.51701 .5971 m .51729 .59447 L .49277 .59586 L F
.69537 .81736 m .66379 .81958 L .66139 .82413 L .392 .013 0 r
F
.69537 .81736 m .69822 .8127 L .66379 .81958 L F
.73087 .2547 m .72396 .25788 L .72654 .26417 L 0 0 0 r
F
.73087 .2547 m .72891 .24801 L .72396 .25788 L F
.17175 .67713 m .13669 .66031 L .13829 .66627 L 1 .57 0 r
F
.17327 .68284 m .17175 .67713 L .13829 .66627 L 1 .552 0 r
F
.85944 .34944 m .83995 .3626 L .84283 .36907 L .22 .067 0 r
F
.85944 .34944 m .85637 .34303 L .83995 .3626 L F
.391 .43024 m .37741 .42419 L .37618 .42712 L 1 1 0 r
F
.391 .43024 m .39199 .42716 L .37741 .42419 L F
.40798 .46683 m .39062 .46047 L .39014 .46346 L 1 .888 0 r
F
.40767 .46986 m .40798 .46683 L .39014 .46346 L 1 .877 0 r
F
.44306 .59215 m .41864 .587 L .41882 .58986 L 1 .474 0 r
F
.44317 .59493 m .44306 .59215 L .41882 .58986 L 1 .461 0 r
F
.70435 .33128 m .69711 .33335 L .6962 .34032 L 0 0 0 r
F
.70435 .33128 m .70528 .32436 L .69711 .33335 L F
.46495 .87449 m .4649 .87097 L .42806 .87041 L .785 .053 0 r
F
.50116 .87395 m .4649 .87097 L .46495 .87449 L .726 .046 0 r
F
.50116 .87395 m .50173 .87043 L .4649 .87097 L F
.52856 .76513 m .49851 .76965 L .49824 .77425 L .671 .067 0 r
F
.52856 .76513 m .52911 .7607 L .49851 .76965 L F
.58917 .7226 m .56175 .72546 L .56117 .72999 L .596 .06 0 r
F
.58917 .7226 m .59007 .71839 L .56175 .72546 L F
.63697 .49057 m .61938 .49434 L .61886 .49786 L .346 .037 0 r
F
.63697 .49057 m .63762 .48704 L .61938 .49434 L F
.84302 .65572 m .81495 .66337 L .81355 .66968 L .232 .011 0 r
F
.84302 .65572 m .84456 .64926 L .81495 .66337 L F
.37436 .5104 m .35561 .50181 L .35514 .50501 L 1 .904 0 r
F
.37403 .51363 m .37436 .5104 L .35514 .50501 L 1 .895 0 r
F
.1001 .45233 m .08036 .42707 L .07844 .43369 L 1 1 0 r
F
.09842 .45897 m .1001 .45233 L .07844 .43369 L F
.33149 .26038 m .36537 .31172 L .36984 .32567 L .567 .072 0 r
F
.33149 .26038 m .33465 .25554 L .36537 .31172 L F
.33465 .25554 m .36127 .29731 L .36537 .31172 L .488 .064 0 r
F
.40767 .46986 m .39014 .46346 L .38969 .46643 L 1 .877 0 r
F
.40738 .47288 m .40767 .46986 L .38969 .46643 L 1 .866 0 r
F
.5656 .57721 m .54301 .57828 L .54263 .58105 L .681 .072 0 r
F
.5656 .57721 m .56612 .57445 L .54301 .57828 L F
.57357 .86606 m .53927 .86515 L .53811 .86879 L .59 .031 0 r
F
.57357 .86606 m .57532 .86238 L .53927 .86515 L F
.1063 .44613 m .08512 .42089 L .08333 .42747 L 1 1 0 r
F
.10475 .45269 m .1063 .44613 L .08333 .42747 L F
.45471 .08826 m .4584 .08448 L .4525 .08799 L .818 1 0 r
F
.75501 .38979 m .74309 .39666 L .74369 .40224 L .009 .005 0 r
F
.75501 .38979 m .75424 .38433 L .74309 .39666 L F
.45471 .08829 m .4584 .08451 L .45251 .08806 L .819 1 0 r
F
.46616 .08633 m .46912 .0821 L .46775 .08196 L .917 1 0 r
F
.46616 .08634 m .46912 .0821 L .46775 .08197 L .918 1 0 r
F
.41833 .58121 m .39476 .57473 L .39493 .5777 L 1 .577 0 r
F
.41848 .58412 m .41833 .58121 L .39493 .5777 L 1 .565 0 r
F
.39199 .42716 m .37866 .42128 L .37741 .42419 L 1 1 0 r
F
.39199 .42716 m .39299 .42409 L .37866 .42128 L F
.26044 .80899 m .22254 .79655 L .22523 .80156 L 1 .236 0 r
F
.26278 .81379 m .26044 .80899 L .22523 .80156 L 1 .211 0 r
F
.68277 .39663 m .67178 .40016 L .67029 .40567 L 0 0 0 r
F
.68277 .39663 m .6844 .39107 L .67178 .40016 L F
.46616 .08676 m .46775 .08221 L .46395 .0871 L .957 1 0 r
F
.46616 .08676 m .46912 .08229 L .46775 .08221 L F
.31694 .78653 m .27819 .78136 L .28024 .7859 L 1 .276 0 r
F
.31855 .79098 m .31694 .78653 L .28024 .7859 L 1 .257 0 r
F
.46616 .08677 m .46775 .08222 L .46395 .08712 L .958 1 0 r
F
.46616 .08677 m .46912 .08229 L .46775 .08222 L F
.39669 .19983 m .41971 .28669 L .41181 .27236 L .755 .211 0 r
F
.78829 .72589 m .75968 .73168 L .75751 .73722 L .269 .003 0 r
F
.78829 .72589 m .79073 .72021 L .75968 .73168 L F
.40738 .47288 m .38969 .46643 L .38926 .46939 L 1 .866 0 r
F
.40711 .47588 m .40738 .47288 L .38926 .46939 L 1 .855 0 r
F
.37403 .51363 m .35514 .50501 L .35471 .5082 L 1 .895 0 r
F
.37373 .51686 m .37403 .51363 L .35471 .5082 L 1 .885 0 r
F
.08387 .47205 m .06168 .44591 L .06016 .45284 L 1 .983 0 r
F
.08256 .47895 m .08387 .47205 L .06016 .45284 L 1 .97 0 r
F
.39044 .85544 m .35262 .84862 L .35438 .85247 L .919 .071 0 r
F
.39166 .85913 m .39044 .85544 L .35438 .85247 L .904 .068 0 r
F
.85729 .35017 m .83797 .36323 L .84073 .3697 L .213 .065 0 r
F
.85729 .35017 m .85437 .34375 L .83797 .36323 L F
.74189 .78468 m .71132 .78823 L .70886 .79327 L .34 .008 0 r
F
.74189 .78468 m .74473 .7795 L .71132 .78823 L F
.69871 .23382 m .6938 .23333 L .69634 .24001 L 0 0 0 r
F
.69871 .23382 m .69643 .22704 L .6938 .23333 L F
.5898 .55806 m .56846 .56018 L .56802 .5631 L .583 .064 0 r
F
.5898 .55806 m .59036 .55514 L .56846 .56018 L F
.39422 .55956 m .3722 .55178 L .37223 .55489 L 1 .707 0 r
F
.39428 .56264 m .39422 .55956 L .37223 .55489 L 1 .696 0 r
F
.2103 .77047 m .1735 .75529 L .17603 .76086 L 1 .355 0 r
F
.21258 .77582 m .2103 .77047 L .17603 .76086 L 1 .331 0 r
F
.41545 .42055 m .41612 .41746 L .40141 .41586 L 1 1 0 r
F
.60992 .84838 m .57702 .84879 L .57535 .85252 L .505 .022 0 r
F
.60992 .84838 m .61215 .84458 L .57702 .84879 L F
.4323 .79999 m .43192 .79562 L .39668 .80201 L .861 .139 0 r
F
.46586 .79209 m .43192 .79562 L .4323 .79999 L .796 .104 0 r
F
.46586 .79209 m .46585 .78765 L .43192 .79562 L F
.87358 .53091 m .84957 .54162 L .84965 .54831 L .168 .021 0 r
F
.87358 .53091 m .87353 .52412 L .84957 .54162 L F
.74777 .4958 m .72676 .50306 L .72661 .50793 L .275 .038 0 r
F
.74777 .4958 m .74788 .49086 L .72676 .50306 L F
.35091 .84468 m .31301 .83624 L .3152 .84037 L .983 .08 0 r
F
.35262 .84862 m .35091 .84468 L .3152 .84037 L .968 .077 0 r
F
.22364 .73387 m .18612 .7216 L .18827 .72694 L 1 .427 0 r
F
.22554 .73899 m .22364 .73387 L .18827 .72694 L 1 .409 0 r
F
.53692 .87233 m .50173 .87043 L .50116 .87395 L .656 .038 0 r
F
.53692 .87233 m .53811 .86879 L .50173 .87043 L F
.39308 .12699 m .40116 .13347 L .41687 .21987 L .841 .324 0 r
F
.40711 .47588 m .38926 .46939 L .38887 .47235 L 1 .855 0 r
F
.40687 .47886 m .40711 .47588 L .38887 .47235 L 1 .843 0 r
F
.10782 .61879 m .07744 .59624 L .07815 .60305 L 1 .722 0 r
F
.10857 .62543 m .10782 .61879 L .07815 .60305 L 1 .704 0 r
F
.27239 .76741 m .23383 .75899 L .23608 .76385 L 1 .336 0 r
F
.27426 .77212 m .27239 .76741 L .23608 .76385 L 1 .317 0 r
F
.73263 .2614 m .72654 .26417 L .72894 .27048 L 0 0 0 r
F
.73263 .2614 m .73087 .2547 L .72654 .26417 L F
.86239 .35589 m .84283 .36907 L .8456 .37557 L .213 .065 0 r
F
.86239 .35589 m .85944 .34944 L .84283 .36907 L F
.4679 .59871 m .44317 .59493 L .44328 .59768 L 1 .375 0 r
F
.4679 .60139 m .4679 .59871 L .44328 .59768 L 1 .361 0 r
F
.49249 .60116 m .4679 .59871 L .4679 .60139 L .931 .28 0 r
F
.49249 .60116 m .49263 .59853 L .4679 .59871 L F
.65901 .44827 m .64441 .45231 L .64353 .45649 L .202 .003 0 r
F
.65901 .44827 m .66005 .44406 L .64441 .45231 L F
.32149 .20755 m .33749 .22938 L .33162 .23005 L .699 .055 0 r
F
.32149 .20755 m .32852 .20793 L .33749 .22938 L F
.87973 .53856 m .85446 .54918 L .85457 .55597 L .19 .025 0 r
F
.87973 .53856 m .87961 .53166 L .85446 .54918 L F
.37373 .51686 m .35471 .5082 L .35431 .5114 L 1 .885 0 r
F
.37345 .52008 m .37373 .51686 L .35431 .5114 L 1 .876 0 r
F
.61353 .53081 m .59384 .53389 L .59339 .53702 L .465 .054 0 r
F
.61353 .53081 m .6141 .52768 L .59384 .53389 L F
.68706 .62659 m .66072 .62949 L .66 .63379 L .463 .051 0 r
F
.68706 .62659 m .68805 .62231 L .66072 .62949 L F
.41612 .41746 m .40237 .41296 L .40141 .41586 L 1 1 0 r
F
.41612 .41746 m .41682 .41438 L .40237 .41296 L F
.30879 .82774 m .27107 .81741 L .27356 .8219 L 1 .151 0 r
F
.31088 .83203 m .30879 .82774 L .27356 .8219 L 1 .126 0 r
F
.54099 .59182 m .51757 .5918 L .51729 .59447 L .766 .12 0 r
F
.54099 .59182 m .54142 .58917 L .51757 .5918 L F
.65116 .84149 m .61885 .84257 L .61671 .84669 L .446 .018 0 r
F
.65116 .84149 m .65381 .83727 L .61885 .84257 L F
.55839 .74756 m .5301 .75161 L .52962 .7562 L .617 .061 0 r
F
.55839 .74756 m .55916 .74326 L .5301 .75161 L F
.40687 .47886 m .38887 .47235 L .38851 .47529 L 1 .843 0 r
F
.40665 .48183 m .40687 .47886 L .38851 .47529 L 1 .831 0 r
F
.12528 .59256 m .09511 .57111 L .09559 .57761 L 1 .757 0 r
F
.12585 .59887 m .12528 .59256 L .09559 .57761 L 1 .741 0 r
F
.72049 .57356 m .6955 .57841 L .69495 .58289 L .375 .046 0 r
F
.72049 .57356 m .7212 .56902 L .6955 .57841 L F
.44317 .59493 m .41882 .58986 L .41901 .59269 L 1 .461 0 r
F
.44328 .59768 m .44317 .59493 L .41901 .59269 L 1 .447 0 r
F
.35837 .79773 m .32021 .79537 L .32193 .79969 L .994 .225 0 r
F
.35962 .80204 m .35837 .79773 L .32193 .79969 L .986 .204 0 r
F
.63634 .49406 m .61886 .49786 L .61834 .50134 L .344 .037 0 r
F
.63634 .49406 m .63697 .49057 L .61886 .49786 L F
.51671 .5997 m .49263 .59853 L .49249 .60116 L .848 .191 0 r
F
.51671 .5997 m .51701 .5971 L .49263 .59853 L F
.09842 .45897 m .07844 .43369 L .07662 .44035 L 1 1 0 r
F
.09684 .46563 m .09842 .45897 L .07662 .44035 L F
.79155 .73613 m .76216 .74139 L .75993 .74702 L .284 .006 0 r
F
.79155 .73613 m .79405 .73035 L .76216 .74139 L F
.41682 .41438 m .40336 .41008 L .40237 .41296 L 1 1 0 r
F
.41682 .41438 m .41755 .41131 L .40336 .41008 L F
.65265 .66746 m .6261 .66952 L .62535 .67379 L .52 .054 0 r
F
.65265 .66746 m .65374 .66333 L .6261 .66952 L F
.61984 .6989 m .59315 .70113 L .59246 .7055 L .556 .056 0 r
F
.61984 .6989 m .62089 .69479 L .59315 .70113 L F
.46395 .0871 m .46775 .08221 L .46649 .08218 L 1 1 0 r
F
.46395 .08712 m .46775 .08222 L .46649 .08219 L F
.37345 .52008 m .35431 .5114 L .35394 .51459 L 1 .876 0 r
F
.37321 .52329 m .37345 .52008 L .35394 .51459 L 1 .866 0 r
F
.39428 .56264 m .37223 .55489 L .37228 .55798 L 1 .696 0 r
F
.39437 .56569 m .39428 .56264 L .37228 .55798 L 1 .684 0 r
F
.75575 .39521 m .74369 .40224 L .74425 .40777 L .013 .006 0 r
F
.75575 .39521 m .75501 .38979 L .74369 .40224 L F
.41848 .58412 m .39493 .5777 L .39513 .58065 L 1 .565 0 r
F
.41864 .587 m .41848 .58412 L .39513 .58065 L 1 .552 0 r
F
.8601 .35662 m .84073 .3697 L .84339 .37619 L .206 .062 0 r
F
.8601 .35662 m .85729 .35017 L .84073 .3697 L F
.10475 .45269 m .08333 .42747 L .08165 .43408 L 1 1 0 r
F
.10332 .45926 m .10475 .45269 L .08165 .43408 L 1 .997 0 r
F
.40665 .48183 m .38851 .47529 L .38817 .47823 L 1 .831 0 r
F
.40646 .48478 m .40665 .48183 L .38817 .47823 L 1 .819 0 r
F
.56506 .57994 m .54263 .58105 L .54224 .58379 L .675 .07 0 r
F
.56506 .57994 m .5656 .57721 L .54263 .58105 L F
.11583 .609 m .08697 .58662 L .08747 .5933 L 1 .748 0 r
F
.1164 .61553 m .11583 .609 L .08747 .5933 L 1 .73 0 r
F
.70075 .24063 m .69634 .24001 L .69862 .24679 L 0 0 0 r
F
.70075 .24063 m .69871 .23382 L .69634 .24001 L F
.69144 .81145 m .66068 .8141 L .65828 .8185 L .377 .008 0 r
F
.69144 .81145 m .69429 .80694 L .66068 .8141 L F
.46505 .86837 m .465 .86495 L .42873 .86441 L .777 .052 0 r
F
.50069 .86775 m .465 .86495 L .46505 .86837 L .715 .044 0 r
F
.50069 .86775 m .50126 .86435 L .465 .86495 L F
.83646 .65263 m .80978 .66061 L .80831 .66678 L .206 .004 0 r
F
.83646 .65263 m .83808 .64633 L .80978 .66061 L F
.49764 .78316 m .46585 .78765 L .46586 .79209 L .722 .07 0 r
F
.49764 .78316 m .49795 .77876 L .46585 .78765 L F
.41755 .41131 m .40438 .40722 L .40336 .41008 L 1 1 0 r
F
.41755 .41131 m .41829 .40824 L .40438 .40722 L F
.58922 .56094 m .56802 .5631 L .56757 .56598 L .577 .062 0 r
F
.58922 .56094 m .5898 .55806 L .56802 .5631 L F
.86524 .36239 m .8456 .37557 L .84828 .38211 L .206 .062 0 r
F
.86524 .36239 m .86239 .35589 L .8456 .37557 L F
.08256 .47895 m .06016 .45284 L .05875 .45979 L 1 .97 0 r
F
.08137 .48585 m .08256 .47895 L .05875 .45979 L 1 .956 0 r
F
.73423 .26809 m .72894 .27048 L .73118 .27681 L 0 0 0 r
F
.73423 .26809 m .73263 .2614 L .72894 .27048 L F
.16293 .70399 m .12948 .68542 L .13129 .69155 L 1 .53 0 r
F
.16465 .70993 m .16293 .70399 L .13129 .69155 L 1 .508 0 r
F
.37321 .52329 m .35394 .51459 L .3536 .51778 L 1 .866 0 r
F
.37298 .5265 m .37321 .52329 L .3536 .51778 L 1 .856 0 r
F
.74762 .50071 m .72661 .50793 L .72643 .51277 L .273 .037 0 r
F
.74762 .50071 m .74777 .4958 L .72661 .50793 L F
.70324 .33811 m .6962 .34032 L .6951 .34719 L 0 0 0 r
F
.70324 .33811 m .70435 .33128 L .6962 .34032 L F
.57188 .8597 m .5382 .85909 L .53704 .8626 L .572 .028 0 r
F
.57188 .8597 m .57363 .85616 L .5382 .85909 L F
.56938 .13195 m .5644 .12286 L .56903 .13201 L 0 0 0 r
F
.56823 .12836 m .5644 .12286 L .56938 .13195 L F
.56851 .13815 m .56572 .12294 L .56612 .12175 L .84 .137 0 r
F
.56677 .1238 m .56612 .12175 L .56641 .12085 L F
.56851 .13815 m .56612 .12175 L .56677 .1238 L F
.57057 .13173 m .56823 .12836 L .56938 .13195 L 0 0 0 r
F
.42806 .87041 m .3904 .86506 L .39167 .86874 L .85 .062 0 r
F
.42873 .87395 m .42806 .87041 L .39167 .86874 L .834 .058 0 r
F
.46495 .87449 m .42806 .87041 L .42873 .87395 L .785 .053 0 r
F
.15835 .71464 m .1238 .6962 L .12581 .70238 L 1 .501 0 r
F
.16023 .72061 m .15835 .71464 L .12581 .70238 L 1 .479 0 r
F
.17327 .68284 m .13829 .66627 L .13999 .67218 L 1 .552 0 r
F
.17487 .68851 m .17327 .68284 L .13999 .67218 L 1 .534 0 r
F
.58822 .72677 m .56117 .72999 L .56055 .73447 L .575 .056 0 r
F
.58822 .72677 m .58917 .7226 L .56117 .72999 L F
.61295 .53391 m .59339 .53702 L .59292 .54012 L .46 .053 0 r
F
.61295 .53391 m .61353 .53081 L .59339 .53702 L F
.84137 .66215 m .81355 .66968 L .81205 .67595 L .226 .008 0 r
F
.84137 .66215 m .84302 .65572 L .81355 .66968 L F
.4525 .08799 m .45709 .08495 L .4507 .0884 L .502 .216 0 r
F
.4525 .08799 m .4584 .08448 L .45713 .08494 L F
.4525 .08799 m .45713 .08494 L .45698 .08503 L F
.45251 .08806 m .45621 .08561 L .45071 .08855 L .489 .214 0 r
F
.45621 .08561 m .45709 .08503 L .45211 .08778 L F
.45621 .08561 m .45211 .08778 L .45071 .08855 L F
.45251 .08806 m .4584 .08451 L .45709 .08503 L F
.45261 .09032 m .45844 .08567 L .4572 .08795 L .032 0 0 r
F
.45091 .08851 m .45368 .08695 L .45615 .08758 L .305 0 0 r
F
.45368 .08695 m .45709 .08503 L .45615 .08758 L F
.45261 .09032 m .4572 .08795 L .45102 .09437 L .032 0 0 r
F
.45102 .09437 m .4572 .08795 L .45674 .10259 L .595 .076 0 r
F
.4572 .08795 m .46357 .08342 L .46297 .0853 L .294 0 0 r
F
.45844 .08567 m .46436 .0817 L .46357 .08342 L .191 0 0 r
F
.45709 .08503 m .46291 .08238 L .45615 .08758 L 0 0 0 r
F
.45674 .10259 m .46297 .0853 L .46555 .21918 L .792 .322 0 r
F
.45615 .08758 m .46291 .08238 L .46263 .09027 L .7 .156 0 r
F
.45614 .08733 m .46262 .08986 L .46247 .0902 L .698 .151 0 r
F
.45615 .08758 m .46263 .09027 L .46247 .0902 L .7 .156 0 r
F
.45615 .08758 m .46247 .0902 L .45619 .08759 L F
.45071 .08855 m .45423 .08792 L .44946 .09124 L .305 0 0 r
F
.45423 .08792 m .45615 .08758 L .44987 .09101 L F
.45423 .08792 m .44987 .09101 L .44946 .09124 L F
.44943 .09133 m .45612 .10434 L .44929 .10491 L .751 .224 0 r
F
.44943 .0908 m .4496 .09113 L .44943 .09116 L F
.45061 .08857 m .45614 .08733 L .44943 .0908 L .289 0 0 r
F
.4507 .0884 m .45107 .08833 L .45061 .08857 L F
.45071 .08855 m .45408 .08669 L .45091 .08851 L .305 0 0 r
F
.45408 .08669 m .45709 .08503 L .45091 .08851 L F
.45107 .08833 m .45614 .08733 L .45061 .08857 L .289 0 0 r
F
.45698 .08503 m .45713 .08494 L .45709 .08495 L .502 .216 0 r
F
.4507 .0884 m .45709 .08495 L .45614 .08733 L .289 0 0 r
F
.44946 .09124 m .45615 .08758 L .45614 .08757 L .94 1 0 r
F
.44943 .0908 m .45589 .08746 L .4559 .0877 L .751 .224 0 r
F
.44943 .0908 m .4559 .0877 L .4496 .09113 L F
.44946 .09124 m .45614 .08757 L .4496 .09113 L .94 1 0 r
F
.45589 .08746 m .45614 .08757 L .45612 .10434 L .751 .224 0 r
F
.4496 .09113 m .45614 .08757 L .4554 .08682 L .94 1 0 r
F
.4496 .09113 m .4559 .0877 L .45612 .10434 L .751 .224 0 r
F
.45589 .08746 m .45614 .08733 L .45614 .08757 L F
.4584 .08451 m .46354 .0819 L .45709 .08503 L 0 0 0 r
F
.45709 .08503 m .46354 .0819 L .46291 .08238 L F
.45709 .08495 m .4629 .08231 L .45614 .08733 L F
.45614 .08733 m .4629 .08231 L .46262 .08986 L .698 .151 0 r
F
.45614 .08757 m .45794 .08803 L .4554 .08682 L .7 .156 0 r
F
.45615 .08758 m .45619 .08759 L .45614 .08757 L F
.45614 .08733 m .46247 .0902 L .45614 .08757 L .698 .151 0 r
F
.45619 .08759 m .45794 .08803 L .45614 .08757 L .7 .156 0 r
F
.44943 .09116 m .4554 .08682 L .44829 .08793 L .94 1 0 r
F
.44946 .09124 m .4496 .09113 L .44943 .09116 L F
.4496 .09113 m .4554 .08682 L .44943 .09116 L F
.44943 .09116 m .44962 .09119 L .44943 .09133 L .751 .224 0 r
F
.4496 .09113 m .44962 .09119 L .44943 .09116 L F
.44962 .09119 m .45612 .10434 L .44943 .09133 L F
.45614 .08757 m .46247 .0902 L .45612 .10434 L .698 .151 0 r
F
.45619 .08759 m .46247 .0902 L .45794 .08803 L .7 .156 0 r
F
.26399 .80346 m .22695 .79095 L .22957 .79589 L 1 .238 0 r
F
.26628 .80818 m .26399 .80346 L .22957 .79589 L 1 .214 0 r
F
.44296 .34685 m .43475 .35494 L .43371 .35787 L 1 .852 0 r
F
.44296 .34685 m .44356 .34263 L .43475 .35494 L F
.44946 .38256 m .44296 .34685 L .43371 .35787 L 1 .301 0 r
F
.46028 .3805 m .44356 .34263 L .44296 .34685 L .05 .019 0 r
F
.45994 .38281 m .44296 .34685 L .44946 .38256 L .071 .024 0 r
F
.45994 .38281 m .46028 .3805 L .44296 .34685 L F
.41829 .40824 m .40542 .40439 L .40438 .40722 L 1 1 0 r
F
.41829 .40824 m .41905 .40519 L .40542 .40439 L F
.4679 .60139 m .44328 .59768 L .4434 .6004 L 1 .361 0 r
F
.4679 .60403 m .4679 .60139 L .4434 .6004 L 1 .347 0 r
F
.49234 .60375 m .4679 .60139 L .4679 .60403 L .926 .266 0 r
F
.49234 .60375 m .49249 .60116 L .4679 .60139 L F
.73706 .77924 m .70745 .78326 L .70496 .78815 L .323 .003 0 r
F
.73706 .77924 m .73991 .77423 L .70745 .78326 L F
.87352 .53768 m .84965 .54831 L .84963 .555 L .161 .018 0 r
F
.87352 .53768 m .87358 .53091 L .84965 .54831 L F
.39437 .56569 m .37228 .55798 L .37236 .56105 L 1 .684 0 r
F
.39448 .56872 m .39437 .56569 L .37236 .56105 L 1 .673 0 r
F
.68118 .40202 m .67029 .40567 L .66883 .411 L 0 0 0 r
F
.68118 .40202 m .68277 .39663 L .67029 .40567 L F
.65802 .45239 m .64353 .45649 L .64269 .46058 L .201 .003 0 r
F
.65802 .45239 m .65901 .44827 L .64353 .45649 L F
.54054 .59442 m .51729 .59447 L .51701 .5971 L .76 .107 0 r
F
.54054 .59442 m .54099 .59182 L .51729 .59447 L F
.37298 .5265 m .3536 .51778 L .3533 .52096 L 1 .856 0 r
F
.37279 .52969 m .37298 .5265 L .3533 .52096 L 1 .847 0 r
F
.8628 .36312 m .84339 .37619 L .84594 .38272 L .198 .059 0 r
F
.8628 .36312 m .8601 .35662 L .84339 .37619 L F
.53586 .86601 m .50126 .86435 L .50069 .86775 L .641 .035 0 r
F
.53586 .86601 m .53704 .8626 L .50126 .86435 L F
.63571 .49749 m .61834 .50134 L .61782 .50477 L .342 .036 0 r
F
.63571 .49749 m .63634 .49406 L .61834 .50134 L F
.09684 .46563 m .07662 .44035 L .07492 .44703 L 1 1 0 r
F
.09538 .47231 m .09684 .46563 L .07492 .44703 L 1 .989 0 r
F
.39668 .80201 m .35962 .80204 L .36092 .80627 L .927 .18 0 r
F
.39751 .80626 m .39668 .80201 L .36092 .80627 L .918 .158 0 r
F
.4323 .79999 m .39668 .80201 L .39751 .80626 L .861 .139 0 r
F
.87973 .54546 m .85457 .55597 L .85456 .56276 L .184 .023 0 r
F
.87973 .54546 m .87973 .53856 L .85457 .55597 L F
.68602 .63084 m .66 .63379 L .65925 .63807 L .451 .049 0 r
F
.68602 .63084 m .68706 .62659 L .66 .63379 L F
.44328 .59768 m .41901 .59269 L .41922 .59549 L 1 .447 0 r
F
.4434 .6004 m .44328 .59768 L .41922 .59549 L 1 .434 0 r
F
.21503 .76521 m .17924 .75 L .18169 .7555 L 1 .36 0 r
F
.21726 .77049 m .21503 .76521 L .18169 .7555 L 1 .336 0 r
F
.75646 .40059 m .74425 .40777 L .74476 .41325 L .017 .006 0 r
F
.75646 .40059 m .75575 .39521 L .74425 .40777 L F
.41864 .587 m .39513 .58065 L .39534 .58357 L 1 .552 0 r
F
.41882 .58986 m .41864 .587 L .39534 .58357 L 1 .54 0 r
F
.71972 .57808 m .69495 .58289 L .69435 .58734 L .371 .045 0 r
F
.71972 .57808 m .72049 .57356 L .69495 .58289 L F
.52798 .76947 m .49824 .77425 L .49795 .77876 L .653 .063 0 r
F
.52798 .76947 m .52856 .76513 L .49824 .77425 L F
.44356 .34263 m .43579 .352 L .43475 .35494 L 1 .768 0 r
F
.46028 .3805 m .46063 .37821 L .44356 .34263 L .05 .019 0 r
F
.10332 .45926 m .08165 .43408 L .08008 .4407 L 1 .997 0 r
F
.10198 .46584 m .10332 .45926 L .08008 .4407 L 1 .985 0 r
F
.5164 .60226 m .49249 .60116 L .49234 .60375 L .842 .177 0 r
F
.5164 .60226 m .51671 .5997 L .49249 .60116 L F
.70257 .24748 m .69862 .24679 L .70062 .25365 L 0 0 0 r
F
.70257 .24748 m .70075 .24063 L .69862 .24679 L F
.41905 .40519 m .40649 .40158 L .40542 .40439 L 1 1 0 r
F
.41905 .40519 m .41984 .40214 L .40649 .40158 L F
.10857 .62543 m .07815 .60305 L .07899 .60983 L 1 .704 0 r
F
.10943 .63204 m .10857 .62543 L .07899 .60983 L 1 .684 0 r
F
.64805 .83524 m .61647 .83673 L .61433 .8407 L .424 .013 0 r
F
.64805 .83524 m .6507 .83118 L .61647 .83673 L F
.86798 .36892 m .84828 .38211 L .85084 .38868 L .2 .06 0 r
F
.86798 .36892 m .86524 .36239 L .84828 .38211 L F
.30825 .83776 m .2702 .8277 L .27281 .83217 L 1 .127 0 r
F
.31042 .84204 m .30825 .83776 L .27281 .83217 L 1 .103 0 r
F
.61 .85851 m .57704 .85859 L .57532 .86238 L .511 .022 0 r
F
.61 .85851 m .61229 .85466 L .57704 .85859 L F
.56451 .58264 m .54224 .58379 L .54184 .5865 L .669 .069 0 r
F
.56451 .58264 m .56506 .57994 L .54224 .58379 L F
.73568 .27473 m .73118 .27681 L .73327 .28314 L 0 0 0 r
F
.73568 .27473 m .73423 .26809 L .73118 .27681 L F
.32852 .20793 m .34371 .22963 L .33749 .22938 L .748 .058 0 r
F
.32852 .20793 m .33588 .20932 L .34371 .22963 L F
.3904 .86506 m .35251 .85839 L .35433 .86223 L .906 .069 0 r
F
.39167 .86874 m .3904 .86506 L .35433 .86223 L .891 .066 0 r
F
.35074 .85446 m .31265 .84624 L .31493 .85034 L .969 .078 0 r
F
.35251 .85839 m .35074 .85446 L .31493 .85034 L .953 .074 0 r
F
.12585 .59887 m .09559 .57761 L .09618 .58409 L 1 .741 0 r
F
.12651 .60515 m .12585 .59887 L .09618 .58409 L 1 .724 0 r
F
.37279 .52969 m .3533 .52096 L .35303 .52414 L 1 .847 0 r
F
.37263 .53288 m .37279 .52969 L .35303 .52414 L 1 .837 0 r
F
.78576 .73151 m .75751 .73722 L .75525 .7427 L .262 0 0 r
F
.78576 .73151 m .78829 .72589 L .75751 .73722 L F
.58862 .56379 m .56757 .56598 L .5671 .56884 L .57 .061 0 r
F
.58862 .56379 m .58922 .56094 L .56757 .56598 L F
.65151 .67156 m .62535 .67379 L .62456 .67804 L .503 .051 0 r
F
.65151 .67156 m .65265 .66746 L .62535 .67379 L F
.74743 .5056 m .72643 .51277 L .72621 .51758 L .272 .036 0 r
F
.74743 .5056 m .74762 .50071 L .72643 .51277 L F
.08137 .48585 m .05875 .45979 L .05747 .46676 L 1 .956 0 r
F
.08029 .49277 m .08137 .48585 L .05747 .46676 L 1 .942 0 r
F
.46921 .4837 m .45019 .48032 L .45004 .48302 L 1 .735 0 r
F
.46921 .4837 m .46924 .48099 L .45019 .48032 L F
.46918 .48641 m .46921 .4837 L .45004 .48302 L 1 .727 0 r
F
.48847 .48348 m .46924 .48099 L .46921 .4837 L 1 .682 0 r
F
.48855 .48619 m .46921 .4837 L .46918 .48641 L 1 .675 0 r
F
.48855 .48619 m .48847 .48348 L .46921 .4837 L F
.46924 .48099 m .45035 .47761 L .45019 .48032 L 1 .742 0 r
F
.46924 .48099 m .46927 .47827 L .45035 .47761 L F
.48847 .48348 m .48838 .48076 L .46924 .48099 L 1 .682 0 r
F
.46918 .48641 m .45004 .48302 L .44989 .48573 L 1 .727 0 r
F
.46915 .48912 m .46918 .48641 L .44989 .48573 L 1 .72 0 r
F
.48863 .48891 m .46918 .48641 L .46915 .48912 L 1 .668 0 r
F
.48863 .48891 m .48855 .48619 L .46918 .48641 L F
.66983 .12929 m .6598 .13751 L .66619 .14111 L .415 .564 0 r
F
.66983 .12929 m .66326 .12608 L .6598 .13751 L F
.46927 .47827 m .45051 .4749 L .45035 .47761 L 1 .748 0 r
F
.46927 .47827 m .4693 .47556 L .45051 .4749 L F
.41984 .40214 m .40759 .39879 L .40649 .40158 L 1 1 0 r
F
.41984 .40214 m .42064 .39911 L .40759 .39879 L F
.46915 .48912 m .44989 .48573 L .44976 .48843 L 1 .72 0 r
F
.46912 .49183 m .46915 .48912 L .44976 .48843 L 1 .713 0 r
F
.48871 .49162 m .46915 .48912 L .46912 .49183 L 1 .66 0 r
F
.48871 .49162 m .48863 .48891 L .46915 .48912 L F
.39448 .56872 m .37236 .56105 L .37247 .56411 L 1 .673 0 r
F
.39461 .57173 m .39448 .56872 L .37247 .56411 L 1 .661 0 r
F
.4693 .47556 m .45068 .47219 L .45051 .4749 L 1 .755 0 r
F
.4693 .47556 m .46933 .47284 L .45068 .47219 L F
.61875 .70297 m .59246 .7055 L .59171 .70983 L .536 .052 0 r
F
.61875 .70297 m .61984 .6989 L .59246 .7055 L F
.69245 .82194 m .66139 .82413 L .65893 .82859 L .386 .01 0 r
F
.69245 .82194 m .69537 .81736 L .66139 .82413 L F
.61236 .53698 m .59292 .54012 L .59244 .54319 L .454 .051 0 r
F
.61236 .53698 m .61295 .53391 L .59292 .54012 L F
.22554 .73899 m .18827 .72694 L .1905 .73224 L 1 .409 0 r
F
.22751 .74407 m .22554 .73899 L .1905 .73224 L 1 .391 0 r
F
.67635 .1326 m .66619 .14111 L .67252 .14481 L .409 .549 0 r
F
.67635 .1326 m .66983 .12929 L .66619 .14111 L F
.1164 .61553 m .08747 .5933 L .08809 .59995 L 1 .73 0 r
F
.11708 .62203 m .1164 .61553 L .08809 .59995 L 1 .711 0 r
F
.46912 .49183 m .44976 .48843 L .44962 .49114 L 1 .713 0 r
F
.4691 .49453 m .46912 .49183 L .44962 .49114 L 1 .706 0 r
F
.48878 .49432 m .46912 .49183 L .4691 .49453 L 1 .653 0 r
F
.48878 .49432 m .48871 .49162 L .46912 .49183 L F
.46933 .47284 m .45085 .46948 L .45068 .47219 L 1 .762 0 r
F
.46933 .47284 m .46936 .47012 L .45085 .46948 L F
.66932 .13018 m .65945 .13813 L .6658 .14179 L .402 .539 0 r
F
.66932 .13018 m .66283 .12686 L .65945 .13813 L F
.47361 .08223 m .47319 .07777 L .47207 .08215 L .855 1 0 r
F
.47361 .08223 m .47375 .07778 L .47319 .07777 L F
.47515 .08214 m .47375 .07778 L .47361 .08223 L .835 .995 0 r
F
.47361 .08223 m .47319 .07777 L .47207 .08215 L .855 1 0 r
F
.47361 .08223 m .47375 .07778 L .47319 .07777 L F
.47515 .08214 m .47375 .07778 L .47361 .08223 L .835 .995 0 r
F
.49683 .48299 m .48838 .48076 L .48847 .48348 L .947 .628 0 r
F
.49683 .48299 m .48836 .48076 L .48845 .48348 L .958 .642 0 r
F
.50758 .48236 m .49811 .48157 L .49683 .48299 L F
.49583 .48409 m .49683 .48299 L .48847 .48348 L .946 .621 0 r
F
.50779 .48508 m .50758 .48236 L .49683 .48299 L .958 .635 0 r
F
.49653 .48415 m .49683 .48299 L .49583 .48409 L .946 .621 0 r
F
.49653 .48415 m .49683 .48299 L .48845 .48348 L .958 .635 0 r
F
.50779 .48508 m .49683 .48299 L .49653 .48415 L F
.50772 .48507 m .49683 .48299 L .49653 .48415 L .946 .621 0 r
F
.50772 .48507 m .50752 .48235 L .49683 .48299 L F
.49811 .48157 m .49706 .48148 L .49683 .48299 L .958 .642 0 r
F
.49706 .48148 m .48838 .48076 L .49683 .48299 L .947 .628 0 r
F
.49706 .48148 m .48836 .48076 L .49683 .48299 L .958 .642 0 r
F
.50752 .48235 m .49706 .48148 L .49683 .48299 L .947 .628 0 r
F
.50758 .48236 m .50737 .47964 L .49735 .48023 L .958 .642 0 r
F
.49706 .48148 m .49735 .48023 L .48838 .48076 L .947 .628 0 r
F
.49706 .48148 m .49735 .48023 L .48836 .48076 L .958 .642 0 r
F
.50758 .48236 m .49735 .48023 L .49706 .48148 L F
.50752 .48235 m .50732 .47964 L .49735 .48023 L .947 .628 0 r
F
.50752 .48235 m .49735 .48023 L .49706 .48148 L F
.49626 .48574 m .48847 .48348 L .48855 .48619 L .946 .621 0 r
F
.49626 .48574 m .48845 .48348 L .48853 .48619 L .958 .635 0 r
F
.50779 .48508 m .49763 .48424 L .49626 .48574 L F
.49533 .48675 m .49626 .48574 L .48855 .48619 L .945 .613 0 r
F
.50798 .4878 m .50779 .48508 L .49626 .48574 L .957 .628 0 r
F
.49596 .4868 m .49626 .48574 L .49533 .48675 L .945 .613 0 r
F
.49596 .4868 m .49626 .48574 L .48853 .48619 L .957 .628 0 r
F
.50798 .4878 m .49787 .48602 L .49711 .4869 L F
.49562 .4885 m .48855 .48619 L .48863 .48891 L .945 .613 0 r
F
.49562 .4885 m .48853 .48619 L .48861 .4889 L .957 .628 0 r
F
.50798 .4878 m .49596 .4868 L .49562 .4885 L F
.49596 .4868 m .48855 .48619 L .49562 .4885 L .945 .613 0 r
F
.49596 .4868 m .48853 .48619 L .49562 .4885 L .957 .628 0 r
F
.5079 .48778 m .49596 .4868 L .49562 .4885 L .945 .613 0 r
F
.50816 .49051 m .50798 .4878 L .49756 .48839 L .957 .62 0 r
F
.50816 .49051 m .49756 .48839 L .49724 .48876 L F
.50816 .49051 m .49562 .4885 L .49534 .48945 L F
.49493 .49125 m .48863 .48891 L .48871 .49162 L .945 .605 0 r
F
.49493 .49125 m .48861 .4889 L .48869 .49161 L .957 .62 0 r
F
.50816 .49051 m .49534 .48945 L .49493 .49125 L F
.49534 .48945 m .48863 .48891 L .49493 .49125 L .945 .605 0 r
F
.49534 .48945 m .48861 .4889 L .49493 .49125 L .957 .62 0 r
F
.50808 .49049 m .49534 .48945 L .49493 .49125 L .945 .605 0 r
F
.50833 .49322 m .50816 .49051 L .49686 .49115 L .956 .613 0 r
F
.50833 .49322 m .49686 .49115 L .49655 .49149 L F
.50833 .49322 m .49493 .49125 L .49466 .4921 L F
.49417 .49401 m .48871 .49162 L .48878 .49432 L .944 .597 0 r
F
.49417 .49401 m .48869 .49161 L .48876 .49431 L .956 .613 0 r
F
.50833 .49322 m .49466 .4921 L .49417 .49401 L F
.49466 .4921 m .48871 .49162 L .49417 .49401 L .944 .597 0 r
F
.49466 .4921 m .48869 .49161 L .49417 .49401 L .956 .613 0 r
F
.50824 .49319 m .49466 .4921 L .49417 .49401 L .944 .597 0 r
F
.50849 .49593 m .50833 .49322 L .49609 .4939 L .955 .605 0 r
F
.50849 .49593 m .49609 .4939 L .49579 .49423 L F
.50849 .49593 m .49417 .49401 L .49391 .49473 L F
.48884 .49702 m .48878 .49432 L .4691 .49453 L 1 .645 0 r
F
.49333 .49676 m .48878 .49432 L .48884 .49702 L .943 .589 0 r
F
.49333 .49676 m .48876 .49431 L .48883 .49701 L .955 .605 0 r
F
.50849 .49593 m .49391 .49473 L .49333 .49676 L F
.49391 .49473 m .48878 .49432 L .49333 .49676 L .943 .589 0 r
F
.49391 .49473 m .48876 .49431 L .49333 .49676 L .955 .605 0 r
F
.5084 .49589 m .49391 .49473 L .49333 .49676 L .943 .589 0 r
F
.50864 .49864 m .50849 .49593 L .49525 .49666 L .955 .598 0 r
F
.50864 .49864 m .49525 .49666 L .49496 .49696 L F
.50864 .49864 m .49333 .49676 L .49311 .49736 L F
.48884 .49702 m .4691 .49453 L .46907 .49723 L 1 .645 0 r
F
.4889 .49972 m .48884 .49702 L .46907 .49723 L .999 .637 0 r
F
.49241 .49952 m .48884 .49702 L .4889 .49972 L .942 .581 0 r
F
.49241 .49952 m .48883 .49701 L .48889 .49971 L .955 .598 0 r
F
.50864 .49864 m .49311 .49736 L .49241 .49952 L F
.49311 .49736 m .48884 .49702 L .49241 .49952 L .942 .581 0 r
F
.49311 .49736 m .48883 .49701 L .49241 .49952 L .955 .598 0 r
F
.50854 .49859 m .49311 .49736 L .49241 .49952 L .942 .581 0 r
F
.50878 .50134 m .50864 .49864 L .49433 .49941 L .954 .59 0 r
F
.50878 .50134 m .49433 .49941 L .49405 .4997 L F
.50878 .50134 m .49241 .49952 L .49223 .49998 L F
.49141 .50227 m .4889 .49972 L .48896 .50241 L .941 .573 0 r
F
.49141 .50227 m .48889 .49971 L .48895 .5024 L .954 .59 0 r
F
.50878 .50134 m .49223 .49998 L .49141 .50227 L F
.49223 .49998 m .4889 .49972 L .49141 .50227 L .941 .573 0 r
F
.49223 .49998 m .48889 .49971 L .49141 .50227 L .954 .59 0 r
F
.50868 .50128 m .49223 .49998 L .49141 .50227 L .941 .573 0 r
F
.50891 .50403 m .50878 .50134 L .49332 .50216 L .953 .583 0 r
F
.50891 .50403 m .49332 .50216 L .49306 .50243 L F
.50891 .50403 m .49141 .50227 L .49127 .50259 L F
.49031 .50502 m .48896 .50241 L .48901 .50509 L .94 .565 0 r
F
.49031 .50502 m .48895 .5024 L .489 .50508 L .953 .583 0 r
F
.50891 .50403 m .49127 .50259 L .49031 .50502 L F
.49127 .50259 m .48896 .50241 L .49031 .50502 L .94 .565 0 r
F
.49127 .50259 m .48895 .5024 L .49031 .50502 L .953 .583 0 r
F
.5088 .50396 m .49127 .50259 L .49031 .50502 L .94 .565 0 r
F
.50903 .50672 m .50891 .50403 L .49222 .50491 L .952 .575 0 r
F
.50903 .50672 m .49222 .50491 L .49197 .50517 L F
.50903 .50672 m .49031 .50502 L .49023 .50518 L F
.4891 .50776 m .48901 .50509 L .48905 .50777 L .939 .557 0 r
F
.4891 .50776 m .489 .50508 L .48905 .50777 L .952 .575 0 r
F
.50903 .50672 m .49023 .50518 L .4891 .50776 L F
.49023 .50518 m .48901 .50509 L .4891 .50776 L .939 .557 0 r
F
.49023 .50518 m .489 .50508 L .4891 .50776 L .952 .575 0 r
F
.50891 .50664 m .49023 .50518 L .4891 .50776 L .939 .557 0 r
F
.50915 .50941 m .50903 .50672 L .4891 .50776 L .951 .567 0 r
F
.4891 .50777 m .4891 .50776 L .48905 .50777 L .938 .548 0 r
F
.4891 .50777 m .4891 .50776 L .48905 .50777 L .951 .567 0 r
F
.50915 .50941 m .4891 .50776 L .4891 .50777 L F
.48929 .50778 m .48933 .50775 L .4891 .50776 L .938 .548 0 r
F
.48929 .50778 m .4891 .50776 L .4891 .50777 L F
.50901 .5093 m .50891 .50664 L .48933 .50775 L F
.50901 .5093 m .48933 .50775 L .48929 .50778 L F
.49197 .50517 m .49222 .50491 L .49031 .50502 L .952 .575 0 r
F
.49023 .50518 m .49031 .50502 L .48901 .50509 L .939 .557 0 r
F
.49023 .50518 m .49031 .50502 L .489 .50508 L .952 .575 0 r
F
.49032 .50519 m .4905 .505 L .49031 .50502 L .939 .557 0 r
F
.49032 .50519 m .49031 .50502 L .49023 .50518 L F
.50891 .50664 m .5088 .50396 L .4905 .505 L F
.50891 .50664 m .4905 .505 L .49032 .50519 L F
.49306 .50243 m .49332 .50216 L .49141 .50227 L .953 .583 0 r
F
.49125 .50259 m .49129 .50255 L .48896 .50241 L .94 .565 0 r
F
.49129 .50255 m .49141 .50227 L .48896 .50241 L F
.49127 .50259 m .49141 .50227 L .48895 .5024 L .953 .583 0 r
F
.49129 .50255 m .49157 .50226 L .49141 .50227 L .94 .565 0 r
F
.5088 .50396 m .50868 .50128 L .49157 .50226 L F
.5088 .50396 m .49157 .50226 L .49125 .50259 L F
.49405 .4997 m .49433 .49941 L .49241 .49952 L .954 .59 0 r
F
.49212 .49997 m .49232 .49976 L .4889 .49972 L .941 .573 0 r
F
.49232 .49976 m .49241 .49952 L .4889 .49972 L F
.49223 .49998 m .49241 .49952 L .48889 .49971 L .954 .59 0 r
F
.49232 .49976 m .49256 .49951 L .49241 .49952 L .941 .573 0 r
F
.50868 .50128 m .50854 .49859 L .49256 .49951 L F
.50868 .50128 m .49256 .49951 L .49212 .49997 L F
.49496 .49696 m .49525 .49666 L .49333 .49676 L .955 .598 0 r
F
.49291 .49735 m .49325 .49698 L .48884 .49702 L .942 .581 0 r
F
.49325 .49698 m .49333 .49676 L .48884 .49702 L F
.49311 .49736 m .49333 .49676 L .48883 .49701 L .955 .598 0 r
F
.49325 .49698 m .49346 .49676 L .49333 .49676 L .942 .581 0 r
F
.50854 .49859 m .5084 .49589 L .49346 .49676 L F
.50854 .49859 m .49346 .49676 L .49291 .49735 L F
.49579 .49423 m .49609 .4939 L .49417 .49401 L .955 .605 0 r
F
.49364 .49471 m .4941 .49421 L .48878 .49432 L .943 .589 0 r
F
.4941 .49421 m .49417 .49401 L .48878 .49432 L F
.49391 .49473 m .49417 .49401 L .48876 .49431 L .955 .605 0 r
F
.4941 .49421 m .49428 .494 L .49417 .49401 L .943 .589 0 r
F
.5084 .49589 m .50824 .49319 L .49428 .494 L F
.5084 .49589 m .49428 .494 L .49364 .49471 L F
.49655 .49149 m .49686 .49115 L .49493 .49125 L .956 .613 0 r
F
.49431 .49207 m .49487 .49144 L .48871 .49162 L .944 .597 0 r
F
.49487 .49144 m .49493 .49125 L .48871 .49162 L F
.49466 .4921 m .49493 .49125 L .48869 .49161 L .956 .613 0 r
F
.49487 .49144 m .49504 .49125 L .49493 .49125 L .944 .597 0 r
F
.50824 .49319 m .50808 .49049 L .49504 .49125 L F
.50824 .49319 m .49504 .49125 L .49431 .49207 L F
.49724 .48876 m .49756 .48839 L .49562 .4885 L .957 .62 0 r
F
.49492 .48942 m .49557 .48867 L .48863 .48891 L .945 .605 0 r
F
.49557 .48867 m .49562 .4885 L .48863 .48891 L F
.49534 .48945 m .49562 .4885 L .48861 .4889 L .957 .62 0 r
F
.49557 .48867 m .49573 .48849 L .49562 .4885 L .945 .605 0 r
F
.50808 .49049 m .5079 .48778 L .49573 .48849 L F
.50808 .49049 m .49573 .48849 L .49492 .48942 L F
.49711 .4869 m .49626 .48574 L .49596 .4868 L .957 .628 0 r
F
.49787 .48602 m .49626 .48574 L .49711 .4869 L F
.5079 .48778 m .49626 .48574 L .49596 .4868 L .945 .613 0 r
F
.5079 .48778 m .50772 .48507 L .49626 .48574 L F
.49763 .48424 m .49653 .48415 L .49626 .48574 L .958 .635 0 r
F
.49653 .48415 m .48847 .48348 L .49626 .48574 L .946 .621 0 r
F
.49653 .48415 m .48845 .48348 L .49626 .48574 L .958 .635 0 r
F
.50772 .48507 m .49653 .48415 L .49626 .48574 L .946 .621 0 r
F
.47515 .08214 m .47432 .07776 L .47375 .07778 L .835 .995 0 r
F
.47515 .08214 m .47432 .07776 L .47375 .07778 L F
.47361 .08233 m .47319 .07779 L .47207 .08225 L .864 1 0 r
F
.47361 .08233 m .47375 .07779 L .47319 .07779 L F
.47515 .08223 m .47375 .07779 L .47361 .08233 L .842 .996 0 r
F
.47361 .08233 m .47319 .07779 L .47207 .08225 L .864 1 0 r
F
.47361 .08233 m .47375 .07779 L .47319 .07779 L F
.47515 .08223 m .47375 .07779 L .47361 .08233 L .842 .996 0 r
F
.55758 .75179 m .52962 .7562 L .52911 .7607 L .596 .057 0 r
F
.55758 .75179 m .55839 .74756 L .52962 .7562 L F
.47515 .08223 m .47432 .07777 L .47375 .07779 L .842 .996 0 r
F
.47667 .08214 m .47432 .07777 L .47515 .08223 L .826 .979 0 r
F
.47515 .08223 m .47432 .07777 L .47375 .07779 L .842 .996 0 r
F
.47667 .08214 m .47432 .07777 L .47515 .08223 L .826 .979 0 r
F
.31855 .79098 m .28024 .7859 L .28236 .79037 L 1 .257 0 r
F
.32021 .79537 m .31855 .79098 L .28236 .79037 L 1 .237 0 r
F
.86537 .36966 m .84594 .38272 L .84838 .38928 L .19 .057 0 r
F
.86537 .36966 m .8628 .36312 L .84594 .38272 L F
.47361 .08245 m .47319 .0778 L .47207 .08237 L .874 1 0 r
F
.47361 .08245 m .47375 .07781 L .47319 .0778 L F
.47515 .08233 m .47375 .07781 L .47361 .08245 L .85 .997 0 r
F
.47361 .08245 m .47319 .0778 L .47207 .08237 L .874 1 0 r
F
.47361 .08245 m .47375 .07781 L .47319 .0778 L F
.47515 .08233 m .47375 .07781 L .47361 .08245 L .85 .997 0 r
F
.4691 .49453 m .44962 .49114 L .4495 .49383 L 1 .706 0 r
F
.46907 .49723 m .4691 .49453 L .4495 .49383 L 1 .699 0 r
F
.6828 .13601 m .67252 .14481 L .67879 .1486 L .402 .532 0 r
F
.6828 .13601 m .67635 .1326 L .67252 .14481 L F
.47515 .08233 m .47432 .07779 L .47375 .07781 L .85 .997 0 r
F
.47667 .08225 m .47432 .07779 L .47515 .08233 L .833 .978 0 r
F
.47515 .08233 m .47432 .07779 L .47375 .07781 L .85 .997 0 r
F
.47667 .08225 m .47432 .07779 L .47515 .08233 L .833 .978 0 r
F
.21258 .77582 m .17603 .76086 L .17866 .76637 L 1 .331 0 r
F
.21495 .78111 m .21258 .77582 L .17866 .76637 L 1 .307 0 r
F
.46936 .47012 m .45103 .46678 L .45085 .46948 L 1 .769 0 r
F
.46936 .47012 m .4694 .46741 L .45103 .46678 L F
.47207 .08215 m .47263 .07773 L .47057 .08208 L .863 1 0 r
F
.47207 .08215 m .47319 .07777 L .47263 .07773 L F
.47207 .08215 m .47263 .07773 L .47057 .08208 L .864 1 0 r
F
.47207 .08215 m .47319 .07777 L .47263 .07773 L F
.47207 .08225 m .47263 .07775 L .47057 .0822 L .873 1 0 r
F
.47207 .08225 m .47319 .07779 L .47263 .07775 L F
.47207 .08225 m .47263 .07775 L .47057 .0822 L .874 1 0 r
F
.47207 .08225 m .47319 .07779 L .47263 .07775 L F
.67575 .13361 m .6658 .14179 L .67208 .14554 L .393 .52 0 r
F
.67575 .13361 m .66932 .13018 L .6658 .14179 L F
.47207 .08237 m .47263 .07777 L .47057 .08235 L .885 1 0 r
F
.47207 .08237 m .47319 .0778 L .47263 .07777 L F
.47207 .08237 m .47263 .07777 L .47057 .08235 L F
.47207 .08237 m .47319 .0778 L .47263 .07777 L F
.48845 .48348 m .46925 .48099 L .46922 .48369 L 1 .695 0 r
F
.48845 .48348 m .48836 .48076 L .46925 .48099 L F
.48853 .48619 m .48845 .48348 L .46922 .48369 L 1 .688 0 r
F
.48836 .48076 m .46928 .47828 L .46925 .48099 L 1 .701 0 r
F
.48836 .48076 m .48826 .47805 L .46928 .47828 L F
.73896 .78978 m .70886 .79327 L .70631 .79824 L .334 .005 0 r
F
.73896 .78978 m .74189 .78468 L .70886 .79327 L F
.42509 .36891 m .42612 .36583 L .41607 .37013 L 1 1 0 r
F
.47667 .08205 m .47487 .07771 L .47432 .07776 L .82 .979 0 r
F
.47667 .08205 m .47487 .07771 L .47432 .07776 L F
.48853 .48619 m .46922 .48369 L .46919 .48639 L 1 .688 0 r
F
.48861 .4889 m .48853 .48619 L .46919 .48639 L 1 .681 0 r
F
.48826 .47805 m .46931 .47558 L .46928 .47828 L 1 .708 0 r
F
.48826 .47805 m .48816 .47533 L .46931 .47558 L F
.37263 .53288 m .35303 .52414 L .35279 .52731 L 1 .837 0 r
F
.37249 .53606 m .37263 .53288 L .35279 .52731 L 1 .826 0 r
F
.47667 .08214 m .47487 .07772 L .47432 .07777 L .826 .979 0 r
F
.47667 .08214 m .47487 .07772 L .47432 .07777 L F
.46907 .49723 m .4495 .49383 L .44938 .49653 L 1 .699 0 r
F
.46904 .49993 m .46907 .49723 L .44938 .49653 L 1 .691 0 r
F
.4889 .49972 m .46907 .49723 L .46904 .49993 L .999 .637 0 r
F
.47667 .08225 m .47487 .07774 L .47432 .07779 L .833 .978 0 r
F
.47667 .08225 m .47487 .07774 L .47432 .07779 L F
.48861 .4889 m .46919 .48639 L .46916 .48909 L 1 .681 0 r
F
.48869 .49161 m .48861 .4889 L .46916 .48909 L 1 .674 0 r
F
.4679 .60403 m .4434 .6004 L .44353 .6031 L 1 .347 0 r
F
.4679 .60663 m .4679 .60403 L .44353 .6031 L .994 .333 0 r
F
.49219 .60632 m .4679 .60403 L .4679 .60663 L .92 .252 0 r
F
.49219 .60632 m .49234 .60375 L .4679 .60403 L F
.4694 .46741 m .45122 .46408 L .45103 .46678 L 1 .776 0 r
F
.4694 .46741 m .46943 .4647 L .45122 .46408 L F
.6892 .13953 m .67879 .1486 L .68499 .15248 L .395 .515 0 r
F
.6892 .13953 m .6828 .13601 L .67879 .1486 L F
.48816 .47533 m .46934 .47287 L .46931 .47558 L 1 .715 0 r
F
.48816 .47533 m .48806 .47262 L .46934 .47287 L F
.46922 .48369 m .45034 .48032 L .4502 .48301 L 1 .744 0 r
F
.46922 .48369 m .46925 .48099 L .45034 .48032 L F
.46919 .48639 m .46922 .48369 L .4502 .48301 L 1 .737 0 r
F
.46925 .48099 m .45049 .47763 L .45034 .48032 L 1 .75 0 r
F
.46925 .48099 m .46928 .47828 L .45049 .47763 L F
.27426 .77212 m .23608 .76385 L .23839 .76866 L 1 .317 0 r
F
.2762 .77677 m .27426 .77212 L .23839 .76866 L 1 .298 0 r
F
.26278 .81379 m .22523 .80156 L .22799 .80648 L 1 .211 0 r
F
.26518 .8185 m .26278 .81379 L .22799 .80648 L 1 .186 0 r
F
.63508 .50089 m .61782 .50477 L .6173 .50815 L .34 .036 0 r
F
.63508 .50089 m .63571 .49749 L .61782 .50477 L F
.46919 .48639 m .4502 .48301 L .45006 .48569 L 1 .737 0 r
F
.46916 .48909 m .46919 .48639 L .45006 .48569 L 1 .731 0 r
F
.46928 .47828 m .45065 .47494 L .45049 .47763 L 1 .756 0 r
F
.46928 .47828 m .46931 .47558 L .45065 .47494 L F
.42873 .86441 m .39166 .85913 L .3929 .86272 L .845 .06 0 r
F
.42939 .86785 m .42873 .86441 L .3929 .86272 L .829 .057 0 r
F
.46505 .86837 m .42873 .86441 L .42939 .86785 L .777 .052 0 r
F
.09538 .47231 m .07492 .44703 L .07333 .45373 L 1 .989 0 r
F
.09401 .479 m .09538 .47231 L .07333 .45373 L 1 .976 0 r
F
.68211 .13714 m .67208 .14554 L .6783 .14938 L .385 .501 0 r
F
.68211 .13714 m .67575 .13361 L .67208 .14554 L F
.43271 .80426 m .4323 .79999 L .39751 .80626 L .851 .115 0 r
F
.46588 .79643 m .4323 .79999 L .43271 .80426 L .784 .079 0 r
F
.46588 .79643 m .46586 .79209 L .4323 .79999 L F
.48869 .49161 m .46916 .48909 L .46913 .49178 L 1 .674 0 r
F
.48876 .49431 m .48869 .49161 L .46913 .49178 L 1 .667 0 r
F
.46916 .48909 m .45006 .48569 L .44992 .48837 L 1 .731 0 r
F
.46913 .49178 m .46916 .48909 L .44992 .48837 L 1 .724 0 r
F
.48806 .47262 m .46937 .47017 L .46934 .47287 L 1 .721 0 r
F
.48806 .47262 m .48795 .4699 L .46937 .47017 L F
.46931 .47558 m .45082 .47225 L .45065 .47494 L 1 .763 0 r
F
.46931 .47558 m .46934 .47287 L .45082 .47225 L F
.47057 .08208 m .4721 .07767 L .46912 .08195 L .879 1 0 r
F
.47057 .08208 m .47263 .07773 L .4721 .07767 L F
.47057 .08208 m .4721 .07767 L .46912 .08195 L F
.47057 .08208 m .47263 .07773 L .4721 .07767 L F
.75713 .40592 m .74476 .41325 L .74524 .41868 L .022 .006 0 r
F
.75713 .40592 m .75646 .40059 L .74476 .41325 L F
.47057 .0822 m .4721 .07769 L .46912 .0821 L .892 1 0 r
F
.47057 .0822 m .47263 .07775 L .4721 .07769 L F
.47057 .0822 m .4721 .07769 L .46912 .0821 L F
.47057 .0822 m .47263 .07775 L .4721 .07769 L F
.41882 .58986 m .39534 .58357 L .39558 .58648 L 1 .54 0 r
F
.41901 .59269 m .41882 .58986 L .39558 .58648 L 1 .526 0 r
F
.46904 .49993 m .44938 .49653 L .44926 .49922 L 1 .691 0 r
F
.46902 .50261 m .46904 .49993 L .44926 .49922 L 1 .684 0 r
F
.48896 .50241 m .46904 .49993 L .46902 .50261 L .998 .63 0 r
F
.48896 .50241 m .4889 .49972 L .46904 .49993 L F
.83474 .65889 m .80831 .66678 L .80675 .6729 L .199 .001 0 r
F
.83474 .65889 m .83646 .65263 L .80831 .66678 L F
.47057 .08235 m .4721 .07771 L .46912 .08229 L .907 1 0 r
F
.47057 .08235 m .47263 .07777 L .4721 .07771 L F
.47057 .08235 m .4721 .07771 L .46912 .08229 L F
.47057 .08235 m .47263 .07777 L .4721 .07771 L F
.54007 .597 m .51701 .5971 L .51671 .5997 L .753 .094 0 r
F
.54007 .597 m .54054 .59442 L .51701 .5971 L F
.46913 .49178 m .44992 .48837 L .4498 .49105 L 1 .724 0 r
F
.46911 .49447 m .46913 .49178 L .4498 .49105 L 1 .718 0 r
F
.48876 .49431 m .46913 .49178 L .46911 .49447 L 1 .667 0 r
F
.42064 .39911 m .40871 .39603 L .40759 .39879 L 1 1 0 r
F
.42064 .39911 m .42147 .39609 L .40871 .39603 L F
.46943 .4647 m .45141 .46138 L .45122 .46408 L 1 .782 0 r
F
.46943 .4647 m .46946 .46199 L .45141 .46138 L F
.46934 .47287 m .45099 .46956 L .45082 .47225 L 1 .769 0 r
F
.46934 .47287 m .46937 .47017 L .45099 .46956 L F
.48883 .49701 m .48876 .49431 L .46911 .49447 L 1 .661 0 r
F
.87061 .3755 m .85084 .38868 L .85331 .39529 L .193 .058 0 r
F
.87061 .3755 m .86798 .36892 L .85084 .38868 L F
.69552 .14314 m .68499 .15248 L .69113 .15646 L .388 .498 0 r
F
.69552 .14314 m .6892 .13953 L .68499 .15248 L F
.48795 .4699 m .46941 .46747 L .46937 .47017 L 1 .728 0 r
F
.48795 .4699 m .48784 .46719 L .46941 .46747 L F
.65708 .45641 m .64269 .46058 L .64188 .46458 L .2 .003 0 r
F
.65708 .45641 m .65802 .45239 L .64269 .46058 L F
.4434 .6004 m .41922 .59549 L .41944 .59827 L 1 .434 0 r
F
.44353 .6031 m .4434 .6004 L .41944 .59827 L 1 .42 0 r
F
.87335 .54444 m .84963 .555 L .8495 .56167 L .153 .015 0 r
F
.87335 .54444 m .87352 .53768 L .84963 .555 L F
.37219 .21101 m .38187 .22256 L .39714 .2761 L .894 .274 0 r
F
.68841 .14075 m .6783 .14938 L .68446 .15331 L .377 .483 0 r
F
.68841 .14075 m .68211 .13714 L .6783 .14938 L F
.10198 .46584 m .08008 .4407 L .07862 .44734 L 1 .985 0 r
F
.10075 .47242 m .10198 .46584 L .07862 .44734 L 1 .972 0 r
F
.70415 .25435 m .70062 .25365 L .70235 .26059 L 0 0 0 r
F
.70415 .25435 m .70257 .24748 L .70062 .25365 L F
.46911 .49447 m .4498 .49105 L .44967 .49373 L 1 .718 0 r
F
.46908 .49716 m .46911 .49447 L .44967 .49373 L 1 .712 0 r
F
.48883 .49701 m .46911 .49447 L .46908 .49716 L 1 .661 0 r
F
.46937 .47017 m .45116 .46687 L .45099 .46956 L 1 .776 0 r
F
.46937 .47017 m .46941 .46747 L .45116 .46687 L F
.73702 .2813 m .73327 .28314 L .7352 .28947 L 0 0 0 r
F
.73702 .2813 m .73568 .27473 L .73327 .28314 L F
.70198 .34481 m .6951 .34719 L .69383 .35394 L F
.70198 .34481 m .70324 .33811 L .6951 .34719 L F
.78895 .74186 m .75993 .74702 L .75762 .75259 L .278 .003 0 r
F
.78895 .74186 m .79155 .73613 L .75993 .74702 L F
.48889 .49971 m .48883 .49701 L .46908 .49716 L 1 .654 0 r
F
.46902 .50261 m .44926 .49922 L .44916 .5019 L 1 .684 0 r
F
.46899 .5053 m .46902 .50261 L .44916 .5019 L 1 .676 0 r
F
.48901 .50509 m .46902 .50261 L .46899 .5053 L .998 .622 0 r
F
.48901 .50509 m .48896 .50241 L .46902 .50261 L F
.48784 .46719 m .46944 .46476 L .46941 .46747 L 1 .734 0 r
F
.48784 .46719 m .48772 .46448 L .46944 .46476 L F
.71892 .58259 m .69435 .58734 L .69371 .59178 L .366 .043 0 r
F
.71892 .58259 m .71972 .57808 L .69435 .58734 L F
.46946 .46199 m .45161 .45868 L .45141 .46138 L 1 .789 0 r
F
.46946 .46199 m .4695 .45928 L .45161 .45868 L F
.46908 .49716 m .44967 .49373 L .44956 .4964 L 1 .712 0 r
F
.46905 .49984 m .46908 .49716 L .44956 .4964 L 1 .705 0 r
F
.48889 .49971 m .46908 .49716 L .46905 .49984 L 1 .654 0 r
F
.46941 .46747 m .45134 .46418 L .45116 .46687 L 1 .782 0 r
F
.46941 .46747 m .46944 .46476 L .45134 .46418 L F
.70178 .14687 m .69113 .15646 L .69721 .16052 L .38 .48 0 r
F
.70178 .14687 m .69552 .14314 L .69113 .15646 L F
.46912 .08195 m .4716 .07759 L .46774 .08177 L .907 1 0 r
F
.46912 .08195 m .4721 .07767 L .4716 .07759 L F
.46912 .08195 m .4716 .0776 L .46774 .08177 L F
.46912 .08195 m .4721 .07767 L .4716 .0776 L F
.68492 .63507 m .65925 .63807 L .65844 .64233 L .438 .047 0 r
F
.68492 .63507 m .68602 .63084 L .65925 .63807 L F
.69466 .14445 m .68446 .15331 L .69055 .15731 L .369 .466 0 r
F
.69466 .14445 m .68841 .14075 L .68446 .15331 L F
.48895 .5024 m .48889 .49971 L .46905 .49984 L 1 .647 0 r
F
.51608 .60479 m .49234 .60375 L .49219 .60632 L .836 .162 0 r
F
.51608 .60479 m .5164 .60226 L .49234 .60375 L F
.46912 .0821 m .4716 .07762 L .46775 .08196 L .924 1 0 r
F
.46912 .0821 m .4721 .07769 L .4716 .07762 L F
.46912 .0821 m .4716 .07762 L .46775 .08197 L .925 1 0 r
F
.46912 .0821 m .4721 .07769 L .4716 .07762 L F
.87962 .55235 m .85456 .56276 L .85445 .56953 L .178 .02 0 r
F
.87962 .55235 m .87973 .54546 L .85456 .56276 L F
.48772 .46448 m .46947 .46206 L .46944 .46476 L 1 .741 0 r
F
.48772 .46448 m .4876 .46177 L .46947 .46206 L F
.46912 .08229 m .4716 .07765 L .46775 .08221 L .945 1 0 r
F
.46912 .08229 m .4721 .07771 L .4716 .07765 L F
.46912 .08229 m .4716 .07765 L .46775 .08222 L .946 1 0 r
F
.46912 .08229 m .4721 .07771 L .4716 .07765 L F
.46899 .5053 m .44916 .5019 L .44906 .50458 L 1 .676 0 r
F
.46897 .50797 m .46899 .5053 L .44906 .50458 L 1 .668 0 r
F
.48905 .50777 m .46899 .5053 L .46897 .50797 L .997 .614 0 r
F
.48905 .50777 m .48901 .50509 L .46899 .5053 L F
.16465 .70993 m .13129 .69155 L .1332 .69764 L 1 .508 0 r
F
.16646 .71581 m .16465 .70993 L .1332 .69764 L 1 .486 0 r
F
.37249 .53606 m .35279 .52731 L .35259 .53048 L 1 .826 0 r
F
.37238 .53923 m .37249 .53606 L .35259 .53048 L 1 .816 0 r
F
.56394 .5853 m .54184 .5865 L .54142 .58917 L .662 .067 0 r
F
.56394 .5853 m .56451 .58264 L .54184 .5865 L F
.46905 .49984 m .44956 .4964 L .44945 .49906 L 1 .705 0 r
F
.46903 .50252 m .46905 .49984 L .44945 .49906 L 1 .699 0 r
F
.48895 .5024 m .46905 .49984 L .46903 .50252 L 1 .647 0 r
F
.465 .87791 m .46495 .87449 L .42873 .87395 L .769 .05 0 r
F
.50058 .87737 m .46495 .87449 L .465 .87791 L .71 .043 0 r
F
.50058 .87737 m .50116 .87395 L .46495 .87449 L F
.39461 .57173 m .37247 .56411 L .37261 .56715 L 1 .661 0 r
F
.39476 .57473 m .39461 .57173 L .37261 .56715 L 1 .649 0 r
F
.46944 .46476 m .45153 .4615 L .45134 .46418 L 1 .788 0 r
F
.46944 .46476 m .46947 .46206 L .45153 .4615 L F
.4695 .45928 m .45181 .45599 L .45161 .45868 L 1 .795 0 r
F
.4695 .45928 m .46953 .45658 L .45181 .45599 L F
.58722 .73089 m .56055 .73447 L .55988 .73889 L .552 .052 0 r
F
.58722 .73089 m .58822 .72677 L .56055 .73447 L F
.67962 .40723 m .66883 .411 L .66742 .41616 L 0 0 0 r
F
.67962 .40723 m .68118 .40202 L .66883 .411 L F
.58801 .56661 m .5671 .56884 L .56662 .57166 L .564 .059 0 r
F
.58801 .56661 m .58862 .56379 L .5671 .56884 L F
.17487 .68851 m .13999 .67218 L .14178 .67805 L 1 .534 0 r
F
.17654 .69414 m .17487 .68851 L .14178 .67805 L 1 .516 0 r
F
.489 .50508 m .48895 .5024 L .46903 .50252 L 1 .64 0 r
F
.83961 .66854 m .81205 .67595 L .81045 .68218 L .22 .006 0 r
F
.83961 .66854 m .84137 .66215 L .81205 .67595 L F
.70797 .15069 m .69721 .16052 L .70322 .16468 L .373 .461 0 r
F
.70797 .15069 m .70178 .14687 L .69721 .16052 L F
.70085 .14822 m .69055 .15731 L .69659 .1614 L .362 .451 0 r
F
.70085 .14822 m .69466 .14445 L .69055 .15731 L F
.4876 .46177 m .46951 .45937 L .46947 .46206 L 1 .747 0 r
F
.4876 .46177 m .48747 .45906 L .46951 .45937 L F
.35962 .80204 m .32193 .79969 L .32371 .80394 L .986 .204 0 r
F
.36092 .80627 m .35962 .80204 L .32371 .80394 L .978 .183 0 r
F
.74719 .51046 m .72621 .51758 L .72595 .52237 L .27 .035 0 r
F
.74719 .51046 m .74743 .5056 L .72621 .51758 L F
.46903 .50252 m .44945 .49906 L .44935 .50172 L 1 .699 0 r
F
.469 .50519 m .46903 .50252 L .44935 .50172 L 1 .693 0 r
F
.489 .50508 m .46903 .50252 L .469 .50519 L 1 .64 0 r
F
.57178 .86966 m .53811 .86879 L .53692 .87233 L .574 .028 0 r
F
.57178 .86966 m .57357 .86606 L .53811 .86879 L F
.46947 .46206 m .45172 .45881 L .45153 .4615 L 1 .795 0 r
F
.46947 .46206 m .46951 .45937 L .45172 .45881 L F
.45004 .48302 m .43152 .47876 L .43125 .48146 L 1 .786 0 r
F
.45004 .48302 m .45019 .48032 L .43152 .47876 L F
.44989 .48573 m .45004 .48302 L .43125 .48146 L 1 .779 0 r
F
.45019 .48032 m .4318 .47606 L .43152 .47876 L 1 .793 0 r
F
.45019 .48032 m .45035 .47761 L .4318 .47606 L F
.46897 .50797 m .44906 .50458 L .44896 .50725 L 1 .668 0 r
F
.46895 .51064 m .46897 .50797 L .44896 .50725 L 1 .66 0 r
F
.48805 .5103 m .48903 .50777 L .46897 .50797 L .996 .606 0 r
F
.488 .51044 m .46897 .50797 L .46895 .51064 L F
.48805 .5103 m .46897 .50797 L .488 .51044 L F
.48799 .51044 m .46898 .50786 L .46896 .51052 L 1 .626 0 r
F
.488 .51044 m .48805 .5103 L .488 .51044 L .996 .606 0 r
F
.4891 .51044 m .48805 .5103 L .488 .51044 L 1 .626 0 r
F
.48909 .51043 m .48805 .5103 L .488 .51044 L .996 .606 0 r
F
.488 .51044 m .48805 .5103 L .48799 .51044 L 1 .626 0 r
F
.48805 .5103 m .46898 .50786 L .48799 .51044 L F
.48805 .5103 m .48905 .50777 L .48903 .50777 L .996 .606 0 r
F
.4891 .51044 m .48906 .50786 L .48891 .50822 L 1 .626 0 r
F
.48906 .50786 m .48905 .50777 L .48805 .5103 L .996 .606 0 r
F
.4891 .51044 m .48887 .50777 L .48805 .5103 L 1 .626 0 r
F
.48909 .51043 m .48906 .50786 L .48805 .5103 L .996 .606 0 r
F
.48891 .50822 m .48905 .50777 L .48887 .50777 L 1 .626 0 r
F
.48906 .50786 m .48905 .50777 L .48891 .50822 L F
.48805 .5103 m .48887 .50777 L .46898 .50786 L F
.42612 .36583 m .41746 .36756 L .41607 .37013 L 1 1 0 r
F
.42612 .36583 m .42715 .36274 L .41746 .36756 L F
.44989 .48573 m .43125 .48146 L .43099 .48415 L 1 .779 0 r
F
.44976 .48843 m .44989 .48573 L .43099 .48415 L 1 .772 0 r
F
.45035 .47761 m .43209 .47337 L .4318 .47606 L 1 .799 0 r
F
.45035 .47761 m .45051 .4749 L .43209 .47337 L F
.61176 .54002 m .59244 .54319 L .59194 .54622 L .449 .05 0 r
F
.61176 .54002 m .61236 .53698 L .59244 .54319 L F
.86783 .37623 m .84838 .38928 L .85071 .39587 L .182 .054 0 r
F
.86783 .37623 m .86537 .36966 L .84838 .38928 L F
.39166 .85913 m .35438 .85247 L .35617 .85624 L .904 .068 0 r
F
.3929 .86272 m .39166 .85913 L .35617 .85624 L .888 .065 0 r
F
.46953 .45658 m .45202 .45331 L .45181 .45599 L 1 .802 0 r
F
.46953 .45658 m .46957 .45388 L .45202 .45331 L F
.31088 .83203 m .27356 .8219 L .27612 .82632 L 1 .126 0 r
F
.31301 .83624 m .31088 .83203 L .27612 .82632 L 1 .102 0 r
F
.16023 .72061 m .12581 .70238 L .12793 .70852 L 1 .479 0 r
F
.16221 .72653 m .16023 .72061 L .12793 .70852 L 1 .456 0 r
F
.48905 .50777 m .489 .50508 L .469 .50519 L 1 .633 0 r
F
.35262 .84862 m .3152 .84037 L .31744 .84441 L .968 .077 0 r
F
.35438 .85247 m .35262 .84862 L .31744 .84441 L .953 .074 0 r
F
.60764 .85208 m .57535 .85252 L .57363 .85616 L .489 .018 0 r
F
.60764 .85208 m .60992 .84838 L .57535 .85252 L F
.44976 .48843 m .43099 .48415 L .43074 .48685 L 1 .772 0 r
F
.44962 .49114 m .44976 .48843 L .43074 .48685 L 1 .765 0 r
F
.08029 .49277 m .05747 .46676 L .0563 .47374 L 1 .942 0 r
F
.07931 .49968 m .08029 .49277 L .0563 .47374 L 1 .927 0 r
F
.40116 .13347 m .41037 .14788 L .41997 .2096 L .921 .375 0 r
F
.45051 .4749 m .4324 .47067 L .43209 .47337 L 1 .806 0 r
F
.45051 .4749 m .45068 .47219 L .4324 .47067 L F
.46774 .08177 m .47113 .07751 L .46648 .08156 L .918 1 0 r
F
.46774 .08177 m .4716 .07759 L .47113 .07751 L F
.46774 .08177 m .47108 .0776 L .46648 .08156 L .926 1 0 r
F
.47108 .0776 m .47112 .07755 L .47111 .07756 L F
.47108 .0776 m .47111 .07756 L .46648 .08156 L F
.47112 .07755 m .47112 .07755 L .46648 .08156 L F
.46648 .08156 m .47113 .07751 L .47071 .07746 L .915 1 0 r
F
.47112 .07755 m .47113 .07754 L .47113 .07754 L .944 1 0 r
F
.46648 .08156 m .47112 .07755 L .47071 .07746 L .917 1 0 r
F
.47112 .07755 m .47113 .07754 L .47113 .07754 L .944 1 0 r
F
.47112 .07755 m .47113 .07754 L .47113 .07754 L .917 1 0 r
F
.47112 .07755 m .47113 .07754 L .47071 .07746 L F
.47112 .07755 m .47113 .07754 L .47071 .07751 L .944 1 0 r
F
.46648 .08182 m .47112 .07755 L .47071 .07751 L F
.46775 .08196 m .47112 .07755 L .46648 .08182 L .94 1 0 r
F
.47112 .07755 m .47113 .07754 L .47112 .07755 L F
.47112 .07755 m .47112 .07755 L .46648 .08182 L F
.47112 .07755 m .47113 .07754 L .47112 .07755 L .926 1 0 r
F
.46774 .08177 m .4716 .0776 L .47114 .07754 L F
.46775 .08196 m .4716 .07762 L .47114 .07754 L .94 1 0 r
F
.47112 .07755 m .47114 .07754 L .47113 .07754 L F
.46775 .08196 m .47114 .07754 L .47112 .07755 L F
.47112 .07755 m .47114 .07754 L .47113 .07754 L .926 1 0 r
F
.46774 .08177 m .47114 .07754 L .47112 .07755 L F
.48747 .45906 m .46954 .45667 L .46951 .45937 L 1 .754 0 r
F
.48747 .45906 m .48734 .45636 L .46954 .45667 L F
.70698 .15207 m .69659 .1614 L .70256 .16557 L .355 .436 0 r
F
.70698 .15207 m .70085 .14822 L .69659 .1614 L F
.46775 .08197 m .47112 .07759 L .46648 .08183 L .95 1 0 r
F
.47112 .07759 m .47112 .07759 L .47112 .07759 L F
.47112 .07759 m .47112 .07759 L .46648 .08183 L F
.47112 .07759 m .47112 .07758 L .46648 .08183 L F
.47112 .07758 m .47113 .07758 L .47113 .07758 L .982 1 0 r
F
.46648 .08183 m .47112 .07758 L .47071 .07751 L .946 1 0 r
F
.47112 .07758 m .47113 .07758 L .47113 .07758 L .982 1 0 r
F
.47112 .07758 m .47113 .07758 L .47113 .07758 L .946 1 0 r
F
.47112 .07758 m .47113 .07758 L .47071 .07751 L F
.47112 .07758 m .47113 .07758 L .47071 .07756 L .982 1 0 r
F
.46649 .08218 m .47112 .07758 L .47071 .07756 L F
.46775 .08197 m .4716 .07762 L .47114 .07758 L .95 1 0 r
F
.47112 .07759 m .47114 .07758 L .47113 .07758 L .968 1 0 r
F
.47112 .07759 m .47114 .07758 L .47113 .07758 L .95 1 0 r
F
.46775 .08197 m .47114 .07758 L .47112 .07759 L F
.46775 .08221 m .4716 .07765 L .47114 .07758 L .968 1 0 r
F
.46775 .08221 m .47114 .07758 L .47112 .07759 L F
.46775 .08221 m .47112 .07759 L .46649 .08218 L F
.47112 .07759 m .47113 .07758 L .47112 .07758 L F
.47112 .07759 m .47112 .07758 L .46649 .08218 L F
.47112 .07759 m .47113 .07758 L .47112 .07758 L .95 1 0 r
F
.71409 .15461 m .70322 .16468 L .70915 .16892 L .364 .442 0 r
F
.71409 .15461 m .70797 .15069 L .70322 .16468 L F
.44962 .49114 m .43074 .48685 L .4305 .48954 L 1 .765 0 r
F
.4495 .49383 m .44962 .49114 L .4305 .48954 L 1 .758 0 r
F
.469 .50519 m .44935 .50172 L .44925 .50437 L 1 .693 0 r
F
.46898 .50786 m .469 .50519 L .44925 .50437 L 1 .686 0 r
F
.48905 .50777 m .469 .50519 L .46898 .50786 L 1 .633 0 r
F
.45068 .47219 m .43271 .46798 L .4324 .47067 L 1 .813 0 r
F
.45068 .47219 m .45085 .46948 L .43271 .46798 L F
.49732 .78747 m .46586 .79209 L .46588 .79643 L .707 .067 0 r
F
.49732 .78747 m .49764 .78316 L .46586 .79209 L F
.10943 .63204 m .07899 .60983 L .07994 .61659 L 1 .684 0 r
F
.1104 .63861 m .10943 .63204 L .07994 .61659 L 1 .664 0 r
F
.46951 .45937 m .45192 .45614 L .45172 .45881 L 1 .801 0 r
F
.46951 .45937 m .46954 .45667 L .45192 .45614 L F
.46775 .08222 m .47113 .07761 L .46649 .08219 L .979 1 0 r
F
.46775 .08222 m .4716 .07765 L .47113 .07761 L F
.12651 .60515 m .09618 .58409 L .09687 .59054 L 1 .724 0 r
F
.12726 .6114 m .12651 .60515 L .09687 .59054 L 1 .706 0 r
F
.4495 .49383 m .4305 .48954 L .43028 .49223 L 1 .758 0 r
F
.44938 .49653 m .4495 .49383 L .43028 .49223 L 1 .751 0 r
F
.45085 .46948 m .43304 .46529 L .43271 .46798 L 1 .819 0 r
F
.45085 .46948 m .45103 .46678 L .43304 .46529 L F
.64845 .84561 m .61671 .84669 L .61452 .85072 L .433 .014 0 r
F
.64845 .84561 m .65116 .84149 L .61671 .84669 L F
.46895 .51064 m .44896 .50725 L .44887 .50992 L 1 .66 0 r
F
.46892 .5133 m .46895 .51064 L .44887 .50992 L 1 .652 0 r
F
.48914 .51311 m .4891 .51044 L .488 .51044 L 1 .618 0 r
F
.48913 .51309 m .48909 .51043 L .488 .51044 L .995 .598 0 r
F
.48694 .51283 m .48799 .51044 L .46895 .51064 L F
.48683 .51312 m .46895 .51064 L .46892 .5133 L F
.48694 .51283 m .46895 .51064 L .48683 .51312 L F
.48681 .51312 m .46896 .51052 L .46893 .51318 L 1 .618 0 r
F
.48683 .51312 m .48694 .51283 L .48683 .51312 L .995 .598 0 r
F
.48914 .51311 m .48694 .51283 L .48683 .51312 L 1 .618 0 r
F
.48913 .51309 m .48694 .51283 L .48683 .51312 L .995 .598 0 r
F
.48683 .51312 m .48694 .51283 L .48681 .51312 L 1 .618 0 r
F
.48694 .51283 m .46896 .51052 L .48681 .51312 L F
.48694 .51283 m .488 .51044 L .48799 .51044 L .995 .598 0 r
F
.48914 .51311 m .488 .51044 L .48791 .51066 L 1 .618 0 r
F
.48914 .51311 m .4878 .51045 L .48694 .51283 L F
.48913 .51309 m .488 .51044 L .48694 .51283 L .995 .598 0 r
F
.48791 .51066 m .488 .51044 L .4878 .51045 L 1 .618 0 r
F
.48694 .51283 m .4878 .51045 L .46896 .51052 L F
.50915 .50941 m .4891 .50777 L .4891 .51044 L .951 .567 0 r
F
.4891 .50777 m .48905 .50777 L .48906 .50786 L .938 .548 0 r
F
.4891 .50777 m .48905 .50777 L .48906 .50786 L .951 .567 0 r
F
.4891 .50777 m .48906 .50786 L .4891 .51044 L F
.50901 .5093 m .4891 .50777 L .48909 .51043 L .938 .548 0 r
F
.4891 .50777 m .48906 .50786 L .48909 .51043 L F
.46957 .45388 m .45223 .45063 L .45202 .45331 L 1 .808 0 r
F
.46957 .45388 m .46961 .45119 L .45223 .45063 L F
.48734 .45636 m .46958 .45399 L .46954 .45667 L 1 .76 0 r
F
.48734 .45636 m .4872 .45366 L .46958 .45399 L F
.63446 .50424 m .6173 .50815 L .61678 .5115 L .338 .035 0 r
F
.63446 .50424 m .63508 .50089 L .6173 .50815 L F
.37238 .53923 m .35259 .53048 L .35241 .53364 L 1 .816 0 r
F
.37229 .54239 m .37238 .53923 L .35241 .53364 L 1 .806 0 r
F
.87313 .38211 m .85331 .39529 L .85567 .40192 L .186 .055 0 r
F
.87313 .38211 m .87061 .3755 L .85331 .39529 L F
.65032 .67563 m .62456 .67804 L .62372 .68227 L .486 .048 0 r
F
.65032 .67563 m .65151 .67156 L .62456 .67804 L F
.75777 .41122 m .74524 .41868 L .74567 .42407 L .027 .006 0 r
F
.75777 .41122 m .75713 .40592 L .74524 .41868 L F
.46898 .50786 m .44925 .50437 L .44916 .50702 L 1 .686 0 r
F
.46896 .51052 m .46898 .50786 L .44916 .50702 L 1 .68 0 r
F
.44938 .49653 m .43028 .49223 L .43006 .49492 L 1 .751 0 r
F
.44926 .49922 m .44938 .49653 L .43006 .49492 L 1 .743 0 r
F
.45103 .46678 m .43338 .4626 L .43304 .46529 L 1 .826 0 r
F
.45103 .46678 m .45122 .46408 L .43338 .4626 L F
.71306 .156 m .70256 .16557 L .70847 .16982 L .349 .421 0 r
F
.71306 .156 m .70698 .15207 L .70256 .16557 L F
.46954 .45667 m .45213 .45346 L .45192 .45614 L 1 .807 0 r
F
.46954 .45667 m .46958 .45399 L .45213 .45346 L F
.09401 .479 m .07333 .45373 L .07185 .46045 L 1 .976 0 r
F
.09275 .4857 m .09401 .479 L .07185 .46045 L 1 .962 0 r
F
.72013 .15864 m .70915 .16892 L .71502 .17325 L .356 .422 0 r
F
.72013 .15864 m .71409 .15461 L .70915 .16892 L F
.41901 .59269 m .39558 .58648 L .39583 .58935 L 1 .526 0 r
F
.41922 .59549 m .41901 .59269 L .39583 .58935 L 1 .513 0 r
F
.526 .47762 m .50716 .47692 L .50737 .47964 L .9 .594 0 r
F
.52633 .48034 m .50737 .47964 L .50758 .48236 L .899 .586 0 r
F
.52633 .48034 m .526 .47762 L .50737 .47964 L F
.52664 .48306 m .50758 .48236 L .50779 .48508 L .898 .578 0 r
F
.52664 .48306 m .52633 .48034 L .50758 .48236 L F
.52566 .47489 m .50693 .47419 L .50716 .47692 L .901 .601 0 r
F
.526 .47762 m .52566 .47489 L .50716 .47692 L .9 .594 0 r
F
.68852 .81587 m .65828 .8185 L .65581 .82281 L .37 .005 0 r
F
.68852 .81587 m .69144 .81145 L .65828 .8185 L F
.53571 .87578 m .50116 .87395 L .50058 .87737 L .64 .035 0 r
F
.53571 .87578 m .53692 .87233 L .50116 .87395 L F
.52693 .48578 m .50779 .48508 L .50798 .4878 L .897 .57 0 r
F
.52693 .48578 m .52664 .48306 L .50779 .48508 L F
.73828 .28778 m .7352 .28947 L .737 .29577 L 0 0 0 r
F
.73828 .28778 m .73702 .2813 L .7352 .28947 L F
.58633 .10206 m .57808 .1053 L .5848 .10832 L .42 .608 0 r
F
.59308 .10486 m .58633 .10206 L .5848 .10832 L .408 .582 0 r
F
.50925 .51208 m .4891 .51044 L .48914 .51311 L .95 .559 0 r
F
.50925 .51208 m .50915 .50941 L .4891 .51044 L F
.5253 .47217 m .50669 .47147 L .50693 .47419 L .902 .609 0 r
F
.52566 .47489 m .5253 .47217 L .50693 .47419 L .901 .601 0 r
F
.4679 .60663 m .44353 .6031 L .44367 .60575 L .994 .333 0 r
F
.4679 .60921 m .4679 .60663 L .44367 .60575 L .989 .318 0 r
F
.49203 .60885 m .4679 .60663 L .4679 .60921 L .914 .237 0 r
F
.49203 .60885 m .49219 .60632 L .4679 .60663 L F
.44926 .49922 m .43006 .49492 L .42986 .4976 L 1 .743 0 r
F
.44916 .5019 m .44926 .49922 L .42986 .4976 L 1 .736 0 r
F
.5091 .51196 m .48909 .51043 L .48913 .51309 L .936 .54 0 r
F
.5091 .51196 m .50901 .5093 L .48909 .51043 L F
.45122 .46408 m .43373 .45992 L .43338 .4626 L 1 .832 0 r
F
.45122 .46408 m .45141 .46138 L .43373 .45992 L F
.46892 .5133 m .44887 .50992 L .44879 .51258 L 1 .652 0 r
F
.4689 .51595 m .46892 .5133 L .44879 .51258 L 1 .644 0 r
F
.48917 .51577 m .48914 .51311 L .48683 .51312 L 1 .611 0 r
F
.48916 .51574 m .48913 .51309 L .48683 .51312 L .994 .589 0 r
F
.48576 .51533 m .48683 .51312 L .46892 .5133 L F
.48742 .51392 m .48683 .51312 L .48677 .51325 L 1 .611 0 r
F
.48917 .51577 m .48749 .51385 L .48742 .51392 L F
.48749 .51385 m .48683 .51312 L .48742 .51392 L F
.48557 .51578 m .46892 .5133 L .4689 .51595 L .994 .589 0 r
F
.48557 .51578 m .46892 .5133 L .48557 .51578 L F
.48576 .51533 m .46892 .5133 L .48558 .51578 L F
.48557 .51578 m .46893 .51318 L .46891 .51582 L 1 .611 0 r
F
.48917 .51577 m .48576 .51533 L .48557 .51578 L F
.48576 .51533 m .46893 .51318 L .48557 .51578 L F
.48558 .51578 m .48557 .51578 L .48557 .51578 L .994 .589 0 r
F
.48366 .51772 m .48556 .51579 L .4689 .51595 L .993 .581 0 r
F
.48556 .51579 m .48557 .51578 L .4689 .51595 L F
.4842 .51843 m .4689 .51595 L .46888 .51859 L F
.4892 .51842 m .4845 .51782 L .4842 .51843 L 1 .604 0 r
F
.48919 .51838 m .4845 .51782 L .4842 .51843 L .993 .581 0 r
F
.4845 .51782 m .4689 .51595 L .4842 .51843 L F
.4842 .51843 m .4845 .51782 L .48415 .51843 L 1 .604 0 r
F
.48415 .51843 m .46891 .51582 L .46889 .51847 L F
.4845 .51782 m .48558 .51578 L .48366 .51772 L .993 .581 0 r
F
.4845 .51782 m .46891 .51582 L .48415 .51843 L 1 .604 0 r
F
.4892 .51842 m .48557 .51578 L .4845 .51782 L F
.48919 .51838 m .48564 .51582 L .4845 .51782 L .993 .581 0 r
F
.48564 .51582 m .48558 .51578 L .4845 .51782 L F
.48923 .52107 m .4892 .51842 L .4856 .51843 L 1 .596 0 r
F
.48923 .52107 m .4856 .51843 L .48509 .5189 L F
.48923 .52107 m .4842 .51843 L .48314 .52029 L F
.48241 .5202 m .48416 .51849 L .46888 .51859 L .992 .572 0 r
F
.48416 .51849 m .4842 .51843 L .46888 .51859 L F
.48269 .52108 m .46888 .51859 L .46886 .52121 L F
.48923 .52107 m .48314 .52029 L .48269 .52108 L 1 .596 0 r
F
.48921 .52101 m .48314 .52029 L .48269 .52108 L .992 .572 0 r
F
.48314 .52029 m .46888 .51859 L .48269 .52108 L F
.48269 .52108 m .48314 .52029 L .48263 .52108 L 1 .596 0 r
F
.48263 .52108 m .46889 .51847 L .46887 .5211 L F
.48314 .52029 m .48423 .51843 L .48241 .5202 L .992 .572 0 r
F
.48314 .52029 m .46889 .51847 L .48263 .52108 L 1 .596 0 r
F
.48921 .52101 m .48432 .51848 L .48314 .52029 L .992 .572 0 r
F
.48432 .51848 m .48423 .51843 L .48314 .52029 L F
.48925 .52371 m .48923 .52107 L .4841 .52108 L 1 .588 0 r
F
.48925 .52371 m .4841 .52108 L .48366 .52147 L F
.48925 .52371 m .48269 .52108 L .48167 .52274 L F
.48106 .52266 m .48261 .52122 L .46886 .52121 L .991 .564 0 r
F
.48261 .52122 m .48269 .52108 L .46886 .52121 L F
.48102 .52371 m .46886 .52121 L .46884 .52383 L F
.48925 .52371 m .48167 .52274 L .48102 .52371 L 1 .588 0 r
F
.48922 .52363 m .48167 .52274 L .48102 .52371 L .991 .564 0 r
F
.48167 .52274 m .46886 .52121 L .48102 .52371 L F
.48102 .52371 m .48167 .52274 L .48095 .52371 L 1 .588 0 r
F
.48095 .52371 m .46887 .5211 L .46885 .52373 L F
.48167 .52274 m .48276 .52108 L .48106 .52266 L .991 .564 0 r
F
.48167 .52274 m .46887 .5211 L .48095 .52371 L 1 .588 0 r
F
.48922 .52363 m .48287 .52112 L .48167 .52274 L .991 .564 0 r
F
.48287 .52112 m .48276 .52108 L .48167 .52274 L F
.48927 .52633 m .48925 .52371 L .48246 .52371 L 1 .58 0 r
F
.48927 .52633 m .48246 .52371 L .48207 .52404 L F
.48927 .52633 m .48102 .52371 L .48006 .52516 L F
.47959 .5251 m .48085 .52398 L .46884 .52383 L .99 .555 0 r
F
.48085 .52398 m .48102 .52371 L .46884 .52383 L F
.47916 .52634 m .46884 .52383 L .46882 .52644 L F
.48927 .52633 m .48006 .52516 L .47916 .52634 L 1 .58 0 r
F
.48923 .52624 m .48006 .52516 L .47916 .52634 L .99 .555 0 r
F
.48006 .52516 m .46884 .52383 L .47916 .52634 L F
.47916 .52634 m .48006 .52516 L .47907 .52634 L 1 .58 0 r
F
.47907 .52634 m .46885 .52373 L .46883 .52634 L F
.48006 .52516 m .46885 .52373 L .47907 .52634 L F
.48006 .52516 m .48115 .52371 L .47959 .5251 L .99 .555 0 r
F
.48923 .52624 m .48125 .52374 L .48006 .52516 L F
.48125 .52374 m .48115 .52371 L .48006 .52516 L F
.48928 .52895 m .48927 .52633 L .48063 .52634 L 1 .572 0 r
F
.48928 .52895 m .48063 .52634 L .48027 .52662 L F
.48928 .52895 m .47916 .52634 L .47828 .52755 L F
.47798 .52751 m .47884 .52678 L .46882 .52644 L .989 .546 0 r
F
.47884 .52678 m .47916 .52634 L .46882 .52644 L F
.47706 .52895 m .46882 .52644 L .46881 .52904 L F
.48928 .52895 m .47828 .52755 L .47706 .52895 L 1 .572 0 r
F
.48924 .52883 m .47828 .52755 L .47706 .52895 L .989 .546 0 r
F
.47828 .52755 m .46882 .52644 L .47706 .52895 L F
.47706 .52895 m .47828 .52755 L .47695 .52895 L 1 .572 0 r
F
.47695 .52895 m .46883 .52634 L .46881 .52896 L F
.47828 .52755 m .46883 .52634 L .47695 .52895 L F
.47828 .52755 m .47937 .52634 L .47798 .52751 L .989 .546 0 r
F
.48924 .52883 m .47943 .52635 L .47828 .52755 L F
.47943 .52635 m .47937 .52634 L .47828 .52755 L F
.48929 .53156 m .48928 .52895 L .47857 .52895 L 1 .564 0 r
F
.48929 .53156 m .47857 .52895 L .47823 .52921 L F
.48929 .53156 m .47706 .52895 L .47631 .52991 L F
.4762 .5299 m .47651 .52965 L .46881 .52904 L .988 .537 0 r
F
.47651 .52965 m .47706 .52895 L .46881 .52904 L F
.47466 .53156 m .46881 .52904 L .46879 .53162 L F
.47631 .52991 m .46881 .52904 L .47466 .53156 L F
.47466 .53156 m .46881 .52896 L .46879 .53156 L 1 .564 0 r
F
.48929 .53156 m .47631 .52991 L .47466 .53156 L F
.47631 .52991 m .46881 .52896 L .47466 .53156 L F
.48924 .53142 m .47631 .52991 L .47466 .53156 L .988 .537 0 r
F
.48929 .53416 m .48929 .53156 L .47622 .53156 L 1 .556 0 r
F
.48929 .53416 m .47622 .53156 L .47591 .53178 L F
.48929 .53416 m .47466 .53156 L .47408 .53223 L F
.47408 .53223 m .47466 .53156 L .46879 .53162 L .986 .528 0 r
F
.47189 .53415 m .46879 .53162 L .46877 .53419 L F
.47408 .53223 m .46879 .53162 L .47189 .53415 L F
.47189 .53415 m .46879 .53156 L .46877 .53415 L 1 .556 0 r
F
.48929 .53416 m .47408 .53223 L .47189 .53415 L F
.47408 .53223 m .46879 .53156 L .47189 .53415 L F
.48924 .53398 m .47408 .53223 L .47189 .53415 L .986 .528 0 r
F
.48929 .53675 m .48929 .53416 L .47189 .53415 L 1 .547 0 r
F
.47156 .53451 m .47189 .53415 L .46877 .53419 L .985 .519 0 r
F
.47156 .53451 m .47189 .53415 L .46877 .53415 L 1 .547 0 r
F
.48929 .53675 m .47189 .53415 L .47156 .53451 L F
.47201 .53456 m .47259 .53415 L .47189 .53415 L .985 .519 0 r
F
.47201 .53456 m .47189 .53415 L .47156 .53451 L F
.48923 .53654 m .48924 .53398 L .47259 .53415 L F
.48923 .53654 m .47259 .53415 L .47201 .53456 L F
.47591 .53178 m .47622 .53156 L .47466 .53156 L 1 .556 0 r
F
.47408 .53223 m .47466 .53156 L .46879 .53156 L F
.47423 .53225 m .47514 .53155 L .47466 .53156 L .986 .528 0 r
F
.47423 .53225 m .47466 .53156 L .47408 .53223 L F
.48924 .53398 m .48924 .53142 L .47514 .53155 L F
.48924 .53398 m .47514 .53155 L .47423 .53225 L F
.47823 .52921 m .47857 .52895 L .47706 .52895 L 1 .564 0 r
F
.47631 .52991 m .47706 .52895 L .46881 .52896 L F
.47651 .52965 m .47738 .52895 L .47706 .52895 L .988 .537 0 r
F
.48924 .53142 m .48924 .52883 L .47738 .52895 L F
.48924 .53142 m .47738 .52895 L .4762 .5299 L F
.48027 .52662 m .48063 .52634 L .47916 .52634 L 1 .572 0 r
F
.47828 .52755 m .47916 .52634 L .46883 .52634 L F
.47884 .52678 m .47937 .52634 L .47916 .52634 L .989 .546 0 r
F
.48924 .52883 m .48923 .52624 L .47937 .52634 L F
.48207 .52404 m .48246 .52371 L .48102 .52371 L 1 .58 0 r
F
.48006 .52516 m .48102 .52371 L .46885 .52373 L F
.48085 .52398 m .48115 .52371 L .48102 .52371 L .99 .555 0 r
F
.48923 .52624 m .48922 .52363 L .48115 .52371 L F
.48366 .52147 m .4841 .52108 L .48269 .52108 L 1 .588 0 r
F
.48167 .52274 m .48269 .52108 L .46887 .5211 L F
.48261 .52122 m .48276 .52108 L .48269 .52108 L .991 .564 0 r
F
.48922 .52363 m .48921 .52101 L .48276 .52108 L F
.48509 .5189 m .4856 .51843 L .4842 .51843 L 1 .596 0 r
F
.48314 .52029 m .4842 .51843 L .46889 .51847 L F
.48416 .51849 m .48423 .51843 L .4842 .51843 L .992 .572 0 r
F
.48921 .52101 m .48919 .51838 L .48423 .51843 L F
.4892 .51842 m .48917 .51577 L .48696 .51577 L 1 .604 0 r
F
.48636 .51636 m .48696 .51577 L .48557 .51578 L F
.4892 .51842 m .48696 .51577 L .48636 .51636 L F
.4845 .51782 m .48557 .51578 L .46891 .51582 L F
.48556 .51579 m .48558 .51578 L .48557 .51578 L .993 .581 0 r
F
.48919 .51838 m .48916 .51574 L .48558 .51578 L F
.48917 .51577 m .48665 .51312 L .48576 .51533 L 1 .611 0 r
F
.48916 .51574 m .48683 .51312 L .48576 .51533 L .994 .589 0 r
F
.48677 .51325 m .48683 .51312 L .48665 .51312 L 1 .611 0 r
F
.48576 .51533 m .48665 .51312 L .46893 .51318 L F
.48916 .51574 m .48576 .51533 L .48558 .51578 L .994 .589 0 r
F
.42913 .31819 m .38263 .12338 L .37528 .12261 L 1 .209 0 r
F
.42056 .30289 m .42546 .30826 L .4274 .32358 L .947 .242 0 r
F
.41181 .27236 m .41971 .28669 L .4248 .31428 L 1 .374 0 r
F
.4248 .31428 m .37528 .12261 L .41056 .26214 L .762 .338 0 r
F
.42546 .30826 m .43052 .32355 L .4274 .32358 L .958 .209 0 r
F
.41971 .28669 m .42913 .31819 L .4248 .31428 L 1 .37 0 r
F
.4248 .31428 m .42913 .31819 L .37528 .12261 L .762 .338 0 r
F
.4274 .32358 m .42906 .32276 L .41056 .26214 L .225 .174 0 r
F
.41181 .27236 m .4248 .31428 L .42428 .31379 L 1 .374 0 r
F
.41459 .29494 m .42056 .30289 L .42458 .32476 L .971 .295 0 r
F
.42056 .30289 m .4274 .32358 L .42458 .32476 L .947 .242 0 r
F
.41645 .29334 m .42428 .31379 L .42007 .30975 L 1 .374 0 r
F
.41181 .27236 m .42428 .31379 L .41645 .29334 L F
.40684 .2827 m .41459 .29494 L .42132 .32455 L 1 .337 0 r
F
.41459 .29494 m .42458 .32476 L .42132 .32455 L .971 .295 0 r
F
.40253 .25555 m .42007 .30975 L .41439 .303 L 1 .368 0 r
F
.40253 .25555 m .41181 .27236 L .42007 .30975 L F
.39718 .26666 m .40684 .2827 L .41504 .31574 L 1 .353 0 r
F
.38187 .22256 m .39224 .23801 L .40695 .29208 L .934 .317 0 r
F
.40684 .2827 m .42132 .32455 L .41504 .31574 L 1 .337 0 r
F
.39224 .23801 m .41366 .30087 L .40695 .29208 L .976 .349 0 r
F
.41366 .30087 m .41439 .303 L .41291 .30082 L F
.41366 .30087 m .41291 .30082 L .40695 .29208 L F
.39718 .26666 m .41504 .31574 L .40422 .29559 L 1 .353 0 r
F
.38187 .22256 m .40563 .28843 L .39714 .2761 L .934 .317 0 r
F
.40563 .28843 m .40695 .29208 L .40404 .28735 L F
.40563 .28843 m .40404 .28735 L .39714 .2761 L F
.39985 .2845 m .39912 .28223 L .39872 .28164 L .423 .128 0 r
F
.40422 .29559 m .40079 .28515 L .39985 .2845 L F
.39714 .2761 m .4005 .28424 L .39872 .28164 L 1 .386 0 r
F
.40079 .28515 m .4005 .28424 L .39985 .2845 L .423 .128 0 r
F
.39714 .2761 m .40404 .28735 L .4005 .28424 L 1 .386 0 r
F
.4005 .28424 m .37256 .19904 L .39948 .28335 L .423 .128 0 r
F
.4005 .28424 m .39948 .28335 L .39985 .2845 L F
.4005 .28424 m .40695 .29208 L .4087 .29833 L 1 .386 0 r
F
.40404 .28735 m .40695 .29208 L .4005 .28424 L F
.4087 .29833 m .36403 .15522 L .37256 .19904 L .675 .29 0 r
F
.40954 .30061 m .40886 .29846 L .4087 .29833 L F
.41504 .31574 m .41025 .30066 L .40954 .30061 L F
.40695 .29208 m .40975 .2991 L .4087 .29833 L 1 .368 0 r
F
.41025 .30066 m .40975 .2991 L .40954 .30061 L .675 .29 0 r
F
.40695 .29208 m .41291 .30082 L .40975 .2991 L 1 .368 0 r
F
.40975 .2991 m .36403 .15522 L .40892 .29864 L .675 .29 0 r
F
.40975 .2991 m .40892 .29864 L .40954 .30061 L F
.42132 .32455 m .41649 .30845 L .41555 .30752 L .806 .375 0 r
F
.41649 .30845 m .41616 .30732 L .41555 .30752 L F
.41439 .303 m .42007 .30975 L .42022 .31047 L 1 .304 0 r
F
.41872 .30931 m .42022 .31047 L .42053 .31195 L F
.41439 .303 m .42022 .31047 L .41872 .30931 L F
.42132 .32455 m .42458 .32476 L .42053 .31195 L .806 .375 0 r
F
.41439 .303 m .42053 .31195 L .41616 .30732 L 1 .304 0 r
F
.41971 .31108 m .42053 .31195 L .41937 .30829 L .806 .375 0 r
F
.42132 .32455 m .42053 .31195 L .41971 .31108 L F
.42132 .32455 m .41937 .30829 L .41616 .30732 L F
.41616 .30732 m .42053 .31195 L .41668 .30861 L 1 .304 0 r
F
.41504 .31574 m .42132 .32455 L .41555 .30752 L .675 .29 0 r
F
.40975 .2991 m .41439 .303 L .41555 .30752 L 1 .368 0 r
F
.41291 .30082 m .41439 .303 L .40975 .2991 L F
.41156 .30479 m .41555 .30752 L .36403 .15522 L .675 .29 0 r
F
.41504 .31574 m .41555 .30752 L .41156 .30479 L F
.41555 .30752 m .42316 .32447 L .41994 .32453 L 1 .304 0 r
F
.41545 .30711 m .41566 .30759 L .41555 .30752 L F
.41566 .30759 m .42316 .32447 L .41555 .30752 L F
.41439 .303 m .41616 .30732 L .41545 .30711 L F
.41616 .30732 m .42316 .32447 L .41545 .30711 L F
.39224 .23801 m .40253 .25555 L .41439 .303 L .976 .349 0 r
F
.41616 .30732 m .41937 .30829 L .36461 .13525 L .806 .375 0 r
F
.41555 .30752 m .41616 .30732 L .41525 .30662 L F
.41152 .30351 m .41555 .30752 L .41994 .32453 L 1 .368 0 r
F
.40975 .2991 m .41555 .30752 L .41152 .30351 L F
.40422 .29559 m .41504 .31574 L .37256 .19904 L .423 .128 0 r
F
.4087 .29833 m .41994 .32453 L .41381 .31648 L 1 .368 0 r
F
.40886 .29846 m .40886 .29844 L .4087 .29833 L .675 .29 0 r
F
.40975 .2991 m .41994 .32453 L .4087 .29833 L 1 .368 0 r
F
.40886 .29844 m .36403 .15522 L .4087 .29833 L .675 .29 0 r
F
.40501 .29516 m .4087 .29833 L .41381 .31648 L 1 .386 0 r
F
.4005 .28424 m .4087 .29833 L .40501 .29516 L F
.39872 .28164 m .41381 .31648 L .40334 .2978 L F
.4005 .28424 m .41381 .31648 L .39872 .28164 L F
.39872 .28164 m .37256 .19904 L .37314 .21677 L .423 .128 0 r
F
.39912 .28223 m .37256 .19904 L .39872 .28164 L F
.41525 .30662 m .36461 .13525 L .36403 .15522 L .806 .375 0 r
F
.41616 .30732 m .36461 .13525 L .41525 .30662 L F
.41668 .30861 m .42053 .31195 L .42316 .32447 L 1 .304 0 r
F
.42458 .32476 m .42116 .31249 L .42053 .31195 L .823 .385 0 r
F
.42116 .31249 m .42094 .31174 L .42053 .31195 L F
.42007 .30975 m .42428 .31379 L .42436 .31421 L 1 .202 0 r
F
.42458 .32476 m .4274 .32358 L .42491 .31514 L .823 .385 0 r
F
.42094 .31174 m .42436 .31421 L .42446 .31475 L 1 .202 0 r
F
.42007 .30975 m .42436 .31421 L .42094 .31174 L F
.42428 .31379 m .4248 .31428 L .42491 .31514 L F
.42458 .32476 m .42491 .31514 L .42394 .31431 L .823 .385 0 r
F
.42428 .31379 m .42491 .31514 L .42598 .32316 L 1 .202 0 r
F
.42394 .31431 m .42491 .31514 L .42375 .31121 L .823 .385 0 r
F
.42458 .32476 m .42375 .31121 L .42094 .31174 L F
.42094 .31174 m .42446 .31475 L .42598 .32316 L 1 .202 0 r
F
.4205 .31182 m .42598 .32316 L .42316 .32447 L F
.42007 .30975 m .42094 .31174 L .4205 .31182 L F
.42094 .31174 m .42598 .32316 L .4205 .31182 L F
.42094 .31174 m .42375 .31121 L .36934 .12711 L .823 .385 0 r
F
.42053 .31195 m .42094 .31174 L .42032 .31128 L F
.42032 .31128 m .36934 .12711 L .36461 .13525 L F
.42094 .31174 m .36934 .12711 L .42032 .31128 L F
.42529 .31641 m .42498 .3153 L .42491 .31514 L .225 .174 0 r
F
.4248 .31428 m .41056 .26214 L .42488 .31492 L .762 .338 0 r
F
.42498 .3153 m .41056 .26214 L .42491 .31514 L .225 .174 0 r
F
.4274 .32358 m .42582 .31781 L .42529 .31641 L F
.42582 .31781 m .41056 .26214 L .42529 .31641 L F
.42491 .31514 m .41056 .26214 L .36934 .12711 L F
.42491 .31514 m .41056 .26214 L .42598 .32316 L .762 .338 0 r
F
.52722 .4885 m .50798 .4878 L .50816 .49051 L .896 .562 0 r
F
.52722 .4885 m .52693 .48578 L .50798 .4878 L F
.57949 .09941 m .57128 .1024 L .57808 .1053 L .429 .627 0 r
F
.58633 .10206 m .57949 .09941 L .57808 .1053 L .42 .608 0 r
F
.4872 .45366 m .46961 .4513 L .46958 .45399 L 1 .767 0 r
F
.4872 .45366 m .48706 .45096 L .46961 .4513 L F
.52493 .46945 m .50644 .46875 L .50669 .47147 L .903 .616 0 r
F
.5253 .47217 m .52493 .46945 L .50669 .47147 L .902 .609 0 r
F
.46961 .45119 m .45245 .44795 L .45223 .45063 L 1 .815 0 r
F
.46961 .45119 m .46964 .4485 L .45245 .44795 L F
.52577 .47763 m .5071 .47692 L .50732 .47964 L .888 .579 0 r
F
.52608 .48034 m .50732 .47964 L .50752 .48235 L .887 .571 0 r
F
.52608 .48034 m .52577 .47763 L .50732 .47964 L F
.52544 .47491 m .50688 .4742 L .5071 .47692 L .889 .587 0 r
F
.52577 .47763 m .52544 .47491 L .5071 .47692 L .888 .579 0 r
F
.46896 .51052 m .44916 .50702 L .44907 .50966 L 1 .68 0 r
F
.46893 .51318 m .46896 .51052 L .44907 .50966 L 1 .674 0 r
F
.46648 .08156 m .47071 .07746 L .46534 .08134 L .915 1 0 r
F
.46648 .08156 m .47071 .07746 L .46534 .08135 L .917 1 0 r
F
.52639 .48305 m .50752 .48235 L .50772 .48507 L .886 .563 0 r
F
.52639 .48305 m .52608 .48034 L .50752 .48235 L F
.10075 .47242 m .07862 .44734 L .07728 .454 L 1 .972 0 r
F
.09963 .47902 m .10075 .47242 L .07728 .454 L 1 .959 0 r
F
.52509 .4722 m .50664 .47148 L .50688 .4742 L .89 .595 0 r
F
.52544 .47491 m .52509 .4722 L .50688 .4742 L .889 .587 0 r
F
.11708 .62203 m .08809 .59995 L .08881 .60659 L 1 .711 0 r
F
.11785 .62851 m .11708 .62203 L .08881 .60659 L 1 .692 0 r
F
.52748 .49122 m .50816 .49051 L .50833 .49322 L .895 .554 0 r
F
.52748 .49122 m .52722 .4885 L .50816 .49051 L F
.44353 .6031 m .41944 .59827 L .41967 .60101 L 1 .42 0 r
F
.44367 .60575 m .44353 .6031 L .41967 .60101 L 1 .406 0 r
F
.57259 .0969 m .56443 .09962 L .57128 .1024 L .442 .645 0 r
F
.57949 .09941 m .57259 .0969 L .57128 .1024 L .429 .627 0 r
F
.45034 .48032 m .43216 .4761 L .43189 .47878 L 1 .796 0 r
F
.45034 .48032 m .45049 .47763 L .43216 .4761 L F
.4502 .48301 m .45034 .48032 L .43189 .47878 L 1 .789 0 r
F
.46958 .45399 m .45234 .45079 L .45213 .45346 L 1 .813 0 r
F
.46958 .45399 m .46961 .4513 L .45234 .45079 L F
.7055 .26124 m .70235 .26059 L .70379 .26759 L 0 0 0 r
F
.7055 .26124 m .70415 .25435 L .70235 .26059 L F
.52667 .48576 m .50772 .48507 L .5079 .48778 L .885 .555 0 r
F
.52667 .48576 m .52639 .48305 L .50772 .48507 L F
.33588 .20932 m .35058 .23148 L .34371 .22963 L .819 .064 0 r
F
.33588 .20932 m .34376 .21225 L .35058 .23148 L F
.45049 .47763 m .43244 .47343 L .43216 .4761 L 1 .802 0 r
F
.45049 .47763 m .45065 .47494 L .43244 .47343 L F
.52455 .46672 m .50618 .46603 L .50644 .46875 L .904 .624 0 r
F
.52493 .46945 m .52455 .46672 L .50644 .46875 L .903 .616 0 r
F
.4502 .48301 m .43189 .47878 L .43163 .48145 L 1 .789 0 r
F
.45006 .48569 m .4502 .48301 L .43163 .48145 L 1 .783 0 r
F
.46648 .08182 m .47071 .07751 L .46535 .08171 L .944 1 0 r
F
.46648 .08183 m .47071 .07751 L .46535 .08173 L .946 1 0 r
F
.39476 .57473 m .37261 .56715 L .37277 .57018 L 1 .649 0 r
F
.39493 .5777 m .39476 .57473 L .37277 .57018 L 1 .637 0 r
F
.5396 .59954 m .51671 .5997 L .5164 .60226 L .746 .081 0 r
F
.5396 .59954 m .54007 .597 L .51671 .5997 L F
.71908 .16 m .70847 .16982 L .71431 .17415 L .343 .407 0 r
F
.71908 .16 m .71306 .156 L .70847 .16982 L F
.52473 .46949 m .5064 .46876 L .50664 .47148 L .891 .603 0 r
F
.52509 .4722 m .52473 .46949 L .50664 .47148 L .89 .595 0 r
F
.65618 .46035 m .64188 .46458 L .64111 .46849 L .199 .004 0 r
F
.65618 .46035 m .65708 .45641 L .64188 .46458 L F
.58599 .10318 m .57789 .10597 L .58455 .10914 L .39 .553 0 r
F
.59262 .10627 m .58455 .10914 L .59113 .11246 L .369 .512 0 r
F
.59262 .10627 m .58599 .10318 L .58455 .10914 L F
.45065 .47494 m .43273 .47075 L .43244 .47343 L 1 .809 0 r
F
.45065 .47494 m .45082 .47225 L .43273 .47075 L F
.44916 .5019 m .42986 .4976 L .42967 .50028 L 1 .736 0 r
F
.44906 .50458 m .44916 .5019 L .42967 .50028 L 1 .728 0 r
F
.73412 .78419 m .70496 .78815 L .7024 .79296 L .316 0 0 r
F
.73412 .78419 m .73706 .77924 L .70496 .78815 L F
.45006 .48569 m .43163 .48145 L .43139 .48412 L 1 .783 0 r
F
.44992 .48837 m .45006 .48569 L .43139 .48412 L 1 .776 0 r
F
.61759 .70701 m .59171 .70983 L .59091 .71413 L .515 .048 0 r
F
.61759 .70701 m .61875 .70297 L .59171 .70983 L F
.57924 .10028 m .57114 .10294 L .57789 .10597 L .407 .588 0 r
F
.58599 .10318 m .57924 .10028 L .57789 .10597 L .39 .553 0 r
F
.45141 .46138 m .43409 .45724 L .43373 .45992 L 1 .838 0 r
F
.45141 .46138 m .45161 .45868 L .43409 .45724 L F
.72609 .16277 m .71502 .17325 L .72081 .17767 L .347 .402 0 r
F
.72609 .16277 m .72013 .15864 L .71502 .17325 L F
.52694 .48846 m .5079 .48778 L .50808 .49049 L .884 .547 0 r
F
.52694 .48846 m .52667 .48576 L .5079 .48778 L F
.52773 .49393 m .50833 .49322 L .50849 .49593 L .894 .546 0 r
F
.52773 .49393 m .52748 .49122 L .50833 .49322 L F
.47021 .07811 m .46985 .07831 L .46535 .08226 L .982 1 0 r
F
.46649 .08218 m .47021 .07811 L .46535 .08226 L F
.46649 .08219 m .47021 .07811 L .46535 .08227 L .985 1 0 r
F
.47021 .07811 m .47071 .07756 L .46985 .07831 L .982 1 0 r
F
.47021 .07811 m .47071 .07756 L .46986 .07831 L .985 1 0 r
F
.47021 .07811 m .46986 .07831 L .46535 .08227 L F
.46534 .08134 m .47035 .07745 L .46435 .08115 L .833 .994 0 r
F
.46534 .08134 m .47071 .07746 L .47035 .07745 L F
.46534 .08135 m .47035 .07745 L .46435 .08116 L .834 .994 0 r
F
.46534 .08135 m .47071 .07746 L .47035 .07745 L F
.46535 .08171 m .47035 .07753 L .46436 .0817 L .851 .978 0 r
F
.46535 .08171 m .47071 .07751 L .47035 .07753 L F
.46535 .08173 m .47035 .07753 L .46436 .08172 L .852 .978 0 r
F
.46535 .08173 m .47071 .07751 L .47035 .07753 L F
.46535 .08226 m .46918 .0787 L .46437 .08258 L .881 .959 0 r
F
.46918 .0787 m .47035 .07762 L .46871 .07898 L F
.46918 .0787 m .46871 .07898 L .46437 .08258 L F
.46918 .0787 m .46992 .07825 L .46922 .07866 L F
.46535 .08226 m .46985 .07831 L .46918 .0787 L F
.46985 .07831 m .46992 .07825 L .46918 .0787 L F
.46535 .08227 m .46919 .07869 L .46437 .08262 L .882 .96 0 r
F
.46919 .07869 m .47035 .07762 L .46874 .07896 L F
.46919 .07869 m .46874 .07896 L .46437 .08262 L F
.46922 .07866 m .47071 .07756 L .47035 .07762 L .881 .959 0 r
F
.46923 .07866 m .47071 .07756 L .47035 .07762 L .882 .96 0 r
F
.46535 .08227 m .46986 .07831 L .46919 .07869 L F
.46919 .07869 m .46993 .07824 L .46923 .07866 L F
.46986 .07831 m .46993 .07824 L .46919 .07869 L F
.46992 .07825 m .47071 .07756 L .46922 .07866 L .881 .959 0 r
F
.46993 .07824 m .47071 .07756 L .46923 .07866 L .882 .96 0 r
F
.46649 .08219 m .47113 .07761 L .47071 .07756 L .985 1 0 r
F
.46437 .08262 m .46855 .07927 L .46365 .08733 L 0 0 0 r
F
.46855 .07927 m .47004 .07807 L .4681 .08088 L F
.46855 .07927 m .4681 .08088 L .46365 .08733 L F
.46918 .07875 m .47035 .07762 L .47004 .07807 L F
.46437 .08262 m .46874 .07896 L .46918 .07876 L F
.46437 .08258 m .46854 .07926 L .46364 .08713 L F
.46436 .08172 m .46669 .08013 L .46357 .08349 L F
.46669 .08013 m .467 .07992 L .46566 .08131 L F
.46669 .08013 m .46566 .08131 L .46357 .08349 L F
.46854 .07926 m .47004 .07806 L .46807 .08085 L F
.46854 .07926 m .46807 .08085 L .46364 .08713 L F
.46357 .08349 m .4671 .08098 L .46297 .08547 L .389 .034 0 r
F
.46785 .08234 m .47004 .07807 L .46981 .08001 L .39 .044 0 r
F
.46365 .08733 m .46824 .08067 L .46785 .08234 L F
.46824 .08067 m .47004 .07807 L .46785 .08234 L F
.46364 .08713 m .46822 .08064 L .46782 .08229 L .393 .044 0 r
F
.46365 .08733 m .46728 .08302 L .46325 .09851 L .39 .044 0 r
F
.46728 .08302 m .46729 .083 L .46481 .09252 L F
.46728 .08302 m .46481 .09252 L .46325 .09851 L F
.46325 .09851 m .46875 .26607 L .46801 .32818 L .802 .334 0 r
F
.46876 .26634 m .47076 .32753 L .46994 .32761 L .802 .335 0 r
F
.46875 .26607 m .46994 .32761 L .46801 .32818 L .802 .334 0 r
F
.46325 .09851 m .46327 .09845 L .46875 .26607 L F
.46326 .09848 m .46875 .26607 L .46325 .09853 L .802 .335 0 r
F
.46875 .26607 m .47076 .32753 L .46991 .3014 L F
.46875 .26607 m .46991 .3014 L .46325 .09853 L F
.46875 .26607 m .46981 .08001 L .46986 .09429 L .802 .334 0 r
F
.46327 .09845 m .46981 .08001 L .46875 .26607 L F
.46729 .083 m .46464 .09362 L .46325 .09851 L .39 .044 0 r
F
.46785 .08234 m .46981 .08001 L .46803 .08502 L F
.46785 .08234 m .46785 .08237 L .46325 .09851 L F
.46785 .08237 m .46803 .08502 L .46395 .09654 L F
.46785 .08237 m .46395 .09654 L .46325 .09851 L F
.46323 .0974 m .46981 .07999 L .46986 .09429 L .802 .335 0 r
F
.46323 .0974 m .46986 .09429 L .46875 .26607 L F
.46328 .0977 m .46329 .09767 L .46331 .09887 L .802 .333 0 r
F
.46325 .09853 m .46876 .26634 L .468 .3278 L .802 .335 0 r
F
.46324 .09912 m .46331 .09887 L .46589 .23429 L .802 .333 0 r
F
.46475 .09231 m .46458 .09296 L .46323 .0974 L .393 .044 0 r
F
.46323 .0974 m .46326 .09848 L .46325 .09853 L .802 .335 0 r
F
.46729 .083 m .46785 .08234 L .46464 .09362 L .39 .044 0 r
F
.46364 .08713 m .46772 .08241 L .46323 .0974 L .393 .044 0 r
F
.46322 .09791 m .46331 .09887 L .46324 .09912 L .802 .333 0 r
F
.46782 .08229 m .46782 .08236 L .46323 .0974 L .393 .044 0 r
F
.46782 .08236 m .46387 .09569 L .46323 .0974 L F
.46297 .08547 m .46328 .0977 L .46322 .09791 L .802 .333 0 r
F
.46328 .0977 m .46331 .09887 L .46322 .09791 L F
.46782 .08236 m .46793 .08497 L .46387 .09569 L .393 .044 0 r
F
.46309 .08763 m .46893 .22002 L .46589 .23429 L .802 .333 0 r
F
.46321 .09801 m .46364 .09764 L .46324 .09924 L .802 .334 0 r
F
.46297 .08547 m .46309 .08763 L .46329 .09767 L .802 .333 0 r
F
.46297 .08547 m .46329 .09767 L .46328 .0977 L F
.4671 .08098 m .46681 .08134 L .46297 .08547 L .389 .034 0 r
F
.46681 .08134 m .46507 .0835 L .46298 .08546 L F
.46681 .08134 m .46298 .08546 L .46297 .08547 L F
.46297 .08547 m .46358 .09665 L .46321 .09801 L .802 .334 0 r
F
.46297 .0853 m .46298 .08546 L .46297 .08547 L F
.46298 .08546 m .46358 .09665 L .46297 .08547 L F
.46358 .09665 m .46364 .09764 L .46321 .09801 L F
.46772 .08241 m .46773 .08259 L .46458 .09296 L .393 .044 0 r
F
.46772 .08241 m .46458 .09296 L .46475 .09231 L F
.46875 .26607 m .46986 .09429 L .47076 .32753 L .802 .335 0 r
F
.46875 .26607 m .46986 .09429 L .47076 .32737 L .802 .334 0 r
F
.46875 .26607 m .47076 .32737 L .46994 .32761 L F
.46876 .26634 m .46994 .32761 L .468 .3278 L .802 .335 0 r
F
.46476 .12552 m .47028 .22035 L .46893 .22002 L .802 .334 0 r
F
.46364 .09764 m .47028 .22035 L .46324 .09924 L F
.46772 .08241 m .46782 .08229 L .46773 .08259 L .393 .044 0 r
F
.46782 .08229 m .46981 .07999 L .46793 .08497 L F
.46782 .08229 m .47004 .07806 L .46981 .07999 L F
.46822 .08064 m .47004 .07806 L .46782 .08229 L F
.4671 .08098 m .46981 .07906 L .46507 .0835 L .389 .034 0 r
F
.46918 .07876 m .46877 .07894 L .46918 .07875 L 0 0 0 r
F
.46874 .07896 m .46877 .07894 L .46918 .07876 L F
.46877 .07894 m .47035 .07762 L .46918 .07875 L F
.46915 .07877 m .47035 .07762 L .47004 .07806 L F
.46437 .08258 m .46871 .07898 L .46915 .07877 L F
.46871 .07898 m .47035 .07762 L .46915 .07877 L F
.46357 .08349 m .46863 .07907 L .46981 .07906 L .389 .034 0 r
F
.46863 .07907 m .47004 .07784 L .46994 .07837 L F
.46863 .07907 m .46994 .07837 L .46981 .07906 L F
.467 .07992 m .46818 .07931 L .46357 .08349 L 0 0 0 r
F
.46818 .07931 m .46861 .07909 L .46767 .07991 L F
.46297 .08547 m .46981 .07906 L .46981 .07927 L .802 .333 0 r
F
.46309 .08763 m .46505 .08519 L .47028 .22035 L .802 .334 0 r
F
.46297 .08547 m .46981 .07927 L .46309 .08763 L .802 .333 0 r
F
.46499 .08345 m .46981 .07905 L .46983 .08604 L .802 .334 0 r
F
.46499 .08345 m .46983 .08604 L .47028 .22035 L F
.46309 .08763 m .46981 .07927 L .47025 .21383 L .802 .333 0 r
F
.46297 .0853 m .46499 .08345 L .46505 .08519 L .802 .334 0 r
F
.46297 .0853 m .46505 .08519 L .46309 .08763 L F
.46279 .08567 m .46464 .08403 L .46277 .08636 L .782 .291 0 r
F
.46278 .08572 m .46457 .08395 L .46276 .08615 L .783 .292 0 r
F
.46795 .07952 m .46749 .08007 L .46357 .08349 L 0 0 0 r
F
.46402 .08344 m .46661 .08147 L .46421 .084 L .389 .034 0 r
F
.46402 .08344 m .46421 .084 L .46297 .0853 L F
.46342 .08389 m .46402 .08344 L .46297 .0853 L F
.46357 .08342 m .46423 .08295 L .46342 .08389 L F
.46423 .08295 m .46981 .07905 L .46342 .08389 L F
.46436 .0817 m .46693 .07995 L .46357 .08342 L 0 0 0 r
F
.46693 .07996 m .46813 .07934 L .46357 .08342 L F
.46818 .07931 m .46749 .08007 L .46795 .07952 L F
.46813 .07934 m .46766 .07989 L .46357 .08342 L F
.46815 .07932 m .46814 .07933 L .46813 .07934 L F
.46814 .07933 m .46766 .07989 L .46813 .07934 L F
.467 .07992 m .47035 .07753 L .47004 .07784 L F
.46436 .08172 m .46685 .07998 L .467 .07992 L F
.46685 .07998 m .47035 .07753 L .467 .07992 L F
.46357 .08342 m .47004 .07784 L .46981 .07905 L .389 .034 0 r
F
.46966 .07855 m .46966 .07855 L .46781 .0796 L .352 .014 0 r
F
.46781 .0796 m .46781 .0796 L .46296 .08234 L F
.46966 .07855 m .46781 .0796 L .46781 .0796 L F
.46692 .07996 m .47035 .07753 L .47004 .07784 L 0 0 0 r
F
.46436 .0817 m .46677 .08002 L .46692 .07996 L F
.46677 .08002 m .47035 .07753 L .46692 .07996 L F
.46315 .08223 m .46773 .07965 L .46296 .08234 L .352 .014 0 r
F
.46773 .07965 m .46966 .07855 L .46774 .07964 L F
.46773 .07965 m .46774 .07964 L .46296 .08234 L F
.46966 .07855 m .46975 .07851 L .46966 .07855 L F
.46586 .08064 m .4696 .07859 L .46298 .08232 L F
.4696 .07859 m .4698 .07848 L .46966 .07855 L F
.4696 .07859 m .46966 .07855 L .46298 .08232 L F
.467 .07992 m .47004 .07784 L .46861 .07909 L 0 0 0 r
F
.46693 .07995 m .46815 .07932 L .46813 .07934 L F
.46693 .07995 m .46813 .07934 L .46693 .07996 L F
.46818 .07931 m .46767 .07991 L .46749 .08007 L F
.46815 .07932 m .46857 .07911 L .46766 .07989 L F
.4628 .0855 m .46439 .08379 L .46279 .08567 L .782 .291 0 r
F
.46291 .08238 m .46433 .08373 L .4628 .0855 L F
.46433 .08373 m .46439 .08379 L .4628 .0855 L F
.46296 .08234 m .46346 .08205 L .46291 .08238 L .352 .014 0 r
F
.46346 .08205 m .46973 .07852 L .46296 .08235 L F
.46346 .08205 m .46296 .08235 L .46291 .08238 L F
.46661 .08147 m .46981 .07905 L .46496 .08348 L .389 .034 0 r
F
.46661 .08147 m .46496 .08348 L .46297 .0853 L F
.46291 .08238 m .4698 .07848 L .4698 .07905 L .782 .291 0 r
F
.4648 .08418 m .4698 .07905 L .46968 .08898 L .783 .292 0 r
F
.4648 .08418 m .4698 .07905 L .46968 .08881 L .782 .291 0 r
F
.46291 .08238 m .4698 .07905 L .4648 .08418 L F
.46975 .07851 m .4698 .07848 L .46975 .07851 L .352 .014 0 r
F
.46975 .07851 m .46975 .07851 L .46296 .08234 L F
.46973 .07852 m .4698 .07848 L .46973 .07852 L F
.46973 .07852 m .46973 .07852 L .46291 .08238 L F
.4629 .08231 m .4698 .07847 L .4698 .07905 L .783 .292 0 r
F
.46298 .08232 m .46315 .08223 L .46296 .08234 L .352 .014 0 r
F
.4629 .08231 m .4698 .07905 L .4648 .08418 L .783 .292 0 r
F
.4629 .08238 m .46439 .08378 L .46278 .08572 L F
.4629 .08231 m .46295 .08236 L .4629 .08238 L F
.46295 .08236 m .46439 .08378 L .4629 .08238 L F
.46439 .08379 m .46464 .08403 L .46279 .08567 L .782 .291 0 r
F
.46439 .08378 m .46457 .08395 L .46278 .08572 L .783 .292 0 r
F
.46671 .08016 m .46975 .0785 L .46573 .08074 L .351 .014 0 r
F
.46389 .08168 m .46981 .07846 L .4698 .07848 L .352 .014 0 r
F
.46975 .0785 m .46977 .07848 L .46975 .07849 L .351 .014 0 r
F
.46975 .0785 m .46975 .07849 L .46573 .08074 L F
.46309 .08763 m .47025 .21383 L .46893 .22002 L .802 .333 0 r
F
.46324 .09924 m .46476 .12552 L .46555 .21918 L .802 .334 0 r
F
.46476 .12552 m .46893 .22002 L .46555 .21918 L F
.4648 .08418 m .46664 .08743 L .46263 .09027 L .782 .291 0 r
F
.46664 .08743 m .46767 .08923 L .46614 .08955 L F
.46664 .08743 m .46614 .08955 L .46263 .09027 L F
.46667 .08602 m .46798 .08731 L .46571 .08947 L .783 .292 0 r
F
.46688 .08616 m .4682 .08741 L .46659 .08734 L .782 .291 0 r
F
.46798 .08731 m .46968 .08898 L .46808 .08918 L .783 .292 0 r
F
.4682 .08741 m .46968 .08881 L .46825 .08813 L .782 .291 0 r
F
.46798 .08731 m .46808 .08918 L .46571 .08947 L .783 .292 0 r
F
.4682 .08741 m .46825 .08813 L .46659 .08734 L .782 .291 0 r
F
.46659 .08734 m .46805 .08804 L .46767 .08923 L F
.46805 .08804 m .46968 .08881 L .46809 .08914 L F
.46805 .08804 m .46809 .08914 L .46767 .08923 L F
.46582 .08597 m .46658 .08593 L .46608 .08643 L .783 .292 0 r
F
.46277 .08636 m .4648 .08418 L .46263 .09027 L .782 .291 0 r
F
.46464 .08403 m .4648 .08418 L .46277 .08636 L F
.46457 .08395 m .46658 .08593 L .46276 .08615 L .783 .292 0 r
F
.46658 .08593 m .46667 .08602 L .4665 .08618 L F
.46658 .08593 m .4665 .08618 L .46262 .08986 L F
.46667 .08602 m .46571 .08947 L .46262 .08986 L F
.4648 .08418 m .46688 .08616 L .46659 .08734 L .782 .291 0 r
F
.46276 .08615 m .46582 .08597 L .46262 .08986 L .783 .292 0 r
F
.46582 .08597 m .46608 .08643 L .46262 .08986 L F
.46977 .07848 m .4698 .07847 L .46978 .07848 L .351 .014 0 r
F
.46977 .07848 m .46978 .07848 L .46573 .08074 L F
.46693 .07995 m .47004 .07784 L .46857 .07911 L 0 0 0 r
F
.46354 .0819 m .46389 .08168 L .4698 .07848 L .352 .014 0 r
F
.46597 .08055 m .46795 .07948 L .46559 .08077 L .351 .014 0 r
F
.46603 .08051 m .46795 .07948 L .46597 .08055 L F
.46603 .08051 m .46964 .07856 L .46795 .07948 L F
.46964 .07856 m .4698 .07847 L .46966 .07855 L F
.46964 .07856 m .46966 .07855 L .46559 .08077 L F
.46437 .08142 m .46603 .08051 L .4634 .08197 L F
.46603 .08051 m .46559 .08077 L .4634 .08197 L F
.46389 .08168 m .47004 .07767 L .46981 .07846 L .352 .014 0 r
F
.46551 .08081 m .46688 .08006 L .46541 .08087 L .351 .014 0 r
F
.46688 .08006 m .4698 .07847 L .46684 .08009 L F
.46688 .08006 m .46684 .08009 L .46541 .08087 L F
.46359 .08186 m .46551 .08081 L .46337 .08199 L F
.46551 .08081 m .46541 .08087 L .46337 .08199 L F
.46354 .0819 m .46586 .08064 L .46298 .08232 L .352 .014 0 r
F
.46337 .08199 m .46671 .08016 L .4629 .08231 L .351 .014 0 r
F
.46671 .08016 m .46573 .08074 L .4629 .08231 L F
.4634 .08197 m .46359 .08186 L .46337 .08199 L F
.46435 .08116 m .47004 .07767 L .46389 .08168 L 0 0 0 r
F
.46369 .08177 m .46389 .08168 L .46354 .0819 L F
.46435 .08116 m .46389 .08168 L .46369 .08177 L F
.46354 .08187 m .46391 .08166 L .4634 .08197 L .351 .014 0 r
F
.46391 .08166 m .46437 .08142 L .46401 .08162 L F
.46391 .08166 m .46401 .08162 L .4634 .08197 L F
.45082 .47225 m .43303 .46808 L .43273 .47075 L 1 .815 0 r
F
.45082 .47225 m .45099 .46956 L .43303 .46808 L F
.52435 .46678 m .50615 .46605 L .5064 .46876 L .892 .61 0 r
F
.52473 .46949 m .52435 .46678 L .5064 .46876 L .891 .603 0 r
F
.52736 .77372 m .49795 .77876 L .49764 .78316 L .634 .059 0 r
F
.52736 .77372 m .52798 .76947 L .49795 .77876 L F
.50934 .51475 m .48914 .51311 L .48917 .51577 L .949 .551 0 r
F
.50934 .51475 m .50925 .51208 L .48914 .51311 L F
.44992 .48837 m .43139 .48412 L .43116 .48678 L 1 .776 0 r
F
.4498 .49105 m .44992 .48837 L .43116 .48678 L 1 .769 0 r
F
.56563 .09448 m .55751 .09696 L .56443 .09962 L .459 .665 0 r
F
.57259 .0969 m .56563 .09448 L .56443 .09962 L .442 .645 0 r
F
.52415 .464 m .50591 .46332 L .50618 .46603 L .905 .631 0 r
F
.52455 .46672 m .52415 .464 L .50618 .46603 L .904 .624 0 r
F
.57241 .09758 m .56432 .10005 L .57114 .10294 L .421 .615 0 r
F
.57924 .10028 m .57241 .09758 L .57114 .10294 L .407 .588 0 r
F
.21726 .77049 m .18169 .7555 L .18423 .76094 L 1 .336 0 r
F
.21956 .77571 m .21726 .77049 L .18423 .76094 L 1 .312 0 r
F
.50919 .51461 m .48913 .51309 L .48916 .51574 L .935 .531 0 r
F
.50919 .51461 m .5091 .51196 L .48913 .51309 L F
.26628 .80818 m .22957 .79589 L .23227 .80076 L 1 .214 0 r
F
.26864 .81284 m .26628 .80818 L .23227 .80076 L 1 .188 0 r
F
.42715 .36274 m .41887 .36503 L .41746 .36756 L 1 1 0 r
F
.42715 .36274 m .4282 .35965 L .41887 .36503 L F
.5272 .49116 m .50808 .49049 L .50824 .49319 L .882 .538 0 r
F
.5272 .49116 m .52694 .48846 L .50808 .49049 L F
.48706 .45096 m .46965 .44862 L .46961 .4513 L 1 .773 0 r
F
.48706 .45096 m .48692 .44827 L .46965 .44862 L F
.4689 .51595 m .44879 .51258 L .44872 .51522 L 1 .644 0 r
F
.46888 .51859 m .4689 .51595 L .44872 .51522 L 1 .636 0 r
F
.45099 .46956 m .43335 .46541 L .43303 .46808 L 1 .821 0 r
F
.45099 .46956 m .45116 .46687 L .43335 .46541 L F
.71806 .58706 m .69371 .59178 L .69304 .5962 L .361 .041 0 r
F
.71806 .58706 m .71892 .58259 L .69371 .59178 L F
.4498 .49105 m .43116 .48678 L .43094 .48945 L 1 .769 0 r
F
.44967 .49373 m .4498 .49105 L .43094 .48945 L 1 .763 0 r
F
.52396 .46406 m .50588 .46333 L .50615 .46605 L .893 .618 0 r
F
.52435 .46678 m .52396 .46406 L .50615 .46605 L .892 .61 0 r
F
.52797 .49664 m .50849 .49593 L .50864 .49864 L .892 .538 0 r
F
.52797 .49664 m .52773 .49393 L .50849 .49593 L F
.46893 .51318 m .44907 .50966 L .44899 .51229 L 1 .674 0 r
F
.46891 .51582 m .46893 .51318 L .44899 .51229 L 1 .668 0 r
F
.56549 .09504 m .55743 .0973 L .56432 .10005 L .434 .639 0 r
F
.57241 .09758 m .56549 .09504 L .56432 .10005 L .421 .615 0 r
F
.46964 .4485 m .45268 .44529 L .45245 .44795 L 1 .821 0 r
F
.46964 .4485 m .46968 .44582 L .45268 .44529 L F
.44906 .50458 m .42967 .50028 L .42949 .50296 L 1 .728 0 r
F
.44896 .50725 m .44906 .50458 L .42949 .50296 L 1 .721 0 r
F
.87306 .5512 m .8495 .56167 L .84926 .56832 L .145 .012 0 r
F
.87306 .5512 m .87335 .54444 L .8495 .56167 L F
.52374 .46129 m .50564 .4606 L .50591 .46332 L .906 .638 0 r
F
.52415 .464 m .52374 .46129 L .50591 .46332 L .905 .631 0 r
F
.45161 .45868 m .43446 .45457 L .43409 .45724 L 1 .845 0 r
F
.45161 .45868 m .45181 .45599 L .43446 .45457 L F
.56563 .09448 m .55861 .09218 L .55751 .09696 L .459 .665 0 r
F
.46961 .4513 m .45255 .44813 L .45234 .45079 L 1 .82 0 r
F
.46961 .4513 m .46965 .44862 L .45255 .44813 L F
.52744 .49386 m .50824 .49319 L .5084 .49589 L .881 .53 0 r
F
.52744 .49386 m .5272 .49116 L .50824 .49319 L F
.37229 .54239 m .35241 .53364 L .35228 .5368 L 1 .806 0 r
F
.37224 .54553 m .37229 .54239 L .35228 .5368 L 1 .795 0 r
F
.45116 .46687 m .43367 .46274 L .43335 .46541 L 1 .828 0 r
F
.45116 .46687 m .45134 .46418 L .43367 .46274 L F
.87017 .38284 m .85071 .39587 L .85293 .40249 L .174 .051 0 r
F
.87017 .38284 m .86783 .37623 L .85071 .39587 L F
.44967 .49373 m .43094 .48945 L .43073 .4921 L 1 .763 0 r
F
.44956 .4964 m .44967 .49373 L .43073 .4921 L 1 .756 0 r
F
.51575 .60728 m .49219 .60632 L .49203 .60885 L .829 .147 0 r
F
.51575 .60728 m .51608 .60479 L .49219 .60632 L F
.72504 .16407 m .71431 .17415 L .72008 .17856 L .337 .392 0 r
F
.72504 .16407 m .71908 .16 L .71431 .17415 L F
.58737 .5694 m .56662 .57166 L .56612 .57445 L .557 .058 0 r
F
.58737 .5694 m .58801 .56661 L .56662 .57166 L F
.52356 .46135 m .50561 .46062 L .50588 .46333 L .894 .626 0 r
F
.52396 .46406 m .52356 .46135 L .50588 .46333 L .893 .618 0 r
F
.56335 .58794 m .54142 .58917 L .54099 .59182 L .655 .066 0 r
F
.56335 .58794 m .56394 .5853 L .54142 .58917 L F
.63802 .12803 m .62971 .13275 L .63581 .13664 L .324 .418 0 r
F
.63802 .12803 m .63179 .12454 L .62971 .13275 L F
.56549 .09504 m .55851 .09263 L .55743 .0973 L .434 .639 0 r
F
.78313 .73707 m .75525 .7427 L .75291 .74811 L .255 0 0 r
F
.78313 .73707 m .78576 .73151 L .75525 .7427 L F
.52819 .49935 m .50864 .49864 L .50878 .50134 L .891 .53 0 r
F
.52819 .49935 m .52797 .49664 L .50864 .49864 L F
.7469 .5153 m .72595 .52237 L .72565 .52714 L .267 .033 0 r
F
.7469 .5153 m .74719 .51046 L .72595 .52237 L F
.50942 .51742 m .48917 .51577 L .4892 .51842 L .948 .543 0 r
F
.50942 .51742 m .50934 .51475 L .48917 .51577 L F
.73197 .16699 m .72081 .17767 L .72653 .18218 L .339 .382 0 r
F
.73197 .16699 m .72609 .16277 L .72081 .17767 L F
.39751 .80626 m .36092 .80627 L .36226 .81042 L .918 .158 0 r
F
.39838 .81042 m .39751 .80626 L .36226 .81042 L .909 .135 0 r
F
.43271 .80426 m .39751 .80626 L .39838 .81042 L .851 .115 0 r
F
.52331 .45857 m .50535 .45789 L .50564 .4606 L .906 .646 0 r
F
.52374 .46129 m .52331 .45857 L .50564 .4606 L .906 .638 0 r
F
.61114 .54302 m .59194 .54622 L .59143 .54923 L .443 .049 0 r
F
.61114 .54302 m .61176 .54002 L .59194 .54622 L F
.68378 .63927 m .65844 .64233 L .6576 .64657 L .425 .044 0 r
F
.68378 .63927 m .68492 .63507 L .65844 .64233 L F
.52766 .49655 m .5084 .49589 L .50854 .49859 L .88 .522 0 r
F
.52766 .49655 m .52744 .49386 L .5084 .49589 L F
.45134 .46418 m .43401 .46007 L .43367 .46274 L 1 .834 0 r
F
.45134 .46418 m .45153 .4615 L .43401 .46007 L F
.44956 .4964 m .43073 .4921 L .43054 .49476 L 1 .756 0 r
F
.44945 .49906 m .44956 .4964 L .43054 .49476 L 1 .75 0 r
F
.50926 .51726 m .48916 .51574 L .48919 .51838 L .934 .523 0 r
F
.50926 .51726 m .50919 .51461 L .48916 .51574 L F
.44896 .50725 m .42949 .50296 L .42933 .50563 L 1 .721 0 r
F
.44887 .50992 m .44896 .50725 L .42933 .50563 L 1 .713 0 r
F
.48692 .44827 m .46969 .44595 L .46965 .44862 L 1 .78 0 r
F
.48692 .44827 m .48677 .44559 L .46969 .44595 L F
.52314 .45865 m .50532 .45791 L .50561 .46062 L .895 .633 0 r
F
.52356 .46135 m .52314 .45865 L .50561 .46062 L .894 .626 0 r
F
.46891 .51582 m .44899 .51229 L .44892 .51491 L 1 .668 0 r
F
.46889 .51847 m .46891 .51582 L .44892 .51491 L 1 .662 0 r
F
.45181 .45599 m .43484 .4519 L .43446 .45457 L 1 .851 0 r
F
.45181 .45599 m .45202 .45331 L .43484 .4519 L F
.87938 .55923 m .85445 .56953 L .85423 .57629 L .171 .017 0 r
F
.87938 .55923 m .87962 .55235 L .85445 .56953 L F
.46888 .51859 m .44872 .51522 L .44865 .51786 L 1 .636 0 r
F
.46886 .52121 m .46888 .51859 L .44865 .51786 L 1 .628 0 r
F
.64419 .13159 m .63581 .13664 L .64181 .14062 L .322 .409 0 r
F
.64419 .13159 m .63802 .12803 L .63581 .13664 L F
.5284 .50205 m .50878 .50134 L .50891 .50403 L .89 .522 0 r
F
.5284 .50205 m .52819 .49935 L .50878 .50134 L F
.4651 .87168 m .46505 .86837 L .42939 .86785 L .76 .048 0 r
F
.50012 .87106 m .46505 .86837 L .4651 .87168 L .698 .041 0 r
F
.50012 .87106 m .50069 .86775 L .46505 .86837 L F
.46968 .44582 m .45291 .44263 L .45268 .44529 L 1 .828 0 r
F
.46968 .44582 m .46972 .44314 L .45291 .44263 L F
.46965 .44862 m .45278 .44547 L .45255 .44813 L 1 .826 0 r
F
.46965 .44862 m .46969 .44595 L .45278 .44547 L F
.52287 .45586 m .50505 .45518 L .50535 .45789 L .907 .653 0 r
F
.52331 .45857 m .52287 .45586 L .50535 .45789 L .906 .646 0 r
F
.22751 .74407 m .1905 .73224 L .19281 .73748 L 1 .391 0 r
F
.22955 .74909 m .22751 .74407 L .19281 .73748 L 1 .372 0 r
F
.52787 .49924 m .50854 .49859 L .50868 .50128 L .878 .513 0 r
F
.52787 .49924 m .52766 .49655 L .50854 .49859 L F
.55672 .75596 m .52911 .7607 L .52856 .76513 L .574 .053 0 r
F
.55672 .75596 m .55758 .75179 L .52911 .7607 L F
.45153 .4615 m .43436 .45741 L .43401 .46007 L 1 .84 0 r
F
.45153 .4615 m .45172 .45881 L .43436 .45741 L F
.44945 .49906 m .43054 .49476 L .43036 .4974 L 1 .75 0 r
F
.44935 .50172 m .44945 .49906 L .43036 .4974 L 1 .743 0 r
F
.8329 .66512 m .80675 .6729 L .80508 .67898 L .192 0 0 r
F
.8329 .66512 m .83474 .65889 L .80675 .6729 L F
.87554 .38876 m .85567 .40192 L .85792 .40859 L .179 .052 0 r
F
.87554 .38876 m .87313 .38211 L .85567 .40192 L F
.70058 .35138 m .69383 .35394 L .69242 .36055 L 0 0 0 r
F
.70058 .35138 m .70198 .34481 L .69383 .35394 L F
.07931 .49968 m .0563 .47374 L .05525 .48074 L 1 .927 0 r
F
.07845 .50661 m .07931 .49968 L .05525 .48074 L 1 .912 0 r
F
.73095 .16823 m .72008 .17856 L .72579 .18304 L .331 .377 0 r
F
.73095 .16823 m .72504 .16407 L .72008 .17856 L F
.5227 .45594 m .50503 .4552 L .50532 .45791 L .896 .641 0 r
F
.52314 .45865 m .5227 .45594 L .50532 .45791 L .895 .633 0 r
F
.50949 .52007 m .4892 .51842 L .48923 .52107 L .946 .535 0 r
F
.50949 .52007 m .50942 .51742 L .4892 .51842 L F
.75838 .41649 m .74567 .42407 L .74607 .42942 L .032 .006 0 r
F
.75838 .41649 m .75777 .41122 L .74567 .42407 L F
.63384 .50755 m .61678 .5115 L .61626 .51481 L .335 .034 0 r
F
.63384 .50755 m .63446 .50424 L .61678 .5115 L F
.44887 .50992 m .42933 .50563 L .42917 .50829 L 1 .713 0 r
F
.44879 .51258 m .44887 .50992 L .42917 .50829 L 1 .705 0 r
F
.45709 .08495 m .46354 .08187 L .4629 .08231 L 0 0 0 r
F
.52859 .50474 m .50891 .50403 L .50903 .50672 L .888 .513 0 r
F
.52859 .50474 m .5284 .50205 L .50891 .50403 L F
.45202 .45331 m .43523 .44924 L .43484 .4519 L 1 .857 0 r
F
.45202 .45331 m .45223 .45063 L .43523 .44924 L F
.5701 .86316 m .53704 .8626 L .53586 .86601 L .555 .024 0 r
F
.5701 .86316 m .57188 .8597 L .53704 .8626 L F
.73777 .17131 m .72653 .18218 L .73218 .18676 L .329 .361 0 r
F
.73777 .17131 m .73197 .16699 L .72653 .18218 L F
.52806 .50192 m .50868 .50128 L .5088 .50396 L .877 .504 0 r
F
.52806 .50192 m .52787 .49924 L .50868 .50128 L F
.45172 .45881 m .43472 .45475 L .43436 .45741 L 1 .846 0 r
F
.45172 .45881 m .45192 .45614 L .43472 .45475 L F
.50932 .51989 m .48919 .51838 L .48921 .52101 L .932 .514 0 r
F
.50932 .51989 m .50926 .51726 L .48919 .51838 L F
.46889 .51847 m .44892 .51491 L .44885 .51753 L 1 .662 0 r
F
.46887 .5211 m .46889 .51847 L .44885 .51753 L 1 .655 0 r
F
.48677 .44559 m .46972 .44328 L .46969 .44595 L 1 .786 0 r
F
.48677 .44559 m .48662 .44291 L .46972 .44328 L F
.67812 .41228 m .66742 .41616 L .66605 .42116 L 0 0 0 r
F
.67812 .41228 m .67962 .40723 L .66742 .41616 L F
.52241 .45315 m .50475 .45248 L .50505 .45518 L .908 .66 0 r
F
.52287 .45586 m .52241 .45315 L .50505 .45518 L .907 .653 0 r
F
.44935 .50172 m .43036 .4974 L .43019 .50004 L 1 .743 0 r
F
.44925 .50437 m .44935 .50172 L .43019 .50004 L 1 .737 0 r
F
.73949 .29416 m .737 .29577 L .73867 .30205 L 0 0 0 r
F
.73949 .29416 m .73828 .28778 L .737 .29577 L F
.52225 .45324 m .50473 .45249 L .50503 .4552 L .897 .648 0 r
F
.5227 .45594 m .52225 .45324 L .50503 .4552 L .896 .641 0 r
F
.46886 .52121 m .44865 .51786 L .44858 .52049 L 1 .628 0 r
F
.46884 .52383 m .46886 .52121 L .44858 .52049 L 1 .62 0 r
F
.41922 .59549 m .39583 .58935 L .39611 .59221 L 1 .513 0 r
F
.41944 .59827 m .41922 .59549 L .39611 .59221 L 1 .5 0 r
F
.09275 .4857 m .07185 .46045 L .07049 .4672 L 1 .962 0 r
F
.0916 .49241 m .09275 .4857 L .07049 .4672 L 1 .948 0 r
F
.46969 .44595 m .453 .44282 L .45278 .44547 L 1 .832 0 r
F
.46969 .44595 m .46972 .44328 L .453 .44282 L F
.39493 .5777 m .37277 .57018 L .37296 .57318 L 1 .637 0 r
F
.39513 .58065 m .39493 .5777 L .37296 .57318 L 1 .624 0 r
F
.46972 .44314 m .45314 .43998 L .45291 .44263 L 1 .834 0 r
F
.46972 .44314 m .46976 .44048 L .45314 .43998 L F
.37224 .54553 m .35228 .5368 L .35217 .53994 L 1 .795 0 r
F
.37221 .54866 m .37224 .54553 L .35217 .53994 L 1 .784 0 r
F
.42873 .87395 m .39167 .86874 L .39296 .87232 L .834 .058 0 r
F
.42942 .87739 m .42873 .87395 L .39296 .87232 L .818 .055 0 r
F
.465 .87791 m .42873 .87395 L .42942 .87739 L .769 .05 0 r
F
.52876 .50743 m .50903 .50672 L .50915 .50941 L .887 .505 0 r
F
.52876 .50743 m .52859 .50474 L .50903 .50672 L F
.63634 .13159 m .62857 .13526 L .63439 .1396 L .248 .27 0 r
F
.63634 .13159 m .63047 .12748 L .62857 .13526 L F
.4282 .35965 m .4203 .36253 L .41887 .36503 L 1 .999 0 r
F
.4282 .35965 m .42925 .35656 L .4203 .36253 L F
.44879 .51258 m .42917 .50829 L .42903 .51094 L 1 .705 0 r
F
.44872 .51522 m .44879 .51258 L .42903 .51094 L 1 .697 0 r
F
.45192 .45614 m .43509 .4521 L .43472 .45475 L 1 .853 0 r
F
.45192 .45614 m .45213 .45346 L .43509 .4521 L F
.52824 .50459 m .5088 .50396 L .50891 .50664 L .875 .496 0 r
F
.52824 .50459 m .52806 .50192 L .5088 .50396 L F
.73678 .17247 m .72579 .18304 L .73143 .1876 L .325 .362 0 r
F
.73678 .17247 m .73095 .16823 L .72579 .18304 L F
.44925 .50437 m .43019 .50004 L .43003 .50267 L 1 .737 0 r
F
.44916 .50702 m .44925 .50437 L .43003 .50267 L 1 .731 0 r
F
.45223 .45063 m .43563 .44659 L .43523 .44924 L 1 .863 0 r
F
.45223 .45063 m .45245 .44795 L .43563 .44659 L F
.52194 .45045 m .50444 .44978 L .50475 .45248 L .909 .668 0 r
F
.52241 .45315 m .52194 .45045 L .50475 .45248 L .908 .66 0 r
F
.21495 .78111 m .17866 .76637 L .18138 .77181 L 1 .307 0 r
F
.2174 .78633 m .21495 .78111 L .18138 .77181 L 1 .282 0 r
F
.50955 .52271 m .48923 .52107 L .48925 .52371 L .945 .526 0 r
F
.50955 .52271 m .50949 .52007 L .48923 .52107 L F
.64535 .83921 m .61433 .8407 L .61215 .84458 L .416 .009 0 r
F
.64535 .83921 m .64805 .83524 L .61433 .8407 L F
.52179 .45054 m .50442 .44979 L .50473 .45249 L .898 .656 0 r
F
.52225 .45324 m .52179 .45054 L .50473 .45249 L .897 .648 0 r
F
.09963 .47902 m .07728 .454 L .07605 .46066 L 1 .959 0 r
F
.09862 .48562 m .09963 .47902 L .07605 .46066 L 1 .945 0 r
F
.31042 .84204 m .27281 .83217 L .27548 .83657 L 1 .103 0 r
F
.31265 .84624 m .31042 .84204 L .27548 .83657 L 1 .082 0 r
F
.46887 .5211 m .44885 .51753 L .44879 .52014 L 1 .655 0 r
F
.46885 .52373 m .46887 .5211 L .44879 .52014 L 1 .649 0 r
F
.32021 .79537 m .28236 .79037 L .28453 .79478 L 1 .237 0 r
F
.32193 .79969 m .32021 .79537 L .28453 .79478 L 1 .216 0 r
F
.4679 .60921 m .44367 .60575 L .44381 .60838 L .989 .318 0 r
F
.46791 .61175 m .4679 .60921 L .44381 .60838 L .983 .303 0 r
F
.49187 .61134 m .4679 .60921 L .46791 .61175 L .908 .222 0 r
F
.49187 .61134 m .49203 .60885 L .4679 .60921 L F
.58616 .73495 m .55988 .73889 L .55916 .74326 L .529 .048 0 r
F
.58616 .73495 m .58722 .73089 L .55988 .73889 L F
.83773 .67488 m .81045 .68218 L .80875 .68837 L .214 .003 0 r
F
.83773 .67488 m .83961 .66854 L .81045 .68218 L F
.2762 .77677 m .23839 .76866 L .24077 .77341 L 1 .298 0 r
F
.27819 .78136 m .2762 .77677 L .24077 .77341 L 1 .279 0 r
F
.74349 .17573 m .73218 .18676 L .73774 .19143 L .32 .34 0 r
F
.74349 .17573 m .73777 .17131 L .73218 .18676 L F
.48662 .44291 m .46976 .44062 L .46972 .44328 L 1 .793 0 r
F
.48662 .44291 m .48646 .44024 L .46976 .44062 L F
.50937 .52251 m .48921 .52101 L .48922 .52363 L .931 .505 0 r
F
.50937 .52251 m .50932 .51989 L .48921 .52101 L F
.12726 .6114 m .09687 .59054 L .09767 .59697 L 1 .706 0 r
F
.12811 .61763 m .12726 .6114 L .09767 .59697 L 1 .688 0 r
F
.17654 .69414 m .14178 .67805 L .14366 .68388 L 1 .516 0 r
F
.1783 .69972 m .17654 .69414 L .14366 .68388 L 1 .497 0 r
F
.70661 .26815 m .70379 .26759 L .70495 .27465 L 0 0 0 r
F
.70661 .26815 m .7055 .26124 L .70379 .26759 L F
.44367 .60575 m .41967 .60101 L .41992 .60373 L 1 .406 0 r
F
.44381 .60838 m .44367 .60575 L .41992 .60373 L 1 .391 0 r
F
.16646 .71581 m .1332 .69764 L .13521 .70369 L 1 .486 0 r
F
.16836 .72164 m .16646 .71581 L .13521 .70369 L 1 .463 0 r
F
.52892 .51012 m .50915 .50941 L .50925 .51208 L .885 .496 0 r
F
.52892 .51012 m .52876 .50743 L .50915 .50941 L F
.78625 .74752 m .75762 .75259 L .75522 .7581 L .271 0 0 r
F
.78625 .74752 m .78895 .74186 L .75762 .75259 L F
.53466 .86933 m .50069 .86775 L .50012 .87106 L .624 .032 0 r
F
.53466 .86933 m .53586 .86601 L .50069 .86775 L F
.1104 .63861 m .07994 .61659 L .081 .62332 L 1 .664 0 r
F
.11147 .64516 m .1104 .63861 L .081 .62332 L 1 .644 0 r
F
.46972 .44328 m .45324 .44018 L .453 .44282 L 1 .838 0 r
F
.46972 .44328 m .46976 .44062 L .45324 .44018 L F
.65531 .46421 m .64111 .46849 L .64037 .47233 L .198 .004 0 r
F
.65531 .46421 m .65618 .46035 L .64111 .46849 L F
.46884 .52383 m .44858 .52049 L .44853 .52311 L 1 .62 0 r
F
.46882 .52644 m .46884 .52383 L .44853 .52311 L 1 .611 0 r
F
.73595 .79482 m .70631 .79824 L .70369 .80314 L .328 .002 0 r
F
.73595 .79482 m .73896 .78978 L .70631 .79824 L F
.45213 .45346 m .43547 .44945 L .43509 .4521 L 1 .859 0 r
F
.45213 .45346 m .45234 .45079 L .43547 .44945 L F
.5284 .50726 m .50891 .50664 L .50901 .5093 L .874 .487 0 r
F
.5284 .50726 m .52824 .50459 L .50891 .50664 L F
.44916 .50702 m .43003 .50267 L .42989 .50529 L 1 .731 0 r
F
.44907 .50966 m .44916 .50702 L .42989 .50529 L 1 .725 0 r
F
.46435 .08115 m .47004 .07766 L .46354 .08187 L 0 0 0 r
F
.46435 .08116 m .47035 .07745 L .47004 .07767 L F
.46435 .08115 m .47035 .07745 L .47004 .07766 L F
.66218 .14284 m .65355 .14888 L .65926 .15318 L .309 .366 0 r
F
.87239 .38948 m .85293 .40249 L .85504 .40913 L .166 .048 0 r
F
.87239 .38948 m .87017 .38284 L .85293 .40249 L F
.52146 .44775 m .50411 .44708 L .50444 .44978 L .91 .675 0 r
F
.52194 .45045 m .52146 .44775 L .50444 .44978 L .909 .668 0 r
F
.5391 .60205 m .5164 .60226 L .51608 .60479 L .739 .072 0 r
F
.5391 .60205 m .5396 .59954 L .5164 .60226 L F
.64907 .67966 m .62372 .68227 L .62283 .68647 L .468 .044 0 r
F
.64907 .67966 m .65032 .67563 L .62372 .68227 L F
.46976 .44048 m .45339 .43734 L .45314 .43998 L 1 .84 0 r
F
.46976 .44048 m .4698 .43782 L .45339 .43734 L F
.64201 .13599 m .63439 .1396 L .64006 .14413 L .215 .205 0 r
F
.64201 .13599 m .63634 .13159 L .63439 .1396 L F
.44872 .51522 m .42903 .51094 L .4289 .51359 L 1 .697 0 r
F
.44865 .51786 m .44872 .51522 L .4289 .51359 L 1 .689 0 r
F
.45245 .44795 m .43605 .44394 L .43563 .44659 L 1 .87 0 r
F
.45245 .44795 m .45268 .44529 L .43605 .44394 L F
.52131 .44785 m .5041 .4471 L .50442 .44979 L .898 .663 0 r
F
.52179 .45054 m .52131 .44785 L .50442 .44979 L .898 .656 0 r
F
.68945 .82644 m .65893 .82859 L .6564 .83298 L .379 .007 0 r
F
.68945 .82644 m .69245 .82194 L .65893 .82859 L F
.5096 .52535 m .48925 .52371 L .48927 .52633 L .943 .518 0 r
F
.5096 .52535 m .50955 .52271 L .48925 .52371 L F
.35251 .85839 m .31493 .85034 L .31726 .85436 L .953 .074 0 r
F
.35433 .86223 m .35251 .85839 L .31726 .85436 L .937 .071 0 r
F
.74255 .17679 m .73143 .1876 L .737 .19224 L .318 .346 0 r
F
.74255 .17679 m .73678 .17247 L .73143 .1876 L F
.43314 .80843 m .43271 .80426 L .39838 .81042 L .84 .092 0 r
F
.4659 .80066 m .43271 .80426 L .43314 .80843 L .771 .071 0 r
F
.4659 .80066 m .46588 .79643 L .43271 .80426 L F
.60767 .86227 m .57532 .86238 L .57357 .86606 L .496 .019 0 r
F
.60767 .86227 m .61 .85851 L .57532 .86238 L F
.39554 .43653 m .39629 .43355 L .38131 .43 L 1 1 0 r
F
.71715 .59152 m .69304 .5962 L .69232 .6006 L .356 .039 0 r
F
.71715 .59152 m .71806 .58706 L .69304 .5962 L F
.58672 .57216 m .56612 .57445 L .5656 .57721 L .551 .056 0 r
F
.58672 .57216 m .58737 .5694 L .56612 .57445 L F
.46885 .52373 m .44879 .52014 L .44873 .52274 L 1 .649 0 r
F
.46883 .52634 m .46885 .52373 L .44873 .52274 L 1 .643 0 r
F
.6105 .546 m .59143 .54923 L .59091 .5522 L .437 .048 0 r
F
.6105 .546 m .61114 .54302 L .59143 .54923 L F
.52907 .51279 m .50925 .51208 L .50934 .51475 L .883 .488 0 r
F
.52907 .51279 m .52892 .51012 L .50925 .51208 L F
.74657 .52012 m .72565 .52714 L .72532 .53188 L .265 .032 0 r
F
.74657 .52012 m .7469 .5153 L .72565 .52714 L F
.48646 .44024 m .4698 .43797 L .46976 .44062 L 1 .799 0 r
F
.48646 .44024 m .4863 .43757 L .4698 .43797 L F
.44907 .50966 m .42989 .50529 L .42976 .5079 L 1 .725 0 r
F
.44899 .51229 m .44907 .50966 L .42976 .5079 L 1 .719 0 r
F
.45234 .45079 m .43587 .44681 L .43547 .44945 L 1 .865 0 r
F
.45234 .45079 m .45255 .44813 L .43587 .44681 L F
.52854 .50992 m .50901 .5093 L .5091 .51196 L .872 .478 0 r
F
.52854 .50992 m .5284 .50726 L .50901 .5093 L F
.26518 .8185 m .22799 .80648 L .23084 .81134 L 1 .186 0 r
F
.26766 .82314 m .26518 .8185 L .23084 .81134 L 1 .161 0 r
F
.5094 .52511 m .48922 .52363 L .48923 .52624 L .929 .496 0 r
F
.5094 .52511 m .50937 .52251 L .48922 .52363 L F
.74913 .18024 m .73774 .19143 L .74323 .19618 L .311 .319 0 r
F
.74913 .18024 m .74349 .17573 L .73774 .19143 L F
.39014 .46346 m .39062 .46047 L .37396 .45624 L 1 .933 0 r
F
.39167 .86874 m .35433 .86223 L .35619 .86598 L .891 .066 0 r
F
.39296 .87232 m .39167 .86874 L .35619 .86598 L .874 .062 0 r
F
.56274 .59054 m .54099 .59182 L .54054 .59442 L .648 .064 0 r
F
.56274 .59054 m .56335 .58794 L .54099 .59182 L F
.16221 .72653 m .12793 .70852 L .13015 .71461 L 1 .456 0 r
F
.16428 .7324 m .16221 .72653 L .13015 .71461 L 1 .432 0 r
F
.52097 .44506 m .50378 .44439 L .50411 .44708 L .91 .682 0 r
F
.52146 .44775 m .52097 .44506 L .50411 .44708 L .91 .675 0 r
F
.37221 .54866 m .35217 .53994 L .3521 .54308 L 1 .784 0 r
F
.3722 .55178 m .37221 .54866 L .3521 .54308 L 1 .773 0 r
F
.39629 .43355 m .38231 .42713 L .38131 .43 L 1 1 0 r
F
.39629 .43355 m .39707 .43057 L .38231 .42713 L F
.66796 .14684 m .65926 .15318 L .66486 .15759 L .301 .343 0 r
F
.66796 .14684 m .66218 .14284 L .65926 .15318 L F
.52082 .44516 m .50377 .44441 L .5041 .4471 L .899 .67 0 r
F
.52131 .44785 m .52082 .44516 L .5041 .4471 L .898 .663 0 r
F
.11785 .62851 m .08881 .60659 L .08966 .61321 L 1 .692 0 r
F
.11873 .63497 m .11785 .62851 L .08966 .61321 L 1 .672 0 r
F
.46976 .44062 m .45347 .43755 L .45324 .44018 L 1 .845 0 r
F
.46976 .44062 m .4698 .43797 L .45347 .43755 L F
.87784 .39545 m .85792 .40859 L .86007 .41528 L .172 .05 0 r
F
.87784 .39545 m .87554 .38876 L .85792 .40859 L F
.51541 .60974 m .49203 .60885 L .49187 .61134 L .822 .132 0 r
F
.51541 .60974 m .51575 .60728 L .49203 .60885 L F
.44865 .51786 m .4289 .51359 L .42878 .51623 L 1 .689 0 r
F
.44858 .52049 m .44865 .51786 L .42878 .51623 L 1 .681 0 r
F
.46882 .52644 m .44853 .52311 L .44848 .52572 L 1 .611 0 r
F
.46881 .52904 m .46882 .52644 L .44848 .52572 L 1 .602 0 r
F
.45268 .44529 m .43647 .44131 L .43605 .44394 L 1 .876 0 r
F
.45268 .44529 m .45291 .44263 L .43647 .44131 L F
.64743 .14072 m .64201 .13599 L .64006 .14413 L .169 .122 0 r
F
.39014 .46346 m .37396 .45624 L .37333 .45917 L 1 .933 0 r
F
.38969 .46643 m .39014 .46346 L .37333 .45917 L 1 .922 0 r
F
.4698 .43782 m .45363 .4347 L .45339 .43734 L 1 .847 0 r
F
.4698 .43782 m .46983 .43517 L .45363 .4347 L F
.87265 .55793 m .84926 .56832 L .84891 .57496 L .138 .008 0 r
F
.87265 .55793 m .87306 .5512 L .84926 .56832 L F
.75894 .42172 m .74607 .42942 L .74643 .43473 L .036 .007 0 r
F
.75894 .42172 m .75838 .41649 L .74607 .42942 L F
.63321 .51082 m .61626 .51481 L .61573 .51808 L .333 .034 0 r
F
.63321 .51082 m .63384 .50755 L .61626 .51481 L F
.39707 .43057 m .38334 .42427 L .38231 .42713 L 1 1 0 r
F
.39707 .43057 m .39788 .42761 L .38334 .42427 L F
.43152 .47876 m .41391 .47366 L .4135 .47634 L 1 .843 0 r
F
.43152 .47876 m .4318 .47606 L .41391 .47366 L F
.43125 .48146 m .43152 .47876 L .4135 .47634 L 1 .837 0 r
F
.43125 .48146 m .4135 .47634 L .41311 .47902 L F
.43099 .48415 m .43125 .48146 L .41311 .47902 L 1 .83 0 r
F
.50965 .52797 m .48927 .52633 L .48928 .52895 L .942 .509 0 r
F
.50965 .52797 m .5096 .52535 L .48927 .52633 L F
.4318 .47606 m .41433 .47098 L .41391 .47366 L 1 .85 0 r
F
.4318 .47606 m .43209 .47337 L .41433 .47098 L F
.5292 .51546 m .50934 .51475 L .50942 .51742 L .882 .479 0 r
F
.5292 .51546 m .52907 .51279 L .50934 .51475 L F
.74825 .18119 m .737 .19224 L .74249 .19696 L .312 .329 0 r
F
.74825 .18119 m .74255 .17679 L .737 .19224 L F
.43099 .48415 m .41311 .47902 L .41274 .48171 L 1 .83 0 r
F
.43074 .48685 m .43099 .48415 L .41274 .48171 L 1 .823 0 r
F
.44899 .51229 m .42976 .5079 L .42964 .5105 L 1 .719 0 r
F
.44892 .51491 m .44899 .51229 L .42964 .5105 L 1 .714 0 r
F
.45255 .44813 m .43627 .44418 L .43587 .44681 L 1 .871 0 r
F
.45255 .44813 m .45278 .44547 L .43627 .44418 L F
.43209 .47337 m .41477 .4683 L .41433 .47098 L 1 .857 0 r
F
.43209 .47337 m .4324 .47067 L .41477 .4683 L F
.52867 .51257 m .5091 .51196 L .50919 .51461 L .87 .469 0 r
F
.52867 .51257 m .52854 .50992 L .5091 .51196 L F
.74065 .30044 m .73867 .30205 L .74024 .30828 L 0 0 0 r
F
.7418 .30661 m .74065 .30044 L .74065 .30045 L F
.7418 .30661 m .74065 .30045 L .74024 .30828 L F
.74293 .31266 m .7418 .30661 L .7418 .30661 L F
.74293 .31266 m .7418 .30661 L .7417 .31448 L F
.74407 .3186 m .74293 .31266 L .74293 .31267 L F
.74407 .3186 m .74293 .31267 L .74307 .32062 L F
.74522 .32444 m .74407 .3186 L .74407 .31861 L F
.74522 .32444 m .74407 .31861 L .74435 .3267 L F
.74637 .33017 m .74522 .32444 L .74522 .32445 L F
.74637 .33017 m .74522 .32445 L .74557 .33273 L F
.74753 .33582 m .74637 .33017 L .74637 .33019 L F
.74753 .33582 m .74637 .33019 L .74672 .3387 L F
.74871 .34138 m .74753 .33582 L .74753 .33583 L F
.74871 .34138 m .74753 .33583 L .74781 .34461 L F
.74988 .34687 m .74871 .34138 L .74871 .34139 L F
.74988 .34687 m .74871 .34139 L .74885 .35046 L F
.75107 .35229 m .74988 .34687 L .74988 .34688 L F
.75107 .35229 m .74988 .34688 L .74985 .35624 L F
.75225 .35764 m .75107 .35229 L .75107 .35229 L F
.75225 .35764 m .75107 .35229 L .7508 .36197 L F
.75342 .36294 m .75225 .35764 L .75225 .35764 L F
.75342 .36294 m .75225 .35764 L .75171 .36764 L F
.75459 .3682 m .75342 .36294 L .75259 .37325 L F
.75459 .3682 m .75342 .36294 L .75459 .3682 L .913 .119 0 r
F
.75225 .35764 m .7508 .36197 L .75171 .36764 L 0 0 0 r
F
.75342 .36294 m .75171 .36764 L .75259 .37325 L F
.74515 .36036 m .75342 .36294 L .75459 .3682 L .913 .119 0 r
F
.75342 .36294 m .75225 .35764 L .75342 .36294 L .969 .123 0 r
F
.75107 .35229 m .74985 .35624 L .7508 .36197 L 0 0 0 r
F
.74322 .35575 m .75225 .35764 L .75342 .36294 L .969 .123 0 r
F
.75223 .35763 m .75107 .35229 L .75225 .35764 L 1 .126 0 r
F
.74988 .34687 m .74885 .35046 L .74985 .35624 L 0 0 0 r
F
.74128 .35114 m .75107 .35229 L .75223 .35763 L 1 .126 0 r
F
.75105 .35228 m .74988 .34687 L .75107 .35229 L 1 .172 0 r
F
.74871 .34138 m .74781 .34461 L .74885 .35046 L 0 0 0 r
F
.73932 .34652 m .74988 .34687 L .75105 .35228 L 1 .172 0 r
F
.74986 .34686 m .74871 .34138 L .74988 .34687 L 1 .229 0 r
F
.74753 .33582 m .74672 .3387 L .74781 .34461 L 0 0 0 r
F
.73737 .34186 m .74871 .34138 L .74986 .34686 L 1 .229 0 r
F
.74868 .34137 m .74753 .33582 L .74871 .34138 L 1 .287 0 r
F
.74637 .33017 m .74557 .33273 L .74672 .3387 L 0 0 0 r
F
.73544 .33717 m .74753 .33582 L .74868 .34137 L 1 .287 0 r
F
.74751 .33581 m .74637 .33017 L .74753 .33582 L 1 .344 0 r
F
.74522 .32444 m .74435 .3267 L .74557 .33273 L 0 0 0 r
F
.73354 .33243 m .74637 .33017 L .74751 .33581 L 1 .344 0 r
F
.74634 .33017 m .74522 .32444 L .74637 .33017 L 1 .399 0 r
F
.74407 .3186 m .74307 .32062 L .74435 .3267 L 0 0 0 r
F
.7317 .32761 m .74522 .32444 L .74634 .33017 L 1 .399 0 r
F
.74519 .32443 m .74407 .3186 L .74522 .32444 L 1 .452 0 r
F
.74293 .31266 m .7417 .31448 L .74307 .32062 L 0 0 0 r
F
.72994 .3227 m .74407 .3186 L .74519 .32443 L 1 .452 0 r
F
.74405 .3186 m .74293 .31266 L .74407 .3186 L 1 .503 0 r
F
.7418 .30661 m .74024 .30828 L .7417 .31448 L 0 0 0 r
F
.72829 .31766 m .74293 .31266 L .74405 .3186 L 1 .503 0 r
F
.74292 .31266 m .7418 .30661 L .74293 .31266 L 1 .552 0 r
F
.72676 .31247 m .7418 .30661 L .74292 .31266 L F
.7418 .30661 m .74065 .30044 L .7418 .30661 L 1 .596 0 r
F
.74065 .30044 m .73949 .29416 L .73867 .30205 L 0 0 0 r
F
.7254 .30709 m .74065 .30044 L .7418 .30661 L 1 .596 0 r
F
.74065 .30044 m .73949 .29416 L .73949 .29416 L 0 0 0 r
F
.61638 .711 m .59091 .71413 L .59007 .71839 L .493 .044 0 r
F
.61638 .711 m .61759 .70701 L .59091 .71413 L F
.42925 .35656 m .42174 .36007 L .4203 .36253 L 1 .924 0 r
F
.42925 .35656 m .43032 .35345 L .42174 .36007 L F
.46883 .52634 m .44873 .52274 L .44867 .52534 L 1 .643 0 r
F
.46881 .52896 m .46883 .52634 L .44867 .52534 L 1 .636 0 r
F
.39513 .58065 m .37296 .57318 L .37318 .57617 L 1 .624 0 r
F
.39534 .58357 m .39513 .58065 L .37318 .57617 L 1 .612 0 r
F
.43074 .48685 m .41274 .48171 L .41238 .48439 L 1 .823 0 r
F
.4305 .48954 m .43074 .48685 L .41238 .48439 L 1 .816 0 r
F
.68258 .64345 m .6576 .64657 L .65671 .6508 L .412 .041 0 r
F
.68258 .64345 m .68378 .63927 L .6576 .64657 L F
.52046 .44237 m .50344 .44171 L .50378 .44439 L .911 .689 0 r
F
.52097 .44506 m .52046 .44237 L .50378 .44439 L .91 .682 0 r
F
.38969 .46643 m .37333 .45917 L .37272 .4621 L 1 .922 0 r
F
.38926 .46939 m .38969 .46643 L .37272 .4621 L 1 .912 0 r
F
.4324 .47067 m .41522 .46563 L .41477 .4683 L 1 .863 0 r
F
.4324 .47067 m .43271 .46798 L .41522 .46563 L F
.4863 .43757 m .46984 .43532 L .4698 .43797 L 1 .806 0 r
F
.4863 .43757 m .48614 .43492 L .46984 .43532 L F
.52032 .44248 m .50343 .44173 L .50377 .44441 L .9 .678 0 r
F
.52082 .44516 m .52032 .44248 L .50377 .44441 L .899 .67 0 r
F
.07845 .50661 m .05525 .48074 L .05431 .48775 L 1 .912 0 r
F
.0777 .51354 m .07845 .50661 L .05431 .48775 L 1 .897 0 r
F
.4305 .48954 m .41238 .48439 L .41204 .48707 L 1 .816 0 r
F
.43028 .49223 m .4305 .48954 L .41204 .48707 L 1 .809 0 r
F
.67361 .151 m .66486 .15759 L .67034 .16213 L .291 .315 0 r
F
.67361 .151 m .66796 .14684 L .66486 .15759 L F
.39788 .42761 m .38441 .42144 L .38334 .42427 L 1 1 0 r
F
.39788 .42761 m .39872 .42465 L .38441 .42144 L F
.50943 .52771 m .48923 .52624 L .48924 .52883 L .928 .486 0 r
F
.50943 .52771 m .5094 .52511 L .48923 .52624 L F
.43271 .46798 m .4157 .46296 L .41522 .46563 L 1 .869 0 r
F
.43271 .46798 m .43304 .46529 L .4157 .46296 L F
.87903 .5661 m .85423 .57629 L .8539 .58303 L .165 .014 0 r
F
.87903 .5661 m .87938 .55923 L .85423 .57629 L F
.75469 .18483 m .74323 .19618 L .74865 .20101 L .301 .298 0 r
F
.75469 .18483 m .74913 .18024 L .74323 .19618 L F
.41944 .59827 m .39611 .59221 L .39641 .59504 L 1 .5 0 r
F
.41967 .60101 m .41944 .59827 L .39641 .59504 L 1 .486 0 r
F
.44858 .52049 m .42878 .51623 L .42868 .51885 L 1 .681 0 r
F
.44853 .52311 m .44858 .52049 L .42868 .51885 L 1 .673 0 r
F
.45291 .44263 m .4369 .43868 L .43647 .44131 L 1 .882 0 r
F
.45291 .44263 m .45314 .43998 L .4369 .43868 L F
.4698 .43797 m .45372 .43492 L .45347 .43755 L 1 .851 0 r
F
.4698 .43797 m .46984 .43532 L .45372 .43492 L F
.0916 .49241 m .07049 .4672 L .06924 .47396 L 1 .948 0 r
F
.09056 .49914 m .0916 .49241 L .06924 .47396 L 1 .933 0 r
F
.43028 .49223 m .41204 .48707 L .41172 .48976 L 1 .809 0 r
F
.43006 .49492 m .43028 .49223 L .41172 .48976 L 1 .802 0 r
F
.36092 .80627 m .32371 .80394 L .32553 .80813 L .978 .183 0 r
F
.36226 .81042 m .36092 .80627 L .32553 .80813 L .968 .161 0 r
F
.38926 .46939 m .37272 .4621 L .37215 .46503 L 1 .912 0 r
F
.38887 .47235 m .38926 .46939 L .37215 .46503 L 1 .901 0 r
F
.46881 .52904 m .44848 .52572 L .44843 .52831 L 1 .602 0 r
F
.46879 .53162 m .46881 .52904 L .44843 .52831 L 1 .594 0 r
F
.43304 .46529 m .41618 .46029 L .4157 .46296 L 1 .876 0 r
F
.43304 .46529 m .43338 .4626 L .41618 .46029 L F
.52931 .51812 m .50942 .51742 L .50949 .52007 L .88 .47 0 r
F
.52931 .51812 m .5292 .51546 L .50942 .51742 L F
.44892 .51491 m .42964 .5105 L .42954 .51309 L 1 .714 0 r
F
.44885 .51753 m .44892 .51491 L .42954 .51309 L 1 .71 0 r
F
.45278 .44547 m .43668 .44155 L .43627 .44418 L 1 .877 0 r
F
.45278 .44547 m .453 .44282 L .43668 .44155 L F
.49698 .79167 m .46588 .79643 L .4659 .80066 L .69 .063 0 r
F
.49698 .79167 m .49732 .78747 L .46588 .79643 L F
.46983 .43517 m .45388 .43208 L .45363 .4347 L 1 .853 0 r
F
.46983 .43517 m .46987 .43252 L .45388 .43208 L F
.52878 .51521 m .50919 .51461 L .50926 .51726 L .869 .46 0 r
F
.52878 .51521 m .52867 .51257 L .50919 .51461 L F
.50968 .53059 m .48928 .52895 L .48929 .53156 L .94 .5 0 r
F
.50968 .53059 m .50965 .52797 L .48928 .52895 L F
.39872 .42465 m .38552 .41862 L .38441 .42144 L 1 1 0 r
F
.39872 .42465 m .39959 .4217 L .38552 .41862 L F
.43006 .49492 m .41172 .48976 L .41141 .49243 L 1 .802 0 r
F
.42986 .4976 m .43006 .49492 L .41141 .49243 L 1 .795 0 r
F
.51993 .43969 m .50309 .43903 L .50344 .44171 L .912 .696 0 r
F
.52046 .44237 m .51993 .43969 L .50344 .44171 L .911 .689 0 r
F
.75387 .18568 m .74249 .19696 L .74791 .20175 L .305 .313 0 r
F
.75387 .18568 m .74825 .18119 L .74249 .19696 L F
.43338 .4626 m .41669 .45763 L .41618 .46029 L 1 .882 0 r
F
.43338 .4626 m .43373 .45992 L .41669 .45763 L F
.5198 .4398 m .50308 .43905 L .50343 .44173 L .901 .685 0 r
F
.52032 .44248 m .5198 .4398 L .50343 .44173 L .9 .678 0 r
F
.46881 .52896 m .44867 .52534 L .44862 .52794 L 1 .636 0 r
F
.46879 .53156 m .46881 .52896 L .44862 .52794 L 1 .629 0 r
F
.3722 .55178 m .3521 .54308 L .35206 .54621 L 1 .773 0 r
F
.37223 .55489 m .3722 .55178 L .35206 .54621 L 1 .762 0 r
F
.09862 .48562 m .07605 .46066 L .07493 .46734 L 1 .945 0 r
F
.09771 .49222 m .09862 .48562 L .07493 .46734 L 1 .931 0 r
F
.46354 .08187 m .47004 .07766 L .4698 .07847 L .351 .014 0 r
F
.87449 .39615 m .85504 .40913 L .85704 .41579 L .157 .045 0 r
F
.87449 .39615 m .87239 .38948 L .85504 .40913 L F
.42939 .86785 m .3929 .86272 L .39418 .86622 L .829 .057 0 r
F
.43008 .8712 m .42939 .86785 L .39418 .86622 L .812 .054 0 r
F
.4651 .87168 m .42939 .86785 L .43008 .8712 L .76 .048 0 r
F
.38887 .47235 m .37215 .46503 L .37161 .46795 L 1 .901 0 r
F
.38851 .47529 m .38887 .47235 L .37161 .46795 L 1 .89 0 r
F
.48614 .43492 m .46988 .43269 L .46984 .43532 L 1 .812 0 r
F
.48614 .43492 m .48597 .43227 L .46988 .43269 L F
.67911 .15532 m .67034 .16213 L .67568 .1668 L .277 .281 0 r
F
.67911 .15532 m .67361 .151 L .67034 .16213 L F
.42986 .4976 m .41141 .49243 L .41112 .49511 L 1 .795 0 r
F
.42967 .50028 m .42986 .4976 L .41112 .49511 L 1 .787 0 r
F
.44853 .52311 m .42868 .51885 L .42858 .52147 L 1 .673 0 r
F
.44848 .52572 m .44853 .52311 L .42858 .52147 L 1 .664 0 r
F
.67668 .41717 m .66605 .42116 L .66474 .42601 L 0 0 0 r
F
.67668 .41717 m .67812 .41228 L .66605 .42116 L F
.50945 .53029 m .48924 .52883 L .48924 .53142 L .926 .477 0 r
F
.50945 .53029 m .50943 .52771 L .48924 .52883 L F
.54346 .47199 m .5253 .47217 L .52566 .47489 L .836 .542 0 r
F
.54392 .47471 m .52566 .47489 L .526 .47762 L .835 .533 0 r
F
.54392 .47471 m .54346 .47199 L .52566 .47489 L F
.45314 .43998 m .43734 .43607 L .4369 .43868 L 1 .888 0 r
F
.45314 .43998 m .45339 .43734 L .43734 .43607 L F
.43373 .45992 m .41721 .45497 L .41669 .45763 L F
.43373 .45992 m .43409 .45724 L .41721 .45497 L F
.54436 .47744 m .526 .47762 L .52633 .48034 L .833 .525 0 r
F
.54436 .47744 m .54392 .47471 L .526 .47762 L F
.54299 .46927 m .52493 .46945 L .5253 .47217 L .838 .55 0 r
F
.54346 .47199 m .54299 .46927 L .5253 .47217 L .836 .542 0 r
F
.65448 .46799 m .64037 .47233 L .63965 .4761 L .197 .004 0 r
F
.65448 .46799 m .65531 .46421 L .64037 .47233 L F
.44381 .60838 m .41992 .60373 L .42018 .60642 L 1 .391 0 r
F
.44396 .61098 m .44381 .60838 L .42018 .60642 L 1 .376 0 r
F
.46791 .61175 m .44381 .60838 L .44396 .61098 L .983 .303 0 r
F
.44885 .51753 m .42954 .51309 L .42946 .51566 L 1 .71 0 r
F
.44879 .52014 m .44885 .51753 L .42946 .51566 L 1 .706 0 r
F
.54477 .48016 m .52633 .48034 L .52664 .48306 L .832 .517 0 r
F
.54477 .48016 m .54436 .47744 L .52633 .48034 L F
.46791 .61425 m .46791 .61175 L .44396 .61098 L .977 .288 0 r
F
.49171 .6138 m .46791 .61175 L .46791 .61425 L .901 .206 0 r
F
.49171 .6138 m .49187 .61134 L .46791 .61175 L F
.69909 .3578 m .69242 .36055 L .69091 .367 L 0 0 0 r
F
.69909 .3578 m .70058 .35138 L .69242 .36055 L F
.76016 .1895 m .74865 .20101 L .75398 .20591 L .292 .278 0 r
F
.76016 .1895 m .75469 .18483 L .74865 .20101 L F
.52941 .52077 m .50949 .52007 L .50955 .52271 L .878 .461 0 r
F
.52941 .52077 m .52931 .51812 L .50949 .52007 L F
.46984 .43532 m .45397 .43231 L .45372 .43492 L 1 .857 0 r
F
.46984 .43532 m .46988 .43269 L .45397 .43231 L F
.39959 .4217 m .38666 .41582 L .38552 .41862 L 1 1 0 r
F
.39959 .4217 m .40049 .41877 L .38666 .41582 L F
.54249 .46655 m .52455 .46672 L .52493 .46945 L .839 .558 0 r
F
.54299 .46927 m .54249 .46655 L .52493 .46945 L .838 .55 0 r
F
.70749 .27506 m .70495 .27465 L .70582 .28175 L 0 0 0 r
F
.70749 .27506 m .70661 .26815 L .70495 .27465 L F
.453 .44282 m .43711 .43893 L .43668 .44155 L 1 .883 0 r
F
.453 .44282 m .45324 .44018 L .43711 .43893 L F
.52888 .51784 m .50926 .51726 L .50932 .51989 L .867 .45 0 r
F
.52888 .51784 m .52878 .51521 L .50926 .51726 L F
.54517 .48288 m .52664 .48306 L .52693 .48578 L .83 .508 0 r
F
.54517 .48288 m .54477 .48016 L .52664 .48306 L F
.35909 .48267 m .34361 .47378 L .34278 .47689 L 1 1 0 r
F
.54198 .46384 m .52415 .464 L .52455 .46672 L .841 .566 0 r
F
.54249 .46655 m .54198 .46384 L .52455 .46672 L .839 .558 0 r
F
.42967 .50028 m .41112 .49511 L .41085 .49778 L 1 .787 0 r
F
.42949 .50296 m .42967 .50028 L .41085 .49778 L 1 .78 0 r
F
.31301 .83624 m .27612 .82632 L .27874 .83065 L 1 .102 0 r
F
.3152 .84037 m .31301 .83624 L .27874 .83065 L 1 .082 0 r
F
.60985 .54895 m .59091 .5522 L .59036 .55514 L .431 .046 0 r
F
.60985 .54895 m .6105 .546 L .59091 .5522 L F
.46879 .53162 m .44843 .52831 L .4484 .53089 L 1 .594 0 r
F
.5194 .43702 m .50274 .43636 L .50309 .43903 L .913 .703 0 r
F
.51993 .43969 m .5194 .43702 L .50309 .43903 L .912 .696 0 r
F
.83097 .67129 m .80508 .67898 L .80332 .68502 L .185 0 0 r
F
.83097 .67129 m .8329 .66512 L .80508 .67898 L F
.54555 .4856 m .52693 .48578 L .52722 .4885 L .829 .5 0 r
F
.54555 .4856 m .54517 .48288 L .52693 .48578 L F
.52671 .77788 m .49764 .78316 L .49732 .78747 L .614 .055 0 r
F
.52671 .77788 m .52736 .77372 L .49764 .78316 L F
.43216 .4761 m .41488 .47107 L .41448 .47373 L 1 .847 0 r
F
.43216 .4761 m .43244 .47343 L .41488 .47107 L F
.43189 .47878 m .43216 .4761 L .41448 .47373 L 1 .84 0 r
F
.38851 .47529 m .37161 .46795 L .37111 .47087 L 1 .89 0 r
F
.38817 .47823 m .38851 .47529 L .37111 .47087 L 1 .88 0 r
F
.51927 .43713 m .50272 .43638 L .50308 .43905 L .901 .692 0 r
F
.5198 .4398 m .51927 .43713 L .50308 .43905 L .901 .685 0 r
F
.43189 .47878 m .41448 .47373 L .4141 .47639 L 1 .84 0 r
F
.43163 .48145 m .43189 .47878 L .4141 .47639 L 1 .833 0 r
F
.43409 .45724 m .41774 .45233 L .41721 .45497 L 1 .894 0 r
F
.43409 .45724 m .43446 .45457 L .41774 .45233 L F
.43244 .47343 m .4153 .46842 L .41488 .47107 L 1 .853 0 r
F
.43244 .47343 m .43273 .47075 L .4153 .46842 L F
.5386 .60452 m .51608 .60479 L .51575 .60728 L .731 .071 0 r
F
.5386 .60452 m .5391 .60205 L .51608 .60479 L F
.46987 .43252 m .45414 .42947 L .45388 .43208 L 1 .859 0 r
F
.46987 .43252 m .46992 .42989 L .45414 .42947 L F
.5097 .53319 m .48929 .53156 L .48929 .53416 L .938 .491 0 r
F
.5097 .53319 m .50968 .53059 L .48929 .53156 L F
.65733 .15142 m .65086 .15379 L .65595 .15895 L .021 .067 0 r
F
.65733 .15142 m .65256 .14585 L .65086 .15379 L F
.54145 .46112 m .52374 .46129 L .52415 .464 L .842 .574 0 r
F
.54198 .46384 m .54145 .46112 L .52415 .464 L .841 .566 0 r
F
.74619 .52492 m .72532 .53188 L .72495 .5366 L .262 .031 0 r
F
.74619 .52492 m .74657 .52012 L .72532 .53188 L F
.43163 .48145 m .4141 .47639 L .41373 .47904 L 1 .833 0 r
F
.43139 .48412 m .43163 .48145 L .41373 .47904 L 1 .826 0 r
F
.88002 .40217 m .86007 .41528 L .86211 .422 L .164 .047 0 r
F
.88002 .40217 m .87784 .39545 L .86007 .41528 L F
.58604 .57489 m .5656 .57721 L .56506 .57994 L .544 .055 0 r
F
.58604 .57489 m .58672 .57216 L .5656 .57721 L F
.43273 .47075 m .41573 .46576 L .4153 .46842 L 1 .86 0 r
F
.43273 .47075 m .43303 .46808 L .41573 .46576 L F
.21956 .77571 m .18423 .76094 L .18686 .76631 L 1 .312 0 r
F
.22195 .78086 m .21956 .77571 L .18686 .76631 L 1 .287 0 r
F
.46879 .53156 m .44862 .52794 L .44857 .53053 L 1 .629 0 r
F
.46877 .53415 m .46879 .53156 L .44857 .53053 L 1 .622 0 r
F
.5459 .48831 m .52722 .4885 L .52748 .49122 L .827 .491 0 r
F
.5459 .48831 m .54555 .4856 L .52722 .4885 L F
.75942 .19025 m .74791 .20175 L .75325 .20662 L .299 .296 0 r
F
.75942 .19025 m .75387 .18568 L .74791 .20175 L F
.78041 .74257 m .75291 .74811 L .75048 .75347 L .248 0 0 r
F
.78041 .74257 m .78313 .73707 L .75291 .74811 L F
.43139 .48412 m .41373 .47904 L .41339 .4817 L 1 .826 0 r
F
.43116 .48678 m .43139 .48412 L .41339 .4817 L 1 .819 0 r
F
.35843 .48585 m .34278 .47689 L .34198 .48001 L 1 1 0 r
F
.3578 .48904 m .35843 .48585 L .34198 .48001 L 1 .999 0 r
F
.43303 .46808 m .41618 .46311 L .41573 .46576 L 1 .867 0 r
F
.43303 .46808 m .43335 .46541 L .41618 .46311 L F
.43032 .35345 m .42319 .35763 L .42174 .36007 L 1 .831 0 r
F
.43032 .35345 m .4314 .35033 L .42319 .35763 L F
.54089 .45841 m .52331 .45857 L .52374 .46129 L .843 .582 0 r
F
.54145 .46112 m .54089 .45841 L .52374 .46129 L .842 .574 0 r
F
.7311 .78906 m .7024 .79296 L .69977 .7977 L .308 0 0 r
F
.7311 .78906 m .73412 .78419 L .7024 .79296 L F
.42949 .50296 m .41085 .49778 L .41059 .50045 L 1 .78 0 r
F
.42933 .50563 m .42949 .50296 L .41059 .50045 L 1 .772 0 r
F
.75947 .42692 m .74643 .43473 L .74675 .44 L .041 .007 0 r
F
.75947 .42692 m .75894 .42172 L .74643 .43473 L F
.71619 .59595 m .69232 .6006 L .69155 .60499 L .351 .037 0 r
F
.71619 .59595 m .71715 .59152 L .69232 .6006 L F
.40049 .41877 m .38784 .41305 L .38666 .41582 L 1 1 0 r
F
.40049 .41877 m .40141 .41586 L .38784 .41305 L F
.54299 .47205 m .52509 .4722 L .52544 .47491 L .824 .527 0 r
F
.54343 .47475 m .52544 .47491 L .52577 .47763 L .822 .518 0 r
F
.54343 .47475 m .54299 .47205 L .52544 .47491 L F
.54253 .46935 m .52473 .46949 L .52509 .4722 L .825 .535 0 r
F
.54299 .47205 m .54253 .46935 L .52509 .4722 L .824 .527 0 r
F
.48597 .43227 m .46992 .43006 L .46988 .43269 L 1 .818 0 r
F
.48597 .43227 m .48579 .42963 L .46992 .43006 L F
.43116 .48678 m .41339 .4817 L .41306 .48435 L 1 .819 0 r
F
.43094 .48945 m .43116 .48678 L .41306 .48435 L 1 .811 0 r
F
.44879 .52014 m .42946 .51566 L .42939 .51822 L 1 .706 0 r
F
.44873 .52274 m .44879 .52014 L .42939 .51822 L 1 .703 0 r
F
.54385 .47746 m .52577 .47763 L .52608 .48034 L .821 .51 0 r
F
.54385 .47746 m .54343 .47475 L .52577 .47763 L F
.68445 .15983 m .67568 .1668 L .68087 .1716 L .261 .241 0 r
F
.68445 .15983 m .67911 .15532 L .67568 .1668 L F
.12811 .61763 m .09767 .59697 L .09857 .60338 L 1 .688 0 r
F
.12905 .62383 m .12811 .61763 L .09857 .60338 L 1 .67 0 r
F
.63258 .51406 m .61573 .51808 L .61519 .52131 L .331 .033 0 r
F
.63258 .51406 m .63321 .51082 L .61573 .51808 L F
.35438 .85247 m .31744 .84441 L .31974 .84836 L .953 .074 0 r
F
.35617 .85624 m .35438 .85247 L .31974 .84836 L .936 .071 0 r
F
.54624 .49103 m .52748 .49122 L .52773 .49393 L .825 .482 0 r
F
.54624 .49103 m .5459 .48831 L .52748 .49122 L F
.54205 .46664 m .52435 .46678 L .52473 .46949 L .827 .543 0 r
F
.54253 .46935 m .54205 .46664 L .52473 .46949 L .825 .535 0 r
F
.43335 .46541 m .41665 .46046 L .41618 .46311 L 1 .873 0 r
F
.43335 .46541 m .43367 .46274 L .41665 .46046 L F
.39534 .58357 m .37318 .57617 L .37342 .57914 L 1 .612 0 r
F
.39558 .58648 m .39534 .58357 L .37342 .57914 L 1 .599 0 r
F
.45339 .43734 m .4378 .43346 L .43734 .43607 L 1 .894 0 r
F
.45339 .43734 m .45363 .4347 L .4378 .43346 L F
.56211 .5931 m .54054 .59442 L .54007 .597 L .64 .062 0 r
F
.56211 .5931 m .56274 .59054 L .54054 .59442 L F
.43446 .45457 m .41829 .44969 L .41774 .45233 L 1 .9 0 r
F
.43446 .45457 m .43484 .4519 L .41829 .44969 L F
.52949 .52341 m .50955 .52271 L .5096 .52535 L .876 .452 0 r
F
.52949 .52341 m .52941 .52077 L .50955 .52271 L F
.54425 .48016 m .52608 .48034 L .52639 .48305 L .819 .501 0 r
F
.54425 .48016 m .54385 .47746 L .52608 .48034 L F
.68553 .82021 m .65581 .82281 L .65329 .82704 L .363 .001 0 r
F
.68553 .82021 m .68852 .81587 L .65581 .82281 L F
.45324 .44018 m .43754 .43632 L .43711 .43893 L 1 .889 0 r
F
.45324 .44018 m .45347 .43755 L .43754 .43632 L F
.54154 .46394 m .52396 .46406 L .52435 .46678 L .828 .552 0 r
F
.54205 .46664 m .54154 .46394 L .52435 .46678 L .827 .543 0 r
F
.54032 .4557 m .52287 .45586 L .52331 .45857 L .845 .59 0 r
F
.54089 .45841 m .54032 .4557 L .52331 .45857 L .843 .582 0 r
F
.50946 .53286 m .48924 .53142 L .48924 .53398 L .924 .468 0 r
F
.50946 .53286 m .50945 .53029 L .48924 .53142 L F
.52896 .52047 m .50932 .51989 L .50937 .52251 L .865 .441 0 r
F
.52896 .52047 m .52888 .51784 L .50932 .51989 L F
.55581 .76005 m .52856 .76513 L .52798 .76947 L .55 .048 0 r
F
.55581 .76005 m .55672 .75596 L .52856 .76513 L F
.38817 .47823 m .37111 .47087 L .37064 .47378 L 1 .88 0 r
F
.3578 .48904 m .34198 .48001 L .34123 .48314 L 1 .999 0 r
F
.3572 .49223 m .3578 .48904 L .34123 .48314 L 1 .991 0 r
F
.60531 .85569 m .57363 .85616 L .57188 .8597 L .473 .014 0 r
F
.60531 .85569 m .60764 .85208 L .57363 .85616 L F
.43094 .48945 m .41306 .48435 L .41275 .487 L 1 .811 0 r
F
.43073 .4921 m .43094 .48945 L .41275 .487 L 1 .804 0 r
F
.54464 .48286 m .52639 .48305 L .52667 .48576 L .818 .492 0 r
F
.54464 .48286 m .54425 .48016 L .52639 .48305 L F
.46988 .43269 m .45422 .4297 L .45397 .43231 L 1 .863 0 r
F
.46988 .43269 m .46992 .43006 L .45422 .4297 L F
.22955 .74909 m .19281 .73748 L .1952 .74268 L 1 .372 0 r
F
.23166 .75407 m .22955 .74909 L .1952 .74268 L 1 .352 0 r
F
.43367 .46274 m .41713 .45782 L .41665 .46046 L 1 .879 0 r
F
.43367 .46274 m .43401 .46007 L .41713 .45782 L F
.46506 .88124 m .465 .87791 L .42942 .87739 L .751 .046 0 r
F
.49999 .8807 m .465 .87791 L .46506 .88124 L .692 .04 0 r
F
.49999 .8807 m .50058 .87737 L .465 .87791 L F
.54102 .46124 m .52356 .46135 L .52396 .46406 L .83 .56 0 r
F
.54154 .46394 m .54102 .46124 L .52396 .46406 L .828 .552 0 r
F
.64568 .84965 m .61452 .85072 L .61229 .85466 L .423 .011 0 r
F
.64568 .84965 m .64845 .84561 L .61452 .85072 L F
.51885 .43435 m .50237 .4337 L .50274 .43636 L .914 .71 0 r
F
.5194 .43702 m .51885 .43435 L .50274 .43636 L .913 .703 0 r
F
.76556 .19426 m .75398 .20591 L .75924 .21088 L .283 .258 0 r
F
.76556 .19426 m .76016 .1895 L .75398 .20591 L F
.64777 .68367 m .62283 .68647 L .62188 .69065 L .449 .041 0 r
F
.64777 .68367 m .64907 .67966 L .62283 .68647 L F
.3929 .86272 m .35617 .85624 L .358 .85991 L .888 .065 0 r
F
.39418 .86622 m .3929 .86272 L .358 .85991 L .871 .061 0 r
F
.54656 .49374 m .52773 .49393 L .52797 .49664 L .823 .474 0 r
F
.54656 .49374 m .54624 .49103 L .52773 .49393 L F
.51873 .43447 m .50236 .43371 L .50272 .43638 L .902 .699 0 r
F
.51927 .43713 m .51873 .43447 L .50272 .43638 L .901 .692 0 r
F
.37223 .55489 m .35206 .54621 L .35205 .54932 L 1 .762 0 r
F
.37228 .55798 m .37223 .55489 L .35205 .54932 L 1 .75 0 r
F
.51506 .61216 m .49187 .61134 L .49171 .6138 L .815 .117 0 r
F
.51506 .61216 m .51541 .60974 L .49187 .61134 L F
.42933 .50563 m .41059 .50045 L .41036 .50311 L 1 .772 0 r
F
.42917 .50829 m .42933 .50563 L .41036 .50311 L 1 .765 0 r
F
.545 .48556 m .52667 .48576 L .52694 .48846 L .816 .484 0 r
F
.545 .48556 m .54464 .48286 L .52667 .48576 L F
.56994 .87315 m .53692 .87233 L .53571 .87578 L .558 .024 0 r
F
.56994 .87315 m .57178 .86966 L .53692 .87233 L F
.53973 .453 m .52241 .45315 L .52287 .45586 L .846 .597 0 r
F
.54032 .4557 m .53973 .453 L .52287 .45586 L .845 .59 0 r
F
.11147 .64516 m .081 .62332 L .08218 .63002 L 1 .644 0 r
F
.11265 .65167 m .11147 .64516 L .08218 .63002 L 1 .623 0 r
F
.54048 .45854 m .52314 .45865 L .52356 .46135 L .831 .568 0 r
F
.54102 .46124 m .54048 .45854 L .52356 .46135 L .83 .56 0 r
F
.26864 .81284 m .23227 .80076 L .23505 .80555 L 1 .188 0 r
F
.27107 .81741 m .26864 .81284 L .23505 .80555 L 1 .163 0 r
F
.43073 .4921 m .41275 .487 L .41245 .48964 L 1 .804 0 r
F
.43054 .49476 m .43073 .4921 L .41245 .48964 L 1 .796 0 r
F
.48929 .53675 m .47156 .53451 L .46876 .53674 L 1 .547 0 r
F
.47156 .53451 m .46877 .53419 L .46876 .53668 L .985 .519 0 r
F
.47156 .53451 m .46877 .53415 L .46876 .53668 L 1 .547 0 r
F
.47156 .53451 m .46876 .53668 L .46876 .53674 L F
.48923 .53654 m .47156 .53451 L .46876 .53674 L .985 .519 0 r
F
.47156 .53451 m .46876 .53668 L .46876 .53674 L F
.43484 .4519 m .41886 .44705 L .41829 .44969 L 1 .906 0 r
F
.43484 .4519 m .43523 .44924 L .41886 .44705 L F
.50971 .53579 m .48929 .53416 L .48929 .53675 L .936 .482 0 r
F
.50971 .53579 m .5097 .53319 L .48929 .53416 L F
.43401 .46007 m .41763 .45518 L .41713 .45782 L 1 .886 0 r
F
.43401 .46007 m .43436 .45741 L .41763 .45518 L F
.46992 .42989 m .4544 .42687 L .45414 .42947 L 1 .865 0 r
F
.46992 .42989 m .46996 .42727 L .4544 .42687 L F
.46877 .53415 m .44857 .53053 L .44852 .53312 L 1 .622 0 r
F
.40141 .41586 m .38905 .41031 L .38784 .41305 L 1 1 0 r
F
.40141 .41586 m .40237 .41296 L .38905 .41031 L F
.54534 .48825 m .52694 .48846 L .5272 .49116 L .814 .475 0 r
F
.54534 .48825 m .545 .48556 L .52694 .48846 L F
.83575 .68119 m .80875 .68837 L .80695 .69451 L .207 0 0 r
F
.83575 .68119 m .83773 .67488 L .80875 .68837 L F
.54685 .49645 m .52797 .49664 L .52819 .49935 L .822 .465 0 r
F
.54685 .49645 m .54656 .49374 L .52797 .49664 L F
.3572 .49223 m .34123 .48314 L .34051 .48627 L 1 .991 0 r
F
.35664 .49542 m .3572 .49223 L .34051 .48627 L 1 .982 0 r
F
.41967 .60101 m .39641 .59504 L .39673 .59784 L 1 .486 0 r
F
.41992 .60373 m .41967 .60101 L .39673 .59784 L 1 .471 0 r
F
.44873 .52274 m .42939 .51822 L .42934 .52075 L 1 .703 0 r
F
.44867 .52534 m .44873 .52274 L .42934 .52075 L 1 .702 0 r
F
.53992 .45585 m .5227 .45594 L .52314 .45865 L .832 .576 0 r
F
.54048 .45854 m .53992 .45585 L .52314 .45865 L .831 .568 0 r
F
.76489 .19491 m .75325 .20662 L .75852 .21156 L .292 .278 0 r
F
.76489 .19491 m .75942 .19025 L .75325 .20662 L F
.6617 .15746 m .65595 .15895 L .66083 .16432 L 0 .043 0 r
F
.6617 .15746 m .65733 .15142 L .65595 .15895 L F
.58505 .73896 m .55916 .74326 L .55839 .74756 L .504 .043 0 r
F
.58505 .73896 m .58616 .73495 L .55916 .74326 L F
.1783 .69972 m .14366 .68388 L .14563 .68967 L 1 .497 0 r
F
.18013 .70526 m .1783 .69972 L .14563 .68967 L 1 .478 0 r
F
.53913 .4503 m .52194 .45045 L .52241 .45315 L .847 .605 0 r
F
.53973 .453 m .53913 .4503 L .52241 .45315 L .846 .597 0 r
F
.43054 .49476 m .41245 .48964 L .41218 .49228 L 1 .796 0 r
F
.43036 .4974 m .43054 .49476 L .41218 .49228 L 1 .788 0 r
F
.87214 .56465 m .84891 .57496 L .84846 .58158 L .13 .005 0 r
F
.87214 .56465 m .87265 .55793 L .84891 .57496 L F
.52955 .52605 m .5096 .52535 L .50965 .52797 L .874 .442 0 r
F
.52955 .52605 m .52949 .52341 L .5096 .52535 L F
.0777 .51354 m .05431 .48775 L .0535 .49476 L 1 .897 0 r
F
.07705 .52046 m .0777 .51354 L .0535 .49476 L 1 .88 0 r
F
.09056 .49914 m .06924 .47396 L .06811 .48073 L 1 .933 0 r
F
.08963 .50587 m .09056 .49914 L .06811 .48073 L 1 .918 0 r
F
.43436 .45741 m .41815 .45254 L .41763 .45518 L 1 .892 0 r
F
.43436 .45741 m .43472 .45475 L .41815 .45254 L F
.54566 .49095 m .5272 .49116 L .52744 .49386 L .812 .466 0 r
F
.54566 .49095 m .54534 .48825 L .5272 .49116 L F
.45363 .4347 m .43826 .43086 L .4378 .43346 L 1 .9 0 r
F
.45363 .4347 m .45388 .43208 L .43826 .43086 L F
.45347 .43755 m .43799 .43373 L .43754 .43632 L 1 .895 0 r
F
.45347 .43755 m .45372 .43492 L .43799 .43373 L F
.48579 .42963 m .46996 .42745 L .46992 .43006 L 1 .825 0 r
F
.48579 .42963 m .48562 .427 L .46996 .42745 L F
.52903 .52308 m .50937 .52251 L .5094 .52511 L .863 .431 0 r
F
.52903 .52308 m .52896 .52047 L .50937 .52251 L F
.39838 .81042 m .36226 .81042 L .36365 .81449 L .909 .135 0 r
F
.39929 .81449 m .39838 .81042 L .36365 .81449 L .899 .111 0 r
F
.43314 .80843 m .39838 .81042 L .39929 .81449 L .84 .092 0 r
F
.68959 .16454 m .68087 .1716 L .6859 .17656 L .239 .194 0 r
F
.68959 .16454 m .68445 .15983 L .68087 .1716 L F
.53935 .45316 m .52225 .45324 L .5227 .45594 L .834 .584 0 r
F
.53992 .45585 m .53935 .45316 L .5227 .45594 L .832 .576 0 r
F
.11873 .63497 m .08966 .61321 L .09061 .6198 L 1 .672 0 r
F
.11971 .64139 m .11873 .63497 L .09061 .6198 L 1 .651 0 r
F
.54713 .49915 m .52819 .49935 L .5284 .50205 L .82 .456 0 r
F
.54713 .49915 m .54685 .49645 L .52819 .49935 L F
.87646 .40285 m .85704 .41579 L .85893 .42248 L .148 .042 0 r
F
.87646 .40285 m .87449 .39615 L .85704 .41579 L F
.43523 .44924 m .41944 .44443 L .41886 .44705 L 1 .912 0 r
F
.43523 .44924 m .43563 .44659 L .41944 .44443 L F
.51829 .43169 m .50199 .43105 L .50237 .4337 L .914 .717 0 r
F
.51885 .43435 m .51829 .43169 L .50237 .4337 L .914 .71 0 r
F
.16836 .72164 m .13521 .70369 L .13733 .70969 L 1 .463 0 r
F
.17035 .72742 m .16836 .72164 L .13733 .70969 L 1 .439 0 r
F
.68133 .64759 m .65671 .6508 L .65577 .655 L .398 .038 0 r
F
.68133 .64759 m .68258 .64345 L .65671 .6508 L F
.50945 .53542 m .48924 .53398 L .48923 .53654 L .923 .458 0 r
F
.50945 .53542 m .50946 .53286 L .48924 .53398 L F
.51817 .43181 m .50199 .43106 L .50236 .43371 L .903 .706 0 r
F
.51873 .43447 m .51817 .43181 L .50236 .43371 L .902 .699 0 r
F
.35664 .49542 m .34051 .48627 L .33982 .48942 L 1 .982 0 r
F
.35611 .49861 m .35664 .49542 L .33982 .48942 L 1 .973 0 r
F
.46992 .43006 m .45448 .42711 L .45422 .4297 L 1 .869 0 r
F
.46992 .43006 m .46996 .42745 L .45448 .42711 L F
.5385 .4476 m .52146 .44775 L .52194 .45045 L .849 .613 0 r
F
.53913 .4503 m .5385 .4476 L .52194 .45045 L .847 .605 0 r
F
.43036 .4974 m .41218 .49228 L .41192 .49492 L 1 .788 0 r
F
.43019 .50004 m .43036 .4974 L .41192 .49492 L 1 .78 0 r
F
.54596 .49363 m .52744 .49386 L .52766 .49655 L .81 .457 0 r
F
.54596 .49363 m .54566 .49095 L .52744 .49386 L F
.43472 .45475 m .41868 .44991 L .41815 .45254 L 1 .898 0 r
F
.43472 .45475 m .43509 .4521 L .41868 .44991 L F
.77088 .19909 m .75924 .21088 L .76442 .21593 L .274 .239 0 r
F
.77088 .19909 m .76556 .19426 L .75924 .21088 L F
.40237 .41296 m .3903 .40759 L .38905 .41031 L 1 1 0 r
F
.40237 .41296 m .40336 .41008 L .3903 .40759 L F
.09771 .49222 m .07493 .46734 L .07393 .47403 L 1 .931 0 r
F
.0969 .49883 m .09771 .49222 L .07393 .47403 L 1 .916 0 r
F
.53875 .45047 m .52179 .45054 L .52225 .45324 L .835 .592 0 r
F
.53935 .45316 m .53875 .45047 L .52225 .45324 L .834 .584 0 r
F
.50025 .08304 m .49293 .08136 L .49282 .08041 L .617 .015 0 r
F
.87856 .57296 m .8539 .58303 L .85346 .58976 L .158 .012 0 r
F
.87856 .57296 m .87903 .5661 L .8539 .58303 L F
.44867 .52534 m .42934 .52075 L .4293 .52327 L 1 .702 0 r
F
.44862 .52794 m .44867 .52534 L .4293 .52327 L F
.54739 .50185 m .5284 .50205 L .52859 .50474 L .818 .447 0 r
F
.54739 .50185 m .54713 .49915 L .5284 .50205 L F
.40804 .38615 m .3988 .38353 L .39722 .38602 L 1 1 0 r
F
.40804 .38615 m .40934 .3834 L .3988 .38353 L F
.48929 .53933 m .48929 .53675 L .46876 .53674 L .999 .538 0 r
F
.50971 .53837 m .48929 .53675 L .48929 .53933 L .934 .472 0 r
F
.50971 .53837 m .50971 .53579 L .48929 .53675 L F
.48929 .53933 m .46876 .53674 L .46874 .53932 L .999 .538 0 r
F
.48921 .53908 m .46876 .53674 L .46874 .53928 L .983 .509 0 r
F
.48921 .53908 m .48923 .53654 L .46876 .53674 L F
.56702 .20437 m .57381 .16162 L .57182 .18697 L .729 .163 0 r
F
.4314 .35033 m .42465 .35523 L .42319 .35763 L 1 .718 0 r
F
.4314 .35033 m .43248 .34719 L .42465 .35523 L F
.46996 .42727 m .45467 .42428 L .4544 .42687 L 1 .872 0 r
F
.46996 .42727 m .47 .42466 L .45467 .42428 L F
.65367 .47171 m .63965 .4761 L .63895 .47981 L .196 .004 0 r
F
.65367 .47171 m .65448 .46799 L .63965 .4761 L F
.54624 .49632 m .52766 .49655 L .52787 .49924 L .809 .448 0 r
F
.54624 .49632 m .54596 .49363 L .52766 .49655 L F
.53447 .87914 m .50058 .87737 L .49999 .8807 L .622 .031 0 r
F
.53447 .87914 m .53571 .87578 L .50058 .87737 L F
.78346 .75313 m .75522 .7581 L .75273 .76355 L .265 0 0 r
F
.78346 .75313 m .78625 .74752 L .75522 .7581 L F
.43563 .44659 m .42003 .44181 L .41944 .44443 L 1 .918 0 r
F
.43563 .44659 m .43605 .44394 L .42003 .44181 L F
.43019 .50004 m .41192 .49492 L .41168 .49754 L 1 .78 0 r
F
.43003 .50267 m .43019 .50004 L .41168 .49754 L 1 .772 0 r
F
.53786 .44492 m .52097 .44506 L .52146 .44775 L .85 .62 0 r
F
.5385 .4476 m .53786 .44492 L .52146 .44775 L .849 .613 0 r
F
.5296 .52867 m .50965 .52797 L .50968 .53059 L .872 .433 0 r
F
.5296 .52867 m .52955 .52605 L .50965 .52797 L F
.60917 .55187 m .59036 .55514 L .5898 .55806 L .425 .045 0 r
F
.60917 .55187 m .60985 .54895 L .59036 .55514 L F
.2174 .78633 m .18138 .77181 L .18419 .77719 L 1 .282 0 r
F
.21993 .79148 m .2174 .78633 L .18419 .77719 L 1 .256 0 r
F
.35611 .49861 m .33982 .48942 L .33917 .49256 L 1 .973 0 r
F
.35561 .50181 m .35611 .49861 L .33917 .49256 L 1 .964 0 r
F
.43509 .4521 m .41923 .44729 L .41868 .44991 L 1 .904 0 r
F
.43509 .4521 m .43547 .44945 L .41923 .44729 L F
.77029 .19965 m .75852 .21156 L .7637 .21658 L .285 .26 0 r
F
.77029 .19965 m .76489 .19491 L .75852 .21156 L F
.45372 .43492 m .43844 .43114 L .43799 .43373 L 1 .901 0 r
F
.45372 .43492 m .45397 .43231 L .43844 .43114 L F
.53814 .44778 m .52131 .44785 L .52179 .45054 L .836 .6 0 r
F
.53875 .45047 m .53814 .44778 L .52179 .45054 L .835 .592 0 r
F
.88208 .40892 m .86211 .422 L .86404 .42874 L .157 .044 0 r
F
.88208 .40892 m .88002 .40217 L .86211 .422 L F
.52907 .52567 m .5094 .52511 L .50943 .52771 L .861 .422 0 r
F
.52907 .52567 m .52903 .52308 L .5094 .52511 L F
.61512 .71495 m .59007 .71839 L .58917 .7226 L .469 .04 0 r
F
.61512 .71495 m .61638 .711 L .59007 .71839 L F
.37228 .55798 m .35205 .54932 L .35208 .55243 L 1 .75 0 r
F
.37236 .56105 m .37228 .55798 L .35208 .55243 L 1 .739 0 r
F
.45388 .43208 m .43873 .42828 L .43826 .43086 L 1 .906 0 r
F
.45388 .43208 m .45414 .42947 L .43873 .42828 L F
.44396 .61098 m .42018 .60642 L .42046 .60907 L 1 .376 0 r
F
.44412 .61354 m .44396 .61098 L .42046 .60907 L 1 .361 0 r
F
.46791 .61425 m .44396 .61098 L .44412 .61354 L .977 .288 0 r
F
.27819 .78136 m .24077 .77341 L .24322 .7781 L 1 .279 0 r
F
.28024 .7859 m .27819 .78136 L .24322 .7781 L 1 .259 0 r
F
.48562 .427 m .47 .42484 L .46996 .42745 L 1 .831 0 r
F
.48562 .427 m .48543 .42437 L .47 .42484 L F
.51771 .42903 m .50161 .4284 L .50199 .43105 L .915 .724 0 r
F
.51829 .43169 m .51771 .42903 L .50199 .43105 L .914 .717 0 r
F
.74575 .5297 m .72495 .5366 L .72454 .5413 L .259 .029 0 r
F
.74575 .5297 m .74619 .52492 L .72495 .5366 L F
.54762 .50454 m .52859 .50474 L .52876 .50743 L .816 .437 0 r
F
.54762 .50454 m .54739 .50185 L .52859 .50474 L F
.75997 .4321 m .74675 .44 L .74703 .44523 L .045 .007 0 r
F
.75997 .4321 m .75947 .42692 L .74675 .44 L F
.46792 .61672 m .46791 .61425 L .44412 .61354 L .971 .272 0 r
F
.49153 .61622 m .46791 .61425 L .46792 .61672 L .894 .191 0 r
F
.49153 .61622 m .49171 .6138 L .46791 .61425 L F
.5176 .42916 m .5016 .42841 L .50199 .43106 L .904 .713 0 r
F
.51817 .43181 m .5176 .42916 L .50199 .43106 L .903 .706 0 r
F
.16428 .7324 m .13015 .71461 L .13247 .72064 L 1 .432 0 r
F
.16645 .73821 m .16428 .7324 L .13247 .72064 L 1 .408 0 r
F
.69451 .16947 m .6859 .17656 L .69076 .18166 L .212 .137 0 r
F
.69451 .16947 m .68959 .16454 L .6859 .17656 L F
.39558 .58648 m .37342 .57914 L .3737 .58208 L 1 .599 0 r
F
.39583 .58935 m .39558 .58648 L .3737 .58208 L 1 .586 0 r
F
.66565 .16397 m .66083 .16432 L .66548 .16991 L 0 .014 0 r
F
.66565 .16397 m .6617 .15746 L .66083 .16432 L F
.70813 .28197 m .70582 .28175 L .7064 .28888 L 0 0 0 r
F
.70813 .28197 m .70749 .27506 L .70582 .28175 L F
.54649 .49899 m .52787 .49924 L .52806 .50192 L .807 .438 0 r
F
.54649 .49899 m .54624 .49632 L .52787 .49924 L F
.58535 .57759 m .56506 .57994 L .56451 .58264 L .537 .053 0 r
F
.58535 .57759 m .58604 .57489 L .56506 .57994 L F
.42775 .37532 m .41854 .37505 L .41724 .37756 L 1 1 0 r
F
.42775 .37532 m .42872 .3724 L .41854 .37505 L F
.43416 .39511 m .42775 .37532 L .41724 .37756 L 1 .217 0 r
F
.44639 .39403 m .42872 .3724 L .42775 .37532 L .363 .11 0 r
F
.4458 .39639 m .42775 .37532 L .43416 .39511 L .373 .127 0 r
F
.4458 .39639 m .44639 .39403 L .42775 .37532 L F
.63194 .51726 m .61519 .52131 L .61465 .52451 L .328 .032 0 r
F
.63194 .51726 m .63258 .51406 L .61519 .52131 L F
.48558 .07891 m .47811 .07657 L .48548 .07854 L .432 0 0 r
F
.50944 .53796 m .48923 .53654 L .48921 .53908 L .921 .448 0 r
F
.50944 .53796 m .50945 .53542 L .48923 .53654 L F
.43003 .50267 m .41168 .49754 L .41147 .50016 L 1 .772 0 r
F
.42989 .50529 m .43003 .50267 L .41147 .50016 L 1 .763 0 r
F
.53719 .44223 m .52046 .44237 L .52097 .44506 L .851 .628 0 r
F
.53786 .44492 m .53719 .44223 L .52097 .44506 L .85 .62 0 r
F
.46996 .42745 m .45474 .42453 L .45448 .42711 L 1 .876 0 r
F
.46996 .42745 m .47 .42484 L .45474 .42453 L F
.5375 .44511 m .52082 .44516 L .52131 .44785 L .838 .608 0 r
F
.53814 .44778 m .5375 .44511 L .52131 .44785 L .836 .6 0 r
F
.32193 .79969 m .28453 .79478 L .28677 .79912 L 1 .216 0 r
F
.32371 .80394 m .32193 .79969 L .28677 .79912 L 1 .195 0 r
F
.43547 .44945 m .4198 .44468 L .41923 .44729 L 1 .91 0 r
F
.43547 .44945 m .43587 .44681 L .4198 .44468 L F
.44862 .52794 m .4293 .52327 L .42929 .52575 L 1 .702 0 r
F
.44857 .53053 m .44862 .52794 L .42929 .52575 L 1 .703 0 r
F
.6753 .42192 m .66474 .42601 L .66348 .43072 L 0 0 0 r
F
.6753 .42192 m .67668 .41717 L .66474 .42601 L F
.53807 .60696 m .51575 .60728 L .51541 .60974 L .724 .069 0 r
F
.53807 .60696 m .5386 .60452 L .51575 .60728 L F
.43605 .44394 m .42064 .43921 L .42003 .44181 L 1 .924 0 r
F
.43605 .44394 m .43647 .44131 L .42064 .43921 L F
.35561 .50181 m .33917 .49256 L .33857 .49571 L 1 .964 0 r
F
.35514 .50501 m .35561 .50181 L .33857 .49571 L 1 .955 0 r
F
.77613 .20399 m .76442 .21593 L .76952 .22105 L .266 .22 0 r
F
.77613 .20399 m .77088 .19909 L .76442 .21593 L F
.73285 .79977 m .70369 .80314 L .70099 .80796 L .321 0 0 r
F
.73285 .79977 m .73595 .79482 L .70369 .80314 L F
.48928 .54189 m .46874 .53932 L .46872 .54189 L .997 .529 0 r
F
.48928 .54189 m .48929 .53933 L .46874 .53932 L F
.5097 .54093 m .48929 .53933 L .48928 .54189 L .932 .463 0 r
F
.5097 .54093 m .50971 .53837 L .48929 .53933 L F
.54783 .50723 m .52876 .50743 L .52892 .51012 L .814 .428 0 r
F
.54783 .50723 m .54762 .50454 L .52876 .50743 L F
.54673 .50167 m .52806 .50192 L .52824 .50459 L .805 .429 0 r
F
.54673 .50167 m .54649 .49899 L .52806 .50192 L F
.71517 .60036 m .69155 .60499 L .69075 .60935 L .345 .035 0 r
F
.71517 .60036 m .71619 .59595 L .69155 .60499 L F
.52964 .53128 m .50968 .53059 L .5097 .53319 L .87 .423 0 r
F
.52964 .53128 m .5296 .52867 L .50968 .53059 L F
.48919 .5416 m .46874 .53928 L .46873 .5418 L .982 .5 0 r
F
.48919 .5416 m .48921 .53908 L .46874 .53928 L F
.56146 .59564 m .54007 .597 L .5396 .59954 L .633 .06 0 r
F
.56146 .59564 m .56211 .5931 L .54007 .597 L F
.45397 .43231 m .43891 .42856 L .43844 .43114 L 1 .907 0 r
F
.45397 .43231 m .45422 .4297 L .43891 .42856 L F
.52911 .52826 m .50943 .52771 L .50945 .53029 L .859 .412 0 r
F
.52911 .52826 m .52907 .52567 L .50943 .52771 L F
.47 .42466 m .45494 .4217 L .45467 .42428 L 1 .878 0 r
F
.47 .42466 m .47004 .42205 L .45494 .4217 L F
.53685 .44243 m .52032 .44248 L .52082 .44516 L .839 .615 0 r
F
.5375 .44511 m .53685 .44243 L .52082 .44516 L .838 .608 0 r
F
.42989 .50529 m .41147 .50016 L .41127 .50278 L 1 .763 0 r
F
.42976 .5079 m .42989 .50529 L .41127 .50278 L 1 .755 0 r
F
.53652 .43955 m .51993 .43969 L .52046 .44237 L .853 .636 0 r
F
.53719 .44223 m .53652 .43955 L .52046 .44237 L .851 .628 0 r
F
.45414 .42947 m .43921 .42571 L .43873 .42828 L 1 .912 0 r
F
.45414 .42947 m .4544 .42687 L .43921 .42571 L F
.43587 .44681 m .42038 .44207 L .4198 .44468 L 1 .916 0 r
F
.43587 .44681 m .43627 .44418 L .42038 .44207 L F
.77559 .20447 m .7637 .21658 L .7688 .22168 L .277 .242 0 r
F
.77559 .20447 m .77029 .19965 L .7637 .21658 L F
.51713 .42639 m .50122 .42576 L .50161 .4284 L .916 .731 0 r
F
.51771 .42903 m .51713 .42639 L .50161 .4284 L .915 .724 0 r
F
.48558 .07891 m .48445 .07857 L .47811 .07657 L .432 0 0 r
F
.48445 .07857 m .47815 .07682 L .47811 .07657 L .698 .029 0 r
F
.48445 .07857 m .47815 .07667 L .47811 .07657 L .432 0 0 r
F
.48445 .07857 m .47811 .07657 L .47811 .07657 L F
.48558 .07888 m .48445 .07857 L .47811 .07657 L .698 .029 0 r
F
.48445 .07857 m .47811 .07657 L .47811 .07657 L F
.51702 .42652 m .50121 .42577 L .5016 .42841 L .905 .72 0 r
F
.5176 .42916 m .51702 .42652 L .5016 .42841 L .904 .713 0 r
F
.69752 .36406 m .69091 .367 L .68933 .37329 L 0 0 0 r
F
.69752 .36406 m .69909 .3578 L .69091 .367 L F
.48543 .42437 m .47004 .42224 L .47 .42484 L 1 .838 0 r
F
.48543 .42437 m .48525 .42176 L .47004 .42224 L F
.43359 .8125 m .43314 .80843 L .39929 .81449 L .828 .074 0 r
F
.46592 .80479 m .43314 .80843 L .43359 .8125 L .758 .068 0 r
F
.46592 .80479 m .4659 .80066 L .43314 .80843 L F
.35514 .50501 m .33857 .49571 L .33799 .49887 L 1 .955 0 r
F
.35471 .5082 m .35514 .50501 L .33799 .49887 L 1 .946 0 r
F
.43647 .44131 m .42127 .43661 L .42064 .43921 L 1 .93 0 r
F
.43647 .44131 m .4369 .43868 L .42127 .43661 L F
.40934 .3834 m .40041 .38108 L .3988 .38353 L 1 1 0 r
F
.40934 .3834 m .41065 .38069 L .40041 .38108 L F
.41992 .60373 m .39673 .59784 L .39707 .60062 L 1 .471 0 r
F
.42018 .60642 m .41992 .60373 L .39707 .60062 L 1 .457 0 r
F
.46516 .8749 m .4651 .87168 L .43008 .8712 L .742 .045 0 r
F
.49953 .87427 m .4651 .87168 L .46516 .8749 L .68 .037 0 r
F
.49953 .87427 m .50012 .87106 L .4651 .87168 L F
.54695 .50433 m .52824 .50459 L .5284 .50726 L .803 .42 0 r
F
.54695 .50433 m .54673 .50167 L .52824 .50459 L F
.44857 .53053 m .42929 .52575 L .42932 .52819 L 1 .703 0 r
F
.44852 .53312 m .44857 .53053 L .42932 .52819 L 1 .707 0 r
F
.5147 .61455 m .49171 .6138 L .49153 .61622 L .807 .102 0 r
F
.5147 .61455 m .51506 .61216 L .49171 .6138 L F
.54803 .50991 m .52892 .51012 L .52907 .51279 L .811 .419 0 r
F
.54803 .50991 m .54783 .50723 L .52892 .51012 L F
.31265 .84624 m .27548 .83657 L .27823 .84087 L 1 .082 0 r
F
.31493 .85034 m .31265 .84624 L .27823 .84087 L .99 .079 0 r
F
.69917 .17466 m .69076 .18166 L .69543 .18692 L .178 .088 0 r
F
.69917 .17466 m .69451 .16947 L .69076 .18166 L F
.87831 .40958 m .85893 .42248 L .8607 .42918 L .139 .039 0 r
F
.87831 .40958 m .87646 .40285 L .85893 .42248 L F
.64258 .84309 m .61215 .84458 L .60992 .84838 L .408 .006 0 r
F
.64258 .84309 m .64535 .83921 L .61215 .84458 L F
.53618 .43976 m .5198 .4398 L .52032 .44248 L .84 .623 0 r
F
.53685 .44243 m .53618 .43976 L .52032 .44248 L .839 .615 0 r
F
.50941 .54049 m .48921 .53908 L .48919 .5416 L .919 .438 0 r
F
.50941 .54049 m .50944 .53796 L .48921 .53908 L F
.56828 .86651 m .53586 .86601 L .53466 .86933 L .538 .02 0 r
F
.56828 .86651 m .5701 .86316 L .53586 .86601 L F
.47 .42484 m .45501 .42196 L .45474 .42453 L 1 .882 0 r
F
.47 .42484 m .47004 .42224 L .45501 .42196 L F
.56851 .13815 m .56641 .12085 L .57057 .13173 L .84 .137 0 r
F
.68638 .83086 m .6564 .83298 L .65381 .83727 L .372 .003 0 r
F
.68638 .83086 m .68945 .82644 L .6564 .83298 L F
.53582 .43688 m .5194 .43702 L .51993 .43969 L .854 .643 0 r
F
.53652 .43955 m .53582 .43688 L .51993 .43969 L .853 .636 0 r
F
.12905 .62383 m .09857 .60338 L .09958 .60976 L 1 .67 0 r
F
.13009 .62999 m .12905 .62383 L .09958 .60976 L 1 .652 0 r
F
.42976 .5079 m .41127 .50278 L .41109 .50538 L 1 .755 0 r
F
.42964 .5105 m .42976 .5079 L .41109 .50538 L 1 .745 0 r
F
.08963 .50587 m .06811 .48073 L .06709 .48753 L 1 .918 0 r
F
.0888 .51261 m .08963 .50587 L .06709 .48753 L 1 .902 0 r
F
.37236 .56105 m .35208 .55243 L .35214 .55552 L 1 .739 0 r
F
.37247 .56411 m .37236 .56105 L .35214 .55552 L 1 .727 0 r
F
.43248 .34719 m .42613 .35287 L .42465 .35523 L 1 .586 0 r
F
.43627 .44418 m .42098 .43948 L .42038 .44207 L 1 .922 0 r
F
.43627 .44418 m .43668 .44155 L .42098 .43948 L F
.26766 .82314 m .23084 .81134 L .23377 .81611 L 1 .161 0 r
F
.2702 .8277 m .26766 .82314 L .23377 .81611 L 1 .135 0 r
F
.66918 .17088 m .66548 .16991 L .66988 .1757 L 0 0 0 r
F
.66918 .17088 m .66565 .16397 L .66548 .16991 L F
.82892 .67743 m .80332 .68502 L .80146 .69101 L .178 0 0 r
F
.82892 .67743 m .83097 .67129 L .80332 .68502 L F
.48926 .54444 m .46872 .54189 L .46871 .54444 L .995 .519 0 r
F
.48926 .54444 m .48928 .54189 L .46872 .54189 L F
.7813 .20896 m .76952 .22105 L .77454 .22624 L .258 .202 0 r
F
.7813 .20896 m .77613 .20399 L .76952 .22105 L F
.52965 .53388 m .5097 .53319 L .50971 .53579 L .868 .413 0 r
F
.52965 .53388 m .52964 .53128 L .5097 .53319 L F
.50967 .54349 m .48928 .54189 L .48926 .54444 L .93 .453 0 r
F
.50967 .54349 m .5097 .54093 L .48928 .54189 L F
.07705 .52046 m .0535 .49476 L .05281 .50178 L 1 .88 0 r
F
.07652 .52739 m .07705 .52046 L .05281 .50178 L 1 .864 0 r
F
.42872 .3724 m .41985 .37256 L .41854 .37505 L 1 1 0 r
F
.42872 .3724 m .42969 .36949 L .41985 .37256 L F
.44699 .3917 m .42969 .36949 L .42872 .3724 L .352 .092 0 r
F
.44639 .39403 m .44699 .3917 L .42872 .3724 L .363 .11 0 r
F
.45422 .4297 m .43938 .426 L .43891 .42856 L 1 .913 0 r
F
.45422 .4297 m .45448 .42711 L .43938 .426 L F
.48546 .07965 m .48335 .07879 L .48558 .07891 L .938 .183 0 r
F
.48546 .07959 m .48335 .07879 L .48558 .07888 L .918 .111 0 r
F
.48335 .07879 m .47815 .07682 L .48445 .07857 L F
.48335 .07879 m .48445 .07857 L .48558 .07891 L .938 .183 0 r
F
.48335 .07879 m .48445 .07857 L .48558 .07888 L .918 .111 0 r
F
.48335 .07879 m .47815 .07667 L .48445 .07857 L .938 .183 0 r
F
.48536 .08252 m .4781 .07803 L .4781 .07795 L 1 .34 0 r
F
.48213 .07997 m .4781 .07795 L .47814 .07702 L 1 .304 0 r
F
.48213 .07997 m .4781 .07795 L .47815 .07682 L 1 .34 0 r
F
.48536 .08252 m .4781 .07795 L .48213 .07997 L F
.48537 .08237 m .4781 .07802 L .4781 .07795 L 1 .304 0 r
F
.48537 .08237 m .4781 .07795 L .48213 .07997 L F
.48546 .07965 m .47811 .07742 L .48335 .07879 L .938 .183 0 r
F
.48546 .07959 m .47811 .07746 L .47811 .07742 L .918 .111 0 r
F
.48335 .07879 m .47811 .07742 L .47815 .07682 L F
.48546 .07959 m .47811 .07742 L .48335 .07879 L F
.48546 .07965 m .47811 .07747 L .47811 .07742 L .938 .183 0 r
F
.48335 .07879 m .47811 .07742 L .47815 .07667 L F
.52912 .53083 m .50945 .53029 L .50946 .53286 L .857 .402 0 r
F
.52912 .53083 m .52911 .52826 L .50945 .53029 L F
.54714 .50699 m .5284 .50726 L .52854 .50992 L .8 .41 0 r
F
.54714 .50699 m .54695 .50433 L .5284 .50726 L F
.64641 .68763 m .62188 .69065 L .62089 .69479 L .429 .037 0 r
F
.64641 .68763 m .64777 .68367 L .62188 .69065 L F
.35471 .5082 m .33799 .49887 L .33746 .50202 L 1 .946 0 r
F
.35431 .5114 m .35471 .5082 L .33746 .50202 L 1 .936 0 r
F
.4369 .43868 m .42191 .43403 L .42127 .43661 L F
.4369 .43868 m .43734 .43607 L .42191 .43403 L F
.5482 .51259 m .52907 .51279 L .5292 .51546 L .809 .409 0 r
F
.5482 .51259 m .54803 .50991 L .52907 .51279 L F
.48917 .54411 m .46873 .5418 L .46871 .54431 L .98 .49 0 r
F
.48917 .54411 m .48919 .5416 L .46873 .5418 L F
.51653 .42375 m .50082 .42313 L .50122 .42576 L .917 .738 0 r
F
.51713 .42639 m .51653 .42375 L .50122 .42576 L .916 .731 0 r
F
.53549 .4371 m .51927 .43713 L .5198 .4398 L .841 .631 0 r
F
.53618 .43976 m .53549 .4371 L .5198 .4398 L .84 .623 0 r
F
.51642 .42389 m .50081 .42314 L .50121 .42577 L .906 .727 0 r
F
.51702 .42652 m .51642 .42389 L .50121 .42577 L .905 .72 0 r
F
.47004 .42205 m .45522 .41914 L .45494 .4217 L 1 .884 0 r
F
.47004 .42205 m .47008 .41946 L .45522 .41914 L F
.4544 .42687 m .4397 .42315 L .43921 .42571 L 1 .918 0 r
F
.4544 .42687 m .45467 .42428 L .4397 .42315 L F
.0969 .49883 m .07393 .47403 L .07304 .48073 L 1 .916 0 r
F
.09621 .50543 m .0969 .49883 L .07304 .48073 L 1 .901 0 r
F
.42942 .87739 m .39296 .87232 L .39428 .87581 L .818 .055 0 r
F
.43012 .88074 m .42942 .87739 L .39428 .87581 L .8 .051 0 r
F
.46506 .88124 m .42942 .87739 L .43012 .88074 L .751 .046 0 r
F
.44852 .53312 m .42932 .52819 L .42939 .53057 L 1 .707 0 r
F
.44847 .53571 m .44852 .53312 L .42939 .53057 L 1 .715 0 r
F
.60848 .55475 m .5898 .55806 L .58922 .56094 L .419 .043 0 r
F
.60848 .55475 m .60917 .55187 L .5898 .55806 L F
.88403 .4157 m .86404 .42874 L .86587 .43551 L .15 .042 0 r
F
.88403 .4157 m .88208 .40892 L .86404 .42874 L F
.65289 .47536 m .63895 .47981 L .63828 .48345 L .194 .004 0 r
F
.65289 .47536 m .65367 .47171 L .63895 .47981 L F
.78082 .20938 m .7688 .22168 L .77382 .22684 L .27 .224 0 r
F
.78082 .20938 m .77559 .20447 L .7688 .22168 L F
.87151 .57136 m .84846 .58158 L .8479 .58817 L .122 .002 0 r
F
.87151 .57136 m .87214 .56465 L .84846 .58158 L F
.53511 .43422 m .51885 .43435 L .5194 .43702 L .855 .65 0 r
F
.53582 .43688 m .53511 .43422 L .5194 .43702 L .854 .643 0 r
F
.42964 .5105 m .41109 .50538 L .41092 .50797 L 1 .745 0 r
F
.42954 .51309 m .42964 .5105 L .41092 .50797 L 1 .735 0 r
F
.48525 .42176 m .47009 .41966 L .47004 .42224 L 1 .844 0 r
F
.48525 .42176 m .48506 .41916 L .47009 .41966 L F
.76042 .43724 m .74703 .44523 L .74728 .45042 L .049 .007 0 r
F
.76042 .43724 m .75997 .4321 L .74703 .44523 L F
.43668 .44155 m .42159 .43689 L .42098 .43948 L 1 .928 0 r
F
.43668 .44155 m .43711 .43893 L .42159 .43689 L F
.39583 .58935 m .3737 .58208 L .374 .58501 L 1 .586 0 r
F
.39611 .59221 m .39583 .58935 L .374 .58501 L 1 .572 0 r
F
.11265 .65167 m .08218 .63002 L .08347 .63669 L 1 .623 0 r
F
.11393 .65815 m .11265 .65167 L .08347 .63669 L 1 .601 0 r
F
.68002 .65171 m .65577 .655 L .65478 .65918 L .388 .035 0 r
F
.68002 .65171 m .68133 .64759 L .65577 .655 L F
.6313 .52043 m .61465 .52451 L .6141 .52768 L .325 .031 0 r
F
.6313 .52043 m .63194 .51726 L .61465 .52451 L F
.49662 .79578 m .4659 .80066 L .46592 .80479 L .673 .059 0 r
F
.49662 .79578 m .49698 .79167 L .4659 .80066 L F
.35433 .86223 m .31726 .85436 L .31965 .85829 L .937 .071 0 r
F
.35619 .86598 m .35433 .86223 L .31965 .85829 L .92 .068 0 r
F
.49268 .08276 m .48558 .07891 L .49292 .08146 L .817 .049 0 r
F
.49269 .08254 m .48558 .07888 L .49293 .08136 L .792 .044 0 r
F
.49269 .08254 m .48546 .07959 L .48558 .07888 L F
.54731 .50964 m .52854 .50992 L .52867 .51257 L .798 .4 0 r
F
.54731 .50964 m .54714 .50699 L .52854 .50992 L F
.74527 .53446 m .72454 .5413 L .72409 .54597 L .256 .028 0 r
F
.74527 .53446 m .74575 .5297 L .72454 .5413 L F
.36226 .81042 m .32553 .80813 L .32742 .81224 L .968 .161 0 r
F
.36365 .81449 m .36226 .81042 L .32742 .81224 L .958 .139 0 r
F
.47004 .42224 m .45529 .4194 L .45501 .42196 L 1 .888 0 r
F
.47004 .42224 m .47009 .41966 L .45529 .4194 L F
.50938 .543 m .48919 .5416 L .48917 .54411 L .917 .428 0 r
F
.50938 .543 m .50941 .54049 L .48919 .5416 L F
.54835 .51525 m .5292 .51546 L .52931 .51812 L .807 .399 0 r
F
.54835 .51525 m .5482 .51259 L .5292 .51546 L F
.53479 .43445 m .51873 .43447 L .51927 .43713 L .843 .638 0 r
F
.53549 .4371 m .53479 .43445 L .51927 .43713 L .841 .631 0 r
F
.53343 .87256 m .50012 .87106 L .49953 .87427 L .606 .028 0 r
F
.53343 .87256 m .53466 .86933 L .50012 .87106 L F
.44412 .61354 m .42046 .60907 L .42075 .6117 L 1 .361 0 r
F
.44429 .61607 m .44412 .61354 L .42075 .6117 L 1 .346 0 r
F
.46792 .61672 m .44412 .61354 L .44429 .61607 L .971 .272 0 r
F
.70354 .18012 m .69543 .18692 L .69989 .19234 L .134 .077 0 r
F
.70354 .18012 m .69917 .17466 L .69543 .18692 L F
.35431 .5114 m .33746 .50202 L .33696 .50518 L 1 .936 0 r
F
.35394 .51459 m .35431 .5114 L .33696 .50518 L 1 .927 0 r
F
.58463 .58026 m .56451 .58264 L .56394 .5853 L .529 .051 0 r
F
.58463 .58026 m .58535 .57759 L .56451 .58264 L F
.60528 .86594 m .57357 .86606 L .57178 .86966 L .48 .015 0 r
F
.60528 .86594 m .60767 .86227 L .57357 .86606 L F
.11971 .64139 m .09061 .6198 L .09168 .62637 L 1 .651 0 r
F
.1208 .64778 m .11971 .64139 L .09168 .62637 L 1 .63 0 r
F
.52966 .53646 m .50971 .53579 L .50971 .53837 L .865 .403 0 r
F
.52966 .53646 m .52965 .53388 L .50971 .53579 L F
.43734 .43607 m .42256 .43146 L .42191 .43403 L 1 .941 0 r
F
.43734 .43607 m .4378 .43346 L .42256 .43146 L F
.48924 .54698 m .46871 .54444 L .46869 .54699 L .993 .51 0 r
F
.48924 .54698 m .48926 .54444 L .46871 .54444 L F
.87796 .5798 m .85346 .58976 L .85291 .59647 L .151 .009 0 r
F
.87796 .5798 m .87856 .57296 L .85346 .58976 L F
.7776 .74801 m .75048 .75347 L .74796 .75876 L .241 0 0 r
F
.7776 .74801 m .78041 .74257 L .75048 .75347 L F
.41065 .38069 m .40203 .37867 L .40041 .38108 L 1 1 0 r
F
.41065 .38069 m .41198 .378 L .40203 .37867 L F
.45448 .42711 m .43987 .42345 L .43938 .426 L 1 .919 0 r
F
.45448 .42711 m .45474 .42453 L .43987 .42345 L F
.52912 .53339 m .50946 .53286 L .50945 .53542 L .854 .392 0 r
F
.52912 .53339 m .52912 .53083 L .50946 .53286 L F
.53437 .43156 m .51829 .43169 L .51885 .43435 L .857 .658 0 r
F
.53511 .43422 m .53437 .43156 L .51885 .43435 L .855 .65 0 r
F
.50964 .54603 m .48926 .54444 L .48924 .54698 L .928 .443 0 r
F
.50964 .54603 m .50967 .54349 L .48926 .54444 L F
.83366 .68745 m .80695 .69451 L .80505 .70061 L .201 0 0 r
F
.83366 .68745 m .83575 .68119 L .80695 .69451 L F
.48445 .10077 m .4781 .07802 L .48537 .08237 L .839 .368 0 r
F
.48505 .08307 m .47811 .07747 L .48546 .07965 L .845 .365 0 r
F
.48506 .08289 m .47811 .07746 L .48546 .07959 L .845 .364 0 r
F
.48505 .08307 m .48345 .0869 L .47811 .07747 L .845 .365 0 r
F
.48439 .10249 m .47863 .2217 L .4781 .07803 L .839 .369 0 r
F
.48445 .10077 m .47863 .2217 L .4781 .07802 L .839 .368 0 r
F
.47708 .31617 m .47407 .33061 L .47808 .07893 L .874 .402 0 r
F
.47713 .31484 m .47407 .33061 L .47808 .0789 L .873 .401 0 r
F
.47407 .33061 m .47388 .33159 L .47763 .10618 L F
.47407 .33061 m .47763 .10618 L .47808 .07893 L .874 .402 0 r
F
.47407 .33061 m .47763 .10618 L .47808 .0789 L .873 .401 0 r
F
.47407 .33061 m .47388 .33151 L .47763 .10618 L .874 .402 0 r
F
.47863 .2217 m .47414 .31512 L .47806 .08041 L .839 .368 0 r
F
.47863 .2217 m .47806 .08041 L .4781 .07803 L .839 .369 0 r
F
.47863 .2217 m .47806 .08041 L .4781 .07802 L .839 .368 0 r
F
.47863 .2217 m .47415 .31454 L .47806 .08041 L .839 .369 0 r
F
.48345 .0869 m .47761 .10148 L .4781 .07779 L .845 .364 0 r
F
.48345 .0869 m .47762 .10083 L .4781 .07779 L .845 .365 0 r
F
.48345 .0869 m .4781 .07779 L .47811 .07747 L F
.48506 .08289 m .48345 .0869 L .47811 .07746 L .845 .364 0 r
F
.48345 .0869 m .4781 .07779 L .47811 .07746 L F
.7864 .214 m .77454 .22624 L .77948 .2315 L .25 .185 0 r
F
.7864 .214 m .7813 .20896 L .77454 .22624 L F
.46792 .61915 m .46792 .61672 L .44429 .61607 L .965 .256 0 r
F
.49136 .6186 m .46792 .61672 L .46792 .61915 L .887 .174 0 r
F
.49136 .6186 m .49153 .61622 L .46792 .61672 L F
.52602 .78196 m .49732 .78747 L .49698 .79167 L .593 .051 0 r
F
.52602 .78196 m .52671 .77788 L .49732 .78747 L F
.44847 .53571 m .42939 .53057 L .43069 .53141 L 1 .715 0 r
F
.44843 .53831 m .44847 .53571 L .43069 .53141 L 1 .797 0 r
F
.42954 .51309 m .41092 .50797 L .41078 .51055 L 1 .735 0 r
F
.42946 .51566 m .42954 .51309 L .41078 .51055 L 1 .725 0 r
F
.51592 .42112 m .50041 .42051 L .50082 .42313 L .918 .745 0 r
F
.51653 .42375 m .51592 .42112 L .50082 .42313 L .917 .738 0 r
F
.43711 .43893 m .42221 .43431 L .42159 .43689 L 1 .934 0 r
F
.43711 .43893 m .43754 .43632 L .42221 .43431 L F
.51581 .42126 m .50041 .42052 L .50081 .42314 L .907 .734 0 r
F
.51642 .42389 m .51581 .42126 L .50081 .42314 L .906 .727 0 r
F
.55486 .76407 m .52798 .76947 L .52736 .77372 L .525 .044 0 r
F
.55486 .76407 m .55581 .76005 L .52798 .76947 L F
.22195 .78086 m .18686 .76631 L .18958 .77162 L 1 .287 0 r
F
.22441 .78594 m .22195 .78086 L .18958 .77162 L 1 .261 0 r
F
.70854 .28886 m .7064 .28888 L .7067 .29602 L 0 0 0 r
F
.70854 .28886 m .70813 .28197 L .7064 .28888 L F
.45467 .42428 m .4402 .42061 L .4397 .42315 L 1 .924 0 r
F
.45467 .42428 m .45494 .4217 L .4402 .42061 L F
.18013 .70526 m .14563 .68967 L .14769 .69541 L 1 .478 0 r
F
.18205 .71075 m .18013 .70526 L .14769 .69541 L 1 .458 0 r
F
.48914 .5466 m .46871 .54431 L .4687 .5468 L .978 .48 0 r
F
.48914 .5466 m .48917 .54411 L .46871 .54431 L F
.54747 .51228 m .52867 .51257 L .52878 .51521 L .796 .39 0 r
F
.54747 .51228 m .54731 .50964 L .52867 .51257 L F
.39296 .87232 m .35619 .86598 L .35809 .86963 L .874 .062 0 r
F
.39428 .87581 m .39296 .87232 L .35809 .86963 L .856 .059 0 r
F
.37247 .56411 m .35214 .55552 L .35224 .5586 L 1 .727 0 r
F
.37261 .56715 m .37247 .56411 L .35224 .5586 L 1 .715 0 r
F
.47008 .41946 m .4555 .41658 L .45522 .41914 L 1 .89 0 r
F
.47008 .41946 m .47012 .41689 L .4555 .41658 L F
.23166 .75407 m .1952 .74268 L .19767 .74781 L 1 .352 0 r
F
.23383 .75899 m .23166 .75407 L .19767 .74781 L 1 .332 0 r
F
.53754 .60936 m .51541 .60974 L .51506 .61216 L .716 .067 0 r
F
.53754 .60936 m .53807 .60696 L .51541 .60974 L F
.49994 .08381 m .49269 .08254 L .49293 .08136 L .666 .027 0 r
F
.67232 .17809 m .66988 .1757 L .67404 .18168 L 0 0 0 r
F
.67232 .17809 m .66918 .17088 L .66988 .1757 L F
.58389 .7429 m .55839 .74756 L .55758 .75179 L .477 .039 0 r
F
.58389 .7429 m .58505 .73896 L .55839 .74756 L F
.78596 .21437 m .77382 .22684 L .77876 .23208 L .262 .206 0 r
F
.78596 .21437 m .78082 .20938 L .77382 .22684 L F
.53406 .4318 m .51817 .43181 L .51873 .43447 L .844 .646 0 r
F
.53479 .43445 m .53406 .4318 L .51873 .43447 L .843 .638 0 r
F
.54848 .51791 m .52931 .51812 L .52941 .52077 L .804 .39 0 r
F
.54848 .51791 m .54835 .51525 L .52931 .51812 L F
.42969 .36949 m .42118 .37011 L .41985 .37256 L 1 1 0 r
F
.42969 .36949 m .43068 .36659 L .42118 .37011 L F
.4476 .38938 m .43068 .36659 L .42969 .36949 L .341 .077 0 r
F
.44699 .3917 m .4476 .38938 L .42969 .36949 L .352 .092 0 r
F
.48506 .41916 m .47013 .41709 L .47009 .41966 L 1 .851 0 r
F
.48506 .41916 m .48487 .41657 L .47013 .41709 L F
.43357 .34403 m .42763 .35054 L .42613 .35287 L .921 .436 0 r
F
.5608 .59814 m .5396 .59954 L .5391 .60205 L .625 .059 0 r
F
.5608 .59814 m .56146 .59564 L .5396 .59954 L F
.40626 .52348 m .38621 .51763 L .38624 .52031 L .772 .944 0 r
F
.4064 .52604 m .40626 .52348 L .38624 .52031 L 1 .607 0 r
F
.71411 .60474 m .69075 .60935 L .6899 .61369 L .339 .032 0 r
F
.71411 .60474 m .71517 .60036 L .69075 .60935 L F
.67397 .42652 m .66348 .43072 L .66228 .43529 L 0 0 0 r
F
.67397 .42652 m .6753 .42192 L .66348 .43072 L F
.35394 .51459 m .33696 .50518 L .3365 .50834 L 1 .927 0 r
F
.3536 .51778 m .35394 .51459 L .3365 .50834 L 1 .917 0 r
F
.53363 .42891 m .51771 .42903 L .51829 .43169 L .858 .665 0 r
F
.53437 .43156 m .53363 .42891 L .51829 .43169 L .857 .658 0 r
F
.88004 .41633 m .8607 .42918 L .86236 .43591 L .13 .036 0 r
F
.88004 .41633 m .87831 .40958 L .8607 .42918 L F
.41391 .47366 m .39748 .46777 L .39693 .47043 L 1 .901 0 r
F
.41391 .47366 m .41433 .47098 L .39748 .46777 L F
.4135 .47634 m .41391 .47366 L .39693 .47043 L 1 .894 0 r
F
.4135 .47634 m .39693 .47043 L .3964 .4731 L F
.41311 .47902 m .4135 .47634 L .3964 .4731 L 1 .888 0 r
F
.728 .79385 m .69977 .7977 L .69707 .80236 L .301 0 0 r
F
.728 .79385 m .7311 .78906 L .69977 .7977 L F
.50707 .08591 m .50025 .08304 L .50749 .08518 L .522 0 0 r
F
.50702 .08649 m .49991 .08416 L .50024 .08321 L .574 .006 0 r
F
.50707 .08591 m .49994 .08381 L .50025 .08304 L .522 0 0 r
F
.41433 .47098 m .39805 .46512 L .39748 .46777 L 1 .907 0 r
F
.41433 .47098 m .41477 .4683 L .39805 .46512 L F
.42018 .60642 m .39707 .60062 L .39743 .60337 L 1 .457 0 r
F
.42046 .60907 m .42018 .60642 L .39743 .60337 L 1 .442 0 r
F
.41311 .47902 m .3964 .4731 L .3959 .47576 L 1 .888 0 r
F
.41274 .48171 m .41311 .47902 L .3959 .47576 L 1 .881 0 r
F
.17035 .72742 m .13733 .70969 L .13955 .71563 L 1 .439 0 r
F
.17243 .73315 m .17035 .72742 L .13955 .71563 L 1 .415 0 r
F
.43754 .43632 m .42286 .43175 L .42221 .43431 L 1 .94 0 r
F
.43754 .43632 m .43799 .43373 L .42286 .43175 L F
.47009 .41966 m .45557 .41685 L .45529 .4194 L 1 .894 0 r
F
.47009 .41966 m .47013 .41709 L .45557 .41685 L F
.41477 .4683 m .39864 .46247 L .39805 .46512 L 1 .913 0 r
F
.41477 .4683 m .41522 .46563 L .39864 .46247 L F
.42946 .51566 m .41078 .51055 L .41066 .51312 L 1 .725 0 r
F
.42939 .51822 m .42946 .51566 L .41066 .51312 L 1 .713 0 r
F
.52964 .53904 m .50971 .53837 L .5097 .54093 L .863 .393 0 r
F
.52964 .53904 m .52966 .53646 L .50971 .53837 L F
.41274 .48171 m .3959 .47576 L .39541 .47843 L 1 .881 0 r
F
.41238 .48439 m .41274 .48171 L .39541 .47843 L 1 .874 0 r
F
.50933 .54549 m .48917 .54411 L .48914 .5466 L .914 .418 0 r
F
.50933 .54549 m .50938 .543 L .48917 .54411 L F
.44843 .53831 m .43069 .53141 L .42864 .53647 L 1 .797 0 r
F
.44839 .5409 m .44843 .53831 L .42864 .53647 L 1 .663 0 r
F
.5476 .51491 m .52878 .51521 L .52888 .51784 L .794 .381 0 r
F
.5476 .51491 m .54747 .51228 L .52878 .51521 L F
.6138 .71885 m .58917 .7226 L .58822 .72677 L .444 .036 0 r
F
.6138 .71885 m .61512 .71495 L .58917 .7226 L F
.48922 .54951 m .46869 .54699 L .46868 .54953 L .99 .5 0 r
F
.48922 .54951 m .48924 .54698 L .46869 .54699 L F
.45474 .42453 m .44036 .42091 L .43987 .42345 L 1 .925 0 r
F
.45474 .42453 m .45501 .42196 L .44036 .42091 L F
.52911 .53594 m .50945 .53542 L .50944 .53796 L .852 .382 0 r
F
.52911 .53594 m .52912 .53339 L .50945 .53542 L F
.41522 .46563 m .39925 .45982 L .39864 .46247 L 1 .92 0 r
F
.41522 .46563 m .4157 .46296 L .39925 .45982 L F
.41238 .48439 m .39541 .47843 L .39495 .4811 L 1 .874 0 r
F
.41204 .48707 m .41238 .48439 L .39495 .4811 L 1 .867 0 r
F
.51529 .4185 m .49999 .41789 L .50041 .42051 L .92 .751 0 r
F
.51592 .42112 m .51529 .4185 L .50041 .42051 L .918 .745 0 r
F
.5096 .54855 m .48924 .54698 L .48922 .54951 L .925 .433 0 r
F
.5096 .54855 m .50964 .54603 L .48924 .54698 L F
.51519 .41864 m .49999 .4179 L .50041 .42052 L .908 .741 0 r
F
.51581 .42126 m .51519 .41864 L .50041 .42052 L .907 .734 0 r
F
.53333 .42916 m .5176 .42916 L .51817 .43181 L .845 .653 0 r
F
.53406 .4318 m .53333 .42916 L .51817 .43181 L .844 .646 0 r
F
.70757 .18588 m .69989 .19234 L .70413 .19793 L .077 .063 0 r
F
.70757 .18588 m .70354 .18012 L .69989 .19234 L F
.4157 .46296 m .39988 .45718 L .39925 .45982 L 1 .926 0 r
F
.4157 .46296 m .41618 .46029 L .39988 .45718 L F
.51433 .6169 m .49153 .61622 L .49136 .6186 L .8 .087 0 r
F
.51433 .6169 m .5147 .61455 L .49153 .61622 L F
.0888 .51261 m .06709 .48753 L .06619 .49433 L 1 .902 0 r
F
.08808 .51935 m .0888 .51261 L .06619 .49433 L 1 .886 0 r
F
.79142 .2191 m .77948 .2315 L .78433 .23682 L .242 .168 0 r
F
.79142 .2191 m .7864 .214 L .77948 .2315 L F
.41204 .48707 m .39495 .4811 L .39451 .48377 L 1 .867 0 r
F
.41172 .48976 m .41204 .48707 L .39451 .48377 L 1 .86 0 r
F
.54859 .52056 m .52941 .52077 L .52949 .52341 L .802 .38 0 r
F
.54859 .52056 m .54848 .51791 L .52941 .52077 L F
.3152 .84037 m .27874 .83065 L .28143 .8349 L 1 .082 0 r
F
.31744 .84441 m .3152 .84037 L .28143 .8349 L .991 .079 0 r
F
.45494 .4217 m .44071 .41808 L .4402 .42061 L 1 .93 0 r
F
.45494 .4217 m .45522 .41914 L .44071 .41808 L F
.51451 .08454 m .50707 .08591 L .50749 .08518 L .136 0 0 r
F
.88586 .42251 m .86587 .43551 L .86758 .44229 L .142 .039 0 r
F
.88586 .42251 m .88403 .4157 L .86587 .43551 L F
.41618 .46029 m .40053 .45455 L .39988 .45718 L 1 .932 0 r
F
.41618 .46029 m .41669 .45763 L .40053 .45455 L F
.5622 .1604 m .56487 .12672 L .56742 .14281 L .938 .187 0 r
F
.60777 .55761 m .58922 .56094 L .58862 .56379 L .413 .042 0 r
F
.60777 .55761 m .60848 .55475 L .58922 .56094 L F
.76083 .44237 m .74728 .45042 L .74749 .45558 L .053 .007 0 r
F
.76083 .44237 m .76042 .43724 L .74728 .45042 L F
.48911 .54907 m .4687 .5468 L .46869 .54927 L .976 .47 0 r
F
.48911 .54907 m .48914 .5466 L .4687 .5468 L F
.3536 .51778 m .3365 .50834 L .33608 .5115 L 1 .917 0 r
F
.3533 .52096 m .3536 .51778 L .33608 .5115 L 1 .907 0 r
F
.65213 .47896 m .63828 .48345 L .63762 .48704 L .193 .004 0 r
F
.65213 .47896 m .65289 .47536 L .63828 .48345 L F
.39611 .59221 m .374 .58501 L .37432 .58791 L 1 .572 0 r
F
.39641 .59504 m .39611 .59221 L .37432 .58791 L 1 .558 0 r
F
.53286 .42626 m .51713 .42639 L .51771 .42903 L .859 .672 0 r
F
.53363 .42891 m .53286 .42626 L .51771 .42903 L .858 .665 0 r
F
.47012 .41689 m .45578 .41405 L .4555 .41658 L 1 .897 0 r
F
.47012 .41689 m .47017 .41432 L .45578 .41405 L F
.41198 .378 m .40367 .3763 L .40203 .37867 L 1 1 0 r
F
.41198 .378 m .41333 .37535 L .40367 .3763 L F
.63065 .52357 m .6141 .52768 L .61353 .53081 L .322 .03 0 r
F
.63065 .52357 m .6313 .52043 L .6141 .52768 L F
.68246 .82447 m .65329 .82704 L .6507 .83118 L .355 0 0 r
F
.68246 .82447 m .68553 .82021 L .65329 .82704 L F
.79101 .21944 m .77876 .23208 L .78361 .23739 L .255 .187 0 r
F
.79101 .21944 m .78596 .21437 L .77876 .23208 L F
.07652 .52739 m .05281 .50178 L .05224 .50881 L 1 .864 0 r
F
.07611 .53432 m .07652 .52739 L .05224 .50881 L 1 .847 0 r
F
.43799 .43373 m .42351 .4292 L .42286 .43175 L 1 .946 0 r
F
.43799 .43373 m .43844 .43114 L .42351 .4292 L F
.48487 .41657 m .47017 .41452 L .47013 .41709 L 1 .857 0 r
F
.48487 .41657 m .48467 .41398 L .47017 .41452 L F
.27107 .81741 m .23505 .80555 L .2379 .81027 L 1 .163 0 r
F
.27356 .8219 m .27107 .81741 L .2379 .81027 L 1 .137 0 r
F
.09621 .50543 m .07304 .48073 L .07226 .48744 L 1 .901 0 r
F
.09562 .51203 m .09621 .50543 L .07226 .48744 L 1 .885 0 r
F
.41669 .45763 m .40121 .45192 L .40053 .45455 L 1 .938 0 r
F
.41669 .45763 m .41721 .45497 L .40121 .45192 L F
.42939 .51822 m .41066 .51312 L .41056 .51568 L 1 .713 0 r
F
.42934 .52075 m .42939 .51822 L .41056 .51568 L 1 .7 0 r
F
.54771 .51754 m .52888 .51784 L .52896 .52047 L .791 .37 0 r
F
.54771 .51754 m .5476 .51491 L .52888 .51784 L F
.69589 .37015 m .68933 .37329 L .6877 .3794 L 0 0 0 r
F
.69589 .37015 m .69752 .36406 L .68933 .37329 L F
.44839 .5409 m .42864 .53647 L .4284 .53928 L 1 .663 0 r
F
.44835 .54349 m .44839 .5409 L .4284 .53928 L 1 .645 0 r
F
.49198 .08693 m .48546 .07959 L .49269 .08254 L .951 .285 0 r
F
.48483 .22393 m .48537 .08237 L .49207 .0943 L 1 .833 0 r
F
.49194 .08765 m .48505 .08307 L .48546 .07965 L .964 .305 0 r
F
.49198 .08693 m .48506 .08289 L .48546 .07959 L .951 .285 0 r
F
.78057 .75867 m .75273 .76355 L .75015 .76893 L .258 0 0 r
F
.78057 .75867 m .78346 .75313 L .75273 .76355 L F
.16645 .73821 m .13247 .72064 L .1349 .72663 L 1 .408 0 r
F
.16871 .74396 m .16645 .73821 L .1349 .72663 L 1 .384 0 r
F
.37261 .56715 m .35224 .5586 L .35236 .56167 L 1 .715 0 r
F
.37277 .57018 m .37261 .56715 L .35236 .56167 L 1 .703 0 r
F
.43008 .8712 m .39418 .86622 L .39548 .86963 L .812 .054 0 r
F
.43077 .87446 m .43008 .8712 L .39548 .86963 L .793 .05 0 r
F
.46516 .8749 m .43008 .8712 L .43077 .87446 L .742 .045 0 r
F
.53257 .42652 m .51702 .42652 L .5176 .42916 L .846 .661 0 r
F
.53333 .42916 m .53257 .42652 L .5176 .42916 L .845 .653 0 r
F
.52961 .5416 m .5097 .54093 L .50967 .54349 L .86 .383 0 r
F
.52961 .5416 m .52964 .53904 L .5097 .54093 L F
.74474 .53919 m .72409 .54597 L .7236 .55062 L .253 .026 0 r
F
.74474 .53919 m .74527 .53446 L .72409 .54597 L F
.67514 .18546 m .67404 .18168 L .67795 .18783 L .683 .084 0 r
F
.67514 .18546 m .67232 .17809 L .67404 .18168 L F
.13009 .62999 m .09958 .60976 L .1007 .61611 L 1 .652 0 r
F
.13122 .63613 m .13009 .62999 L .1007 .61611 L 1 .633 0 r
F
.41721 .45497 m .4019 .4493 L .40121 .45192 L 1 .944 0 r
F
.41721 .45497 m .41774 .45233 L .4019 .4493 L F
.47013 .41709 m .45585 .41432 L .45557 .41685 L 1 .901 0 r
F
.47013 .41709 m .47017 .41452 L .45585 .41432 L F
.54868 .5232 m .52949 .52341 L .52955 .52605 L .799 .37 0 r
F
.54868 .5232 m .54859 .52056 L .52949 .52341 L F
.45501 .42196 m .44086 .41838 L .44036 .42091 L 1 .931 0 r
F
.45501 .42196 m .45529 .4194 L .44086 .41838 L F
.52907 .53847 m .50944 .53796 L .50941 .54049 L .85 .371 0 r
F
.52907 .53847 m .52911 .53594 L .50944 .53796 L F
.43068 .36659 m .42253 .36768 L .42118 .37011 L 1 1 0 r
F
.43068 .36659 m .43168 .36368 L .42253 .36768 L F
.44821 .38709 m .43168 .36368 L .43068 .36659 L .329 .074 0 r
F
.4476 .38938 m .44821 .38709 L .43068 .36659 L .341 .077 0 r
F
.4064 .52604 m .38624 .52031 L .38628 .52298 L 1 .607 0 r
F
.40653 .52857 m .4064 .52604 L .38628 .52298 L 1 .599 0 r
F
.50927 .54796 m .48914 .5466 L .48911 .54907 L .912 .408 0 r
F
.50927 .54796 m .50933 .54549 L .48914 .5466 L F
.46866 .55205 m .46868 .54953 L .4483 .54864 L 1 .554 0 r
F
.48919 .55202 m .46868 .54953 L .46866 .55205 L .988 .489 0 r
F
.48919 .55202 m .48922 .54951 L .46868 .54953 L F
.39929 .81449 m .36365 .81449 L .36508 .81847 L .899 .111 0 r
F
.40023 .81847 m .39929 .81449 L .36508 .81847 L .888 .089 0 r
F
.43359 .8125 m .39929 .81449 L .40023 .81847 L .828 .074 0 r
F
.51466 .41588 m .49957 .41529 L .49999 .41789 L .921 .758 0 r
F
.51529 .4185 m .51466 .41588 L .49999 .41789 L .92 .751 0 r
F
.51456 .41603 m .49957 .4153 L .49999 .4179 L .909 .748 0 r
F
.51519 .41864 m .51456 .41603 L .49999 .4179 L .908 .741 0 r
F
.58389 .5829 m .56394 .5853 L .56335 .58794 L .521 .05 0 r
F
.58389 .5829 m .58463 .58026 L .56394 .5853 L F
.56515 .08973 m .55861 .09218 L .56563 .09448 L .382 .558 0 r
F
.56515 .08973 m .55821 .08758 L .55861 .09218 L F
.35617 .85624 m .31974 .84836 L .32209 .85223 L .936 .071 0 r
F
.358 .85991 m .35617 .85624 L .32209 .85223 L .919 .068 0 r
F
.53208 .42362 m .51653 .42375 L .51713 .42639 L .861 .68 0 r
F
.53286 .42626 m .53208 .42362 L .51713 .42639 L .859 .672 0 r
F
.50955 .55106 m .48922 .54951 L .48919 .55202 L .923 .422 0 r
F
.50955 .55106 m .5096 .54855 L .48922 .54951 L F
.21993 .79148 m .18419 .77719 L .18709 .78249 L 1 .256 0 r
F
.22254 .79655 m .21993 .79148 L .18709 .78249 L 1 .23 0 r
F
.56835 .1613 m .57057 .13173 L .57294 .14728 L .952 .195 0 r
F
.3533 .52096 m .33608 .5115 L .33569 .51466 L 1 .907 0 r
F
.35303 .52414 m .3533 .52096 L .33569 .51466 L 1 .897 0 r
F
.87076 .57805 m .8479 .58817 L .84724 .59475 L .114 0 0 r
F
.87076 .57805 m .87151 .57136 L .8479 .58817 L F
.44429 .61607 m .42075 .6117 L .42106 .61429 L 1 .346 0 r
F
.44446 .61856 m .44429 .61607 L .42106 .61429 L 1 .33 0 r
F
.46792 .61915 m .44429 .61607 L .44446 .61856 L .965 .256 0 r
F
.41488 .47107 m .39872 .46526 L .39818 .4679 L 1 .9 0 r
F
.41488 .47107 m .4153 .46842 L .39872 .46526 L F
.41448 .47373 m .41488 .47107 L .39818 .4679 L 1 .893 0 r
F
.64284 .85359 m .61229 .85466 L .61 .85851 L .415 .007 0 r
F
.64284 .85359 m .64568 .84965 L .61229 .85466 L F
.55967 .46554 m .54249 .46655 L .54299 .46927 L .765 .485 0 r
F
.56026 .46825 m .54299 .46927 L .54346 .47199 L .763 .476 0 r
F
.56026 .46825 m .55967 .46554 L .54299 .46927 L F
.41448 .47373 m .39818 .4679 L .39766 .47053 L 1 .893 0 r
F
.4141 .47639 m .41448 .47373 L .39766 .47053 L 1 .886 0 r
F
.41774 .45233 m .40261 .44669 L .4019 .4493 L 1 .95 0 r
F
.41774 .45233 m .41829 .44969 L .40261 .44669 L F
.28024 .7859 m .24322 .7781 L .24574 .78273 L 1 .259 0 r
F
.28236 .79037 m .28024 .7859 L .24574 .78273 L 1 .238 0 r
F
.55906 .46283 m .54198 .46384 L .54249 .46655 L .767 .494 0 r
F
.55967 .46554 m .55906 .46283 L .54249 .46655 L .765 .485 0 r
F
.56496 .09051 m .55851 .09263 L .56549 .09504 L .354 .514 0 r
F
.56496 .09051 m .55804 .08832 L .55851 .09263 L F
.4153 .46842 m .39929 .46263 L .39872 .46526 L 1 .906 0 r
F
.4153 .46842 m .41573 .46576 L .39929 .46263 L F
.56082 .47097 m .54346 .47199 L .54392 .47471 L .761 .467 0 r
F
.56082 .47097 m .56026 .46825 L .54346 .47199 L F
.79637 .22428 m .78433 .23682 L .78911 .24222 L .234 .151 0 r
F
.79637 .22428 m .79142 .2191 L .78433 .23682 L F
.64499 .69156 m .62089 .69479 L .61984 .6989 L .408 .033 0 r
F
.64499 .69156 m .64641 .68763 L .62089 .69479 L F
.45522 .41914 m .44123 .41556 L .44071 .41808 L 1 .936 0 r
F
.45522 .41914 m .4555 .41658 L .44123 .41556 L F
.4141 .47639 m .39766 .47053 L .39717 .47317 L 1 .886 0 r
F
.41373 .47904 m .4141 .47639 L .39717 .47317 L 1 .879 0 r
F
.55842 .46013 m .54145 .46112 L .54198 .46384 L .769 .502 0 r
F
.55906 .46283 m .55842 .46013 L .54198 .46384 L .767 .494 0 r
F
.43844 .43114 m .42418 .42666 L .42351 .4292 L 1 .951 0 r
F
.43844 .43114 m .43891 .42856 L .42418 .42666 L F
.56136 .47368 m .54392 .47471 L .54436 .47744 L .759 .458 0 r
F
.56136 .47368 m .56082 .47097 L .54392 .47471 L F
.41573 .46576 m .39987 .46 L .39929 .46263 L 1 .913 0 r
F
.41573 .46576 m .41618 .46311 L .39987 .46 L F
.5478 .52015 m .52896 .52047 L .52903 .52308 L .789 .36 0 r
F
.5478 .52015 m .54771 .51754 L .52896 .52047 L F
.67866 .6558 m .65478 .65918 L .65374 .66333 L .379 .032 0 r
F
.67866 .6558 m .68002 .65171 L .65478 .65918 L F
.55776 .45742 m .54089 .45841 L .54145 .46112 L .771 .511 0 r
F
.55842 .46013 m .55776 .45742 L .54145 .46112 L .769 .502 0 r
F
.41373 .47904 m .39717 .47317 L .39669 .47581 L 1 .879 0 r
F
.41339 .4817 m .41373 .47904 L .39669 .47581 L 1 .871 0 r
F
.42934 .52075 m .41056 .51568 L .41047 .51822 L 1 .7 0 r
F
.4293 .52327 m .42934 .52075 L .41047 .51822 L 1 .685 0 r
F
.56188 .4764 m .54436 .47744 L .54477 .48016 L .757 .449 0 r
F
.56188 .4764 m .56136 .47368 L .54436 .47744 L F
.60294 .8592 m .57188 .8597 L .5701 .86316 L .456 .011 0 r
F
.60294 .8592 m .60531 .85569 L .57188 .8597 L F
.71121 .19199 m .70413 .19793 L .70814 .20369 L .003 .045 0 r
F
.71121 .19199 m .70757 .18588 L .70413 .19793 L F
.41618 .46311 m .40048 .45738 L .39987 .46 L 1 .92 0 r
F
.41618 .46311 m .41665 .46046 L .40048 .45738 L F
.5318 .42389 m .51642 .42389 L .51702 .42652 L .848 .668 0 r
F
.53257 .42652 m .5318 .42389 L .51702 .42652 L .846 .661 0 r
F
.46868 .55173 m .46869 .54927 L .44832 .54857 L 1 .517 0 r
F
.48907 .55153 m .46869 .54927 L .46868 .55173 L .974 .46 0 r
F
.48907 .55153 m .48911 .54907 L .46869 .54927 L F
.55708 .45472 m .54032 .4557 L .54089 .45841 L .773 .52 0 r
F
.55776 .45742 m .55708 .45472 L .54089 .45841 L .771 .511 0 r
F
.47017 .41432 m .45608 .41152 L .45578 .41405 L 1 .903 0 r
F
.47017 .41432 m .47021 .41176 L .45608 .41152 L F
.41339 .4817 m .39669 .47581 L .39624 .47845 L 1 .871 0 r
F
.41306 .48435 m .41339 .4817 L .39624 .47845 L 1 .864 0 r
F
.46793 .62155 m .46792 .61915 L .44446 .61856 L .958 .24 0 r
F
.49118 .62095 m .46792 .61915 L .46793 .62155 L .88 .158 0 r
F
.49118 .62095 m .49136 .6186 L .46792 .61915 L F
.82677 .68352 m .80146 .69101 L .79951 .69695 L .171 0 0 r
F
.82677 .68352 m .82892 .67743 L .80146 .69101 L F
.56237 .47911 m .54477 .48016 L .54517 .48288 L .755 .44 0 r
F
.56237 .47911 m .56188 .4764 L .54477 .48016 L F
.41665 .46046 m .4011 .45476 L .40048 .45738 L 1 .926 0 r
F
.41665 .46046 m .41713 .45782 L .4011 .45476 L F
.41829 .44969 m .40335 .44409 L .40261 .44669 L 1 .955 0 r
F
.41829 .44969 m .41886 .44705 L .40335 .44409 L F
.79597 .22459 m .78361 .23739 L .78837 .24277 L .247 .168 0 r
F
.79597 .22459 m .79101 .21944 L .78361 .23739 L F
.48467 .41398 m .47021 .41198 L .47017 .41452 L 1 .864 0 r
F
.48467 .41398 m .48447 .41141 L .47021 .41198 L F
.54874 .52583 m .52955 .52605 L .5296 .52867 L .797 .36 0 r
F
.54874 .52583 m .54868 .5232 L .52955 .52605 L F
.39418 .86622 m .358 .85991 L .35988 .86349 L .871 .061 0 r
F
.39548 .86963 m .39418 .86622 L .35988 .86349 L .853 .058 0 r
F
.88164 .4231 m .86236 .43591 L .86391 .44265 L .12 .032 0 r
F
.88164 .4231 m .88004 .41633 L .86236 .43591 L F
.57206 .09187 m .56563 .09448 L .57259 .0969 L .365 .532 0 r
F
.57206 .09187 m .56515 .08973 L .56563 .09448 L F
.55637 .45203 m .53973 .453 L .54032 .4557 L .775 .528 0 r
F
.55708 .45472 m .55637 .45203 L .54032 .4557 L .773 .52 0 r
F
.41306 .48435 m .39624 .47845 L .39581 .48109 L 1 .864 0 r
F
.41275 .487 m .41306 .48435 L .39581 .48109 L 1 .856 0 r
F
.56283 .48183 m .54517 .48288 L .54555 .4856 L .752 .43 0 r
F
.56283 .48183 m .56237 .47911 L .54517 .48288 L F
.87726 .58663 m .85291 .59647 L .85225 .60316 L .144 .006 0 r
F
.87726 .58663 m .87796 .5798 L .85291 .59647 L F
.52957 .54414 m .50967 .54349 L .50964 .54603 L .857 .372 0 r
F
.52957 .54414 m .52961 .5416 L .50967 .54349 L F
.38638 .50396 m .36801 .49675 L .36782 .49957 L .613 .847 0 r
F
.3863 .50673 m .38638 .50396 L .36782 .49957 L 1 .77 0 r
F
.53698 .61173 m .51506 .61216 L .5147 .61455 L .707 .065 0 r
F
.53698 .61173 m .53754 .60936 L .51506 .61216 L F
.41713 .45782 m .40175 .45214 L .4011 .45476 L 1 .932 0 r
F
.41713 .45782 m .41763 .45518 L .40175 .45214 L F
.11393 .65815 m .08347 .63669 L .08488 .64334 L 1 .601 0 r
F
.11531 .66459 m .11393 .65815 L .08488 .64334 L 1 .579 0 r
F
.70871 .29573 m .7067 .29602 L .70672 .30316 L 0 0 0 r
F
.70871 .29573 m .70854 .28886 L .7067 .29602 L F
.53129 .421 m .51592 .42112 L .51653 .42375 L .863 .687 0 r
F
.53208 .42362 m .53129 .421 L .51653 .42375 L .861 .68 0 r
F
.56012 .6006 m .5391 .60205 L .5386 .60452 L .616 .057 0 r
F
.56012 .6006 m .5608 .59814 L .5391 .60205 L F
.32371 .80394 m .28677 .79912 L .28907 .8034 L 1 .195 0 r
F
.32553 .80813 m .32371 .80394 L .28907 .8034 L 1 .173 0 r
F
.55564 .44934 m .53913 .4503 L .53973 .453 L .777 .537 0 r
F
.55637 .45203 m .55564 .44934 L .53973 .453 L .775 .528 0 r
F
.57188 .09257 m .56549 .09504 L .57241 .09758 L .355 .518 0 r
F
.57188 .09257 m .56496 .09051 L .56549 .09504 L F
.45529 .4194 m .44138 .41587 L .44086 .41838 L 1 .937 0 r
F
.45529 .4194 m .45557 .41685 L .44138 .41587 L F
.52902 .54098 m .50941 .54049 L .50938 .543 L .847 .361 0 r
F
.52902 .54098 m .52907 .53847 L .50941 .54049 L F
.41333 .37535 m .40533 .37396 L .40367 .3763 L 1 1 0 r
F
.41333 .37535 m .41469 .37272 L .40533 .37396 L F
.42046 .60907 m .39743 .60337 L .39781 .60609 L 1 .442 0 r
F
.42075 .6117 m .42046 .60907 L .39781 .60609 L 1 .427 0 r
F
.41275 .487 m .39581 .48109 L .39541 .48373 L 1 .856 0 r
F
.41245 .48964 m .41275 .487 L .39541 .48373 L 1 .848 0 r
F
.56808 .87655 m .53571 .87578 L .53447 .87914 L .54 .02 0 r
F
.56808 .87655 m .56994 .87315 L .53571 .87578 L F
.56328 .48454 m .54555 .4856 L .5459 .48831 L .75 .421 0 r
F
.56328 .48454 m .56283 .48183 L .54555 .4856 L F
.71298 .6091 m .6899 .61369 L .689 .61801 L .332 .03 0 r
F
.71298 .6091 m .71411 .60474 L .6899 .61369 L F
.47017 .41452 m .45614 .4118 L .45585 .41432 L 1 .907 0 r
F
.47017 .41452 m .47021 .41198 L .45614 .4118 L F
.51401 .41328 m .49914 .4127 L .49957 .41529 L .922 .765 0 r
F
.51466 .41588 m .51401 .41328 L .49957 .41529 L .921 .758 0 r
F
.46866 .55205 m .4483 .54864 L .44828 .5512 L 1 .554 0 r
F
.46865 .55456 m .46866 .55205 L .44828 .5512 L 1 .543 0 r
F
.48915 .55451 m .46866 .55205 L .46865 .55456 L .985 .479 0 r
F
.48915 .55451 m .48919 .55202 L .46866 .55205 L F
.51392 .41343 m .49914 .4127 L .49957 .4153 L .91 .754 0 r
F
.51456 .41603 m .51392 .41343 L .49957 .4153 L .909 .748 0 r
F
.35303 .52414 m .33569 .51466 L .33534 .51782 L 1 .897 0 r
F
.35279 .52731 m .35303 .52414 L .33534 .51782 L 1 .887 0 r
F
.46512 .88447 m .46506 .88124 L .43012 .88074 L .733 .043 0 r
F
.49939 .88393 m .46506 .88124 L .46512 .88447 L .674 .036 0 r
F
.49939 .88393 m .49999 .8807 L .46506 .88124 L F
.1208 .64778 m .09168 .62637 L .09286 .63292 L 1 .63 0 r
F
.12199 .65415 m .1208 .64778 L .09286 .63292 L 1 .608 0 r
F
.41763 .45518 m .40242 .44954 L .40175 .45214 L 1 .938 0 r
F
.41763 .45518 m .41815 .45254 L .40242 .44954 L F
.5092 .55042 m .48911 .54907 L .48907 .55153 L .91 .397 0 r
F
.5092 .55042 m .50927 .54796 L .48911 .54907 L F
.43891 .42856 m .42487 .42413 L .42418 .42666 L 1 .957 0 r
F
.43891 .42856 m .43938 .426 L .42487 .42413 L F
.54786 .52275 m .52903 .52308 L .52907 .52567 L .786 .35 0 r
F
.54786 .52275 m .5478 .52015 L .52903 .52308 L F
.72966 .80466 m .70099 .80796 L .69822 .8127 L .314 0 0 r
F
.72966 .80466 m .73285 .79977 L .70099 .80796 L F
.55489 .44665 m .5385 .4476 L .53913 .4503 L .779 .545 0 r
F
.55564 .44934 m .55489 .44665 L .53913 .4503 L .777 .537 0 r
F
.67271 .43099 m .66228 .43529 L .66114 .43973 L 0 0 0 r
F
.67271 .43099 m .67397 .42652 L .66228 .43529 L F
.55831 .46298 m .54154 .46394 L .54205 .46664 L .754 .479 0 r
F
.5589 .46567 m .54205 .46664 L .54253 .46935 L .752 .47 0 r
F
.5589 .46567 m .55831 .46298 L .54205 .46664 L F
.7612 .44746 m .74749 .45558 L .74766 .46071 L .056 .006 0 r
F
.7612 .44746 m .76083 .44237 L .74749 .45558 L F
.55947 .46836 m .54253 .46935 L .54299 .47205 L .75 .461 0 r
F
.55947 .46836 m .5589 .46567 L .54253 .46935 L F
.55769 .4603 m .54102 .46124 L .54154 .46394 L .756 .488 0 r
F
.55831 .46298 m .55769 .4603 L .54154 .46394 L .754 .479 0 r
F
.53101 .42128 m .51581 .42126 L .51642 .42389 L .849 .675 0 r
F
.5318 .42389 m .53101 .42128 L .51642 .42389 L .848 .668 0 r
F
.50949 .55356 m .48919 .55202 L .48915 .55451 L .92 .412 0 r
F
.50949 .55356 m .50955 .55106 L .48919 .55202 L F
.37277 .57018 m .35236 .56167 L .35253 .56472 L 1 .703 0 r
F
.37296 .57318 m .37277 .57018 L .35253 .56472 L 1 .69 0 r
F
.56002 .47105 m .54299 .47205 L .54343 .47475 L .748 .452 0 r
F
.56002 .47105 m .55947 .46836 L .54299 .47205 L F
.41245 .48964 m .39541 .48373 L .39502 .48636 L 1 .848 0 r
F
.41218 .49228 m .41245 .48964 L .39502 .48636 L 1 .84 0 r
F
.56369 .48725 m .5459 .48831 L .54624 .49103 L .748 .412 0 r
F
.56369 .48725 m .56328 .48454 L .5459 .48831 L F
.39641 .59504 m .37432 .58791 L .37468 .5908 L 1 .558 0 r
F
.39673 .59784 m .39641 .59504 L .37468 .5908 L 1 .544 0 r
F
.40653 .52857 m .38628 .52298 L .38633 .52563 L 1 .599 0 r
F
.40667 .5311 m .40653 .52857 L .38633 .52563 L 1 .596 0 r
F
.55705 .45761 m .54048 .45854 L .54102 .46124 L .758 .497 0 r
F
.55769 .4603 m .55705 .45761 L .54102 .46124 L .756 .488 0 r
F
.62998 .52667 m .61353 .53081 L .61295 .53391 L .32 .029 0 r
F
.62998 .52667 m .63065 .52357 L .61353 .53081 L F
.88758 .42935 m .86758 .44229 L .86918 .4491 L .135 .036 0 r
F
.88758 .42935 m .88586 .42251 L .86758 .44229 L F
.65139 .4825 m .63762 .48704 L .63697 .49057 L .192 .004 0 r
F
.65139 .4825 m .65213 .47896 L .63762 .48704 L F
.60704 .56044 m .58862 .56379 L .58801 .56661 L .406 .04 0 r
F
.60704 .56044 m .60777 .55761 L .58862 .56379 L F
.56054 .47374 m .54343 .47475 L .54385 .47746 L .746 .442 0 r
F
.56054 .47374 m .56002 .47105 L .54343 .47475 L F
.57899 .09385 m .57259 .0969 L .57949 .09941 L .373 .549 0 r
F
.57899 .09385 m .57206 .09187 L .57259 .0969 L F
.4555 .41658 m .44176 .41306 L .44123 .41556 L 1 .942 0 r
F
.4555 .41658 m .45578 .41405 L .44176 .41306 L F
.43168 .36368 m .42388 .36527 L .42253 .36768 L 1 1 0 r
F
.43168 .36368 m .43269 .36078 L .42388 .36527 L F
.44883 .38481 m .43269 .36078 L .43168 .36368 L .317 .072 0 r
F
.44821 .38709 m .44883 .38481 L .43168 .36368 L .329 .074 0 r
F
.41815 .45254 m .40311 .44694 L .40242 .44954 L 1 .945 0 r
F
.41815 .45254 m .41868 .44991 L .40311 .44694 L F
.55638 .45493 m .53992 .45585 L .54048 .45854 L .76 .505 0 r
F
.55705 .45761 m .55638 .45493 L .54048 .45854 L .758 .497 0 r
F
.08808 .51935 m .06619 .49433 L .0654 .50115 L 1 .886 0 r
F
.08747 .52609 m .08808 .51935 L .0654 .50115 L 1 .869 0 r
F
.80123 .22952 m .78911 .24222 L .7938 .24767 L .227 .135 0 r
F
.80123 .22952 m .79637 .22428 L .78911 .24222 L F
.55412 .44397 m .53786 .44492 L .5385 .4476 L .781 .553 0 r
F
.55489 .44665 m .55412 .44397 L .5385 .4476 L .779 .545 0 r
F
.40986 .3933 m .39997 .38953 L .3985 .39199 L 1 1 0 r
F
.40986 .3933 m .41104 .3906 L .39997 .38953 L F
.41686 .40701 m .40986 .3933 L .3985 .39199 L 1 .089 0 r
F
.43006 .40688 m .41104 .3906 L .40986 .3933 L .637 .395 0 r
F
.42928 .40929 m .40986 .3933 L .41686 .40701 L .648 .403 0 r
F
.42928 .40929 m .43006 .40688 L .40986 .3933 L F
.56103 .47644 m .54385 .47746 L .54425 .48016 L .744 .433 0 r
F
.56103 .47644 m .56054 .47374 L .54385 .47746 L F
.54879 .52844 m .5296 .52867 L .52964 .53128 L .794 .349 0 r
F
.54879 .52844 m .54874 .52583 L .5296 .52867 L F
.67774 .19286 m .67795 .18783 L .68162 .19412 L .786 .106 0 r
F
.67774 .19286 m .67514 .18546 L .67795 .18783 L F
.55569 .45226 m .53935 .45316 L .53992 .45585 L .762 .514 0 r
F
.55638 .45493 m .55569 .45226 L .53992 .45585 L .76 .505 0 r
F
.56408 .48996 m .54624 .49103 L .54656 .49374 L .745 .402 0 r
F
.56408 .48996 m .56369 .48725 L .54624 .49103 L F
.41218 .49228 m .39502 .48636 L .39466 .489 L 1 .84 0 r
F
.41192 .49492 m .41218 .49228 L .39466 .489 L 1 .832 0 r
F
.57872 .09481 m .57241 .09758 L .57924 .10028 L .348 .502 0 r
F
.57872 .09481 m .57188 .09257 L .57241 .09758 L F
.51395 .61921 m .49136 .6186 L .49118 .62095 L .791 .074 0 r
F
.51395 .61921 m .51433 .6169 L .49136 .6186 L F
.5615 .47913 m .54425 .48016 L .54464 .48286 L .741 .424 0 r
F
.5615 .47913 m .56103 .47644 L .54425 .48016 L F
.49906 .08635 m .49269 .08254 L .49994 .08381 L .782 .089 0 r
F
.53048 .41837 m .51529 .4185 L .51592 .42112 L .864 .694 0 r
F
.53129 .421 m .53048 .41837 L .51592 .42112 L .863 .687 0 r
F
.46868 .55173 m .44832 .54857 L .44834 .55103 L 1 .517 0 r
F
.46867 .55417 m .46868 .55173 L .44834 .55103 L 1 .507 0 r
F
.48902 .55396 m .46868 .55173 L .46867 .55417 L .972 .449 0 r
F
.48902 .55396 m .48907 .55153 L .46868 .55173 L F
.83146 .69367 m .80505 .70061 L .80305 .70666 L .194 0 0 r
F
.83146 .69367 m .83366 .68745 L .80505 .70061 L F
.47021 .41176 m .45637 .40901 L .45608 .41152 L 1 .909 0 r
F
.47021 .41176 m .47025 .40922 L .45637 .40901 L F
.41868 .44991 m .40383 .44435 L .40311 .44694 L 1 .951 0 r
F
.41868 .44991 m .41923 .44729 L .40383 .44435 L F
.55498 .44958 m .53875 .45047 L .53935 .45316 L .764 .523 0 r
F
.55569 .45226 m .55498 .44958 L .53935 .45316 L .762 .514 0 r
F
.3863 .50673 m .36782 .49957 L .36765 .50238 L 1 .77 0 r
F
.38625 .50948 m .3863 .50673 L .36765 .50238 L 1 .76 0 r
F
.43406 .81646 m .43359 .8125 L .40023 .81847 L .816 .071 0 r
F
.46594 .8088 m .43359 .8125 L .43406 .81646 L .743 .065 0 r
F
.46594 .8088 m .46592 .80479 L .43359 .8125 L F
.48447 .41141 m .47026 .40944 L .47021 .41198 L 1 .87 0 r
F
.48447 .41141 m .48427 .40885 L .47026 .40944 L F
.55333 .4413 m .53719 .44223 L .53786 .44492 L .782 .561 0 r
F
.55412 .44397 m .55333 .4413 L .53786 .44492 L .781 .553 0 r
F
.80084 .22982 m .78837 .24277 L .79304 .24822 L .239 .149 0 r
F
.80084 .22982 m .79597 .22459 L .78837 .24277 L F
.09562 .51203 m .07226 .48744 L .0716 .49415 L 1 .885 0 r
F
.09513 .51863 m .09562 .51203 L .0716 .49415 L 1 .869 0 r
F
.5295 .54667 m .50964 .54603 L .5096 .54855 L .855 .362 0 r
F
.5295 .54667 m .52957 .54414 L .50964 .54603 L F
.56195 .48181 m .54464 .48286 L .545 .48556 L .739 .414 0 r
F
.56195 .48181 m .5615 .47913 L .54464 .48286 L F
.7144 .19846 m .70814 .20369 L .7119 .20961 L 0 .023 0 r
F
.7144 .19846 m .71121 .19199 L .70814 .20369 L F
.74415 .54391 m .7236 .55062 L .72307 .55525 L .249 .024 0 r
F
.74415 .54391 m .74474 .53919 L .7236 .55062 L F
.54791 .52534 m .52907 .52567 L .52911 .52826 L .783 .34 0 r
F
.54791 .52534 m .54786 .52275 L .52907 .52567 L F
.56445 .49267 m .54656 .49374 L .54685 .49645 L .743 .392 0 r
F
.56445 .49267 m .56408 .48996 L .54656 .49374 L F
.35279 .52731 m .33534 .51782 L .33504 .52098 L 1 .887 0 r
F
.35259 .53048 m .35279 .52731 L .33504 .52098 L 1 .876 0 r
F
.43938 .426 m .42557 .42162 L .42487 .42413 L 1 .963 0 r
F
.43938 .426 m .43987 .42345 L .42557 .42162 L F
.18205 .71075 m .14769 .69541 L .14985 .7011 L 1 .458 0 r
F
.18404 .7162 m .18205 .71075 L .14985 .7011 L 1 .438 0 r
F
.41192 .49492 m .39466 .489 L .39432 .49162 L 1 .832 0 r
F
.41168 .49754 m .41192 .49492 L .39432 .49162 L 1 .824 0 r
F
.52896 .54348 m .50938 .543 L .50933 .54549 L .844 .35 0 r
F
.52896 .54348 m .52902 .54098 L .50938 .543 L F
.45557 .41685 m .4419 .41338 L .44138 .41587 L 1 .943 0 r
F
.45557 .41685 m .45585 .41432 L .4419 .41338 L F
.55425 .44691 m .53814 .44778 L .53875 .45047 L .765 .531 0 r
F
.55498 .44958 m .55425 .44691 L .53875 .45047 L .764 .523 0 r
F
.07611 .53432 m .05224 .50881 L .05179 .51584 L 1 .847 0 r
F
.0758 .54124 m .07611 .53432 L .05179 .51584 L 1 .829 0 r
F
.5302 .41866 m .51519 .41864 L .51581 .42126 L .85 .682 0 r
F
.53101 .42128 m .5302 .41866 L .51581 .42126 L .849 .675 0 r
F
.51336 .41068 m .4987 .41011 L .49914 .4127 L .924 .772 0 r
F
.51401 .41328 m .51336 .41068 L .49914 .4127 L .922 .765 0 r
F
.51326 .41083 m .4987 .41012 L .49914 .4127 L .912 .761 0 r
F
.51392 .41343 m .51326 .41083 L .49914 .4127 L .91 .754 0 r
F
.58587 .09593 m .57949 .09941 L .58633 .10206 L .376 .551 0 r
F
.58587 .09593 m .57899 .09385 L .57949 .09941 L F
.46865 .55456 m .44828 .5512 L .44827 .55375 L 1 .543 0 r
F
.46864 .55705 m .46865 .55456 L .44827 .55375 L 1 .532 0 r
F
.48911 .55699 m .46865 .55456 L .46864 .55705 L .982 .468 0 r
F
.48911 .55699 m .48915 .55451 L .46865 .55456 L F
.56237 .4845 m .545 .48556 L .54534 .48825 L .737 .404 0 r
F
.56237 .4845 m .56195 .48181 L .545 .48556 L F
.41923 .44729 m .40456 .44177 L .40383 .44435 L 1 .956 0 r
F
.41923 .44729 m .4198 .44468 L .40456 .44177 L F
.55251 .43863 m .53652 .43955 L .53719 .44223 L .784 .57 0 r
F
.55333 .4413 m .55251 .43863 L .53719 .44223 L .782 .561 0 r
F
.47021 .41198 m .45643 .4093 L .45614 .4118 L 1 .913 0 r
F
.47021 .41198 m .47026 .40944 L .45643 .4093 L F
.58313 .5855 m .56335 .58794 L .56274 .59054 L .513 .048 0 r
F
.58313 .5855 m .58389 .5829 L .56335 .58794 L F
.53322 .88239 m .49999 .8807 L .49939 .88393 L .604 .027 0 r
F
.53322 .88239 m .53447 .87914 L .49999 .8807 L F
.55349 .44425 m .5375 .44511 L .53814 .44778 L .767 .54 0 r
F
.55425 .44691 m .55349 .44425 L .53814 .44778 L .765 .531 0 r
F
.50912 .55286 m .48907 .55153 L .48902 .55396 L .907 .386 0 r
F
.50912 .55286 m .5092 .55042 L .48907 .55153 L F
.58267 .74678 m .55758 .75179 L .55672 .75596 L .449 .034 0 r
F
.58267 .74678 m .58389 .7429 L .55758 .75179 L F
.77469 .75338 m .74796 .75876 L .74536 .76398 L .234 0 0 r
F
.77469 .75338 m .7776 .74801 L .74796 .75876 L F
.4483 .54864 m .42815 .54468 L .42808 .54732 L 1 .618 0 r
F
.44828 .5512 m .4483 .54864 L .42808 .54732 L 1 .606 0 r
F
.56479 .49538 m .54685 .49645 L .54713 .49915 L .74 .382 0 r
F
.56479 .49538 m .56445 .49267 L .54685 .49645 L F
.54881 .53105 m .52964 .53128 L .52965 .53388 L .791 .339 0 r
F
.54881 .53105 m .54879 .52844 L .52964 .53128 L F
.2702 .8277 m .23377 .81611 L .23677 .8208 L 1 .135 0 r
F
.27281 .83217 m .2702 .8277 L .23677 .8208 L 1 .109 0 r
F
.50941 .55603 m .48915 .55451 L .48911 .55699 L .917 .401 0 r
F
.50941 .55603 m .50949 .55356 L .48915 .55451 L F
.58539 .09752 m .57924 .10028 L .58599 .10318 L .309 .425 0 r
F
.58539 .09752 m .57872 .09481 L .57924 .10028 L F
.41168 .49754 m .39432 .49162 L .39401 .49425 L 1 .824 0 r
F
.41147 .50016 m .41168 .49754 L .39401 .49425 L 1 .815 0 r
F
.56277 .48719 m .54534 .48825 L .54566 .49095 L .734 .395 0 r
F
.56277 .48719 m .56237 .4845 L .54534 .48825 L F
.61242 .7227 m .58822 .72677 L .58722 .73089 L .418 .031 0 r
F
.61242 .7227 m .6138 .71885 L .58822 .72677 L F
.41469 .37272 m .40701 .37167 L .40533 .37396 L 1 1 0 r
F
.41469 .37272 m .41607 .37013 L .40701 .37167 L F
.44832 .54857 m .42828 .54448 L .42831 .54697 L 1 .581 0 r
F
.44834 .55103 m .44832 .54857 L .42831 .54697 L 1 .571 0 r
F
.68324 .83519 m .65381 .83727 L .65116 .84149 L .364 0 0 r
F
.68324 .83519 m .68638 .83086 L .65381 .83727 L F
.52965 .41576 m .51466 .41588 L .51529 .4185 L .866 .701 0 r
F
.53048 .41837 m .52965 .41576 L .51529 .4185 L .864 .694 0 r
F
.55386 .76801 m .52736 .77372 L .52671 .77788 L .499 .039 0 r
F
.55386 .76801 m .55486 .76407 L .52736 .77372 L F
.55167 .43597 m .53582 .43688 L .53652 .43955 L .786 .578 0 r
F
.55251 .43863 m .55167 .43597 L .53652 .43955 L .784 .57 0 r
F
.4198 .44468 m .40531 .4392 L .40456 .44177 L 1 .962 0 r
F
.4198 .44468 m .42038 .44207 L .40531 .4392 L F
.55271 .44159 m .53685 .44243 L .5375 .44511 L .769 .548 0 r
F
.55349 .44425 m .55271 .44159 L .5375 .44511 L .767 .54 0 r
F
.23383 .75899 m .19767 .74781 L .20022 .75289 L 1 .332 0 r
F
.23608 .76385 m .23383 .75899 L .20022 .75289 L 1 .312 0 r
F
.44446 .61856 m .42106 .61429 L .42138 .61685 L 1 .33 0 r
F
.44464 .62102 m .44446 .61856 L .42138 .61685 L 1 .313 0 r
F
.46793 .62155 m .44446 .61856 L .44464 .62102 L .958 .24 0 r
F
.31493 .85034 m .27823 .84087 L .28104 .84509 L .99 .079 0 r
F
.31726 .85436 m .31493 .85034 L .28104 .84509 L .973 .076 0 r
F
.41104 .3906 m .40147 .3871 L .39997 .38953 L 1 1 0 r
F
.41104 .3906 m .41223 .38793 L .40147 .3871 L F
.43086 .40448 m .41223 .38793 L .41104 .3906 L .627 .386 0 r
F
.43006 .40688 m .43086 .40448 L .41104 .3906 L .637 .395 0 r
F
.80602 .23483 m .7938 .24767 L .7984 .25319 L .219 .118 0 r
F
.80602 .23483 m .80123 .22952 L .7938 .24767 L F
.40667 .5311 m .38633 .52563 L .3864 .52826 L 1 .596 0 r
F
.4068 .53361 m .40667 .5311 L .3864 .52826 L F
.49625 .79978 m .46592 .80479 L .46594 .8088 L .655 .055 0 r
F
.49625 .79978 m .49662 .79578 L .46592 .80479 L F
.17243 .73315 m .13955 .71563 L .14187 .72153 L 1 .415 0 r
F
.17461 .73883 m .17243 .73315 L .14187 .72153 L 1 .39 0 r
F
.88311 .4299 m .86391 .44265 L .86534 .4494 L .111 .029 0 r
F
.88311 .4299 m .88164 .4231 L .86391 .44265 L F
.38625 .50948 m .36765 .50238 L .36751 .50517 L 1 .76 0 r
F
.38622 .51222 m .38625 .50948 L .36751 .50517 L 1 .75 0 r
F
.56314 .48987 m .54566 .49095 L .54596 .49363 L .732 .385 0 r
F
.56314 .48987 m .56277 .48719 L .54566 .49095 L F
.56511 .49808 m .54713 .49915 L .54739 .50185 L .738 .372 0 r
F
.56511 .49808 m .56479 .49538 L .54713 .49915 L F
.54793 .52791 m .52911 .52826 L .52912 .53083 L .781 .329 0 r
F
.54793 .52791 m .54791 .52534 L .52911 .52826 L F
.63975 .84688 m .60992 .84838 L .60764 .85208 L .4 .002 0 r
F
.63975 .84688 m .64258 .84309 L .60992 .84838 L F
.37296 .57318 m .35253 .56472 L .35272 .56776 L 1 .69 0 r
F
.37318 .57617 m .37296 .57318 L .35272 .56776 L 1 .677 0 r
F
.5253 .78593 m .49698 .79167 L .49662 .79578 L .57 .046 0 r
F
.5253 .78593 m .52602 .78196 L .49698 .79167 L F
.59263 .0983 m .58633 .10206 L .59308 .10486 L .361 .517 0 r
F
.59263 .0983 m .58587 .09593 L .58633 .10206 L F
.43987 .42345 m .42629 .41912 L .42557 .42162 L 1 .969 0 r
F
.43987 .42345 m .44036 .42091 L .42629 .41912 L F
.69425 .37607 m .6877 .3794 L .68605 .38533 L 0 0 0 r
F
.69425 .37607 m .69589 .37015 L .6877 .3794 L F
.52938 .41606 m .51456 .41603 L .51519 .41864 L .852 .689 0 r
F
.5302 .41866 m .52938 .41606 L .51519 .41864 L .85 .682 0 r
F
.43269 .36078 m .42526 .3629 L .42388 .36527 L 1 1 0 r
F
.43269 .36078 m .43371 .35787 L .42526 .3629 L F
.44946 .38256 m .43371 .35787 L .43269 .36078 L 1 .301 0 r
F
.44883 .38481 m .44946 .38256 L .43269 .36078 L .317 .072 0 r
F
.22441 .78594 m .18958 .77162 L .19239 .77686 L 1 .261 0 r
F
.22695 .79095 m .22441 .78594 L .19239 .77686 L 1 .235 0 r
F
.41147 .50016 m .39401 .49425 L .39372 .49686 L 1 .815 0 r
F
.41127 .50278 m .41147 .50016 L .39372 .49686 L 1 .806 0 r
F
.35259 .53048 m .33504 .52098 L .33476 .52414 L 1 .876 0 r
F
.35241 .53364 m .35259 .53048 L .33476 .52414 L 1 .866 0 r
F
.47025 .40922 m .45667 .40652 L .45637 .40901 L 1 .915 0 r
F
.47025 .40922 m .4703 .4067 L .45667 .40652 L F
.46867 .55417 m .44834 .55103 L .44836 .55347 L 1 .507 0 r
F
.46866 .55658 m .46867 .55417 L .44836 .55347 L 1 .497 0 r
F
.48897 .55638 m .46867 .55417 L .46866 .55658 L .97 .439 0 r
F
.48897 .55638 m .48902 .55396 L .46867 .55417 L F
.5519 .43894 m .53618 .43976 L .53685 .44243 L .771 .556 0 r
F
.55271 .44159 m .5519 .43894 L .53685 .44243 L .769 .548 0 r
F
.48427 .40885 m .4703 .40692 L .47026 .40944 L 1 .877 0 r
F
.48427 .40885 m .48406 .4063 L .4703 .40692 L F
.38816 .40166 m .38961 .39897 L .37878 .39653 L 1 1 0 r
F
.52942 .54919 m .5096 .54855 L .50955 .55106 L .852 .351 0 r
F
.52942 .54919 m .5295 .54667 L .5096 .54855 L F
.50586 .08925 m .49994 .08381 L .50707 .08591 L .881 .067 0 r
F
.50586 .08925 m .49906 .08635 L .49994 .08381 L F
.13122 .63613 m .1007 .61611 L .10192 .62244 L 1 .633 0 r
F
.13245 .64223 m .13122 .63613 L .10192 .62244 L 1 .613 0 r
F
.80562 .23513 m .79304 .24822 L .79762 .25374 L .231 .131 0 r
F
.80562 .23513 m .80084 .22982 L .79304 .24822 L F
.55081 .43331 m .53511 .43422 L .53582 .43688 L .788 .586 0 r
F
.55167 .43597 m .55081 .43331 L .53582 .43688 L .786 .578 0 r
F
.36365 .81449 m .32742 .81224 L .32935 .81627 L .958 .139 0 r
F
.36508 .81847 m .36365 .81449 L .32935 .81627 L .948 .116 0 r
F
.86991 .58471 m .84724 .59475 L .84646 .60129 L .105 0 0 r
F
.86991 .58471 m .87076 .57805 L .84724 .59475 L F
.42038 .44207 m .40609 .43664 L .40531 .4392 L 1 .968 0 r
F
.42038 .44207 m .42098 .43948 L .40609 .43664 L F
.76152 .45254 m .74766 .46071 L .7478 .46581 L .059 .006 0 r
F
.76152 .45254 m .7612 .44746 L .74766 .46071 L F
.46794 .62391 m .46793 .62155 L .44464 .62102 L .951 .223 0 r
F
.49099 .62326 m .46793 .62155 L .46794 .62391 L .872 .141 0 r
F
.49099 .62326 m .49118 .62095 L .46793 .62155 L F
.52888 .54596 m .50933 .54549 L .50927 .54796 L .842 .339 0 r
F
.52888 .54596 m .52896 .54348 L .50933 .54549 L F
.45585 .41432 m .44243 .4109 L .4419 .41338 L 1 .949 0 r
F
.45585 .41432 m .45614 .4118 L .44243 .4109 L F
.51269 .40809 m .49825 .40754 L .4987 .41011 L .926 .778 0 r
F
.51336 .41068 m .51269 .40809 L .4987 .41011 L .924 .772 0 r
F
.5126 .40825 m .49825 .40754 L .4987 .41012 L .913 .768 0 r
F
.51326 .41083 m .5126 .40825 L .4987 .41012 L .912 .761 0 r
F
.56348 .49254 m .54596 .49363 L .54624 .49632 L .729 .375 0 r
F
.56348 .49254 m .56314 .48987 L .54596 .49363 L F
.67724 .65985 m .65374 .66333 L .65265 .66746 L .37 .029 0 r
F
.67724 .65985 m .67866 .6558 L .65374 .66333 L F
.6293 .52975 m .61295 .53391 L .61236 .53698 L .317 .028 0 r
F
.6293 .52975 m .62998 .52667 L .61295 .53391 L F
.42075 .6117 m .39781 .60609 L .39821 .60878 L 1 .427 0 r
F
.42106 .61429 m .42075 .6117 L .39821 .60878 L 1 .411 0 r
F
.68017 .20018 m .68162 .19412 L .68504 .20053 L .853 .121 0 r
F
.68017 .20018 m .67774 .19286 L .68162 .19412 L F
.39673 .59784 m .37468 .5908 L .37506 .59366 L 1 .544 0 r
F
.39707 .60062 m .39673 .59784 L .37506 .59366 L 1 .53 0 r
F
.5654 .50077 m .54739 .50185 L .54762 .50454 L .735 .362 0 r
F
.5654 .50077 m .56511 .49808 L .54739 .50185 L F
.54881 .53364 m .52965 .53388 L .52966 .53646 L .788 .328 0 r
F
.54881 .53364 m .54881 .53105 L .52965 .53388 L F
.55941 .60304 m .5386 .60452 L .53807 .60696 L .608 .055 0 r
F
.55941 .60304 m .56012 .6006 L .5386 .60452 L F
.59181 .10089 m .58599 .10318 L .59262 .10627 L .228 .277 0 r
F
.59181 .10089 m .58539 .09752 L .58599 .10318 L F
.65067 .48598 m .63697 .49057 L .63634 .49406 L .19 .004 0 r
F
.65067 .48598 m .65139 .4825 L .63697 .49057 L F
.46864 .55705 m .44827 .55375 L .44827 .55628 L 1 .532 0 r
F
.46863 .55953 m .46864 .55705 L .44827 .55628 L 1 .52 0 r
F
.48907 .55946 m .46864 .55705 L .46863 .55953 L .979 .457 0 r
F
.48907 .55946 m .48911 .55699 L .46864 .55705 L F
.44828 .5512 m .42808 .54732 L .42804 .54993 L 1 .606 0 r
F
.44827 .55375 m .44828 .5512 L .42804 .54993 L 1 .594 0 r
F
.53642 .61405 m .5147 .61455 L .51433 .6169 L .698 .063 0 r
F
.53642 .61405 m .53698 .61173 L .5147 .61455 L F
.55108 .4363 m .53549 .4371 L .53618 .43976 L .772 .565 0 r
F
.5519 .43894 m .55108 .4363 L .53618 .43976 L .771 .556 0 r
F
.60628 .56324 m .58801 .56661 L .58737 .5694 L .4 .039 0 r
F
.60628 .56324 m .60704 .56044 L .58801 .56661 L F
.47026 .40944 m .45673 .40681 L .45643 .4093 L 1 .92 0 r
F
.47026 .40944 m .4703 .40692 L .45673 .40681 L F
.88918 .43621 m .86918 .4491 L .87068 .45592 L .127 .033 0 r
F
.88918 .43621 m .88758 .42935 L .86918 .4491 L F
.41127 .50278 m .39372 .49686 L .39345 .49948 L 1 .806 0 r
F
.41109 .50538 m .41127 .50278 L .39345 .49948 L 1 .797 0 r
F
.52881 .41315 m .51401 .41328 L .51466 .41588 L .868 .708 0 r
F
.52965 .41576 m .52881 .41315 L .51466 .41588 L .866 .701 0 r
F
.64352 .69545 m .61984 .6989 L .61875 .70297 L .393 .029 0 r
F
.64352 .69545 m .64499 .69156 L .61984 .6989 L F
.46522 .87803 m .46516 .8749 L .43077 .87446 L .723 .041 0 r
F
.49893 .87738 m .46516 .8749 L .46522 .87803 L .661 .033 0 r
F
.49893 .87738 m .49953 .87427 L .46516 .8749 L F
.56642 .86977 m .53466 .86933 L .53343 .87256 L .519 .016 0 r
F
.56642 .86977 m .56828 .86651 L .53466 .86933 L F
.71709 .20532 m .7119 .20961 L .7154 .21569 L 0 0 0 r
F
.71709 .20532 m .7144 .19846 L .7119 .20961 L F
.71181 .61343 m .689 .61801 L .68805 .62231 L .326 .027 0 r
F
.71181 .61343 m .71298 .6091 L .689 .61801 L F
.54993 .43066 m .53437 .43156 L .53511 .43422 L .79 .593 0 r
F
.55081 .43331 m .54993 .43066 L .53511 .43422 L .788 .586 0 r
F
.50903 .55528 m .48902 .55396 L .48897 .55638 L .905 .375 0 r
F
.50903 .55528 m .50912 .55286 L .48902 .55396 L F
.5638 .49522 m .54624 .49632 L .54649 .49899 L .727 .365 0 r
F
.5638 .49522 m .56348 .49254 L .54624 .49632 L F
.70867 .30257 m .70672 .30316 L .70649 .31027 L 0 0 0 r
F
.70867 .30257 m .70871 .29573 L .70672 .30316 L F
.42098 .43948 m .40688 .43409 L .40609 .43664 L 1 .974 0 r
F
.42098 .43948 m .42159 .43689 L .40688 .43409 L F
.50933 .55849 m .48911 .55699 L .48907 .55946 L .914 .39 0 r
F
.50933 .55849 m .50941 .55603 L .48911 .55699 L F
.6715 .43535 m .66114 .43973 L .66005 .44406 L 0 0 0 r
F
.6715 .43535 m .67271 .43099 L .66114 .43973 L F
.59922 .10112 m .59263 .0983 L .59308 .10486 L .321 .437 0 r
F
.44834 .55103 m .42831 .54697 L .42835 .54943 L 1 .571 0 r
F
.44836 .55347 m .44834 .55103 L .42835 .54943 L 1 .561 0 r
F
.54793 .53048 m .52912 .53083 L .52912 .53339 L .778 .318 0 r
F
.54793 .53048 m .54793 .52791 L .52912 .53083 L F
.87643 .59344 m .85225 .60316 L .85149 .60983 L .137 .003 0 r
F
.87643 .59344 m .87726 .58663 L .85225 .60316 L F
.37687 .44452 m .3631 .43677 L .36211 .43962 L 1 1 0 r
F
.37687 .44452 m .37769 .44159 L .3631 .43677 L F
.72481 .79857 m .69707 .80236 L .69429 .80694 L .293 0 0 r
F
.72481 .79857 m .728 .79385 L .69707 .80236 L F
.37769 .44159 m .36414 .43392 L .3631 .43677 L 1 1 0 r
F
.37769 .44159 m .37854 .43868 L .36414 .43392 L F
.52854 .41346 m .51392 .41343 L .51456 .41603 L .854 .696 0 r
F
.52938 .41606 m .52854 .41346 L .51456 .41603 L .852 .689 0 r
F
.56566 .50346 m .54762 .50454 L .54783 .50723 L .732 .352 0 r
F
.56566 .50346 m .5654 .50077 L .54762 .50454 L F
.08747 .52609 m .0654 .50115 L .06473 .50797 L 1 .869 0 r
F
.08697 .53284 m .08747 .52609 L .06473 .50797 L 1 .851 0 r
F
.55023 .43366 m .53479 .43445 L .53549 .4371 L .774 .573 0 r
F
.55108 .4363 m .55023 .43366 L .53549 .4371 L .772 .565 0 r
F
.38622 .51222 m .36751 .50517 L .36739 .50795 L 1 .75 0 r
F
.38621 .51494 m .38622 .51222 L .36739 .50795 L 1 .74 0 r
F
.37854 .43868 m .36522 .43109 L .36414 .43392 L 1 1 0 r
F
.37854 .43868 m .37942 .43577 L .36522 .43109 L F
.44036 .42091 m .42701 .41664 L .42629 .41912 L 1 .974 0 r
F
.44036 .42091 m .44086 .41838 L .42701 .41664 L F
.16871 .74396 m .1349 .72663 L .13743 .73255 L 1 .384 0 r
F
.17106 .74966 m .16871 .74396 L .13743 .73255 L 1 .358 0 r
F
.41223 .38793 m .403 .38471 L .40147 .3871 L 1 1 0 r
F
.41223 .38793 m .41346 .38529 L .403 .38471 L F
.43167 .40211 m .41346 .38529 L .41223 .38793 L .615 .377 0 r
F
.43086 .40448 m .43167 .40211 L .41223 .38793 L .627 .386 0 r
F
.81072 .24021 m .7984 .25319 L .80292 .25878 L .211 .102 0 r
F
.81072 .24021 m .80602 .23483 L .7984 .25319 L F
.35241 .53364 m .33476 .52414 L .33453 .52729 L 1 .866 0 r
F
.35228 .5368 m .35241 .53364 L .33453 .52729 L 1 .855 0 r
F
.37942 .43577 m .36635 .42828 L .36522 .43109 L 1 1 0 r
F
.37942 .43577 m .38035 .43288 L .36635 .42828 L F
.52314 .16623 m .52775 .09928 L .53142 .12079 L 1 .431 0 r
F
.38961 .39897 m .3805 .39406 L .37878 .39653 L 1 1 0 r
F
.38961 .39897 m .39109 .39631 L .3805 .39406 L F
.4068 .53361 m .3864 .52826 L .38648 .53088 L 1 .596 0 r
F
.40691 .53612 m .4068 .53361 L .38648 .53088 L 1 .598 0 r
F
.54903 .42802 m .53363 .42891 L .53437 .43156 L .792 .601 0 r
F
.54993 .43066 m .54903 .42802 L .53437 .43156 L .79 .593 0 r
F
.35619 .86598 m .31965 .85829 L .32209 .86213 L .92 .068 0 r
F
.35809 .86963 m .35619 .86598 L .32209 .86213 L .902 .065 0 r
F
.56409 .49789 m .54649 .49899 L .54673 .50167 L .724 .355 0 r
F
.56409 .49789 m .5638 .49522 L .54649 .49899 L F
.74352 .5486 m .72307 .55525 L .72249 .55986 L .245 .022 0 r
F
.74352 .5486 m .74415 .54391 L .72307 .55525 L F
.41607 .37013 m .4087 .36941 L .40701 .37167 L 1 1 0 r
F
.41607 .37013 m .41746 .36756 L .4087 .36941 L F
.52933 .55168 m .50955 .55106 L .50949 .55356 L .849 .34 0 r
F
.52933 .55168 m .52942 .54919 L .50955 .55106 L F
.38035 .43288 m .36751 .42548 L .36635 .42828 L 1 1 0 r
F
.38035 .43288 m .38131 .43 L .36751 .42548 L F
.77757 .76414 m .75015 .76893 L .74748 .77425 L .251 0 0 r
F
.77757 .76414 m .78057 .75867 L .75015 .76893 L F
.42159 .43689 m .40769 .43155 L .40688 .43409 L 1 .98 0 r
F
.42159 .43689 m .42221 .43431 L .40769 .43155 L F
.48406 .4063 m .47035 .40441 L .4703 .40692 L 1 .883 0 r
F
.48406 .4063 m .48385 .40377 L .47035 .40441 L F
.4703 .4067 m .45697 .40404 L .45667 .40652 L 1 .922 0 r
F
.4703 .4067 m .47034 .40418 L .45697 .40404 L F
.37333 .45917 m .37396 .45624 L .35852 .45114 L 1 .982 0 r
F
.46866 .55658 m .44836 .55347 L .44839 .55589 L 1 .497 0 r
F
.46865 .55898 m .46866 .55658 L .44839 .55589 L 1 .486 0 r
F
.48892 .55878 m .46866 .55658 L .46865 .55898 L .967 .428 0 r
F
.48892 .55878 m .48897 .55638 L .46866 .55658 L F
.11531 .66459 m .08488 .64334 L .0864 .64995 L 1 .579 0 r
F
.1168 .671 m .11531 .66459 L .0864 .64995 L 1 .556 0 r
F
.54879 .53623 m .52966 .53646 L .52964 .53904 L .785 .317 0 r
F
.54879 .53623 m .54881 .53364 L .52966 .53646 L F
.51356 .62148 m .49118 .62095 L .49099 .62326 L .783 .072 0 r
F
.51356 .62148 m .51395 .61921 L .49118 .62095 L F
.09513 .51863 m .0716 .49415 L .07106 .50086 L 1 .869 0 r
F
.09475 .52523 m .09513 .51863 L .07106 .50086 L 1 .853 0 r
F
.82452 .68956 m .79951 .69695 L .79746 .70285 L .163 0 0 r
F
.82452 .68956 m .82677 .68352 L .79951 .69695 L F
.59805 .1046 m .59181 .10089 L .59262 .10627 L .135 .134 0 r
F
.43012 .88074 m .39428 .87581 L .39563 .8792 L .8 .051 0 r
F
.43084 .88399 m .43012 .88074 L .39563 .8792 L .781 .048 0 r
F
.46512 .88447 m .43012 .88074 L .43084 .88399 L .733 .043 0 r
F
.54936 .43103 m .53406 .4318 L .53479 .43445 L .776 .581 0 r
F
.55023 .43366 m .54936 .43103 L .53479 .43445 L .774 .573 0 r
F
.51201 .4055 m .4978 .40497 L .49825 .40754 L .928 .785 0 r
F
.51269 .40809 m .51201 .4055 L .49825 .40754 L .926 .778 0 r
F
.52878 .54842 m .50927 .54796 L .5092 .55042 L .839 .328 0 r
F
.52878 .54842 m .52888 .54596 L .50927 .54796 L F
.51192 .40567 m .4978 .40497 L .49825 .40754 L .915 .774 0 r
F
.5126 .40825 m .51192 .40567 L .49825 .40754 L .913 .768 0 r
F
.12199 .65415 m .09286 .63292 L .09415 .63943 L 1 .608 0 r
F
.12328 .66048 m .12199 .65415 L .09415 .63943 L 1 .586 0 r
F
.8103 .24051 m .79762 .25374 L .8021 .25932 L .222 .112 0 r
F
.8103 .24051 m .80562 .23513 L .79762 .25374 L F
.45614 .4118 m .44297 .40844 L .44243 .4109 L 1 .955 0 r
F
.45614 .4118 m .45643 .4093 L .44297 .40844 L F
.44827 .55375 m .42804 .54993 L .42802 .55252 L 1 .594 0 r
F
.44827 .55628 m .44827 .55375 L .42802 .55252 L 1 .582 0 r
F
.5659 .50615 m .54783 .50723 L .54803 .50991 L .729 .342 0 r
F
.5659 .50615 m .56566 .50346 L .54783 .50723 L F
.52795 .41055 m .51336 .41068 L .51401 .41328 L .87 .714 0 r
F
.52881 .41315 m .52795 .41055 L .51401 .41328 L .868 .708 0 r
F
.38131 .43 m .36872 .42271 L .36751 .42548 L 1 1 0 r
F
.38131 .43 m .38231 .42713 L .36872 .42271 L F
.37318 .57617 m .35272 .56776 L .35295 .57078 L 1 .677 0 r
F
.37342 .57914 m .37318 .57617 L .35295 .57078 L 1 .664 0 r
F
.43371 .35787 m .42664 .36054 L .42526 .3629 L 1 1 0 r
F
.43371 .35787 m .43475 .35494 L .42664 .36054 L F
.60284 .8695 m .57178 .86966 L .56994 .87315 L .463 .011 0 r
F
.60284 .8695 m .60528 .86594 L .57178 .86966 L F
.46863 .55953 m .44827 .55628 L .44827 .5588 L 1 .52 0 r
F
.46862 .56199 m .46863 .55953 L .44827 .5588 L 1 .508 0 r
F
.48902 .5619 m .46863 .55953 L .46862 .56199 L .976 .446 0 r
F
.48902 .5619 m .48907 .55946 L .46863 .55953 L F
.58235 .58808 m .56274 .59054 L .56211 .5931 L .505 .046 0 r
F
.58235 .58808 m .58313 .5855 L .56274 .59054 L F
.56436 .50055 m .54673 .50167 L .54695 .50433 L .721 .344 0 r
F
.56436 .50055 m .56409 .49789 L .54673 .50167 L F
.0758 .54124 m .05179 .51584 L .05146 .52288 L 1 .829 0 r
F
.07561 .54815 m .0758 .54124 L .05146 .52288 L 1 .81 0 r
F
.54811 .42539 m .53286 .42626 L .53363 .42891 L .794 .609 0 r
F
.54903 .42802 m .54811 .42539 L .53363 .42891 L .792 .601 0 r
F
.4703 .40692 m .45703 .40434 L .45673 .40681 L 1 .926 0 r
F
.4703 .40692 m .47035 .40441 L .45703 .40434 L F
.54792 .53303 m .52912 .53339 L .52911 .53594 L .775 .307 0 r
F
.54792 .53303 m .54793 .53048 L .52912 .53339 L F
.38231 .42713 m .36997 .41995 L .36872 .42271 L 1 1 0 r
F
.38231 .42713 m .38334 .42427 L .36997 .41995 L F
.52769 .41087 m .51326 .41083 L .51392 .41343 L .855 .703 0 r
F
.52854 .41346 m .52769 .41087 L .51392 .41343 L .854 .696 0 r
F
.53218 .87568 m .49953 .87427 L .49893 .87738 L .587 .024 0 r
F
.53218 .87568 m .53343 .87256 L .49953 .87427 L F
.54848 .4284 m .53333 .42916 L .53406 .4318 L .778 .589 0 r
F
.54936 .43103 m .54848 .4284 L .53406 .4318 L .776 .581 0 r
F
.42825 .54201 m .40702 .53863 L .40712 .54115 L 1 .658 0 r
F
.42815 .54468 m .42825 .54201 L .40712 .54115 L 1 .643 0 r
F
.42221 .43431 m .40853 .42902 L .40769 .43155 L 1 .985 0 r
F
.42221 .43431 m .42286 .43175 L .40853 .42902 L F
.44086 .41838 m .42776 .41417 L .42701 .41664 L 1 .98 0 r
F
.44086 .41838 m .44138 .41587 L .42776 .41417 L F
.50893 .55768 m .48897 .55638 L .48892 .55878 L .902 .364 0 r
F
.50893 .55768 m .50903 .55528 L .48897 .55638 L F
.42827 .54198 m .40887 .53697 L .40888 .53949 L 1 .652 0 r
F
.42828 .54448 m .42827 .54198 L .40888 .53949 L 1 .642 0 r
F
.88446 .43671 m .86534 .4494 L .86666 .45617 L .101 .026 0 r
F
.88446 .43671 m .88311 .4299 L .86534 .4494 L F
.38621 .51494 m .36739 .50795 L .36731 .51072 L 1 .74 0 r
F
.38621 .51763 m .38621 .51494 L .36731 .51072 L 1 .73 0 r
F
.50923 .56093 m .48907 .55946 L .48902 .5619 L .911 .378 0 r
F
.50923 .56093 m .50933 .55849 L .48907 .55946 L F
.27356 .8219 m .2379 .81027 L .24084 .81491 L 1 .137 0 r
F
.27612 .82632 m .27356 .8219 L .24084 .81491 L 1 .111 0 r
F
.44836 .55347 m .42835 .54943 L .42841 .55188 L 1 .561 0 r
F
.44839 .55589 m .44836 .55347 L .42841 .55188 L 1 .55 0 r
F
.55805 .11934 m .55584 .10451 L .56128 .11228 L .92 .138 0 r
F
.56611 .50882 m .54803 .50991 L .5482 .51259 L .727 .332 0 r
F
.56611 .50882 m .5659 .50615 L .54803 .50991 L F
.35228 .5368 m .33453 .52729 L .33434 .53043 L 1 .855 0 r
F
.35217 .53994 m .35228 .5368 L .33434 .53043 L 1 .844 0 r
F
.7618 .45759 m .7478 .46581 L .74789 .47087 L .062 .006 0 r
F
.7618 .45759 m .76152 .45254 L .7478 .46581 L F
.38334 .42427 m .37126 .41722 L .36997 .41995 L 1 1 0 r
F
.38334 .42427 m .38441 .42144 L .37126 .41722 L F
.39428 .87581 m .35809 .86963 L .36003 .87318 L .856 .059 0 r
F
.39563 .8792 m .39428 .87581 L .36003 .87318 L .837 .055 0 r
F
.22254 .79655 m .18709 .78249 L .19008 .78773 L 1 .23 0 r
F
.22523 .80156 m .22254 .79655 L .19008 .78773 L 1 .204 0 r
F
.28236 .79037 m .24574 .78273 L .24832 .7873 L 1 .238 0 r
F
.28453 .79478 m .28236 .79037 L .24832 .7873 L 1 .217 0 r
F
.5553 .2043 m .56742 .14281 L .56634 .16896 L 1 .404 0 r
F
.5553 .2043 m .5622 .1604 L .56742 .14281 L F
.39109 .39631 m .38224 .39162 L .3805 .39406 L 1 1 0 r
F
.39109 .39631 m .39259 .39369 L .38224 .39162 L F
.62861 .53279 m .61236 .53698 L .61176 .54002 L .313 .026 0 r
F
.62861 .53279 m .6293 .52975 L .61236 .53698 L F
.68252 .20733 m .68504 .20053 L .68824 .20705 L .902 .13 0 r
F
.68252 .20733 m .68017 .20018 L .68504 .20053 L F
.31744 .84441 m .28143 .8349 L .28418 .83907 L .991 .079 0 r
F
.31974 .84836 m .31744 .84441 L .28418 .83907 L .974 .076 0 r
F
.67933 .82863 m .6507 .83118 L .64805 .83524 L .346 0 0 r
F
.67933 .82863 m .68246 .82447 L .6507 .83118 L F
.44464 .62102 m .42138 .61685 L .42171 .61938 L 1 .313 0 r
F
.44483 .62344 m .44464 .62102 L .42171 .61938 L 1 .297 0 r
F
.46794 .62391 m .44464 .62102 L .44483 .62344 L .951 .223 0 r
F
.5646 .5032 m .54695 .50433 L .54714 .50699 L .719 .334 0 r
F
.5646 .5032 m .56436 .50055 L .54695 .50433 L F
.41346 .38529 m .40454 .38236 L .403 .38471 L 1 1 0 r
F
.41346 .38529 m .4147 .38269 L .40454 .38236 L F
.43249 .39976 m .4147 .38269 L .41346 .38529 L .604 .367 0 r
F
.43167 .40211 m .43249 .39976 L .41346 .38529 L .615 .377 0 r
F
.71924 .21256 m .7154 .21569 L .71863 .22192 L 0 0 0 r
F
.71924 .21256 m .71709 .20532 L .7154 .21569 L F
.54717 .42277 m .53208 .42362 L .53286 .42626 L .796 .616 0 r
F
.54811 .42539 m .54717 .42277 L .53286 .42626 L .794 .609 0 r
F
.54875 .53879 m .52964 .53904 L .52961 .5416 L .782 .306 0 r
F
.54875 .53879 m .54879 .53623 L .52964 .53904 L F
.64995 .48942 m .63634 .49406 L .63571 .49749 L .188 .003 0 r
F
.64995 .48942 m .65067 .48598 L .63634 .49406 L F
.81534 .24566 m .80292 .25878 L .80735 .26442 L .204 .087 0 r
F
.81534 .24566 m .81072 .24021 L .80292 .25878 L F
.39707 .60062 m .37506 .59366 L .37547 .59649 L 1 .53 0 r
F
.39743 .60337 m .39707 .60062 L .37547 .59649 L 1 .515 0 r
F
.52922 .55417 m .50949 .55356 L .50941 .55603 L .846 .328 0 r
F
.52922 .55417 m .52933 .55168 L .50949 .55356 L F
.52708 .40796 m .51269 .40809 L .51336 .41068 L .872 .721 0 r
F
.52795 .41055 m .52708 .40796 L .51336 .41068 L .87 .714 0 r
F
.54757 .42578 m .53257 .42652 L .53333 .42916 L .779 .597 0 r
F
.54848 .4284 m .54757 .42578 L .53333 .42916 L .778 .589 0 r
F
.40691 .53612 m .38648 .53088 L .38657 .53348 L 1 .598 0 r
F
.40702 .53863 m .40691 .53612 L .38657 .53348 L 1 .602 0 r
F
.44827 .55628 m .42802 .55252 L .42802 .55508 L 1 .582 0 r
F
.44827 .5588 m .44827 .55628 L .42802 .55508 L 1 .57 0 r
F
.51132 .40293 m .49734 .40241 L .4978 .40497 L .93 .791 0 r
F
.51201 .4055 m .51132 .40293 L .4978 .40497 L .928 .785 0 r
F
.40023 .81847 m .36508 .81847 L .36656 .82238 L .888 .089 0 r
F
.4012 .82235 m .40023 .81847 L .36656 .82238 L .876 .074 0 r
F
.43406 .81646 m .40023 .81847 L .4012 .82235 L .816 .071 0 r
F
.51123 .4031 m .49734 .40241 L .4978 .40497 L .917 .781 0 r
F
.51192 .40567 m .51123 .4031 L .4978 .40497 L .915 .774 0 r
F
.60551 .56601 m .58737 .5694 L .58672 .57216 L .394 .037 0 r
F
.60551 .56601 m .60628 .56324 L .58737 .5694 L F
.82914 .69983 m .80305 .70666 L .80095 .71266 L .187 0 0 r
F
.82914 .69983 m .83146 .69367 L .80305 .70666 L F
.48385 .40377 m .47039 .40191 L .47035 .40441 L 1 .89 0 r
F
.48385 .40377 m .48363 .40124 L .47039 .40191 L F
.42286 .43175 m .40938 .42651 L .40853 .42902 L 1 .991 0 r
F
.42286 .43175 m .42351 .4292 L .40938 .42651 L F
.42815 .54468 m .40712 .54115 L .40721 .54366 L 1 .643 0 r
F
.42808 .54732 m .42815 .54468 L .40721 .54366 L 1 .632 0 r
F
.52867 .55087 m .5092 .55042 L .50912 .55286 L .836 .317 0 r
F
.52867 .55087 m .52878 .54842 L .5092 .55042 L F
.42106 .61429 m .39821 .60878 L .39863 .61145 L 1 .411 0 r
F
.42138 .61685 m .42106 .61429 L .39863 .61145 L 1 .395 0 r
F
.40909 .52415 m .40918 .52156 L .39082 .51818 L 1 .757 0 r
F
.47034 .40418 m .45728 .40158 L .45697 .40404 L 1 .928 0 r
F
.47034 .40418 m .47039 .40168 L .45728 .40158 L F
.45643 .4093 m .44352 .40599 L .44297 .40844 L 1 .961 0 r
F
.45643 .4093 m .45673 .40681 L .44352 .40599 L F
.89066 .44309 m .87068 .45592 L .87206 .46276 L .119 .03 0 r
F
.89066 .44309 m .88918 .43621 L .87068 .45592 L F
.46865 .55898 m .44839 .55589 L .44843 .55829 L 1 .486 0 r
F
.46864 .56136 m .46865 .55898 L .44843 .55829 L 1 .475 0 r
F
.48886 .56115 m .46865 .55898 L .46864 .56136 L .965 .416 0 r
F
.48886 .56115 m .48892 .55878 L .46865 .55898 L F
.81488 .24597 m .8021 .25932 L .80649 .26497 L .214 .094 0 r
F
.81488 .24597 m .8103 .24051 L .8021 .25932 L F
.5663 .5115 m .5482 .51259 L .54835 .51525 L .724 .321 0 r
F
.5663 .5115 m .56611 .50882 L .5482 .51259 L F
.54788 .53556 m .52911 .53594 L .52907 .53847 L .772 .296 0 r
F
.54788 .53556 m .54792 .53303 L .52911 .53594 L F
.52683 .40829 m .5126 .40825 L .51326 .41083 L .857 .71 0 r
F
.52769 .41087 m .52683 .40829 L .51326 .41083 L .855 .703 0 r
F
.46795 .62624 m .46794 .62391 L .44483 .62344 L .943 .205 0 r
F
.4908 .62553 m .46794 .62391 L .46795 .62624 L .864 .124 0 r
F
.4908 .62553 m .49099 .62326 L .46794 .62391 L F
.56482 .50585 m .54714 .50699 L .54731 .50964 L .716 .324 0 r
F
.56482 .50585 m .5646 .5032 L .54714 .50699 L F
.55869 .60543 m .53807 .60696 L .53754 .60936 L .599 .053 0 r
F
.55869 .60543 m .55941 .60304 L .53807 .60696 L F
.41746 .36756 m .41041 .3672 L .4087 .36941 L 1 1 0 r
F
.41746 .36756 m .41887 .36503 L .41041 .3672 L F
.55077 .25134 m .56641 .18466 L .55914 .22406 L .882 .195 0 r
F
.56344 .19642 m .57294 .14728 L .5722 .17069 L 1 .406 0 r
F
.56344 .19642 m .56835 .1613 L .57294 .14728 L F
.46862 .56199 m .44827 .5588 L .44829 .5613 L 1 .508 0 r
F
.46861 .56444 m .46862 .56199 L .44829 .5613 L 1 .496 0 r
F
.48897 .56433 m .46862 .56199 L .46861 .56444 L .973 .434 0 r
F
.48897 .56433 m .48902 .5619 L .46862 .56199 L F
.18404 .7162 m .14985 .7011 L .1521 .70674 L 1 .438 0 r
F
.18612 .7216 m .18404 .7162 L .1521 .70674 L 1 .417 0 r
F
.54621 .42015 m .53129 .421 L .53208 .42362 L .798 .624 0 r
F
.54717 .42277 m .54621 .42015 L .53208 .42362 L .796 .616 0 r
F
.44138 .41587 m .42851 .41172 L .42776 .41417 L 1 .986 0 r
F
.44138 .41587 m .4419 .41338 L .42851 .41172 L F
.64302 .10718 m .63624 .11467 L .64297 .11756 L .402 .574 0 r
F
.64302 .10718 m .63621 .10476 L .63624 .11467 L F
.53583 .61635 m .51433 .6169 L .51395 .61921 L .689 .061 0 r
F
.53583 .61635 m .53642 .61405 L .51433 .6169 L F
.54664 .42317 m .5318 .42389 L .53257 .42652 L .781 .604 0 r
F
.54757 .42578 m .54664 .42317 L .53257 .42652 L .779 .597 0 r
F
.42828 .54448 m .40888 .53949 L .40891 .542 L 1 .642 0 r
F
.42831 .54697 m .42828 .54448 L .40891 .542 L 1 .632 0 r
F
.47035 .40441 m .45734 .40188 L .45703 .40434 L 1 .932 0 r
F
.47035 .40441 m .47039 .40191 L .45734 .40188 L F
.38621 .51763 m .36731 .51072 L .36724 .51347 L 1 .73 0 r
F
.38624 .52031 m .38621 .51763 L .36724 .51347 L 1 .721 0 r
F
.43475 .35494 m .42803 .35822 L .42664 .36054 L 1 .931 0 r
F
.43475 .35494 m .43579 .352 L .42803 .35822 L F
.86894 .59135 m .84646 .60129 L .84559 .60782 L .097 0 0 r
F
.86894 .59135 m .86991 .58471 L .84646 .60129 L F
.69259 .38181 m .68605 .38533 L .6844 .39107 L 0 0 0 r
F
.69259 .38181 m .69425 .37607 L .68605 .38533 L F
.71058 .61774 m .68805 .62231 L .68706 .62659 L .318 .024 0 r
F
.71058 .61774 m .71181 .61343 L .68805 .62231 L F
.32553 .80813 m .28907 .8034 L .29142 .80761 L 1 .173 0 r
F
.32742 .81224 m .32553 .80813 L .29142 .80761 L 1 .151 0 r
F
.67576 .66387 m .65265 .66746 L .65151 .67156 L .36 .025 0 r
F
.67576 .66387 m .67724 .65985 L .65265 .66746 L F
.35217 .53994 m .33434 .53043 L .33418 .53358 L 1 .844 0 r
F
.3521 .54308 m .35217 .53994 L .33418 .53358 L 1 .832 0 r
F
.37342 .57914 m .35295 .57078 L .35321 .57378 L 1 .664 0 r
F
.3737 .58208 m .37342 .57914 L .35321 .57378 L 1 .651 0 r
F
.61098 .7265 m .58722 .73089 L .58616 .73495 L .396 .026 0 r
F
.61098 .7265 m .61242 .7227 L .58722 .73089 L F
.67035 .43959 m .66005 .44406 L .65901 .44827 L 0 0 0 r
F
.67035 .43959 m .6715 .43535 L .66005 .44406 L F
.13245 .64223 m .10192 .62244 L .10325 .62873 L 1 .613 0 r
F
.13377 .64829 m .13245 .64223 L .10325 .62873 L 1 .593 0 r
F
.50882 .56006 m .48892 .55878 L .48886 .56115 L .899 .352 0 r
F
.50882 .56006 m .50893 .55768 L .48892 .55878 L F
.48975 .21929 m .49207 .0943 L .49847 .10434 L .868 .389 0 r
F
.50913 .56336 m .48902 .5619 L .48897 .56433 L .908 .367 0 r
F
.50913 .56336 m .50923 .56093 L .48902 .5619 L F
.39259 .39369 m .38401 .38921 L .38224 .39162 L 1 1 0 r
F
.39259 .39369 m .39411 .3911 L .38401 .38921 L F
.42351 .4292 m .41025 .42402 L .40938 .42651 L 1 .996 0 r
F
.42351 .4292 m .42418 .42666 L .41025 .42402 L F
.44839 .55589 m .42841 .55188 L .42847 .55431 L 1 .55 0 r
F
.44843 .55829 m .44839 .55589 L .42847 .55431 L 1 .54 0 r
F
.08697 .53284 m .06473 .50797 L .06418 .5148 L 1 .851 0 r
F
.08659 .53958 m .08697 .53284 L .06418 .5148 L 1 .833 0 r
F
.74282 .55327 m .72249 .55986 L .72187 .56445 L .241 .02 0 r
F
.74282 .55327 m .74352 .5486 L .72249 .55986 L F
.54869 .54135 m .52961 .5416 L .52957 .54414 L .779 .295 0 r
F
.54869 .54135 m .54875 .53879 L .52961 .5416 L F
.40909 .52415 m .39082 .51818 L .3907 .52078 L 1 .757 0 r
F
.40901 .52674 m .40909 .52415 L .3907 .52078 L 1 .748 0 r
F
.56645 .51416 m .54835 .51525 L .54848 .51791 L .721 .311 0 r
F
.56645 .51416 m .5663 .5115 L .54835 .51525 L F
.42808 .54732 m .40721 .54366 L .40731 .54618 L 1 .632 0 r
F
.42804 .54993 m .42808 .54732 L .40731 .54618 L 1 .623 0 r
F
.72639 .80946 m .69822 .8127 L .69537 .81736 L .306 0 0 r
F
.72639 .80946 m .72966 .80466 L .69822 .8127 L F
.5262 .40537 m .51201 .4055 L .51269 .40809 L .874 .728 0 r
F
.52708 .40796 m .5262 .40537 L .51269 .40809 L .872 .721 0 r
F
.565 .50849 m .54731 .50964 L .54747 .51228 L .713 .313 0 r
F
.565 .50849 m .56482 .50585 L .54731 .50964 L F
.5814 .7506 m .55672 .75596 L .55581 .76005 L .42 .028 0 r
F
.5814 .7506 m .58267 .74678 L .55672 .75596 L F
.358 .85991 m .32209 .85223 L .32449 .85601 L .919 .068 0 r
F
.35988 .86349 m .358 .85991 L .32449 .85601 L .901 .064 0 r
F
.70841 .30936 m .70649 .31027 L .706 .31735 L 0 0 0 r
F
.70841 .30936 m .70867 .30257 L .70649 .31027 L F
.63994 .85745 m .61 .85851 L .60767 .86227 L .407 .003 0 r
F
.63994 .85745 m .64284 .85359 L .61 .85851 L F
.4147 .38269 m .40611 .38005 L .40454 .38236 L 1 1 0 r
F
.4147 .38269 m .41596 .38011 L .40611 .38005 L F
.43332 .39742 m .41596 .38011 L .4147 .38269 L .592 .358 0 r
F
.43249 .39976 m .43332 .39742 L .4147 .38269 L .604 .367 0 r
F
.54523 .41754 m .53048 .41837 L .53129 .421 L .8 .631 0 r
F
.54621 .42015 m .54523 .41754 L .53129 .421 L .798 .624 0 r
F
.52909 .55663 m .50941 .55603 L .50933 .55849 L .842 .317 0 r
F
.52909 .55663 m .52922 .55417 L .50941 .55603 L F
.54568 .42057 m .53101 .42128 L .5318 .42389 L .783 .612 0 r
F
.54664 .42317 m .54568 .42057 L .5318 .42389 L .781 .604 0 r
F
.44827 .5588 m .42802 .55508 L .42804 .55762 L 1 .57 0 r
F
.44829 .5613 m .44827 .5588 L .42804 .55762 L 1 .558 0 r
F
.81987 .25117 m .80735 .26442 L .81169 .27013 L .196 .085 0 r
F
.81987 .25117 m .81534 .24566 L .80735 .26442 L F
.43077 .87446 m .39548 .86963 L .39682 .87294 L .793 .05 0 r
F
.43148 .87761 m .43077 .87446 L .39682 .87294 L .774 .046 0 r
F
.46522 .87803 m .43077 .87446 L .43148 .87761 L .723 .041 0 r
F
.51062 .40035 m .49687 .39986 L .49734 .40241 L .932 .798 0 r
F
.51132 .40293 m .51062 .40035 L .49734 .40241 L .93 .791 0 r
F
.51054 .40053 m .49687 .39986 L .49734 .40241 L .919 .787 0 r
F
.51123 .4031 m .51054 .40053 L .49734 .40241 L .917 .781 0 r
F
.52595 .40572 m .51192 .40567 L .5126 .40825 L .859 .716 0 r
F
.52683 .40829 m .52595 .40572 L .5126 .40825 L .857 .71 0 r
F
.09475 .52523 m .07106 .50086 L .07063 .50757 L 1 .853 0 r
F
.09448 .53182 m .09475 .52523 L .07063 .50757 L 1 .836 0 r
F
.40702 .53863 m .38657 .53348 L .38668 .53607 L 1 .602 0 r
F
.40712 .54115 m .40702 .53863 L .38668 .53607 L 1 .605 0 r
F
.87548 .60023 m .85149 .60983 L .85061 .61647 L .13 0 0 r
F
.87548 .60023 m .87643 .59344 L .85149 .60983 L F
.54781 .53809 m .52907 .53847 L .52902 .54098 L .769 .285 0 r
F
.54781 .53809 m .54788 .53556 L .52907 .53847 L F
.52853 .55329 m .50912 .55286 L .50903 .55528 L .833 .305 0 r
F
.52853 .55329 m .52867 .55087 L .50912 .55286 L F
.64976 .10974 m .64302 .10718 L .64297 .11756 L .393 .552 0 r
F
.77168 .75869 m .74536 .76398 L .74268 .76914 L .226 0 0 r
F
.77168 .75869 m .77469 .75338 L .74536 .76398 L F
.64199 .69929 m .61875 .70297 L .61759 .70701 L .379 .024 0 r
F
.64199 .69929 m .64352 .69545 L .61875 .70297 L F
.45673 .40681 m .44408 .40356 L .44352 .40599 L 1 .967 0 r
F
.45673 .40681 m .45703 .40434 L .44408 .40356 L F
.48363 .40124 m .47044 .39943 L .47039 .40191 L 1 .897 0 r
F
.48363 .40124 m .48341 .39872 L .47044 .39943 L F
.58155 .59062 m .56211 .5931 L .56146 .59564 L .497 .044 0 r
F
.58155 .59062 m .58235 .58808 L .56211 .5931 L F
.17461 .73883 m .14187 .72153 L .1443 .72737 L 1 .39 0 r
F
.17688 .74444 m .17461 .73883 L .1443 .72737 L 1 .365 0 r
F
.47039 .40168 m .4576 .39913 L .45728 .40158 L 1 .935 0 r
F
.47039 .40168 m .47043 .39919 L .4576 .39913 L F
.51316 .62372 m .49099 .62326 L .4908 .62553 L .773 .069 0 r
F
.51316 .62372 m .51356 .62148 L .49099 .62326 L F
.76203 .46263 m .74789 .47087 L .74795 .47591 L .064 .005 0 r
F
.76203 .46263 m .7618 .45759 L .74789 .47087 L F
.46864 .56136 m .44843 .55829 L .44847 .56067 L 1 .475 0 r
F
.46863 .56371 m .46864 .56136 L .44847 .56067 L 1 .464 0 r
F
.48879 .56351 m .46864 .56136 L .46863 .56371 L .962 .405 0 r
F
.48879 .56351 m .48886 .56115 L .46864 .56136 L F
.60052 .86262 m .5701 .86316 L .56828 .86651 L .44 .007 0 r
F
.60052 .86262 m .60294 .8592 L .5701 .86316 L F
.42418 .42666 m .41114 .42154 L .41025 .42402 L 1 1 0 r
F
.42418 .42666 m .42487 .42413 L .41114 .42154 L F
.4419 .41338 m .42928 .40929 L .42851 .41172 L 1 .991 0 r
F
.4419 .41338 m .44243 .4109 L .42928 .40929 L F
.81937 .2515 m .80649 .26497 L .81079 .27069 L .205 .085 0 r
F
.81937 .2515 m .81488 .24597 L .80649 .26497 L F
.6279 .5358 m .61176 .54002 L .61114 .54302 L .31 .025 0 r
F
.6279 .5358 m .62861 .53279 L .61176 .54002 L F
.72083 .22018 m .71863 .22192 L .7216 .22829 L 0 0 0 r
F
.72083 .22018 m .71924 .21256 L .71863 .22192 L F
.6848 .2143 m .68824 .20705 L .6912 .21365 L .977 .135 0 r
F
.88569 .44354 m .86666 .45617 L .86787 .46295 L .09 .022 0 r
F
.88569 .44354 m .88446 .43671 L .86666 .45617 L F
.23608 .76385 m .20022 .75289 L .20285 .75792 L 1 .312 0 r
F
.23839 .76866 m .23608 .76385 L .20285 .75792 L 1 .291 0 r
F
.56659 .51681 m .54848 .51791 L .54859 .52056 L .717 .3 0 r
F
.56659 .51681 m .56645 .51416 L .54848 .51791 L F
.56517 .51113 m .54747 .51228 L .5476 .51491 L .71 .302 0 r
F
.56517 .51113 m .565 .50849 L .54747 .51228 L F
.46861 .56444 m .44829 .5613 L .44831 .56378 L 1 .496 0 r
F
.4686 .56687 m .46861 .56444 L .44831 .56378 L 1 .484 0 r
F
.48891 .56674 m .46861 .56444 L .4686 .56687 L .97 .422 0 r
F
.48891 .56674 m .48897 .56433 L .46861 .56444 L F
.55282 .77186 m .52671 .77788 L .52602 .78196 L .471 .034 0 r
F
.55282 .77186 m .55386 .76801 L .52671 .77788 L F
.42831 .54697 m .40891 .542 L .40896 .54449 L 1 .632 0 r
F
.42835 .54943 m .42831 .54697 L .40896 .54449 L 1 .622 0 r
F
.38624 .52031 m .36724 .51347 L .36721 .5162 L 1 .721 0 r
F
.38628 .52298 m .38624 .52031 L .36721 .5162 L 1 .713 0 r
F
.40901 .52674 m .3907 .52078 L .3906 .52337 L 1 .748 0 r
F
.40895 .52932 m .40901 .52674 L .3906 .52337 L 1 .739 0 r
F
.64925 .49282 m .63571 .49749 L .63508 .50089 L .186 .003 0 r
F
.64925 .49282 m .64995 .48942 L .63571 .49749 L F
.43455 .82033 m .43406 .81646 L .4012 .82235 L .802 .067 0 r
F
.46597 .81272 m .43406 .81646 L .43455 .82033 L .727 .061 0 r
F
.46597 .81272 m .46594 .8088 L .43406 .81646 L F
.42804 .54993 m .40731 .54618 L .4074 .54869 L 1 .623 0 r
F
.42802 .55252 m .42804 .54993 L .4074 .54869 L 1 .613 0 r
F
.07561 .54815 m .05146 .52288 L .05125 .52991 L 1 .81 0 r
F
.07553 .55506 m .07561 .54815 L .05125 .52991 L 1 .791 0 r
F
.3521 .54308 m .33418 .53358 L .33406 .53671 L 1 .832 0 r
F
.35206 .54621 m .3521 .54308 L .33406 .53671 L 1 .821 0 r
F
.54471 .41798 m .5302 .41866 L .53101 .42128 L .785 .619 0 r
F
.54568 .42057 m .54471 .41798 L .53101 .42128 L .783 .612 0 r
F
.54423 .41493 m .52965 .41576 L .53048 .41837 L .802 .639 0 r
F
.54523 .41754 m .54423 .41493 L .53048 .41837 L .8 .631 0 r
F
.47039 .40191 m .45765 .39944 L .45734 .40188 L 1 .939 0 r
F
.47039 .40191 m .47044 .39943 L .45765 .39944 L F
.39411 .3911 m .38581 .38685 L .38401 .38921 L 1 1 0 r
F
.39411 .3911 m .39565 .38854 L .38581 .38685 L F
.5486 .54389 m .52957 .54414 L .5295 .54667 L .776 .284 0 r
F
.5486 .54389 m .54869 .54135 L .52957 .54414 L F
.5253 .40279 m .51132 .40293 L .51201 .4055 L .877 .734 0 r
F
.5262 .40537 m .5253 .40279 L .51201 .4055 L .874 .728 0 r
F
.39548 .86963 m .35988 .86349 L .36179 .86698 L .853 .058 0 r
F
.39682 .87294 m .39548 .86963 L .36179 .86698 L .833 .054 0 r
F
.39743 .60337 m .37547 .59649 L .3759 .59931 L 1 .515 0 r
F
.39781 .60609 m .39743 .60337 L .3759 .59931 L 1 .5 0 r
F
.41887 .36503 m .41213 .36503 L .41041 .3672 L 1 1 0 r
F
.41887 .36503 m .4203 .36253 L .41213 .36503 L F
.50901 .56576 m .48897 .56433 L .48891 .56674 L .905 .355 0 r
F
.50901 .56576 m .50913 .56336 L .48897 .56433 L F
.60471 .56876 m .58672 .57216 L .58604 .57489 L .39 .035 0 r
F
.60471 .56876 m .60551 .56601 L .58672 .57216 L F
.44843 .55829 m .42847 .55431 L .42855 .55672 L 1 .54 0 r
F
.44847 .56067 m .44843 .55829 L .42855 .55672 L 1 .529 0 r
F
.5087 .56242 m .48886 .56115 L .48879 .56351 L .896 .341 0 r
F
.5087 .56242 m .50882 .56006 L .48886 .56115 L F
.43579 .352 m .42944 .35591 L .42803 .35822 L 1 .831 0 r
F
.43579 .352 m .43683 .34904 L .42944 .35591 L F
.39748 .46777 m .38249 .46117 L .38179 .4638 L 1 .958 0 r
F
.39748 .46777 m .39805 .46512 L .38249 .46117 L F
.39693 .47043 m .39748 .46777 L .38179 .4638 L 1 .952 0 r
F
.12328 .66048 m .09415 .63943 L .09556 .64592 L 1 .586 0 r
F
.12467 .66677 m .12328 .66048 L .09556 .64592 L 1 .563 0 r
F
.39693 .47043 m .38179 .4638 L .38112 .46643 L 1 .952 0 r
F
.3964 .4731 m .39693 .47043 L .38112 .46643 L 1 .945 0 r
F
.39805 .46512 m .3832 .45854 L .38249 .46117 L 1 .964 0 r
F
.39805 .46512 m .39864 .46247 L .3832 .45854 L F
.44483 .62344 m .42171 .61938 L .42206 .62188 L 1 .297 0 r
F
.44502 .62583 m .44483 .62344 L .42206 .62188 L 1 .279 0 r
F
.46795 .62624 m .44483 .62344 L .44502 .62583 L .943 .205 0 r
F
.3964 .4731 m .38112 .46643 L .38048 .46907 L 1 .945 0 r
F
.3959 .47576 m .3964 .4731 L .38048 .46907 L 1 .938 0 r
F
.39864 .46247 m .38395 .45593 L .3832 .45854 L 1 .97 0 r
F
.39864 .46247 m .39925 .45982 L .38395 .45593 L F
.1168 .671 m .0864 .64995 L .08804 .65652 L 1 .556 0 r
F
.11839 .67736 m .1168 .671 L .08804 .65652 L 1 .532 0 r
F
.52505 .40314 m .51123 .4031 L .51192 .40567 L .861 .723 0 r
F
.52595 .40572 m .52505 .40314 L .51192 .40567 L .859 .716 0 r
F
.89202 .45 m .87206 .46276 L .87333 .46961 L .111 .027 0 r
F
.89202 .45 m .89066 .44309 L .87206 .46276 L F
.22695 .79095 m .19239 .77686 L .19529 .78204 L 1 .235 0 r
F
.22957 .79589 m .22695 .79095 L .19529 .78204 L 1 .208 0 r
F
.3959 .47576 m .38048 .46907 L .37987 .47172 L 1 .938 0 r
F
.39541 .47843 m .3959 .47576 L .37987 .47172 L 1 .932 0 r
F
.5653 .51375 m .5476 .51491 L .54771 .51754 L .707 .291 0 r
F
.5653 .51375 m .56517 .51113 L .5476 .51491 L F
.42487 .42413 m .41205 .41907 L .41114 .42154 L 1 1 0 r
F
.42487 .42413 m .42557 .42162 L .41205 .41907 L F
.44829 .5613 m .42804 .55762 L .42808 .56014 L 1 .558 0 r
F
.44831 .56378 m .44829 .5613 L .42808 .56014 L 1 .546 0 r
F
.54773 .54059 m .52902 .54098 L .52896 .54348 L .766 .274 0 r
F
.54773 .54059 m .54781 .53809 L .52902 .54098 L F
.55961 .13999 m .56128 .11228 L .56572 .12294 L 1 .573 0 r
F
.52455 .78982 m .49662 .79578 L .49625 .79978 L .546 .042 0 r
F
.52455 .78982 m .5253 .78593 L .49662 .79578 L F
.39925 .45982 m .38472 .45332 L .38395 .45593 L 1 .976 0 r
F
.39925 .45982 m .39988 .45718 L .38472 .45332 L F
.3737 .58208 m .35321 .57378 L .3535 .57677 L 1 .651 0 r
F
.374 .58501 m .3737 .58208 L .3535 .57677 L 1 .637 0 r
F
.56669 .51946 m .54859 .52056 L .54868 .5232 L .714 .289 0 r
F
.56669 .51946 m .56659 .51681 L .54859 .52056 L F
.52895 .55908 m .50933 .55849 L .50923 .56093 L .839 .305 0 r
F
.52895 .55908 m .52909 .55663 L .50933 .55849 L F
.42138 .61685 m .39863 .61145 L .39907 .61408 L 1 .395 0 r
F
.42171 .61938 m .42138 .61685 L .39907 .61408 L 1 .379 0 r
F
.50991 .39779 m .4964 .39731 L .49687 .39986 L .935 .804 0 r
F
.51062 .40035 m .50991 .39779 L .49687 .39986 L .932 .798 0 r
F
.41596 .38011 m .4077 .37777 L .40611 .38005 L 1 1 0 r
F
.41596 .38011 m .41724 .37756 L .4077 .37777 L F
.43416 .39511 m .41724 .37756 L .41596 .38011 L 1 .217 0 r
F
.43332 .39742 m .43416 .39511 L .41596 .38011 L .592 .358 0 r
F
.50983 .39797 m .4964 .39732 L .49687 .39986 L .921 .794 0 r
F
.51054 .40053 m .50983 .39797 L .49687 .39986 L .919 .787 0 r
F
.39541 .47843 m .37987 .47172 L .37928 .47436 L 1 .932 0 r
F
.39495 .4811 m .39541 .47843 L .37928 .47436 L 1 .925 0 r
F
.56617 .87985 m .53447 .87914 L .53322 .88239 L .522 .017 0 r
F
.56617 .87985 m .56808 .87655 L .53447 .87914 L F
.27281 .83217 m .23677 .8208 L .23985 .82542 L 1 .109 0 r
F
.27548 .83657 m .27281 .83217 L .23985 .82542 L 1 .086 0 r
F
.54373 .41539 m .52938 .41606 L .5302 .41866 L .786 .627 0 r
F
.54471 .41798 m .54373 .41539 L .5302 .41866 L .785 .619 0 r
F
.39988 .45718 m .38551 .45071 L .38472 .45332 L 1 .982 0 r
F
.39988 .45718 m .40053 .45455 L .38551 .45071 L F
.49586 .80367 m .46594 .8088 L .46597 .81272 L .635 .051 0 r
F
.49586 .80367 m .49625 .79978 L .46594 .8088 L F
.40712 .54115 m .38668 .53607 L .3868 .53865 L 1 .605 0 r
F
.40721 .54366 m .40712 .54115 L .3868 .53865 L 1 .608 0 r
F
.82216 .69556 m .79746 .70285 L .79531 .70869 L .156 0 0 r
F
.82216 .69556 m .82452 .68956 L .79746 .70285 L F
.82431 .25676 m .81169 .27013 L .81595 .2759 L .188 .082 0 r
F
.82431 .25676 m .81987 .25117 L .81169 .27013 L F
.54321 .41234 m .52881 .41315 L .52965 .41576 L .804 .646 0 r
F
.54423 .41493 m .54321 .41234 L .52965 .41576 L .802 .639 0 r
F
.40895 .52932 m .3906 .52337 L .39052 .52595 L 1 .739 0 r
F
.4089 .53188 m .40895 .52932 L .39052 .52595 L 1 .73 0 r
F
.52839 .5557 m .50903 .55528 L .50893 .55768 L .829 .293 0 r
F
.52839 .5557 m .52853 .55329 L .50903 .55528 L F
.45703 .40434 m .44465 .40115 L .44408 .40356 L 1 .974 0 r
F
.45703 .40434 m .45734 .40188 L .44465 .40115 L F
.39495 .4811 m .37928 .47436 L .37872 .47701 L 1 .925 0 r
F
.39451 .48377 m .39495 .4811 L .37872 .47701 L 1 .918 0 r
F
.44243 .4109 m .43006 .40688 L .42928 .40929 L 1 .997 0 r
F
.44243 .4109 m .44297 .40844 L .43006 .40688 L F
.17106 .74966 m .13743 .73255 L .14006 .73842 L 1 .358 0 r
F
.1735 .75529 m .17106 .74966 L .14006 .73842 L 1 .332 0 r
F
.36942 .48247 m .35324 .47429 L .35275 .47718 L .452 .696 0 r
F
.37818 .47966 m .37872 .47701 L .37713 .4765 L 1 .968 0 r
F
.37713 .4765 m .35433 .46851 L .35377 .4714 L 1 .66 0 r
F
.37872 .47701 m .37928 .47436 L .37779 .47388 L 1 .975 0 r
F
.37777 .47387 m .35494 .46561 L .35433 .46851 L 1 .661 0 r
F
.37928 .47436 m .37987 .47172 L .37862 .47131 L 1 .982 0 r
F
.37843 .47124 m .35558 .46272 L .35494 .46561 L 1 .661 0 r
F
.37987 .47172 m .38048 .46907 L .37931 .46869 L 1 .989 0 r
F
.37911 .46862 m .35626 .45982 L .35558 .46272 L 1 .662 0 r
F
.38048 .46907 m .38112 .46643 L .38001 .46607 L 1 .995 0 r
F
.37982 .466 m .35697 .45692 L .35626 .45982 L 1 .662 0 r
F
.38112 .46643 m .38179 .4638 L .38074 .46345 L 1 1 0 r
F
.38055 .46339 m .35773 .45403 L .35697 .45692 L .997 .662 0 r
F
.38179 .4638 m .38249 .46117 L .38149 .46084 L 1 1 0 r
F
.38249 .46117 m .3832 .45854 L .3821 .45818 L F
.38137 .46056 m .3821 .45818 L .36916 .45391 L F
.38249 .46117 m .3821 .45818 L .38137 .46056 L F
.38063 .46317 m .38148 .46087 L .38129 .46081 L F
.38057 .46314 m .38129 .46082 L .35773 .45403 L .997 .662 0 r
F
.38129 .46082 m .3813 .46078 L .35773 .45403 L F
.38179 .4638 m .38149 .46084 L .38063 .46317 L 1 1 0 r
F
.38257 .46394 m .3813 .46078 L .38129 .46082 L .997 .662 0 r
F
.38063 .46317 m .38129 .46082 L .38057 .46314 L F
.38257 .46394 m .38129 .46082 L .38063 .46317 L F
.3813 .46078 m .36907 .45409 L .35773 .45403 L 1 1 0 r
F
.38129 .46081 m .3813 .46078 L .36832 .4565 L F
.38148 .46087 m .3813 .46078 L .38129 .46081 L F
.38063 .46317 m .38129 .46081 L .36832 .4565 L F
.38129 .46082 m .3813 .46078 L .3813 .46078 L .997 .662 0 r
F
.38148 .46087 m .38149 .46084 L .3813 .46078 L 1 1 0 r
F
.38257 .46394 m .38323 .46133 L .3813 .46078 L .997 .662 0 r
F
.38249 .46117 m .36916 .45391 L .3691 .45409 L 1 1 0 r
F
.36958 .45435 m .3691 .45409 L .36907 .45409 L F
.38249 .46117 m .3691 .45409 L .3813 .46078 L F
.38323 .46133 m .36907 .45409 L .3813 .46078 L F
.3813 .46078 m .3691 .45409 L .36832 .4565 L F
.38323 .46133 m .36987 .45409 L .3691 .45409 L F
.38323 .46133 m .3691 .45409 L .36958 .45435 L F
.38062 .46316 m .35773 .45403 L .38055 .46339 L .997 .662 0 r
F
.38055 .46339 m .36832 .4565 L .36751 .4591 L 1 1 0 r
F
.38179 .4638 m .38063 .46317 L .38055 .46339 L F
.38056 .46336 m .38062 .46316 L .38055 .46339 L .997 .662 0 r
F
.38063 .46317 m .38062 .46316 L .38055 .46339 L F
.38063 .46317 m .36832 .4565 L .38055 .46339 L 1 1 0 r
F
.38055 .46339 m .38056 .46336 L .38055 .46339 L .997 .662 0 r
F
.38257 .46394 m .38063 .46317 L .38055 .46339 L F
.3799 .46577 m .38074 .46345 L .38055 .46339 L 1 1 0 r
F
.38112 .46643 m .38074 .46345 L .3799 .46577 L F
.38194 .46656 m .38257 .46394 L .38056 .46339 L 1 .662 0 r
F
.3799 .46577 m .38056 .46339 L .35697 .45692 L F
.38194 .46656 m .38056 .46339 L .3799 .46577 L F
.3799 .46577 m .35697 .45692 L .37982 .466 L F
.3792 .46838 m .38001 .46607 L .37982 .466 L 1 .995 0 r
F
.38048 .46907 m .38001 .46607 L .3792 .46838 L F
.38133 .46918 m .38194 .46656 L .37982 .466 L 1 .662 0 r
F
.37913 .46836 m .37982 .466 L .35626 .45982 L F
.37919 .46838 m .35626 .45982 L .37911 .46862 L F
.37851 .47099 m .37931 .46869 L .37911 .46862 L 1 .989 0 r
F
.37987 .47172 m .37931 .46869 L .37851 .47099 L F
.38075 .4718 m .38133 .46918 L .37911 .46862 L 1 .661 0 r
F
.37844 .47097 m .37911 .46862 L .35558 .46272 L F
.37851 .47099 m .35558 .46272 L .37843 .47124 L F
.37786 .47361 m .37862 .47131 L .37843 .47124 L 1 .982 0 r
F
.37928 .47436 m .37862 .47131 L .37786 .47361 L F
.38019 .47442 m .38075 .4718 L .37843 .47124 L 1 .661 0 r
F
.37779 .47358 m .37843 .47124 L .35494 .46561 L F
.37785 .47361 m .35494 .46561 L .37777 .47387 L F
.37967 .47705 m .38019 .47442 L .37777 .47387 L 1 .66 0 r
F
.37715 .4762 m .37777 .47387 L .35433 .46851 L F
.37722 .47623 m .37777 .47387 L .37715 .4762 L F
.37721 .47622 m .37746 .4752 L .37777 .47387 L 1 .975 0 r
F
.37746 .4752 m .37779 .47388 L .37777 .47387 L F
.37722 .47623 m .37779 .47388 L .37721 .47622 L F
.37872 .47701 m .37788 .47418 L .37722 .47623 L F
.37788 .47418 m .37779 .47388 L .37722 .47623 L F
.37721 .47622 m .35433 .46851 L .37713 .4765 L 1 .66 0 r
F
.37713 .4765 m .36458 .46956 L .36393 .47219 L 1 .975 0 r
F
.37872 .47701 m .37722 .47623 L .37713 .4765 L F
.37714 .47647 m .37721 .47622 L .37713 .4765 L 1 .66 0 r
F
.37722 .47623 m .37721 .47622 L .37714 .4765 L F
.37722 .47623 m .36458 .46956 L .37713 .4765 L 1 .975 0 r
F
.37714 .4765 m .37714 .47647 L .37713 .4765 L 1 .66 0 r
F
.37967 .47705 m .37722 .47623 L .37714 .4765 L F
.37967 .47705 m .37777 .47387 L .37722 .47623 L F
.37777 .47387 m .36527 .46694 L .36458 .46956 L 1 .982 0 r
F
.37779 .47388 m .37777 .47387 L .37777 .47387 L F
.37777 .47387 m .36527 .46694 L .37777 .47387 L F
.37928 .47436 m .37786 .47361 L .37779 .47388 L F
.37786 .47361 m .37843 .47124 L .37779 .47358 L 1 .661 0 r
F
.37786 .47361 m .37777 .47387 L .37779 .47388 L 1 .982 0 r
F
.37777 .47387 m .37778 .47384 L .37777 .47387 L 1 .661 0 r
F
.37778 .47384 m .37785 .47361 L .37777 .47387 L F
.37786 .47361 m .37785 .47361 L .37777 .47387 L F
.37786 .47361 m .36527 .46694 L .37777 .47387 L 1 .982 0 r
F
.38019 .47442 m .37844 .47126 L .37786 .47361 L 1 .661 0 r
F
.37844 .47126 m .37843 .47124 L .37786 .47361 L F
.37843 .47124 m .36599 .46432 L .36527 .46694 L 1 .989 0 r
F
.37845 .47125 m .37843 .47124 L .37843 .47124 L F
.37843 .47124 m .36599 .46432 L .37843 .47124 L F
.37987 .47172 m .37851 .47099 L .37845 .47125 L F
.37851 .47099 m .37911 .46862 L .37844 .47097 L 1 .661 0 r
F
.37851 .47099 m .37843 .47124 L .37845 .47125 L 1 .989 0 r
F
.37843 .47125 m .37844 .47121 L .37843 .47124 L 1 .661 0 r
F
.37844 .47121 m .37851 .47099 L .37843 .47124 L F
.37851 .47099 m .37851 .47099 L .37843 .47125 L F
.37851 .47099 m .36599 .46432 L .37843 .47124 L 1 .989 0 r
F
.38075 .4718 m .37912 .46864 L .37851 .47099 L 1 .661 0 r
F
.37912 .46864 m .37911 .46862 L .37851 .47099 L F
.37911 .46862 m .36674 .46171 L .36599 .46432 L 1 .995 0 r
F
.37913 .46863 m .37911 .46862 L .37911 .46862 L F
.37911 .46862 m .36674 .46171 L .37911 .46862 L F
.38048 .46907 m .3792 .46838 L .37913 .46863 L F
.3792 .46838 m .37982 .466 L .37913 .46836 L 1 .662 0 r
F
.3792 .46838 m .37911 .46862 L .37913 .46863 L 1 .995 0 r
F
.37911 .46862 m .37912 .46859 L .37911 .46862 L 1 .662 0 r
F
.37912 .46859 m .37919 .46838 L .37911 .46862 L F
.3792 .46838 m .37919 .46838 L .37911 .46862 L F
.3792 .46838 m .36674 .46171 L .37911 .46862 L 1 .995 0 r
F
.38133 .46918 m .37982 .46602 L .3792 .46838 L 1 .662 0 r
F
.37982 .46602 m .37982 .466 L .3792 .46838 L F
.37982 .466 m .36751 .4591 L .36674 .46171 L 1 1 0 r
F
.37984 .46601 m .37982 .466 L .37982 .466 L F
.37982 .466 m .36751 .4591 L .37982 .466 L F
.38112 .46643 m .3799 .46577 L .37984 .46601 L F
.3799 .46577 m .37982 .466 L .37984 .46601 L F
.37982 .466 m .37983 .46597 L .37982 .466 L 1 .662 0 r
F
.37983 .46597 m .3799 .46577 L .37982 .466 L F
.3799 .46577 m .3799 .46577 L .37982 .466 L F
.3799 .46577 m .36751 .4591 L .37982 .466 L 1 1 0 r
F
.37976 .4657 m .38055 .46339 L .36751 .4591 L F
.3799 .46577 m .38055 .46339 L .37976 .4657 L F
.38194 .46656 m .3799 .46577 L .37982 .466 L 1 .662 0 r
F
.37905 .4683 m .37982 .466 L .36674 .46171 L 1 .995 0 r
F
.3792 .46838 m .37982 .466 L .37905 .4683 L F
.38133 .46918 m .3792 .46838 L .37911 .46862 L 1 .662 0 r
F
.37837 .47092 m .37911 .46862 L .36599 .46432 L 1 .989 0 r
F
.37851 .47099 m .37911 .46862 L .37837 .47092 L F
.38075 .4718 m .37851 .47099 L .37843 .47125 L 1 .661 0 r
F
.37771 .47353 m .37843 .47124 L .36527 .46694 L 1 .982 0 r
F
.37786 .47361 m .37843 .47124 L .37771 .47353 L F
.38019 .47442 m .37786 .47361 L .37777 .47387 L 1 .661 0 r
F
.37708 .47615 m .37777 .47387 L .36458 .46956 L 1 .975 0 r
F
.37721 .47622 m .37777 .47387 L .37708 .47615 L F
.37917 .47967 m .37967 .47705 L .37714 .4765 L 1 .658 0 r
F
.37713 .4765 m .37714 .4765 L .37713 .4765 L F
.37917 .47967 m .37714 .4765 L .37713 .4765 L F
.37661 .47884 m .37713 .4765 L .35377 .4714 L F
.37818 .47966 m .37724 .47682 L .37661 .47884 L 1 .968 0 r
F
.37724 .47682 m .37713 .4765 L .37661 .47884 L F
.37652 .47913 m .35377 .4714 L .35324 .47429 L 1 .658 0 r
F
.37661 .47884 m .35377 .4714 L .37652 .47913 L F
.37652 .47913 m .36393 .47219 L .3633 .47482 L 1 .968 0 r
F
.37818 .47966 m .37661 .47884 L .37652 .47913 L F
.37661 .47884 m .36393 .47219 L .37652 .47913 L F
.37917 .47967 m .37661 .47884 L .37652 .47913 L 1 .658 0 r
F
.37917 .47967 m .37713 .4765 L .37661 .47884 L F
.37661 .47884 m .37713 .4765 L .37647 .47877 L 1 .968 0 r
F
.37647 .47877 m .37713 .4765 L .36393 .47219 L F
.36942 .48247 m .37812 .47997 L .35324 .47429 L .452 .696 0 r
F
.37812 .47997 m .37652 .47913 L .35324 .47429 L F
.37767 .48232 m .37812 .47997 L .3633 .47482 L 1 .961 0 r
F
.37812 .47997 m .37818 .47966 L .37652 .47913 L F
.37812 .47997 m .37652 .47913 L .3633 .47482 L F
.37812 .47997 m .37917 .47967 L .37652 .47913 L .452 .696 0 r
F
.36908 .48535 m .36942 .48247 L .35275 .47718 L 1 .895 0 r
F
.48341 .39872 m .47048 .39696 L .47044 .39943 L 1 .904 0 r
F
.48341 .39872 m .48319 .39621 L .47048 .39696 L F
.46518 .88759 m .46512 .88447 L .43084 .88399 L .713 .039 0 r
F
.49877 .88706 m .46512 .88447 L .46518 .88759 L .655 .032 0 r
F
.49877 .88706 m .49939 .88393 L .46512 .88447 L F
.55795 .60779 m .53754 .60936 L .53698 .61173 L .589 .05 0 r
F
.55795 .60779 m .55869 .60543 L .53754 .60936 L F
.42802 .55252 m .4074 .54869 L .40749 .5512 L 1 .613 0 r
F
.42802 .55508 m .42802 .55252 L .40749 .5512 L 1 .604 0 r
F
.38628 .52298 m .36721 .5162 L .36719 .51893 L 1 .713 0 r
F
.38633 .52563 m .38628 .52298 L .36719 .51893 L 1 .705 0 r
F
.47043 .39919 m .45791 .3967 L .4576 .39913 L 1 .941 0 r
F
.47043 .39919 m .47048 .39671 L .45791 .3967 L F
.42835 .54943 m .40896 .54449 L .40902 .54696 L 1 .622 0 r
F
.42841 .55188 m .42835 .54943 L .40902 .54696 L 1 .611 0 r
F
.68002 .83943 m .65116 .84149 L .64845 .84561 L .357 0 0 r
F
.68002 .83943 m .68324 .83519 L .65116 .84149 L F
.46796 .62852 m .46795 .62624 L .44502 .62583 L .935 .188 0 r
F
.4906 .62777 m .46795 .62624 L .46796 .62852 L .855 .107 0 r
F
.4906 .62777 m .4908 .62553 L .46795 .62624 L F
.50633 .23424 m .51872 .09866 L .52078 .09286 L 1 .544 0 r
F
.51872 .09866 m .51868 .0987 L .51958 .09584 L .177 0 0 r
F
.51872 .09866 m .5188 .09776 L .51958 .09584 L 1 .544 0 r
F
.51872 .09866 m .51958 .09584 L .52078 .09286 L F
.52691 .0889 m .51872 .09866 L .52097 .09139 L .177 0 0 r
F
.51872 .09866 m .51958 .09584 L .52097 .09139 L F
.46863 .56371 m .44847 .56067 L .44852 .56303 L 1 .464 0 r
F
.46863 .56605 m .46863 .56371 L .44852 .56303 L 1 .452 0 r
F
.48873 .56584 m .46863 .56371 L .46863 .56605 L .96 .394 0 r
F
.48873 .56584 m .48879 .56351 L .46863 .56371 L F
.82376 .25711 m .81079 .27069 L .81499 .27647 L .196 .083 0 r
F
.82376 .25711 m .81937 .2515 L .81079 .27069 L F
.52439 .40021 m .51062 .40035 L .51132 .40293 L .88 .74 0 r
F
.5253 .40279 m .52439 .40021 L .51132 .40293 L .877 .734 0 r
F
.35206 .54621 m .33406 .53671 L .33398 .53984 L 1 .821 0 r
F
.35205 .54932 m .35206 .54621 L .33398 .53984 L 1 .809 0 r
F
.4686 .56687 m .44831 .56378 L .44834 .56624 L 1 .484 0 r
F
.46859 .56927 m .4686 .56687 L .44834 .56624 L 1 .471 0 r
F
.48884 .56913 m .4686 .56687 L .46859 .56927 L .966 .41 0 r
F
.48884 .56913 m .48891 .56674 L .4686 .56687 L F
.36508 .81847 m .32935 .81627 L .33134 .82023 L .948 .116 0 r
F
.36656 .82238 m .36508 .81847 L .33134 .82023 L .936 .094 0 r
F
.5485 .54641 m .5295 .54667 L .52942 .54919 L .772 .272 0 r
F
.5485 .54641 m .5486 .54389 L .5295 .54667 L F
.74208 .55792 m .72187 .56445 L .7212 .56902 L .236 .018 0 r
F
.74208 .55792 m .74282 .55327 L .72187 .56445 L F
.66926 .44373 m .65901 .44827 L .65802 .45239 L 0 0 0 r
F
.66926 .44373 m .67035 .43959 L .65901 .44827 L F
.53523 .6186 m .51395 .61921 L .51356 .62148 L .68 .059 0 r
F
.53523 .6186 m .53583 .61635 L .51395 .61921 L F
.56541 .51637 m .54771 .51754 L .5478 .52015 L .703 .28 0 r
F
.56541 .51637 m .5653 .51375 L .54771 .51754 L F
.39565 .38854 m .38762 .38452 L .38581 .38685 L 1 1 0 r
F
.39565 .38854 m .39722 .38602 L .38762 .38452 L F
.42557 .42162 m .41298 .41662 L .41205 .41907 L F
.42557 .42162 m .42629 .41912 L .41298 .41662 L F
.70929 .62201 m .68706 .62659 L .68602 .63084 L .311 .022 0 r
F
.70929 .62201 m .71058 .61774 L .68706 .62659 L F
.56678 .5221 m .54868 .5232 L .54874 .52583 L .711 .278 0 r
F
.56678 .5221 m .56669 .51946 L .54868 .5232 L F
.47044 .39943 m .45796 .39701 L .45765 .39944 L 1 .946 0 r
F
.47044 .39943 m .47048 .39696 L .45796 .39701 L F
.54272 .41281 m .52854 .41346 L .52938 .41606 L .788 .634 0 r
F
.54373 .41539 m .54272 .41281 L .52938 .41606 L .786 .627 0 r
F
.08659 .53958 m .06418 .5148 L .06375 .52164 L 1 .833 0 r
F
.08631 .54633 m .08659 .53958 L .06375 .52164 L 1 .815 0 r
F
.77449 .76955 m .74748 .77425 L .74473 .7795 L .244 0 0 r
F
.77449 .76955 m .77757 .76414 L .74748 .77425 L F
.31726 .85436 m .28104 .84509 L .28391 .84923 L .973 .076 0 r
F
.31965 .85829 m .31726 .85436 L .28391 .84923 L .955 .072 0 r
F
.52415 .40058 m .51054 .40053 L .51123 .4031 L .863 .729 0 r
F
.52505 .40314 m .52415 .40058 L .51123 .4031 L .861 .723 0 r
F
.36908 .48535 m .35275 .47718 L .35229 .48006 L 1 .895 0 r
F
.36877 .48822 m .36908 .48535 L .35229 .48006 L 1 .885 0 r
F
.54218 .40975 m .52795 .41055 L .52881 .41315 L .806 .653 0 r
F
.54321 .41234 m .54218 .40975 L .52881 .41315 L .804 .646 0 r
F
.76221 .46764 m .74795 .47591 L .74797 .48092 L .065 .004 0 r
F
.76221 .46764 m .76203 .46263 L .74795 .47591 L F
.72154 .8032 m .69429 .80694 L .69144 .81145 L .285 0 0 r
F
.72154 .8032 m .72481 .79857 L .69429 .80694 L F
.62718 .53879 m .61114 .54302 L .6105 .546 L .307 .024 0 r
F
.62718 .53879 m .6279 .5358 L .61114 .54302 L F
.54762 .54308 m .52896 .54348 L .52888 .54596 L .762 .262 0 r
F
.54762 .54308 m .54773 .54059 L .52896 .54348 L F
.72187 .22811 m .7216 .22829 L .72429 .23478 L 0 0 0 r
F
.72187 .22811 m .72083 .22018 L .7216 .22829 L F
.44847 .56067 m .42855 .55672 L .42864 .55911 L 1 .529 0 r
F
.44852 .56303 m .44847 .56067 L .42864 .55911 L 1 .517 0 r
F
.50888 .56815 m .48891 .56674 L .48884 .56913 L .901 .343 0 r
F
.50888 .56815 m .50901 .56576 L .48891 .56674 L F
.4089 .53188 m .39052 .52595 L .39047 .52852 L 1 .73 0 r
F
.40888 .53443 m .4089 .53188 L .39047 .52852 L 1 .72 0 r
F
.39872 .46526 m .38392 .45872 L .38323 .46133 L 1 .955 0 r
F
.39872 .46526 m .39929 .46263 L .38392 .45872 L F
.39818 .4679 m .39872 .46526 L .38323 .46133 L 1 .948 0 r
F
.50857 .56476 m .48879 .56351 L .48873 .56584 L .893 .329 0 r
F
.50857 .56476 m .5087 .56242 L .48879 .56351 L F
.63687 .85058 m .60764 .85208 L .60531 .85569 L .391 0 0 r
F
.63687 .85058 m .63975 .84688 L .60764 .85208 L F
.86786 .59797 m .84559 .60782 L .8446 .61432 L .089 0 0 r
F
.86786 .59797 m .86894 .59135 L .84559 .60782 L F
.39818 .4679 m .38323 .46133 L .38257 .46394 L 1 .948 0 r
F
.39766 .47053 m .39818 .4679 L .38257 .46394 L 1 .941 0 r
F
.39929 .46263 m .38464 .45612 L .38392 .45872 L 1 .961 0 r
F
.39929 .46263 m .39987 .46 L .38464 .45612 L F
.68704 .22107 m .6912 .21365 L .69393 .22032 L 1 .146 0 r
F
.68704 .22107 m .6848 .2143 L .6912 .21365 L F
.44831 .56378 m .42808 .56014 L .42813 .56264 L 1 .546 0 r
F
.44834 .56624 m .44831 .56378 L .42813 .56264 L 1 .533 0 r
F
.67423 .66786 m .65151 .67156 L .65032 .67563 L .349 .022 0 r
F
.67423 .66786 m .67576 .66387 L .65151 .67156 L F
.64855 .49617 m .63508 .50089 L .63446 .50424 L .184 .002 0 r
F
.64855 .49617 m .64925 .49282 L .63508 .50089 L F
.39766 .47053 m .38257 .46394 L .38194 .46656 L 1 .941 0 r
F
.39717 .47317 m .39766 .47053 L .38194 .46656 L 1 .935 0 r
F
.39987 .46 m .38538 .45352 L .38464 .45612 L 1 .968 0 r
F
.39987 .46 m .40048 .45738 L .38538 .45352 L F
.69094 .38738 m .6844 .39107 L .68277 .39663 L 0 0 0 r
F
.69094 .38738 m .69259 .38181 L .6844 .39107 L F
.58073 .59312 m .56146 .59564 L .5608 .59814 L .488 .042 0 r
F
.58073 .59312 m .58155 .59062 L .56146 .59564 L F
.09448 .53182 m .07063 .50757 L .07031 .51429 L 1 .836 0 r
F
.09432 .5384 m .09448 .53182 L .07031 .51429 L 1 .818 0 r
F
.5092 .39522 m .49592 .39478 L .4964 .39731 L .938 .811 0 r
F
.50991 .39779 m .5092 .39522 L .4964 .39731 L .935 .804 0 r
F
.50911 .39541 m .49592 .39478 L .4964 .39732 L .924 .8 0 r
F
.50983 .39797 m .50911 .39541 L .4964 .39732 L .921 .794 0 r
F
.39717 .47317 m .38194 .46656 L .38133 .46918 L 1 .935 0 r
F
.39669 .47581 m .39717 .47317 L .38133 .46918 L 1 .928 0 r
F
.4203 .36253 m .41387 .3629 L .41213 .36503 L 1 1 0 r
F
.4203 .36253 m .42174 .36007 L .41387 .3629 L F
.43683 .34904 m .43085 .35363 L .42944 .35591 L 1 .71 0 r
F
.43683 .34904 m .43789 .34604 L .43085 .35363 L F
.40048 .45738 m .38614 .45093 L .38538 .45352 L 1 .974 0 r
F
.40048 .45738 m .4011 .45476 L .38614 .45093 L F
.52879 .5615 m .50923 .56093 L .50913 .56336 L .835 .293 0 r
F
.52879 .5615 m .52895 .55908 L .50923 .56093 L F
.39159 .40491 m .3815 .399 L .37991 .40149 L 1 1 0 r
F
.39159 .40491 m .39291 .40225 L .3815 .399 L F
.39948 .41585 m .39159 .40491 L .37991 .40149 L .928 .07 0 r
F
.41298 .41662 m .39291 .40225 L .39159 .40491 L .805 .552 0 r
F
.41205 .41907 m .39159 .40491 L .39948 .41585 L .812 .556 0 r
F
.41205 .41907 m .41298 .41662 L .39159 .40491 L F
.40721 .54366 m .3868 .53865 L .38693 .54122 L 1 .608 0 r
F
.40731 .54618 m .40721 .54366 L .38693 .54122 L 1 .61 0 r
F
.88679 .45038 m .86787 .46295 L .86896 .46973 L .08 .019 0 r
F
.88679 .45038 m .88569 .44354 L .86787 .46295 L F
.44297 .40844 m .43086 .40448 L .43006 .40688 L 1 1 0 r
F
.44297 .40844 m .44352 .40599 L .43086 .40448 L F
.82672 .70595 m .80095 .71266 L .79875 .71861 L .18 0 0 r
F
.82672 .70595 m .82914 .69983 L .80095 .71266 L F
.42802 .55508 m .40749 .5512 L .4076 .5537 L 1 .604 0 r
F
.42804 .55762 m .42802 .55508 L .4076 .5537 L 1 .594 0 r
F
.39669 .47581 m .38133 .46918 L .38075 .4718 L 1 .928 0 r
F
.39624 .47845 m .39669 .47581 L .38075 .4718 L 1 .92 0 r
F
.41724 .37756 m .4093 .37554 L .4077 .37777 L 1 1 0 r
F
.41724 .37756 m .41854 .37505 L .4093 .37554 L F
.5655 .51897 m .5478 .52015 L .54786 .52275 L .7 .269 0 r
F
.5655 .51897 m .56541 .51637 L .5478 .52015 L F
.4011 .45476 m .38694 .44835 L .38614 .45093 L 1 .98 0 r
F
.4011 .45476 m .40175 .45214 L .38694 .44835 L F
.70795 .3161 m .706 .31735 L .70528 .32436 L 0 0 0 r
F
.70795 .3161 m .70841 .30936 L .706 .31735 L F
.53193 .88554 m .49939 .88393 L .49877 .88706 L .585 .023 0 r
F
.53193 .88554 m .53322 .88239 L .49939 .88393 L F
.13377 .64829 m .10325 .62873 L .10469 .635 L 1 .593 0 r
F
.13518 .65432 m .13377 .64829 L .10469 .635 L 1 .573 0 r
F
.52823 .55809 m .50893 .55768 L .50882 .56006 L .826 .281 0 r
F
.52823 .55809 m .52839 .5557 L .50893 .55768 L F
.38633 .52563 m .36719 .51893 L .3672 .52164 L 1 .705 0 r
F
.3864 .52826 m .38633 .52563 L .3672 .52164 L 1 .697 0 r
F
.45734 .40188 m .44522 .39876 L .44465 .40115 L 1 .98 0 r
F
.45734 .40188 m .45765 .39944 L .44522 .39876 L F
.82866 .26241 m .81595 .2759 L .82011 .28172 L .18 .08 0 r
F
.82866 .26241 m .82431 .25676 L .81595 .2759 L F
.36877 .48822 m .35229 .48006 L .35187 .48293 L 1 .885 0 r
F
.36849 .49107 m .36877 .48822 L .35187 .48293 L 1 .875 0 r
F
.54169 .41024 m .52769 .41087 L .52854 .41346 L .79 .641 0 r
F
.54272 .41281 m .54169 .41024 L .52854 .41346 L .788 .634 0 r
F
.56683 .52472 m .54874 .52583 L .54879 .52844 L .708 .267 0 r
F
.56683 .52472 m .56678 .5221 L .54874 .52583 L F
.39781 .60609 m .3759 .59931 L .37637 .6021 L 1 .5 0 r
F
.39821 .60878 m .39781 .60609 L .37637 .6021 L 1 .485 0 r
F
.39624 .47845 m .38075 .4718 L .38019 .47442 L 1 .92 0 r
F
.39581 .48109 m .39624 .47845 L .38019 .47442 L 1 .913 0 r
F
.48319 .39621 m .47053 .3945 L .47048 .39696 L 1 .91 0 r
F
.48319 .39621 m .48297 .39372 L .47053 .3945 L F
.42629 .41912 m .41392 .41419 L .41298 .41662 L 1 1 0 r
F
.42629 .41912 m .42701 .41664 L .41392 .41419 L F
.42841 .55188 m .40902 .54696 L .4091 .54942 L 1 .611 0 r
F
.42847 .55431 m .42841 .55188 L .4091 .54942 L 1 .6 0 r
F
.40175 .45214 m .38775 .44578 L .38694 .44835 L 1 .986 0 r
F
.40175 .45214 m .40242 .44954 L .38775 .44578 L F
.52347 .39763 m .50991 .39779 L .51062 .40035 L .883 .746 0 r
F
.52439 .40021 m .52347 .39763 L .51062 .40035 L .88 .74 0 r
F
.51274 .62592 m .4908 .62553 L .4906 .62777 L .764 .067 0 r
F
.51274 .62592 m .51316 .62372 L .4908 .62553 L F
.374 .58501 m .3535 .57677 L .35383 .57974 L 1 .637 0 r
F
.37432 .58791 m .374 .58501 L .35383 .57974 L 1 .623 0 r
F
.57357 .45564 m .55776 .45742 L .55842 .46013 L .686 .431 0 r
F
.57432 .45833 m .55842 .46013 L .55906 .46283 L .684 .422 0 r
F
.57432 .45833 m .57357 .45564 L .55842 .46013 L F
.57279 .45295 m .55708 .45472 L .55776 .45742 L .689 .441 0 r
F
.57357 .45564 m .57279 .45295 L .55776 .45742 L .686 .431 0 r
F
.57504 .46102 m .55906 .46283 L .55967 .46554 L .681 .412 0 r
F
.57504 .46102 m .57432 .45833 L .55906 .46283 L F
.54113 .40716 m .52708 .40796 L .52795 .41055 L .809 .66 0 r
F
.54218 .40975 m .54113 .40716 L .52795 .41055 L .806 .653 0 r
F
.66953 .11835 m .66283 .12686 L .66932 .13018 L .351 .466 0 r
F
.66953 .11835 m .66303 .11532 L .66283 .12686 L F
.57199 .45027 m .55637 .45203 L .55708 .45472 L .691 .45 0 r
F
.57279 .45295 m .57199 .45027 L .55708 .45472 L .689 .441 0 r
F
.60389 .57147 m .58604 .57489 L .58535 .57759 L .386 .033 0 r
F
.60389 .57147 m .60471 .56876 L .58604 .57489 L F
.54837 .54892 m .52942 .54919 L .52933 .55168 L .769 .26 0 r
F
.54837 .54892 m .5485 .54641 L .52942 .54919 L F
.35205 .54932 m .33398 .53984 L .33394 .54297 L 1 .809 0 r
F
.35208 .55243 m .35205 .54932 L .33394 .54297 L 1 .797 0 r
F
.57573 .46372 m .55967 .46554 L .56026 .46825 L .678 .402 0 r
F
.57573 .46372 m .57504 .46102 L .55967 .46554 L F
.47048 .39671 m .45823 .39428 L .45791 .3967 L 1 .948 0 r
F
.47048 .39671 m .47053 .39425 L .45823 .39428 L F
.18612 .7216 m .1521 .70674 L .15444 .71234 L 1 .417 0 r
F
.18827 .72694 m .18612 .7216 L .15444 .71234 L 1 .396 0 r
F
.87441 .607 m .85061 .61647 L .84962 .62309 L .123 0 0 r
F
.87441 .607 m .87548 .60023 L .85061 .61647 L F
.57116 .44759 m .55564 .44934 L .55637 .45203 L .694 .46 0 r
F
.57199 .45027 m .57116 .44759 L .55637 .45203 L .691 .45 0 r
F
.39581 .48109 m .38019 .47442 L .37967 .47705 L 1 .913 0 r
F
.39541 .48373 m .39581 .48109 L .37967 .47705 L 1 .905 0 r
F
.40242 .44954 m .3886 .44321 L .38775 .44578 L 1 .992 0 r
F
.40242 .44954 m .40311 .44694 L .3886 .44321 L F
.57639 .46642 m .56026 .46825 L .56082 .47097 L .675 .393 0 r
F
.57639 .46642 m .57573 .46372 L .56026 .46825 L F
.82804 .26279 m .81499 .27647 L .81909 .2823 L .187 .08 0 r
F
.82804 .26279 m .82376 .25711 L .81499 .27647 L F
.46863 .56605 m .44852 .56303 L .44857 .56537 L 1 .452 0 r
F
.46862 .56836 m .46863 .56605 L .44857 .56537 L 1 .44 0 r
F
.48865 .56815 m .46863 .56605 L .46862 .56836 L .957 .382 0 r
F
.48865 .56815 m .48873 .56584 L .46863 .56605 L F
.39722 .38602 m .38946 .38223 L .38762 .38452 L 1 1 0 r
F
.39722 .38602 m .3988 .38353 L .38946 .38223 L F
.34829 .45839 m .34934 .45535 L .33608 .44943 L F
.46859 .56927 m .44834 .56624 L .44838 .56868 L 1 .471 0 r
F
.46858 .57166 m .46859 .56927 L .44838 .56868 L 1 .459 0 r
F
.48877 .5715 m .46859 .56927 L .46858 .57166 L .963 .398 0 r
F
.48877 .5715 m .48884 .56913 L .46859 .56927 L F
.52323 .39802 m .50983 .39797 L .51054 .40053 L .866 .735 0 r
F
.52415 .40058 m .52323 .39802 L .51054 .40053 L .863 .729 0 r
F
.5703 .44492 m .55489 .44665 L .55564 .44934 L .697 .469 0 r
F
.57116 .44759 m .5703 .44492 L .55564 .44934 L .694 .46 0 r
F
.60949 .73024 m .58616 .73495 L .58505 .73896 L .38 .02 0 r
F
.60949 .73024 m .61098 .7265 L .58616 .73495 L F
.34829 .45839 m .33608 .44943 L .33489 .45238 L 1 1 0 r
F
.34729 .46144 m .34829 .45839 L .33489 .45238 L F
.89326 .45692 m .87333 .46961 L .87449 .47648 L .103 .024 0 r
F
.89326 .45692 m .89202 .45 L .87333 .46961 L F
.40888 .53443 m .39047 .52852 L .39043 .53107 L 1 .72 0 r
F
.40887 .53697 m .40888 .53443 L .39043 .53107 L 1 .71 0 r
F
.57703 .46913 m .56082 .47097 L .56136 .47368 L .673 .383 0 r
F
.57703 .46913 m .57639 .46642 L .56082 .47097 L F
.07553 .55506 m .05125 .52991 L .05116 .53694 L 1 .791 0 r
F
.07556 .56196 m .07553 .55506 L .05116 .53694 L 1 .772 0 r
F
.28453 .79478 m .24832 .7873 L .25098 .79181 L 1 .217 0 r
F
.28677 .79912 m .28453 .79478 L .25098 .79181 L 1 .195 0 r
F
.34729 .46144 m .33489 .45238 L .33374 .45536 L 1 1 0 r
F
.34631 .46451 m .34729 .46144 L .33374 .45536 L F
.22523 .80156 m .19008 .78773 L .19316 .79289 L 1 .204 0 r
F
.22799 .80648 m .22523 .80156 L .19316 .79289 L 1 .177 0 r
F
.39541 .48373 m .37967 .47705 L .37917 .47967 L 1 .905 0 r
F
.39502 .48636 m .39541 .48373 L .37917 .47967 L 1 .898 0 r
F
.56942 .44226 m .55412 .44397 L .55489 .44665 L .699 .478 0 r
F
.5703 .44492 m .56942 .44226 L .55489 .44665 L .697 .469 0 r
F
.40311 .44694 m .38946 .44066 L .3886 .44321 L 1 .998 0 r
F
.40311 .44694 m .40383 .44435 L .38946 .44066 L F
.5475 .54555 m .52888 .54596 L .52878 .54842 L .759 .25 0 r
F
.5475 .54555 m .54762 .54308 L .52888 .54596 L F
.39291 .40225 m .38312 .39656 L .3815 .399 L 1 1 0 r
F
.39291 .40225 m .39426 .39963 L .38312 .39656 L F
.41392 .41419 m .39426 .39963 L .39291 .40225 L .798 .548 0 r
F
.41298 .41662 m .41392 .41419 L .39291 .40225 L .805 .552 0 r
F
.57764 .47183 m .56136 .47368 L .56188 .4764 L .67 .373 0 r
F
.57764 .47183 m .57703 .46913 L .56136 .47368 L F
.47048 .39696 m .45828 .3946 L .45796 .39701 L 1 .952 0 r
F
.47048 .39696 m .47053 .3945 L .45828 .3946 L F
.64039 .70309 m .61759 .70701 L .61638 .711 L .365 .019 0 r
F
.64039 .70309 m .64199 .69929 L .61759 .70701 L F
.34631 .46451 m .33374 .45536 L .33263 .45835 L 1 1 0 r
F
.34537 .46759 m .34631 .46451 L .33263 .45835 L F
.56555 .52157 m .54786 .52275 L .54791 .52534 L .697 .258 0 r
F
.56555 .52157 m .5655 .51897 L .54786 .52275 L F
.36849 .49107 m .35187 .48293 L .35149 .4858 L 1 .875 0 r
F
.36824 .49392 m .36849 .49107 L .35149 .4858 L 1 .866 0 r
F
.56851 .4396 m .55333 .4413 L .55412 .44397 L .702 .487 0 r
F
.56942 .44226 m .56851 .4396 L .55412 .44397 L .699 .478 0 r
F
.44502 .62583 m .42206 .62188 L .42242 .62434 L 1 .279 0 r
F
.44522 .62819 m .44502 .62583 L .42242 .62434 L 1 .262 0 r
F
.46796 .62852 m .44502 .62583 L .44522 .62819 L .935 .188 0 r
F
.42171 .61938 m .39907 .61408 L .39954 .61669 L 1 .379 0 r
F
.42206 .62188 m .42171 .61938 L .39954 .61669 L 1 .362 0 r
F
.54065 .40767 m .52683 .40829 L .52769 .41087 L .792 .648 0 r
F
.54169 .41024 m .54065 .40767 L .52769 .41087 L .79 .641 0 r
F
.34537 .46759 m .33263 .45835 L .33156 .46135 L 1 1 0 r
F
.34447 .47068 m .34537 .46759 L .33156 .46135 L F
.67677 .12009 m .66983 .12929 L .67635 .1326 L .369 .501 0 r
F
.67677 .12009 m .67016 .11721 L .66983 .12929 L F
.57822 .47454 m .56188 .4764 L .56237 .47911 L .667 .362 0 r
F
.57822 .47454 m .57764 .47183 L .56188 .4764 L F
.44834 .56624 m .42813 .56264 L .4282 .56511 L 1 .533 0 r
F
.44838 .56868 m .44834 .56624 L .4282 .56511 L 1 .521 0 r
F
.44852 .56303 m .42864 .55911 L .42874 .56148 L 1 .517 0 r
F
.44857 .56537 m .44852 .56303 L .42874 .56148 L 1 .506 0 r
F
.56453 .87294 m .53343 .87256 L .53218 .87568 L .499 .012 0 r
F
.56453 .87294 m .56642 .86977 L .53343 .87256 L F
.27612 .82632 m .24084 .81491 L .24384 .81947 L 1 .111 0 r
F
.27874 .83065 m .27612 .82632 L .24384 .81947 L 1 .087 0 r
F
.50874 .57051 m .48884 .56913 L .48877 .5715 L .897 .33 0 r
F
.50874 .57051 m .50888 .56815 L .48884 .56913 L F
.56686 .52734 m .54879 .52844 L .54881 .53105 L .704 .255 0 r
F
.56686 .52734 m .56683 .52472 L .54879 .52844 L F
.40383 .44435 m .39036 .43812 L .38946 .44066 L 1 1 0 r
F
.40383 .44435 m .40456 .44177 L .39036 .43812 L F
.42804 .55762 m .4076 .5537 L .40771 .55619 L 1 .594 0 r
F
.42808 .56014 m .42804 .55762 L .40771 .55619 L 1 .584 0 r
F
.42701 .41664 m .41488 .41178 L .41392 .41419 L 1 1 0 r
F
.42701 .41664 m .42776 .41417 L .41488 .41178 L F
.50842 .56707 m .48873 .56584 L .48865 .56815 L .89 .317 0 r
F
.50842 .56707 m .50857 .56476 L .48873 .56584 L F
.50847 .39266 m .49543 .39225 L .49592 .39478 L .942 .817 0 r
F
.5092 .39522 m .50847 .39266 L .49592 .39478 L .938 .811 0 r
F
.50839 .39286 m .49543 .39225 L .49592 .39478 L .927 .806 0 r
F
.50911 .39541 m .50839 .39286 L .49592 .39478 L .924 .8 0 r
F
.54006 .40459 m .5262 .40537 L .52708 .40796 L .811 .666 0 r
F
.54113 .40716 m .54006 .40459 L .52708 .40796 L .809 .66 0 r
F
.56758 .43695 m .55251 .43863 L .55333 .4413 L .704 .496 0 r
F
.56851 .4396 m .56758 .43695 L .55333 .4413 L .702 .487 0 r
F
.44352 .40599 m .43167 .40211 L .43086 .40448 L 1 1 0 r
F
.44352 .40599 m .44408 .40356 L .43167 .40211 L F
.40731 .54618 m .38693 .54122 L .38707 .54377 L 1 .61 0 r
F
.4074 .54869 m .40731 .54618 L .38707 .54377 L 1 .609 0 r
F
.46528 .88105 m .46522 .87803 L .43148 .87761 L .703 .037 0 r
F
.49832 .88039 m .46522 .87803 L .46528 .88105 L .641 .029 0 r
F
.49832 .88039 m .49893 .87738 L .46522 .87803 L F
.34447 .47068 m .33156 .46135 L .33053 .46437 L 1 1 0 r
F
.34361 .47378 m .34447 .47068 L .33053 .46437 L F
.52861 .56391 m .50913 .56336 L .50901 .56576 L .831 .281 0 r
F
.52861 .56391 m .52879 .5615 L .50913 .56336 L F
.57877 .47724 m .56237 .47911 L .56283 .48183 L .664 .352 0 r
F
.57877 .47724 m .57822 .47454 L .56237 .47911 L F
.58007 .75434 m .55581 .76005 L .55486 .76407 L .397 .022 0 r
F
.58007 .75434 m .5814 .7506 L .55581 .76005 L F
.3864 .52826 m .3672 .52164 L .36724 .52433 L 1 .697 0 r
F
.38648 .53088 m .3864 .52826 L .36724 .52433 L 1 .69 0 r
F
.35809 .86963 m .32209 .86213 L .32459 .86587 L .902 .065 0 r
F
.36003 .87318 m .35809 .86963 L .32459 .86587 L .882 .061 0 r
F
.52254 .39506 m .5092 .39522 L .50991 .39779 L .886 .752 0 r
F
.52347 .39763 m .52254 .39506 L .50991 .39779 L .883 .746 0 r
F
.67594 .12155 m .66932 .13018 L .67575 .13361 L .332 .429 0 r
F
.67594 .12155 m .66953 .11835 L .66932 .13018 L F
.55719 .61012 m .53698 .61173 L .53642 .61405 L .579 .048 0 r
F
.55719 .61012 m .55795 .60779 L .53698 .61173 L F
.74127 .56255 m .7212 .56902 L .72049 .57356 L .231 .016 0 r
F
.74127 .56255 m .74208 .55792 L .7212 .56902 L F
.56662 .43431 m .55167 .43597 L .55251 .43863 L .706 .504 0 r
F
.56758 .43695 m .56662 .43431 L .55251 .43863 L .704 .496 0 r
F
.40456 .44177 m .39128 .43559 L .39036 .43812 L 1 1 0 r
F
.40456 .44177 m .40531 .4392 L .39128 .43559 L F
.76235 .47264 m .74797 .48092 L .74795 .48591 L .067 .004 0 r
F
.76235 .47264 m .76221 .46764 L .74797 .48092 L F
.43789 .34604 m .43228 .35137 L .43085 .35363 L .989 .567 0 r
F
.43789 .34604 m .43895 .343 L .43228 .35137 L F
.52805 .56046 m .50882 .56006 L .5087 .56242 L .823 .269 0 r
F
.52805 .56046 m .52823 .55809 L .50882 .56006 L F
.42847 .55431 m .4091 .54942 L .4092 .55186 L 1 .6 0 r
F
.42855 .55672 m .42847 .55431 L .4092 .55186 L 1 .589 0 r
F
.45765 .39944 m .4458 .39639 L .44522 .39876 L 1 .986 0 r
F
.45765 .39944 m .45796 .39701 L .4458 .39639 L F
.66821 .44777 m .65802 .45239 L .65708 .45641 L 0 0 0 r
F
.66821 .44777 m .66926 .44373 L .65802 .45239 L F
.57176 .45323 m .55638 .45493 L .55705 .45761 L .675 .426 0 r
F
.57251 .4559 m .55705 .45761 L .55769 .4603 L .673 .416 0 r
F
.57251 .4559 m .57176 .45323 L .55705 .45761 L F
.62643 .54175 m .6105 .546 L .60985 .54895 L .303 .022 0 r
F
.62643 .54175 m .62718 .53879 L .6105 .546 L F
.57324 .45856 m .55769 .4603 L .55831 .46298 L .67 .407 0 r
F
.57324 .45856 m .57251 .4559 L .55769 .4603 L F
.41854 .37505 m .41092 .37333 L .4093 .37554 L 1 1 0 r
F
.41854 .37505 m .41985 .37256 L .41092 .37333 L F
.34361 .47378 m .33053 .46437 L .32954 .46741 L F
.34278 .47689 m .34361 .47378 L .32954 .46741 L F
.57098 .45058 m .55569 .45226 L .55638 .45493 L .678 .436 0 r
F
.57176 .45323 m .57098 .45058 L .55638 .45493 L .675 .426 0 r
F
.67612 .83271 m .64805 .83524 L .64535 .83921 L .338 0 0 r
F
.67612 .83271 m .67933 .82863 L .64805 .83524 L F
.4886 .2856 m .49847 .10434 L .50239 .13779 L 1 .636 0 r
F
.57394 .46123 m .55831 .46298 L .5589 .46567 L .667 .397 0 r
F
.57394 .46123 m .57324 .45856 L .55831 .46298 L F
.54822 .55141 m .52933 .55168 L .52922 .55417 L .765 .248 0 r
F
.54822 .55141 m .54837 .54892 L .52933 .55168 L F
.57929 .47995 m .56283 .48183 L .56328 .48454 L .661 .342 0 r
F
.57929 .47995 m .57877 .47724 L .56283 .48183 L F
.57017 .44792 m .55498 .44958 L .55569 .45226 L .68 .445 0 r
F
.57098 .45058 m .57017 .44792 L .55569 .45226 L .678 .436 0 r
F
.83291 .26813 m .82011 .28172 L .82417 .28761 L .172 .077 0 r
F
.83291 .26813 m .82866 .26241 L .82011 .28172 L F
.72241 .23626 m .72429 .23478 L .72672 .24136 L .813 .147 0 r
F
.72241 .23626 m .72187 .22811 L .72429 .23478 L F
.48297 .39372 m .47058 .39206 L .47053 .3945 L 1 .917 0 r
F
.48297 .39372 m .48274 .39123 L .47058 .39206 L F
.64785 .49948 m .63446 .50424 L .63384 .50755 L .182 .002 0 r
F
.64785 .49948 m .64855 .49617 L .63446 .50424 L F
.40887 .53697 m .39043 .53107 L .39043 .53362 L 1 .71 0 r
F
.40888 .53949 m .40887 .53697 L .39043 .53362 L 1 .7 0 r
F
.42174 .36007 m .41563 .36082 L .41387 .3629 L 1 .961 0 r
F
.42174 .36007 m .42319 .35763 L .41563 .36082 L F
.5746 .4639 m .5589 .46567 L .55947 .46836 L .665 .387 0 r
F
.5746 .4639 m .57394 .46123 L .5589 .46567 L F
.17688 .74444 m .1443 .72737 L .14682 .73316 L 1 .365 0 r
F
.17924 .75 m .17688 .74444 L .14682 .73316 L 1 .339 0 r
F
.35208 .55243 m .33394 .54297 L .33393 .54608 L 1 .797 0 r
F
.35214 .55552 m .35208 .55243 L .33393 .54608 L 1 .785 0 r
F
.12467 .66677 m .09556 .64592 L .09707 .65237 L 1 .563 0 r
F
.12617 .67302 m .12467 .66677 L .09707 .65237 L 1 .539 0 r
F
.36824 .49392 m .35149 .4858 L .35114 .48865 L 1 .866 0 r
F
.36801 .49675 m .36824 .49392 L .35114 .48865 L 1 .856 0 r
F
.5223 .39546 m .50911 .39541 L .50983 .39797 L .869 .741 0 r
F
.52323 .39802 m .5223 .39546 L .50983 .39797 L .866 .735 0 r
F
.39426 .39963 m .38479 .39415 L .38312 .39656 L 1 1 0 r
F
.39426 .39963 m .39564 .39705 L .38479 .39415 L F
.41488 .41178 m .39564 .39705 L .39426 .39963 L .791 .545 0 r
F
.41392 .41419 m .41488 .41178 L .39426 .39963 L .798 .548 0 r
F
.56933 .44527 m .55425 .44691 L .55498 .44958 L .683 .455 0 r
F
.57017 .44792 m .56933 .44527 L .55498 .44958 L .68 .445 0 r
F
.46797 .63077 m .46796 .62852 L .44522 .62819 L .927 .17 0 r
F
.4904 .62996 m .46796 .62852 L .46797 .63077 L .846 .09 0 r
F
.4904 .62996 m .4906 .62777 L .46796 .62852 L F
.4012 .82235 m .36656 .82238 L .36809 .8262 L .876 .074 0 r
F
.40221 .82614 m .4012 .82235 L .36809 .8262 L .863 .071 0 r
F
.43455 .82033 m .4012 .82235 L .40221 .82614 L .802 .067 0 r
F
.64327 .12325 m .63802 .12803 L .64419 .13159 L .24 .312 0 r
F
.64327 .12325 m .63691 .12048 L .63802 .12803 L F
.56563 .43167 m .55081 .43331 L .55167 .43597 L .709 .513 0 r
F
.56662 .43431 m .56563 .43167 L .55167 .43597 L .706 .504 0 r
F
.56558 .52415 m .54791 .52534 L .54793 .52791 L .693 .247 0 r
F
.56558 .52415 m .56555 .52157 L .54791 .52534 L F
.57525 .46658 m .55947 .46836 L .56002 .47105 L .662 .377 0 r
F
.57525 .46658 m .5746 .4639 L .55947 .46836 L F
.39205 .5024 m .37553 .49557 L .37519 .49822 L 1 .866 0 r
F
.39179 .50504 m .39205 .5024 L .37519 .49822 L 1 .857 0 r
F
.31974 .84836 m .28418 .83907 L .287 .84315 L .974 .076 0 r
F
.32209 .85223 m .31974 .84836 L .287 .84315 L .956 .073 0 r
F
.68924 .22767 m .69393 .22032 L .69643 .22704 L 1 .173 0 r
F
.68924 .22767 m .68704 .22107 L .69393 .22032 L F
.63554 .12346 m .63047 .12748 L .63634 .13159 L .168 .177 0 r
F
.63554 .12346 m .62957 .11991 L .63047 .12748 L F
.53958 .40512 m .52595 .40572 L .52683 .40829 L .794 .655 0 r
F
.54065 .40767 m .53958 .40512 L .52683 .40829 L .792 .648 0 r
F
.34278 .47689 m .32954 .46741 L .32859 .47045 L 1 1 0 r
F
.34198 .48001 m .34278 .47689 L .32859 .47045 L F
.3988 .38353 m .39131 .37999 L .38946 .38223 L F
.3988 .38353 m .40041 .38108 L .39131 .37999 L F
.56262 .08713 m .55821 .08758 L .56515 .08973 L .05 .088 0 r
F
.56262 .08713 m .5565 .08236 L .55821 .08758 L F
.47053 .39425 m .45856 .39188 L .45823 .39428 L 1 .955 0 r
F
.47053 .39425 m .47057 .3918 L .45856 .39188 L F
.53462 .62082 m .51356 .62148 L .51316 .62372 L .669 .056 0 r
F
.53462 .62082 m .53523 .6186 L .51356 .62148 L F
.60036 .87298 m .56994 .87315 L .56808 .87655 L .446 .007 0 r
F
.60036 .87298 m .60284 .8695 L .56994 .87315 L F
.56847 .44263 m .55349 .44425 L .55425 .44691 L .685 .464 0 r
F
.56933 .44527 m .56847 .44263 L .55425 .44691 L .683 .455 0 r
F
.40531 .4392 m .39222 .43307 L .39128 .43559 L 1 1 0 r
F
.40531 .4392 m .40609 .43664 L .39222 .43307 L F
.11839 .67736 m .08804 .65652 L .08979 .66306 L 1 .532 0 r
F
.12009 .68368 m .11839 .67736 L .08979 .66306 L 1 .508 0 r
F
.57978 .48266 m .56328 .48454 L .56369 .48725 L .658 .331 0 r
F
.57978 .48266 m .57929 .47995 L .56328 .48454 L F
.57586 .46925 m .56002 .47105 L .56054 .47374 L .659 .366 0 r
F
.57586 .46925 m .57525 .46658 L .56002 .47105 L F
.08631 .54633 m .06375 .52164 L .06344 .52848 L 1 .815 0 r
F
.08614 .55306 m .08631 .54633 L .06344 .52848 L 1 .796 0 r
F
.70794 .62626 m .68602 .63084 L .68492 .63507 L .303 .019 0 r
F
.70794 .62626 m .70929 .62201 L .68602 .63084 L F
.76858 .76392 m .74268 .76914 L .73991 .77423 L .218 0 0 r
F
.76858 .76392 m .77168 .75869 L .74268 .76914 L F
.54735 .54801 m .52878 .54842 L .52867 .55087 L .755 .238 0 r
F
.54735 .54801 m .5475 .54555 L .52878 .54842 L F
.46858 .57166 m .44838 .56868 L .44842 .57109 L 1 .459 0 r
F
.46858 .57402 m .46858 .57166 L .44842 .57109 L 1 .446 0 r
F
.4887 .57385 m .46858 .57166 L .46858 .57402 L .959 .386 0 r
F
.4887 .57385 m .48877 .5715 L .46858 .57166 L F
.56686 .52994 m .54881 .53105 L .54881 .53364 L .7 .244 0 r
F
.56686 .52994 m .56686 .52734 L .54881 .53105 L F
.83222 .26853 m .81909 .2823 L .82309 .2882 L .178 .077 0 r
F
.83222 .26853 m .82804 .26279 L .81909 .2823 L F
.32742 .81224 m .29142 .80761 L .29384 .81175 L 1 .151 0 r
F
.32935 .81627 m .32742 .81224 L .29384 .81175 L .997 .129 0 r
F
.56758 .44 m .55271 .44159 L .55349 .44425 L .688 .473 0 r
F
.56847 .44263 m .56758 .44 L .55349 .44425 L .685 .464 0 r
F
.46862 .56836 m .44857 .56537 L .44863 .56769 L 1 .44 0 r
F
.46862 .57065 m .46862 .56836 L .44863 .56769 L 1 .428 0 r
F
.48857 .57044 m .46862 .56836 L .46862 .57065 L .954 .37 0 r
F
.48857 .57044 m .48865 .56815 L .46862 .56836 L F
.43084 .88399 m .39563 .8792 L .397 .8825 L .781 .048 0 r
F
.43158 .88714 m .43084 .88399 L .397 .8825 L .76 .044 0 r
F
.46518 .88759 m .43084 .88399 L .43158 .88714 L .713 .039 0 r
F
.53898 .40201 m .5253 .40279 L .5262 .40537 L .814 .673 0 r
F
.54006 .40459 m .53898 .40201 L .5262 .40537 L .811 .666 0 r
F
.37432 .58791 m .35383 .57974 L .35419 .5827 L 1 .623 0 r
F
.37468 .5908 m .37432 .58791 L .35419 .5827 L 1 .609 0 r
F
.68332 .1231 m .67635 .1326 L .6828 .13601 L .361 .481 0 r
F
.68332 .1231 m .67677 .12009 L .67635 .1326 L F
.56462 .42904 m .54993 .43066 L .55081 .43331 L .711 .522 0 r
F
.56563 .43167 m .56462 .42904 L .55081 .43331 L .709 .513 0 r
F
.56239 .08815 m .55804 .08832 L .56496 .09051 L .018 .093 0 r
F
.56239 .08815 m .55616 .08395 L .55804 .08832 L F
.42776 .41417 m .41586 .40939 L .41488 .41178 L 1 1 0 r
F
.42776 .41417 m .42851 .41172 L .41586 .40939 L F
.57644 .47193 m .56054 .47374 L .56103 .47644 L .656 .356 0 r
F
.57644 .47193 m .57586 .46925 L .56054 .47374 L F
.57988 .5956 m .5608 .59814 L .56012 .6006 L .479 .04 0 r
F
.57988 .5956 m .58073 .59312 L .5608 .59814 L F
.34198 .48001 m .32859 .47045 L .32768 .47351 L 1 1 0 r
F
.34123 .48314 m .34198 .48001 L .32768 .47351 L F
.88776 .45723 m .86896 .46973 L .86993 .47653 L .069 .015 0 r
F
.88776 .45723 m .88679 .45038 L .86896 .46973 L F
.23839 .76866 m .20285 .75792 L .20556 .76288 L 1 .291 0 r
F
.24077 .77341 m .23839 .76866 L .20556 .76288 L 1 .269 0 r
F
.56666 .43737 m .5519 .43894 L .55271 .44159 L .69 .482 0 r
F
.56758 .44 m .56666 .43737 L .55271 .44159 L .688 .473 0 r
F
.47053 .3945 m .45861 .39221 L .45828 .3946 L 1 .959 0 r
F
.47053 .3945 m .47058 .39206 L .45861 .39221 L F
.72303 .81418 m .69537 .81736 L .69245 .82194 L .299 0 0 r
F
.72303 .81418 m .72639 .80946 L .69537 .81736 L F
.58024 .48536 m .56369 .48725 L .56408 .48996 L .654 .321 0 r
F
.58024 .48536 m .57978 .48266 L .56369 .48725 L F
.42808 .56014 m .40771 .55619 L .40784 .55867 L 1 .584 0 r
F
.42813 .56264 m .42808 .56014 L .40784 .55867 L 1 .574 0 r
F
.40609 .43664 m .39318 .43056 L .39222 .43307 L 1 1 0 r
F
.40609 .43664 m .40688 .43409 L .39318 .43056 L F
.39179 .50504 m .37519 .49822 L .37487 .50086 L 1 .857 0 r
F
.39155 .50769 m .39179 .50504 L .37487 .50086 L 1 .849 0 r
F
.09432 .5384 m .07031 .51429 L .07011 .521 L 1 .818 0 r
F
.09427 .54497 m .09432 .5384 L .07011 .521 L 1 .8 0 r
F
.39821 .60878 m .37637 .6021 L .37686 .60486 L 1 .485 0 r
F
.39863 .61145 m .39821 .60878 L .37686 .60486 L 1 .469 0 r
F
.57699 .47461 m .56103 .47644 L .5615 .47913 L .653 .346 0 r
F
.57699 .47461 m .57644 .47193 L .56103 .47644 L F
.44838 .56868 m .4282 .56511 L .42828 .56757 L 1 .521 0 r
F
.44842 .57109 m .44838 .56868 L .42828 .56757 L 1 .508 0 r
F
.53091 .87871 m .49893 .87738 L .49832 .88039 L .566 .02 0 r
F
.53091 .87871 m .53218 .87568 L .49893 .87738 L F
.55173 .77563 m .52602 .78196 L .5253 .78593 L .441 .028 0 r
F
.55173 .77563 m .55282 .77186 L .52602 .78196 L F
.44408 .40356 m .43249 .39976 L .43167 .40211 L 1 1 0 r
F
.44408 .40356 m .44465 .40115 L .43249 .39976 L F
.4074 .54869 m .38707 .54377 L .38723 .54631 L 1 .609 0 r
F
.40749 .5512 m .4074 .54869 L .38723 .54631 L 1 .607 0 r
F
.8197 .7015 m .79531 .70869 L .79307 .71448 L .148 0 0 r
F
.8197 .7015 m .82216 .69556 L .79531 .70869 L F
.36801 .49675 m .35114 .48865 L .35082 .49151 L 1 .856 0 r
F
.36782 .49957 m .36801 .49675 L .35082 .49151 L 1 .846 0 r
F
.55972 .16315 m .56572 .12294 L .56851 .13815 L 1 .806 0 r
F
.55972 .16315 m .55961 .13999 L .56572 .12294 L F
.68225 .1249 m .67575 .13361 L .68211 .13714 L .311 .39 0 r
F
.68225 .1249 m .67594 .12155 L .67575 .13361 L F
.56359 .42642 m .54903 .42802 L .54993 .43066 L .714 .53 0 r
F
.56462 .42904 m .56359 .42642 L .54993 .43066 L .711 .522 0 r
F
.60305 .57415 m .58535 .57759 L .58463 .58026 L .381 .031 0 r
F
.60305 .57415 m .60389 .57147 L .58535 .57759 L F
.44857 .56537 m .42874 .56148 L .42886 .56383 L 1 .506 0 r
F
.44863 .56769 m .44857 .56537 L .42886 .56383 L 1 .494 0 r
F
.50774 .3901 m .49494 .38972 L .49543 .39225 L .946 .823 0 r
F
.50847 .39266 m .50774 .3901 L .49543 .39225 L .942 .817 0 r
F
.50765 .3903 m .49494 .38972 L .49543 .39225 L .931 .812 0 r
F
.50839 .39286 m .50765 .3903 L .49543 .39225 L .927 .806 0 r
F
.38648 .53088 m .36724 .52433 L .3673 .52701 L 1 .69 0 r
F
.38657 .53348 m .38648 .53088 L .3673 .52701 L 1 .683 0 r
F
.56572 .43474 m .55108 .4363 L .5519 .43894 L .693 .491 0 r
F
.56666 .43737 m .56572 .43474 L .5519 .43894 L .69 .482 0 r
F
.52159 .39248 m .50847 .39266 L .5092 .39522 L .89 .758 0 r
F
.52254 .39506 m .52159 .39248 L .5092 .39522 L .886 .752 0 r
F
.5086 .57285 m .48877 .5715 L .4887 .57385 L .894 .318 0 r
F
.5086 .57285 m .50874 .57051 L .48877 .5715 L F
.34123 .48314 m .32768 .47351 L .32681 .47658 L 1 1 0 r
F
.34051 .48627 m .34123 .48314 L .32681 .47658 L F
.39563 .8792 m .36003 .87318 L .36201 .87664 L .837 .055 0 r
F
.397 .8825 m .39563 .8792 L .36201 .87664 L .817 .051 0 r
F
.57752 .47728 m .5615 .47913 L .56195 .48181 L .65 .335 0 r
F
.57752 .47728 m .57699 .47461 L .5615 .47913 L F
.39564 .39705 m .38649 .3918 L .38479 .39415 L 1 1 0 r
F
.39564 .39705 m .39706 .3945 L .38649 .3918 L F
.41586 .40939 m .39706 .3945 L .39564 .39705 L .784 .541 0 r
F
.41488 .41178 m .41586 .40939 L .39564 .39705 L .791 .545 0 r
F
.52842 .5663 m .50901 .56576 L .50888 .56815 L .828 .268 0 r
F
.52842 .5663 m .52861 .56391 L .50901 .56576 L F
.50827 .56936 m .48865 .56815 L .48857 .57044 L .886 .304 0 r
F
.50827 .56936 m .50842 .56707 L .48865 .56815 L F
.56559 .52672 m .54793 .52791 L .54793 .53048 L .69 .235 0 r
F
.56559 .52672 m .56558 .52415 L .54793 .52791 L F
.40888 .53949 m .39043 .53362 L .39044 .53615 L 1 .7 0 r
F
.40891 .542 m .40888 .53949 L .39044 .53615 L 1 .69 0 r
F
.5385 .40256 m .52505 .40314 L .52595 .40572 L .797 .661 0 r
F
.53958 .40512 m .5385 .40256 L .52595 .40572 L .794 .655 0 r
F
.58067 .48807 m .56408 .48996 L .56445 .49267 L .651 .31 0 r
F
.58067 .48807 m .58024 .48536 L .56408 .48996 L F
.86666 .60457 m .8446 .61432 L .84351 .62078 L .08 0 0 r
F
.86666 .60457 m .86786 .59797 L .8446 .61432 L F
.67263 .6718 m .65032 .67563 L .64907 .67966 L .338 .018 0 r
F
.67263 .6718 m .67423 .66786 L .65032 .67563 L F
.42855 .55672 m .4092 .55186 L .40932 .55428 L 1 .589 0 r
F
.42864 .55911 m .42855 .55672 L .40932 .55428 L 1 .578 0 r
F
.56475 .43213 m .55023 .43366 L .55108 .4363 L .695 .5 0 r
F
.56572 .43474 m .56475 .43213 L .55108 .4363 L .693 .491 0 r
F
.40688 .43409 m .39418 .42807 L .39318 .43056 L 1 1 0 r
F
.40688 .43409 m .40769 .43155 L .39418 .42807 L F
.68931 .39278 m .68277 .39663 L .68118 .40202 L 0 0 0 r
F
.68931 .39278 m .69094 .38738 L .68277 .39663 L F
.54805 .55388 m .52922 .55417 L .52909 .55663 L .761 .236 0 r
F
.54805 .55388 m .54822 .55141 L .52922 .55417 L F
.52135 .3929 m .50839 .39286 L .50911 .39541 L .872 .746 0 r
F
.5223 .39546 m .52135 .3929 L .50911 .39541 L .869 .741 0 r
F
.89438 .46386 m .87449 .47648 L .87553 .48336 L .095 .021 0 r
F
.89438 .46386 m .89326 .45692 L .87449 .47648 L F
.52785 .5628 m .5087 .56242 L .50857 .56476 L .819 .257 0 r
F
.52785 .5628 m .52805 .56046 L .5087 .56242 L F
.56253 .42381 m .54811 .42539 L .54903 .42802 L .716 .538 0 r
F
.56359 .42642 m .56253 .42381 L .54903 .42802 L .714 .53 0 r
F
.45796 .39701 m .44639 .39403 L .4458 .39639 L 1 .992 0 r
F
.45796 .39701 m .45828 .3946 L .44639 .39403 L F
.39155 .50769 m .37487 .50086 L .37458 .5035 L 1 .849 0 r
F
.39133 .51032 m .39155 .50769 L .37458 .5035 L 1 .841 0 r
F
.50822 .27976 m .53142 .12079 L .5237 .19935 L 1 .7 0 r
F
.51232 .62807 m .4906 .62777 L .4904 .62996 L .754 .065 0 r
F
.51232 .62807 m .51274 .62592 L .4906 .62777 L F
.53788 .39944 m .52439 .40021 L .5253 .40279 L .817 .679 0 r
F
.53898 .40201 m .53788 .39944 L .5253 .40279 L .814 .673 0 r
F
.35214 .55552 m .33393 .54608 L .33397 .54919 L 1 .785 0 r
F
.35224 .5586 m .35214 .55552 L .33397 .54919 L 1 .773 0 r
F
.57801 .47996 m .56195 .48181 L .56237 .4845 L .647 .325 0 r
F
.57801 .47996 m .57752 .47728 L .56195 .48181 L F
.56683 .53254 m .54881 .53364 L .54879 .53623 L .697 .232 0 r
F
.56683 .53254 m .56686 .52994 L .54881 .53364 L F
.41985 .37256 m .41254 .37116 L .41092 .37333 L 1 1 0 r
F
.41985 .37256 m .42118 .37011 L .41254 .37116 L F
.34051 .48627 m .32681 .47658 L .32598 .47966 L F
.33982 .48942 m .34051 .48627 L .32598 .47966 L F
.7073 .32275 m .70528 .32436 L .70435 .33128 L 0 0 0 r
F
.7073 .32275 m .70795 .3161 L .70528 .32436 L F
.43895 .343 m .43372 .34914 L .43228 .35137 L .904 .407 0 r
F
.48274 .39123 m .47062 .38963 L .47058 .39206 L 1 .924 0 r
F
.48274 .39123 m .48251 .38875 L .47062 .38963 L F
.1735 .75529 m .14006 .73842 L .1428 .74423 L 1 .332 0 r
F
.17603 .76086 m .1735 .75529 L .1428 .74423 L 1 .306 0 r
F
.83707 .27391 m .82417 .28761 L .82815 .29355 L .164 .075 0 r
F
.83707 .27391 m .83291 .26813 L .82417 .28761 L F
.42851 .41172 m .41686 .40701 L .41586 .40939 L 1 1 0 r
F
.42851 .41172 m .42928 .40929 L .41686 .40701 L F
.56376 .42952 m .54936 .43103 L .55023 .43366 L .697 .509 0 r
F
.56475 .43213 m .56376 .42952 L .55023 .43366 L .695 .5 0 r
F
.6898 .12621 m .6828 .13601 L .6892 .13953 L .351 .461 0 r
F
.6898 .12621 m .68332 .1231 L .6828 .13601 L F
.58107 .49077 m .56445 .49267 L .56479 .49538 L .648 .299 0 r
F
.58107 .49077 m .58067 .48807 L .56445 .49267 L F
.40041 .38108 m .39319 .37778 L .39131 .37999 L 1 1 0 r
F
.40041 .38108 m .40203 .37867 L .39319 .37778 L F
.64124 .12748 m .63634 .13159 L .64201 .13599 L .124 .104 0 r
F
.64124 .12748 m .63554 .12346 L .63634 .13159 L F
.54718 .55045 m .52867 .55087 L .52853 .55329 L .751 .226 0 r
F
.54718 .55045 m .54735 .54801 L .52867 .55087 L F
.22957 .79589 m .19529 .78204 L .19828 .78714 L 1 .208 0 r
F
.23227 .80076 m .22957 .79589 L .19828 .78714 L 1 .181 0 r
F
.36782 .49957 m .35082 .49151 L .35054 .49435 L 1 .846 0 r
F
.36765 .50238 m .36782 .49957 L .35054 .49435 L 1 .836 0 r
F
.57848 .48263 m .56237 .4845 L .56277 .48719 L .644 .314 0 r
F
.57848 .48263 m .57801 .47996 L .56237 .4845 L F
.13518 .65432 m .10469 .635 L .10622 .64122 L 1 .573 0 r
F
.13669 .66031 m .13518 .65432 L .10622 .64122 L 1 .552 0 r
F
.47057 .3918 m .45889 .3895 L .45856 .39188 L 1 .962 0 r
F
.47057 .3918 m .47062 .38937 L .45889 .3895 L F
.56145 .4212 m .54717 .42277 L .54811 .42539 L .719 .547 0 r
F
.56253 .42381 m .56145 .4212 L .54811 .42539 L .716 .538 0 r
F
.07556 .56196 m .05116 .53694 L .0512 .54396 L 1 .772 0 r
F
.07571 .56885 m .07556 .56196 L .0512 .54396 L 1 .752 0 r
F
.40769 .43155 m .39519 .42559 L .39418 .42807 L 1 1 0 r
F
.40769 .43155 m .40853 .42902 L .39519 .42559 L F
.42206 .62188 m .39954 .61669 L .40002 .61926 L 1 .362 0 r
F
.42242 .62434 m .42206 .62188 L .40002 .61926 L 1 .345 0 r
F
.76243 .47762 m .74795 .48591 L .74788 .49086 L .067 .003 0 r
F
.76243 .47762 m .76235 .47264 L .74795 .48591 L F
.62567 .54467 m .60985 .54895 L .60917 .55187 L .3 .021 0 r
F
.62567 .54467 m .62643 .54175 L .60985 .54895 L F
.42319 .35763 m .41739 .35878 L .41563 .36082 L 1 .875 0 r
F
.42319 .35763 m .42465 .35523 L .41739 .35878 L F
.43507 .82409 m .43455 .82033 L .40221 .82614 L .787 .064 0 r
F
.466 .81653 m .43455 .82033 L .43507 .82409 L .71 .057 0 r
F
.466 .81653 m .46597 .81272 L .43455 .82033 L F
.57102 .09069 m .56723 .09007 L .57206 .09187 L .108 .142 0 r
F
.56723 .09007 m .56515 .08973 L .5674 .09042 L F
.56723 .09007 m .5674 .09042 L .57206 .09187 L F
.56689 .08935 m .56515 .08973 L .57102 .09069 L F
.56965 .08769 m .56621 .08791 L .56689 .08935 L .385 .441 0 r
F
.56689 .08935 m .56262 .08713 L .56515 .08973 L .108 .142 0 r
F
.56621 .08791 m .56584 .08793 L .56689 .08935 L .385 .441 0 r
F
.56965 .08769 m .56689 .08935 L .57102 .09069 L F
.56937 .08882 m .56584 .08793 L .56689 .08935 L .108 .142 0 r
F
.56584 .08793 m .56262 .08713 L .56689 .08935 L F
.56584 .08793 m .56239 .08815 L .56689 .08935 L .385 .441 0 r
F
.56689 .08935 m .56239 .08815 L .56496 .09051 L F
.57102 .09069 m .56496 .09051 L .57188 .09257 L F
.56689 .08935 m .56496 .09051 L .57102 .09069 L F
.56937 .08882 m .56689 .08935 L .57102 .09069 L .108 .142 0 r
F
.64715 .50276 m .63384 .50755 L .63321 .51082 L .18 .001 0 r
F
.64715 .50276 m .64785 .49948 L .63384 .50755 L F
.46858 .57402 m .44842 .57109 L .44847 .57348 L 1 .446 0 r
F
.46857 .57637 m .46858 .57402 L .44847 .57348 L 1 .433 0 r
F
.48862 .57617 m .46858 .57402 L .46857 .57637 L .955 .373 0 r
F
.48862 .57617 m .4887 .57385 L .46858 .57402 L F
.63698 .8612 m .60767 .86227 L .60528 .86594 L .398 0 0 r
F
.63698 .8612 m .63994 .85745 L .60767 .86227 L F
.87322 .61374 m .84962 .62309 L .84852 .62968 L .115 0 0 r
F
.87322 .61374 m .87441 .607 L .84962 .62309 L F
.56274 .42692 m .54848 .4284 L .54936 .43103 L .699 .518 0 r
F
.56376 .42952 m .56274 .42692 L .54936 .43103 L .697 .509 0 r
F
.33982 .48942 m .32598 .47966 L .32519 .48275 L 1 1 0 r
F
.33917 .49256 m .33982 .48942 L .32519 .48275 L F
.44522 .62819 m .42242 .62434 L .42279 .62677 L 1 .262 0 r
F
.44543 .6305 m .44522 .62819 L .42279 .62677 L .999 .244 0 r
F
.46797 .63077 m .44522 .62819 L .44543 .6305 L .927 .17 0 r
F
.42813 .56264 m .40784 .55867 L .40798 .56113 L 1 .574 0 r
F
.4282 .56511 m .42813 .56264 L .40798 .56113 L 1 .563 0 r
F
.8363 .27435 m .82309 .2882 L .82699 .29416 L .169 .074 0 r
F
.8363 .27435 m .83222 .26853 L .82309 .2882 L F
.52376 .7936 m .49625 .79978 L .49586 .80367 L .52 .037 0 r
F
.52376 .7936 m .52455 .78982 L .49625 .79978 L F
.39133 .51032 m .37458 .5035 L .37431 .50613 L 1 .841 0 r
F
.39114 .51295 m .39133 .51032 L .37431 .50613 L 1 .832 0 r
F
.35988 .86349 m .32449 .85601 L .32694 .85969 L .901 .064 0 r
F
.36179 .86698 m .35988 .86349 L .32694 .85969 L .881 .061 0 r
F
.46862 .57065 m .44863 .56769 L .4487 .56999 L 1 .428 0 r
F
.46861 .57291 m .46862 .57065 L .4487 .56999 L 1 .416 0 r
F
.48849 .5727 m .46862 .57065 L .46861 .57291 L .951 .357 0 r
F
.48849 .5727 m .48857 .57044 L .46862 .57065 L F
.53741 .40001 m .52415 .40058 L .52505 .40314 L .799 .667 0 r
F
.5385 .40256 m .53741 .40001 L .52505 .40314 L .797 .661 0 r
F
.68848 .12836 m .68211 .13714 L .68841 .14075 L .293 .357 0 r
F
.68848 .12836 m .68225 .1249 L .68211 .13714 L F
.56557 .52928 m .54793 .53048 L .54792 .53303 L .686 .223 0 r
F
.56557 .52928 m .56559 .52672 L .54793 .53048 L F
.58144 .49347 m .56479 .49538 L .56511 .49808 L .645 .288 0 r
F
.58144 .49347 m .58107 .49077 L .56479 .49538 L F
.39706 .3945 m .38822 .38949 L .38649 .3918 L 1 1 0 r
F
.39706 .3945 m .3985 .39199 L .38822 .38949 L F
.41686 .40701 m .3985 .39199 L .39706 .3945 L 1 .089 0 r
F
.41586 .40939 m .41686 .40701 L .39706 .3945 L .784 .541 0 r
F
.74041 .56715 m .72049 .57356 L .71972 .57808 L .226 .014 0 r
F
.74041 .56715 m .74127 .56255 L .72049 .57356 L F
.52064 .38991 m .50774 .3901 L .50847 .39266 L .894 .763 0 r
F
.52159 .39248 m .52064 .38991 L .50847 .39266 L .89 .758 0 r
F
.72256 .24451 m .72672 .24136 L .72891 .24801 L .903 .169 0 r
F
.72256 .24451 m .72241 .23626 L .72672 .24136 L F
.6672 .45172 m .65708 .45641 L .65618 .46035 L 0 0 0 r
F
.6672 .45172 m .66821 .44777 L .65708 .45641 L F
.57891 .48531 m .56277 .48719 L .56314 .48987 L .64 .303 0 r
F
.57891 .48531 m .57848 .48263 L .56277 .48719 L F
.38657 .53348 m .3673 .52701 L .36738 .52967 L 1 .683 0 r
F
.38668 .53607 m .38657 .53348 L .36738 .52967 L 1 .676 0 r
F
.40749 .5512 m .38723 .54631 L .3874 .54884 L 1 .607 0 r
F
.4076 .5537 m .40749 .5512 L .3874 .54884 L 1 .604 0 r
F
.44465 .40115 m .43332 .39742 L .43249 .39976 L 1 1 0 r
F
.44465 .40115 m .44522 .39876 L .43332 .39742 L F
.47058 .39206 m .45893 .38984 L .45861 .39221 L 1 .966 0 r
F
.47058 .39206 m .47062 .38963 L .45893 .38984 L F
.40891 .542 m .39044 .53615 L .39048 .53867 L 1 .69 0 r
F
.40896 .54449 m .40891 .542 L .39048 .53867 L 1 .68 0 r
F
.44842 .57109 m .42828 .56757 L .42838 .57 L 1 .508 0 r
F
.44847 .57348 m .44842 .57109 L .42838 .57 L 1 .495 0 r
F
.56035 .41861 m .54621 .42015 L .54717 .42277 L .721 .555 0 r
F
.56145 .4212 m .56035 .41861 L .54717 .42277 L .719 .547 0 r
F
.82419 .71202 m .79875 .71861 L .79645 .7245 L .173 0 0 r
F
.82419 .71202 m .82672 .70595 L .79875 .71861 L F
.50699 .38754 m .49444 .38719 L .49494 .38972 L .951 .829 0 r
F
.50774 .3901 m .50699 .38754 L .49494 .38972 L .946 .823 0 r
F
.50691 .38775 m .49444 .38719 L .49494 .38972 L .935 .817 0 r
F
.50765 .3903 m .50691 .38775 L .49494 .38972 L .931 .812 0 r
F
.53677 .39687 m .52347 .39763 L .52439 .40021 L .821 .685 0 r
F
.53788 .39944 m .53677 .39687 L .52439 .40021 L .817 .679 0 r
F
.37468 .5908 m .35419 .5827 L .35458 .58563 L 1 .609 0 r
F
.37506 .59366 m .37468 .5908 L .35458 .58563 L 1 .594 0 r
F
.5617 .42433 m .54757 .42578 L .54848 .4284 L .702 .526 0 r
F
.56274 .42692 m .5617 .42433 L .54848 .4284 L .699 .518 0 r
F
.69137 .23413 m .69643 .22704 L .69871 .23382 L 1 .187 0 r
F
.69137 .23413 m .68924 .22767 L .69643 .22704 L F
.40853 .42902 m .39623 .42313 L .39519 .42559 L 1 1 0 r
F
.40853 .42902 m .40938 .42651 L .39623 .42313 L F
.55641 .6124 m .53642 .61405 L .53583 .61635 L .569 .046 0 r
F
.55641 .6124 m .55719 .61012 L .53642 .61405 L F
.44863 .56769 m .42886 .56383 L .42899 .56616 L 1 .494 0 r
F
.4487 .56999 m .44863 .56769 L .42899 .56616 L 1 .482 0 r
F
.56678 .53512 m .54879 .53623 L .54875 .53879 L .693 .22 0 r
F
.56678 .53512 m .56683 .53254 L .54879 .53623 L F
.5204 .39034 m .50765 .3903 L .50839 .39286 L .876 .752 0 r
F
.52135 .3929 m .5204 .39034 L .50839 .39286 L .872 .746 0 r
F
.7713 .77489 m .74473 .7795 L .74189 .78468 L .236 0 0 r
F
.7713 .77489 m .77449 .76955 L .74473 .7795 L F
.49545 .80746 m .46597 .81272 L .466 .81653 L .614 .047 0 r
F
.49545 .80746 m .49586 .80367 L .46597 .81272 L F
.33917 .49256 m .32519 .48275 L .32444 .48585 L 1 1 0 r
F
.33857 .49571 m .33917 .49256 L .32444 .48585 L F
.50844 .57517 m .4887 .57385 L .48862 .57617 L .89 .305 0 r
F
.50844 .57517 m .5086 .57285 L .4887 .57385 L F
.52821 .56866 m .50888 .56815 L .50874 .57051 L .824 .256 0 r
F
.52821 .56866 m .52842 .5663 L .50888 .56815 L F
.54786 .55634 m .52909 .55663 L .52895 .55908 L .757 .224 0 r
F
.54786 .55634 m .54805 .55388 L .52909 .55663 L F
.42864 .55911 m .40932 .55428 L .40946 .55669 L 1 .578 0 r
F
.42874 .56148 m .42864 .55911 L .40946 .55669 L 1 .567 0 r
F
.57932 .48798 m .56314 .48987 L .56348 .49254 L .637 .292 0 r
F
.57932 .48798 m .57891 .48531 L .56314 .48987 L F
.58178 .49617 m .56511 .49808 L .5654 .50077 L .641 .277 0 r
F
.58178 .49617 m .58144 .49347 L .56511 .49808 L F
.36765 .50238 m .35054 .49435 L .35029 .49718 L 1 .836 0 r
F
.36751 .50517 m .36765 .50238 L .35029 .49718 L 1 .827 0 r
F
.5081 .57163 m .48857 .57044 L .48849 .5727 L .883 .292 0 r
F
.5081 .57163 m .50827 .56936 L .48857 .57044 L F
.27548 .83657 m .23985 .82542 L .24301 .82995 L 1 .086 0 r
F
.27823 .84087 m .27548 .83657 L .24301 .82995 L 1 .082 0 r
F
.63874 .70684 m .61638 .711 L .61512 .71495 L .35 .014 0 r
F
.63874 .70684 m .64039 .70309 L .61638 .711 L F
.39114 .51295 m .37431 .50613 L .37408 .50876 L 1 .832 0 r
F
.39097 .51557 m .39114 .51295 L .37408 .50876 L 1 .823 0 r
F
.69622 .12944 m .6892 .13953 L .69552 .14314 L .342 .44 0 r
F
.69622 .12944 m .6898 .12621 L .6892 .13953 L F
.59805 .86594 m .56828 .86651 L .56642 .86977 L .43 .002 0 r
F
.59805 .86594 m .60052 .86262 L .56828 .86651 L F
.43148 .87761 m .39682 .87294 L .39818 .87616 L .774 .046 0 r
F
.43221 .88067 m .43148 .87761 L .39818 .87616 L .753 .043 0 r
F
.46528 .88105 m .43148 .87761 L .43221 .88067 L .703 .037 0 r
F
.18827 .72694 m .15444 .71234 L .15687 .71789 L 1 .396 0 r
F
.1905 .73224 m .18827 .72694 L .15687 .71789 L 1 .375 0 r
F
.35224 .5586 m .33397 .54919 L .33404 .55228 L 1 .773 0 r
F
.35236 .56167 m .35224 .5586 L .33404 .55228 L 1 .76 0 r
F
.52764 .56512 m .50857 .56476 L .50842 .56707 L .815 .244 0 r
F
.52764 .56512 m .52785 .5628 L .50857 .56476 L F
.55922 .41602 m .54523 .41754 L .54621 .42015 L .724 .562 0 r
F
.56035 .41861 m .55922 .41602 L .54621 .42015 L .721 .555 0 r
F
.56063 .42174 m .54664 .42317 L .54757 .42578 L .704 .535 0 r
F
.5617 .42433 m .56063 .42174 L .54757 .42578 L .702 .526 0 r
F
.45828 .3946 m .44699 .3917 L .44639 .39403 L 1 .999 0 r
F
.45828 .3946 m .45861 .39221 L .44699 .3917 L F
.60793 .73392 m .58505 .73896 L .58389 .7429 L .362 .014 0 r
F
.60793 .73392 m .60949 .73024 L .58505 .73896 L F
.46798 .63298 m .46797 .63077 L .44543 .6305 L .918 .151 0 r
F
.49019 .63212 m .46797 .63077 L .46798 .63298 L .836 .074 0 r
F
.49019 .63212 m .4904 .62996 L .46797 .63077 L F
.88861 .46409 m .86993 .47653 L .87079 .48333 L .058 .011 0 r
F
.88861 .46409 m .88776 .45723 L .86993 .47653 L F
.08614 .55306 m .06344 .52848 L .06325 .53532 L 1 .796 0 r
F
.08608 .5598 m .08614 .55306 L .06325 .53532 L 1 .776 0 r
F
.53399 .62299 m .51316 .62372 L .51274 .62592 L .659 .054 0 r
F
.53399 .62299 m .53462 .62082 L .51316 .62372 L F
.54698 .55286 m .52853 .55329 L .52839 .5557 L .747 .214 0 r
F
.54698 .55286 m .54718 .55045 L .52853 .55329 L F
.57901 .59804 m .56012 .6006 L .55941 .60304 L .469 .037 0 r
F
.57901 .59804 m .57988 .5956 L .56012 .6006 L F
.5363 .39747 m .52323 .39802 L .52415 .40058 L .802 .673 0 r
F
.53741 .40001 m .5363 .39747 L .52415 .40058 L .799 .667 0 r
F
.48251 .38875 m .47067 .38721 L .47062 .38963 L 1 .932 0 r
F
.48251 .38875 m .48228 .38628 L .47067 .38721 L F
.40203 .37867 m .39508 .37561 L .39319 .37778 L 1 1 0 r
F
.40203 .37867 m .40367 .3763 L .39508 .37561 L F
.39863 .61145 m .37686 .60486 L .37737 .6076 L 1 .469 0 r
F
.39907 .61408 m .39863 .61145 L .37737 .6076 L 1 .453 0 r
F
.40938 .42651 m .39729 .42068 L .39623 .42313 L 1 1 0 r
F
.40938 .42651 m .41025 .42402 L .39729 .42068 L F
.70653 .63047 m .68492 .63507 L .68378 .63927 L .294 .016 0 r
F
.70653 .63047 m .70794 .62626 L .68492 .63507 L F
.42118 .37011 m .41419 .36903 L .41254 .37116 L 1 1 0 r
F
.42118 .37011 m .42253 .36768 L .41419 .36903 L F
.60219 .5768 m .58463 .58026 L .58389 .5829 L .377 .029 0 r
F
.60219 .5768 m .60305 .57415 L .58463 .58026 L F
.57969 .49064 m .56348 .49254 L .5638 .49522 L .634 .281 0 r
F
.57969 .49064 m .57932 .48798 L .56348 .49254 L F
.33857 .49571 m .32444 .48585 L .32373 .48895 L 1 1 0 r
F
.33799 .49887 m .33857 .49571 L .32373 .48895 L 1 .998 0 r
F
.56552 .53182 m .54792 .53303 L .54788 .53556 L .682 .212 0 r
F
.56552 .53182 m .56557 .52928 L .54792 .53303 L F
.84113 .27976 m .82815 .29355 L .83202 .29956 L .155 .072 0 r
F
.84113 .27976 m .83707 .27391 L .82815 .29355 L F
.64654 .13215 m .64201 .13599 L .64743 .14072 L .041 .083 0 r
F
.64654 .13215 m .64124 .12748 L .64201 .13599 L F
.36656 .82238 m .33134 .82023 L .33339 .82411 L .936 .094 0 r
F
.36809 .8262 m .36656 .82238 L .33339 .82411 L .924 .076 0 r
F
.58209 .49886 m .5654 .50077 L .56566 .50346 L .638 .266 0 r
F
.58209 .49886 m .58178 .49617 L .5654 .50077 L F
.3985 .39199 m .38999 .38724 L .38822 .38949 L 1 1 0 r
F
.3985 .39199 m .39997 .38953 L .38999 .38724 L F
.71819 .80776 m .69144 .81145 L .68852 .81587 L .276 0 0 r
F
.71819 .80776 m .72154 .8032 L .69144 .81145 L F
.69467 .13186 m .68841 .14075 L .69466 .14445 L .28 .337 0 r
F
.69467 .13186 m .68848 .12836 L .68841 .14075 L F
.35726 .25208 m .36025 .24688 L .35335 .23719 L 1 1 0 r
F
.55954 .41917 m .54568 .42057 L .54664 .42317 L .706 .543 0 r
F
.56063 .42174 m .55954 .41917 L .54664 .42317 L .704 .535 0 r
F
.39682 .87294 m .36179 .86698 L .36374 .87037 L .833 .054 0 r
F
.39818 .87616 m .39682 .87294 L .36374 .87037 L .813 .051 0 r
F
.4282 .56511 m .40798 .56113 L .40814 .56358 L 1 .563 0 r
F
.42828 .56757 m .4282 .56511 L .40814 .56358 L 1 .552 0 r
F
.53564 .3943 m .52254 .39506 L .52347 .39763 L .824 .69 0 r
F
.53677 .39687 m .53564 .3943 L .52347 .39763 L .821 .685 0 r
F
.67673 .84359 m .64845 .84561 L .64568 .84965 L .348 0 0 r
F
.67673 .84359 m .68002 .83943 L .64845 .84561 L F
.09427 .54497 m .07011 .521 L .07003 .5277 L 1 .8 0 r
F
.09432 .55153 m .09427 .54497 L .07003 .5277 L 1 .782 0 r
F
.40896 .54449 m .39048 .53867 L .39054 .54117 L 1 .68 0 r
F
.40902 .54696 m .40896 .54449 L .39054 .54117 L 1 .669 0 r
F
.55807 .41343 m .54423 .41493 L .54523 .41754 L .726 .57 0 r
F
.55922 .41602 m .55807 .41343 L .54523 .41754 L .724 .562 0 r
F
.51967 .38732 m .50699 .38754 L .50774 .3901 L .899 .768 0 r
F
.52064 .38991 m .51967 .38732 L .50774 .3901 L .894 .763 0 r
F
.38668 .53607 m .36738 .52967 L .36748 .53232 L 1 .676 0 r
F
.3868 .53865 m .38668 .53607 L .36748 .53232 L 1 .67 0 r
F
.39097 .51557 m .37408 .50876 L .37387 .51137 L 1 .823 0 r
F
.39082 .51818 m .39097 .51557 L .37387 .51137 L 1 .814 0 r
F
.4076 .5537 m .3874 .54884 L .38759 .55135 L 1 .604 0 r
F
.40771 .55619 m .4076 .5537 L .38759 .55135 L 1 .599 0 r
F
.46857 .57637 m .44847 .57348 L .44853 .57585 L 1 .433 0 r
F
.46857 .57869 m .46857 .57637 L .44853 .57585 L 1 .419 0 r
F
.48853 .57848 m .46857 .57637 L .46857 .57869 L .952 .359 0 r
F
.48853 .57848 m .48862 .57617 L .46857 .57637 L F
.12617 .67302 m .09707 .65237 L .09871 .65879 L 1 .539 0 r
F
.12777 .67924 m .12617 .67302 L .09871 .65879 L 1 .515 0 r
F
.5667 .53768 m .54875 .53879 L .54869 .54135 L .689 .208 0 r
F
.5667 .53768 m .56678 .53512 L .54875 .53879 L F
.44522 .39876 m .43416 .39511 L .43332 .39742 L 1 1 0 r
F
.44522 .39876 m .4458 .39639 L .43416 .39511 L F
.36751 .50517 m .35029 .49718 L .35007 .5 L 1 .827 0 r
F
.36739 .50795 m .36751 .50517 L .35007 .5 L 1 .817 0 r
F
.57668 .08869 m .57652 .0888 L .57899 .09385 L .405 .527 0 r
F
.57652 .0888 m .57206 .09187 L .57826 .09364 L F
.57652 .0888 m .57826 .09364 L .57899 .09385 L F
.57647 .08867 m .57206 .09187 L .57668 .08869 L F
.57647 .08867 m .56965 .08769 L .57102 .09069 L .415 .628 0 r
F
.57663 .08854 m .57641 .08851 L .57647 .08867 L F
.57641 .08851 m .56965 .08769 L .57647 .08867 L F
.57662 .08856 m .56937 .08882 L .57102 .09069 L .405 .527 0 r
F
.57647 .08867 m .57102 .09069 L .57206 .09187 L F
.57662 .08856 m .57102 .09069 L .57647 .08867 L F
.57647 .08867 m .57102 .09069 L .57188 .09257 L .415 .628 0 r
F
.57668 .08869 m .57188 .09257 L .57872 .09481 L F
.57663 .08854 m .57647 .08867 L .57668 .08869 L F
.57647 .08867 m .57188 .09257 L .57668 .08869 L F
.57662 .08856 m .57647 .08867 L .57668 .08869 L .405 .527 0 r
F
.369 .41212 m .36011 .40532 L .35835 .40786 L 1 1 0 r
F
.369 .41212 m .37056 .40944 L .36011 .40532 L F
.84026 .28023 m .82699 .29416 L .83079 .30018 L .16 .071 0 r
F
.84026 .28023 m .8363 .27435 L .82699 .29416 L F
.58003 .49331 m .5638 .49522 L .56409 .49789 L .63 .27 0 r
F
.58003 .49331 m .57969 .49064 L .5638 .49522 L F
.46861 .57291 m .4487 .56999 L .44878 .57226 L 1 .416 0 r
F
.46861 .57515 m .46861 .57291 L .44878 .57226 L 1 .404 0 r
F
.4884 .57494 m .46861 .57291 L .46861 .57515 L .947 .345 0 r
F
.4884 .57494 m .48849 .5727 L .46861 .57291 L F
.89537 .47082 m .87553 .48336 L .87646 .49024 L .087 .018 0 r
F
.89537 .47082 m .89438 .46386 L .87553 .48336 L F
.51944 .38778 m .50691 .38775 L .50765 .3903 L .88 .757 0 r
F
.5204 .39034 m .51944 .38778 L .50765 .3903 L .876 .752 0 r
F
.50624 .38497 m .49394 .38466 L .49444 .38719 L .956 .834 0 r
F
.50699 .38754 m .50624 .38497 L .49444 .38719 L .951 .829 0 r
F
.50616 .38519 m .49394 .38466 L .49444 .38719 L .94 .823 0 r
F
.50691 .38775 m .50616 .38519 L .49444 .38719 L .935 .817 0 r
F
.44847 .57348 m .42838 .57 L .4285 .5724 L 1 .495 0 r
F
.44853 .57585 m .44847 .57348 L .4285 .5724 L 1 .482 0 r
F
.41025 .42402 m .39837 .41826 L .39729 .42068 L 1 1 0 r
F
.41025 .42402 m .41114 .42154 L .39837 .41826 L F
.33799 .49887 m .32373 .48895 L .32306 .49206 L 1 .998 0 r
F
.33746 .50202 m .33799 .49887 L .32306 .49206 L 1 .988 0 r
F
.47062 .38963 m .45927 .38748 L .45893 .38984 L 1 .973 0 r
F
.47062 .38963 m .47067 .38721 L .45927 .38748 L F
.42465 .35523 m .41918 .35679 L .41739 .35878 L .946 .768 0 r
F
.42465 .35523 m .42613 .35287m .69622 .12944 L .69552 .14314 L F
.54764 .55878 m .52895 .55908 L .52879 .5615 L .753 .211 0 r
F
.54764 .55878 m .54786 .55634 L .52895 .55908 L F
.75459 .3682 m .75259 .37325 L .75343 .37881 L 0 0 0 r
F
.5569 .41086 m .54321 .41234 L .54423 .41493 L .729 .578 0 r
F
.55807 .41343 m .5569 .41086 L .54423 .41493 L .726 .57 0 r
F
.53517 .39493 m .5223 .39546 L .52323 .39802 L .804 .679 0 r
F
.5363 .39747 m .53517 .39493 L .52323 .39802 L .802 .673 0 r
F
.4487 .56999 m .42899 .56616 L .42912 .56846 L 1 .482 0 r
F
.44878 .57226 m .4487 .56999 L .42912 .56846 L 1 .469 0 r
F
.35726 .25208 m .35335 .23719 L .35282 .24751 L 1 1 0 r
F
.35591 .26016 m .35726 .25208 L .35282 .24751 L 1 .775 0 r
F
.42874 .56148 m .40946 .55669 L .40961 .55907 L 1 .567 0 r
F
.42886 .56383 m .42874 .56148 L .40961 .55907 L 1 .555 0 r
F
.57869 .75801 m .55486 .76407 L .55386 .76801 L .378 .016 0 r
F
.57869 .75801 m .58007 .75434 L .55486 .76407 L F
.31965 .85829 m .28391 .84923 L .28685 .85327 L .955 .072 0 r
F
.32209 .86213 m .31965 .85829 L .28685 .85327 L .935 .069 0 r
F
.52798 .57101 m .50874 .57051 L .5086 .57285 L .819 .243 0 r
F
.52798 .57101 m .52821 .56866 L .50874 .57051 L F
.56423 .88305 m .53322 .88239 L .53193 .88554 L .503 .012 0 r
F
.56423 .88305 m .56617 .87985 L .53322 .88239 L F
.28677 .79912 m .25098 .79181 L .25371 .79625 L 1 .195 0 r
F
.28907 .8034 m .28677 .79912 L .25371 .79625 L 1 .172 0 r
F
.50827 .57747 m .48862 .57617 L .48853 .57848 L .885 .292 0 r
F
.50827 .57747 m .50844 .57517 L .48862 .57617 L F
.56544 .53435 m .54788 .53556 L .54781 .53809 L .678 .2 0 r
F
.56544 .53435 m .56552 .53182 L .54788 .53556 L F
.51189 .63019 m .4904 .62996 L .49019 .63212 L .743 .063 0 r
F
.51189 .63019 m .51232 .62807 L .4904 .62996 L F
.58035 .49596 m .56409 .49789 L .56436 .50055 L .626 .259 0 r
F
.58035 .49596 m .58003 .49331 L .56409 .49789 L F
.54493 .28046 m .55914 .22406 L .5508 .26205 L 1 .547 0 r
F
.54493 .28046 m .55077 .25134 L .55914 .22406 L F
.55497 .23791 m .5722 .17069 L .56702 .20437 L 1 .636 0 r
F
.55497 .23791 m .56344 .19642 L .5722 .17069 L F
.22799 .80648 m .19316 .79289 L .19633 .79798 L 1 .177 0 r
F
.23084 .81134 m .22799 .80648 L .19633 .79798 L 1 .15 0 r
F
.35236 .56167 m .33404 .55228 L .33415 .55537 L 1 .76 0 r
F
.35253 .56472 m .35236 .56167 L .33415 .55537 L 1 .747 0 r
F
.68772 .39802 m .68118 .40202 L .67962 .40723 L 0 0 0 r
F
.68772 .39802 m .68931 .39278 L .68118 .40202 L F
.39082 .51818 m .37387 .51137 L .37369 .51399 L 1 .814 0 r
F
.3907 .52078 m .39082 .51818 L .37369 .51399 L 1 .805 0 r
F
.37506 .59366 m .35458 .58563 L .35501 .58855 L 1 .594 0 r
F
.37547 .59649 m .37506 .59366 L .35501 .58855 L 1 .58 0 r
F
.37056 .40944 m .3619 .40281 L .36011 .40532 L 1 1 0 r
F
.37056 .40944 m .37215 .40679 L .3619 .40281 L F
.86536 .61114 m .84351 .62078 L .84231 .62722 L .072 0 0 r
F
.86536 .61114 m .86666 .60457 L .84351 .62078 L F
.50793 .57387 m .48849 .5727 L .4884 .57494 L .879 .279 0 r
F
.50793 .57387 m .5081 .57163 L .48849 .5727 L F
.67098 .67571 m .64907 .67966 L .64777 .68367 L .326 .013 0 r
F
.67098 .67571 m .67263 .6718 L .64907 .67966 L F
.17924 .75 m .14682 .73316 L .14945 .73889 L 1 .339 0 r
F
.18169 .7555 m .17924 .75 L .14945 .73889 L 1 .312 0 r
F
.5345 .39173 m .52159 .39248 L .52254 .39506 L .828 .695 0 r
F
.53564 .3943 m .5345 .39173 L .52254 .39506 L .824 .69 0 r
F
.54677 .55526 m .52839 .5557 L .52823 .55809 L .743 .202 0 r
F
.54677 .55526 m .54698 .55286 L .52839 .5557 L F
.52741 .56742 m .50842 .56707 L .50827 .56936 L .811 .232 0 r
F
.52741 .56742 m .52764 .56512 L .50842 .56707 L F
.45861 .39221 m .4476 .38938 L .44699 .3917 L 1 1 0 r
F
.45861 .39221 m .45893 .38984 L .4476 .38938 L F
.42242 .62434 m .40002 .61926 L .40052 .62181 L 1 .345 0 r
F
.42279 .62677 m .42242 .62434 L .40052 .62181 L 1 .328 0 r
F
.72245 .25271 m .72891 .24801 L .73087 .2547 L 1 .298 0 r
F
.72245 .25271 m .72256 .24451 L .72891 .24801 L F
.66624 .45559 m .65618 .46035 L .65531 .46421 L 0 0 0 r
F
.66624 .45559 m .6672 .45172 L .65618 .46035 L F
.55729 .41404 m .54373 .41539 L .54471 .41798 L .711 .559 0 r
F
.55843 .4166 m .55729 .41404 L .54471 .41798 L .708 .551 0 r
F
.39997 .38953 m .39179 .38503 L .38999 .38724 L 1 1 0 r
F
.39997 .38953 m .40147 .3871 L .39179 .38503 L F
.33746 .50202 m .32306 .49206 L .32244 .49518 L 1 .988 0 r
F
.33696 .50518 m .33746 .50202 L .32244 .49518 L 1 .978 0 r
F
.63393 .85418 m .60531 .85569 L .60294 .8592 L .381 0 0 r
F
.63393 .85418 m .63687 .85058 L .60531 .85569 L F
.41114 .42154 m .39948 .41585 L .39837 .41826 L 1 1 0 r
F
.41114 .42154 m .41205 .41907 L .39948 .41585 L F
.40367 .3763 m .39699 .37349 L .39508 .37561 L F
.40367 .3763 m .40533 .37396 L .39699 .37349 L F
.70087 .13536 m .69466 .14445 L .70085 .14822 L .274 .33 0 r
F
.70087 .13536 m .69467 .13186 L .69466 .14445 L F
.7395 .57173 m .71972 .57808 L .71892 .58259 L .221 .012 0 r
F
.7395 .57173 m .74041 .56715 L .71972 .57808 L F
.58262 .50423 m .5659 .50615 L .56611 .50882 L .63 .244 0 r
F
.58262 .50423 m .58237 .50155 L .5659 .50615 L F
.51416 .21286 m .5258 .10781 L .52314 .16623 L .498 .066 0 r
F
.36739 .50795 m .35007 .5 L .34989 .50282 L 1 .817 0 r
F
.36731 .51072 m .36739 .50795 L .34989 .50282 L 1 .807 0 r
F
.70649 .32933 m .70435 .33128 L .70324 .33811 L 0 0 0 r
F
.70649 .32933 m .7073 .32275 L .70435 .33128 L F
.48228 .38628 m .47072 .38481 L .47067 .38721 L 1 .939 0 r
F
.48228 .38628 m .48204 .38381 L .47072 .38481 L F
.46524 .89061 m .46518 .88759 L .43158 .88714 L .692 .035 0 r
F
.49815 .89008 m .46518 .88759 L .46524 .89061 L .635 .028 0 r
F
.49815 .89008 m .49877 .88706 L .46518 .88759 L F
.40902 .54696 m .39054 .54117 L .39063 .54366 L 1 .669 0 r
F
.4091 .54942 m .40902 .54696 L .39063 .54366 L 1 .658 0 r
F
.55571 .40829 m .54218 .40975 L .54321 .41234 L .731 .585 0 r
F
.5569 .41086 m .55571 .40829 L .54321 .41234 L .729 .578 0 r
F
.07571 .56885 m .0512 .54396 L .05136 .55098 L 1 .752 0 r
F
.07597 .57572 m .07571 .56885 L .05136 .55098 L 1 .731 0 r
F
.69343 .24048 m .69871 .23382 L .70075 .24063 L 1 .189 0 r
F
.69343 .24048 m .69137 .23413 L .69871 .23382 L F
.5187 .38473 m .50624 .38497 L .50699 .38754 L .905 .773 0 r
F
.51967 .38732 m .5187 .38473 L .50699 .38754 L .899 .768 0 r
F
.54565 .25137 m .56634 .16896 L .55975 .209 L 1 .726 0 r
F
.54565 .25137 m .5553 .2043 L .56634 .16896 L F
.56659 .54023 m .54869 .54135 L .5486 .54389 L .685 .196 0 r
F
.56659 .54023 m .5667 .53768 L .54869 .54135 L F
.44543 .6305 m .42279 .62677 L .42318 .62916 L .999 .244 0 r
F
.44565 .63278 m .44543 .6305 L .42318 .62916 L .991 .225 0 r
F
.46798 .63298 m .44543 .6305 L .44565 .63278 L .918 .151 0 r
F
.42828 .56757 m .40814 .56358 L .40831 .56602 L 1 .552 0 r
F
.42838 .57 m .42828 .56757 L .40831 .56602 L 1 .54 0 r
F
.42253 .36768 m .41584 .36692 L .41419 .36903 L 1 1 0 r
F
.42253 .36768 m .42388 .36527 L .41584 .36692 L F
.3868 .53865 m .36748 .53232 L .3676 .53496 L 1 .67 0 r
F
.38693 .54122 m .3868 .53865 L .3676 .53496 L 1 .663 0 r
F
.84509 .28568 m .83202 .29956 L .8358 .30561 L .147 .069 0 r
F
.84509 .28568 m .84113 .27976 L .83202 .29956 L F
.58063 .49862 m .56436 .50055 L .5646 .5032 L .623 .247 0 r
F
.58063 .49862 m .58035 .49596 L .56436 .50055 L F
.81714 .70739 m .79307 .71448 L .79073 .72021 L .14 0 0 r
F
.81714 .70739 m .8197 .7015 L .79307 .71448 L F
.40771 .55619 m .38759 .55135 L .38779 .55385 L 1 .599 0 r
F
.40784 .55867 m .40771 .55619 L .38779 .55385 L 1 .593 0 r
F
.51846 .38521 m .50616 .38519 L .50691 .38775 L .884 .761 0 r
F
.51944 .38778 m .51846 .38521 L .50691 .38775 L .88 .757 0 r
F
.55613 .41149 m .54272 .41281 L .54373 .41539 L .713 .567 0 r
F
.55729 .41404 m .55613 .41149 L .54373 .41539 L .711 .559 0 r
F
.37215 .40679 m .36372 .40035 L .3619 .40281 L 1 1 0 r
F
.37215 .40679 m .37376 .40418 L .36372 .40035 L F
.53403 .39238 m .52135 .3929 L .5223 .39546 L .807 .684 0 r
F
.53517 .39493 m .53403 .39238 L .5223 .39546 L .804 .679 0 r
F
.76539 .76909 m .73991 .77423 L .73706 .77924 L .21 0 0 r
F
.76539 .76909 m .76858 .76392 L .73991 .77423 L F
.55562 .61466 m .53583 .61635 L .53523 .6186 L .558 .044 0 r
F
.55562 .61466 m .55641 .6124 L .53583 .61635 L F
.3907 .52078 m .37369 .51399 L .37354 .51659 L 1 .805 0 r
F
.3906 .52337 m .3907 .52078 L .37354 .51659 L 1 .796 0 r
F
.27874 .83065 m .24384 .81947 L .24693 .82395 L 1 .087 0 r
F
.28143 .8349 m .27874 .83065 L .24693 .82395 L 1 .083 0 r
F
.66787 .13572 m .66218 .14284 L .66796 .14684 L .26 .312 0 r
F
.66787 .13572 m .66188 .13235 L .66218 .14284 L F
.46857 .57869 m .44853 .57585 L .4486 .5782 L 1 .419 0 r
F
.46856 .58098 m .46857 .57869 L .4486 .5782 L 1 .406 0 r
F
.48844 .58076 m .46857 .57869 L .46856 .58098 L .947 .346 0 r
F
.48844 .58076 m .48853 .57848 L .46857 .57869 L F
.87192 .62046 m .84852 .62968 L .84731 .63624 L .108 0 0 r
F
.87192 .62046 m .87322 .61374 L .84852 .62968 L F
.33696 .50518 m .32244 .49518 L .32185 .49831 L 1 .978 0 r
F
.3365 .50834 m .33696 .50518 L .32185 .49831 L 1 .969 0 r
F
.13669 .66031 m .10622 .64122 L .10787 .64742 L 1 .552 0 r
F
.13829 .66627 m .13669 .66031 L .10787 .64742 L 1 .531 0 r
F
.50549 .38239 m .49343 .38213 L .49394 .38466 L .963 .839 0 r
F
.50624 .38497 m .50549 .38239 L .49394 .38466 L .956 .834 0 r
F
.50541 .38262 m .49343 .38213 L .49394 .38466 L .946 .828 0 r
F
.50616 .38519 m .50541 .38262 L .49394 .38466 L .94 .823 0 r
F
.70885 .13626 m .70178 .14687 L .70797 .15069 L .321 .395 0 r
F
.70885 .13626 m .70257 .13279 L .70178 .14687 L F
.58363 .08934 m .57899 .09385 L .58587 .09593 L .425 .647 0 r
F
.58363 .08934 m .5768 .08858 L .57899 .09385 L F
.5768 .08858 m .57668 .08869 L .57899 .09385 L F
.58336 .09027 m .5768 .08858 L .57872 .09481 L .382 .558 0 r
F
.5768 .08858 m .57663 .08854 L .57668 .08869 L F
.5768 .08858 m .57668 .08869 L .57872 .09481 L F
.5768 .08858 m .57662 .08856 L .57668 .08869 L .425 .647 0 r
F
.58283 .5069 m .56611 .50882 L .5663 .5115 L .626 .232 0 r
F
.58283 .5069 m .58262 .50423 L .56611 .50882 L F
.24077 .77341 m .20556 .76288 L .20835 .76779 L 1 .269 0 r
F
.24322 .7781 m .24077 .77341 L .20835 .76779 L 1 .247 0 r
F
.84412 .28618 m .83079 .30018 L .83448 .30625 L .15 .068 0 r
F
.84412 .28618 m .84026 .28023 L .83079 .30018 L F
.5545 .40573 m .54113 .40716 L .54218 .40975 L .734 .592 0 r
F
.55571 .40829 m .5545 .40573 L .54218 .40975 L .731 .585 0 r
F
.44853 .57585 m .4285 .5724 L .42863 .57479 L 1 .482 0 r
F
.4486 .5782 m .44853 .57585 L .42863 .57479 L 1 .468 0 r
F
.56534 .53687 m .54781 .53809 L .54773 .54059 L .674 .187 0 r
F
.56534 .53687 m .56544 .53435 L .54781 .53809 L F
.6013 .57942 m .58389 .5829 L .58313 .5855 L .372 .027 0 r
F
.6013 .57942 m .60219 .5768 L .58389 .5829 L F
.46861 .57515 m .44878 .57226 L .44886 .5745 L 1 .404 0 r
F
.46861 .57737 m .46861 .57515 L .44886 .5745 L 1 .391 0 r
F
.4883 .57716 m .46861 .57515 L .46861 .57737 L .944 .332 0 r
F
.4883 .57716 m .4884 .57494 L .46861 .57515 L F
.39907 .61408 m .37737 .6076 L .37792 .61031 L 1 .453 0 r
F
.39954 .61669 m .39907 .61408 L .37792 .61031 L 1 .436 0 r
F
.88933 .47096 m .87079 .48333 L .87154 .49013 L .047 .008 0 r
F
.88933 .47096 m .88861 .46409 L .87079 .48333 L F
.54741 .5612 m .52879 .5615 L .52861 .56391 L .749 .199 0 r
F
.54741 .5612 m .54764 .55878 L .52879 .5615 L F
.53334 .38915 m .52064 .38991 L .52159 .39248 L .832 .7 0 r
F
.5345 .39173 m .53334 .38915 L .52159 .39248 L .828 .695 0 r
F
.47067 .38721 m .4596 .38514 L .45927 .38748 L 1 .981 0 r
F
.47067 .38721 m .47072 .38481 L .4596 .38514 L F
.58088 .50127 m .5646 .5032 L .56482 .50585 L .619 .236 0 r
F
.58088 .50127 m .58063 .49862 L .5646 .5032 L F
.57812 .60045 m .55941 .60304 L .55869 .60543 L .459 .035 0 r
F
.57812 .60045 m .57901 .59804 L .55941 .60304 L F
.42886 .56383 m .40961 .55907 L .40978 .56143 L 1 .555 0 r
F
.42899 .56616 m .42886 .56383 L .40978 .56143 L 1 .543 0 r
F
.58336 .09027 m .57872 .09481 L .58539 .09752 L .382 .558 0 r
F
.36731 .51072 m .34989 .50282 L .34974 .50562 L 1 .807 0 r
F
.36724 .51347 m .36731 .51072 L .34974 .50562 L 1 .798 0 r
F
.55495 .40895 m .54169 .41024 L .54272 .41281 L .715 .574 0 r
F
.55613 .41149 m .55495 .40895 L .54272 .41281 L .713 .567 0 r
F
.44878 .57226 m .42912 .56846 L .42928 .57074 L 1 .469 0 r
F
.44886 .5745 m .44878 .57226 L .42928 .57074 L 1 .457 0 r
F
.40147 .3871 m .39361 .38287 L .39179 .38503 L 1 1 0 r
F
.40147 .388 L .52764 .56512 L .731 .163 0 r
F
.546 .56234 m .54628 .56 L .52785 .5628 L F
.85151 .29827 m .83807 .31237 L .84155 .31855 L .13 .062 0 r
F
.85151 .29827 m .84787 .29219 L .83807 .31237 L F
.47076 .38241 m .46028 .3805 L .45994 .38281 L 1 .996 0 r
F
.47076 .38241 m .47081 .38003 L .46028 .3805 L F
.36179 .86698 m .32694 .85969 L .32945 .86328 L .881 .061 0 r
F
.36374 .87037 m .36179 .86698 L .32945 .86328 L .86 .057 0 r
F
.65604 .15299 m .65605 .15288 L .65771 .15355 L .83 .176 0 r
F
.65771 .15355 m .65733 .15142 L .65935 .15422 L .697 .098 0 r
F
.65771 .15355 m .65515 .14465 L .65733 .15142 L F
.658 .13644 m .65515 .14465 L .65771 .15355 L 0 0 0 r
F
.65605 .15288 m .658 .13644 L .65771 .15355 L .83 .176 0 r
F
.65771 .15355 m .65935 .15422 L .6617 .15746 L .697 .098 0 r
F
.36719 .51893 m .34954 .51119 L .34948 .51395 L 1 .779 0 r
F
.3672 .52164 m .36719 .51893 L .34948 .51395 L 1 .77 0 r
F
.09447 .55807 m .07006 .5344 L .07021 .54109 L 1 .763 0 r
F
.09474 .5646 m .09447 .55807 L .07021 .54109 L 1 .743 0 r
F
.38723 .54631 m .36792 .54018 L .36812 .54277 L 1 .65 0 r
F
.3874 .54884 m .38723 .54631 L .36812 .54277 L 1 .643 0 r
F
.39043 .53107 m .37326 .52435 L .37322 .52691 L 1 .766 0 r
F
.39043 .53362 m .39043 .53107 L .37322 .52691 L 1 .756 0 r
F
.81447 .71323 m .79073 .72021 L .78829 .72589 L .131 0 0 r
F
.81447 .71323 m .81714 .70739 L .79073 .72021 L F
.46861 .57956 m .44895 .57672 L .44904 .57892 L 1 .378 0 r
F
.4686 .58172 m .46861 .57956 L .44904 .57892 L 1 .364 0 r
F
.4881 .58151 m .46861 .57956 L .4686 .58172 L .936 .305 0 r
F
.4881 .58151 m .48821 .57935 L .46861 .57956 L F
.35295 .57078 m .33449 .56152 L .33472 .56457 L 1 .72 0 r
F
.35321 .57378 m .35295 .57078 L .33472 .56457 L 1 .707 0 r
F
.56487 .54432 m .5475 .54555 L .54735 .54801 L .662 .15 0 r
F
.56487 .54432 m .56506 .54185 L .5475 .54555 L F
.5155 .37739 m .50388 .37743 L .50465 .38003 L .902 .77 0 r
F
.51649 .38002 m .5155 .37739 L .50465 .38003 L .895 .768 0 r
F
.38464 .45612 m .37157 .44895 L .37071 .45152 L 1 1 0 r
F
.38464 .45612 m .38538 .45352 L .37157 .44895 L F
.38392 .45872 m .38464 .45612 L .37071 .45152 L F
.38392 .45872 m .37071 .45152 L .36987 .45409 L F
.38323 .46133 m .38392 .45872 L .36987 .45409 L F
.36809 .8262 m .33339 .82411 L .33548 .82792 L .924 .076 0 r
F
.36965 .82993 m .36809 .8262 L .33548 .82792 L .911 .074 0 r
F
.38538 .45352 m .37247 .4464 L .37157 .44895 L 1 1 0 r
F
.38538 .45352 m .38614 .45093 L .37247 .4464 L F
.35558 .46272 m .3418 .45381 L .34099 .45668 L F
.35494 .46561 m .35558 .46272 L .34099 .45668 L 1 .994 0 r
F
.52721 .57791 m .50827 .57747 L .50808 .57974 L .806 .202 0 r
F
.52721 .57791 m .52748 .57563 L .50827 .57747 L F
.72205 .26846 m .73263 .2614 L .73423 .26809 L 1 .595 0 r
F
.72205 .26846 m .72224 .26073 L .73263 .2614 L F
.44895 .57672 m .42944 .573 L .42962 .57523 L 1 .444 0 r
F
.44904 .57892 m .44895 .57672 L .42962 .57523 L 1 .43 0 r
F
.38614 .45093 m .37339 .44385 L .37247 .4464 L 1 1 0 r
F
.38614 .45093 m .38694 .44835 L .37339 .44385 L F
.54818 .39298 m .53564 .3943 L .53677 .39687 L .75 .623 0 r
F
.54948 .39553 m .54818 .39298 L .53677 .39687 L .746 .618 0 r
F
.40814 .56358 m .38824 .55881 L .3885 .56127 L 1 .578 0 r
F
.40831 .56602 m .40814 .56358 L .3885 .56127 L 1 .569 0 r
F
.4087 .36941 m .40282 .36736 L .40086 .36936 L 1 1 0 r
F
.4087 .36941 m .41041 .3672 L .40282 .36736 L F
.37398 .41185 m .36407 .40435 L .36243 .40688 L F
.37398 .41185 m .3754 .40921 L .36407 .40435 L F
.39623 .42313 m .3754 .40921 L .37398 .41185 L .912 .646 0 r
F
.39519 .42559 m .39623 .42313 L .37398 .41185 L .917 .647 0 r
F
.38694 .44835 m .37435 .44131 L .37339 .44385 L 1 1 0 r
F
.38694 .44835 m .38775 .44578 L .37435 .44131 L F
.72721 .14737 m .72013 .15864 L .72609 .16277 L .284 .319 0 r
F
.72721 .14737 m .72118 .14355 L .72013 .15864 L F
.54874 .39634 m .5363 .39747 L .53741 .40001 L .727 .608 0 r
F
.55002 .39885 m .54874 .39634 L .53741 .40001 L .724 .602 0 r
F
.42863 .57479 m .40871 .57083 L .40893 .57321 L 1 .516 0 r
F
.42877 .57715 m .42863 .57479 L .40893 .57321 L 1 .503 0 r
F
.4596 .38514 m .44946 .38256 L .44883 .38481 L 1 1 0 r
F
.4596 .38514 m .45994 .38281 L .44946 .38256 L F
.52663 .57419 m .50793 .57387 L .50774 .57609 L .798 .192 0 r
F
.52663 .57419 m .52691 .57196 L .50793 .57387 L F
.50769 .58422 m .48835 .58301 L .48825 .58524 L .872 .25 0 r
F
.50769 .58422 m .50789 .58199 L .48835 .58301 L F
.28907 .8034 m .25371 .79625 L .25651 .80062 L 1 .172 0 r
F
.29142 .80761 m .28907 .8034 L .25651 .80062 L 1 .15 0 r
F
.73748 .58082 m .71806 .58706 L .71715 .59152 L .208 .007 0 r
F
.73748 .58082 m .73852 .57629 L .71806 .58706 L F
.58169 .51439 m .56541 .51637 L .5655 .51897 L .599 .177 0 r
F
.58169 .51439 m .58159 .51178 L .56541 .51637 L F
.3805 .39406 m .37326 .38857 L .3713 .39085 L 1 1 0 r
F
.3805 .39406 m .38224 .39162 L .37326 .38857 L F
.37767 .48232 m .3633 .47482 L .36271 .47746 L 1 .961 0 r
F
.37719 .48497 m .37767 .48232 L .36271 .47746 L 1 .953 0 r
F
.38775 .44578 m .37534 .43879 L .37435 .44131 L 1 1 0 r
F
.38775 .44578 m .3886 .44321 L .37534 .43879 L F
.52936 .38216 m .51748 .38262 L .51846 .38521 L .823 .7 0 r
F
.53054 .38473 m .52936 .38216 L .51846 .38521 L .818 .697 0 r
F
.58345 .52017 m .56678 .5221 L .56683 .52472 L .606 .173 0 r
F
.58345 .52017 m .58339 .51753 L .56678 .5221 L F
.69725 .25293 m .70257 .24748 L .70415 .25435 L 1 .17 0 r
F
.69725 .25293 m .6954 .24674 L .70257 .24748 L F
.33504 .52098 m .31993 .51083 L .31956 .51397 L 1 .927 0 r
F
.33476 .52414 m .33504 .52098 L .31956 .51397 L 1 .916 0 r
F
.48156 .37888 m .47086 .37765 L .47081 .38003 L 1 .962 0 r
F
.48156 .37888 m .48132 .37641 L .47086 .37765 L F
.67337 .84765 m .64568 .84965 L .64284 .85359 L .34 0 0 r
F
.67337 .84765 m .67673 .84359 L .64568 .84965 L F
.23084 .81134 m .19633 .79798 L .19959 .80299 L 1 .15 0 r
F
.23377 .81611 m .23084 .81134 L .19959 .80299 L 1 .123 0 r
F
.35494 .46561 m .34099 .45668 L .34023 .45956 L 1 .994 0 r
F
.35433 .46851 m .35494 .46561 L .34023 .45956 L 1 .985 0 r
F
.68494 .14707 m .67911 .15532 L .68445 .15983 L .222 .21 0 r
F
.68494 .14707 m .67942 .14306 L .67911 .15532 L F
.64432 .51551 m .6313 .52043 L .63065 .52357 L .169 0 0 r
F
.64432 .51551 m .64504 .51237 L .6313 .52043 L F
.50734 .58046 m .48821 .57935 L .4881 .58151 L .867 .239 0 r
F
.50734 .58046 m .50755 .57829 L .48821 .57935 L F
.3886 .44321 m .37635 .43628 L .37534 .43879 L 1 1 0 r
F
.3886 .44321 m .38946 .44066 L .37635 .43628 L F
.58451 .13158 m .59181 .10089 L .59805 .1046 L 1 .453 0 r
F
.58451 .13158 m .58945 .09403 L .59181 .10089 L F
.5659 .55029 m .54822 .55141 L .54805 .55388 L .667 .146 0 r
F
.5659 .55029 m .56611 .5478 L .54822 .55141 L F
.59553 .86916 m .56642 .86977 L .56453 .87294 L .42 0 0 r
F
.59553 .86916 m .59805 .86594 L .56642 .86977 L F
.42318 .62916 m .40105 .62432 L .40159 .6268 L 1 .31 0 r
F
.42358 .63152 m .42318 .62916 L .40159 .6268 L 1 .291 0 r
F
.50319 .37453 m .49188 .37447 L .4924 .37704 L .987 .852 0 r
F
.50396 .37717 m .50319 .37453 L .4924 .37704 L .978 .849 0 r
F
.50311 .3748 m .49188 .37447 L .4924 .37704 L .969 .84 0 r
F
.50388 .37743 m .50311 .3748 L .4924 .37704 L .96 .837 0 r
F
.40611 .38005 m .39919 .37665 L .39731 .37868 L 1 1 0 r
F
.40611 .38005 m .4077 .37777 L .39919 .37665 L F
.3754 .40921 m .36576 .40186 L .36407 .40435 L F
.3754 .40921 m .37686 .4066 L .36576 .40186 L F
.39729 .42068 m .37686 .4066 L .3754 .40921 L .907 .645 0 r
F
.39623 .42313 m .39729 .42068 L .3754 .40921 L .912 .646 0 r
F
.37719 .48497 m .36271 .47746 L .36215 .4801 L 1 .953 0 r
F
.37673 .48762 m .37719 .48497 L .36215 .4801 L 1 .946 0 r
F
.75799 .38373 m .75501 .38979 L .75575 .39521 L 0 0 0 r
F
.75799 .38373 m .75688 .37858 L .75501 .38979 L F
.52864 .37872 m .51673 .37949 L .51772 .38212 L .853 .712 0 r
F
.52983 .38136 m .52864 .37872 L .51772 .38212 L .847 .71 0 r
F
.42913 .34824 m .4246 .35113 L .42278 .35297 L .766 .319 0 r
F
.42913 .34824 m .43065 .34599 L .4246 .35113 L F
.38946 .44066 m .37739 .43378 L .37635 .43628 L 1 1 0 r
F
.38946 .44066 m .39036 .43812 L .37739 .43378 L F
.76211 .77419 m .73706 .77924 L .73412 .78419 L .201 0 0 r
F
.76211 .77419 m .76539 .76909 L .73706 .77924 L F
.72548 .14962 m .71908 .16 L .72504 .16407 L .263 .304 0 r
F
.72548 .14962 m .71938 .14597 L .71908 .16 L F
.39043 .53362 m .37322 .52691 L .37321 .52947 L 1 .756 0 r
F
.39044 .53615 m .39043 .53362 L .37321 .52947 L 1 .745 0 r
F
.40946 .55669 m .39102 .55102 L .3912 .55344 L 1 .624 0 r
F
.40961 .55907 m .40946 .55669 L .3912 .55344 L 1 .611 0 r
F
.59944 .58457 m .58235 .58808 L .58155 .59062 L .363 .023 0 r
F
.59944 .58457 m .60038 .58201 L .58235 .58808 L F
.54657 .56833 m .52821 .56866 L .52798 .57101 L .735 .159 0 r
F
.54657 .56833 m .54687 .56597 L .52821 .56866 L F
.51475 .37413 m .50319 .37453 L .50396 .37717 L .934 .783 0 r
F
.51574 .37683 m .51475 .37413 L .50396 .37717 L .925 .782 0 r
F
.54687 .39043 m .5345 .39173 L .53564 .3943 L .753 .628 0 r
F
.54818 .39298 m .54687 .39043 L .53564 .3943 L .75 .623 0 r
F
.3672 .52164 m .34948 .51395 L .34946 .51671 L 1 .77 0 r
F
.36724 .52433 m .3672 .52164 L .34946 .51671 L 1 .76 0 r
F
.42664 .36054 m .42085 .36076 L .41917 .36278 L 1 1 0 r
F
.42664 .36054 m .42803 .35822 L .42085 .36076 L F
.62242 .55611 m .60704 .56044 L .60628 .56324 L .283 .014 0 r
F
.62242 .55611 m .62327 .55329 L .60704 .56044 L F
.35433 .46851 m .34023 .45956 L .3395 .46244 L 1 .985 0 r
F
.35377 .4714 m .35433 .46851 L .3395 .46244 L 1 .976 0 r
F
.24322 .7781 m .20835 .76779 L .21121 .77263 L 1 .247 0 r
F
.24574 .78273 m .24322 .7781 L .21121 .77263 L 1 .224 0 r
F
.85635 .3038 m .84307 .31788 L .84655 .3241 L .12 .061 0 r
F
.85635 .3038 m .8527 .2977 L .84307 .31788 L F
.51099 .63431 m .48998 .63423 L .48976 .63631 L .721 .058 0 r
F
.51099 .63431 m .51145 .63227 L .48998 .63423 L F
.76223 .49735 m .74743 .5056 L .74719 .51046 L .066 0 0 r
F
.76223 .49735 m .76236 .49244 L .74743 .5056 L F
.68466 .40801 m .67812 .41228 L .67668 .41717 L 0 0 0 r
F
.68466 .40801 m .68616 .40309 L .67812 .41228 L F
.63525 .71418 m .6138 .71885 L .61242 .7227 L .316 .003 0 r
F
.63525 .71418 m .63703 .71054 L .6138 .71885 L F
.43221 .88067 m .39818 .87616 L .39956 .87928 L .753 .043 0 r
F
.43295 .88363 m .43221 .88067 L .39956 .87928 L .731 .038 0 r
F
.46534 .88397 m .43221 .88067 L .43295 .88363 L .681 .033 0 r
F
.54744 .39383 m .53517 .39493 L .5363 .39747 L .729 .613 0 r
F
.54874 .39634 m .54744 .39383 L .5363 .39747 L .727 .608 0 r
F
.39036 .43812 m .37846 .43129 L .37739 .43378 L 1 1 0 r
F
.39036 .43812 m .39128 .43559 L .37846 .43129 L F
.37673 .48762 m .36215 .4801 L .36161 .48274 L 1 .946 0 r
F
.37631 .49028 m .37673 .48762 L .36161 .48274 L 1 .938 0 r
F
.40002 .61926 m .37849 .613 L .37908 .61565 L 1 .419 0 r
F
.40052 .62181 m .40002 .61926 L .37908 .61565 L 1 .402 0 r
F
.3874 .54884 m .36812 .54277 L .36833 .54535 L 1 .643 0 r
F
.38759 .55135 m .3874 .54884 L .36833 .54535 L 1 .636 0 r
F
.56466 .54677 m .54735 .54801 L .54718 .55045 L .657 .138 0 r
F
.56466 .54677 m .56487 .54432 L .54735 .54801 L F
.58175 .51699 m .5655 .51897 L .56555 .52157 L .595 .165 0 r
F
.58175 .51699 m .58169 .51439 L .5655 .51897 L F
.51451 .37473 m .50311 .3748 L .50388 .37743 L .91 .771 0 r
F
.5155 .37739 m .51451 .37473 L .50388 .37743 L .902 .77 0 r
F
.42928 .57074 m .41018 .56609 L .4104 .56839 L 1 .517 0 r
F
.42944 .573 m .42928 .57074 L .4104 .56839 L 1 .504 0 r
F
.5457 .56465 m .52764 .56512 L .52741 .56742 L .726 .15 0 r
F
.5457 .56465 m .546 .56234 L .52764 .56512 L F
.44876 .58281 m .42893 .57948 L .4291 .58179 L 1 .441 0 r
F
.44885 .58508 m .44876 .58281 L .4291 .58179 L 1 .426 0 r
F
.46856 .5855 m .44876 .58281 L .44885 .58508 L .997 .377 0 r
F
.58348 .5228 m .56683 .52472 L .56686 .52734 L .602 .161 0 r
F
.58348 .5228 m .58345 .52017 L .56683 .52472 L F
.37686 .4066 m .36751 .39942 L .36576 .40186 L 1 1 0 r
F
.37686 .4066 m .37837 .40403 L .36751 .39942 L F
.39837 .41826 m .37837 .40403 L .37686 .4066 L .901 .643 0 r
F
.39729 .42068 m .39837 .41826 L .37686 .4066 L .907 .645 0 r
F
.38224 .39162 m .37525 .38633 L .37326 .38857 L 1 1 0 r
F
.38224 .39162 m .38401 .38921 L .37525 .38633 L F
.44587 .63502 m .42358 .63152 L .42399 .63385 L .983 .206 0 r
F
.4461 .63722 m .44587 .63502 L .42399 .63385 L .973 .187 0 r
F
.46801 .63728 m .44587 .63502 L .4461 .63722 L .899 .114 0 r
F
.89039 .48471 m .87217 .49693 L .87268 .50373 L .025 0 0 r
F
.89039 .48471 m .88992 .47784 L .87217 .49693 L F
.58439 .44247 m .5703 .44492 L .57116 .44759 L .598 .381 0 r
F
.58533 .44512 m .57116 .44759 L .57199 .45027 L .595 .371 0 r
F
.58533 .44512 m .58439 .44247 L .57116 .44759 L F
.46856 .58772 m .46856 .5855 L .44885 .58508 L .993 .363 0 r
F
.48814 .58745 m .46856 .5855 L .46856 .58772 L .934 .304 0 r
F
.48814 .58745 m .48825 .58524 L .46856 .5855 L F
.58625 .44778 m .57199 .45027 L .57279 .45295 L .592 .361 0 r
F
.58625 .44778 m .58533 .44512 L .57199 .45027 L F
.58342 .43983 m .56942 .44226 L .5703 .44492 L .602 .391 0 r
F
.58439 .44247 m .58342 .43983 L .5703 .44492 L .598 .381 0 r
F
.37637 .6021 m .35596 .59432 L .35648 .59718 L 1 .549 0 r
F
.37686 .60486 m .37637 .6021 L .35648 .59718 L 1 .533 0 r
F
.39818 .87616 m .36374 .87037 L .36574 .87367 L .813 .051 0 r
F
.39956 .87928 m .39818 .87616 L .36574 .87367 L .791 .047 0 r
F
.39128 .43559 m .37957 .42882 L .37846 .43129 L 1 1 0 r
F
.39128 .43559 m .39222 .43307 L .37957 .42882 L F
.58713 .45044 m .57279 .45295 L .57357 .45564 L .588 .35 0 r
F
.58713 .45044 m .58625 .44778 L .57279 .45295 L F
.58241 .43719 m .56851 .4396 L .56942 .44226 L .605 .401 0 r
F
.58342 .43983 m .58241 .43719 L .56942 .44226 L .602 .391 0 r
F
.33476 .52414 m .31956 .51397 L .31923 .51711 L 1 .916 0 r
F
.33453 .52729 m .33476 .52414 L .31923 .51711 L 1 .904 0 r
F
.8188 .72399 m .79405 .73035 L .79155 .73613 L .158 0 0 r
F
.8188 .72399 m .82155 .71803 L .79405 .73035 L F
.47081 .38003 m .46063 .37821 L .46028 .3805 L 1 1 0 r
F
.47081 .38003 m .47086 .37765 L .46063 .37821 L F
.52817 .37957 m .51649 .38002 L .51748 .38262 L .828 .702 0 r
F
.52936 .38216 m .52817 .37957 L .51748 .38262 L .823 .7 0 r
F
.55396 .61905 m .53462 .62082 L .53399 .62299 L .535 .038 0 r
F
.55396 .61905 m .5548 .61687 L .53462 .62082 L F
.35321 .57378 m .33472 .56457 L .33498 .56761 L 1 .707 0 r
F
.3535 .57677 m .35321 .57378 L .33498 .56761 L 1 .693 0 r
F
.07634 .58258 m .05164 .55799 L .05205 .56499 L 1 .71 0 r
F
.07683 .58942 m .07634 .58258 L .05205 .56499 L 1 .688 0 r
F
.58798 .45311 m .57357 .45564 L .57432 .45833 L .585 .339 0 r
F
.58798 .45311 m .58713 .45044 L .57357 .45564 L F
.35377 .4714 m .3395 .46244 L .33882 .46532 L 1 .976 0 r
F
.35324 .47429 m .35377 .4714 L .33882 .46532 L 1 .967 0 r
F
.58138 .43457 m .56758 .43695 L .56851 .4396 L .608 .411 0 r
F
.58241 .43719 m .58138 .43457 L .56851 .4396 L .605 .401 0 r
F
.57627 .60515 m .55795 .60779 L .55719 .61012 L .438 .03 0 r
F
.57627 .60515 m .57721 .60282 L .55795 .60779 L F
.17866 .76637 m .14564 .74998 L .14858 .75566 L 1 .279 0 r
F
.18138 .77181 m .17866 .76637 L .14858 .75566 L 1 .252 0 r
F
.32209 .86213 m .28685 .85327 L .28985 .85722 L .935 .069 0 r
F
.32459 .86587 m .32209 .86213 L .28985 .85722 L .915 .065 0 r
F
.60326 .09605 m .59711 .09269 L .59922 .10112 L .25 .285 0 r
F
.85504 .3044 m .84155 .31855 L .84492 .32478 L .12 .059 0 r
F
.85504 .3044 m .85151 .29827 L .84155 .31855 L F
.37631 .49028 m .36161 .48274 L .36111 .48538 L 1 .938 0 r
F
.37591 .49293 m .37631 .49028 L .36111 .48538 L 1 .93 0 r
F
.5888 .45578 m .57432 .45833 L .57504 .46102 L .581 .329 0 r
F
.5888 .45578 m .58798 .45311 L .57432 .45833 L F
.58032 .43195 m .56662 .43431 L .56758 .43695 L .611 .421 0 r
F
.58138 .43457 m .58032 .43195 L .56758 .43695 L .608 .411 0 r
F
.40831 .56602 m .3885 .56127 L .38877 .56371 L 1 .569 0 r
F
.4085 .56843 m .40831 .56602 L .38877 .56371 L 1 .559 0 r
F
.73315 .15132 m .72609 .16277 L .73197 .16699 L .27 .29 0 r
F
.73315 .15132 m .72721 .14737 L .72609 .16277 L F
.4686 .58172 m .44904 .57892 L .44914 .58109 L 1 .364 0 r
F
.4686 .58386 m .4686 .58172 L .44914 .58109 L .996 .35 0 r
F
.48799 .58365 m .4686 .58172 L .4686 .58386 L .932 .291 0 r
F
.48799 .58365 m .4881 .58151 L .4686 .58172 L F
.12948 .68542 m .10045 .66518 L .10231 .67152 L 1 .49 0 r
F
.13129 .69155 m .12948 .68542 L .10231 .67152 L 1 .465 0 r
F
.52692 .58016 m .50808 .57974 L .50789 .58199 L .801 .188 0 r
F
.52692 .58016 m .52721 .57791 L .50808 .57974 L F
.54554 .38788 m .53334 .38915 L .5345 .39173 L .757 .632 0 r
F
.54687 .39043 m .54554 .38788 L .5345 .39173 L .753 .628 0 r
F
.66356 .46675 m .65367 .47171 L .65289 .47536 L 0 0 0 r
F
.66356 .46675 m .66442 .4631 L .65367 .47171 L F
.39222 .43307 m .38069 .42636 L .37957 .42882 L 1 1 0 r
F
.39222 .43307 m .39318 .43056 L .38069 .42636 L F
.86241 .62419 m .84101 .63363 L .8396 .64 L .054 0 0 r
F
.86241 .62419 m .86394 .61768 L .84101 .63363 L F
.58959 .45846 m .57504 .46102 L .57573 .46372 L .578 .318 0 r
F
.58959 .45846 m .5888 .45578 L .57504 .46102 L F
.57923 .42934 m .56563 .43167 L .56662 .43431 L .614 .43 0 r
F
.58032 .43195 m .57923 .42934 L .56662 .43431 L .611 .421 0 r
F
.41041 .3672 m .40479 .36541 L .40282 .36736 L 1 1 0 r
F
.41041 .3672 m .41213 .36503 L .40479 .36541 L F
.44904 .57892 m .42962 .57523 L .4298 .57744 L 1 .43 0 r
F
.44914 .58109 m .44904 .57892 L .4298 .57744 L 1 .417 0 r
F
.66748 .6834 m .64641 .68763 L .64499 .69156 L .299 .004 0 r
F
.66748 .6834 m .66926 .67957 L .64641 .68763 L F
.5494 .78289 m .52455 .78982 L .52376 .7936 L .392 .016 0 r
F
.5494 .78289 m .55059 .7793 L .52455 .78982 L F
.70441 .34216 m .70198 .34481 L .70058 .35138 L 0 0 0 r
F
.70441 .34216 m .70551 .3358 L .70198 .34481 L F
.42877 .57715 m .40893 .57321 L .40917 .57557 L 1 .503 0 r
F
.42893 .57948 m .42877 .57715 L .40917 .57557 L 1 .49 0 r
F
.52746 .37604 m .51574 .37683 L .51673 .37949 L .86 .712 0 r
F
.52864 .37872 m .52746 .37604 L .51673 .37949 L .853 .712 0 r
F
.28143 .8349 m .24693 .82395 L .25009 .82835 L 1 .083 0 r
F
.28418 .83907 m .28143 .8349 L .25009 .82835 L .997 .079 0 r
F
.54613 .39132 m .53403 .39238 L .53517 .39493 L .732 .619 0 r
F
.54744 .39383 m .54613 .39132 L .53517 .39493 L .729 .613 0 r
F
.39044 .53615 m .37321 .52947 L .37323 .53201 L 1 .745 0 r
F
.39048 .53867 m .39044 .53615 L .37323 .53201 L 1 .735 0 r
F
.56566 .55276 m .54805 .55388 L .54786 .55634 L .662 .134 0 r
F
.56566 .55276 m .5659 .55029 L .54805 .55388 L F
.37837 .40403 m .3693 .39703 L .36751 .39942 L 1 1 0 r
F
.37837 .40403 m .37991 .40149 L .3693 .39703 L F
.39948 .41585 m .37991 .40149 L .37837 .40403 L .928 .07 0 r
F
.39837 .41826 m .39948 .41585 L .37837 .40403 L .901 .643 0 r
F
.63092 .85768 m .60294 .8592 L .60052 .86262 L .371 0 0 r
F
.63092 .85768 m .63393 .85418 L .60294 .8592 L F
.59034 .46115 m .57573 .46372 L .57639 .46642 L .574 .307 0 r
F
.59034 .46115 m .58959 .45846 L .57573 .46372 L F
.57811 .42673 m .56462 .42904 L .56563 .43167 L .617 .44 0 r
F
.57923 .42934 m .57811 .42673 L .56563 .43167 L .614 .43 0 r
F
.52634 .57639 m .50774 .57609 L .50755 .57829 L .794 .178 0 r
F
.52634 .57639 m .52663 .57419 L .50774 .57609 L F
.6584 .16514 m .6617 .15746 L .66565 .16397 L .94 .168 0 r
F
.6584 .16514 m .65771 .15355 L .6617 .15746 L F
.19281 .73748 m .15939 .72338 L .16201 .72882 L 1 .353 0 r
F
.1952 .74268 m .19281 .73748 L .16201 .72882 L 1 .33 0 r
F
.36724 .52433 m .34946 .51671 L .34947 .51945 L 1 .76 0 r
F
.3673 .52701 m .36724 .52433 L .34947 .51945 L 1 .751 0 r
F
.37591 .49293 m .36111 .48538 L .36065 .48801 L 1 .93 0 r
F
.37553 .49557 m .37591 .49293 L .36065 .48801 L 1 .922 0 r
F
.50748 .58641 m .48825 .58524 L .48814 .58745 L .867 .236 0 r
F
.50748 .58641 m .50769 .58422 L .48825 .58524 L F
.89763 .49177 m .87797 .50404 L .87856 .51094 L .062 .009 0 r
F
.89763 .49177 m .897 .48478 L .87797 .50404 L F
.35324 .47429 m .33882 .46532 L .33818 .46821 L 1 .967 0 r
F
.35275 .47718 m .35324 .47429 L .33818 .46821 L 1 .957 0 r
F
.69025 .15133 m .68445 .15983 L .68959 .16454 L .198 .157 0 r
F
.69025 .15133 m .68494 .14707 L .68445 .15983 L F
.60464 .74108 m .58267 .74678 L .5814 .7506 L .321 .001 0 r
F
.60464 .74108 m .60631 .73753 L .58267 .74678 L F
.48132 .37641 m .47091 .37527 L .47086 .37765 L 1 .97 0 r
F
.48132 .37641 m .48107 .37393 L .47091 .37527 L F
.4077 .37777 m .40107 .37465 L .39919 .37665 L 1 1 0 r
F
.4077 .37777 m .4093 .37554 L .40107 .37465 L F
.35619 .27073 m .35355 .25949 L .35533 .27252 L .92 .17 0 r
F
.35806 .28334 m .35619 .27073 L .35533 .27252 L .817 .137 0 r
F
.58179 .51958 m .56555 .52157 L .565584521 L .34354 .44807 L .316 .449 0 r
F
.33857 .44357 m .33988 .44067 L .32907 .43439 L 1 1 0 r
F
.33857 .44357 m .32907 .43439 L .32764 .4372 L F
.34354 .44807 m .34448 .44521 L .33198 .43851 L F
.34354 .44807 m .33198 .43851 L .33093 .44134 L F
.32587 .43953 m .32764 .4372 L .31884 .43028 L F
.32633 .43988 m .32764 .4372 L .32587 .43953 L F
.32625 .44004 m .31884 .43028 L .31736 .43304 L F
.32764 .4372 m .32907 .43439 L .32036 .42755 L F
.32764 .4372 m .32036 .42755 L .31884 .43028 L F
.33093 .44134 m .33198 .43851 L .32121 .43106 L F
.33093 .44134 m .32121 .43106 L .32007 .43388 L F
.32142 .43529 m .33093 .44134 L .32007 .43388 L F
.32625 .44004 m .32633 .43988 L .32587 .43953 L F
.34265 .45094 m .33368 .4436 L .32992 .44418 L F
.33368 .4436 m .33093 .44134 L .3307 .44198 L F
.33368 .4436 m .33311 .44332 L .33074 .442 L 0 .09 0 r
F
.33311 .44332 m .3263 .44006 L .33071 .44199 L F
.33311 .44332 m .33071 .44199 L .33072 .44199 L F
.33368 .4436 m .3307 .44198 L .32992 .44418 L 1 1 0 r
F
.33368 .4436 m .33074 .442 L .33072 .44199 L 0 .09 0 r
F
.32142 .43529 m .32625 .44004 L .31736 .43304 L 0 .099 0 r
F
.32992 .44142 m .33075 .44186 L .32142 .43529 L 1 1 0 r
F
.3307 .44198 m .32625 .44004 L .32142 .43529 L 0 .099 0 r
F
.3307 .44198 m .33075 .44186 L .32453 .43854 L 1 1 0 r
F
.33075 .44186 m .33093 .44134 L .32142 .43529 L F
.34406 .44782 m .3307 .44198 L .32142 .43529 L 0 .099 0 r
F
.32453 .43854 m .32992 .44142 L .32142 .43529 L 1 1 0 r
F
.3263 .44006 m .32625 .44004 L .32628 .44005 L 0 .09 0 r
F
.32992 .44418 m .3307 .44198 L .32453 .43854 L 1 1 0 r
F
.33988 .44067 m .33055 .4316 L .32907 .43439 L F
.34448 .44521 m .33308 .43569 L .33198 .43851 L F
.32907 .43439 m .33055 .4316 L .32193 .42484 L F
.32907 .43439 m .32193 .42484 L .32036 .42755 L F
.33198 .43851 m .33308 .43569 L .32239 .42826 L F
.33198 .43851 m .32239 .42826 L .32121 .43106 L F
.34122 .4378 m .33206 .42884 L .33055 .4316 L F
.33988 .44067 m .34122 .4378 L .33055 .4316 L F
.33308 .43569 m .33423 .43289 L .32362 .42547 L F
.33308 .43569 m .32362 .42547 L .32239 .42826 L F
.31994 .43424 m .31737 .43305 L .31994 .43424 L 0 .099 0 r
F
.32142 .43529 m .32108 .4351 L .31994 .43424 L F
.32108 .4351 m .31737 .43305 L .31994 .43424 L F
.31993 .43424 m .31736 .43304 L .3189 .43292 L .173 .191 0 r
F
.31993 .43424 m .3189 .43292 L .31902 .43291 L F
.31935 .43339 m .32007 .43388 L .31902 .43291 L 1 1 0 r
F
.31993 .43424 m .32007 .43388 L .31893 .43311 L F
.31736 .43304 m .31884 .43028 L .32025 .43021 L .142 0 0 r
F
.31736 .43304 m .32025 .43021 L .31917 .43259 L F
.34122 .4378 m .3426 .43494 L .33206 .42884 L 1 1 0 r
F
.3426 .43494 m .33361 .42611 L .33206 .42884 L F
.3426 .43494 m .34401 .43211 L .33361 .42611 L F
.34401 .43211 m .33521 .4234 L .33361 .42611 L F
.34401 .43211 m .34546 .4293 L .33521 .4234 L F
.34867 .43388 m .33797 .42456 L .33667 .42732 L F
.34755 .4367 m .34867 .43388 L .33667 .42732 L F
.34755 .4367 m .33667 .42732 L .33543 .43009 L F
.34648 .43953 m .34755 .4367 L .33543 .43009 L F
.34648 .43953 m .33543 .43009 L .33423 .43289 L F
.37435 .44131 m .35104 .4283 L .34983 .43108 L 1 .712 0 r
F
.37435 .44131 m .37534 .43879 L .35104 .4283 L F
.37534 .43879 m .3523 .42553 L .35104 .4283 L 1 .711 0 r
F
.37534 .43879 m .37635 .43628 L .3523 .42553 L F
.37635 .43628 m .3536 .42279 L .3523 .42553 L F
.35104 .4283 m .3523 .42553 L .35463 .42565 L 0 0 0 r
F
.35104 .4283 m .35463 .42565 L .35337 .42807 L F
.34983 .43108 m .35104 .4283 L .35337 .42807 L F
.34983 .43108 m .35337 .42807 L .33797 .42456 L F
.34867 .43388 m .34983 .43108 L .33797 .42456 L 1 1 0 r
F
.33543 .43009 m .33667 .42732 L .34245 .42672 L 0 0 0 r
F
.33543 .43009 m .34245 .42672 L .34121 .42914 L F
.33423 .43289 m .33543 .43009 L .34121 .42914 L F
.33423 .43289 m .34121 .42914 L .32362 .42547 L F
.31917 .43259 m .32025 .43021 L .32028 .43021 L .142 0 0 r
F
.32007 .43388 m .32121 .43106 L .32028 .43021 L 1 1 0 r
F
.32007 .43388 m .32028 .43021 L .32027 .43024 L F
.31917 .43259 m .32028 .43021 L .31917 .43259 L .142 0 0 r
F
.32193 .42484 m .31716 .41499 L .31549 .4176 L 1 1 0 r
F
.32036 .42755 m .32193 .42484 L .31549 .4176 L F
.32036 .42755 m .31549 .4176 L .31386 .42023 L F
.31884 .43028 m .32036 .42755 L .31386 .42023 L F
.33797 .42456 m .35181 .42771 L .34504 .42192 L .156 .168 0 r
F
.35181 .42771 m .35337 .42807 L .34504 .42192 L F
.33993 .41754 m .34504 .42192 L .3387 .41535 L 1 1 0 r
F
.33797 .42456 m .34502 .42193 L .34372 .42431 L .156 .168 0 r
F
.34502 .42193 m .34504 .42192 L .34372 .42431 L F
.33667 .42732 m .33797 .42456 L .34372 .42431 L 0 0 0 r
F
.33667 .42732 m .3437 .42432 L .34245 .42672 L F
.3437 .42432 m .34372 .42431 L .34245 .42672 L F
.34119 .42911 m .34245 .42672 L .33597 .42005 L 1 1 0 r
F
.34121 .42914 m .34245 .42672 L .34119 .42911 L F
.34243 .42669 m .34372 .42431 L .33732 .41769 L F
.34245 .42672 m .34372 .42431 L .34243 .42669 L F
.34372 .42431 m .34504 .42192 L .33993 .41754 L F
.32362 .42547 m .34121 .42914 L .33467 .42243 L .263 .353 0 r
F
.32239 .42826 m .32362 .42547 L .33341 .42483 L .065 0 0 r
F
.32239 .42826 m .33341 .42483 L .33219 .42725 L F
.32121 .43106 m .32239 .42826 L .33219 .42725 L .057 0 0 r
F
.31884 .43028 m .31386 .42023 L .32293 .42523 L 1 1 0 r
F
.32362 .42547 m .33467 .42243 L .33341 .42483 L .263 .353 0 r
F
.32121 .43106 m .33219 .42725 L .32293 .42523 L .057 0 0 r
F
.32121 .43106 m .32293 .42523 L .32028 .43021 L F
.32028 .43021 m .32293 .42523 L .33101 .42968 L 1 1 0 r
F
.31884 .43028 m .32293 .42523 L .32028 .43021 L F
.32028 .43021 m .32293 .42523 L .31236 .42292 L .057 0 0 r
F
.32007 .43388 m .32027 .4302 L .31917 .43259 L 1 1 0 r
F
.31917 .43259 m .32028 .43021 L .33101 .42968 L .142 0 0 r
F
.32027 .43024 m .32028 .43021 L .32027 .4302 L 1 1 0 r
F
.31917 .43259 m .32027 .4302 L .31236 .42292 L F
.31736 .43304 m .31917 .43259 L .31902 .43291 L .142 0 0 r
F
.31902 .43291 m .31236 .42292 L .31118 .42573 L 1 1 0 r
F
.32007 .43388 m .31917 .43259 L .31902 .43291 L F
.31914 .43265 m .31914 .43265 L .31902 .43291 L .142 0 0 r
F
.31917 .43259 m .31917 .43259 L .31914 .43265 L F
.31917 .43259 m .31236 .42292 L .31902 .43291 L 1 1 0 r
F
.31914 .43265 m .33101 .42968 L .31902 .43291 L .142 0 0 r
F
.31917 .43259 m .33101 .42968 L .31914 .43265 L F
.31902 .43291 m .33101 .42968 L .32983 .43211 L F
.31415 .4299 m .31893 .43311 L .31118 .42573 L 1 1 0 r
F
.31893 .43311 m .31935 .43339 L .31897 .43303 L F
.31893 .43311 m .31897 .43303 L .31118 .42573 L F
.3188 .43339 m .31893 .43311 L .31415 .4299 L F
.31993 .43424 m .31893 .43311 L .3188 .43339 L F
.32034 .43415 m .32007 .43388 L .31993 .43424 L F
.32142 .43529 m .31994 .43424 L .31994 .43424 L 0 .099 0 r
F
.32142 .43529 m .32034 .43415 L .31993 .43424 L 1 1 0 r
F
.32142 .43529 m .31994 .43424 L .33528 .44139 L 0 .099 0 r
F
.31737 .43305 m .31737 .43304 L .33528 .44139 L F
.32992 .44418 m .32142 .43529 L .31993 .43424 L 1 1 0 r
F
.31993 .43424 m .31902 .43291 L .32983 .43211 L .173 .191 0 r
F
.31935 .43339 m .31902 .43291 L .31118 .42573 L 1 1 0 r
F
.31737 .43305 m .31736 .43304 L .31737 .43304 L 0 .099 0 r
F
.31899 .4367 m .31993 .43424 L .31415 .4299 L 1 1 0 r
F
.33528 .44139 m .31993 .43424 L .32983 .43211 L .173 .191 0 r
F
.32523 .44097 m .31993 .43424 L .31899 .4367 L 1 1 0 r
F
.32992 .44418 m .31993 .43424 L .32523 .44097 L F
.33046 .43754 m .33528 .44139 L .32869 .43456 L F
.34165 .44648 m .32142 .43529 L .33528 .44139 L 0 .099 0 r
F
.35243 .45258 m .33368 .4436 L .34406 .44782 L 0 .09 0 r
F
.33368 .4436 m .33072 .44199 L .34406 .44782 L F
.3263 .44006 m .32628 .44005 L .34406 .44782 L F
.35487 .45375 m .34316 .44889 L .33368 .4436 L F
.33424 .44389 m .33528 .44139 L .33046 .43754 L 1 1 0 r
F
.34406 .44782 m .34165 .44648 L .33528 .44139 L 0 .099 0 r
F
.33775 .44423 m .34406 .44782 L .33528 .44139 L 1 1 0 r
F
.34265 .45094 m .34326 .44895 L .33696 .44628 L F
.34776 .45085 m .34326 .44895 L .34265 .45094 L F
.34776 .45085 m .34326 .44895 L .34328 .44896 L .98 .632 0 r
F
.34776 .45085 m .34328 .44896 L .35487 .45375 L F
.34309 .45036 m .34406 .44782 L .33775 .44423 L 1 1 0 r
F
.35487 .45375 m .35243 .45258 L .34406 .44782 L 0 .09 0 r
F
.33696 .44628 m .33993 .44709 L .33368 .4436 L 1 1 0 r
F
.34717 .45048 m .35487 .45375 L .34406 .44782 L F
.36511 .45809 m .34776 .45085 L .35487 .45375 L .98 .632 0 r
F
.35626 .45982 m .35697 .45692 L .34265 .45094 L 1 1 0 r
F
.35399 .45632 m .35487 .45375 L .34717 .45048 L F
.36751 .4591 m .36511 .45809 L .35487 .45375 L .98 .632 0 r
F
.35697 .45692 m .35709 .45647 L .35475 .4552 L 1 1 0 r
F
.36751 .4591 m .36832 .4565 L .34796 .44993 L .98 .632 0 r
F
.36832 .4565 m .34848 .44787 L .34796 .44993 L .979 .635 0 r
F
.34796 .44991 m .34448 .44521 L .34796 .44993 L .316 .449 0 r
F
.76236 .49244 m .74762 .50071 L .74743 .5056 L .067 0 0 r
F
.76236 .49244 m .76244 .48752 L .74762 .50071 L F
.67942 .14306 m .67361 .151 L .67911 .15532 L .24 .253 0 r
F
.67942 .14306 m .67372 .13929 L .67361 .151 L F
.57721 .60282 m .55869 .60543 L .55795 .60779 L .449 .033 0 r
F
.57721 .60282 m .57812 .60045 L .55869 .60543 L F
.52962 .88163 m .49832 .88039 L .4977 .8833 L .545 .016 0 r
F
.52962 .88163 m .53091 .87871 L .49832 .88039 L F
.50396 .37717 m .4924 .37704 L .49292 .37959 L .978 .849 0 r
F
.50473 .37979 m .50396 .37717 L .49292 .37959 L .97 .844 0 r
F
.50388 .37743 m .4924 .37704 L .49292 .37959 L .96 .837 0 r
F
.50465 .38003 m .50388 .37743 L .49292 .37959 L .952 .833 0 r
F
.42526 .3629 m .41917 .36278 L .4175 .36484 L 1 1 0 r
F
.42526 .3629 m .42664 .36054 L .41917 .36278 L F
.49503 .81114 m .466 .81653 L .46603 .82023 L .592 .043 0 r
F
.49503 .81114 m .49545 .80746 L .466 .81653 L F
.397 .8825 m .36201 .87664 L .36403 .88 L .817 .051 0 r
F
.39841 .88569 m .397 .8825 L .36403 .88 L .795 .047 0 r
F
.8527 .2977 m .83949 .31172 L .84307 .31788 L .129 .064 0 r
F
.8527 .2977 m .84895 .29166 L .83949 .31172 L F
.53054 .38473 m .51846 .38521 L .51944 .38778 L .818 .697 0 r
F
.53172 .38729 m .53054 .38473 L .51944 .38778 L .814 .693 0 r
F
.54948 .39553 m .53677 .39687 L .53788 .39944 L .746 .618 0 r
F
.55076 .39808 m .54948 .39553 L .53788 .39944 L .743 .612 0 r
F
.40454 .38236 m .39731 .37868 L .39545 .38075 L 1 1 0 r
F
.40454 .38236 m .40611 .38005 L .39731 .37868 L F
.3759 .59931 m .35547 .59145 L .35596 .59432 L 1 .564 0 r
F
.37637 .6021 m .3759 .59931 L .35596 .59432 L 1 .549 0 r
F
.56611 .5478 m .54837 .54892 L .54822 .55141 L .672 .159 0 r
F
.56611 .5478 m .5663 .54529 L .54837 .54892 L F
.54687 .56597 m .52842 .5663 L .52821 .56866 L .739 .173 0 r
F
.54687 .56597 m .54715 .56359 L .52842 .5663 L F
.37878 .39653 m .3713 .39085 L .36937 .39316 L 1 1 0 r
F
.37878 .39653 m .3805 .39406 L .3713 .39085 L F
.08614 .56652 m .06317 .54216 L .06322 .54899 L 1 .756 0 r
F
.0863 .57323 m .08614 .56652 L .06322 .54899 L 1 .735 0 r
F
.87049 .62715 m .84731 .63624 L .84599 .64277 L .1 0 0 r
F
.87049 .62715 m .87192 .62046 L .84731 .63624 L F
.71938 .14597 m .71306 .156 L .71908 .16 L .267 .315 0 r
F
.71938 .14597 m .71323 .14239 L .71306 .156 L F
.58339 .51753 m .56669 .51946 L .56678 .5221 L .61 .185 0 r
F
.58339 .51753 m .5833 .51489 L .56669 .51946 L F
.55002 .39885 m .53741 .40001 L .5385 .40256 L .724 .602 0 r
F
.55128 .40136 m .55002 .39885 L .5385 .40256 L .722 .595 0 r
F
.58159 .51178 m .5653 .51375 L .56541 .51637 L .603 .189 0 r
F
.58159 .51178 m .58146 .50917 L .5653 .51375 L F
.40932 .55428 m .39087 .54858 L .39102 .55102 L 1 .635 0 r
F
.40946 .55669 m .40932 .55428 L .39102 .55102 L 1 .624 0 r
F
.33534 .51782 m .32035 .5077 L .31993 .51083 L 1 .937 0 r
F
.33504 .52098 m .33534 .51782 L .31993 .51083 L 1 .927 0 r
F
.63396 .86487 m .60528 .86594 L .60284 .8695 L .389 0 0 r
F
.63396 .86487 m .63698 .8612 L .60528 .86594 L F
.27823 .84087 m .24301 .82995 L .24625 .83439 L 1 .082 0 r
F
.28104 .84509 m .27823 .84087 L .24625 .83439 L .994 .079 0 r
F
.897 .48478 m .87727 .49714 L .87797 .50404 L .071 .012 0 r
F
.897 .48478 m .89625 .47779 L .87727 .49714 L F
.44868 .58052 m .42877 .57715 L .42893 .57948 L 1 .455 0 r
F
.44876 .58281 m .44868 .58052 L .42893 .57948 L 1 .441 0 r
F
.46856 .58326 m .44868 .58052 L .44876 .58281 L 1 .392 0 r
F
.51574 .37683 m .50396 .37717 L .50473 .37979 L .925 .782 0 r
F
.51673 .37949 m .51574 .37683 L .50473 .37979 L .918 .78 0 r
F
.46856 .5855 m .46856 .58326 L .44876 .58281 L .997 .377 0 r
F
.48825 .58524 m .46856 .58326 L .46856 .5855 L .939 .318 0 r
F
.48825 .58524 m .48835 .58301 L .46856 .58326 L F
.35626 .45982 m .34265 .45094 L .3418 .45381 L 1 1 0 r
F
.35558 .46272 m .35626 .45982 L .3418 .45381 L F
.53269 .62723 m .51232 .62807 L .51189 .63019 L .636 .049 0 r
F
.53269 .62723 m .53335 .62513 L .51232 .62807 L F
.46801 .63728 m .46799 .63515 L .44587 .63502 L .899 .114 0 r
F
.48976 .63631 m .46799 .63515 L .46801 .63728 L .816 .07 0 r
F
.48976 .63631 m .48998 .63423 L .46799 .63515 L F
.59711 .09269 m .59263 .0983 L .59922 .10112 L .379 .541 0 r
F
.59711 .09269 m .59047 .0907 L .59263 .0983 L F
.13829 .66627 m .10787 .64742 L .10962 .65358 L 1 .531 0 r
F
.13999 .67218 m .13829 .66627 L .10962 .65358 L 1 .509 0 r
F
.42912 .56846 m .40997 .56377 L .41018 .56609 L 1 .53 0 r
F
.42928 .57074 m .42912 .56846 L .41018 .56609 L 1 .517 0 r
F
.57725 .76159 m .55386 .76801 L .55282 .77186 L .358 .009 0 r
F
.57725 .76159 m .57869 .75801 L .55386 .76801 L F
.52983 .38136 m .51772 .38212 L .5187 .38473 L .847 .71 0 r
F
.53101 .38397 m .52983 .38136 L .5187 .38473 L .842 .708 0 r
F
.70354 .63881 m .68258 .64345 L .68133 .64759 L .276 .009 0 r
F
.70354 .63881 m .70507 .63466 L .68258 .64345 L F
.71476 .81224 m .68852 .81587 L .68553 .82021 L .267 0 0 r
F
.71476 .81224 m .71819 .80776 L .68852 .81587 L F
.3726 .41452 m .36243 .40688 L .36083 .40946 L 1 1 0 r
F
.3726 .41452 m .37398 .41185 L .36243 .40688 L F
.38185 .42392 m .3726 .41452 L .36083 .40946 L .707 .04 0 r
F
.39519 .42559 m .37398 .41185 L .3726 .41452 L .917 .647 0 r
F
.39418 .42807 m .3726 .41452 L .38185 .42392 L .923 .649 0 r
F
.39418 .42807 m .39519 .42559 L .3726 .41452 L F
.66442 .4631 m .65448 .46799 L .65367 .47171 L 0 0 0 r
F
.66442 .4631 m .66532 .45938 L .65448 .46799 L F
.18169 .7555 m .14945 .73889 L .15218 .74457 L 1 .312 0 r
F
.18423 .76094 m .18169 .7555 L .15218 .74457 L 1 .285 0 r
F
.546 .56234 m .52785 .5628 L .52764 .56512 L .731 .163 0 r
F
.546 .56234 m .54628 .56 L .52785 .5628 L F
.85151 .29827 m .83807 .31237 L .84155 .31855 L .13 .062 0 r
F
.85151 .29827 m .84787 .29219 L .83807 .31237 L F
.47076 .38241 m .46028 .3805 L .45994 .38281 L 1 .996 0 r
F
.47076 .38241 m .47081 .38003 L .46028 .3805 L F
.36179 .86698 m .32694 .85969 L .32945 .86328 L .881 .061 0 r
F
.36374 .87037 m .36179 .86698 L .32945 .86328 L .86 .057 0 r
F
.65604 .15299 m .65605 .15288 L .65771 .15355 L .83 .176 0 r
F
.65771 .15355 m .65733 .15142 L .65935 .15422 L .697 .098 0 r
F
.65771 .15355 m .65515 .14465 L .65733 .15142 L F
.658 .13644 m .65515 .14465 L .65771 .15355 L 0 0 0 r
F
.65605 .15288 m .658 .13644 L .65771 .15355 L .83 .176 0 r
F
.65771 .15355 m .65935 .15422 L .6617 .15746 L .697 .098 0 r
F
.36719 .51893 m .34954 .51119 L .34948 .51395 L 1 .779 0 r
F
.3672 .52164 m .36719 .51893 L .34948 .51395 L 1 .77 0 r
F
.09447 .55807 m .07006 .5344 L .07021 .54109 L 1 .763 0 r
F
.09474 .5646 m .09447 .55807 L .07021 .54109 L 1 .743 0 r
F
.38723 .54631 m .36792 .54018 L .36812 .54277 L 1 .65 0 r
F
.3874 .54884 m .38723 .54631 L .36812 .54277 L 1 .643 0 r
F
.39043 .53107 m .37326 .52435 L .37322 .52691 L 1 .766 0 r
F
.39043 .53362 m .39043 .53107 L .37322 .52691 L 1 .756 0 r
F
.81447 .71323 m .79073 .72021 L .78829 .72589 L .131 0 0 r
F
.81447 .71323 m .81714 .70739 L .79073 .72021 L F
.46861 .57956 m .44895 .57672 L .44904 .57892 L 1 .378 0 r
F
.4686 .58172 m .46861 .57956 L .44904 .57892 L 1 .364 0 r
F
.4881 .58151 m .46861 .57956 L .4686 .58172 L .936 .305 0 r
F
.4881 .58151 m .48821 .57935 L .46861 .57956 L F
.35295 .57078 m .33449 .56152 L .33472 .56457 L 1 .72 0 r
F
.35321 .57378 m .35295 .57078 L .33472 .56457 L 1 .707 0 r
F
.56487 .54432 m .5475 .54555 L .54735 .54801 L .662 .15 0 r
F
.56487 .54432 m .56506 .54185 L .5475 .54555 L F
.5155 .37739 m .50388 .37743 L .50465 .38003 L .902 .77 0 r
F
.51649 .38002 m .5155 .37739 L .50465 .38003 L .895 .768 0 r
F
.38464 .45612 m .37157 .44895 L .37071 .45152 L 1 1 0 r
F
.38464 .45612 m .38538 .45352 L .37157 .44895 L F
.38392 .45872 m .38464 .45612 L .37071 .45152 L F
.38392 .45872 m .37071 .45152 L .36987 .45409 L F
.38323 .46133 m .38392 .45872 L .36987 .45409 L F
.36809 .8262 m .33339 .82411 L .33548 .82792 L .924 .076 0 r
F
.36965 .82993 m .36809 .8262 L .33548 .82792 L .911 .074 0 r
F
.38538 .45352 m .37247 .4464 L .37157 .44895 L 1 1 0 r
F
.38538 .45352 m .38614 .45093 L .37247 .4464 L F
.35558 .46272 m .3418 .45381 L .34099 .45668 L F
.35494 .46561 m .35558 .46272 L .34099 .45668 L 1 .994 0 r
F
.52721 .57791 m .50827 .57747 L .50808 .57974 L .806 .202 0 r
F
.52721 .57791 m .52748 .57563 L .50827 .57747 L F
.72205 .26846 m .73263 .2614 L .73423 .26809 L 1 .595 0 r
F
.72205 .26846 m .72224 .26073 L .73263 .2614 L F
.44895 .57672 m .42944 .573 L .42962 .57523 L 1 .444 0 r
F
.44904 .57892 m .44895 .57672 L .42962 .57523 L 1 .43 0 r
F
.38614 .45093 m .37339 .44385 L .37247 .4464 L 1 1 0 r
F
.38614 .45093 m .38694 .44835 L .37339 .44385 L F
.54818 .39298 m .53564 .3943 L .53677 .39687 L .75 .623 0 r
F
.54948 .39553 m .54818 .39298 L .53677 .39687 L .746 .618 0 r
F
.40814 .56358 m .38824 .55881 L .3885 .56127 L 1 .578 0 r
F
.40831 .56602 m .40814 .56358 L .3885 .56127 L 1 .569 0 r
F
.4087 .36941 m .40282 .36736 L .40086 .36936 L 1 1 0 r
F
.4087 .36941 m .41041 .3672 L .40282 .36736 L F
.37398 .41185 m .36407 .40435 L .36243 .40688 L F
.37398 .41185 m .3754 .40921 L .36407 .40435 L F
.39623 .42313 m .3754 .40921 L .37398 .41185 L .912 .646 0 r
F
.39519 .42559 m .39623 .42313 L .37398 .41185 L .917 .647 0 r
F
.38694 .44835 m .37435 .44131 L .37339 .44385 L 1 1 0 r
F
.38694 .44835 m .38775 .44578 L .37435 .44131 L F
.72721 .14737 m .72013 .15864 L .72609 .16277 L .284 .319 0 r
F
.72721 .14737 m .72118 .14355 L .72013 .15864 L F
.54874 .39634 m .5363 .39747 L .53741 .40001 L .727 .608 0 r
F
.55002 .39885 m .54874 .39634 L .53741 .40001 L .724 .602 0 r
F
.42863 .57479 m .40871 .57083 L .40893 .57321 L 1 .516 0 r
F
.42877 .57715 m .42863 .57479 L .40893 .57321 L 1 .503 0 r
F
.4596 .38514 m .44946 .38256 L .44883 .38481 L 1 1 0 r
F
.4596 .38514 m .45994 .38281 L .44946 .38256 L F
.52663 .57419 m .50793 .57387 L .50774 .57609 L .798 .192 0 r
F
.52663 .57419 m .52691 .57196 L .50793 .57387 L F
.50769 .58422 m .48835 .58301 L .48825 .58524 L .872 .25 0 r
F
.50769 .58422 m .50789 .58199 L .48835 .58301 L F
.28907 .8034 m .25371 .79625 L .25651 .80062 L 1 .172 0 r
F
.29142 .80761 m .28907 .8034 L .25651 .80062 L 1 .15 0 r
F
.73748 .58082 m .71806 .58706 L .71715 .59152 L .208 .007 0 r
F
.73748 .58082 m .73852 .57629 L .71806 .58706 L F
.58169 .51439 m .56541 .51637 L .5655 .51897 L .599 .177 0 r
F
.58169 .51439 m .58159 .51178 L .56541 .51637 L F
.3805 .39406 m .37326 .38857 L .3713 .39085 L 1 1 0 r
F
.3805 .39406 m .38224 .39162 L .37326 .38857 L F
.37767 .48232 m .3633 .47482 L .36271 .47746 L 1 .961 0 r
F
.37719 .48497 m .37767 .48232 L .36271 .47746 L 1 .953 0 r
F
.38775 .44578 m .37534 .43879 L .37435 .44131 L 1 1 0 r
F
.38775 .44578 m .3886 .44321 L .37534 .43879 L F
.52936 .38216 m .51748 .38262 L .51846 .38521 L .823 .7 0 r
F
.53054 .38473 m .52936 .38216 L .51846 .38521 L .818 .697 0 r
F
.58345 .52017 m .56678 .5221 L .56683 .52472 L .606 .173 0 r
F
.58345 .52017 m .58339 .51753 L .56678 .5221 L F
.69725 .25293 m .70257 .24748 L .70415 .25435 L 1 .17 0 r
F
.69725 .25293 m .6954 .24674 L .70257 .24748 L F
.33504 .52098 m .31993 .51083 L .31956 .51397 L 1 .927 0 r
F
.33476 .52414 m .33504 .52098 L .31956 .51397 L 1 .916 0 r
F
.48156 .37888 m .47086 .37765 L .47081 .38003 L 1 .962 0 r
F
.48156 .37888 m .48132 .37641 L .47086 .37765 L F
.67337 .84765 m .64568 .84965 L .64284 .85359 L .34 0 0 r
F
.67337 .84765 m .67673 .84359 L .64568 .84965 L F
.23084 .81134 m .19633 .79798 L .19959 .80299 L 1 .15 0 r
F
.23377 .81611 m .23084 .81134 L .19959 .80299 L 1 .123 0 r
F
.35494 .46561 m .34099 .45668 L .34023 .45956 L 1 .994 0 r
F
.35433 .46851 m .35494 .46561 L .34023 .45956 L 1 .985 0 r
F
.68494 .14707 m .67911 .15532 L .68445 .15983 L .222 .21 0 r
F
.68494 .14707 m .67942 .14306 L .67911 .15532 L F
.64432 .51551 m .6313 .52043 L .63065 .52357 L .169 0 0 r
F
.64432 .51551 m .64504 .51237 L .6313 .52043 L F
.50734 .58046 m .48821 .57935 L .4881 .58151 L .867 .239 0 r
F
.50734 .58046 m .50755 .57829 L .48821 .57935 L F
.3886 .44321 m .37635 .43628 L .37534 .43879 L 1 1 0 r
F
.3886 .44321 m .38946 .44066 L .37635 .43628 L F
.58451 .13158 m .59181 .10089 L .59805 .1046 L 1 .453 0 r
F
.58451 .13158 m .58945 .09403 L .59181 .10089 L F
.5659 .55029 m .54822 .55141 L .54805 .55388 L .667 .146 0 r
F
.5659 .55029 m .56611 .5478 L .54822 .55141 L F
.59553 .86916 m .56642 .86977 L .56453 .87294 L .42 0 0 r
F
.59553 .86916 m .59805 .86594 L .56642 .86977 L F
.42318 .62916 m .40105 .62432 L .40159 .6268 L 1 .31 0 r
F
.42358 .63152 m .42318 .62916 L .40159 .6268 L 1 .291 0 r
F
.50319 .37453 m .49188 .37447 L .4924 .37704 L .987 .852 0 r
F
.50396 .37717 m .50319 .37453 L .4924 .37704 L .978 .849 0 r
F
.50311 .3748 m .49188 .37447 L .4924 .37704 L .969 .84 0 r
F
.50388 .37743 m .50311 .3748 L .4924 .37704 L .96 .837 0 r
F
.40611 .38005 m .39919 .37665 L .39731 .37868 L 1 1 0 r
F
.40611 .38005 m .4077 .37777 L .39919 .37665 L F
.3754 .40921 m .36576 .40186 L .36407 .40435 L F
.3754 .40921 m .37686 .4066 L .36576 .40186 L F
.39729 .42068 m .37686 .4066 L .3754 .40921 L .907 .645 0 r
F
.39623 .42313 m .39729 .42068 L .3754 .40921 L .912 .646 0 r
F
.37719 .48497 m .36271 .47746 L .36215 .4801 L 1 .953 0 r
F
.37673 .48762 m .37719 .48497 L .36215 .4801 L 1 .946 0 r
F
.75799 .38373 m .75501 .38979 L .75575 .39521 L 0 0 0 r
F
.75799 .38373 m .75688 .37858 L .75501 .38979 L F
.52864 .37872 m .51673 .37949 L .51772 .38212 L .853 .712 0 r
F
.52983 .38136 m .52864 .37872 L .51772 .38212 L .847 .71 0 r
F
.42913 .34824 m .4246 .35113 L .42278 .35297 L .766 .319 0 r
F
.42913 .34824 m .43065 .34599 L .4246 .35113 L F
.38946 .44066 m .37739 .43378 L .37635 .43628 L 1 1 0 r
F
.38946 .44066 m .39036 .43812 L .37739 .43378 L F
.76211 .77419 m .73706 .77924 L .73412 .78419 L .201 0 0 r
F
.76211 .77419 m .76539 .76909 L .73706 .77924 L F
.72548 .14962 m .71908 .16 L .72504 .16407 L .263 .304 0 r
F
.72548 .14962 m .71938 .14597 L .71908 .16 L F
.39043 .53362 m .37322 .52691 L .37321 .52947 L 1 .756 0 r
F
.39044 .53615 m .39043 .53362 L .37321 .52947 L 1 .745 0 r
F
.40946 .55669 m .39102 .55102 L .3912 .55344 L 1 .624 0 r
F
.40961 .55907 m .40946 .55669 L .3912 .55344 L 1 .611 0 r
F
.59944 .58457 m .58235 .58808 L .58155 .59062 L .363 .023 0 r
F
.59944 .58457 m .60038 .58201 L .58235 .58808 L F
.54657 .56833 m .52821 .56866 L .52798 .57101 L .735 .159 0 r
F
.54657 .56833 m .54687 .56597 L .52821 .56866 L F
.51475 .37413 m .50319 .37453 L .50396 .37717 L .934 .783 0 r
F
.51574 .37683 m .51475 .37413 L .50396 .37717 L .925 .782 0 r
F
.54687 .39043 m .5345 .39173 L .53564 .3943 L .753 .628 0 r
F
.54818 .39298 m .54687 .39043 L .53564 .3943 L .75 .623 0 r
F
.3672 .52164 m .34948 .51395 L .34946 .51671 L 1 .77 0 r
F
.36724 .52433 m .3672 .52164 L .34946 .51671 L 1 .76 0 r
F
.42664 .36054 m .42085 .36076 L .41917 .36278 L 1 1 0 r
F
.42664 .36054 m .42803 .35822 L .42085 .36076 L F
.62242 .55611 m .60704 .56044 L .60628 .56324 L .283 .014 0 r
F
.62242 .55611 m .62327 .55329 L .60704 .56044 L F
.35433 .46851 m .34023 .45956 L .3395 .46244 L 1 .985 0 r
F
.35377 .4714 m .35433 .46851 L .3395 .46244 L 1 .976 0 r
F
.24322 .7781 m .20835 .76779 L .21121 .77263 L 1 .247 0 r
F
.24574 .78273 m .24322 .7781 L .21121 .77263 L 1 .224 0 r
F
.85635 .3038 m .84307 .31788 L .84655 .3241 L .12 .061 0 r
F
.85635 .3038 m .8527 .2977 L .84307 .31788 L F
.51099 .63431 m .48998 .63423 L .48976 .63631 L .721 .058 0 r
F
.51099 .63431 m .51145 .63227 L .48998 .63423 L F
.76223 .49735 m .74743 .5056 L .74719 .51046 L .066 0 0 r
F
.76223 .49735 m .76236 .49244 L .74743 .5056 L F
.68466 .40801 m .67812 .41228 L .67668 .41717 L 0 0 0 r
F
.68466 .40801 m .68616 .40309 L .67812 .41228 L F
.63525 .71418 m .6138 .71885 L .61242 .7227 L .316 .003 0 r
F
.63525 .71418 m .63703 .71054 L .6138 .71885 L F
.43221 .88067 m .39818 .87616 L .39956 .87928 L .753 .043 0 r
F
.43295 .88363 m .43221 .88067 L .39956 .87928 L .731 .038 0 r
F
.46534 .88397 m .43221 .88067 L .43295 .88363 L .681 .033 0 r
F
.54744 .39383 m .53517 .39493 L .5363 .39747 L .729 .613 0 r
F
.54874 .39634 m .54744 .39383 L .5363 .39747 L .727 .608 0 r
F
.39036 .43812 m .37846 .43129 L .37739 .43378 L 1 1 0 r
F
.39036 .43812 m .39128 .43559 L .37846 .43129 L F
.37673 .48762 m .36215 .4801 L .36161 .48274 L 1 .946 0 r
F
.37631 .49028 m .37673 .48762 L .36161 .48274 L 1 .938 0 r
F
.40002 .61926 m .37849 .613 L .37908 .61565 L 1 .419 0 r
F
.40052 .62181 m .40002 .61926 L .37908 .61565 L 1 .402 0 r
F
.3874 .54884 m .36812 .54277 L .36833 .54535 L 1 .643 0 r
F
.38759 .55135 m .3874 .54884 L .36833 .54535 L 1 .636 0 r
F
.56466 .54677 m .54735 .54801 L .54718 .55045 L .657 .138 0 r
F
.56466 .54677 m .56487 .54432 L .54735 .54801 L F
.58175 .51699 m .5655 .51897 L .56555 .52157 L .595 .165 0 r
F
.58175 .51699 m .58169 .51439 L .5655 .51897 L F
.51451 .37473 m .50311 .3748 L .50388 .37743 L .91 .771 0 r
F
.5155 .37739 m .51451 .37473 L .50388 .37743 L .902 .77 0 r
F
.42928 .57074 m .41018 .56609 L .4104 .56839 L 1 .517 0 r
F
.42944 .573 m .42928 .57074 L .4104 .56839 L 1 .504 0 r
F
.5457 .56465 m .52764 .56512 L .52741 .56742 L .726 .15 0 r
F
.5457 .56465 m .546 .56234 L .52764 .56512 L F
.44876 .58281 m .42893 .57948 L .4291 .58179 L 1 .441 0 r
F
.44885 .58508 m .44876 .58281 L .4291 .58179 L 1 .426 0 r
F
.46856 .5855 m .44876 .58281 L .44885 .58508 L .997 .377 0 r
F
.58348 .5228 m .56683 .52472 L .56686 .52734 L .602 .161 0 r
F
.58348 .5228 m .58345 .52017 L .56683 .52472 L F
.37686 .4066 m .36751 .39942 L .36576 .40186 L 1 1 0 r
F
.37686 .4066 m .37837 .40403 L .36751 .39942 L F
.39837 .41826 m .37837 .40403 L .37686 .4066 L .901 .643 0 r
F
.39729 .42068 m .39837 .41826 L .37686 .4066 L .907 .645 0 r
F
.38224 .39162 m .37525 .38633 L .37326 .38857 L 1 1 0 r
F
.38224 .39162 m .38401 .38921 L .37525 .38633 L F
.44587 .63502 m .42358 .63152 L .42399 .63385 L .983 .206 0 r
F
.4461 .63722 m .44587 .63502 L .42399 .63385 L .973 .187 0 r
F
.46801 .63728 m .44587 .63502 L .4461 .63722 L .899 .114 0 r
F
.89039 .48471 m .87217 .49693 L .87268 .50373 L .025 0 0 r
F
.89039 .48471 m .88992 .47784 L .87217 .49693 L F
.58439 .44247 m .5703 .44492 L .57116 .44759 L .598 .381 0 r
F
.58533 .44512 m .57116 .44759 L .57199 .45027 L .595 .371 0 r
F
.58533 .44512 m .58439 .44247 L .57116 .44759 L F
.46856 .58772 m .46856 .5855 L .44885 .58508 L .993 .363 0 r
F
.48814 .58745 m .46856 .5855 L .46856 .58772 L .934 .304 0 r
F
.48814 .58745 m .48825 .58524 L .46856 .5855 L F
.58625 .44778 m .57199 .45027 L .57279 .45295 L .592 .361 0 r
F
.58625 .44778 m .58533 .44512 L .57199 .45027 L F
.58342 .43983 m .56942 .44226 L .5703 .44492 L .602 .391 0 r
F
.58439 .44247 m .58342 .43983 L .5703 .44492 L .598 .381 0 r
F
.37637 .6021 m .35596 .59432 L .35648 .59718 L 1 .549 0 r
F
.37686 .60486 m .37637 .6021 L .35648 .59718 L 1 .533 0 r
F
.39818 .87616 m .36374 .87037 L .36574 .87367 L .813 .051 0 r
F
.39956 .87928 m .39818 .87616 L .36574 .87367 L .791 .047 0 r
F
.39128 .43559 m .37957 .42882 L .37846 .43129 L 1 1 0 r
F
.39128 .43559 m .39222 .43307 L .37957 .42882 L F
.58713 .45044 m .57279 .45295 L .57357 .45564 L .588 .35 0 r
F
.58713 .45044 m .58625 .44778 L .57279 .45295 L F
.58241 .43719 m .56851 .4396 L .56942 .44226 L .605 .401 0 r
F
.58342 .43983 m .58241 .43719 L .56942 .44226 L .602 .391 0 r
F
.33476 .52414 m .31956 .51397 L .31923 .51711 L 1 .916 0 r
F
.33453 .52729 m .33476 .52414 L .31923 .51711 L 1 .904 0 r
F
.8188 .72399 m .79405 .73035 L .79155 .73613 L .158 0 0 r
F
.8188 .72399 m .82155 .71803 L .79405 .73035 L F
.47081 .38003 m .46063 .37821 L .46028 .3805 L 1 1 0 r
F
.47081 .38003 m .47086 .37765 L .46063 .37821 L F
.52817 .37957 m .51649 .38002 L .51748 .38262 L .828 .702 0 r
F
.52936 .38216 m .52817 .37957 L .51748 .38262 L .823 .7 0 r
F
.55396 .61905 m .53462 .62082 L .53399 .62299 L .535 .038 0 r
F
.55396 .61905 m .5548 .61687 L .53462 .62082 L F
.35321 .57378 m .33472 .56457 L .33498 .56761 L 1 .707 0 r
F
.3535 .57677 m .35321 .57378 L .33498 .56761 L 1 .693 0 r
F
.07634 .58258 m .05164 .55799 L .05205 .56499 L 1 .71 0 r
F
.07683 .58942 m .07634 .58258 L .05205 .56499 L 1 .688 0 r
F
.58798 .45311 m .57357 .45564 L .57432 .45833 L .585 .339 0 r
F
.58798 .45311 m .58713 .45044 L .57357 .45564 L F
.35377 .4714 m .3395 .46244 L .33882 .46532 L 1 .976 0 r
F
.35324 .47429 m .35377 .4714 L .33882 .46532 L 1 .967 0 r
F
.58138 .43457 m .56758 .43695 L .56851 .4396 L .608 .411 0 r
F
.58241 .43719 m .58138 .43457 L .56851 .4396 L .605 .401 0 r
F
.57627 .60515 m .55795 .60779 L .55719 .61012 L .438 .03 0 r
F
.57627 .60515 m .57721 .60282 L .55795 .60779 L F
.17866 .76637 m .14564 .74998 L .14858 .75566 L 1 .279 0 r
F
.18138 .77181 m .17866 .76637 L .14858 .75566 L 1 .252 0 r
F
.32209 .86213 m .28685 .85327 L .28985 .85722 L .935 .069 0 r
F
.32459 .86587 m .32209 .86213 L .28985 .85722 L .915 .065 0 r
F
.60326 .09605 m .59711 .09269 L .59922 .10112 L .25 .285 0 r
F
.85504 .3044 m .84155 .31855 L .84492 .32478 L .12 .059 0 r
F
.85504 .3044 m .85151 .29827 L .84155 .31855 L F
.37631 .49028 m .36161 .48274 L .36111 .48538 L 1 .938 0 r
F
.37591 .49293 m .37631 .49028 L .36111 .48538 L 1 .93 0 r
F
.5888 .45578 m .57432 .45833 L .57504 .46102 L .581 .329 0 r
F
.5888 .45578 m .58798 .45311 L .57432 .45833 L F
.58032 .43195 m .56662 .43431 L .56758 .43695 L .611 .421 0 r
F
.58138 .43457 m .58032 .43195 L .56758 .43695 L .608 .411 0 r
F
.40831 .56602 m .3885 .56127 L .38877 .56371 L 1 .569 0 r
F
.4085 .56843 m .40831 .56602 L .38877 .56371 L 1 .559 0 r
F
.73315 .15132 m .72609 .16277 L .73197 .16699 L .27 .29 0 r
F
.73315 .15132 m .72721 .14737 L .72609 .16277 L F
.4686 .58172 m .44904 .57892 L .44914 .58109 L 1 .364 0 r
F
.4686 .58386 m .4686 .58172 L .44914 .58109 L .996 .35 0 r
F
.48799 .58365 m .4686 .58172 L .4686 .58386 L .932 .291 0 r
F
.48799 .58365 m .4881 .58151 L .4686 .58172 L F
.12948 .68542 m .10045 .66518 L .10231 .67152 L 1 .49 0 r
F
.13129 .69155 m .12948 .68542 L .10231 .67152 L 1 .465 0 r
F
.52692 .58016 m .50808 .57974 L .50789 .58199 L .801 .188 0 r
F
.52692 .58016 m .52721 .57791 L .50808 .57974 L F
.54554 .38788 m .53334 .38915 L .5345 .39173 L .757 .632 0 r
F
.54687 .39043 m .54554 .38788 L .5345 .39173 L .753 .628 0 r
F
.66356 .46675 m .65367 .47171 L .65289 .47536 L 0 0 0 r
F
.66356 .46675 m .66442 .4631 L .65367 .47171 L F
.39222 .43307 m .38069 .42636 L .37957 .42882 L 1 1 0 r
F
.39222 .43307 m .39318 .43056 L .38069 .42636 L F
.86241 .62419 m .84101 .63363 L .8396 .64 L .054 0 0 r
F
.86241 .62419 m .86394 .61768 L .84101 .63363 L F
.58959 .45846 m .57504 .46102 L .57573 .46372 L .578 .318 0 r
F
.58959 .45846 m .5888 .45578 L .57504 .46102 L F
.57923 .42934 m .56563 .43167 L .56662 .43431 L .614 .43 0 r
F
.58032 .43195 m .57923 .42934 L .56662 .43431 L .611 .421 0 r
F
.41041 .3672 m .40479 .36541 L .40282 .36736 L 1 1 0 r
F
.41041 .3672 m .41213 .36503 L .40479 .36541 L F
.44904 .57892 m .42962 .57523 L .4298 .57744 L 1 .43 0 r
F
.44914 .58109 m .44904 .57892 L .4298 .57744 L 1 .417 0 r
F
.66748 .6834 m .64641 .68763 L .64499 .69156 L .299 .004 0 r
F
.66748 .6834 m .66926 .67957 L .64641 .68763 L F
.5494 .78289 m .52455 .78982 L .52376 .7936 L .392 .016 0 r
F
.5494 .78289 m .55059 .7793 L .52455 .78982 L F
.70441 .34216 m .70198 .34481 L .70058 .35138 L 0 0 0 r
F
.70441 .34216 m .70551 .3358 L .70198 .34481 L F
.42877 .57715 m .40893 .57321 L .40917 .57557 L 1 .503 0 r
F
.42893 .57948 m .42877 .57715 L .40917 .57557 L 1 .49 0 r
F
.52746 .37604 m .51574 .37683 L .51673 .37949 L .86 .712 0 r
F
.52864 .37872 m .52746 .37604 L .51673 .37949 L .853 .712 0 r
F
.28143 .8349 m .24693 .82395 L .25009 .82835 L 1 .083 0 r
F
.28418 .83907 m .28143 .8349 L .25009 .82835 L .997 .079 0 r
F
.54613 .39132 m .53403 .39238 L .53517 .39493 L .732 .619 0 r
F
.54744 .39383 m .54613 .39132 L .53517 .39493 L .729 .613 0 r
F
.39044 .53615 m .37321 .52947 L .37323 .53201 L 1 .745 0 r
F
.39048 .53867 m .39044 .53615 L .37323 .53201 L 1 .735 0 r
F
.56566 .55276 m .54805 .55388 L .54786 .55634 L .662 .134 0 r
F
.56566 .55276 m .5659 .55029 L .54805 .55388 L F
.37837 .40403 m .3693 .39703 L .36751 .39942 L 1 1 0 r
F
.37837 .40403 m .37991 .40149 L .3693 .39703 L F
.39948 .41585 m .37991 .40149 L .37837 .40403 L .928 .07 0 r
F
.39837 .41826 m .39948 .41585 L .37837 .40403 L .901 .643 0 r
F
.63092 .85768 m .60294 .8592 L .60052 .86262 L .371 0 0 r
F
.63092 .85768 m .63393 .85418 L .60294 .8592 L F
.59034 .46115 m .57573 .46372 L .57639 .46642 L .574 .307 0 r
F
.59034 .46115 m .58959 .45846 L .57573 .46372 L F
.57811 .42673 m .56462 .42904 L .56563 .43167 L .617 .44 0 r
F
.57923 .42934 m .57811 .42673 L .56563 .43167 L .614 .43 0 r
F
.52634 .57639 m .50774 .57609 L .50755 .57829 L .794 .178 0 r
F
.52634 .57639 m .52663 .57419 L .50774 .57609 L F
.6584 .16514 m .6617 .15746 L .66565 .16397 L .94 .168 0 r
F
.6584 .16514 m .65771 .15355 L .6617 .15746 L F
.19281 .73748 m .15939 .72338 L .16201 .72882 L 1 .353 0 r
F
.1952 .74268 m .19281 .73748 L .16201 .72882 L 1 .33 0 r
F
.36724 .52433 m .34946 .51671 L .34947 .51945 L 1 .76 0 r
F
.3673 .52701 m .36724 .52433 L .34947 .51945 L 1 .751 0 r
F
.37591 .49293 m .36111 .48538 L .36065 .48801 L 1 .93 0 r
F
.37553 .49557 m .37591 .49293 L .36065 .48801 L 1 .922 0 r
F
.50748 .58641 m .48825 .58524 L .48814 .58745 L .867 .236 0 r
F
.50748 .58641 m .50769 .58422 L .48825 .58524 L F
.89763 .49177 m .87797 .50404 L .87856 .51094 L .062 .009 0 r
F
.89763 .49177 m .897 .48478 L .87797 .50404 L F
.35324 .47429 m .33882 .46532 L .33818 .46821 L 1 .967 0 r
F
.35275 .47718 m .35324 .47429 L .33818 .46821 L 1 .957 0 r
F
.69025 .15133 m .68445 .15983 L .68959 .16454 L .198 .157 0 r
F
.69025 .15133 m .68494 .14707 L .68445 .15983 L F
.60464 .74108 m .58267 .74678 L .5814 .7506 L .321 .001 0 r
F
.60464 .74108 m .60631 .73753 L .58267 .74678 L F
.48132 .37641 m .47091 .37527 L .47086 .37765 L 1 .97 0 r
F
.48132 .37641 m .48107 .37393 L .47091 .37527 L F
.4077 .37777 m .40107 .37465 L .39919 .37665 L 1 1 0 r
F
.4077 .37777 m .4093 .37554 L .40107 .37465 L F
.35619 .27073 m .35355 .25949 L .35533 .27252 L .92 .17 0 r
F
.35806 .28334 m .35619 .27073 L .35533 .27252 L .817 .137 0 r
F
.58179 .51958 m .56555 .52157 L .56558 .52415 L .59 .153 0 r
F
.58179 .51958 m .58175 .51699 L .56555 .52157 L F
.39318 .43056 m .38185 .42392 L .38069 .42636 L 1 1 0 r
F
.39318 .43056 m .39418 .42807 L .38185 .42392 L F
.50242 .37184 m .49136 .37188 L .49188 .37447 L .998 .854 0 r
F
.50319 .37453 m .50242 .37184 L .49188 .37447 L .987 .852 0 r
F
.50234 .37213 m .49136 .37188 L .49188 .37447 L .979 .843 0 r
F
.50311 .3748 m .50234 .37213 L .49188 .37447 L .969 .84 0 r
F
.57697 .42414 m .56359 .42642 L .56462 .42904 L .621 .449 0 r
F
.57811 .42673 m .57697 .42414 L .56462 .42904 L .617 .44 0 r
F
.59107 .46383 m .57639 .46642 L .57703 .46913 L .57 .296 0 r
F
.59107 .46383 m .59034 .46115 L .57639 .46642 L F
.51376 .37138 m .50242 .37184 L .50319 .37453 L .944 .782 0 r
F
.51475 .37413 m .51376 .37138 L .50319 .37453 L .934 .783 0 r
F
.73152 .15337 m .72504 .16407 L .73095 .16823 L .258 .29 0 r
F
.73152 .15337 m .72548 .14962 L .72504 .16407 L F
.0863 .57323 m .06322 .54899 L .06338 .55583 L 1 .735 0 r
F
.08658 .57994 m .0863 .57323 L .06338 .55583 L 1 .714 0 r
F
.58348 .52541 m .56686 .52734 L .56686 .52994 L .597 .148 0 r
F
.58348 .52541 m .58348 .5228 L .56686 .52734 L F
.40961 .55907 m .3912 .55344 L .3914 .55584 L 1 .611 0 r
F
.40978 .56143 m .40961 .55907 L .3914 .55584 L 1 .599 0 r
F
.50712 .5826 m .4881 .58151 L .48799 .58365 L .862 .225 0 r
F
.50712 .5826 m .50734 .58046 L .4881 .58151 L F
.38401 .38921 m .37726 .38414 L .37525 .38633 L 1 1 0 r
F
.38401 .38921 m .38581 .38685 L .37726 .38414 L F
.64359 .51861 m .63065 .52357 L .62998 .52667 L .166 0 0 r
F
.64359 .51861 m .64432 .51551 L .63065 .52357 L F
.72201 .27582 m .73423 .26809 L .73568 .27473 L 1 .662 0 r
F
.72201 .27582 m .72205 .26846 L .73423 .26809 L F
.1238 .6962 m .09364 .67601 L .09573 .68242 L 1 .458 0 r
F
.12581 .70238 m .1238 .6962 L .09573 .68242 L 1 .433 0 r
F
.56226 .88615 m .53193 .88554 L .53063 .88859 L .483 .008 0 r
F
.56226 .88615 m .56423 .88305 L .53193 .88554 L F
.33453 .52729 m .31923 .51711 L .31894 .52025 L 1 .904 0 r
F
.33434 .53043 m .33453 .52729 L .31894 .52025 L 1 .893 0 r
F
.53202 .62929 m .51189 .63019 L .51145 .63227 L .624 .046 0 r
F
.53202 .62929 m .53269 .62723 L .51189 .63019 L F
.57579 .42156 m .56253 .42381 L .56359 .42642 L .624 .458 0 r
F
.57697 .42414 m .57579 .42156 L .56359 .42642 L .621 .449 0 r
F
.54624 .57066 m .52798 .57101 L .52774 .57333 L .729 .146 0 r
F
.54624 .57066 m .54657 .56833 L .52798 .57101 L F
.59176 .46652 m .57703 .46913 L .57764 .47183 L .566 .285 0 r
F
.59176 .46652 m .59107 .46383 L .57703 .46913 L F
.33134 .82023 m .29633 .81582 L .29887 .81982 L .985 .106 0 r
F
.33339 .82411 m .33134 .82023 L .29887 .81982 L .972 .084 0 r
F
.56443 .5492 m .54718 .55045 L .54698 .55286 L .652 .125 0 r
F
.56443 .5492 m .56466 .54677 L .54718 .55045 L F
.70195 .64293 m .68133 .64759 L .68002 .65171 L .266 .005 0 r
F
.70195 .64293 m .70354 .63881 L .68133 .64759 L F
.46802 .63937 m .46801 .63728 L .4461 .63722 L .889 .095 0 r
F
.48954 .63834 m .46801 .63728 L .46802 .63937 L .804 .067 0 r
F
.48954 .63834 m .48976 .63631 L .46801 .63728 L F
.09474 .5646 m .07021 .54109 L .07047 .54778 L 1 .743 0 r
F
.09511 .57111 m .09474 .5646 L .07047 .54778 L 1 .723 0 r
F
.51351 .37203 m .50234 .37213 L .50311 .3748 L .919 .771 0 r
F
.51451 .37473 m .51351 .37203 L .50311 .3748 L .91 .771 0 r
F
.38759 .55135 m .36833 .54535 L .36857 .54791 L 1 .636 0 r
F
.38779 .55385 m .38759 .55135 L .36857 .54791 L 1 .628 0 r
F
.52697 .37695 m .5155 .37739 L .51649 .38002 L .833 .702 0 r
F
.52817 .37957 m .52697 .37695 L .51649 .38002 L .828 .702 0 r
F
.37553 .49557 m .36065 .48801 L .36021 .49065 L 1 .922 0 r
F
.37519 .49822 m .37553 .49557 L .36021 .49065 L 1 .913 0 r
F
.5442 .38531 m .53218 .38657 L .53334 .38915 L .761 .636 0 r
F
.54554 .38788 m .5442 .38531 L .53334 .38915 L .757 .632 0 r
F
.75907 .38884 m .75575 .39521 L .75646 .40059 L 0 0 0 r
F
.75907 .38884 m .75799 .38373 L .75575 .39521 L F
.71607 .82338 m .68945 .82644 L .68638 .83086 L .282 0 0 r
F
.71607 .82338 m .71959 .81882 L .68945 .82644 L F
.37991 .40149 m .37114 .39468 L .3693 .39703 L 1 1 0 r
F
.37991 .40149 m .3815 .399 L .37114 .39468 L F
.35275 .47718 m .33818 .46821 L .33759 .47109 L 1 .957 0 r
F
.35229 .48006 m .35275 .47718 L .33759 .47109 L 1 .948 0 r
F
.5831 .44291 m .56933 .44527 L .57017 .44792 L .585 .367 0 r
F
.58401 .44553 m .57017 .44792 L .57098 .45058 L .582 .356 0 r
F
.58401 .44553 m .5831 .44291 L .57017 .44792 L F
.58215 .44029 m .56847 .44263 L .56933 .44527 L .589 .378 0 r
F
.5831 .44291 m .58215 .44029 L .56933 .44527 L .585 .367 0 r
F
.42803 .35822 m .42255 .35877 L .42085 .36076 L 1 .99 0 r
F
.42803 .35822 m .42944 .35591 L .42255 .35877 L F
.5849 .44816 m .57098 .45058 L .57176 .45323 L .578 .346 0 r
F
.5849 .44816 m .58401 .44553 L .57098 .45058 L F
.86894 .63381 m .84599 .64277 L .84456 .64926 L .092 0 0 r
F
.86894 .63381 m .87049 .62715 L .84599 .64277 L F
.58117 .43768 m .56758 .44 L .56847 .44263 L .592 .388 0 r
F
.58215 .44029 m .58117 .43768 L .56847 .44263 L .589 .378 0 r
F
.73639 .58533 m .71715 .59152 L .71619 .59595 L .202 .004 0 r
F
.73639 .58533 m .73748 .58082 L .71715 .59152 L F
.5448 .38881 m .53288 .38984 L .53403 .39238 L .735 .623 0 r
F
.54613 .39132 m .5448 .38881 L .53403 .39238 L .732 .619 0 r
F
.57459 .41898 m .56145 .4212 L .56253 .42381 L .627 .467 0 r
F
.57579 .42156 m .57459 .41898 L .56253 .42381 L .624 .458 0 r
F
.8599 .30996 m .84655 .3241 L .84993 .33036 L .111 .058 0 r
F
.8599 .30996 m .85635 .3038 L .84655 .3241 L F
.59242 .46922 m .57764 .47183 L .57822 .47454 L .563 .273 0 r
F
.59242 .46922 m .59176 .46652 L .57764 .47183 L F
.59798 .11146 m .58451 .13158 L .59805 .1046 L 0 0 0 r
F
.58575 .4508 m .57176 .45323 L .57251 .4559 L .575 .335 0 r
F
.58575 .4508 m .5849 .44816 L .57176 .45323 L F
.69896 .25909 m .70415 .25435 L .7055 .26124 L 1 .152 0 r
F
.69896 .25909 m .69725 .25293 L .70415 .25435 L F
.58016 .43508 m .56666 .43737 L .56758 .44 L .595 .398 0 r
F
.58117 .43768 m .58016 .43508 L .56758 .44 L .592 .388 0 r
F
.54538 .56694 m .52741 .56742 L .52717 .5697 L .721 .137 0 r
F
.54538 .56694 m .5457 .56465 L .52741 .56742 L F
.43065 .34599 m .42643 .34936 L .4246 .35113 L .722 .224 0 r
F
.23505 .80555 m .20137 .79217 L .20453 .79713 L 1 .154 0 r
F
.2379 .81027 m .23505 .80555 L .20453 .79713 L 1 .127 0 r
F
.40326 .82984 m .36965 .82993 L .37127 .83358 L .849 .068 0 r
F
.40433 .83344 m .40326 .82984 L .37127 .83358 L .834 .065 0 r
F
.4356 .82775 m .40326 .82984 L .40433 .83344 L .772 .061 0 r
F
.42944 .573 m .4104 .56839 L .41065 .57067 L 1 .504 0 r
F
.42962 .57523 m .42944 .573 L .41065 .57067 L 1 .491 0 r
F
.6695 .8406 m .64258 .84309 L .63975 .84688 L .319 0 0 r
F
.6695 .8406 m .67284 .83671 L .64258 .84309 L F
.58658 .45344 m .57251 .4559 L .57324 .45856 L .571 .324 0 r
F
.58658 .45344 m .58575 .4508 L .57251 .4559 L F
.57912 .43248 m .56572 .43474 L .56666 .43737 L .598 .408 0 r
F
.58016 .43508 m .57912 .43248 L .56666 .43737 L .595 .398 0 r
F
.52627 .37332 m .51475 .37413 L .51574 .37683 L .868 .711 0 r
F
.52746 .37604 m .52627 .37332 L .51574 .37683 L .86 .712 0 r
F
.62156 .5589 m .60628 .56324 L .60551 .56601 L .279 .012 0 r
F
.62156 .5589 m .62242 .55611 L .60628 .56324 L F
.44885 .58508 m .4291 .58179 L .42929 .58407 L 1 .426 0 r
F
.44895 .58732 m .44885 .58508 L .42929 .58407 L 1 .412 0 r
F
.46856 .58772 m .44885 .58508 L .44895 .58732 L .993 .363 0 r
F
.76204 .50225 m .74719 .51046 L .7469 .5153 L .065 0 0 r
F
.76204 .50225 m .76223 .49735 L .74719 .51046 L F
.39048 .53867 m .37323 .53201 L .37328 .53454 L 1 .735 0 r
F
.39054 .54117 m .39048 .53867 L .37328 .53454 L 1 .723 0 r
F
.58737 .45609 m .57324 .45856 L .57394 .46123 L .568 .313 0 r
F
.58737 .45609 m .58658 .45344 L .57324 .45856 L F
.57805 .4299 m .56475 .43213 L .56572 .43474 L .601 .418 0 r
F
.57912 .43248 m .57805 .4299 L .56572 .43474 L .598 .408 0 r
F
.57337 .41641 m .56035 .41861 L .56145 .4212 L .63 .476 0 r
F
.57459 .41898 m .57337 .41641 L .56145 .4212 L .627 .467 0 r
F
.58179 .52216 m .56558 .52415 L .56559 .52672 L .586 .14 0 r
F
.58179 .52216 m .58179 .51958 L .56558 .52415 L F
.4653 .89353 m .46524 .89061 L .43233 .89018 L .67 .031 0 r
F
.49751 .893 m .46524 .89061 L .4653 .89353 L .613 .024 0 r
F
.49751 .893 m .49815 .89008 L .46524 .89061 L F
.73899 .1554 m .73197 .16699 L .73777 .17131 L .254 .259 0 r
F
.73899 .1554 m .73315 .15132 L .73197 .16699 L F
.13999 .67218 m .10962 .65358 L .11147 .65969 L 1 .509 0 r
F
.14178 .67805 m .13999 .67218 L .11147 .65969 L 1 .487 0 r
F
.59304 .47191 m .57822 .47454 L .57877 .47724 L .559 .262 0 r
F
.59304 .47191 m .59242 .46922 L .57822 .47454 L F
.76464 .78536 m .73896 .78978 L .73595 .79482 L .221 0 0 r
F
.76464 .78536 m .76802 .78016 L .73896 .78978 L F
.3535 .57677 m .33498 .56761 L .33528 .57064 L 1 .693 0 r
F
.35383 .57974 m .3535 .57677 L .33528 .57064 L 1 .678 0 r
F
.4085 .56843 m .38877 .56371 L .38906 .56613 L 1 .559 0 r
F
.40871 .57083 m .4085 .56843 L .38906 .56613 L 1 .549 0 r
F
.37519 .49822 m .36021 .49065 L .35981 .49329 L 1 .913 0 r
F
.37487 .50086 m .37519 .49822 L .35981 .49329 L 1 .905 0 r
F
.46856 .58992 m .46856 .58772 L .44895 .58732 L .988 .348 0 r
F
.48803 .58962 m .46856 .58772 L .46856 .58992 L .929 .289 0 r
F
.48803 .58962 m .48814 .58745 L .46856 .58772 L F
.59848 .5871 m .58155 .59062 L .58073 .59312 L .358 .021 0 r
F
.59848 .5871 m .59944 .58457 L .58155 .59062 L F
.47086 .37765 m .46098 .37593 L .46063 .37821 L 1 1 0 r
F
.47086 .37765 m .47091 .37527 L .46098 .37593 L F
.58813 .45874 m .57394 .46123 L .5746 .4639 L .564 .302 0 r
F
.58813 .45874 m .58737 .45609 L .57394 .46123 L F
.3673 .52701 m .34947 .51945 L .3495 .52218 L 1 .751 0 r
F
.36738 .52967 m .3673 .52701 L .3495 .52218 L 1 .742 0 r
F
.57695 .42732 m .56376 .42952 L .56475 .43213 L .604 .428 0 r
F
.57805 .4299 m .57695 .42732 L .56475 .43213 L .601 .418 0 r
F
.58345 .52802 m .56686 .52994 L .56683 .53254 L .592 .136 0 r
F
.58345 .52802 m .58348 .52541 L .56686 .52994 L F
.56539 .55521 m .54786 .55634 L .54764 .55878 L .657 .121 0 r
F
.56539 .55521 m .56566 .55276 L .54786 .55634 L F
.42358 .63152 m .40159 .6268 L .40215 .62925 L 1 .291 0 r
F
.42399 .63385 m .42358 .63152 L .40215 .62925 L 1 .273 0 r
F
.35229 .48006 m .33759 .47109 L .33703 .47397 L 1 .948 0 r
F
.35187 .48293 m .35229 .48006 L .33703 .47397 L 1 .939 0 r
F
.85845 .3106 m .84492 .32478 L .84818 .33105 L .11 .056 0 r
F
.85845 .3106 m .85504 .3044 L .84492 .32478 L F
.38581 .38685 m .37929 .38198 L .37726 .38414 L 1 1 0 r
F
.38581 .38685 m .38762 .38452 L .37929 .38198 L F
.57212 .41386 m .55922 .41602 L .56035 .41861 L .633 .485 0 r
F
.57337 .41641 m .57212 .41386 L .56035 .41861 L .63 .476 0 r
F
.58885 .46139 m .5746 .4639 L .57525 .46658 L .56 .29 0 r
F
.58885 .46139 m .58813 .45874 L .5746 .4639 L F
.41213 .36503 m .40678 .3635 L .40479 .36541 L 1 1 0 r
F
.41213 .36503 m .41387 .3629 L .40678 .3635 L F
.57583 .42475 m .56274 .42692 L .56376 .42952 L .607 .438 0 r
F
.57695 .42732 m .57583 .42475 L .56376 .42952 L .604 .428 0 r
F
.37686 .60486 m .35648 .59718 L .35704 .60001 L 1 .533 0 r
F
.37737 .6076 m .37686 .60486 L .35704 .60001 L 1 .517 0 r
F
.52661 .58239 m .50789 .58199 L .50769 .58422 L .795 .174 0 r
F
.52661 .58239 m .52692 .58016 L .50789 .58199 L F
.3815 .399 m .37303 .3924 L .37114 .39468 L 1 1 0 r
F
.3815 .399 m .38312 .39656 L .37303 .3924 L F
.54285 .38274 m .53101 .38397 L .53218 .38657 L .765 .638 0 r
F
.5442 .38531 m .54285 .38274 L .53218 .38657 L .761 .636 0 r
F
.33434 .53043 m .31894 .52025 L .31869 .52339 L 1 .893 0 r
F
.33418 .53358 m .33434 .53043 L .31869 .52339 L 1 .881 0 r
F
.4686 .58386 m .44914 .58109 L .44925 .58324 L .996 .35 0 r
F
.46861 .58597 m .4686 .58386 L .44925 .58324 L .992 .336 0 r
F
.48788 .58575 m .4686 .58386 L .46861 .58597 L .928 .277 0 r
F
.48788 .58575 m .48799 .58365 L .4686 .58386 L F
.59363 .47461 m .57877 .47724 L .57929 .47995 L .555 .251 0 r
F
.59363 .47461 m .59304 .47191 L .57877 .47724 L F
.50242 .37184 m .50165 .36911 L .49136 .37188 L .998 .854 0 r
F
.51277 .36857 m .50165 .36911 L .50242 .37184 L .955 .78 0 r
F
.51376 .37138 m .51277 .36857 L .50242 .37184 L .944 .782 0 r
F
.42893 .57948 m .40917 .57557 L .40943 .5779 L 1 .49 0 r
F
.4291 .58179 m .42893 .57948 L .40943 .5779 L 1 .477 0 r
F
.4093 .37554 m .40297 .37268 L .40107 .37465 L 1 1 0 r
F
.4093 .37554 m .41092 .37333 L .40297 .37268 L F
.40052 .62181 m .37908 .61565 L .37971 .61828 L 1 .402 0 r
F
.40105 .62432 m .40052 .62181 L .37971 .61828 L 1 .385 0 r
F
.44914 .58109 m .4298 .57744 L .43001 .57963 L 1 .417 0 r
F
.44925 .58324 m .44914 .58109 L .43001 .57963 L 1 .403 0 r
F
.54345 .38629 m .53172 .38729 L .53288 .38984 L .738 .627 0 r
F
.5448 .38881 m .54345 .38629 L .53288 .38984 L .735 .623 0 r
F
.73751 .1572 m .73095 .16823 L .73678 .17247 L .251 .275 0 r
F
.73751 .1572 m .73152 .15337 L .73095 .16823 L F
.50165 .36911 m .49084 .36924 L .49136 .37188 L 1 .855 0 r
F
.50157 .36942 m .49084 .36924 L .49136 .37188 L .99 .844 0 r
F
.50234 .37213 m .50157 .36942 L .49136 .37188 L .979 .843 0 r
F
.58955 .46404 m .57525 .46658 L .57586 .46925 L .556 .279 0 r
F
.58955 .46404 m .58885 .46139 L .57525 .46658 L F
.52577 .3743 m .51451 .37473 L .5155 .37739 L .839 .702 0 r
F
.52697 .37695 m .52577 .3743 L .5155 .37739 L .833 .702 0 r
F
.6832 .41278 m .67668 .41717 L .6753 .42192 L 0 0 0 r
F
.6832 .41278 m .68466 .40801 L .67668 .41717 L F
.57467 .42219 m .5617 .42433 L .56274 .42692 L .61 .447 0 r
F
.57583 .42475 m .57467 .42219 L .56274 .42692 L .607 .438 0 r
F
.32449 .85601 m .28988 .84714 L .29283 .85105 L .936 .069 0 r
F
.32694 .85969 m .32449 .85601 L .29283 .85105 L .916 .065 0 r
F
.52603 .57857 m .50755 .57829 L .50734 .58046 L .789 .164 0 r
F
.52603 .57857 m .52634 .57639 L .50755 .57829 L F
.40978 .56143 m .3914 .55584 L .39163 .55822 L 1 .599 0 r
F
.40997 .56377 m .40978 .56143 L .39163 .55822 L 1 .586 0 r
F
.48107 .37393 m .47096 .3729 L .47091 .37527 L 1 .978 0 r
F
.48107 .37393 m .48083 .37144 L .47096 .3729 L F
.69531 .1559 m .68959 .16454 L .69451 .16947 L .164 .094 0 r
F
.69531 .1559 m .69025 .15133 L .68959 .16454 L F
.37487 .50086 m .35981 .49329 L .35944 .49593 L 1 .905 0 r
F
.37458 .5035 m .37487 .50086 L .35944 .49593 L 1 .896 0 r
F
.66272 .47035 m .65289 .47536 L .65213 .47896 L 0 0 0 r
F
.66272 .47035 m .66356 .46675 L .65289 .47536 L F
.5221 .80086 m .49545 .80746 L .49503 .81114 L .464 .026 0 r
F
.5221 .80086 m .52295 .79728 L .49545 .80746 L F
.57084 .41131 m .55807 .41343 L .55922 .41602 L .636 .493 0 r
F
.57212 .41386 m .57084 .41131 L .55922 .41602 L .633 .485 0 r
F
.89074 .49159 m .87268 .50373 L .87308 .51053 L .013 0 0 r
F
.89074 .49159 m .89039 .48471 L .87268 .50373 L F
.56417 .55162 m .54698 .55286 L .54677 .55526 L .648 .112 0 r
F
.56417 .55162 m .56443 .5492 L .54698 .55286 L F
.51251 .36927 m .50157 .36942 L .50234 .37213 L .929 .769 0 r
F
.51351 .37203 m .51251 .36927 L .50234 .37213 L .919 .771 0 r
F
.81169 .71901 m .78829 .72589 L .78576 .73151 L .123 0 0 r
F
.81169 .71901 m .81447 .71323 L .78829 .72589 L F
.50725 .58859 m .48814 .58745 L .48803 .58962 L .862 .221 0 r
F
.50725 .58859 m .50748 .58641 L .48814 .58745 L F
.51053 .6363 m .48976 .63631 L .48954 .63834 L .708 .055 0 r
F
.51053 .6363 m .51099 .63431 L .48976 .63631 L F
.59419 .47731 m .57929 .47995 L .57978 .48266 L .551 .239 0 r
F
.59419 .47731 m .59363 .47461 L .57929 .47995 L F
.59021 .4667 m .57586 .46925 L .57644 .47193 L .552 .268 0 r
F
.59021 .4667 m .58955 .46404 L .57586 .46925 L F
.57349 .41964 m .56063 .42174 L .5617 .42433 L .613 .457 0 r
F
.57467 .42219 m .57349 .41964 L .5617 .42433 L .61 .447 0 r
F
.38779 .55385 m .36857 .54791 L .36883 .55045 L 1 .628 0 r
F
.38801 .55634 m .38779 .55385 L .36883 .55045 L 1 .619 0 r
F
.35187 .48293 m .33703 .47397 L .33652 .47685 L 1 .939 0 r
F
.35149 .4858 m .35187 .48293 L .33652 .47685 L 1 .929 0 r
F
.57531 .60746 m .55719 .61012 L .55641 .6124 L .428 .028 0 r
F
.57531 .60746 m .57627 .60515 L .55719 .61012 L F
.52508 .37055 m .51376 .37138 L .51475 .37413 L .876 .708 0 r
F
.52627 .37332 m .52508 .37055 L .51475 .37413 L .868 .711 0 r
F
.58177 .52473 m .56559 .52672 L .56557 .52928 L .581 .128 0 r
F
.58177 .52473 m .58179 .52216 L .56559 .52672 L F
.5459 .57298 m .52774 .57333 L .52748 .57563 L .724 .132 0 r
F
.5459 .57298 m .54624 .57066 L .52774 .57333 L F
.18423 .76094 m .15218 .74457 L .15501 .75018 L 1 .285 0 r
F
.18686 .76631 m .18423 .76094 L .15501 .75018 L 1 .258 0 r
F
.5069 .58471 m .48799 .58365 L .48788 .58575 L .857 .21 0 r
F
.5069 .58471 m .50712 .5826 L .48799 .58365 L F
.4461 .63722 m .42399 .63385 L .42442 .63613 L .973 .187 0 r
F
.44634 .63938 m .4461 .63722 L .42442 .63613 L .964 .167 0 r
F
.46802 .63937 m .4461 .63722 L .44634 .63938 L .889 .095 0 r
F
.55311 .62118 m .53399 .62299 L .53335 .62513 L .523 .036 0 r
F
.55311 .62118 m .55396 .61905 L .53399 .62299 L F
.39054 .54117 m .37328 .53454 L .37336 .53706 L 1 .723 0 r
F
.39063 .54366 m .39054 .54117 L .37336 .53706 L 1 .712 0 r
F
.64285 .52169 m .62998 .52667 L .6293 .52975 L .162 0 0 r
F
.64285 .52169 m .64359 .51861 L .62998 .52667 L F
.56954 .40876 m .5569 .41086 L .55807 .41343 L .639 .501 0 r
F
.57084 .41131 m .56954 .40876 L .55807 .41343 L .636 .493 0 r
F
.5293 .89153 m .49815 .89008 L .49751 .893 L .543 .015 0 r
F
.5293 .89153 m .53063 .88859 L .49815 .89008 L F
.57576 .7651 m .55282 .77186 L .55173 .77563 L .336 .002 0 r
F
.57576 .7651 m .57725 .76159 L .55282 .77186 L F
.57228 .4171 m .55954 .41917 L .56063 .42174 L .616 .466 0 r
F
.57349 .41964 m .57228 .4171 L .56063 .42174 L .613 .457 0 r
F
.59084 .46936 m .57644 .47193 L .57699 .47461 L .548 .256 0 r
F
.59084 .46936 m .59021 .4667 L .57644 .47193 L F
.38312 .39656 m .37497 .39017 L .37303 .3924 L 1 1 0 r
F
.38312 .39656 m .38479 .39415 L .37497 .39017 L F
.58339 .53061 m .56683 .53254 L .56678 .53512 L .588 .124 0 r
F
.58339 .53061 m .58345 .52802 L .56683 .53254 L F
.5415 .38014 m .52983 .38136 L .53101 .38397 L .77 .64 0 r
F
.54285 .38274 m .5415 .38014 L .53101 .38397 L .765 .638 0 r
F
.59471 .48001 m .57978 .48266 L .58024 .48536 L .547 .227 0 r
F
.59471 .48001 m .59419 .47731 L .57978 .48266 L F
.36201 .87664 m .32713 .86951 L .32974 .87306 L .862 .057 0 r
F
.36403 .88 m .36201 .87664 L .32974 .87306 L .84 .053 0 r
F
.37458 .5035 m .35944 .49593 L .3591 .49856 L 1 .896 0 r
F
.37431 .50613 m .37458 .5035 L .3591 .49856 L 1 .887 0 r
F
.54504 .56921 m .52717 .5697 L .52691 .57196 L .716 .123 0 r
F
.54504 .56921 m .54538 .56694 L .52717 .5697 L F
.36738 .52967 m .3495 .52218 L .34957 .52489 L 1 .742 0 r
F
.36748 .53232 m .36738 .52967 L .34957 .52489 L 1 .732 0 r
F
.07683 .58942 m .05205 .56499 L .05258 .57198 L 1 .688 0 r
F
.07744 .59624 m .07683 .58942 L .05258 .57198 L 1 .665 0 r
F
.65701 .17943 m .66565 .16397 L .66918 .17088 L 1 .63 0 r
F
.65701 .17943 m .6584 .16514 L .66565 .16397 L F
.76013 .39393 m .75646 .40059 L .75713 .40592 L 0 0 0 r
F
.76013 .39393 m .75907 .38884 L .75646 .40059 L F
.5421 .38377 m .53054 .38473 L .53172 .38729 L .741 .63 0 r
F
.54345 .38629 m .5421 .38377 L .53172 .38729 L .738 .627 0 r
F
.38762 .38452 m .38135 .37987 L .37929 .38198 L 1 1 0 r
F
.38762 .38452 m .38946 .38223 L .38135 .37987 L F
.42944 .35591 m .42425 .35682 L .42255 .35877 L 1 .91 0 r
F
.42944 .35591 m .43085 .35363 L .42425 .35682 L F
.42962 .57523 m .41065 .57067 L .41091 .57292 L 1 .491 0 r
F
.4298 .57744 m .42962 .57523 L .41091 .57292 L 1 .477 0 r
F
.33418 .53358 m .31869 .52339 L .31848 .52652 L 1 .881 0 r
F
.33406 .53671 m .33418 .53358 L .31848 .52652 L 1 .869 0 r
F
.89814 .49878 m .87856 .51094 L .87903 .51785 L .053 .005 0 r
F
.89814 .49878 m .89763 .49177 L .87856 .51094 L F
.86334 .31618 m .84993 .33036 L .8532 .33667 L .101 .055 0 r
F
.86334 .31618 m .8599 .30996 L .84993 .33036 L F
.74472 .15961 m .73777 .17131 L .74349 .17573 L .236 .225 0 r
F
.74472 .15961 m .73899 .1554 L .73777 .17131 L F
.57104 .41457 m .55843 .4166 L .55954 .41917 L .619 .475 0 r
F
.57228 .4171 m .57104 .41457 L .55954 .41917 L .616 .466 0 r
F
.59143 .47203 m .57699 .47461 L .57752 .47728 L .544 .244 0 r
F
.59143 .47203 m .59084 .46936 L .57699 .47461 L F
.43615 .83131 m .4356 .82775 L .40433 .83344 L .755 .057 0 r
F
.46607 .82382 m .4356 .82775 L .43615 .83131 L .673 .05 0 r
F
.46607 .82382 m .46603 .82023 L .4356 .82775 L F
.56822 .40623 m .55571 .40829 L .5569 .41086 L .642 .509 0 r
F
.56954 .40876 m .56822 .40623 L .5569 .41086 L .639 .501 0 r
F
.40871 .57083 m .38906 .56613 L .38937 .56853 L 1 .549 0 r
F
.40893 .57321 m .40871 .57083 L .38937 .56853 L 1 .538 0 r
F
.56065 .87895 m .53091 .87871 L .52962 .88163 L .458 .003 0 r
F
.56065 .87895 m .56261 .876 L .53091 .87871 L F
.56509 .55765 m .54764 .55878 L .54741 .5612 L .652 .108 0 r
F
.56509 .55765 m .56539 .55521 L .54764 .55878 L F
.63341 .71777 m .61242 .7227 L .61098 .7265 L .296 0 0 r
F
.63341 .71777 m .63525 .71418 L .61242 .7227 L F
.35149 .4858 m .33652 .47685 L .33604 .47972 L 1 .929 0 r
F
.35114 .48865 m .35149 .4858 L .33604 .47972 L 1 .919 0 r
F
.72218 .28279 m .73568 .27473 L .73702 .2813 L 1 .689 0 r
F
.72218 .28279 m .72201 .27582 L .73568 .27473 L F
.50165 .36911 m .50088 .3663 L .49084 .36924 L 1 .855 0 r
F
.51179 .36567 m .50088 .3663 L .50165 .36911 L .967 .774 0 r
F
.51277 .36857 m .51179 .36567 L .50165 .36911 L .955 .78 0 r
F
.44895 .58732 m .42929 .58407 L .42949 .58633 L 1 .412 0 r
F
.44905 .58953 m .44895 .58732 L .42949 .58633 L 1 .397 0 r
F
.46856 .58992 m .44895 .58732 L .44905 .58953 L .988 .348 0 r
F
.52457 .3716 m .51351 .37203 L .51451 .37473 L .846 .699 0 r
F
.52577 .3743 m .52457 .3716 L .51451 .37473 L .839 .702 0 r
F
.35383 .57974 m .33528 .57064 L .33562 .57366 L 1 .678 0 r
F
.35419 .5827 m .35383 .57974 L .33562 .57366 L 1 .664 0 r
F
.5952 .4827 m .58024 .48536 L .58067 .48807 L .542 .215 0 r
F
.5952 .4827 m .59471 .48001 L .58024 .48536 L F
.49459 .81472 m .46603 .82023 L .46607 .82382 L .568 .038 0 r
F
.49459 .81472 m .49503 .81114 L .46603 .82023 L F
.70318 .34841 m .70058 .35138 L .69909 .3578 L 0 0 0 r
F
.70318 .34841 m .70441 .34216 L .70058 .35138 L F
.47091 .37527 m .46133 .37366 L .46098 .37593 L 1 1 0 r
F
.47091 .37527 m .47096 .3729 L .46133 .37366 L F
.46856 .59208 m .46856 .58992 L .44905 .58953 L .984 .333 0 r
F
.48792 .59178 m .46856 .58992 L .46856 .59208 L .924 .274 0 r
F
.48792 .59178 m .48803 .58962 L .46856 .58992 L F
.62067 .56166 m .60551 .56601 L .60471 .56876 L .274 .01 0 r
F
.62067 .56166 m .62156 .5589 L .60551 .56601 L F
.56978 .41205 m .55729 .41404 L .55843 .4166 L .622 .484 0 r
F
.57104 .41457 m .56978 .41205 L .55843 .4166 L .619 .475 0 r
F
.08658 .57994 m .06338 .55583 L .06367 .56265 L 1 .714 0 r
F
.08697 .58662 m .08658 .57994 L .06367 .56265 L 1 .692 0 r
F
.41092 .37333 m .40486 .37074 L .40297 .37268 L 1 1 0 r
F
.41092 .37333 m .41254 .37116 L .40486 .37074 L F
.86077 .63066 m .8396 .64 L .83808 .64633 L .045 0 0 r
F
.86077 .63066 m .86241 .62419 L .8396 .64 L F
.59199 .47469 m .57752 .47728 L .57801 .47996 L .54 .232 0 r
F
.59199 .47469 m .59143 .47203 L .57752 .47728 L F
.37431 .50613 m .3591 .49856 L .35879 .50119 L 1 .887 0 r
F
.37408 .50876 m .37431 .50613 L .35879 .50119 L 1 .878 0 r
F
.74342 .16113 m .73678 .17247 L .74255 .17679 L .244 .258 0 r
F
.74342 .16113 m .73751 .1572 L .73678 .17247 L F
.71125 .81663 m .68553 .82021 L .68246 .82447 L .258 0 0 r
F
.71125 .81663 m .71476 .81224 L .68553 .82021 L F
.76179 .50712 m .7469 .5153 L .74657 .52012 L .063 0 0 r
F
.76179 .50712 m .76204 .50225 L .7469 .5153 L F
.66564 .68717 m .64499 .69156 L .64352 .69545 L .284 0 0 r
F
.66564 .68717 m .66748 .6834 L .64499 .69156 L F
.58171 .52728 m .56557 .52928 L .56552 .53182 L .577 .116 0 r
F
.58171 .52728 m .58177 .52473 L .56557 .52928 L F
.5239 .3677 m .51277 .36857 L .51376 .37138 L .885 .702 0 r
F
.52508 .37055 m .5239 .3677 L .51376 .37138 L .876 .708 0 r
F
.56687 .4037 m .5545 .40573 L .55571 .40829 L .645 .516 0 r
F
.56822 .40623 m .56687 .4037 L .55571 .40829 L .642 .509 0 r
F
.50157 .36942 m .50079 .36663 L .49084 .36924 L .99 .844 0 r
F
.51152 .36643 m .50079 .36663 L .50157 .36942 L .94 .764 0 r
F
.51251 .36927 m .51152 .36643 L .50157 .36942 L .929 .769 0 r
F
.41387 .3629 m .40878 .36163 L .40678 .3635 L 1 1 0 r
F
.41387 .3629 m .41563 .36082 L .40878 .36163 L F
.50088 .3663 m .49031 .36656 L .49084 .36924 L 1 .854 0 r
F
.50079 .36663 m .49031 .36656 L .49084 .36924 L 1 .843 0 r
F
.73523 .58981 m .71619 .59595 L .71517 .60036 L .195 .002 0 r
F
.73523 .58981 m .73639 .58533 L .71619 .59595 L F
.4291 .58179 m .40943 .5779 L .40971 .58021 L 1 .477 0 r
F
.42929 .58407 m .4291 .58179 L .40971 .58021 L 1 .463 0 r
F
.86174 .31685 m .84818 .33105 L .85133 .33738 L .099 .053 0 r
F
.86174 .31685 m .85845 .3106 L .84818 .33105 L F
.40997 .56377 m .39163 .55822 L .39188 .56058 L 1 .586 0 r
F
.41018 .56609 m .40997 .56377 L .39188 .56058 L 1 .573 0 r
F
.38479 .39415 m .37696 .388 L .37497 .39017 L 1 1 0 r
F
.38479 .39415 m .38649 .3918 L .37696 .388 L F
.56388 .55401 m .54677 .55526 L .54654 .55764 L .643 .1 0 r
F
.56388 .55401 m .56417 .55162 L .54677 .55526 L F
.59525 .87962 m .56617 .87985 L .56423 .88305 L .426 0 0 r
F
.59525 .87962 m .59783 .87635 L .56617 .87985 L F
.54013 .37752 m .52864 .37872 L .52983 .38136 L .775 .64 0 r
F
.5415 .38014 m .54013 .37752 L .52983 .38136 L .77 .64 0 r
F
.52629 .58459 m .50769 .58422 L .50748 .58641 L .79 .16 0 r
F
.52629 .58459 m .52661 .58239 L .50769 .58422 L F
.4654 .88679 m .46534 .88397 L .43295 .88363 L .658 .028 0 r
F
.49707 .88611 m .46534 .88397 L .4654 .88679 L .597 .021 0 r
F
.49707 .88611 m .4977 .8833 L .46534 .88397 L F
.70053 .26523 m .7055 .26124 L .70661 .26815 L .985 .144 0 r
F
.70053 .26523 m .69896 .25909 L .7055 .26124 L F
.53133 .63131 m .51145 .63227 L .51099 .63431 L .611 .044 0 r
F
.53133 .63131 m .53202 .62929 L .51145 .63227 L F
.09511 .57111 m .07047 .54778 L .07085 .55445 L 1 .723 0 r
F
.09559 .57761 m .09511 .57111 L .07085 .55445 L 1 .703 0 r
F
.13129 .69155 m .10231 .67152 L .10429 .67783 L 1 .465 0 r
F
.1332 .69764 m .13129 .69155 L .10429 .67783 L 1 .439 0 r
F
.46861 .58597 m .44925 .58324 L .44936 .58535 L .992 .336 0 r
F
.46861 .58805 m .46861 .58597 L .44936 .58535 L .987 .321 0 r
F
.48776 .58784 m .46861 .58597 L .46861 .58805 L .923 .262 0 r
F
.48776 .58784 m .48788 .58575 L .46861 .58597 L F
.59566 .4854 m .58067 .48807 L .58107 .49077 L .538 .204 0 r
F
.59566 .4854 m .5952 .4827 L .58067 .48807 L F
.7003 .64701 m .68002 .65171 L .67866 .6558 L .255 .001 0 r
F
.7003 .64701 m .70195 .64293 L .68002 .65171 L F
.39063 .54366 m .37336 .53706 L .37346 .53956 L 1 .712 0 r
F
.39074 .54613 m .39063 .54366 L .37346 .53956 L 1 .7 0 r
F
.44925 .58324 m .43001 .57963 L .43022 .58179 L 1 .403 0 r
F
.44936 .58535 m .44925 .58324 L .43022 .58179 L 1 .388 0 r
F
.54073 .38124 m .52936 .38216 L .53054 .38473 L .744 .632 0 r
F
.5421 .38377 m .54073 .38124 L .53054 .38473 L .741 .63 0 r
F
.58329 .53319 m .56678 .53512 L .5667 .53768 L .583 .111 0 r
F
.58329 .53319 m .58339 .53061 L .56678 .53512 L F
.48083 .37144 m .47101 .37053 L .47096 .3729 L 1 .986 0 r
F
.48083 .37144 m .48058 .36894 L .47101 .37053 L F
.56849 .40953 m .55613 .41149 L .55729 .41404 L .624 .492 0 r
F
.56978 .41205 m .56849 .40953 L .55729 .41404 L .622 .484 0 r
F
.38801 .55634 m .36883 .55045 L .36912 .55298 L 1 .619 0 r
F
.38824 .55881 m .38801 .55634 L .36912 .55298 L 1 .611 0 r
F
.28104 .84509 m .24625 .83439 L .24956 .83875 L .994 .079 0 r
F
.28391 .84923 m .28104 .84509 L .24956 .83875 L .974 .075 0 r
F
.46804 .64142 m .46802 .63937 L .44634 .63938 L .878 .077 0 r
F
.48932 .64033 m .46802 .63937 L .46804 .64142 L .792 .065 0 r
F
.48932 .64033 m .48954 .63834 L .46802 .63937 L F
.59749 .5896 m .58073 .59312 L .57988 .5956 L .352 .018 0 r
F
.59749 .5896 m .59848 .5871 L .58073 .59312 L F
.59252 .47735 m .57801 .47996 L .57848 .48263 L .536 .221 0 r
F
.59252 .47735 m .59199 .47469 L .57801 .47996 L F
.52571 .58072 m .50734 .58046 L .50712 .5826 L .784 .15 0 r
F
.52571 .58072 m .52603 .57857 L .50734 .58046 L F
.29142 .80761 m .25651 .80062 L .25937 .80492 L 1 .15 0 r
F
.29384 .81175 m .29142 .80761 L .25937 .80492 L 1 .127 0 r
F
.35114 .48865 m .33604 .47972 L .3356 .48259 L 1 .919 0 r
F
.35082 .49151 m .35114 .48865 L .3356 .48259 L 1 .91 0 r
F
.81594 .7299 m .79155 .73613 L .78895 .74186 L .15 0 0 r
F
.81594 .7299 m .8188 .72399 L .79155 .73613 L F
.70006 .16082 m .69451 .16947 L .69917 .17466 L .118 .082 0 r
F
.70006 .16082 m .69531 .1559 L .69451 .16947 L F
.75873 .77922 m .73412 .78419 L .7311 .78906 L .192 0 0 r
F
.75873 .77922 m .76211 .77419 L .73412 .78419 L F
.37737 .6076 m .35704 .60001 L .35763 .60283 L 1 .517 0 r
F
.37792 .61031 m .37737 .6076 L .35763 .60283 L 1 .501 0 r
F
.56551 .40118 m .55327 .40318 L .5545 .40573 L .648 .524 0 r
F
.56687 .4037 m .56551 .40118 L .5545 .40573 L .645 .516 0 r
F
.38946 .38223 m .38342 .37779 L .38135 .37987 L 1 1 0 r
F
.38946 .38223 m .39131 .37999 L .38342 .37779 L F
.36748 .53232 m .34957 .52489 L .34967 .52759 L 1 .732 0 r
F
.3676 .53496 m .36748 .53232 L .34967 .52759 L 1 .723 0 r
F
.24574 .78273 m .21121 .77263 L .21416 .77741 L 1 .224 0 r
F
.24832 .7873 m .24574 .78273 L .21416 .77741 L 1 .201 0 r
F
.23377 .81611 m .19959 .80299 L .20294 .80792 L 1 .123 0 r
F
.23677 .8208 m .23377 .81611 L .20294 .80792 L 1 .097 0 r
F
.33406 .53671 m .31848 .52652 L .31832 .52965 L 1 .869 0 r
F
.33398 .53984 m .33406 .53671 L .31832 .52965 L 1 .857 0 r
F
.54553 .57527 m .52748 .57563 L .52721 .57791 L .719 .118 0 r
F
.54553 .57527 m .5459 .57298 L .52748 .57563 L F
.6619 .47389 m .65213 .47896 L .65139 .4825 L 0 0 0 r
F
.6619 .47389 m .66272 .47035 L .65213 .47896 L F
.50702 .59073 m .48803 .58962 L .48792 .59178 L .856 .206 0 r
F
.50702 .59073 m .50725 .58859 L .48803 .58962 L F
.36965 .82993 m .33548 .82792 L .33763 .83164 L .911 .074 0 r
F
.37127 .83358 m .36965 .82993 L .33763 .83164 L .896 .071 0 r
F
.37408 .50876 m .35879 .50119 L .35852 .50381 L 1 .878 0 r
F
.37387 .51137 m .37408 .50876 L .35852 .50381 L 1 .869 0 r
F
.56718 .40703 m .55495 .40895 L .55613 .41149 L .627 .5 0 r
F
.56849 .40953 m .56718 .40703 L .55613 .41149 L .624 .492 0 r
F
.52337 .36883 m .51251 .36927 L .51351 .37203 L .854 .694 0 r
F
.52457 .3716 m .52337 .36883 L .51351 .37203 L .846 .699 0 r
F
.59608 .4881 m .58107 .49077 L .58144 .49347 L .534 .192 0 r
F
.59608 .4881 m .59566 .4854 L .58107 .49077 L F
.59301 .48001 m .57848 .48263 L .57891 .48531 L .531 .209 0 r
F
.59301 .48001 m .59252 .47735 L .57848 .48263 L F
.50666 .5868 m .48788 .58575 L .48776 .58784 L .852 .196 0 r
F
.50666 .5868 m .5069 .58471 L .48788 .58575 L F
.50088 .3663 m .50012 .36339 L .49031 .36656 L 1 .854 0 r
F
.51082 .36264 m .50012 .36339 L .50088 .3663 L .979 .766 0 r
F
.51179 .36567 m .51082 .36264 L .50088 .3663 L .967 .774 0 r
F
.42399 .63385 m .40215 .62925 L .40274 .63166 L 1 .273 0 r
F
.42442 .63613 m .42399 .63385 L .40274 .63166 L 1 .253 0 r
F
.40105 .62432 m .37971 .61828 L .38036 .62089 L 1 .385 0 r
F
.40159 .6268 m .40105 .62432 L .38036 .62089 L 1 .367 0 r
F
.18138 .77181 m .14858 .75566 L .15162 .76128 L 1 .252 0 r
F
.18419 .77719 m .18138 .77181 L .15162 .76128 L 1 .224 0 r
F
.86728 .64044 m .84456 .64926 L .84302 .65572 L .084 0 0 r
F
.86728 .64044 m .86894 .63381 L .84456 .64926 L F
.54468 .57146 m .52691 .57196 L .52663 .57419 L .711 .11 0 r
F
.54468 .57146 m .54504 .56921 L .52691 .57196 L F
.6421 .52474 m .6293 .52975 L .62861 .53279 L .159 0 0 r
F
.6421 .52474 m .64285 .52169 L .6293 .52975 L F
.53877 .37486 m .52746 .37604 L .52864 .37872 L .78 .639 0 r
F
.54013 .37752 m .53877 .37486 L .52864 .37872 L .775 .64 0 r
F
.75034 .16394 m .74349 .17573 L .74913 .18024 L .217 .189 0 r
F
.75034 .16394 m .74472 .15961 L .74349 .17573 L F
.52273 .36475 m .51179 .36567 L .51277 .36857 L .894 .693 0 r
F
.5239 .3677 m .52273 .36475 L .51277 .36857 L .885 .702 0 r
F
.56477 .56006 m .54741 .5612 L .54715 .56359 L .647 .095 0 r
F
.56477 .56006 m .56509 .55765 L .54741 .5612 L F
.63088 .86843 m .60284 .8695 L .60036 .87298 L .38 0 0 r
F
.63088 .86843 m .63396 .86487 L .60284 .8695 L F
.56412 .39867 m .55203 .40062 L .55327 .40318 L .651 .531 0 r
F
.56551 .40118 m .56412 .39867 L .55327 .40318 L .648 .524 0 r
F
.58162 .52982 m .56552 .53182 L .56544 .53435 L .572 .103 0 r
F
.58162 .52982 m .58171 .52728 L .56552 .53182 L F
.1952 .74268 m .16201 .72882 L .16471 .73421 L 1 .33 0 r
F
.19767 .74781 m .1952 .74268 L .16471 .73421 L 1 .307 0 r
F
.38649 .3918 m .37899 .3859 L .37696 .388 L 1 1 0 r
F
.38649 .3918 m .38822 .38949 L .37899 .3859 L F
.12581 .70238 m .09573 .68242 L .09794 .68879 L 1 .433 0 r
F
.12793 .70852 m .12581 .70238 L .09794 .68879 L 1 .406 0 r
F
.43233 .89018 m .39841 .88569 L .39984 .88878 L .739 .04 0 r
F
.43309 .89312 m .43233 .89018 L .39984 .88878 L .716 .036 0 r
F
.4653 .89353 m .43233 .89018 L .43309 .89312 L .67 .031 0 r
F
.4298 .57744 m .41091 .57292 L .41119 .57515 L 1 .477 0 r
F
.43001 .57963 m .4298 .57744 L .41119 .57515 L 1 .463 0 r
F
.6029 .74455 m .5814 .7506 L .58007 .75434 L .297 0 0 r
F
.6029 .74455 m .60464 .74108 L .5814 .7506 L F
.40893 .57321 m .38937 .56853 L .3897 .57092 L 1 .538 0 r
F
.40917 .57557 m .40893 .57321 L .3897 .57092 L 1 .526 0 r
F
.6818 .41741 m .6753 .42192 L .67397 .42652 L 0 0 0 r
F
.6818 .41741 m .6832 .41278 L .6753 .42192 L F
.53935 .37869 m .52817 .37957 L .52936 .38216 L .747 .633 0 r
F
.54073 .38124 m .53935 .37869 L .52936 .38216 L .744 .632 0 r
F
.35082 .49151 m .3356 .48259 L .33521 .48546 L 1 .91 0 r
F
.35054 .49435 m .35082 .49151 L .33521 .48546 L 1 .9 0 r
F
.56584 .40454 m .55375 .40641 L .55495 .40895 L .629 .508 0 r
F
.56718 .40703 m .56584 .40454 L .55495 .40895 L .627 .5 0 r
F
.76115 .399 m .75713 .40592 L .75777 .41122 L 0 0 0 r
F
.76115 .399 m .76013 .39393 L .75713 .40592 L F
.43085 .35363 m .42596 .3549 L .42425 .35682 L .961 .808 0 r
F
.43085 .35363 m .43228 .35137 L .42596 .3549 L F
.39841 .88569 m .36403 .88 L .3661 .88326 L .795 .047 0 r
F
.39984 .88878 m .39841 .88569 L .3661 .88326 L .772 .043 0 r
F
.89097 .49847 m .87308 .51053 L .87336 .51733 L .001 0 0 r
F
.89097 .49847 m .89074 .49159 L .87308 .51053 L F
.50079 .36663 m .50003 .36376 L .49031 .36656 L 1 .843 0 r
F
.51054 .36348 m .50003 .36376 L .50079 .36663 L .952 .757 0 r
F
.51152 .36643 m .51054 .36348 L .50079 .36663 L .94 .764 0 r
F
.86667 .32245 m .8532 .33667 L .85637 .34303 L .092 .052 0 r
F
.86667 .32245 m .86334 .31618 L .8532 .33667 L F
.59347 .48267 m .57891 .48531 L .57932 .48798 L .527 .196 0 r
F
.59347 .48267 m .59301 .48001 L .57891 .48531 L F
.5283 .88445 m .4977 .8833 L .49707 .88611 L .522 .011 0 r
F
.5283 .88445 m .52962 .88163 L .4977 .8833 L F
.36374 .87037 m .32945 .86328 L .332 .86678 L .86 .057 0 r
F
.36574 .87367 m .36374 .87037 L .332 .86678 L .838 .053 0 r
F
.59647 .49079 m .58144 .49347 L .58178 .49617 L .529 .179 0 r
F
.59647 .49079 m .59608 .4881 L .58144 .49347 L F
.58316 .53576 m .5667 .53768 L .56659 .54023 L .578 .099 0 r
F
.58316 .53576 m .58329 .53319 L .5667 .53768 L F
.41254 .37116 m .40676 .36881 L .40486 .37074 L 1 1 0 r
F
.41254 .37116 m .41419 .36903 L .40676 .36881 L F
.35419 .5827 m .33562 .57366 L .336 .57666 L 1 .664 0 r
F
.35458 .58563 m .35419 .5827 L .336 .57666 L 1 .649 0 r
F
.66994 .85162 m .64284 .85359 L .63994 .85745 L .33 0 0 r
F
.66994 .85162 m .67337 .84765 L .64284 .85359 L F
.37387 .51137 m .35852 .50381 L .35827 .50643 L 1 .869 0 r
F
.37369 .51399 m .37387 .51137 L .35827 .50643 L 1 .859 0 r
F
.57433 .60972 m .55641 .6124 L .55562 .61466 L .416 .025 0 r
F
.57433 .60972 m .57531 .60746 L .55641 .6124 L F
.74926 .16516 m .74255 .17679 L .74825 .18119 L .236 .24 0 r
F
.74926 .16516 m .74342 .16113 L .74255 .17679 L F
.39074 .54613 m .37346 .53956 L .37359 .54204 L 1 .7 0 r
F
.39087 .54858 m .39074 .54613 L .37359 .54204 L 1 .689 0 r
F
.14178 .67805 m .11147 .65969 L .11343 .66577 L 1 .487 0 r
F
.14366 .68388 m .14178 .67805 L .11343 .66577 L 1 .464 0 r
F
.44905 .58953 m .42949 .58633 L .4297 .58856 L 1 .397 0 r
F
.44917 .59172 m .44905 .58953 L .4297 .58856 L 1 .382 0 r
F
.46856 .59208 m .44905 .58953 L .44917 .59172 L .984 .333 0 r
F
.56356 .55639 m .54654 .55764 L .54628 .56 L .637 .087 0 r
F
.56356 .55639 m .56388 .55401 L .54654 .55764 L F
.50012 .36339 m .48979 .36381 L .49031 .36656 L 1 .851 0 r
F
.50003 .36376 m .48979 .36381 L .49031 .36656 L 1 .84 0 r
F
.56271 .39616 m .55076 .39808 L .55203 .40062 L .654 .537 0 r
F
.56412 .39867 m .56271 .39616 L .55203 .40062 L .651 .531 0 r
F
.47096 .3729 m .46169 .37141 L .46133 .37366 L 1 1 0 r
F
.47096 .3729 m .47101 .37053 L .46169 .37141 L F
.41018 .56609 m .39188 .56058 L .39215 .56292 L 1 .573 0 r
F
.4104 .56839 m .41018 .56609 L .39215 .56292 L 1 .56 0 r
F
.51006 .63825 m .48954 .63834 L .48932 .64033 L .695 .052 0 r
F
.51006 .63825 m .51053 .6363 L .48954 .63834 L F
.39131 .37999 m .38551 .37576 L .38342 .37779 L 1 1 0 r
F
.39131 .37999 m .39319 .37778 L .38551 .37576 L F
.56448 .40205 m .55252 .40389 L .55375 .40641 L .632 .516 0 r
F
.56584 .40454 m .56448 .40205 L .55375 .40641 L .629 .508 0 r
F
.33398 .53984 m .31832 .52965 L .31819 .53278 L 1 .857 0 r
F
.33394 .54297 m .33398 .53984 L .31819 .53278 L 1 .844 0 r
F
.41563 .36082 m .41079 .35982 L .40878 .36163 L .964 .99 0 r
F
.41563 .36082 m .41739 .35878 L .41079 .35982 L F
.46856 .59422 m .46856 .59208 L .44917 .59172 L .979 .317 0 r
F
.4878 .5939 m .46856 .59208 L .46856 .59422 L .919 .259 0 r
F
.4878 .5939 m .48792 .59178 L .46856 .59208 L F
.38824 .55881 m .36912 .55298 L .36943 .55549 L 1 .611 0 r
F
.3885 .56127 m .38824 .55881 L .36943 .55549 L 1 .601 0 r
F
.42929 .58407 m .40971 .58021 L .41 .5825 L 1 .463 0 r
F
.42949 .58633 m .42929 .58407 L .41 .5825 L 1 .448 0 r
F
.54818 .78638 m .52376 .7936 L .52295 .79728 L .372 .009 0 r
F
.54818 .78638 m .5494 .78289 L .52376 .7936 L F
.3676 .53496 m .34967 .52759 L .3498 .53028 L 1 .723 0 r
F
.36775 .53758 m .3676 .53496 L .3498 .53028 L 1 .713 0 r
F
.55223 .62328 m .53335 .62513 L .53269 .62723 L .51 .033 0 r
F
.55223 .62328 m .55311 .62118 L .53335 .62513 L F
.52219 .36598 m .51152 .36643 L .51251 .36927 L .862 .686 0 r
F
.52337 .36883 m .52219 .36598 L .51251 .36927 L .854 .694 0 r
F
.5374 .37216 m .52627 .37332 L .52746 .37604 L .786 .636 0 r
F
.53877 .37486 m .5374 .37216 L .52746 .37604 L .78 .639 0 r
F
.59389 .48533 m .57932 .48798 L .57969 .49064 L .522 .184 0 r
F
.59389 .48533 m .59347 .48267 L .57932 .48798 L F
.44634 .63938 m .42442 .63613 L .42486 .63838 L .964 .167 0 r
F
.44658 .64151 m .44634 .63938 L .42486 .63838 L .954 .147 0 r
F
.46804 .64142 m .44634 .63938 L .44658 .64151 L .878 .077 0 r
F
.65447 .19467 m .66918 .17088 L .67232 .17809 L 1 .88 0 r
F
.65447 .19467 m .65701 .17943 L .66918 .17088 L F
.61975 .56439 m .60471 .56876 L .60389 .57147 L .269 .008 0 r
F
.61975 .56439 m .62067 .56166 L .60471 .56876 L F
.52595 .58677 m .50748 .58641 L .50725 .58859 L .784 .145 0 r
F
.52595 .58677 m .52629 .58459 L .50748 .58641 L F
.72261 .28937 m .73702 .2813 L .73828 .28778 L 1 .688 0 r
F
.72261 .28937 m .72218 .28279 L .73702 .2813 L F
.86491 .32316 m .85133 .33738 L .85437 .34375 L .088 .049 0 r
F
.86491 .32316 m .86174 .31685 L .85133 .33738 L F
.48058 .36894 m .47106 .36816 L .47101 .37053 L 1 .994 0 r
F
.48058 .36894 m .48033 .3664 L .47106 .36816 L F
.52159 .36166 m .51082 .36264 L .51179 .36567 L .904 .68 0 r
F
.52273 .36475 m .52159 .36166 L .51179 .36567 L .894 .693 0 r
F
.55057 .231 m .56835 .1613 L .56344 .19642 L 1 .921 0 r
F
.53272 .28729 m .5553 .2043 L .54565 .25137 L 1 .963 0 r
F
.53272 .28729 m .53936 .25229 L .5553 .2043 L F
.55057 .231 m .55709 .19267 L .56835 .1613 L 1 .921 0 r
F
.35054 .49435 m .33521 .48546 L .33485 .48832 L 1 .9 0 r
F
.35029 .49718 m .35054 .49435 L .33485 .48832 L 1 .89 0 r
F
.59682 .49348 m .58178 .49617 L .58209 .49886 L .525 .167 0 r
F
.59682 .49348 m .59647 .49079 L .58178 .49617 L F
.89852 .50579 m .87903 .51785 L .87938 .52475 L .045 .002 0 r
F
.89852 .50579 m .89814 .49878 L .87903 .51785 L F
.76148 .51198 m .74657 .52012 L .74619 .52492 L .061 0 0 r
F
.76148 .51198 m .76179 .50712 L .74657 .52012 L F
.50012 .36339 m .49937 .36036 L .48979 .36381 L 1 .851 0 r
F
.50988 .35946 m .49937 .36036 L .50012 .36339 L .992 .753 0 r
F
.51082 .36264 m .50988 .35946 L .50012 .36339 L .979 .766 0 r
F
.38822 .38949 m .38106 .38387 L .37899 .3859 L 1 1 0 r
F
.38822 .38949 m .38999 .38724 L .38106 .38387 L F
.53797 .37611 m .52697 .37695 L .52817 .37957 L .751 .633 0 r
F
.53935 .37869 m .53797 .37611 L .52817 .37957 L .747 .633 0 r
F
.44936 .58535 m .43022 .58179 L .43044 .58392 L 1 .388 0 r
F
.44948 .58744 m .44936 .58535 L .43044 .58392 L 1 .373 0 r
F
.46861 .58805 m .44936 .58535 L .44948 .58744 L .987 .321 0 r
F
.46861 .59011 m .46861 .58805 L .44948 .58744 L .983 .307 0 r
F
.48764 .58989 m .46861 .58805 L .46861 .59011 L .918 .248 0 r
F
.48764 .58989 m .48776 .58784 L .46861 .58805 L F
.5815 .53235 m .56544 .53435 L .56534 .53687 L .567 .091 0 r
F
.5815 .53235 m .58162 .52982 L .56544 .53435 L F
.56128 .39365 m .54948 .39553 L .55076 .39808 L .657 .543 0 r
F
.56271 .39616 m .56128 .39365 L .55076 .39808 L .654 .537 0 r
F
.64025 .09654 m .63621 .10476 L .64302 .10718 L .385 .557 0 r
F
.64025 .09654 m .63346 .09466 L .63621 .10476 L F
.52537 .58285 m .50712 .5826 L .5069 .58471 L .778 .136 0 r
F
.52537 .58285 m .52571 .58072 L .50712 .5826 L F
.37369 .51399 m .35827 .50643 L .35807 .50904 L 1 .859 0 r
F
.37354 .51659 m .37369 .51399 L .35807 .50904 L 1 .849 0 r
F
.56309 .39957 m .55128 .40136 L .55252 .40389 L .634 .523 0 r
F
.56448 .40205 m .56309 .39957 L .55252 .40389 L .632 .516 0 r
F
.70441 .16618 m .69917 .17466 L .70354 .18012 L .052 .065 0 r
F
.70441 .16618 m .70006 .16082 L .69917 .17466 L F
.54514 .57753 m .52721 .57791 L .52692 .58016 L .713 .104 0 r
F
.54514 .57753 m .54553 .57527 L .52721 .57791 L F
.07744 .59624 m .05258 .57198 L .05323 .57896 L 1 .665 0 r
F
.07815 .60305 m .07744 .59624 L .05323 .57896 L 1 .642 0 r
F
.59297 .87228 m .56453 .87294 L .56261 .876 L .409 0 0 r
F
.59297 .87228 m .59553 .86916 L .56453 .87294 L F
.59428 .48799 m .57969 .49064 L .58003 .49331 L .518 .172 0 r
F
.59428 .48799 m .59389 .48533 L .57969 .49064 L F
.50003 .36376 m .49927 .36076 L .48979 .36381 L 1 .84 0 r
F
.50958 .36039 m .49927 .36076 L .50003 .36376 L .965 .745 0 r
F
.51054 .36348 m .50958 .36039 L .50003 .36376 L .952 .757 0 r
F
.28418 .83907 m .25009 .82835 L .25333 .83266 L .997 .079 0 r
F
.287 .84315 m .28418 .83907 L .25333 .83266 L .977 .076 0 r
F
.56442 .56246 m .54715 .56359 L .54687 .56597 L .641 .082 0 r
F
.56442 .56246 m .56477 .56006 L .54715 .56359 L F
.73401 .59427 m .71517 .60036 L .71411 .60474 L .188 0 0 r
F
.73401 .59427 m .73523 .58981 L .71517 .60036 L F
.50677 .59285 m .48792 .59178 L .4878 .5939 L .851 .191 0 r
F
.50677 .59285 m .50702 .59073 L .48792 .59178 L F
.66111 .47737 m .65139 .4825 L .65067 .48598 L 0 0 0 r
F
.66111 .47737 m .6619 .47389 L .65139 .4825 L F
.75584 .16841 m .74913 .18024 L .75469 .18483 L .196 .153 0 r
F
.75584 .16841 m .75034 .16394 L .74913 .18024 L F
.583 .53831 m .56659 .54023 L .56646 .54277 L .573 .087 0 r
F
.583 .53831 m .58316 .53576 L .56659 .54023 L F
.54429 .57368 m .52663 .57419 L .52634 .57639 L .705 .096 0 r
F
.54429 .57368 m .54468 .57146 L .52663 .57419 L F
.37792 .61031 m .35763 .60283 L .35825 .60562 L 1 .501 0 r
F
.37849 .613 m .37792 .61031 L .35825 .60562 L 1 .484 0 r
F
.70193 .27135 m .70661 .26815 L .70749 .27506 L .95 .146 0 r
F
.70193 .27135 m .70053 .26523 L .70661 .26815 L F
.59648 .59206 m .57988 .5956 L .57901 .59804 L .347 .016 0 r
F
.59648 .59206 m .59749 .5896 L .57988 .5956 L F
.59714 .49617 m .58209 .49886 L .58237 .50155 L .52 .155 0 r
F
.59714 .49617 m .59682 .49348 L .58209 .49886 L F
.53604 .3694 m .52508 .37055 L .52627 .37332 L .792 .63 0 r
F
.5374 .37216 m .53604 .3694 L .52627 .37332 L .786 .636 0 r
F
.39087 .54858 m .37359 .54204 L .37375 .54452 L 1 .689 0 r
F
.39102 .55102 m .39087 .54858 L .37375 .54452 L 1 .676 0 r
F
.08697 .58662 m .06367 .56265 L .06408 .56947 L 1 .692 0 r
F
.08747 .5933 m .08697 .58662 L .06408 .56947 L 1 .67 0 r
F
.55983 .39114 m .54818 .39298 L .54948 .39553 L .66 .548 0 r
F
.56128 .39365 m .55983 .39114 L .54948 .39553 L .657 .543 0 r
F
.80882 .72474 m .78576 .73151 L .78313 .73707 L .114 0 0 r
F
.80882 .72474 m .81169 .71901 L .78576 .73151 L F
.50641 .58885 m .48776 .58784 L .48764 .58989 L .847 .181 0 r
F
.50641 .58885 m .50666 .5868 L .48776 .58784 L F
.40917 .57557 m .3897 .57092 L .39005 .57328 L 1 .526 0 r
F
.40943 .5779 m .40917 .57557 L .39005 .57328 L 1 .514 0 r
F
.64133 .52776 m .62861 .53279 L .6279 .5358 L .155 0 0 r
F
.64133 .52776 m .6421 .52474 L .62861 .53279 L F
.56169 .3971 m .55002 .39885 L .55128 .40136 L .637 .53 0 r
F
.56309 .39957 m .56169 .3971 L .55128 .40136 L .634 .523 0 r
F
.32459 .86587 m .28985 .85722 L .29292 .86107 L .915 .065 0 r
F
.32713 .86951 m .32459 .86587 L .29292 .86107 L .893 .061 0 r
F
.76116 .79048 m .73595 .79482 L .73285 .79977 L .213 0 0 r
F
.76116 .79048 m .76464 .78536 L .73595 .79482 L F
.35806 .28334 m .35533 .27252 L .35779 .28577 L .817 .137 0 r
F
.36127 .29731 m .35806 .28334 L .35779 .28577 L .778 .119 0 r
F
.52101 .36303 m .51054 .36348 L .51152 .36643 L .871 .675 0 r
F
.52219 .36598 m .52101 .36303 L .51152 .36643 L .862 .686 0 r
F
.2379 .81027 m .20453 .79713 L .20779 .80201 L 1 .127 0 r
F
.24084 .81491 m .2379 .81027 L .20779 .80201 L 1 .101 0 r
F
.35029 .49718 m .33485 .48832 L .33453 .49117 L 1 .89 0 r
F
.35007 .5 m .35029 .49718 L .33453 .49117 L 1 .88 0 r
F
.43001 .57963 m .41119 .57515 L .41148 .57735 L 1 .463 0 r
F
.43022 .58179 m .43001 .57963 L .41148 .57735 L 1 .449 0 r
F
.70186 .35452 m .69909 .3578 L .69752 .36406 L 0 0 0 r
F
.70186 .35452 m .70318 .34841 L .69909 .3578 L F
.52047 .3584 m .50988 .35946 L .51082 .36264 L .913 .662 0 r
F
.52159 .36166 m .52047 .3584 L .51082 .36264 L .904 .68 0 r
F
.39319 .37778 m .38762 .37377 L .38551 .37576 L 1 1 0 r
F
.39319 .37778 m .39508 .37561 L .38762 .37377 L F
.33339 .82411 m .29887 .81982 L .30147 .82374 L .972 .084 0 r
F
.33548 .82792 m .33339 .82411 L .30147 .82374 L .958 .077 0 r
F
.33394 .54297 m .31819 .53278 L .31812 .53591 L 1 .844 0 r
F
.33393 .54608 m .33394 .54297 L .31812 .53591 L 1 .831 0 r
F
.56322 .55874 m .54628 .56 L .546 .56234 L .632 .075 0 r
F
.56322 .55874 m .56356 .55639 L .54628 .56 L F
.41419 .36903 m .40866 .36691 L .40676 .36881 L 1 1 0 r
F
.41419 .36903 m .41584 .36692 L .40866 .36691 L F
.49937 .36036 m .48927 .36097 L .48979 .36381 L 1 .844 0 r
F
.49927 .36076 m .48927 .36097 L .48979 .36381 L 1 .833 0 r
F
.75503 .16929 m .74825 .18119 L .75387 .18568 L .228 .221 0 r
F
.75503 .16929 m .74926 .16516 L .74825 .18119 L F
.53659 .3735 m .52577 .3743 L .52697 .37695 L .755 .631 0 r
F
.53797 .37611 m .53659 .3735 L .52697 .37695 L .751 .633 0 r
F
.09559 .57761 m .07085 .55445 L .07134 .56111 L 1 .703 0 r
F
.09618 .58409 m .09559 .57761 L .07134 .56111 L 1 .682 0 r
F
.71246 .82785 m .68638 .83086 L .68324 .83519 L .273 0 0 r
F
.71246 .82785 m .71607 .82338 L .68638 .83086 L F
.59464 .49064 m .58003 .49331 L .58035 .49596 L .513 .16 0 r
F
.59464 .49064 m .59428 .48799 L .58003 .49331 L F
.53063 .63328 m .51099 .63431 L .51053 .6363 L .597 .041 0 r
F
.53063 .63328 m .53133 .63131 L .51099 .63431 L F
.36775 .53758 m .3498 .53028 L .34996 .53295 L 1 .713 0 r
F
.36792 .54018 m .36775 .53758 L .34996 .53295 L 1 .704 0 r
F
.37354 .51659 m .35807 .50904 L .35789 .51165 L 1 .849 0 r
F
.37342 .51919 m .37354 .51659 L .35789 .51165 L 1 .839 0 r
F
.49549 .33549 m .49526 .32768 L .48647 .33843 L 1 .681 0 r
F
.76214 .40405 m .75777 .41122 L .75838 .41649 L 0 0 0 r
F
.76214 .40405 m .76115 .399 L .75777 .41122 L F
.43228 .35137 m .42769 .35303 L .42596 .3549 L .892 .68 0 r
F
.43228 .35137 m .43372 .34914 L .42769 .35303 L F
.69859 .65105 m .67866 .6558 L .67724 .65985 L .244 0 0 r
F
.69859 .65105 m .7003 .64701 L .67866 .6558 L F
.38999 .38724 m .38317 .3819 L .38106 .38387 L 1 1 0 r
F
.38999 .38724 m .39179 .38503 L .38317 .3819 L F
.4104 .56839 m .39215 .56292 L .39244 .56524 L 1 .56 0 r
F
.41065 .57067 m .4104 .56839 L .39244 .56524 L 1 .546 0 r
F
.49937 .36036 m .49863 .35716 L .48927 .36097 L 1 .844 0 r
F
.50896 .35607 m .49863 .35716 L .49937 .36036 L 1 .735 0 r
F
.50988 .35946 m .50896 .35607 L .49937 .36036 L .992 .753 0 r
F
.43295 .88363 m .39956 .87928 L .40098 .88229 L .731 .038 0 r
F
.43371 .88649 m .43295 .88363 L .40098 .88229 L .708 .034 0 r
F
.4654 .88679 m .43295 .88363 L .43371 .88649 L .658 .028 0 r
F
.35458 .58563 m .336 .57666 L .33642 .57964 L 1 .649 0 r
F
.35501 .58855 m .35458 .58563 L .33642 .57964 L 1 .633 0 r
F
.85902 .63711 m .83808 .64633 L .83646 .65263 L .036 0 0 r
F
.85902 .63711 m .86077 .63066 L .83808 .64633 L F
.86989 .32878 m .85637 .34303 L .85944 .34944 L .082 .049 0 r
F
.86989 .32878 m .86667 .32245 L .85637 .34303 L F
.46805 .64343 m .46804 .64142 L .44658 .64151 L .866 .073 0 r
F
.48909 .64228 m .46804 .64142 L .46805 .64343 L .78 .062 0 r
F
.48909 .64228 m .48932 .64033 L .46804 .64142 L F
.3885 .56127 m .36943 .55549 L .36976 .55798 L 1 .601 0 r
F
.38877 .56371 m .3885 .56127 L .36976 .55798 L 1 .591 0 r
F
.58135 .53487 m .56534 .53687 L .56521 .53937 L .561 .079 0 r
F
.58135 .53487 m .5815 .53235 L .56534 .53687 L F
.66373 .6909 m .64352 .69545 L .64199 .69929 L .267 0 0 r
F
.66373 .6909 m .66564 .68717 L .64352 .69545 L F
.39956 .87928 m .36574 .87367 L .36777 .87687 L .791 .047 0 r
F
.40098 .88229 m .39956 .87928 L .36777 .87687 L .768 .042 0 r
F
.62786 .86109 m .60052 .86262 L .59805 .86594 L .36 0 0 r
F
.62786 .86109 m .63092 .85768 L .60052 .86262 L F
.55837 .38863 m .54687 .39043 L .54818 .39298 L .663 .553 0 r
F
.55983 .39114 m .55837 .38863 L .54818 .39298 L .66 .548 0 r
F
.44917 .59172 m .4297 .58856 L .42993 .59076 L 1 .382 0 r
F
.44929 .59388 m .44917 .59172 L .42993 .59076 L 1 .366 0 r
F
.46856 .59422 m .44917 .59172 L .44929 .59388 L .979 .317 0 r
F
.56026 .39464 m .54874 .39634 L .55002 .39885 L .639 .537 0 r
F
.56169 .3971 m .56026 .39464 L .55002 .39885 L .637 .53 0 r
F
.59742 .49886 m .58237 .50155 L .58262 .50423 L .515 .143 0 r
F
.59742 .49886 m .59714 .49617 L .58237 .50155 L F
.40159 .6268 m .38036 .62089 L .38103 .62346 L 1 .367 0 r
F
.40215 .62925 m .40159 .6268 L .38103 .62346 L 1 .348 0 r
F
.47101 .37053 m .46204 .36916 L .46169 .37141 L 1 1 0 r
F
.47101 .37053 m .47106 .36816 L .46204 .36916 L F
.18686 .76631 m .15501 .75018 L .15794 .75573 L 1 .258 0 r
F
.18958 .77162 m .18686 .76631 L .15794 .75573 L 1 .23 0 r
F
.6315 .72129 m .61098 .7265 L .60949 .73024 L .274 0 0 r
F
.6315 .72129 m .63341 .71777 L .61098 .7265 L F
.41739 .35878 m .41282 .35805 L .41079 .35982 L .92 .927 0 r
F
.41739 .35878 m .41918 .35679 L .41282 .35805 L F
.53469 .36656 m .5239 .3677 L .52508 .37055 L .798 .622 0 r
F
.53604 .3694 m .53469 .36656 L .52508 .37055 L .792 .63 0 r
F
.42949 .58633 m .41 .5825 L .41032 .58476 L 1 .448 0 r
F
.4297 .58856 m .42949 .58633 L .41032 .58476 L 1 .434 0 r
F
.49927 .36076 m .49853 .3576 L .48927 .36097 L 1 .833 0 r
F
.50864 .35711 m .49853 .3576 L .49927 .36076 L .978 .729 0 r
F
.50958 .36039 m .50864 .35711 L .49927 .36076 L .965 .745 0 r
F
.42442 .63613 m .40274 .63166 L .40334 .63405 L 1 .253 0 r
F
.42486 .63838 m .42442 .63613 L .40334 .63405 L 1 .234 0 r
F
.48033 .3664 m .47111 .36577 L .47106 .36816 L 1 1 0 r
F
.48033 .3664 m .48008 .36382 L .47111 .36577 L F
.68044 .42192 m .67397 .42652 L .67271 .43099 L 0 0 0 r
F
.68044 .42192 m .6818 .41741 L .67397 .42652 L F
.46856 .59633 m .46856 .59422 L .44929 .59388 L .974 .302 0 r
F
.48767 .59599 m .46856 .59422 L .46856 .59633 L .914 .243 0 r
F
.48767 .59599 m .4878 .5939 L .46856 .59422 L F
.5194 .3549 m .50896 .35607 L .50988 .35946 L .923 .639 0 r
F
.52047 .3584 m .5194 .3549 L .50988 .35946 L .913 .662 0 r
F
.59496 .49329 m .58035 .49596 L .58063 .49862 L .508 .147 0 r
F
.59496 .49329 m .59464 .49064 L .58035 .49596 L F
.40433 .83344 m .37127 .83358 L .37293 .83714 L .834 .065 0 r
F
.40544 .83695 m .40433 .83344 L .37293 .83714 L .818 .062 0 r
F
.43615 .83131 m .40433 .83344 L .40544 .83695 L .755 .057 0 r
F
.35007 .5 m .33453 .49117 L .33425 .49402 L 1 .88 0 r
F
.34989 .50282 m .35007 .5 L .33425 .49402 L 1 .87 0 r
F
.58281 .54085 m .56646 .54277 L .5663 .54529 L .567 .075 0 r
F
.58281 .54085 m .583 .53831 L .56646 .54277 L F
.66608 .84441 m .63975 .84688 L .63687 .85058 L .308 0 0 r
F
.66608 .84441 m .6695 .8406 L .63975 .84688 L F
.52559 .58892 m .50725 .58859 L .50702 .59073 L .778 .13 0 r
F
.52559 .58892 m .52595 .58677 L .50725 .58859 L F
.51986 .35992 m .50958 .36039 L .51054 .36348 L .88 .659 0 r
F
.52101 .36303 m .51986 .35992 L .51054 .36348 L .871 .675 0 r
F
.89107 .50535 m .87336 .51733 L .87353 .52412 L 0 0 0 r
F
.89107 .50535 m .89097 .49847 L .87336 .51733 L F
.57421 .76852 m .55173 .77563 L .55059 .7793 L .311 0 0 r
F
.57421 .76852 m .57576 .7651 L .55173 .77563 L F
.4909 .34481 m .48685 .34348 L .48729 .34774 L 1 .727 0 r
F
.49607 .34063 m .49352 .34142 L .4909 .34481 L F
.49352 .34142 m .48685 .34348 L .4909 .34481 L F
.49661 .34565 m .49607 .34063 L .48729 .34774 L 1 .763 0 r
F
.5051 .33328 m .49867 .33476 L .49592 .34146 L 1 .561 0 r
F
.49867 .33476 m .49549 .33549 L .49571 .33858 L F
.49867 .33476 m .49571 .33858 L .49592 .34146 L F
.50552 .33988 m .5051 .33328 L .49592 .34146 L 1 .603 0 r
F
.1332 .69764 m .10429 .67783 L .10637 .6841 L 1 .439 0 r
F
.13521 .70369 m .1332 .69764 L .10637 .6841 L 1 .413 0 r
F
.5352 .37084 m .52457 .3716 L .52577 .3743 L .76 .626 0 r
F
.53659 .3735 m .5352 .37084 L .52577 .3743 L .755 .631 0 r
F
.86796 .32952 m .85437 .34375 L .85729 .35017 L .077 .046 0 r
F
.86796 .32952 m .86491 .32316 L .85437 .34375 L F
.64698 .09859 m .64302 .10718 L .64976 .10974 L .374 .532 0 r
F
.64698 .09859 m .64025 .09654 L .64302 .10718 L F
.37342 .51919 m .35789 .51165 L .35775 .51425 L 1 .839 0 r
F
.37333 .52177 m .37342 .51919 L .35775 .51425 L 1 .829 0 r
F
.55881 .39218 m .54744 .39383 L .54874 .39634 L .641 .543 0 r
F
.56026 .39464 m .55881 .39218 L .54874 .39634 L .639 .537 0 r
F
.55689 .38612 m .54554 .38788 L .54687 .39043 L .667 .557 0 r
F
.55837 .38863 m .55689 .38612 L .54687 .39043 L .663 .553 0 r
F
.61881 .5671 m .60389 .57147 L .60305 .57415 L .264 .005 0 r
F
.61881 .5671 m .61975 .56439 L .60389 .57147 L F
.56404 .56483 m .54687 .56597 L .54657 .56833 L .636 .072 0 r
F
.56404 .56483 m .56442 .56246 L .54687 .56597 L F
.44948 .58744 m .43044 .58392 L .43068 .58602 L 1 .373 0 r
F
.44961 .58951 m .44948 .58744 L .43068 .58602 L 1 .358 0 r
F
.46861 .59011 m .44948 .58744 L .44961 .58951 L .983 .307 0 r
F
.54473 .57977 m .52692 .58016 L .52661 .58239 L .707 .09 0 r
F
.54473 .57977 m .54514 .57753 L .52692 .58016 L F
.57332 .61195 m .55562 .61466 L .5548 .61687 L .407 .022 0 r
F
.57332 .61195 m .57433 .60972 L .55562 .61466 L F
.39102 .55102 m .37375 .54452 L .37394 .54697 L 1 .676 0 r
F
.3912 .55344 m .39102 .55102 L .37394 .54697 L 1 .664 0 r
F
.52501 .58495 m .5069 .58471 L .50666 .5868 L .773 .121 0 r
F
.52501 .58495 m .52537 .58285 L .5069 .58471 L F
.33489 .45238 m .32491 .44289 L .3236 .44577 L 1 1 0 r
F
.33374 .45536 m .33489 .45238 L .3236 .44577 L F
.46861 .59213 m .46861 .59011 L .44961 .58951 L .978 .291 0 r
F
.48751 .59191 m .46861 .59011 L .46861 .59213 L .913 .232 0 r
F
.48751 .59191 m .48764 .58989 L .46861 .59011 L F
.59767 .50154 m .58262 .50423 L .58283 .5069 L .51 .13 0 r
F
.59767 .50154 m .59742 .49886 L .58262 .50423 L F
.76111 .51682 m .74619 .52492 L .74575 .5297 L .058 0 0 r
F
.76111 .51682 m .76148 .51198 L .74619 .52492 L F
.49863 .35716 m .49583 .3574 L .495 .35863 L 1 .833 0 r
F
.49863 .35716 m .49791 .35371 L .48875 .358 L F
.50808 .35238 m .49791 .35371 L .49863 .35716 L 1 .712 0 r
F
.50896 .35607 m .50808 .35238 L .49863 .35716 L 1 .735 0 r
F
.50775 .35356 m .49798 .35421 L .49853 .3576 L .991 .706 0 r
F
.49798 .35421 m .49781 .35422 L .49785 .3544 L F
.49798 .35421 m .49785 .3544 L .49853 .3576 L F
.495 .35863 m .48875 .358 L .48927 .36097 L 1 .833 0 r
F
.49583 .3574 m .48875 .358 L .495 .35863 L F
.39508 .37561 m .38974 .37182 L .38762 .37377 L 1 1 0 r
F
.39508 .37561 m .39699 .37349 L .38974 .37182 L F
.76124 .17297 m .75469 .18483 L .76016 .1895 L .175 .12 0 r
F
.76124 .17297 m .75584 .16841 L .75469 .18483 L F
.52122 .80434 m .49503 .81114 L .49459 .81472 L .433 .02 0 r
F
.52122 .80434 m .5221 .80086 L .49503 .81114 L F
.33393 .54608 m .31812 .53591 L .31808 .53903 L 1 .831 0 r
F
.33397 .54919 m .33393 .54608 L .31808 .53903 L 1 .818 0 r
F
.33374 .45536 m .3236 .44577 L .32233 .44867 L 1 1 0 r
F
.33263 .45835 m .33374 .45536 L .32233 .44867 L F
.39179 .38503 m .38531 .38 L .38317 .3819 L F
.39179 .38503 m .39361 .38287 L .38531 .38 L F
.70823 .1721 m .70354 .18012 L .70757 .18588 L 0 .041 0 r
F
.70823 .1721 m .70441 .16618 L .70354 .18012 L F
.7233 .29559 m .73828 .28778 L .73949 .29416 L 1 .668 0 r
F
.7233 .29559 m .72261 .28937 L .73828 .28778 L F
.86549 .64704 m .84302 .65572 L .84137 .66215 L .076 0 0 r
F
.86549 .64704 m .86728 .64044 L .84302 .65572 L F
.54388 .57588 m .52634 .57639 L .52603 .57857 L .7 .083 0 r
F
.54388 .57588 m .54429 .57368 L .52634 .57639 L F
.53335 .36362 m .52273 .36475 L .5239 .3677 L .805 .61 0 r
F
.53469 .36656 m .53335 .36362 L .5239 .3677 L .798 .622 0 r
F
.5184 .35106 m .50808 .35238 L .50896 .35607 L .931 .61 0 r
F
.5194 .3549 m .5184 .35106 L .50896 .35607 L .923 .639 0 r
F
.49853 .3576 m .48875 .358 L .48927 .36097 L 1 .822 0 r
F
.36792 .54018 m .34996 .53295 L .35015 .53561 L 1 .704 0 r
F
.36812 .54277 m .36792 .54018 L .35015 .53561 L 1 .694 0 r
F
.59525 .49594 m .58063 .49862 L .58088 .50127 L .504 .135 0 r
F
.59525 .49594 m .59496 .49329 L .58063 .49862 L F
.66032 .48081 m .65067 .48598 L .64995 .48942 L 0 0 0 r
F
.66032 .48081 m .66111 .47737 L .65067 .48598 L F
.40943 .5779 m .39005 .57328 L .39043 .57563 L 1 .514 0 r
F
.40971 .58021 m .40943 .5779 L .39043 .57563 L 1 .501 0 r
F
.58117 .53737 m .56521 .53937 L .56506 .54185 L .556 .072 0 r
F
.58117 .53737 m .58135 .53487 L .56521 .53937 L F
.56285 .56108 m .546 .56234 L .5457 .56465 L .626 .071 0 r
F
.56285 .56108 m .56322 .55874 L .546 .56234 L F
.50651 .59494 m .4878 .5939 L .48767 .59599 L .845 .175 0 r
F
.50651 .59494 m .50677 .59285 L .4878 .5939 L F
.33263 .45835 m .32233 .44867 L .32111 .45158 L 1 1 0 r
F
.33156 .46135 m .33263 .45835 L .32111 .45158 L F
.54241 .29798 m .54493 .28046 L .5508 .26205 L 1 .648 0 r
F
.54825 .27011 m .56702 .20437 L .55911 .24182 L 1 .87 0 r
F
.54825 .27011 m .55497 .23791 L .56702 .20437 L F
.81298 .73574 m .78895 .74186 L .78625 .74752 L .142 0 0 r
F
.81298 .73574 m .81594 .7299 L .78895 .74186 L F
.41584 .36692 m .41056 .36503 L .40866 .36691 L 1 1 0 r
F
.41584 .36692 m .4175 .36484 L .41056 .36503 L F
.76072 .17352 m .75387 .18568 L .75942 .19025 L .219 .201 0 r
F
.76072 .17352 m .75503 .16929 L .75387 .18568 L F
.55134 .62534 m .53269 .62723 L .53202 .62929 L .497 .03 0 r
F
.55134 .62534 m .55223 .62328 L .53269 .62723 L F
.56024 .88914 m .53063 .88859 L .5293 .89153 L .462 .004 0 r
F
.56024 .88914 m .56226 .88615 L .53063 .88859 L F
.55734 .38972 m .54613 .39132 L .54744 .39383 L .644 .548 0 r
F
.55881 .39218 m .55734 .38972 L .54744 .39383 L .641 .543 0 r
F
.89878 .5128 m .87938 .52475 L .87961 .53166 L .036 0 0 r
F
.89878 .5128 m .89852 .50579 L .87938 .52475 L F
.49853 .3576 m .49781 .35422 L .48875 .358 L 1 .822 0 r
F
.50864 .35711 m .50775 .35356 L .49853 .3576 L .978 .729 0 r
F
.5554 .3836 m .5442 .38531 L .54554 .38788 L .67 .561 0 r
F
.55689 .38612 m .5554 .3836 L .54554 .38788 L .667 .557 0 r
F
.64055 .53076 m .6279 .5358 L .62718 .53879 L .151 0 0 r
F
.64055 .53076 m .64133 .52776 L .6279 .5358 L F
.50958 .64016 m .48932 .64033 L .48909 .64228 L .681 .049 0 r
F
.50958 .64016 m .51006 .63825 L .48932 .64033 L F
.43022 .58179 m .41148 .57735 L .4118 .57953 L 1 .449 0 r
F
.43044 .58392 m .43022 .58179 L .4118 .57953 L 1 .434 0 r
F
.65253 .20809 m .67232 .17809 L .67514 .18546 L 1 .933 0 r
F
.65253 .20809 m .65447 .19467 L .67232 .17809 L F
.51875 .35661 m .50864 .35711 L .50958 .36039 L .889 .638 0 r
F
.51986 .35992 m .51875 .35661 L .50958 .36039 L .88 .659 0 r
F
.34989 .50282 m .33425 .49402 L .33401 .49686 L 1 .87 0 r
F
.34974 .50562 m .34989 .50282 L .33401 .49686 L 1 .86 0 r
F
.50615 .59088 m .48764 .58989 L .48751 .59191 L .842 .166 0 r
F
.50615 .59088 m .50641 .58885 L .48764 .58989 L F
.41065 .57067 m .39244 .56524 L .39276 .56754 L 1 .546 0 r
F
.41091 .57292 m .41065 .57067 L .39276 .56754 L 1 .532 0 r
F
.53382 .36812 m .52337 .36883 L .52457 .3716 L .764 .619 0 r
F
.5352 .37084 m .53382 .36812 L .52457 .3716 L .76 .626 0 r
F
.44658 .64151 m .42486 .63838 L .42532 .64059 L .954 .147 0 r
F
.44683 .64359 m .44658 .64151 L .42532 .64059 L .943 .127 0 r
F
.46805 .64343 m .44658 .64151 L .44683 .64359 L .866 .073 0 r
F
.33156 .46135 m .32111 .45158 L .31993 .45452 L 1 1 0 r
F
.33053 .46437 m .33156 .46135 L .31993 .45452 L F
.38877 .56371 m .36976 .55798 L .37012 .56045 L 1 .591 0 r
F
.38906 .56613 m .38877 .56371 L .37012 .56045 L 1 .581 0 r
F
.50808 .35238 m .50728 .34826 L .49791 .35371 L 1 .712 0 r
F
.37849 .613 m .35825 .60562 L .35891 .60838 L 1 .484 0 r
F
.37908 .61565 m .37849 .613 L .35891 .60838 L 1 .467 0 r
F
.37333 .52177 m .35775 .51425 L .35764 .51685 L 1 .829 0 r
F
.37326 .52435 m .37333 .52177 L .35764 .51685 L 1 .818 0 r
F
.12793 .70852 m .09794 .68879 L .10027 .69512 L 1 .406 0 r
F
.13015 .71461 m .12793 .70852 L .10027 .69512 L 1 .379 0 r
F
.32694 .85969 m .29283 .85105 L .29584 .85486 L .916 .065 0 r
F
.32945 .86328 m .32694 .85969 L .29584 .85486 L .894 .061 0 r
F
.59788 .50421 m .58283 .5069 L .58302 .50957 L .505 .118 0 r
F
.59788 .50421 m .59767 .50154 L .58283 .5069 L F
.76308 .40909 m .75838 .41649 L .75894 .42172 L 0 0 0 r
F
.76308 .40909 m .76214 .40405 L .75838 .41649 L F
.50728 .34826 m .49724 .34993 L .49791 .35371 L 1 .682 0 r
F
.49791 .35371 m .49517 .35404 L .4941 .3555 L 1 .816 0 r
F
.49791 .35371 m .49724 .34993 L .48825 .35486 L F
.5069 .34964 m .4978 .35045 L .49781 .35422 L 1 .678 0 r
F
.4978 .35045 m .49712 .35051 L .49725 .3512 L F
.4978 .35045 m .49725 .3512 L .49781 .35422 L F
.4941 .3555 m .48825 .35486 L .48875 .358 L 1 .816 0 r
F
.49517 .35404 m .48825 .35486 L .4941 .3555 L F
.43372 .34914 m .42944 .3512 L .42769 .35303 L .812 .524 0 r
F
.43372 .34914 m .43517 .34694 L .42944 .3512 L F
.35501 .58855 m .33642 .57964 L .33687 .58261 L 1 .633 0 r
F
.35547 .59145 m .35501 .58855 L .33687 .58261 L 1 .618 0 r
F
.58259 .54338 m .5663 .54529 L .56611 .5478 L .562 .072 0 r
F
.58259 .54338 m .58281 .54085 L .5663 .54529 L F
.59544 .5945 m .57901 .59804 L .57812 .60045 L .341 .013 0 r
F
.59544 .5945 m .59648 .59206 L .57901 .59804 L F
.14366 .68388 m .11343 .66577 L .11549 .67181 L 1 .464 0 r
F
.14563 .68967 m .14366 .68388 L .11549 .67181 L 1 .441 0 r
F
.73273 .5987 m .71411 .60474 L .71298 .6091 L .18 0 0 r
F
.73273 .5987 m .73401 .59427 L .71411 .60474 L F
.53204 .36054 m .52159 .36166 L .52273 .36475 L .811 .593 0 r
F
.53335 .36362 m .53204 .36054 L .52273 .36475 L .805 .61 0 r
F
.5955 .49858 m .58088 .50127 L .58111 .50391 L .499 .123 0 r
F
.5955 .49858 m .59525 .49594 L .58088 .50127 L F
.33053 .46437 m .31993 .45452 L .3188 .45747 L 1 1 0 r
F
.32954 .46741 m .33053 .46437 L .3188 .45747 L F
.87299 .33517 m .85944 .34944 L .86239 .35589 L .073 .046 0 r
F
.87299 .33517 m .86989 .32878 L .85944 .34944 L F
.47106 .36816 m .46241 .36692 L .46204 .36916 L 1 1 0 r
F
.47106 .36816 m .47111 .36577 L .46241 .36692 L F
.75526 .78417 m .7311 .78906 L .728 .79385 L .183 0 0 r
F
.75526 .78417 m .75873 .77922 L .7311 .78906 L F
.19767 .74781 m .16471 .73421 L .1675 .73954 L 1 .307 0 r
F
.20022 .75289 m .19767 .74781 L .1675 .73954 L 1 .284 0 r
F
.70316 .27746 m .70749 .27506 L .70813 .28197 L .911 .147 0 r
F
.70316 .27746 m .70193 .27135 L .70749 .27506 L F
.55585 .38727 m .5448 .38881 L .54613 .39132 L .646 .553 0 r
F
.55734 .38972 m .55585 .38727 L .54613 .39132 L .644 .548 0 r
F
.44929 .59388 m .42993 .59076 L .43017 .59293 L 1 .366 0 r
F
.44942 .596 m .44929 .59388 L .43017 .59293 L 1 .35 0 r
F
.46856 .59633 m .44929 .59388 L .44942 .596 L .974 .302 0 r
F
.55389 .38106 m .54285 .38274 L .5442 .38531 L .674 .563 0 r
F
.5554 .3836 m .55389 .38106 L .5442 .38531 L .67 .561 0 r
F
.24832 .7873 m .21416 .77741 L .21718 .78213 L 1 .201 0 r
F
.25098 .79181 m .24832 .7873 L .21718 .78213 L 1 .178 0 r
F
.48008 .36382 m .47116 .36337 L .47111 .36577 L 1 1 0 r
F
.48008 .36382 m .47983 .36118 L .47116 .36337 L F
.41918 .35679 m .41486 .35633 L .41282 .35805 L .869 .849 0 r
F
.41918 .35679 m .42097 .35485 L .41486 .35633 L F
.49549 .33549 m .48647 .33843 L .48685 .34348 L 1 .681 0 r
F
.49592 .34146 m .49549 .33549 L .48685 .34348 L 1 .72 0 r
F
.07815 .60305 m .05323 .57896 L .05401 .58592 L 1 .642 0 r
F
.07899 .60983 m .07815 .60305 L .05401 .58592 L 1 .619 0 r
F
.3912 .55344 m .37394 .54697 L .37416 .54941 L 1 .664 0 r
F
.3914 .55584 m .3912 .55344 L .37416 .54941 L 1 .651 0 r
F
.4297 .58856 m .41032 .58476 L .41065 .587 L 1 .434 0 r
F
.42993 .59076 m .4297 .58856 L .41065 .587 L 1 .419 0 r
F
.70765 .82093 m .68246 .82447 L .67933 .82863 L .248 0 0 r
F
.70765 .82093 m .71125 .81663 L .68246 .82447 L F
.6011 .74795 m .58007 .75434 L .57869 .75801 L .271 0 0 r
F
.6011 .74795 m .6029 .74455 L .58007 .75434 L F
.51769 .35303 m .50775 .35356 L .50864 .35711 L .898 .61 0 r
F
.51875 .35661 m .51769 .35303 L .50864 .35711 L .889 .638 0 r
F
.39361 .38287 m .38748 .37816 L .38531 .38 L 1 1 0 r
F
.39361 .38287 m .39545 .38075 L .38748 .37816 L F
.46537 .89635 m .4653 .89353 L .43309 .89312 L .647 .026 0 r
F
.49686 .89582 m .4653 .89353 L .46537 .89635 L .59 .019 0 r
F
.49686 .89582 m .49751 .893 L .4653 .89353 L F
.39699 .37349 m .39188 .36991 L .38974 .37182 L 1 1 0 r
F
.39699 .37349 m .39892 .3714 L .39188 .36991 L F
.18419 .77719 m .15162 .76128 L .15476 .76683 L 1 .224 0 r
F
.18709 .78249 m .18419 .77719 L .15476 .76683 L 1 .196 0 r
F
.49724 .34993 m .49661 .34565 L .48776 .35147 L 1 .793 0 r
F
.49213 .3486 m .48729 .34774 L .48776 .35147 L 1 .763 0 r
F
.49661 .34565 m .494 .34624 L .49213 .3486 L F
.494 .34624 m .48729 .34774 L .49213 .3486 L F
.50552 .33988 m .49805 .34111 L .49648 .34633 L 1 .603 0 r
F
.49805 .34111 m .49592 .34146 L .49616 .3435 L F
.49805 .34111 m .49616 .3435 L .49648 .34633 L F
.50614 .34517 m .50552 .33988 L .49648 .34633 L 1 .643 0 r
F
.49781 .35422 m .48825 .35486 L .48875 .358 L 1 .807 0 r
F
.49781 .35422 m .49712 .35051 L .48825 .35486 L F
.50775 .35356 m .5069 .34964 L .49781 .35422 L .991 .706 0 r
F
.32954 .46741 m .3188 .45747 L .3177 .46044 L 1 1 0 r
F
.32859 .47045 m .32954 .46741 L .3177 .46044 L F
.33397 .54919 m .31808 .53903 L .31808 .54215 L 1 .818 0 r
F
.33404 .55228 m .33397 .54919 L .31808 .54215 L 1 .805 0 r
F
.43671 .83476 m .43615 .83131 L .40544 .83695 L .737 .053 0 r
F
.46611 .82731 m .43615 .83131 L .43671 .83476 L .652 .045 0 r
F
.46611 .82731 m .46607 .82382 L .43615 .83131 L F
.56364 .56719 m .54657 .56833 L .54624 .57066 L .63 .071 0 r
F
.56364 .56719 m .56404 .56483 L .54657 .56833 L F
.49724 .34993 m .49455 .35036 L .49316 .35216 L 1 .793 0 r
F
.50614 .34517 m .4978 .34618 L .49712 .35051 L 1 .643 0 r
F
.4978 .34618 m .49648 .34633 L .49668 .34762 L F
.4978 .34618 m .49668 .34762 L .49712 .35051 L F
.49316 .35216 m .48776 .35147 L .48825 .35486 L 1 .793 0 r
F
.49455 .35036 m .48776 .35147 L .49316 .35216 L F
.29384 .81175 m .25937 .80492 L .26231 .80916 L 1 .127 0 r
F
.29633 .81582 m .29384 .81175 L .26231 .80916 L 1 .104 0 r
F
.49414 .81818 m .46607 .82382 L .46611 .82731 L .542 .033 0 r
F
.49414 .81818 m .49459 .81472 L .46607 .82382 L F
.53245 .36533 m .52219 .36598 L .52337 .36883 L .769 .609 0 r
F
.53382 .36812 m .53245 .36533 L .52337 .36883 L .764 .619 0 r
F
.08747 .5933 m .06408 .56947 L .0646 .57628 L 1 .67 0 r
F
.08809 .59995 m .08747 .5933 L .0646 .57628 L 1 .646 0 r
F
.34974 .50562 m .33401 .49686 L .33381 .4997 L 1 .86 0 r
F
.34962 .50841 m .34974 .50562 L .33381 .4997 L 1 .85 0 r
F
.58096 .53985 m .56506 .54185 L .56487 .54432 L .551 .071 0 r
F
.58096 .53985 m .58117 .53737 L .56506 .54185 L F
.46857 .59841 m .46856 .59633 L .44942 .596 L .969 .285 0 r
F
.48754 .59806 m .46856 .59633 L .46857 .59841 L .908 .227 0 r
F
.48754 .59806 m .48767 .59599 L .46856 .59633 L F
.52522 .59104 m .50702 .59073 L .50677 .59285 L .772 .115 0 r
F
.52522 .59104 m .52559 .58892 L .50702 .59073 L F
.59805 .50688 m .58302 .50957 L .58318 .51223 L .5 .106 0 r
F
.59805 .50688 m .59788 .50421 L .58302 .50957 L F
.36812 .54277 m .35015 .53561 L .35037 .53825 L 1 .694 0 r
F
.36833 .54535 m .36812 .54277 L .35037 .53825 L 1 .684 0 r
F
.53078 .35728 m .52047 .3584 L .52159 .36166 L .817 .571 0 r
F
.53204 .36054 m .53078 .35728 L .52159 .36166 L .811 .593 0 r
F
.65365 .1008 m .64976 .10974 L .65644 .11245 L .361 .506 0 r
F
.65365 .1008 m .64698 .09859 L .64976 .10974 L F
.5443 .58199 m .52661 .58239 L .52629 .58459 L .701 .077 0 r
F
.5443 .58199 m .54473 .57977 L .52661 .58239 L F
.37326 .52435 m .35764 .51685 L .35756 .51943 L 1 .818 0 r
F
.37322 .52691 m .37326 .52435 L .35756 .51943 L 1 .808 0 r
F
.76655 .17762 m .76016 .1895 L .76556 .19426 L .156 .095 0 r
F
.76655 .17762 m .76124 .17297 L .76016 .1895 L F
.23677 .8208 m .20294 .80792 L .20638 .81278 L 1 .097 0 r
F
.23985 .82542 m .23677 .8208 L .20638 .81278 L 1 .087 0 r
F
.09618 .58409 m .07134 .56111 L .07196 .56775 L 1 .682 0 r
F
.09687 .59054 m .09618 .58409 L .07196 .56775 L 1 .661 0 r
F
.59571 .50121 m .58111 .50391 L .5813 .50654 L .494 .11 0 r
F
.59571 .50121 m .5955 .49858 L .58111 .50391 L F
.87089 .33593 m .85729 .35017 L .8601 .35662 L .066 .042 0 r
F
.87089 .33593 m .86796 .32952 L .85729 .35017 L F
.32859 .47045 m .3177 .46044 L .31665 .46343 L 1 1 0 r
F
.32768 .47351 m .32859 .47045 L .31665 .46343 L F
.70047 .3605 m .69752 .36406 L .69589 .37015 L 0 0 0 r
F
.70047 .3605 m .70186 .35452 L .69752 .36406 L F
.55435 .38481 m .54345 .38629 L .5448 .38881 L .648 .557 0 r
F
.55585 .38727 m .55435 .38481 L .5448 .38881 L .646 .553 0 r
F
.40215 .62925 m .38103 .62346 L .38174 .626 L 1 .348 0 r
F
.40274 .63166 m .40215 .62925 L .38174 .626 L 1 .33 0 r
F
.52464 .58702 m .50666 .5868 L .50641 .58885 L .767 .107 0 r
F
.52464 .58702 m .52501 .58495 L .50666 .5868 L F
.44961 .58951 m .43068 .58602 L .43093 .5881 L 1 .358 0 r
F
.44975 .59154 m .44961 .58951 L .43093 .5881 L 1 .343 0 r
F
.46861 .59213 m .44961 .58951 L .44975 .59154 L .978 .291 0 r
F
.55238 .37851 m .5415 .38014 L .54285 .38274 L .677 .564 0 r
F
.55389 .38106 m .55238 .37851 L .54285 .38274 L .674 .563 0 r
F
.52991 .63522 m .51053 .6363 L .51006 .63825 L .583 .038 0 r
F
.52991 .63522 m .53063 .63328 L .51053 .6363 L F
.5167 .34906 m .5069 .34964 L .50775 .35356 L .905 .575 0 r
F
.51769 .35303 m .5167 .34906 L .50775 .35356 L .898 .61 0 r
F
.56246 .56339 m .5457 .56465 L .54538 .56694 L .621 .07 0 r
F
.56246 .56339 m .56285 .56108 L .5457 .56465 L F
.54346 .57805 m .52603 .57857 L .52571 .58072 L .694 .072 0 r
F
.54346 .57805 m .54388 .57588 L .52603 .57857 L F
.46862 .59412 m .46861 .59213 L .44975 .59154 L .973 .276 0 r
F
.48738 .5939 m .46861 .59213 L .46862 .59412 L .908 .217 0 r
F
.48738 .5939 m .48751 .59191 L .46861 .59213 L F
.69681 .65505 m .67724 .65985 L .67576 .66387 L .231 0 0 r
F
.69681 .65505 m .69859 .65105 L .67724 .65985 L F
.61784 .56978 m .60305 .57415 L .60219 .5768 L .259 .003 0 r
F
.61784 .56978 m .61881 .5671 L .60305 .57415 L F
.36403 .88 m .32974 .87306 L .33239 .87652 L .84 .053 0 r
F
.3661 .88326 m .36403 .88 L .33239 .87652 L .816 .049 0 r
F
.67915 .4263 m .67271 .43099 L .6715 .43535 L 0 0 0 r
F
.67915 .4263 m .68044 .42192 L .67271 .43099 L F
.4175 .36484 m .41247 .36316 L .41056 .36503 L 1 1 0 r
F
.4175 .36484 m .41917 .36278 L .41247 .36316 L F
.76633 .17785 m .75942 .19025 L .76489 .19491 L .209 .181 0 r
F
.76633 .17785 m .76072 .17352 L .75942 .19025 L F
.49712 .35051 m .48776 .35147 L .48825 .35486 L 1 .784 0 r
F
.49712 .35051 m .49648 .34633 L .48776 .35147 L F
.5069 .34964 m .50614 .34517 L .49712 .35051 L 1 .678 0 r
F
.40971 .58021 m .39043 .57563 L .39082 .57795 L 1 .501 0 r
F
.41 .5825 m .40971 .58021 L .39082 .57795 L 1 .488 0 r
F
.51583 .34452 m .50614 .34517 L .5069 .34964 L .91 .535 0 r
F
.28391 .84923 m .24956 .83875 L .25295 .84302 L .974 .075 0 r
F
.28685 .85327 m .28391 .84923 L .25295 .84302 L .953 .072 0 r
F
.76069 .52165 m .74575 .5297 L .74527 .53446 L .055 0 0 r
F
.76069 .52165 m .76111 .51682 L .74575 .5297 L F
.52956 .35379 m .5194 .3549 L .52047 .3584 L .822 .543 0 r
F
.53078 .35728 m .52956 .35379 L .52047 .3584 L .817 .571 0 r
F
.46807 .64539 m .46805 .64343 L .44683 .64359 L .854 .071 0 r
F
.48885 .64419 m .46805 .64343 L .46807 .64539 L .767 .059 0 r
F
.48885 .64419 m .48909 .64228 L .46805 .64343 L F
.58233 .54589 m .56611 .5478 L .5659 .55029 L .556 .07 0 r
F
.58233 .54589 m .58259 .54338 L .56611 .5478 L F
.5167 .34906 m .51583 .34452 L .5069 .34964 L .905 .575 0 r
F
.65955 .4842 m .64995 .48942 L .64925 .49282 L 0 0 0 r
F
.65955 .4842 m .66032 .48081 L .64995 .48942 L F
.49592 .34146 m .48685 .34348 L .48729 .34774 L 1 .72 0 r
F
.49648 .34633 m .49592 .34146 L .48729 .34774 L 1 .755 0 r
F
.32768 .47351 m .31665 .46343 L .31564 .46643 L 1 1 0 r
F
.32681 .47658 m .32768 .47351 L .31564 .46643 L F
.38906 .56613 m .37012 .56045 L .3705 .56291 L 1 .581 0 r
F
.38937 .56853 m .38906 .56613 L .3705 .56291 L 1 .57 0 r
F
.42486 .63838 m .40334 .63405 L .40397 .63639 L 1 .234 0 r
F
.42532 .64059 m .42486 .63838 L .40397 .63639 L 1 .214 0 r
F
.41091 .57292 m .39276 .56754 L .3931 .56981 L 1 .532 0 r
F
.41119 .57515 m .41091 .57292 L .3931 .56981 L 1 .518 0 r
F
.71135 .17875 m .70757 .18588 L .71121 .19199 L 0 .003 0 r
F
.71135 .17875 m .70823 .1721 L .70757 .18588 L F
.53109 .36243 m .52101 .36303 L .52219 .36598 L .774 .595 0 r
F
.53245 .36533 m .53109 .36243 L .52219 .36598 L .769 .609 0 r
F
.50624 .597 m .48767 .59599 L .48754 .59806 L .839 .159 0 r
F
.50624 .597 m .50651 .59494 L .48767 .59599 L F
.89105 .51222 m .87353 .52412 L .87358 .53091 L 0 0 0 r
F
.89105 .51222 m .89107 .50535 L .87353 .52412 L F
.49648 .34633 m .48729 .34774 L .48776 .35147 L 1 .755 0 r
F
.43044 .58392 m .4118 .57953 L .41213 .58168 L 1 .434 0 r
F
.43068 .58602 m .43044 .58392 L .41213 .58168 L 1 .418 0 r
F
.63975 .53372 m .62718 .53879 L .62643 .54175 L .147 0 0 r
F
.63975 .53372 m .64055 .53076 L .62718 .53879 L F
.59819 .50954 m .58318 .51223 L .5833 .51489 L .495 .093 0 r
F
.59819 .50954 m .59805 .50688 L .58318 .51223 L F
.85715 .64352 m .83646 .65263 L .83474 .65889 L .027 0 0 r
F
.85715 .64352 m .85902 .63711 L .83646 .65263 L F
.37127 .83358 m .33763 .83164 L .33983 .83529 L .896 .071 0 r
F
.37293 .83714 m .37127 .83358 L .33983 .83529 L .881 .067 0 r
F
.72424 .30148 m .73949 .29416 L .74065 .30044 L 1 .636 0 r
F
.72424 .30148 m .7233 .29559 L .73949 .29416 L F
.52794 .89437 m .49751 .893 L .49686 .89582 L .521 .01 0 r
F
.52794 .89437 m .5293 .89153 L .49751 .893 L F
.55283 .38234 m .5421 .38377 L .54345 .38629 L .65 .56 0 r
F
.55435 .38481 m .55283 .38234 L .54345 .38629 L .648 .557 0 r
F
.52843 .34995 m .5184 .35106 L .5194 .3549 L .825 .508 0 r
F
.52956 .35379 m .52843 .34995 L .5194 .3549 L .822 .543 0 r
F
.57229 .61415 m .5548 .61687 L .55396 .61905 L .4 .019 0 r
F
.57229 .61415 m .57332 .61195 L .5548 .61687 L F
.55086 .37594 m .54013 .37752 L .5415 .38014 L .681 .563 0 r
F
.55238 .37851 m .55086 .37594 L .5415 .38014 L .677 .564 0 r
F
.5959 .50384 m .5813 .50654 L .58146 .50917 L .488 .098 0 r
F
.5959 .50384 m .59571 .50121 L .5813 .50654 L F
.34962 .50841 m .33381 .4997 L .33364 .50252 L 1 .85 0 r
F
.34954 .51119 m .34962 .50841 L .33364 .50252 L 1 .839 0 r
F
.39545 .38075 m .38966 .37637 L .38748 .37816 L 1 1 0 r
F
.39545 .38075 m .39731 .37868 L .38966 .37637 L F
.66176 .69457 m .64199 .69929 L .64039 .70309 L .25 0 0 r
F
.66176 .69457 m .66373 .6909 L .64199 .69929 L F
.50588 .59288 m .48751 .59191 L .48738 .5939 L .836 .15 0 r
F
.50588 .59288 m .50615 .59088 L .48751 .59191 L F
.3914 .55584 m .37416 .54941 L .37441 .55183 L 1 .651 0 r
F
.39163 .55822 m .3914 .55584 L .37441 .55183 L 1 .638 0 r
F
.55865 .88181 m .52962 .88163 L .5283 .88445 L .447 0 0 r
F
.55865 .88181 m .56065 .87895 L .52962 .88163 L F
.37322 .52691 m .35756 .51943 L .35751 .522 L 1 .808 0 r
F
.37321 .52947 m .37322 .52691 L .35751 .522 L 1 .796 0 r
F
.39892 .3714 m .39403 .36804 L .39188 .36991 L 1 1 0 r
F
.39892 .3714 m .40086 .36936 L .39403 .36804 L F
.76399 .41411 m .75894 .42172 L .75947 .42692 L 0 0 0 r
F
.76399 .41411 m .76308 .40909 L .75894 .42172 L F
.33404 .55228 m .31808 .54215 L .31813 .54526 L 1 .805 0 r
F
.33415 .55537 m .33404 .55228 L .31813 .54526 L 1 .791 0 r
F
.32681 .47658 m .31564 .46643 L .31468 .46944 L 1 1 0 r
F
.32598 .47966 m .32681 .47658 L .31468 .46944 L F
.35547 .59145 m .33687 .58261 L .33737 .58557 L 1 .618 0 r
F
.35596 .59432 m .35547 .59145 L .33737 .58557 L 1 .602 0 r
F
.36674 .46171 m .36751 .4591 L .35487 .45375 L 1 1 0 r
F
.80584 .7304 m .78313 .73707 L .78041 .74257 L .106 0 0 r
F
.80584 .7304 m .80882 .72474 L .78313 .73707 L F
.58071 .54232 m .56487 .54432 L .56466 .54677 L .545 .069 0 r
F
.58071 .54232 m .58096 .53985 L .56487 .54432 L F
.43517 .34694 m .43119 .34943 L .42944 .3512 L .77 .343 0 r
F
.43517 .34694 m .43664 .34477 L .43119 .34943 L F
.47983 .36118 m .47121 .36093 L .47116 .36337 L 1 1 0 r
F
.47983 .36118 m .47958 .35846 L .47121 .36093 L F
.5469 .78977 m .52295 .79728 L .5221 .80086 L .35 .001 0 r
F
.5469 .78977 m .54818 .78638 L .52295 .79728 L F
.36674 .46171 m .35487 .45375 L .35399 .45632 L 1 1 0 r
F
.36599 .46432 m .36674 .46171 L .35399 .45632 L F
.36833 .54535 m .35037 .53825 L .35062 .54088 L 1 .684 0 r
F
.36857 .54791 m .36833 .54535 L .35062 .54088 L 1 .673 0 r
F
.37908 .61565 m .35891 .60838 L .3596 .61113 L 1 .467 0 r
F
.37971 .61828 m .37908 .61565 L .3596 .61113 L 1 .449 0 r
F
.59262 .88278 m .56423 .88305 L .56226 .88615 L .415 0 0 r
F
.59262 .88278 m .59525 .87962 L .56423 .88305 L F
.56321 .56952 m .54624 .57066 L .5459 .57298 L .624 .069 0 r
F
.56321 .56952 m .56364 .56719 L .54624 .57066 L F
.87599 .34161 m .86239 .35589 L .86524 .36239 L .063 .042 0 r
F
.87599 .34161 m .87299 .33517 L .86239 .35589 L F
.52976 .35939 m .51986 .35992 L .52101 .36303 L .779 .575 0 r
F
.53109 .36243 m .52976 .35939 L .52101 .36303 L .774 .595 0 r
F
.42097 .35485 m .41691 .35467 L .41486 .35633 L .81 .753 0 r
F
.42097 .35485 m .42278 .35297 L .41691 .35467 L F
.42993 .59076 m .41065 .587 L .411 .58921 L 1 .419 0 r
F
.43017 .59293 m .42993 .59076 L .411 .58921 L 1 .403 0 r
F
.62954 .72475 m .60949 .73024 L .60793 .73392 L .251 0 0 r
F
.62954 .72475 m .6315 .72129 L .60949 .73024 L F
.44942 .596 m .43017 .59293 L .43042 .59508 L 1 .35 0 r
F
.44955 .5981 m .44942 .596 L .43042 .59508 L 1 .334 0 r
F
.46857 .59841 m .44942 .596 L .44955 .5981 L .969 .285 0 r
F
.36599 .46432 m .35399 .45632 L .35314 .45891 L 1 1 0 r
F
.36527 .46694 m .36599 .46432 L .35314 .45891 L F
.89891 .51982 m .87961 .53166 L .87973 .53856 L .027 0 0 r
F
.89891 .51982 m .89878 .5128 L .87961 .53166 L F
.54934 .37333 m .53877 .37486 L .54013 .37752 L .684 .561 0 r
F
.55086 .37594 m .54934 .37333 L .54013 .37752 L .681 .563 0 r
F
.5513 .37987 m .54073 .38124 L .5421 .38377 L .652 .561 0 r
F
.55283 .38234 m .5513 .37987 L .5421 .38377 L .65 .56 0 r
F
.37247 .4464 m .34867 .43388 L .34755 .4367 L 1 .713 0 r
F
.37247 .4464 m .37339 .44385 L .34867 .43388 L F
.37157 .44895 m .37247 .4464 L .34755 .4367 L F
.37339 .44385 m .34983 .43108 L .34867 .43388 L 1 .712 0 r
F
.37339 .44385 m .37435 .44131 L .34983 .43108 L F
.37157 .44895 m .34755 .4367 L .34648 .43953 L 1 .713 0 r
F
.37071 .45152 m .37157 .44895 L .34648 .43953 L F
.55043 .62736 m .53202 .62929 L .53133 .63131 L .483 .027 0 r
F
.55043 .62736 m .55134 .62534 L .53202 .62929 L F
.32598 .47966 m .31468 .46944 L .31376 .47246 L 1 1 0 r
F
.32519 .48275 m .32598 .47966 L .31376 .47246 L F
.59438 .5969 m .57812 .60045 L .57721 .60282 L .334 .01 0 r
F
.59438 .5969 m .59544 .5945 L .57812 .60045 L F
.37071 .45152 m .34648 .43953 L .34546 .44236 L 1 .713 0 r
F
.36987 .45409 m .37071 .45152 L .34546 .44236 L F
.5983 .5122 m .5833 .51489 L .58339 .51753 L .49 .081 0 r
F
.5983 .5122 m .59819 .50954 L .5833 .51489 L F
.59604 .50646 m .58146 .50917 L .58159 .51178 L .483 .086 0 r
F
.59604 .50646 m .5959 .50384 L .58146 .50917 L F
.6523 .21828 m .67514 .18546 L .67774 .19286 L 1 .838 0 r
F
.6523 .21828 m .65253 .20809 L .67514 .18546 L F
.36987 .45409 m .34546 .44236 L .34448 .44521 L 1 .713 0 r
F
.77168 .18468 m .76556 .19426 L .77088 .19909 L .141 .092 0 r
F
.77174 .18369 m .77134 .18438 L .77168 .18468 L F
.77134 .18438 m .76556 .19426 L .77168 .18468 L F
.7767 .19333 m .77088 .19909 L .77613 .20399 L .131 .091 0 r
F
.80667 .22722 m .80123 .22952 L .80602 .23483 L .091 .08 0 r
F
.8115 .23178 m .80602 .23483 L .81072 .24021 L .082 .077 0 r
F
.81629 .2361 m .81072 .24021 L .81534 .24566 L .073 .075 0 r
F
.82105 .24015 m .81534 .24566 L .81987 .25117 L .063 .072 0 r
F
.82577 .24393 m .81987 .25117 L .82431 .25676 L .053 .068 0 r
F
.83046 .24743 m .82431 .25676 L .82866 .26241 L .042 .065 0 r
F
.83519 .25013 m .82866 .26241 L .83291 .26813 L .031 .062 0 r
F
.83536 .24912 m .83496 .24986 L .83519 .25013 L .047 .062 0 r
F
.83496 .24986 m .83494 .2499 L .83519 .25013 L F
.83028 .24737 m .82431 .25676 L .83046 .24743 L .042 .065 0 r
F
.83552 .24811 m .83122 .24253 L .83051 .24701 L .047 .062 0 r
F
.83471 .2497 m .83051 .24701 L .83046 .24743 L .031 .062 0 r
F
.83471 .2497 m .83046 .24743 L .82866 .26241 L F
.83506 .24901 m .83471 .2497 L .83536 .24912 L .047 .062 0 r
F
.83471 .2497 m .82866 .26241 L .83519 .25013 L .031 .062 0 r
F
.83471 .2497 m .82804 .26279 L .83497 .24984 L .047 .062 0 r
F
.83471 .2497 m .83497 .24984 L .83536 .24912 L F
.83471 .2497 m .83051 .24701 L .82804 .26279 L F
.83552 .24811 m .83051 .24701 L .83471 .2497 L F
.83122 .24253 m .82966 .24557 L .83067 .24599 L .06 .065 0 r
F
.82944 .246 m .82431 .25676 L .83051 .24701 L .042 .065 0 r
F
.82966 .24557 m .82944 .246 L .83067 .24599 L .06 .065 0 r
F
.82944 .246 m .82577 .24393 L .82431 .25676 L .042 .065 0 r
F
.82944 .246 m .82376 .25711 L .83035 .24651 L .06 .065 0 r
F
.82944 .246 m .83035 .24651 L .83067 .24599 L F
.8268 .23703 m .82436 .24178 L .82596 .24257 L .073 .069 0 r
F
.82436 .24178 m .82432 .24187 L .82596 .24257 L F
.82423 .24204 m .81987 .25117 L .82581 .24357 L .053 .068 0 r
F
.82229 .23162 m .81916 .23768 L .82123 .23885 L .086 .072 0 r
F
.81916 .23768 m .81915 .2377 L .81919 .23772 L F
.81916 .23768 m .81919 .23772 L .82123 .23885 L F
.81908 .23783 m .81534 .24566 L .82108 .23984 L .063 .072 0 r
F
.81915 .2377 m .81908 .23783 L .82123 .23885 L .086 .072 0 r
F
.81908 .23783 m .81629 .2361 L .81534 .24566 L .063 .072 0 r
F
.81908 .23783 m .81488 .24597 L .82105 .23905 L .086 .072 0 r
F
.81908 .23783 m .82105 .23905 L .82123 .23885 L F
.81646 .23486 m .81591 .23537 L .81632 .23582 L .098 .076 0 r
F
.81591 .23537 m .81589 .23538 L .81632 .23582 L F
.81767 .22628 m .81401 .23334 L .81646 .23486 L F
.81399 .2334 m .81072 .24021 L .81632 .23582 L .073 .075 0 r
F
.81401 .23334 m .81399 .2334 L .81646 .23486 L .098 .076 0 r
F
.81399 .2334 m .8115 .23178 L .81072 .24021 L .073 .075 0 r
F
.81399 .2334 m .8103 .24051 L .81637 .23495 L .098 .076 0 r
F
.81399 .2334 m .81637 .23495 L .81646 .23486 L F
.81165 .2306 m .81107 .23104 L .81152 .23154 L .11 .079 0 r
F
.81107 .23104 m .81106 .23104 L .81152 .23154 L F
.81296 .22104 m .80893 .22876 L .81165 .2306 L F
.80893 .22877 m .80602 .23483 L .81152 .23154 L .082 .077 0 r
F
.80893 .22876 m .80893 .22877 L .81165 .2306 L .11 .079 0 r
F
.80893 .22877 m .80667 .22722 L .80602 .23483 L .082 .077 0 r
F
.80893 .22877 m .80562 .23513 L .81163 .23062 L .11 .079 0 r
F
.80893 .22877 m .81163 .23062 L .81165 .2306 L F
.80681 .22608 m .8062 .22646 L .80669 .22699 L .122 .082 0 r
F
.8062 .22646 m .8062 .22646 L .80669 .22699 L F
.80814 .21588 m .80391 .22396 L .80681 .22608 L F
.80648 .22709 m .80123 .22952 L .80667 .22722 L .091 .08 0 r
F
.80391 .22396 m .80123 .22952 L .80669 .22699 L F
.80178 .22241 m .79637 .22428 L .80123 .22952 L .098 .083 0 r
F
.80192 .22129 m .80129 .22163 L .8018 .2222 L .134 .086 0 r
F
.80324 .2108 m .79893 .21897 L .80192 .22129 L F
.79893 .21897 m .79892 .21899 L .80192 .22129 L F
.79892 .21899 m .80129 .22163 L .80192 .22129 L F
.79685 .21737 m .79142 .2191 L .79637 .22428 L .105 .085 0 r
F
.79666 .21722 m .79142 .2191 L .79685 .21737 L F
.80324 .2108 m .79823 .20582 L .79687 .21715 L .134 .086 0 r
F
.79892 .21899 m .79687 .21715 L .79637 .22428 L .098 .083 0 r
F
.79892 .21899 m .79687 .21715 L .79597 .22459 L .134 .086 0 r
F
.80324 .2108 m .79687 .21715 L .79892 .21899 L F
.79698 .2162 m .79634 .21655 L .79687 .21715 L .146 .089 0 r
F
.79823 .20582 m .79401 .21379 L .79698 .2162 L F
.79397 .21386 m .79142 .2191 L .79687 .21715 L .105 .085 0 r
F
.79187 .21206 m .7864 .214 L .79142 .2191 L .112 .087 0 r
F
.79401 .21379 m .79397 .21386 L .79698 .2162 L .146 .089 0 r
F
.79397 .21386 m .79187 .21206 L .79142 .2191 L .105 .085 0 r
F
.79397 .21386 m .79101 .21944 L .79681 .21629 L .146 .089 0 r
F
.79397 .21386 m .79681 .21629 L .79698 .2162 L F
.79201 .21076 m .79134 .21116 L .79188 .21182 L .157 .092 0 r
F
.79134 .21116 m .79132 .21117 L .79188 .21182 L F
.79314 .20092 m .78916 .20837 L .79201 .21076 L F
.79168 .2119 m .7864 .214 L .79187 .21206 L .112 .087 0 r
F
.78906 .20856 m .7864 .214 L .79188 .21182 L F
.78684 .20642 m .7813 .20896 L .7864 .214 L .117 .088 0 r
F
.78916 .20837 m .78906 .20856 L .79201 .21076 L .157 .092 0 r
F
.78906 .20856 m .78684 .20642 L .7864 .214 L .112 .087 0 r
F
.78906 .20856 m .78596 .21437 L .7916 .211 L .157 .092 0 r
F
.78906 .20856 m .7916 .211 L .79201 .21076 L F
.787 .2048 m .78626 .20535 L .78686 .20614 L .168 .1 0 r
F
.78626 .20535 m .78621 .20538 L .78686 .20614 L F
.78795 .19612 m .78446 .20261 L .787 .2048 L F
.78664 .20625 m .7813 .20896 L .78684 .20642 L .117 .088 0 r
F
.78423 .20304 m .7813 .20896 L .78686 .20614 L F
.78178 .20029 m .77613 .20399 L .7813 .20896 L .123 .089 0 r
F
.78446 .20261 m .78423 .20304 L .787 .2048 L .168 .1 0 r
F
.78423 .20304 m .78178 .20029 L .7813 .20896 L .117 .088 0 r
F
.78423 .20304 m .78082 .20938 L .78627 .20534 L .168 .1 0 r
F
.78423 .20304 m .78627 .20534 L .787 .2048 L F
.782 .19798 m .7811 .19889 L .7818 .19993 L .179 .12 0 r
F
.7811 .19889 m .78101 .19898 L .7818 .19993 L F
.78267 .19141 m .78004 .19626 L .782 .19798 L F
.77953 .19721 m .77613 .20399 L .7818 .19993 L .123 .089 0 r
F
.78004 .19626 m .77953 .19721 L .782 .19798 L .179 .12 0 r
F
.77953 .19721 m .7767 .19333 L .77613 .20399 L .123 .089 0 r
F
.77953 .19721 m .77559 .20447 L .78091 .19908 L .179 .12 0 r
F
.77953 .19721 m .78091 .19908 L .782 .19798 L F
.77705 .18947 m .77587 .19124 L .77673 .19278 L .189 .14 0 r
F
.77587 .19124 m .7757 .1915 L .77673 .19278 L F
.77731 .18679 m .77624 .18875 L .77705 .18947 L F
.77513 .19079 m .77088 .19909 L .77673 .19278 L .131 .091 0 r
F
.77624 .18875 m .77513 .19079 L .77705 .18947 L .189 .14 0 r
F
.77513 .19079 m .77168 .18468 L .77088 .19909 L .131 .091 0 r
F
.77513 .19079 m .77029 .19965 L .77561 .19164 L .189 .14 0 r
F
.77513 .19079 m .77561 .19164 L .77705 .18947 L F
.77136 .18319 m .76655 .17762 L .76556 .19426 L .141 .092 0 r
F
.77145 .18302 m .77124 .18281 L .77136 .18319 L .2 .161 0 r
F
.77187 .18227 m .77091 .1815 L .77091 .18152 L F
.77183 .18233 m .77091 .18152 L .77145 .18302 L F
.77187 .18227 m .77091 .18152 L .77183 .18233 L F
.77079 .18142 m .76655 .17762 L .76933 .18084 L .141 .092 0 r
F
.77079 .18142 m .76933 .18084 L .77136 .18319 L F
.76638 .17755 m .76633 .17785 L .77079 .18142 L .105 .097 0 r
F
.77091 .18152 m .76633 .17785 L .77145 .18302 L .2 .161 0 r
F
.77091 .1815 m .77079 .18142 L .77091 .18152 L F
.77079 .18142 m .76633 .17785 L .77091 .18152 L F
.77181 .18232 m .77079 .18142 L .7708 .18144 L .141 .092 0 r
F
.77181 .18232 m .7709 .18176 L .77136 .18319 L F
.77136 .18319 m .76633 .17785 L .76489 .19491 L .2 .161 0 r
F
.77124 .18281 m .76633 .17785 L .77136 .18319 L F
.75778 .1558 m .75584 .16841 L .76124 .17297 L .005 .07 0 r
F
.76614 .17688 m .76124 .17297 L .76655 .17762 L .73 .12 0 r
F
.76613 .17687 m .7661 .17684 L .76614 .17688 L F
.7661 .17684 m .76124 .17297 L .76614 .17688 L F
.76638 .17755 m .76641 .17756 L .76881 .17968 L 1 .313 0 r
F
.76641 .17756 m .76655 .17762 L .77079 .18142 L F
.77077 .18124 m .76638 .17755 L .77079 .18142 L .105 .097 0 r
F
.76834 .16464 m .76644 .17716 L .77077 .18124 L F
.76644 .17716 m .76638 .17755 L .77077 .18124 L F
.76613 .17687 m .76072 .17352 L .76633 .17785 L .12 .1 0 r
F
.76098 .17189 m .75778 .1558 L .76124 .17297 L .73 .12 0 r
F
.75778 .1558 m .75286 .15096 L .75584 .16841 L .005 .07 0 r
F
.76098 .17189 m .75708 .1566 L .76072 .17352 L .12 .1 0 r
F
.75802 .15725 m .758 .15714 L .76098 .17189 L .73 .12 0 r
F
.758 .15714 m .75778 .1558 L .76098 .17189 L F
.76197 .16553 m .75802 .15725 L .76098 .17189 L .12 .1 0 r
F
.75802 .15725 m .75708 .1566 L .76098 .17189 L F
.75919 .16447 m .75802 .15725 L .76098 .17189 L .73 .12 0 r
F
.76098 .17189 m .76072 .17352 L .76139 .17393 L .12 .1 0 r
F
.76098 .17189 m .76124 .17297 L .76613 .17687 L .73 .12 0 r
F
.76098 .17189 m .76139 .17393 L .76613 .17687 L .12 .1 0 r
F
.76275 .16056 m .76197 .16553 L .76613 .17687 L F
.76197 .16553 m .76098 .17189 L .76613 .17687 L F
.75919 .16447 m .76098 .17189 L .76613 .17687 L .73 .12 0 r
F
.75286 .15096 m .75034 .16394 L .75584 .16841 L .103 .091 0 r
F
.75708 .1566 m .75503 .16929 L .76072 .17352 L .135 .108 0 r
F
.75916 .17441 m .75919 .16447 L .76613 .17687 L 1 .313 0 r
F
.76621 .17708 m .76613 .17687 L .76626 .1771 L F
.76834 .16464 m .76275 .16056 L .76613 .17687 L .105 .097 0 r
F
.76638 .17755 m .76613 .17687 L .76633 .17785 L F
.76621 .17708 m .76613 .17687 L .76621 .17708 L 1 .313 0 r
F
.76834 .16464 m .76613 .17687 L .76638 .17755 L .105 .097 0 r
F
.75916 .17441 m .76613 .17687 L .76621 .17708 L 1 .313 0 r
F
.76643 .17757 m .76626 .1771 L .76655 .17762 L F
.75916 .17441 m .76626 .1771 L .76643 .17757 L F
.76275 .16056 m .75922 .15809 L .76197 .16553 L .12 .1 0 r
F
.75922 .15809 m .75802 .15725 L .76197 .16553 L F
.75916 .17441 m .76638 .17755 L .77181 .18232 L 1 .313 0 r
F
.76638 .17755 m .76881 .17968 L .77181 .18232 L F
.77177 .1818 m .77079 .18142 L .77187 .18227 L .105 .097 0 r
F
.76834 .16464 m .77079 .18142 L .77177 .1818 L F
.76641 .17756 m .77079 .18142 L .77181 .18232 L 1 .313 0 r
F
.77731 .18679 m .77187 .18227 L .77174 .18369 L .189 .14 0 r
F
.77182 .18386 m .77174 .18369 L .77173 .1838 L .131 .091 0 r
F
.77211 .18488 m .77173 .1838 L .77168 .18468 L F
.77731 .18679 m .77174 .18369 L .77513 .19079 L .189 .14 0 r
F
.77704 .18706 m .77173 .1838 L .77211 .18488 L .131 .091 0 r
F
.77704 .18706 m .77168 .18468 L .77513 .19079 L F
.77513 .19079 m .77174 .18369 L .77029 .19965 L .189 .14 0 r
F
.77704 .18706 m .77181 .18232 L .77174 .18369 L .131 .091 0 r
F
.77704 .18706 m .77174 .18369 L .77182 .18386 L F
.77699 .19325 m .77673 .19278 L .7767 .19333 L .123 .089 0 r
F
.78267 .19141 m .77731 .18679 L .77673 .19278 L .179 .12 0 r
F
.77702 .19324 m .77673 .19278 L .77699 .19325 L .123 .089 0 r
F
.78267 .19141 m .77673 .19278 L .77953 .19721 L .179 .12 0 r
F
.78224 .19181 m .7767 .19333 L .77953 .19721 L .123 .089 0 r
F
.77644 .1931 m .77088 .19909 L .7767 .19333 L .131 .091 0 r
F
.77953 .19721 m .77673 .19278 L .77559 .20447 L .179 .12 0 r
F
.78224 .19181 m .77673 .19278 L .77702 .19324 L .123 .089 0 r
F
.78224 .19181 m .77704 .18706 L .77673 .19278 L F
.78196 .20017 m .7818 .19993 L .78178 .20029 L .117 .088 0 r
F
.78795 .19612 m .78267 .19141 L .7818 .19993 L .168 .1 0 r
F
.78198 .20016 m .7818 .19993 L .78196 .20017 L .117 .088 0 r
F
.78795 .19612 m .7818 .19993 L .78423 .20304 L .168 .1 0 r
F
.78741 .1966 m .78178 .20029 L .78423 .20304 L .117 .088 0 r
F
.78155 .2001 m .77613 .20399 L .78178 .20029 L .123 .089 0 r
F
.78423 .20304 m .7818 .19993 L .78082 .20938 L .168 .1 0 r
F
.78741 .1966 m .7818 .19993 L .78198 .20016 L .117 .088 0 r
F
.78741 .1966 m .78224 .19181 L .7818 .19993 L F
.78698 .2063 m .78686 .20614 L .78684 .20642 L .112 .087 0 r
F
.79314 .20092 m .78795 .19612 L .78686 .20614 L .157 .092 0 r
F
.78699 .20629 m .78686 .20614 L .78698 .2063 L .112 .087 0 r
F
.79314 .20092 m .78686 .20614 L .78906 .20856 L .157 .092 0 r
F
.79255 .20143 m .78684 .20642 L .78906 .20856 L .112 .087 0 r
F
.78906 .20856 m .78686 .20614 L .78596 .21437 L .157 .092 0 r
F
.79255 .20143 m .78686 .20614 L .78699 .20629 L .112 .087 0 r
F
.79255 .20143 m .78741 .1966 L .78686 .20614 L F
.79199 .21194 m .79188 .21182 L .79187 .21206 L .105 .085 0 r
F
.79823 .20582 m .79314 .20092 L .79188 .21182 L .146 .089 0 r
F
.792 .21193 m .79188 .21182 L .79199 .21194 L .105 .085 0 r
F
.79823 .20582 m .79188 .21182 L .79397 .21386 L .146 .089 0 r
F
.79763 .20632 m .79187 .21206 L .79397 .21386 L .105 .085 0 r
F
.79397 .21386 m .79188 .21182 L .79101 .21944 L .146 .089 0 r
F
.79763 .20632 m .79188 .21182 L .792 .21193 L .105 .085 0 r
F
.79763 .20632 m .79255 .20143 L .79188 .21182 L F
.80265 .21128 m .79763 .20632 L .79687 .21715 L .098 .083 0 r
F
.80265 .21128 m .79687 .21715 L .79892 .21899 L F
.80373 .22434 m .8018 .2222 L .80123 .22952 L .091 .08 0 r
F
.80814 .21588 m .80324 .2108 L .8018 .2222 L .122 .082 0 r
F
.80391 .22396 m .8018 .2222 L .80373 .22434 L .091 .08 0 r
F
.80159 .22228 m .79637 .22428 L .80178 .22241 L .098 .083 0 r
F
.80391 .22396 m .8018 .2222 L .80084 .22982 L .122 .082 0 r
F
.80814 .21588 m .8018 .2222 L .80391 .22396 L F
.80759 .21631 m .8018 .2222 L .80391 .22396 L .091 .08 0 r
F
.80759 .21631 m .80265 .21128 L .8018 .2222 L F
.79892 .21899 m .79637 .22428 L .8018 .2222 L .098 .083 0 r
F
.79892 .21899 m .79597 .22459 L .80129 .22163 L .134 .086 0 r
F
.80391 .22396 m .80084 .22982 L .80681 .22608 L .122 .082 0 r
F
.80678 .2271 m .80669 .22699 L .80667 .22722 L .082 .077 0 r
F
.81296 .22104 m .80814 .21588 L .80669 .22699 L .11 .079 0 r
F
.8068 .22708 m .80669 .22699 L .80678 .2271 L .082 .077 0 r
F
.81296 .22104 m .80669 .22699 L .80893 .22877 L .11 .079 0 r
F
.81246 .22141 m .80667 .22722 L .80893 .22877 L .082 .077 0 r
F
.80893 .22877 m .80669 .22699 L .80562 .23513 L .11 .079 0 r
F
.81246 .22141 m .80669 .22699 L .8068 .22708 L .082 .077 0 r
F
.81246 .22141 m .80759 .21631 L .80669 .22699 L F
.81164 .23166 m .81152 .23154 L .8115 .23178 L .073 .075 0 r
F
.81767 .22628 m .81296 .22104 L .81152 .23154 L .098 .076 0 r
F
.81166 .23164 m .81152 .23154 L .81164 .23166 L .073 .075 0 r
F
.81767 .22628 m .81152 .23154 L .81399 .2334 L .098 .076 0 r
F
.81724 .2266 m .8115 .23178 L .81399 .2334 L .073 .075 0 r
F
.81131 .23167 m .80602 .23483 L .8115 .23178 L .082 .077 0 r
F
.81399 .2334 m .81152 .23154 L .8103 .24051 L .098 .076 0 r
F
.81724 .2266 m .81152 .23154 L .81166 .23164 L .073 .075 0 r
F
.81724 .2266 m .81246 .22141 L .81152 .23154 L F
.81646 .23598 m .81632 .23582 L .81629 .2361 L .063 .072 0 r
F
.82229 .23162 m .81767 .22628 L .81632 .23582 L .086 .072 0 r
F
.81649 .23595 m .81632 .23582 L .81646 .23598 L .063 .072 0 r
F
.82229 .23162 m .81632 .23582 L .81908 .23783 L .086 .072 0 r
F
.82193 .23187 m .81629 .2361 L .81908 .23783 L .063 .072 0 r
F
.8161 .23599 m .81072 .24021 L .81629 .2361 L .073 .075 0 r
F
.81908 .23783 m .81632 .23582 L .81488 .24597 L .086 .072 0 r
F
.82193 .23187 m .81632 .23582 L .81649 .23595 L .063 .072 0 r
F
.82193 .23187 m .81724 .2266 L .81632 .23582 L F
.82126 .24004 m .82108 .23984 L .82105 .24015 L .053 .068 0 r
F
.8268 .23703 m .82229 .23162 L .82108 .23984 L .073 .069 0 r
F
.82132 .24001 m .82108 .23984 L .82126 .24004 L .053 .068 0 r
F
.82423 .24204 m .82105 .24015 L .81987 .25117 L F
.8268 .23703 m .82108 .23984 L .82423 .24204 L .073 .069 0 r
F
.82653 .23722 m .82105 .24015 L .82423 .24204 L .053 .068 0 r
F
.82086 .24006 m .81534 .24566 L .82105 .24015 L .063 .072 0 r
F
.82423 .24204 m .82108 .23984 L .81937 .2515 L .073 .069 0 r
F
.82653 .23722 m .82108 .23984 L .82132 .24001 L .053 .068 0 r
F
.82653 .23722 m .82193 .23187 L .82108 .23984 L F
.82472 .24232 m .81937 .2515 L .82549 .24321 L .073 .069 0 r
F
.82432 .24187 m .82423 .24204 L .82472 .24232 L F
.82423 .24204 m .81937 .2515 L .82472 .24232 L F
.82432 .24187 m .82549 .24321 L .82596 .24257 L F
.82607 .24386 m .82581 .24357 L .82577 .24393 L .042 .065 0 r
F
.83122 .24253 m .8268 .23703 L .82581 .24357 L .06 .065 0 r
F
.8262 .24383 m .82581 .24357 L .82607 .24386 L .042 .065 0 r
F
.83122 .24253 m .82581 .24357 L .82944 .246 L .06 .065 0 r
F
.83104 .24265 m .82577 .24393 L .82944 .246 L .042 .065 0 r
F
.82559 .24386 m .81987 .25117 L .82577 .24393 L .053 .068 0 r
F
.82944 .246 m .82581 .24357 L .82376 .25711 L .06 .065 0 r
F
.83104 .24265 m .82581 .24357 L .8262 .24383 L .042 .065 0 r
F
.83104 .24265 m .82653 .23722 L .82581 .24357 L F
.83545 .24816 m .83104 .24265 L .83051 .24701 L .031 .062 0 r
F
.83545 .24816 m .83051 .24701 L .83471 .2497 L F
.83945 .2535 m .83856 .2522 L .83519 .25013 L .019 .058 0 r
F
.83975 .25374 m .83856 .2522 L .83945 .2535 L F
.83975 .25374 m .83519 .25013 L .83921 .25488 L F
.83698 .23267 m .83555 .24778 L .83841 .25189 L 0 .038 0 r
F
.83873 .25221 m .83841 .25189 L .83874 .25236 L F
.83698 .23267 m .83841 .25189 L .83873 .25221 L F
.83698 .23267 m .83874 .25236 L .83964 .25314 L F
.83698 .23267 m .83272 .22719 L .83552 .24811 L F
.83977 .25327 m .83964 .25314 L .83975 .25374 L 0 .034 0 r
F
.84396 .25941 m .83707 .27391 L .84113 .27976 L .007 .055 0 r
F
.84396 .25941 m .83975 .25374 L .83707 .27391 L F
.84806 .26516 m .84396 .25941 L .84113 .27976 L 0 .051 0 r
F
.8471 .25957 m .84396 .25941 L .84806 .26516 L 0 .029 0 r
F
.84806 .26516 m .84113 .27976 L .84509 .28568 L 0 .051 0 r
F
.85205 .27098 m .84806 .26516 L .84509 .28568 L 0 .048 0 r
F
.85065 .26252 m .84806 .26516 L .85205 .27098 L 0 .024 0 r
F
.85205 .27098 m .84509 .28568 L .84895 .29166 L 0 .048 0 r
F
.85594 .27687 m .85205 .27098 L .84895 .29166 L 0 .044 0 r
F
.85409 .26535 m .85205 .27098 L .85594 .27687 L 0 .019 0 r
F
.85594 .27687 m .84895 .29166 L .8527 .2977 L 0 .044 0 r
F
.85972 .28284 m .85594 .27687 L .8527 .2977 L 0 .04 0 r
F
.85742 .2681 m .85594 .27687 L .85972 .28284 L 0 .013 0 r
F
.85972 .28284 m .8527 .2977 L .85635 .3038 L 0 .04 0 r
F
.86339 .28887 m .85972 .28284 L .85635 .3038 L 0 .036 0 r
F
.86055 .27014 m .85972 .28284 L .86339 .28887 L 0 .008 0 r
F
.86035 .26832 m .86023 .26972 L .86055 .27014 L 0 .007 0 r
F
.86023 .26972 m .86022 .26986 L .86055 .27014 L F
.86025 .26734 m .86018 .26831 L .86035 .26832 L F
.86007 .26973 m .85972 .28284 L .86055 .27014 L 0 .008 0 r
F
.86018 .26831 m .86007 .26973 L .86035 .26832 L 0 .007 0 r
F
.86007 .26973 m .85742 .2681 L .85972 .28284 L 0 .008 0 r
F
.86007 .26973 m .85906 .28317 L .86022 .26983 L 0 .007 0 r
F
.86007 .26973 m .86022 .26983 L .86035 .26832 L F
.85666 .26136 m .85632 .26562 L .85714 .26572 L 0 .012 0 r
F
.85632 .26562 m .85628 .26618 L .85714 .26572 L F
.85624 .26663 m .85594 .27687 L .85734 .26757 L 0 .013 0 r
F
.85381 .26306 m .85349 .26428 L .85403 .26495 L 0 .018 0 r
F
.85349 .26428 m .85345 .26445 L .85403 .26495 L F
.85294 .25546 m .85235 .26281 L .85381 .26306 L F
.85229 .26346 m .85205 .27098 L .85403 .26495 L 0 .019 0 r
F
.85235 .26281 m .85229 .26346 L .85381 .26306 L 0 .018 0 r
F
.85229 .26346 m .85065 .26252 L .85205 .27098 L 0 .019 0 r
F
.85229 .26346 m .85166 .27119 L .85352 .26417 L 0 .018 0 r
F
.85229 .26346 m .85352 .26417 L .85381 .26306 L F
.85038 .26031 m .84985 .26134 L .85061 .26224 L 0 .023 0 r
F
.84985 .26134 m .84976 .26151 L .85061 .26224 L F
.84912 .24964 m .84826 .25983 L .85038 .26031 L F
.84823 .2602 m .84806 .26516 L .85061 .26224 L 0 .024 0 r
F
.84826 .25983 m .84823 .2602 L .85038 .26031 L 0 .023 0 r
F
.84823 .2602 m .8471 .25957 L .84806 .26516 L 0 .024 0 r
F
.84823 .2602 m .84779 .26531 L .84995 .26115 L 0 .023 0 r
F
.84823 .2602 m .84995 .26115 L .85038 .26031 L F
.84683 .25742 m .8459 .25806 L .84707 .2594 L 0 .028 0 r
F
.8459 .25806 m .84569 .25821 L .84707 .2594 L F
.84518 .2439 m .84406 .25664 L .84683 .25742 L F
.84405 .25679 m .84396 .25941 L .84707 .2594 L 0 .029 0 r
F
.84276 .25627 m .84133 .25587 L .84396 .25941 L 0 .034 0 r
F
.84406 .25664 m .84405 .25679 L .84683 .25742 L 0 .028 0 r
F
.84405 .25679 m .84381 .2595 L .84613 .25791 L F
.84405 .25679 m .84613 .25791 L .84683 .25742 L F
.84113 .23824 m .83698 .23267 L .83963 .25308 L 0 .033 0 r
F
.84113 .23824 m .83963 .25308 L .83964 .2531 L F
.84113 .23824 m .83964 .25314 L .83977 .25322 L F
.84351 .2569 m .84276 .25627 L .84396 .25941 L 0 .034 0 r
F
.84276 .25627 m .83975 .25374 L .84133 .25587 L F
.84113 .23824 m .83984 .2525 L .84342 .25638 L 0 .033 0 r
F
.84518 .2439 m .84113 .23824 L .84342 .25638 L 0 .028 0 r
F
.84344 .2564 m .84342 .25638 L .84344 .25646 L 0 .029 0 r
F
.84405 .25679 m .84344 .25646 L .84396 .25941 L F
.84406 .25664 m .84342 .25638 L .84381 .2595 L 0 .028 0 r
F
.84518 .2439 m .84342 .25638 L .84406 .25664 L F
.84342 .25638 m .83977 .25322 L .84266 .25606 L 0 .034 0 r
F
.84342 .25638 m .84266 .25606 L .84351 .2569 L F
.83984 .2525 m .83977 .25322 L .84342 .25638 L 0 .033 0 r
F
.84032 .23878 m .83977 .25322 L .84342 .25638 L 0 .034 0 r
F
.83977 .25322 m .83975 .25374 L .84351 .2569 L F
.83975 .25374 m .83291 .26813 L .83707 .27391 L .019 .058 0 r
F
.83977 .25322 m .83972 .25376 L .84342 .25638 L 0 .033 0 r
F
.84342 .25638 m .83972 .25376 L .84381 .2595 L F
.8445 .24433 m .84032 .23878 L .84342 .25638 L 0 .029 0 r
F
.8445 .24433 m .84342 .25638 L .84344 .2564 L F
.8445 .24433 m .84344 .25646 L .84405 .25679 L F
.84712 .25945 m .84707 .2594 L .8471 .25957 L 0 .024 0 r
F
.84912 .24964 m .84518 .2439 L .84707 .2594 L 0 .023 0 r
F
.84712 .25943 m .84707 .2594 L .84712 .25945 L 0 .024 0 r
F
.84912 .24964 m .84707 .2594 L .84823 .2602 L 0 .023 0 r
F
.84858 .24997 m .8471 .25957 L .84823 .2602 L 0 .024 0 r
F
.84823 .2602 m .84707 .2594 L .84779 .26531 L 0 .023 0 r
F
.84858 .24997 m .84707 .2594 L .84712 .25943 L 0 .024 0 r
F
.84858 .24997 m .8445 .24433 L .84707 .2594 L F
.8507 .26235 m .85061 .26224 L .85065 .26252 L 0 .019 0 r
F
.85294 .25546 m .84912 .24964 L .85061 .26224 L 0 .018 0 r
F
.85071 .26232 m .85061 .26224 L .8507 .26235 L 0 .019 0 r
F
.85294 .25546 m .85061 .26224 L .85229 .26346 L 0 .018 0 r
F
.85254 .2557 m .85065 .26252 L .85229 .26346 L 0 .019 0 r
F
.8504 .26248 m .84806 .26516 L .85065 .26252 L 0 .024 0 r
F
.85229 .26346 m .85061 .26224 L .85166 .27119 L 0 .018 0 r
F
.85254 .2557 m .85061 .26224 L .85071 .26232 L 0 .019 0 r
F
.85254 .2557 m .84858 .24997 L .85061 .26224 L F
.8542 .26517 m .85403 .26495 L .85409 .26535 L 0 .013 0 r
F
.85666 .26136 m .85294 .25546 L .85403 .26495 L 0 .012 0 r
F
.85423 .26511 m .85403 .26495 L .8542 .26517 L 0 .013 0 r
F
.85624 .26663 m .85409 .26535 L .85594 .27687 L F
.85666 .26136 m .85403 .26495 L .85624 .26663 L 0 .012 0 r
F
.85639 .26151 m .85409 .26535 L .85624 .26663 L 0 .013 0 r
F
.85391 .26532 m .85205 .27098 L .85409 .26535 L 0 .019 0 r
F
.85624 .26663 m .85403 .26495 L .85542 .27715 L 0 .012 0 r
F
.85639 .26151 m .85403 .26495 L .85423 .26511 L 0 .013 0 r
F
.85639 .26151 m .85254 .2557 L .85403 .26495 L F
.85693 .26704 m .85542 .27715 L .85694 .26705 L 0 .012 0 r
F
.85628 .26618 m .85624 .26663 L .85693 .26704 L F
.85624 .26663 m .85542 .27715 L .85693 .26704 L F
.85628 .26618 m .85694 .26705 L .85714 .26572 L F
.85769 .26803 m .85734 .26757 L .85742 .2681 L 0 .008 0 r
F
.86025 .26734 m .85666 .26136 L .85734 .26757 L 0 .007 0 r
F
.85786 .26799 m .85734 .26757 L .85769 .26803 L 0 .008 0 r
F
.86025 .26734 m .85734 .26757 L .86007 .26973 L 0 .007 0 r
F
.86013 .26741 m .85742 .2681 L .86007 .26973 L 0 .008 0 r
F
.85726 .26809 m .85594 .27687 L .85742 .2681 L 0 .013 0 r
F
.86007 .26973 m .85734 .26757 L .85906 .28317 L 0 .007 0 r
F
.86013 .26741 m .85734 .26757 L .85786 .26799 L 0 .008 0 r
F
.86013 .26741 m .85639 .26151 L .85734 .26757 L F
.86376 .27339 m .86304 .2722 L .86055 .27014 L 0 .003 0 r
F
.86373 .27448 m .86055 .27014 L .86339 .28887 L F
.86376 .27339 m .86055 .27014 L .86373 .27448 L F
.86373 .2734 m .86304 .2722 L .86258 .28927 L 0 .002 0 r
F
.86304 .2722 m .86025 .26734 L .86055 .27014 L F
.86304 .2722 m .86055 .27014 L .86258 .28927 L F
.86304 .2722 m .86013 .26741 L .86055 .27014 L 0 .003 0 r
F
.86013 .26741 m .86007 .26973 L .86055 .27014 L 0 .008 0 r
F
.86055 .27014 m .85906 .28317 L .86258 .28927 L 0 .007 0 r
F
.86022 .26986 m .85906 .28317 L .86055 .27014 L F
.85734 .26757 m .85726 .26809 L .85742 .2681 L 0 .013 0 r
F
.85714 .26572 m .85691 .26721 L .85734 .26757 L 0 .012 0 r
F
.85639 .26151 m .85624 .26663 L .85734 .26757 L 0 .013 0 r
F
.85734 .26757 m .85542 .27715 L .85906 .28317 L 0 .012 0 r
F
.85691 .26721 m .85542 .27715 L .85734 .26757 L F
.85403 .26495 m .85391 .26532 L .85409 .26535 L 0 .019 0 r
F
.85254 .2557 m .85229 .26346 L .85403 .26495 L F
.85403 .26495 m .85166 .27119 L .85542 .27715 L 0 .018 0 r
F
.85345 .26445 m .85166 .27119 L .85403 .26495 L F
.85061 .26224 m .8504 .26248 L .85065 .26252 L 0 .024 0 r
F
.84858 .24997 m .84823 .2602 L .85061 .26224 L F
.85061 .26224 m .84779 .26531 L .85166 .27119 L 0 .023 0 r
F
.84976 .26151 m .84779 .26531 L .85061 .26224 L F
.84707 .2594 m .84635 .2594 L .8471 .25957 L 0 .029 0 r
F
.84635 .2594 m .84396 .25941 L .8471 .25957 L F
.8445 .24433 m .84405 .25679 L .84707 .2594 L F
.84707 .2594 m .84381 .2595 L .84779 .26531 L 0 .028 0 r
F
.84569 .25821 m .84381 .2595 L .84707 .2594 L F
.83964 .2531 m .83963 .25308 L .83964 .25314 L 0 .033 0 r
F
.83977 .25322 m .83964 .25314 L .83977 .25327 L 0 .034 0 r
F
.83977 .25322 m .83964 .25314 L .83972 .25376 L 0 .033 0 r
F
.84032 .23878 m .83964 .25314 L .83977 .25322 L 0 .034 0 r
F
.84032 .23878 m .83602 .23333 L .83964 .25314 L F
.83555 .24778 m .83552 .24811 L .83856 .2522 L 0 .038 0 r
F
.83555 .24778 m .83856 .2522 L .83972 .25376 L F
.83272 .22719 m .83122 .24253 L .83552 .24811 L 0 .042 0 r
F
.83602 .23333 m .83545 .24816 L .83856 .2522 L 0 .039 0 r
F
.83964 .25314 m .83856 .2522 L .83975 .25374 L F
.83602 .23333 m .83856 .2522 L .83964 .25314 L F
.83964 .25314 m .83874 .25236 L .83972 .25376 L 0 .038 0 r
F
.83921 .25488 m .83519 .25013 L .83291 .26813 L .019 .058 0 r
F
.83972 .25376 m .83856 .2522 L .83222 .26853 L .034 .058 0 r
F
.83856 .2522 m .83552 .24811 L .83519 .25013 L F
.83856 .2522 m .83519 .25013 L .83222 .26853 L F
.83856 .2522 m .83545 .24816 L .83519 .25013 L .019 .058 0 r
F
.83552 .24811 m .83506 .24901 L .83536 .24912 L .047 .062 0 r
F
.83545 .24816 m .83471 .2497 L .83519 .25013 L .031 .062 0 r
F
.83519 .25013 m .82804 .26279 L .83222 .26853 L .047 .062 0 r
F
.83494 .2499 m .82804 .26279 L .83519 .25013 L F
.83051 .24701 m .83028 .24737 L .83046 .24743 L .042 .065 0 r
F
.83067 .24599 m .83022 .24673 L .83051 .24701 L .06 .065 0 r
F
.83104 .24265 m .82944 .246 L .83051 .24701 L .042 .065 0 r
F
.83051 .24701 m .82376 .25711 L .82804 .26279 L .06 .065 0 r
F
.83022 .24673 m .82376 .25711 L .83051 .24701 L F
.82581 .24357 m .82559 .24386 L .82577 .24393 L .053 .068 0 r
F
.82596 .24257 m .82547 .24324 L .82581 .24357 L .073 .069 0 r
F
.82653 .23722 m .82423 .24204 L .82581 .24357 L .053 .068 0 r
F
.82581 .24357 m .81937 .2515 L .82376 .25711 L .073 .069 0 r
F
.82547 .24324 m .81937 .2515 L .82581 .24357 L F
.82108 .23984 m .82086 .24006 L .82105 .24015 L .063 .072 0 r
F
.82123 .23885 m .82069 .23945 L .82108 .23984 L .086 .072 0 r
F
.82193 .23187 m .81908 .23783 L .82108 .23984 L .063 .072 0 r
F
.82108 .23984 m .81488 .24597 L .81937 .2515 L .086 .072 0 r
F
.82069 .23945 m .81488 .24597 L .82108 .23984 L F
.81632 .23582 m .8161 .23599 L .81629 .2361 L .073 .075 0 r
F
.81724 .2266 m .81399 .2334 L .81632 .23582 L F
.81632 .23582 m .8103 .24051 L .81488 .24597 L .098 .076 0 r
F
.81589 .23538 m .8103 .24051 L .81632 .23582 L F
.81152 .23154 m .81131 .23167 L .8115 .23178 L .082 .077 0 r
F
.81246 .22141 m .80893 .22877 L .81152 .23154 L F
.81152 .23154 m .80562 .23513 L .8103 .24051 L .11 .079 0 r
F
.81106 .23104 m .80562 .23513 L .81152 .23154 L F
.80669 .22699 m .80648 .22709 L .80667 .22722 L .091 .08 0 r
F
.80759 .21631 m .80391 .22396 L .80669 .22699 L F
.80669 .22699 m .80084 .22982 L .80562 .23513 L .122 .082 0 r
F
.8062 .22646 m .80084 .22982 L .80669 .22699 L F
.8018 .2222 m .80159 .22228 L .80178 .22241 L .098 .083 0 r
F
.80265 .21128 m .79892 .21899 L .8018 .2222 L F
.8018 .2222 m .79597 .22459 L .80084 .22982 L .134 .086 0 r
F
.80129 .22163 m .79597 .22459 L .8018 .2222 L F
.79687 .21715 m .79666 .21722 L .79685 .21737 L .105 .085 0 r
F
.79763 .20632 m .79397 .21386 L .79687 .21715 L F
.79687 .21715 m .79101 .21944 L .79597 .22459 L .146 .089 0 r
F
.79634 .21655 m .79101 .21944 L .79687 .21715 L F
.79188 .21182 m .79168 .2119 L .79187 .21206 L .112 .087 0 r
F
.79255 .20143 m .78906 .20856 L .79188 .21182 L F
.79188 .21182 m .78596 .21437 L .79101 .21944 L .157 .092 0 r
F
.79132 .21117 m .78596 .21437 L .79188 .21182 L F
.78686 .20614 m .78664 .20625 L .78684 .20642 L .117 .088 0 r
F
.78741 .1966 m .78423 .20304 L .78686 .20614 L F
.78686 .20614 m .78082 .20938 L .78596 .21437 L .168 .1 0 r
F
.78621 .20538 m .78082 .20938 L .78686 .20614 L F
.7818 .19993 m .78155 .2001 L .78178 .20029 L .123 .089 0 r
F
.78224 .19181 m .77953 .19721 L .7818 .19993 L F
.7818 .19993 m .77559 .20447 L .78082 .20938 L .179 .12 0 r
F
.78101 .19898 m .77559 .20447 L .7818 .19993 L F
.77673 .19278 m .77644 .1931 L .7767 .19333 L .131 .091 0 r
F
.77704 .18706 m .77513 .19079 L .77673 .19278 L F
.77673 .19278 m .77029 .19965 L .77559 .20447 L .189 .14 0 r
F
.7757 .1915 m .77029 .19965 L .77673 .19278 L F
.77136 .18319 m .76556 .19426 L .77174 .18369 L .141 .092 0 r
F
.77174 .18369 m .76489 .19491 L .77029 .19965 L .2 .161 0 r
F
.77187 .18227 m .77136 .18319 L .77174 .18369 L F
.77136 .18319 m .76489 .19491 L .77174 .18369 L F
.77181 .18232 m .77136 .18319 L .77174 .18369 L .141 .092 0 r
F
.36527 .46694 m .35314 .45891 L .35233 .4615 L 1 1 0 r
F
.36458 .46956 m .36527 .46694 L .35233 .4615 L F
.46547 .88951 m .4654 .88679 L .43371 .88649 L .634 .024 0 r
F
.49643 .88882 m .4654 .88679 L .46547 .88951 L .573 .016 0 r
F
.49643 .88882 m .49707 .88611 L .4654 .88679 L F
.73138 .60309 m .71298 .6091 L .71181 .61343 L .171 0 0 r
F
.73138 .60309 m .73273 .5987 L .71298 .6091 L F
.56204 .56568 m .54538 .56694 L .54504 .56921 L .615 .068 0 r
F
.56204 .56568 m .56246 .56339 L .54538 .56694 L F
.13521 .70369 m .10637 .6841 L .10857 .69032 L 1 .413 0 r
F
.13733 .70969 m .13521 .70369 L .10857 .69032 L 1 .386 0 r
F
.54384 .58418 m .52629 .58459 L .52595 .58677 L .695 .072 0 r
F
.54384 .58418 m .5443 .58199 L .52629 .58459 L F
.66643 .8555 m .63994 .85745 L .63698 .8612 L .321 0 0 r
F
.66643 .8555 m .66994 .85162 L .63994 .85745 L F
.58205 .54838 m .5659 .55029 L .56566 .55276 L .55 .068 0 r
F
.58205 .54838 m .58233 .54589 L .5659 .55029 L F
.37635 .43628 m .37739 .43378 L .3536 .42279 L 1 .711 0 r
F
.66024 .10318 m .65365 .1008 L .65644 .11245 L .346 .476 0 r
F
.52483 .59314 m .50677 .59285 L .50651 .59494 L .766 .1 0 r
F
.52483 .59314 m .52522 .59104 L .50677 .59285 L F
.62774 .8719 m .60036 .87298 L .59783 .87635 L .37 0 0 r
F
.62774 .8719 m .63088 .86843 L .60036 .87298 L F
.50908 .64203 m .48909 .64228 L .48885 .64419 L .667 .046 0 r
F
.50908 .64203 m .50958 .64016 L .48909 .64228 L F
.34954 .51119 m .33364 .50252 L .33352 .50533 L 1 .839 0 r
F
.34948 .51395 m .34954 .51119 L .33352 .50533 L 1 .829 0 r
F
.86359 .6536 m .84137 .66215 L .83961 .66854 L .068 0 0 r
F
.86359 .6536 m .86549 .64704 L .84137 .66215 L F
.46857 .60046 m .46857 .59841 L .44955 .5981 L .963 .269 0 r
F
.4874 .60009 m .46857 .59841 L .46857 .60046 L .902 .21 0 r
F
.4874 .60009 m .48754 .59806 L .46857 .59841 L F
.44683 .64359 m .42532 .64059 L .42579 .64277 L .943 .127 0 r
F
.44709 .64563 m .44683 .64359 L .42579 .64277 L .932 .107 0 r
F
.46807 .64539 m .44683 .64359 L .44709 .64563 L .854 .071 0 r
F
.75759 .79552 m .73285 .79977 L .72966 .80466 L .204 0 0 r
F
.75759 .79552 m .76116 .79048 L .73285 .79977 L F
.37739 .43378 m .36707 .42636 L .3536 .42279 L 1 1 0 r
F
.37739 .43378 m .37846 .43129 L .36707 .42636 L F
.54011 .2811 m .55975 .209 L .55077 .25134 L 1 .937 0 r
F
.54011 .2811 m .54565 .25137 L .55975 .209 L F
.41917 .36278 m .41438 .36132 L .41247 .36316 L 1 1 0 r
F
.41917 .36278 m .42085 .36076 L .41438 .36132 L F
.36458 .46956 m .35233 .4615 L .35156 .4641 L F
.36393 .47219 m .36458 .46956 L .35156 .4641 L F
.37321 .52947 m .35751 .522 L .3575 .52457 L 1 .796 0 r
F
.37323 .53201 m .37321 .52947 L .3575 .52457 L 1 .785 0 r
F
.52848 .35616 m .51875 .35661 L .51986 .35992 L .783 .55 0 r
F
.52976 .35939 m .52848 .35616 L .51986 .35992 L .779 .575 0 r
F
.7042 .28357 m .70813 .28197 L .70854 .28886 L .896 .148 0 r
F
.7042 .28357 m .70316 .27746 L .70813 .28197 L F
.54301 .58019 m .52571 .58072 L .52537 .58285 L .688 .071 0 r
F
.54301 .58019 m .54346 .57805 L .52571 .58072 L F
.52425 .58906 m .50641 .58885 L .50615 .59088 L .761 .092 0 r
F
.52425 .58906 m .52464 .58702 L .50641 .58885 L F
.18958 .77162 m .15794 .75573 L .16098 .76122 L 1 .23 0 r
F
.19239 .77686 m .18958 .77162 L .16098 .76122 L 1 .202 0 r
F
.8737 .34239 m .8601 .35662 L .8628 .36312 L .054 .039 0 r
F
.8737 .34239 m .87089 .33593 L .8601 .35662 L F
.41 .5825 m .39082 .57795 L .39124 .58025 L 1 .488 0 r
F
.41032 .58476 m .41 .5825 L .39124 .58025 L 1 .474 0 r
F
.44975 .59154 m .43093 .5881 L .43119 .59015 L 1 .343 0 r
F
.44989 .59354 m .44975 .59154 L .43119 .59015 L 1 .327 0 r
F
.46862 .59412 m .44975 .59154 L .44989 .59354 L .973 .276 0 r
F
.39731 .37868 m .39185 .37462 L .38966 .37637 L 1 1 0 r
F
.39731 .37868 m .39919 .37665 L .39185 .37462 L F
.32519 .48275 m .31376 .47246 L .31288 .4755 L F
.32444 .48585 m .32519 .48275 L .31288 .4755 L F
.54781 .37068 m .5374 .37216 L .53877 .37486 L .688 .557 0 r
F
.54934 .37333 m .54781 .37068 L .53877 .37486 L .684 .561 0 r
F
.38937 .56853 m .3705 .56291 L .37091 .56534 L 1 .57 0 r
F
.3897 .57092 m .38937 .56853 L .37091 .56534 L 1 .558 0 r
F
.37846 .43129 m .35635 .41737 L .36707 .42636 L .996 .709 0 r
F
.37846 .43129 m .37957 .42882 L .35635 .41737 L F
.54976 .37739 m .53935 .37869 L .54073 .38124 L .654 .562 0 r
F
.5513 .37987 m .54976 .37739 L .54073 .38124 L .652 .561 0 r
F
.24084 .81491 m .20779 .80201 L .21114 .80682 L 1 .101 0 r
F
.24384 .81947 m .24084 .81491 L .21114 .80682 L 1 .088 0 r
F
.41119 .57515 m .3931 .56981 L .39347 .57206 L 1 .518 0 r
F
.41148 .57735 m .41119 .57515 L .39347 .57206 L 1 .503 0 r
F
.46862 .59609 m .46862 .59412 L .44989 .59354 L .968 .259 0 r
F
.48724 .59587 m .46862 .59412 L .46862 .59609 L .902 .201 0 r
F
.48724 .59587 m .48738 .5939 L .46862 .59412 L F
.36574 .87367 m .332 .86678 L .33461 .87019 L .838 .053 0 r
F
.36777 .87687 m .36574 .87367 L .33461 .87019 L .815 .049 0 r
F
.36393 .47219 m .35156 .4641 L .35082 .4667 L 1 1 0 r
F
.3633 .47482 m .36393 .47219 L .35082 .4667 L F
.65879 .48754 m .64925 .49282 L .64855 .49617 L 0 0 0 r
F
.65879 .48754 m .65955 .4842 L .64925 .49282 L F
.40086 .36936 m .3962 .36621 L .39403 .36804 L 1 1 0 r
F
.40086 .36936 m .40282 .36736 L .3962 .36621 L F
.39163 .55822 m .37441 .55183 L .37468 .55423 L 1 .638 0 r
F
.39188 .56058 m .39163 .55822 L .37468 .55423 L 1 .624 0 r
F
.3523 .42553 m .35592 .42325 L .35463 .42565 L 0 0 0 r
F
.3523 .42553 m .3536 .42279 L .35593 .42324 L F
.35335 .42804 m .35463 .42565 L .34639 .41954 L 1 1 0 r
F
.35337 .42807 m .35463 .42565 L .35335 .42804 L F
.35592 .42325 m .35593 .42324 L .35463 .42565 L 0 0 0 r
F
.61685 .57243 m .60219 .5768 L .6013 .57942 L .254 .001 0 r
F
.61685 .57243 m .61784 .56978 L .60219 .5768 L F
.37957 .42882 m .35779 .4147 L .35635 .41737 L .991 .709 0 r
F
.37957 .42882 m .38069 .42636 L .35779 .4147 L F
.58043 .54477 m .56466 .54677 L .56443 .5492 L .539 .067 0 r
F
.58043 .54477 m .58071 .54232 L .56466 .54677 L F
.33415 .55537 m .31813 .54526 L .31822 .54837 L 1 .791 0 r
F
.3343 .55845 m .33415 .55537 L .31822 .54837 L 1 .777 0 r
F
.287 .84315 m .25333 .83266 L .25665 .83689 L .977 .076 0 r
F
.28988 .84714 m .287 .84315 L .25665 .83689 L .956 .072 0 r
F
.52725 .35267 m .51769 .35303 L .51875 .35661 L .786 .517 0 r
F
.52848 .35616 m .52725 .35267 L .51875 .35661 L .783 .55 0 r
F
.59615 .50908 m .58159 .51178 L .58169 .51439 L .478 .074 0 r
F
.59615 .50908 m .59604 .50646 L .58159 .51178 L F
.59837 .51485 m .58339 .51753 L .58345 .52017 L .484 .073 0 r
F
.59837 .51485 m .5983 .5122 L .58339 .51753 L F
.35635 .41737 m .36002 .41614 L .35863 .41849 L 0 0 0 r
F
.35635 .41737 m .35779 .4147 L .36003 .41614 L F
.36707 .42636 m .35635 .41737 L .35863 .41849 L 0 .024 0 r
F
.35724 .42083 m .35863 .41849 L .35067 .41254 L 1 1 0 r
F
.35726 .42086 m .35863 .41849 L .35724 .42083 L F
.36002 .41614 m .36003 .41614 L .35863 .41849 L 0 0 0 r
F
.43068 .58602 m .41213 .58168 L .41248 .58381 L 1 .418 0 r
F
.43093 .5881 m .43068 .58602 L .41248 .58381 L 1 .403 0 r
F
.63893 .53667 m .62643 .54175 L .62567 .54467 L .143 0 0 r
F
.63893 .53667 m .63975 .53372 L .62643 .54175 L F
.76019 .52646 m .74527 .53446 L .74474 .53919 L .052 0 0 r
F
.76019 .52646 m .76069 .52165 L .74527 .53446 L F
.07899 .60983 m .05401 .58592 L .05491 .59286 L 1 .619 0 r
F
.07994 .61659 m .07899 .60983 L .05491 .59286 L 1 .594 0 r
F
.36857 .54791 m .35062 .54088 L .3509 .54349 L 1 .673 0 r
F
.36883 .55045 m .36857 .54791 L .3509 .54349 L 1 .663 0 r
F
.39984 .88878 m .3661 .88326 L .3682 .88642 L .772 .043 0 r
F
.4013 .89177 m .39984 .88878 L .3682 .88642 L .748 .039 0 r
F
.43309 .89312 m .39984 .88878 L .4013 .89177 L .716 .036 0 r
F
.6779 .43057 m .6715 .43535 L .67035 .43959 L 0 0 0 r
F
.6779 .43057 m .67915 .4263 L .6715 .43535 L F
.38069 .42636 m .35929 .41206 L .35779 .4147 L .986 .708 0 r
F
.38069 .42636 m .38185 .42392 L .35929 .41206 L F
.3633 .47482 m .35082 .4667 L .35011 .46931 L 1 1 0 r
F
.36271 .47746 m .3633 .47482 L .35011 .46931 L F
.50597 .59903 m .48754 .59806 L .4874 .60009 L .832 .143 0 r
F
.50597 .59903 m .50624 .597 L .48754 .59806 L F
.40274 .63166 m .38174 .626 L .38246 .62852 L 1 .33 0 r
F
.40334 .63405 m .40274 .63166 L .38246 .62852 L 1 .31 0 r
F
.43387 .89596 m .43309 .89312 L .4013 .89177 L .691 .031 0 r
F
.46537 .89635 m .43309 .89312 L .43387 .89596 L .647 .026 0 r
F
.63932 .11526 m .63691 .12048 L .64327 .12325 L .3 .403 0 r
F
.63932 .11526 m .6362 .11475 L .63691 .12048 L F
.6362 .11475 m .63348 .11556 L .63691 .12048 L F
.63899 .11599 m .6362 .11475 L .63554 .12346 L .289 .371 0 r
F
.6362 .11475 m .63289 .11329 L .63348 .11556 L F
.6362 .11475 m .63348 .11556 L .63554 .12346 L F
.6362 .11475 m .63251 .11416 L .63348 .11556 L .3 .403 0 r
F
.35779 .4147 m .36145 .41382 L .36003 .41614 L 0 0 0 r
F
.35779 .4147 m .35929 .41206 L .36146 .41381 L F
.35861 .41846 m .36003 .41614 L .35217 .41025 L 1 1 0 r
F
.35863 .41849 m .36003 .41614 L .35861 .41846 L F
.36145 .41382 m .36146 .41381 L .36003 .41614 L 0 0 0 r
F
.32444 .48585 m .31288 .4755 L .31205 .47855 L 1 1 0 r
F
.32373 .48895 m .32444 .48585 L .31205 .47855 L F
.08809 .59995 m .0646 .57628 L .06525 .58308 L 1 .646 0 r
F
.08881 .60659 m .08809 .59995 L .06525 .58308 L 1 .623 0 r
F
.54629 .36798 m .53604 .3694 L .5374 .37216 L .691 .549 0 r
F
.54781 .37068 m .54629 .36798 L .5374 .37216 L .688 .557 0 r
F
.14563 .68967 m .11549 .67181 L .11765 .67781 L 1 .441 0 r
F
.14769 .69541 m .14563 .68967 L .11765 .67781 L 1 .418 0 r
F
.47958 .35846 m .47126 .35845 L .47121 .36093 L 1 1 0 r
F
.47958 .35846 m .47933 .35563 L .47126 .35845 L F
.33548 .82792 m .30147 .82374 L .30414 .82759 L .958 .077 0 r
F
.33763 .83164 m .33548 .82792 L .30414 .82759 L .943 .074 0 r
F
.70877 .83224 m .68324 .83519 L .68002 .83943 L .264 0 0 r
F
.70877 .83224 m .71246 .82785 L .68324 .83519 L F
.57261 .77185 m .55059 .7793 L .5494 .78289 L .284 0 0 r
F
.57261 .77185 m .57421 .76852 L .55059 .7793 L F
.5261 .34882 m .5167 .34906 L .51769 .35303 L .788 .476 0 r
F
.52725 .35267 m .5261 .34882 L .51769 .35303 L .786 .517 0 r
F
.76484 .41911 m .75947 .42692 L .75997 .4321 L 0 0 0 r
F
.76484 .41911 m .76399 .41411 L .75947 .42692 L F
.52696 .88716 m .49707 .88611 L .49643 .88882 L .498 .006 0 r
F
.52696 .88716 m .5283 .88445 L .49707 .88611 L F
.71349 .18639 m .71121 .19199 L .7144 .19846 L 0 0 0 r
F
.71349 .18639 m .71135 .17875 L .71121 .19199 L F
.54821 .37488 m .53797 .37611 L .53935 .37869 L .656 .561 0 r
F
.54976 .37739 m .54821 .37488 L .53935 .37869 L .654 .562 0 r
F
.80991 .74152 m .78625 .74752 L .78346 .75313 L .134 0 0 r
F
.80991 .74152 m .81298 .73574 L .78625 .74752 L F
.13015 .71461 m .10027 .69512 L .10271 .70139 L 1 .379 0 r
F
.13247 .72064 m .13015 .71461 L .10271 .70139 L 1 .352 0 r
F
.34948 .51395 m .33352 .50533 L .33343 .50814 L 1 .829 0 r
F
.34946 .51671 m .34948 .51395 L .33343 .50814 L 1 .818 0 r
F
.5056 .59485 m .48738 .5939 L .48724 .59587 L .83 .134 0 r
F
.5056 .59485 m .50588 .59288 L .48738 .5939 L F
.09687 .59054 m .07196 .56775 L .07268 .57438 L 1 .661 0 r
F
.09767 .59697 m .09687 .59054 L .07268 .57438 L 1 .639 0 r
F
.38185 .42392 m .36083 .40946 L .35929 .41206 L .707 .04 0 r
F
.35929 .41206 m .36293 .41151 L .36146 .41381 L 0 0 0 r
F
.35929 .41206 m .36083 .40946 L .36293 .41151 L F
.35596 .59432 m .33737 .58557 L .3379 .58851 L 1 .602 0 r
F
.35648 .59718 m .35596 .59432 L .3379 .58851 L 1 .586 0 r
F
.56276 .57183 m .5459 .57298 L .54553 .57527 L .617 .067 0 r
F
.56276 .57183 m .56321 .56952 L .5459 .57298 L F
.34546 .44236 m .34648 .43953 L .33423 .43289 L 1 1 0 r
F
.7254 .30709 m .72424 .30148 L .74065 .30044 L 1 .596 0 r
F
.37323 .53201 m .3575 .52457 L .35752 .52712 L 1 .785 0 r
F
.37328 .53454 m .37323 .53201 L .35752 .52712 L 1 .773 0 r
F
.36271 .47746 m .35011 .46931 L .34944 .47193 L 1 1 0 r
F
.36215 .4801 m .36271 .47746 L .34944 .47193 L 1 .999 0 r
F
.69901 .36633 m .69589 .37015 L .69425 .37607 L 0 0 0 r
F
.69901 .36633 m .70047 .3605 L .69589 .37015 L F
.43664 .34477 m .43296 .34772 L .43119 .34943 L .723 .224 0 r
F
.52918 .63711 m .51006 .63825 L .50958 .64016 L .568 .035 0 r
F
.52918 .63711 m .52991 .63522 L .51006 .63825 L F
.58173 .55085 m .56566 .55276 L .56539 .55521 L .544 .067 0 r
F
.58173 .55085 m .58205 .54838 L .56566 .55276 L F
.36083 .40946 m .36444 .40922 L .36293 .41151 L 0 0 0 r
F
.36083 .40946 m .36243 .40688 L .36444 .40922 L F
.69497 .65902 m .67576 .66387 L .67423 .66786 L .218 0 0 r
F
.69497 .65902 m .69681 .65505 L .67576 .66387 L F
.34546 .44236 m .33423 .43289 L .33308 .43569 L 1 1 0 r
F
.34448 .44521 m .34546 .44236 L .33308 .43569 L F
.42278 .35297 m .41898 .35306 L .41691 .35467 L .743 .639 0 r
F
.42278 .35297 m .4246 .35113 L .41898 .35306 L F
.89092 .51908 m .87358 .53091 L .87352 .53768 L 0 0 0 r
F
.89092 .51908 m .89105 .51222 L .87358 .53091 L F
.43017 .59293 m .411 .58921 L .41137 .5914 L 1 .403 0 r
F
.43042 .59508 m .43017 .59293 L .41137 .5914 L 1 .387 0 r
F
.56159 .56795 m .54504 .56921 L .54468 .57146 L .608 .066 0 r
F
.56159 .56795 m .56204 .56568 L .54504 .56921 L F
.87887 .34809 m .86524 .36239 L .86798 .36892 L .053 .039 0 r
F
.87887 .34809 m .87599 .34161 L .86524 .36239 L F
.32373 .48895 m .31205 .47855 L .31126 .48161 L 1 1 0 r
F
.32306 .49206 m .32373 .48895 L .31126 .48161 L F
.54478 .3652 m .53469 .36656 L .53604 .3694 L .694 .539 0 r
F
.54629 .36798 m .54478 .3652 L .53604 .3694 L .691 .549 0 r
F
.42532 .64059 m .40397 .63639 L .40461 .63871 L 1 .214 0 r
F
.42579 .64277 m .42532 .64059 L .40461 .63871 L 1 .193 0 r
F
.39919 .37665 m .39403 .37289 L .39185 .37462 L 1 1 0 r
F
.39919 .37665 m .40107 .37465 L .39403 .37289 L F
.59623 .51168 m .58169 .51439 L .58175 .51699 L .472 .072 0 r
F
.59623 .51168 m .59615 .50908 L .58169 .51439 L F
.57124 .6163 m .55396 .61905 L .55311 .62118 L .393 .016 0 r
F
.57124 .6163 m .57229 .61415 L .55396 .61905 L F
.44955 .5981 m .43042 .59508 L .43069 .59719 L 1 .334 0 r
F
.44969 .60017 m .44955 .5981 L .43069 .59719 L 1 .317 0 r
F
.46857 .60046 m .44955 .5981 L .44969 .60017 L .963 .269 0 r
F
.32713 .86951 m .29292 .86107 L .29606 .86484 L .893 .061 0 r
F
.32974 .87306 m .32713 .86951 L .29606 .86484 L .87 .057 0 r
F
.46809 .64732 m .46807 .64539 L .44709 .64563 L .841 .068 0 r
F
.48861 .64605 m .46807 .64539 L .46809 .64732 L .753 .057 0 r
F
.48861 .64605 m .48885 .64419 L .46807 .64539 L F
.5984 .51749 m .58345 .52017 L .58348 .5228 L .479 .071 0 r
F
.5984 .51749 m .59837 .51485 L .58345 .52017 L F
.36215 .4801 m .34944 .47193 L .3488 .47455 L 1 .999 0 r
F
.36161 .48274 m .36215 .4801 L .3488 .47455 L 1 .991 0 r
F
.59036 .8753 m .56261 .876 L .56065 .87895 L .398 0 0 r
F
.59036 .8753 m .59297 .87228 L .56261 .876 L F
.36243 .40688 m .36597 .40696 L .36444 .40922 L 0 0 0 r
F
.36243 .40688 m .36407 .40435 L .36597 .40696 L F
.37971 .61828 m .3596 .61113 L .36031 .61385 L 1 .449 0 r
F
.38036 .62089 m .37971 .61828 L .36031 .61385 L 1 .431 0 r
F
.54666 .37234 m .53659 .3735 L .53797 .37611 L .657 .558 0 r
F
.54821 .37488 m .54666 .37234 L .53797 .37611 L .656 .561 0 r
F
.42085 .36076 m .4163 .3595 L .41438 .36132 L 1 1 0 r
F
.42085 .36076 m .42255 .35877 L .4163 .3595 L F
.54337 .58634 m .52595 .58677 L .52559 .58892 L .688 .07 0 r
F
.54337 .58634 m .54384 .58418 L .52595 .58677 L F
.59128 .42637 m .57923 .42934 L .58032 .43195 L .5 .333 0 r
F
.59246 .42895 m .58032 .43195 L .58138 .43457 L .496 .323 0 r
F
.59246 .42895 m .59128 .42637 L .58032 .43195 L F
.5936 .43154 m .58138 .43457 L .58241 .43719 L .492 .312 0 r
F
.5936 .43154 m .59246 .42895 L .58138 .43457 L F
.59008 .4238 m .57811 .42673 L .57923 .42934 L .504 .344 0 r
F
.59128 .42637 m .59008 .4238 L .57923 .42934 L .5 .333 0 r
F
.20022 .75289 m .1675 .73954 L .17039 .74481 L 1 .284 0 r
F
.20285 .75792 m .20022 .75289 L .17039 .74481 L 1 .26 0 r
F
.59471 .43414 m .58241 .43719 L .58342 .43983 L .487 .301 0 r
F
.59471 .43414 m .5936 .43154 L .58241 .43719 L F
.58884 .42125 m .57697 .42414 L .57811 .42673 L .507 .354 0 r
F
.59008 .4238 m .58884 .42125 L .57811 .42673 L .504 .344 0 r
F
.58013 .5472 m .56443 .5492 L .56417 .55162 L .533 .066 0 r
F
.58013 .5472 m .58043 .54477 L .56443 .5492 L F
.63899 .11599 m .63554 .12346 L .64124 .12748 L .289 .371 0 r
F
.40282 .36736 m .39838 .36442 L .3962 .36621 L 1 1 0 r
F
.40282 .36736 m .40479 .36541 L .39838 .36442 L F
.59579 .43674 m .58342 .43983 L .58439 .44247 L .483 .289 0 r
F
.59579 .43674 m .59471 .43414 L .58342 .43983 L F
.3897 .57092 m .37091 .56534 L .37134 .56776 L 1 .558 0 r
F
.39005 .57328 m .3897 .57092 L .37134 .56776 L 1 .546 0 r
F
.58757 .4187 m .57579 .42156 L .57697 .42414 L .511 .365 0 r
F
.58884 .42125 m .58757 .4187 L .57697 .42414 L .507 .354 0 r
F
.39188 .56058 m .37468 .55423 L .37498 .55662 L 1 .624 0 r
F
.39215 .56292 m .39188 .56058 L .37498 .55662 L 1 .61 0 r
F
.3343 .55845 m .31822 .54837 L .31835 .55147 L 1 .777 0 r
F
.33449 .56152 m .3343 .55845 L .31835 .55147 L 1 .763 0 r
F
.52443 .5952 m .50651 .59494 L .50624 .597 L .759 .085 0 r
F
.52443 .5952 m .52483 .59314 L .50651 .59494 L F
.59683 .43936 m .58439 .44247 L .58533 .44512 L .479 .278 0 r
F
.59683 .43936 m .59579 .43674 L .58439 .44247 L F
.54254 .58231 m .52537 .58285 L .52501 .58495 L .681 .069 0 r
F
.54254 .58231 m .54301 .58019 L .52537 .58285 L F
.58628 .41616 m .57459 .41898 L .57579 .42156 L .515 .375 0 r
F
.58757 .4187 m .58628 .41616 L .57579 .42156 L .511 .365 0 r
F
.41032 .58476 m .39124 .58025 L .39168 .58253 L 1 .474 0 r
F
.41065 .587 m .41032 .58476 L .39168 .58253 L 1 .459 0 r
F
.36407 .40435 m .36754 .40472 L .36597 .40696 L 0 0 0 r
F
.36407 .40435 m .36576 .40186 L .36754 .40472 L F
.54329 .36233 m .53335 .36362 L .53469 .36656 L .697 .524 0 r
F
.54478 .3652 m .54329 .36233 L .53469 .36656 L .694 .539 0 r
F
.59329 .59926 m .57721 .60282 L .57627 .60515 L .328 .008 0 r
F
.59329 .59926 m .59438 .5969 L .57721 .60282 L F
.46857 .60247 m .46857 .60046 L .44969 .60017 L .957 .252 0 r
F
.48726 .6021 m .46857 .60046 L .46857 .60247 L .896 .194 0 r
F
.48726 .6021 m .4874 .60009 L .46857 .60046 L F
.40544 .83695 m .37293 .83714 L .37463 .84062 L .818 .062 0 r
F
.40658 .84036 m .40544 .83695 L .37463 .84062 L .801 .058 0 r
F
.43671 .83476 m .40544 .83695 L .40658 .84036 L .737 .053 0 r
F
.36161 .48274 m .3488 .47455 L .3482 .47717 L 1 .991 0 r
F
.36111 .48538 m .36161 .48274 L .3482 .47717 L 1 .983 0 r
F
.41148 .57735 m .39347 .57206 L .39385 .57429 L 1 .503 0 r
F
.4118 .57953 m .41148 .57735 L .39385 .57429 L 1 .488 0 r
F
.59924 .75127 m .57869 .75801 L .57725 .76159 L .242 0 0 r
F
.59924 .75127 m .6011 .74795 L .57869 .75801 L F
.59785 .44198 m .58533 .44512 L .58625 .44778 L .475 .266 0 r
F
.59785 .44198 m .59683 .43936 L .58533 .44512 L F
.34946 .51671 m .33343 .50814 L .33337 .51093 L 1 .818 0 r
F
.34947 .51945 m .34946 .51671 L .33337 .51093 L 1 .808 0 r
F
.58495 .41363 m .57337 .41641 L .57459 .41898 L .519 .384 0 r
F
.58628 .41616 m .58495 .41363 L .57459 .41898 L .515 .375 0 r
F
.52385 .59107 m .50615 .59088 L .50588 .59288 L .754 .078 0 r
F
.52385 .59107 m .52425 .58906 L .50615 .59088 L F
.52031 .8077 m .49459 .81472 L .49414 .81818 L .409 .014 0 r
F
.52031 .8077 m .52122 .80434 L .49459 .81472 L F
.6626 .84812 m .63687 .85058 L .63393 .85418 L .297 0 0 r
F
.6626 .84812 m .66608 .84441 L .63687 .85058 L F
.32306 .49206 m .31126 .48161 L .31052 .48468 L 1 1 0 r
F
.32244 .49518 m .32306 .49206 L .31052 .48468 L F
.36127 .29731 m .35779 .28577 L .36044 .29841 L .778 .119 0 r
F
.36537 .31172 m .36127 .29731 L .36044 .29841 L .798 .115 0 r
F
.36883 .55045 m .3509 .54349 L .35121 .54608 L 1 .663 0 r
F
.36912 .55298 m .36883 .55045 L .35121 .54608 L 1 .652 0 r
F
.62475 .86439 m .59805 .86594 L .59553 .86916 L .349 0 0 r
F
.62475 .86439 m .62786 .86109 L .59805 .86594 L F
.44989 .59354 m .43119 .59015 L .43146 .59217 L 1 .327 0 r
F
.45003 .59551 m .44989 .59354 L .43146 .59217 L 1 .31 0 r
F
.46862 .59609 m .44989 .59354 L .45003 .59551 L .968 .259 0 r
F
.85518 .64989 m .83474 .65889 L .8329 .66512 L .018 0 0 r
F
.85518 .64989 m .85715 .64352 L .83474 .65889 L F
.87638 .3489 m .8628 .36312 L .86537 .36966 L .042 .035 0 r
F
.87638 .3489 m .8737 .34239 L .8628 .36312 L F
.89891 .52683 m .87973 .53856 L .87973 .54546 L .018 0 0 r
F
.89891 .52683 m .89891 .51982 L .87973 .53856 L F
.37328 .53454 m .35752 .52712 L .35758 .52967 L 1 .773 0 r
F
.37336 .53706 m .37328 .53454 L .35758 .52967 L 1 .761 0 r
F
.59882 .44462 m .58625 .44778 L .58713 .45044 L .47 .255 0 r
F
.59882 .44462 m .59785 .44198 L .58625 .44778 L F
.65804 .49085 m .64855 .49617 L .64785 .49948 L 0 0 0 r
F
.65804 .49085 m .65879 .48754 L .64855 .49617 L F
.5836 .41111 m .57212 .41386 L .57337 .41641 L .522 .394 0 r
F
.58495 .41363 m .5836 .41111 L .57337 .41641 L .519 .384 0 r
F
.7517 .78904 m .728 .79385 L .72481 .79857 L .174 0 0 r
F
.7517 .78904 m .75526 .78417 L .728 .79385 L F
.72997 .60746 m .71181 .61343 L .71058 .61774 L .163 0 0 r
F
.72997 .60746 m .73138 .60309 L .71181 .61343 L F
.18709 .78249 m .15476 .76683 L .15801 .77232 L 1 .196 0 r
F
.19008 .78773 m .18709 .78249 L .15801 .77232 L 1 .167 0 r
F
.5451 .36977 m .5352 .37084 L .53659 .3735 L .659 .552 0 r
F
.54666 .37234 m .5451 .36977 L .53659 .3735 L .657 .558 0 r
F
.3418 .45381 m .34265 .45094 L .32992 .44418 L 1 1 0 r
F
.25098 .79181 m .21718 .78213 L .22029 .78678 L 1 .178 0 r
F
.25371 .79625 m .25098 .79181 L .22029 .78678 L 1 .154 0 r
F
.65973 .69819 m .64039 .70309 L .63874 .70684 L .23 0 0 r
F
.65973 .69819 m .66176 .69457 L .64039 .70309 L F
.47933 .35563 m .47131 .35591 L .47126 .35845 L 1 1 0 r
F
.47933 .35563 m .47909 .35264 L .47131 .35591 L F
.46863 .59802 m .46862 .59609 L .45003 .59551 L .962 .243 0 r
F
.4871 .5978 m .46862 .59609 L .46863 .59802 L .896 .185 0 r
F
.4871 .5978 m .48724 .59587 L .46862 .59609 L F
.59977 .44726 m .58713 .45044 L .58798 .45311 L .466 .243 0 r
F
.59977 .44726 m .59882 .44462 L .58713 .45044 L F
.59627 .51428 m .58175 .51699 L .58179 .51958 L .467 .07 0 r
F
.59627 .51428 m .59623 .51168 L .58175 .51699 L F
.58222 .40861 m .57084 .41131 L .57212 .41386 L .526 .403 0 r
F
.5836 .41111 m .58222 .40861 L .57212 .41386 L .522 .394 0 r
F
.54949 .62934 m .53133 .63131 L .53063 .63328 L .468 .024 0 r
F
.54949 .62934 m .55043 .62736 L .53133 .63131 L F
.36576 .40186 m .36915 .40251 L .36754 .40472 L 0 0 0 r
F
.36576 .40186 m .36751 .39942 L .36915 .40251 L F
.63809 .53958 m .62567 .54467 L .62489 .54757 L .139 0 0 r
F
.63809 .53958 m .63893 .53667 L .62567 .54467 L F
.54182 .35933 m .53204 .36054 L .53335 .36362 L .699 .505 0 r
F
.54329 .36233 m .54182 .35933 L .53335 .36362 L .697 .524 0 r
F
.43093 .5881 m .41248 .58381 L .41284 .5859 L 1 .403 0 r
F
.43119 .59015 m .43093 .5881 L .41284 .5859 L 1 .386 0 r
F
.36111 .48538 m .3482 .47717 L .34764 .47979 L 1 .983 0 r
F
.36065 .48801 m .36111 .48538 L .34764 .47979 L 1 .974 0 r
F
.5984 .52012 m .58348 .5228 L .58348 .52541 L .473 .07 0 r
F
.5984 .52012 m .5984 .51749 L .58348 .5228 L F
.58138 .55331 m .56539 .55521 L .56509 .55765 L .538 .065 0 r
F
.58138 .55331 m .58173 .55085 L .56539 .55521 L F
.61583 .57505 m .6013 .57942 L .60038 .58201 L .248 0 0 r
F
.61583 .57505 m .61685 .57243 L .6013 .57942 L F
.65373 .22562 m .67774 .19286 L .68017 .20018 L 1 .685 0 r
F
.65373 .22562 m .6523 .21828 L .67774 .19286 L F
.64595 .11685 m .63932 .11526 L .64327 .12325 L .308 .436 0 r
F
.60068 .4499 m .58798 .45311 L .5888 .45578 L .461 .231 0 r
F
.60068 .4499 m .59977 .44726 L .58798 .45311 L F
.58081 .40611 m .56954 .40876 L .57084 .41131 L .529 .412 0 r
F
.58222 .40861 m .58081 .40611 L .57084 .41131 L .526 .403 0 r
F
.40098 .88229 m .36777 .87687 L .36984 .87998 L .768 .042 0 r
F
.40242 .88521 m .40098 .88229 L .36984 .87998 L .743 .038 0 r
F
.43371 .88649 m .40098 .88229 L .40242 .88521 L .708 .034 0 r
F
.56227 .57411 m .54553 .57527 L .54514 .57753 L .611 .065 0 r
F
.56227 .57411 m .56276 .57183 L .54553 .57527 L F
.70505 .28968 m .70854 .28886 L .70871 .29573 L .88 .149 0 r
F
.70505 .28968 m .7042 .28357 L .70854 .28886 L F
.43448 .88925 m .43371 .88649 L .40242 .88521 L .683 .03 0 r
F
.46547 .88951 m .43371 .88649 L .43448 .88925 L .634 .024 0 r
F
.3713 .39085 m .37326 .38857 L .36571 .38471 L 1 1 0 r
F
.40107 .37465 m .39619 .37118 L .39403 .37289 L F
.40107 .37465 m .40297 .37268 L .39619 .37118 L F
.75964 .53125 m .74474 .53919 L .74415 .54391 L .048 0 0 r
F
.75964 .53125 m .76019 .52646 L .74474 .53919 L F
.3418 .45381 m .32992 .44418 L .32896 .44703 L 1 1 0 r
F
.34099 .45668 m .3418 .45381 L .32896 .44703 L F
.76565 .42411 m .75997 .4321 L .76042 .43724 L 0 0 0 r
F
.76565 .42411 m .76484 .41911 L .75997 .4321 L F
.50568 .60103 m .4874 .60009 L .48726 .6021 L .825 .127 0 r
F
.50568 .60103 m .50597 .59903 L .4874 .60009 L F
.32244 .49518 m .31052 .48468 L .30982 .48776 L 1 1 0 r
F
.32185 .49831 m .32244 .49518 L .30982 .48776 L F
.57937 .40362 m .56822 .40623 L .56954 .40876 L .533 .421 0 r
F
.58081 .40611 m .57937 .40362 L .56954 .40876 L .529 .412 0 r
F
.60155 .45256 m .5888 .45578 L .58959 .45846 L .456 .219 0 r
F
.60155 .45256 m .60068 .4499 L .5888 .45578 L F
.35648 .59718 m .3379 .58851 L .33847 .59143 L 1 .586 0 r
F
.35704 .60001 m .35648 .59718 L .33847 .59143 L 1 .569 0 r
F
.5404 .35617 m .53078 .35728 L .53204 .36054 L .699 .479 0 r
F
.54182 .35933 m .5404 .35617 L .53204 .36054 L .699 .505 0 r
F
.44709 .64563 m .42579 .64277 L .42627 .64491 L .932 .107 0 r
F
.44736 .64764 m .44709 .64563 L .42627 .64491 L .92 .087 0 r
F
.46809 .64732 m .44709 .64563 L .44736 .64764 L .841 .068 0 r
F
.36751 .39942 m .37079 .40033 L .36915 .40251 L 0 0 0 r
F
.36751 .39942 m .3693 .39703 L .37079 .40033 L F
.50858 .64386 m .48885 .64419 L .48861 .64605 L .651 .043 0 r
F
.50858 .64386 m .50908 .64203 L .48885 .64419 L F
.6767 .43473 m .67035 .43959 L .66926 .44373 L 0 0 0 r
F
.6767 .43473 m .6779 .43057 L .67035 .43959 L F
.58985 .42702 m .57805 .4299 L .57912 .43248 L .49 .323 0 r
F
.591 .42957 m .57912 .43248 L .58016 .43508 L .485 .311 0 r
F
.591 .42957 m .58985 .42702 L .57912 .43248 L F
.54354 .36715 m .53382 .36812 L .5352 .37084 L .66 .544 0 r
F
.5451 .36977 m .54354 .36715 L .5352 .37084 L .659 .552 0 r
F
.58867 .42448 m .57695 .42732 L .57805 .4299 L .494 .334 0 r
F
.58985 .42702 m .58867 .42448 L .57805 .4299 L .49 .323 0 r
F
.50531 .59679 m .48724 .59587 L .4871 .5978 L .823 .119 0 r
F
.50531 .59679 m .5056 .59485 L .48724 .59587 L F
.56112 .57019 m .54468 .57146 L .54429 .57368 L .602 .064 0 r
F
.56112 .57019 m .56159 .56795 L .54468 .57146 L F
.59211 .43214 m .58016 .43508 L .58117 .43768 L .481 .3 0 r
F
.59211 .43214 m .591 .42957 L .58016 .43508 L F
.36065 .48801 m .34764 .47979 L .34711 .48242 L 1 .974 0 r
F
.36021 .49065 m .36065 .48801 L .34711 .48242 L 1 .965 0 r
F
.58746 .42194 m .57583 .42475 L .57695 .42732 L .498 .345 0 r
F
.58867 .42448 m .58746 .42194 L .57695 .42732 L .494 .334 0 r
F
.59319 .43471 m .58117 .43768 L .58215 .44029 L .477 .288 0 r
F
.59319 .43471 m .59211 .43214 L .58117 .43768 L F
.57979 .54962 m .56417 .55162 L .56388 .55401 L .527 .064 0 r
F
.57979 .54962 m .58013 .5472 L .56417 .55162 L F
.58621 .41942 m .57467 .42219 L .57583 .42475 L .502 .356 0 r
F
.58746 .42194 m .58621 .41942 L .57583 .42475 L .498 .345 0 r
F
.57791 .40114 m .56687 .4037 L .56822 .40623 L .536 .429 0 r
F
.57937 .40362 m .57791 .40114 L .56822 .40623 L .533 .421 0 r
F
.29633 .81582 m .26231 .80916 L .26531 .81332 L 1 .104 0 r
F
.29887 .81982 m .29633 .81582 L .26531 .81332 L 1 .082 0 r
F
.70398 .82515 m .67933 .82863 L .67612 .83271 L .238 0 0 r
F
.70398 .82515 m .70765 .82093 L .67933 .82863 L F
.34947 .51945 m .33337 .51093 L .33336 .51372 L 1 .808 0 r
F
.3495 .52218 m .34947 .51945 L .33336 .51372 L 1 .797 0 r
F
.59424 .43729 m .58215 .44029 L .5831 .44291 L .472 .276 0 r
F
.59424 .43729 m .59319 .43471 L .58215 .44029 L F
.60239 .45522 m .58959 .45846 L .59034 .46115 L .452 .207 0 r
F
.60239 .45522 m .60155 .45256 L .58959 .45846 L F
.40479 .36541 m .40057 .36268 L .39838 .36442 L .994 1 0 r
F
.40479 .36541 m .40678 .3635 L .40057 .36268 L F
.53903 .35279 m .52956 .35379 L .53078 .35728 L .698 .447 0 r
F
.5404 .35617 m .53903 .35279 L .53078 .35728 L .699 .479 0 r
F
.58494 .41691 m .57349 .41964 L .57467 .42219 L .505 .367 0 r
F
.58621 .41942 m .58494 .41691 L .57467 .42219 L .502 .356 0 r
F
.34099 .45668 m .32896 .44703 L .32805 .44989 L 1 1 0 r
F
.34023 .45956 m .34099 .45668 L .32805 .44989 L F
.80275 .73601 m .78041 .74257 L .7776 .74801 L .097 0 0 r
F
.80275 .73601 m .80584 .7304 L .78041 .74257 L F
.53775 .3491 m .52843 .34995 L .52956 .35379 L .695 .406 0 r
F
.4246 .35113 m .42106 .35151 L .41898 .35306 L .7 .504 0 r
F
.4246 .35113 m .42643 .34936 L .42106 .35151 L F
.72676 .31247 m .7254 .30709 L .7418 .30661 L 1 .552 0 r
F
.59526 .43988 m .5831 .44291 L .58401 .44553 L .468 .264 0 r
F
.59526 .43988 m .59424 .43729 L .5831 .44291 L F
.33449 .56152 m .31835 .55147 L .31853 .55456 L 1 .763 0 r
F
.33472 .56457 m .33449 .56152 L .31853 .55456 L 1 .748 0 r
F
.39215 .56292 m .37498 .55662 L .37532 .55898 L 1 .61 0 r
F
.39244 .56524 m .39215 .56292 L .37532 .55898 L 1 .596 0 r
F
.67373 .10742 m .67016 .11721 L .67677 .12009 L .332 .454 0 r
F
.67373 .10742 m .66714 .10499 L .67016 .11721 L F
.37336 .53706 m .35758 .52967 L .35767 .5322 L 1 .761 0 r
F
.37346 .53956 m .37336 .53706 L .35767 .5322 L 1 .749 0 r
F
.42255 .35877 m .41823 .35772 L .4163 .3595 L .979 1 0 r
F
.42255 .35877 m .42425 .35682 L .41823 .35772 L F
.43042 .59508 m .41137 .5914 L .41176 .59356 L 1 .387 0 r
F
.43069 .59719 m .43042 .59508 L .41176 .59356 L 1 .371 0 r
F
.53903 .35279 m .53775 .3491 L .52956 .35379 L .698 .447 0 r
F
.40334 .63405 m .38246 .62852 L .38322 .63101 L 1 .31 0 r
F
.40397 .63639 m .40334 .63405 L .38322 .63101 L 1 .291 0 r
F
.59627 .51687 m .58179 .51958 L .58179 .52216 L .461 .069 0 r
F
.59627 .51687 m .59627 .51428 L .58179 .51958 L F
.58363 .41441 m .57228 .4171 L .57349 .41964 L .509 .377 0 r
F
.58494 .41691 m .58363 .41441 L .57349 .41964 L .505 .367 0 r
F
.71424 .19541 m .7144 .19846 L .71709 .20532 L 0 0 0 r
F
.71424 .19541 m .71376 .19006 L .7144 .19846 L F
.71303 .2063 m .71424 .19541 L .71539 .19943 L .901 .186 0 r
F
.71303 .2063 m .71539 .19943 L .71709 .20532 L F
.71115 .21178 m .71303 .2063 L .70926 .21953 L .746 .184 0 r
F
.71464 .19995 m .71424 .19541 L .71303 .2063 L 0 0 0 r
F
.71959 .18036 m .71424 .19541 L .71464 .19995 L F
.71522 .19505 m .71303 .2063 L .71115 .21178 L .746 .184 0 r
F
.71424 .19541 m .71349 .18639 L .71376 .19006 L 0 0 0 r
F
.86156 .66013 m .83961 .66854 L .83773 .67488 L .06 0 0 r
F
.86156 .66013 m .86359 .6536 L .83961 .66854 L F
.23985 .82542 m .20638 .81278 L .20991 .81755 L 1 .087 0 r
F
.24301 .82995 m .23985 .82542 L .20991 .81755 L 1 .084 0 r
F
.6275 .72815 m .60793 .73392 L .60631 .73753 L .225 0 0 r
F
.6275 .72815 m .62954 .72475 L .60793 .73392 L F
.57643 .39867 m .56551 .40118 L .56687 .4037 L .539 .437 0 r
F
.57791 .40114 m .57643 .39867 L .56687 .4037 L .536 .429 0 r
F
.59623 .44248 m .58401 .44553 L .5849 .44816 L .463 .252 0 r
F
.59623 .44248 m .59526 .43988 L .58401 .44553 L F
.88163 .35463 m .86798 .36892 L .87061 .3755 L .042 .036 0 r
F
.88163 .35463 m .87887 .34809 L .86798 .36892 L F
.39005 .57328 m .37134 .56776 L .3718 .57016 L 1 .546 0 r
F
.39043 .57563 m .39005 .57328 L .3718 .57016 L 1 .534 0 r
F
.32945 .86328 m .29584 .85486 L .29891 .85858 L .894 .061 0 r
F
.332 .86678 m .32945 .86328 L .29891 .85858 L .871 .057 0 r
F
.37326 .38857 m .36789 .38263 L .36571 .38471 L 1 1 0 r
F
.37326 .38857 m .37525 .38633 L .36789 .38263 L F
.3693 .39703 m .37246 .39817 L .37079 .40033 L 0 0 0 r
F
.3693 .39703 m .37114 .39468 L .37246 .39817 L F
.60319 .45788 m .59034 .46115 L .59107 .46383 L .447 .194 0 r
F
.60319 .45788 m .60239 .45522 L .59034 .46115 L F
.58229 .41192 m .57104 .41457 L .57228 .4171 L .513 .387 0 r
F
.58363 .41441 m .58229 .41192 L .57228 .4171 L .509 .377 0 r
F
.59836 .52274 m .58348 .52541 L .58345 .52802 L .467 .068 0 r
F
.59836 .52274 m .5984 .52012 L .58348 .52541 L F
.54287 .58848 m .52559 .58892 L .52522 .59104 L .681 .068 0 r
F
.54287 .58848 m .54337 .58634 L .52559 .58892 L F
.44969 .60017 m .43069 .59719 L .43097 .59927 L 1 .317 0 r
F
.44984 .6022 m .44969 .60017 L .43097 .59927 L 1 .299 0 r
F
.46857 .60247 m .44969 .60017 L .44984 .6022 L .957 .252 0 r
F
.13733 .70969 m .10857 .69032 L .11088 .6965 L 1 .386 0 r
F
.13955 .71563 m .13733 .70969 L .11088 .6965 L 1 .359 0 r
F
.36912 .55298 m .35121 .54608 L .35155 .54866 L 1 .652 0 r
F
.36943 .55549 m .36912 .55298 L .35155 .54866 L 1 .64 0 r
F
.32185 .49831 m .30982 .48776 L .30916 .49085 L 1 1 0 r
F
.32131 .50143 m .32185 .49831 L .30916 .49085 L 1 .993 0 r
F
.36021 .49065 m .34711 .48242 L .34662 .48505 L 1 .965 0 r
F
.35981 .49329 m .36021 .49065 L .34662 .48505 L 1 .956 0 r
F
.59718 .44508 m .5849 .44816 L .58575 .4508 L .458 .24 0 r
F
.59718 .44508 m .59623 .44248 L .5849 .44816 L F
.542 .36445 m .53245 .36533 L .53382 .36812 L .66 .532 0 r
F
.54354 .36715 m .542 .36445 L .53382 .36812 L .66 .544 0 r
F
.6731 .10859 m .66953 .11835 L .67594 .12155 L .301 .385 0 r
F
.6731 .10859 m .66674 .10575 L .66953 .11835 L F
.58092 .40945 m .56978 .41205 L .57104 .41457 L .516 .397 0 r
F
.58229 .41192 m .58092 .40945 L .57104 .41457 L .513 .387 0 r
F
.34023 .45956 m .32805 .44989 L .32719 .45276 L 1 1 0 r
F
.3395 .46244 m .34023 .45956 L .32719 .45276 L F
.41065 .587 m .39168 .58253 L .39214 .58478 L 1 .459 0 r
F
.411 .58921 m .41065 .587 L .39214 .58478 L 1 .444 0 r
F
.57492 .3962 m .56412 .39867 L .56551 .40118 L .543 .444 0 r
F
.57643 .39867 m .57492 .3962 L .56551 .40118 L .539 .437 0 r
F
.4118 .57953 m .39385 .57429 L .39426 .57649 L 1 .488 0 r
F
.41213 .58168 m .4118 .57953 L .39426 .57649 L 1 .472 0 r
F
.54205 .5844 m .52501 .58495 L .52464 .58702 L .675 .067 0 r
F
.54205 .5844 m .54254 .58231 L .52501 .58495 L F
.08881 .60659 m .06525 .58308 L .06602 .58986 L 1 .623 0 r
F
.08966 .61321 m .08881 .60659 L .06602 .58986 L 1 .598 0 r
F
.46615 .83069 m .46611 .82731 L .43671 .83476 L .63 .041 0 r
F
.49368 .82154 m .46611 .82731 L .46615 .83069 L .515 .028 0 r
F
.49368 .82154 m .49414 .81818 L .46611 .82731 L F
.07994 .61659 m .05491 .59286 L .05593 .59978 L 1 .594 0 r
F
.081 .62332 m .07994 .61659 L .05593 .59978 L 1 .569 0 r
F
.4373 .83812 m .43671 .83476 L .40658 .84036 L .718 .05 0 r
F
.46615 .83069 m .43671 .83476 L .4373 .83812 L .63 .041 0 r
F
.59809 .44769 m .58575 .4508 L .58658 .45344 L .453 .227 0 r
F
.59809 .44769 m .59718 .44508 L .58575 .4508 L F
.47909 .35264 m .47136 .35329 L .47131 .35591 L 1 1 0 r
F
.47909 .35264 m .47885 .34943 L .47136 .35329 L F
.60396 .46055 m .59107 .46383 L .59176 .46652 L .442 .182 0 r
F
.60396 .46055 m .60319 .45788 L .59107 .46383 L F
.524 .59724 m .50624 .597 L .50597 .59903 L .752 .073 0 r
F
.524 .59724 m .52443 .5952 L .50624 .597 L F
.09767 .59697 m .07268 .57438 L .07353 .58099 L 1 .639 0 r
F
.09857 .60338 m .09767 .59697 L .07353 .58099 L 1 .616 0 r
F
.57953 .40698 m .56849 .40953 L .56978 .41205 L .52 .407 0 r
F
.58092 .40945 m .57953 .40698 L .56978 .41205 L .516 .397 0 r
F
.38036 .62089 m .36031 .61385 L .36107 .61654 L 1 .431 0 r
F
.38103 .62346 m .38036 .62089 L .36107 .61654 L 1 .413 0 r
F
.58099 .55575 m .56509 .55765 L .56477 .56006 L .531 .063 0 r
F
.58099 .55575 m .58138 .55331 L .56509 .55765 L F
.65729 .49412 m .64785 .49948 L .64715 .50276 L 0 0 0 r
F
.65729 .49412 m .65804 .49085 L .64785 .49948 L F
.64479 .11926 m .64124 .12748 L .64654 .13215 L .26 .291 0 r
F
.64479 .11926 m .63899 .11599 L .64124 .12748 L F
.89066 .52594 m .87352 .53768 L .87335 .54444 L 0 0 0 r
F
.89066 .52594 m .89092 .51908 L .87352 .53768 L F
.69751 .37202 m .69425 .37607 L .69259 .38181 L F
.69751 .37202 m .69901 .36633 L .69425 .37607 L F
.52343 .59306 m .50588 .59288 L .5056 .59485 L .748 .072 0 r
F
.52343 .59306 m .52385 .59107 L .50588 .59288 L F
.40297 .37268 m .39834 .36946 L .39619 .37118 L 1 1 0 r
F
.40297 .37268 m .40486 .37074 L .39834 .36946 L F
.59896 .45031 m .58658 .45344 L .58737 .45609 L .448 .215 0 r
F
.59896 .45031 m .59809 .44769 L .58658 .45344 L F
.57339 .39374 m .56271 .39616 L .56412 .39867 L .546 .451 0 r
F
.57492 .3962 m .57339 .39374 L .56412 .39867 L .543 .444 0 r
F
.46858 .60446 m .46857 .60247 L .44984 .6022 L .951 .234 0 r
F
.48712 .60407 m .46857 .60247 L .46858 .60446 L .889 .176 0 r
F
.48712 .60407 m .48726 .6021 L .46857 .60247 L F
.57017 .61842 m .55311 .62118 L .55223 .62328 L .386 .013 0 r
F
.57017 .61842 m .57124 .6163 L .55311 .62118 L F
.52843 .63896 m .50958 .64016 L .50908 .64203 L .552 .031 0 r
F
.52843 .63896 m .52918 .63711 L .50958 .64016 L F
.37114 .39468 m .37416 .39604 L .37246 .39817 L 0 0 0 r
F
.37114 .39468 m .37303 .3924 L .37416 .39604 L F
.55819 .89203 m .5293 .89153 L .52794 .89437 L .45 0 0 r
F
.55819 .89203 m .56024 .88914 L .5293 .89153 L F
.5781 .40453 m .56718 .40703 L .56849 .40953 L .523 .416 0 r
F
.57953 .40698 m .5781 .40453 L .56849 .40953 L .52 .407 0 r
F
.45003 .59551 m .43146 .59217 L .43175 .59416 L 1 .31 0 r
F
.45018 .59746 m .45003 .59551 L .43175 .59416 L 1 .293 0 r
F
.46863 .59802 m .45003 .59551 L .45018 .59746 L .962 .243 0 r
F
.35981 .49329 m .34662 .48505 L .34616 .48768 L 1 .956 0 r
F
.35944 .49593 m .35981 .49329 L .34616 .48768 L 1 .947 0 r
F
.87893 .35546 m .86537 .36966 L .86783 .37623 L .03 .031 0 r
F
.87893 .35546 m .87638 .3489 L .86537 .36966 L F
.60469 .46323 m .59176 .46652 L .59242 .46922 L .437 .169 0 r
F
.60469 .46323 m .60396 .46055 L .59176 .46652 L F
.3395 .46244 m .32719 .45276 L .32637 .45563 L 1 1 0 r
F
.33882 .46532 m .3395 .46244 L .32637 .45563 L F
.54046 .36167 m .53109 .36243 L .53245 .36533 L .66 .515 0 r
F
.542 .36445 m .54046 .36167 L .53245 .36533 L .66 .532 0 r
F
.42579 .64277 m .40461 .63871 L .40527 .64099 L 1 .193 0 r
F
.42627 .64491 m .42579 .64277 L .40527 .64099 L 1 .173 0 r
F
.3495 .52218 m .33336 .51372 L .33338 .51649 L 1 .797 0 r
F
.34957 .52489 m .3495 .52218 L .33338 .51649 L 1 .786 0 r
F
.37525 .38633 m .37009 .3806 L .36789 .38263 L 1 1 0 r
F
.37525 .38633 m .37726 .38414 L .37009 .3806 L F
.69306 .66294 m .67423 .66786 L .67263 .6718 L .204 0 0 r
F
.69306 .66294 m .69497 .65902 L .67423 .66786 L F
.63723 .54247 m .62489 .54757 L .62409 .55045 L .134 0 0 r
F
.63723 .54247 m .63809 .53958 L .62489 .54757 L F
.59624 .51945 m .58179 .52216 L .58177 .52473 L .455 .067 0 r
F
.59624 .51945 m .59627 .51687 L .58179 .52216 L F
.32131 .50143 m .30916 .49085 L .30855 .49394 L 1 .993 0 r
F
.32081 .50456 m .32131 .50143 L .30855 .49394 L 1 .982 0 r
F
.56176 .57638 m .54514 .57753 L .54473 .57977 L .604 .063 0 r
F
.56176 .57638 m .56227 .57411 L .54514 .57753 L F
.5998 .45293 m .58737 .45609 L .58813 .45874 L .443 .202 0 r
F
.5998 .45293 m .59896 .45031 L .58737 .45609 L F
.28685 .85327 m .25295 .84302 L .25642 .8472 L .953 .072 0 r
F
.28985 .85722 m .28685 .85327 L .25642 .8472 L .931 .068 0 r
F
.59217 .60159 m .57627 .60515 L .57531 .60746 L .321 .005 0 r
F
.59217 .60159 m .59329 .59926 L .57627 .60515 L F
.14769 .69541 m .11765 .67781 L .11992 .68376 L 1 .418 0 r
F
.14985 .7011 m .14769 .69541 L .11992 .68376 L 1 .394 0 r
F
.43119 .59015 m .41284 .5859 L .41323 .58797 L 1 .386 0 r
F
.43146 .59217 m .43119 .59015 L .41323 .58797 L 1 .37 0 r
F
.57665 .40208 m .56584 .40454 L .56718 .40703 L .526 .425 0 r
F
.5781 .40453 m .57665 .40208 L .56718 .40703 L .523 .416 0 r
F
.57184 .39129 m .56128 .39365 L .56271 .39616 L .549 .458 0 r
F
.57339 .39374 m .57184 .39129 L .56271 .39616 L .546 .451 0 r
F
.46863 .59992 m .46863 .59802 L .45018 .59746 L .956 .226 0 r
F
.48695 .5997 m .46863 .59802 L .46863 .59992 L .89 .168 0 r
F
.48695 .5997 m .4871 .5978 L .46863 .59802 L F
.37346 .53956 m .35767 .5322 L .35779 .53472 L 1 .749 0 r
F
.37359 .54204 m .37346 .53956 L .35779 .53472 L 1 .736 0 r
F
.57942 .55202 m .56388 .55401 L .56356 .55639 L .521 .062 0 r
F
.57942 .55202 m .57979 .54962 L .56388 .55401 L F
.54558 .79305 m .5221 .80086 L .52122 .80434 L .325 0 0 r
F
.54558 .79305 m .5469 .78977 L .5221 .80086 L F
.46811 .6492 m .46809 .64732 L .44736 .64764 L .828 .065 0 r
F
.48837 .64787 m .46809 .64732 L .46811 .6492 L .738 .054 0 r
F
.48837 .64787 m .48861 .64605 L .46809 .64732 L F
.59828 .52535 m .58345 .52802 L .58339 .53061 L .461 .066 0 r
F
.59828 .52535 m .59836 .52274 L .58345 .52802 L F
.19239 .77686 m .16098 .76122 L .16411 .76664 L 1 .202 0 r
F
.19529 .78204 m .19239 .77686 L .16411 .76664 L 1 .173 0 r
F
.7664 .4291 m .76042 .43724 L .76083 .44237 L 0 0 0 r
F
.7664 .4291 m .76565 .42411 L .76042 .43724 L F
.40678 .3635 m .40277 .36097 L .40057 .36268 L .967 1 0 r
F
.40678 .3635 m .40878 .36163 L .40277 .36097 L F
.6006 .45556 m .58813 .45874 L .58885 .46139 L .438 .19 0 r
F
.6006 .45556 m .5998 .45293 L .58813 .45874 L F
.61479 .57764 m .60038 .58201 L .59944 .58457 L .242 0 0 r
F
.61479 .57764 m .61583 .57505 L .60038 .58201 L F
.60538 .46591 m .59242 .46922 L .59304 .47191 L .432 .157 0 r
F
.60538 .46591 m .60469 .46323 L .59242 .46922 L F
.56062 .57241 m .54429 .57368 L .54388 .57588 L .595 .063 0 r
F
.56062 .57241 m .56112 .57019 L .54429 .57368 L F
.37293 .83714 m .33983 .83529 L .34209 .83885 L .881 .067 0 r
F
.37463 .84062 m .37293 .83714 L .34209 .83885 L .865 .064 0 r
F
.57517 .39965 m .56448 .40205 L .56584 .40454 L .529 .434 0 r
F
.57665 .40208 m .57517 .39965 L .56584 .40454 L .526 .425 0 r
F
.33472 .56457 m .31853 .55456 L .31875 .55764 L 1 .748 0 r
F
.33498 .56761 m .33472 .56457 L .31875 .55764 L 1 .733 0 r
F
.53896 .35877 m .52976 .35939 L .53109 .36243 L .66 .493 0 r
F
.54046 .36167 m .53896 .35877 L .53109 .36243 L .66 .515 0 r
F
.39244 .56524 m .37532 .55898 L .37567 .56132 L 1 .596 0 r
F
.39276 .56754 m .39244 .56524 L .37567 .56132 L 1 .581 0 r
F
.13247 .72064 m .10271 .70139 L .10526 .70762 L 1 .352 0 r
F
.1349 .72663 m .13247 .72064 L .10526 .70762 L 1 .324 0 r
F
.37303 .3924 m .3659 .38488 L .37416 .39604 L 1 1 0 r
F
.37303 .3924 m .37497 .39017 L .3659 .38488 L F
.57027 .38883 m .55983 .39114 L .56128 .39365 L .552 .463 0 r
F
.57184 .39129 m .57027 .38883 L .56128 .39365 L .549 .458 0 r
F
.33882 .46532 m .32637 .45563 L .32559 .4585 L 1 1 0 r
F
.33818 .46821 m .33882 .46532 L .32559 .4585 L F
.35704 .60001 m .33847 .59143 L .33907 .59433 L 1 .569 0 r
F
.35763 .60283 m .35704 .60001 L .33907 .59433 L 1 .552 0 r
F
.35944 .49593 m .34616 .48768 L .34574 .49031 L 1 .947 0 r
F
.3591 .49856 m .35944 .49593 L .34574 .49031 L 1 .938 0 r
F
.50538 .603 m .48726 .6021 L .48712 .60407 L .818 .11 0 r
F
.50538 .603 m .50568 .60103 L .48726 .6021 L F
.8988 .53385 m .87973 .54546 L .87962 .55235 L .009 0 0 r
F
.8988 .53385 m .89891 .52683 L .87973 .54546 L F
.72849 .6118 m .71058 .61774 L .70929 .62201 L .153 0 0 r
F
.72849 .6118 m .72997 .60746 L .71058 .61774 L F
.75902 .53602 m .74415 .54391 L .74352 .5486 L .044 0 0 r
F
.75902 .53602 m .75964 .53125 L .74415 .54391 L F
.75393 .80049 m .72966 .80466 L .72639 .80946 L .195 0 0 r
F
.75393 .80049 m .75759 .79552 L .72966 .80466 L F
.36943 .55549 m .35155 .54866 L .35191 .55122 L 1 .64 0 r
F
.36976 .55798 m .36943 .55549 L .35191 .55122 L 1 .629 0 r
F
.60136 .4582 m .58885 .46139 L .58955 .46404 L .433 .177 0 r
F
.60136 .4582 m .6006 .45556 L .58885 .46139 L F
.42425 .35682 m .42018 .35598 L .41823 .35772 L .943 .972 0 r
F
.42425 .35682 m .42596 .3549 L .42018 .35598 L F
.57367 .39723 m .56309 .39957 L .56448 .40205 L .532 .442 0 r
F
.57517 .39965 m .57367 .39723 L .56448 .40205 L .529 .434 0 r
F
.50501 .5987 m .4871 .5978 L .48695 .5997 L .817 .103 0 r
F
.50501 .5987 m .50531 .59679 L .4871 .5978 L F
.39043 .57563 m .3718 .57016 L .37228 .57253 L 1 .534 0 r
F
.39082 .57795 m .39043 .57563 L .37228 .57253 L 1 .52 0 r
F
.37726 .38414 m .37232 .37861 L .37009 .3806 L 1 1 0 r
F
.37726 .38414 m .37929 .38198 L .37232 .37861 L F
.60604 .46859 m .59304 .47191 L .59363 .47461 L .427 .144 0 r
F
.60604 .46859 m .60538 .46591 L .59304 .47191 L F
.80673 .74725 m .78346 .75313 L .78057 .75867 L .125 0 0 r
F
.80673 .74725 m .80991 .74152 L .78346 .75313 L F
.32081 .50456 m .30855 .49394 L .30798 .49704 L 1 .982 0 r
F
.32035 .5077 m .32081 .50456 L .30798 .49704 L 1 .971 0 r
F
.47885 .34943 m .47141 .35054 L .47136 .35329 L 1 1 0 r
F
.47885 .34943 m .47862 .3459 L .47141 .35054 L F
.67555 .43879 m .66926 .44373 L .66821 .44777 L 0 0 0 r
F
.67555 .43879 m .6767 .43473 L .66926 .44373 L F
.42643 .34936 m .42314 .35002 L .42106 .35151 L .662 .352 0 r
F
.42643 .34936 m .42828 .34764 L .42314 .35002 L F
.46544 .89905 m .46537 .89635 L .43387 .89596 L .622 .021 0 r
F
.49621 .89853 m .46537 .89635 L .46544 .89905 L .566 .014 0 r
F
.49621 .89853 m .49686 .89582 L .46537 .89635 L F
.68027 .10998 m .67677 .12009 L .68332 .1231 L .321 .431 0 r
F
.68027 .10998 m .67373 .10742 L .67677 .12009 L F
.56868 .38638 m .55837 .38863 L .55983 .39114 L .555 .469 0 r
F
.57027 .38883 m .56868 .38638 L .55983 .39114 L .552 .463 0 r
F
.54854 .63128 m .53063 .63328 L .52991 .63522 L .453 .02 0 r
F
.54854 .63128 m .54949 .62934 L .53063 .63328 L F
.53749 .3557 m .52848 .35616 L .52976 .35939 L .657 .464 0 r
F
.53896 .35877 m .53749 .3557 L .52976 .35939 L .66 .493 0 r
F
.3661 .88326 m .33239 .87652 L .33509 .87987 L .816 .049 0 r
F
.3682 .88642 m .3661 .88326 L .33509 .87987 L .791 .045 0 r
F
.43069 .59719 m .41176 .59356 L .41216 .59569 L 1 .371 0 r
F
.43097 .59927 m .43069 .59719 L .41216 .59569 L 1 .354 0 r
F
.65633 .23106 m .68017 .20018 L .68252 .20733 L 1 .547 0 r
F
.65633 .23106 m .65373 .22562 L .68017 .20018 L F
.59618 .52201 m .58177 .52473 L .58171 .52728 L .449 .065 0 r
F
.59618 .52201 m .59624 .51945 L .58177 .52473 L F
.70571 .29578 m .70871 .29573 L .70867 .30257 L .861 .15 0 r
F
.70571 .29578 m .70505 .28968 L .70871 .29573 L F
.60209 .46084 m .58955 .46404 L .59021 .4667 L .428 .164 0 r
F
.60209 .46084 m .60136 .4582 L .58955 .46404 L F
.58058 .55817 m .56477 .56006 L .56442 .56246 L .525 .061 0 r
F
.58058 .55817 m .58099 .55575 L .56477 .56006 L F
.40486 .37074 m .40046 .36772 L .39834 .36946 L 1 1 0 r
F
.40486 .37074 m .40676 .36881 L .40046 .36772 L F
.57214 .39481 m .56169 .3971 L .56309 .39957 L .534 .45 0 r
F
.57367 .39723 m .57214 .39481 L .56309 .39957 L .532 .442 0 r
F
.72829 .31766 m .72676 .31247 L .74293 .31266 L 1 .503 0 r
F
.54235 .59059 m .52522 .59104 L .52483 .59314 L .674 .066 0 r
F
.54235 .59059 m .54287 .58848 L .52522 .59104 L F
.33818 .46821 m .32559 .4585 L .32486 .46138 L 1 1 0 r
F
.33759 .47109 m .33818 .46821 L .32486 .46138 L F
.34957 .52489 m .33338 .51649 L .33344 .51925 L 1 .786 0 r
F
.34967 .52759 m .34957 .52489 L .33344 .51925 L 1 .774 0 r
F
.24384 .81947 m .21114 .80682 L .21457 .81154 L 1 .088 0 r
F
.24693 .82395 m .24384 .81947 L .21457 .81154 L 1 .085 0 r
F
.88428 .36121 m .87061 .3755 L .87313 .38211 L .032 .033 0 r
F
.88428 .36121 m .88163 .35463 L .87061 .3755 L F
.41213 .58168 m .39426 .57649 L .3947 .57867 L 1 .472 0 r
F
.41248 .58381 m .41213 .58168 L .3947 .57867 L 1 .456 0 r
F
.3591 .49856 m .34574 .49031 L .34536 .49293 L 1 .938 0 r
F
.35879 .50119 m .3591 .49856 L .34536 .49293 L 1 .928 0 r
F
.85309 .65623 m .8329 .66512 L .83097 .67129 L .009 0 0 r
F
.85309 .65623 m .85518 .64989 L .8329 .66512 L F
.411 .58921 m .39214 .58478 L .39262 .58701 L 1 .444 0 r
F
.41137 .5914 m .411 .58921 L .39262 .58701 L 1 .429 0 r
F
.37497 .39017 m .36814 .38287 L .3659 .38488 L 1 1 0 r
F
.37497 .39017 m .37696 .388 L .36814 .38287 L F
.53607 .35242 m .52725 .35267 L .52848 .35616 L .653 .426 0 r
F
.53749 .3557 m .53607 .35242 L .52848 .35616 L .657 .464 0 r
F
.44984 .6022 m .43097 .59927 L .43126 .60133 L 1 .299 0 r
F
.45 .6042 m .44984 .6022 L .43126 .60133 L 1 .282 0 r
F
.46858 .60446 m .44984 .6022 L .45 .6042 L .951 .234 0 r
F
.60666 .47128 m .59363 .47461 L .59419 .47731 L .422 .132 0 r
F
.60666 .47128 m .60604 .46859 L .59363 .47461 L F
.56708 .38393 m .55689 .38612 L .55837 .38863 L .558 .473 0 r
F
.56868 .38638 m .56708 .38393 L .55837 .38863 L .555 .469 0 r
F
.54154 .58646 m .52464 .58702 L .52425 .58906 L .668 .065 0 r
F
.54154 .58646 m .54205 .5844 L .52464 .58702 L F
.59817 .52794 m .58339 .53061 L .58329 .53319 L .455 .065 0 r
F
.59817 .52794 m .59828 .52535 L .58339 .53061 L F
.53474 .34884 m .5261 .34882 L .52725 .35267 L .646 .38 0 r
F
.37359 .54204 m .35779 .53472 L .35794 .53722 L 1 .736 0 r
F
.37375 .54452 m .37359 .54204 L .35794 .53722 L 1 .723 0 r
F
.67919 .1119 m .67594 .12155 L .68225 .1249 L .242 .275 0 r
F
.67919 .1119 m .6731 .10859 L .67594 .12155 L F
.53607 .35242 m .53474 .34884 L .52725 .35267 L .653 .426 0 r
F
.57095 .77508 m .5494 .78289 L .54818 .78638 L .253 0 0 r
F
.57095 .77508 m .57261 .77185 L .5494 .78289 L F
.65654 .49735 m .64715 .50276 L .64645 .50599 L 0 0 0 r
F
.65654 .49735 m .65729 .49412 L .64715 .50276 L F
.57058 .39241 m .56026 .39464 L .56169 .3971 L .536 .457 0 r
F
.57214 .39481 m .57058 .39241 L .56169 .3971 L .534 .45 0 r
F
.60278 .46348 m .59021 .4667 L .59084 .46936 L .423 .151 0 r
F
.60278 .46348 m .60209 .46084 L .59021 .4667 L F
.65762 .70176 m .63874 .70684 L .63703 .71054 L .209 0 0 r
F
.65762 .70176 m .65973 .69819 L .63874 .70684 L F
.44736 .64764 m .42627 .64491 L .42676 .647 L .92 .087 0 r
F
.44763 .6496 m .44736 .64764 L .42676 .647 L .908 .075 0 r
F
.46811 .6492 m .44736 .64764 L .44763 .6496 L .828 .065 0 r
F
.57902 .55439 m .56356 .55639 L .56322 .55874 L .514 .06 0 r
F
.57902 .55439 m .57942 .55202 L .56356 .55639 L F
.52357 .59925 m .50597 .59903 L .50568 .60103 L .744 .071 0 r
F
.52357 .59925 m .524 .59724 L .50597 .59903 L F
.20285 .75792 m .17039 .74481 L .17336 .75002 L 1 .26 0 r
F
.20556 .76288 m .20285 .75792 L .17336 .75002 L 1 .235 0 r
F
.71303 .2063 m .71709 .20532 L .71924 .21256 L .901 .186 0 r
F
.40397 .63639 m .38322 .63101 L .384 .63346 L 1 .291 0 r
F
.40461 .63871 m .40397 .63639 L .384 .63346 L 1 .271 0 r
F
.50807 .64564 m .48861 .64605 L .48837 .64787 L .635 .04 0 r
F
.50807 .64564 m .50858 .64386 L .48861 .64605 L F
.37929 .38198 m .37456 .37666 L .37232 .37861 L 1 1 0 r
F
.37929 .38198 m .38135 .37987 L .37456 .37666 L F
.66286 .85928 m .63698 .8612 L .63396 .86487 L .31 0 0 r
F
.66286 .85928 m .66643 .8555 L .63698 .8612 L F
.32035 .5077 m .30798 .49704 L .30746 .50015 L 1 .971 0 r
F
.31993 .51083 m .32035 .5077 L .30746 .50015 L 1 .959 0 r
F
.56545 .38147 m .5554 .3836 L .55689 .38612 L .56 .476 0 r
F
.56708 .38393 m .56545 .38147 L .55689 .38612 L .558 .473 0 r
F
.523 .59501 m .5056 .59485 L .50531 .59679 L .741 .07 0 r
F
.523 .59501 m .52343 .59306 L .5056 .59485 L F
.33759 .47109 m .32486 .46138 L .32418 .46426 L 1 1 0 r
F
.33703 .47397 m .33759 .47109 L .32418 .46426 L 1 .991 0 r
F
.56123 .57861 m .54473 .57977 L .5443 .58199 L .597 .061 0 r
F
.56123 .57861 m .56176 .57638 L .54473 .57977 L F
.40878 .36163 m .40499 .35931 L .40277 .36097 L .937 1 0 r
F
.40878 .36163 m .41079 .35982 L .40499 .35931 L F
.60724 .47397 m .59419 .47731 L .59471 .48001 L .416 .119 0 r
F
.60724 .47397 m .60666 .47128 L .59419 .47731 L F
.569 .39001 m .55881 .39218 L .56026 .39464 L .539 .464 0 r
F
.57058 .39241 m .569 .39001 L .56026 .39464 L .536 .457 0 r
F
.55662 .88456 m .5283 .88445 L .52696 .88716 L .435 0 0 r
F
.55662 .88456 m .55865 .88181 L .5283 .88445 L F
.63635 .54533 m .62409 .55045 L .62327 .55329 L .13 0 0 r
F
.63635 .54533 m .63723 .54247 L .62409 .55045 L F
.46859 .60641 m .46858 .60446 L .45 .6042 L .944 .216 0 r
F
.48696 .60601 m .46858 .60446 L .46859 .60641 L .882 .159 0 r
F
.48696 .60601 m .48712 .60407 L .46858 .60446 L F
.60344 .46612 m .59084 .46936 L .59143 .47203 L .417 .138 0 r
F
.60344 .46612 m .60278 .46348 L .59084 .46936 L F
.35879 .50119 m .34536 .49293 L .34501 .49556 L 1 .928 0 r
F
.35852 .50381 m .35879 .50119 L .34501 .49556 L 1 .918 0 r
F
.45018 .59746 m .43175 .59416 L .43204 .59611 L 1 .293 0 r
F
.45034 .59937 m .45018 .59746 L .43204 .59611 L 1 .276 0 r
F
.46863 .59992 m .45018 .59746 L .45034 .59937 L .956 .226 0 r
F
.33498 .56761 m .31875 .55764 L .31901 .56072 L 1 .733 0 r
F
.33528 .57064 m .33498 .56761 L .31901 .56072 L 1 .718 0 r
F
.38103 .62346 m .36107 .61654 L .36185 .61921 L 1 .413 0 r
F
.38174 .626 m .38103 .62346 L .36185 .61921 L 1 .394 0 r
F
.47862 .3459 m .47146 .3476 L .47141 .35054 L 1 .984 0 r
F
.47862 .3459 m .47841 .34187 L .47146 .3476 L F
.52656 .89711 m .49686 .89582 L .49621 .89853 L .497 .005 0 r
F
.52656 .89711 m .52794 .89437 L .49686 .89582 L F
.88135 .36206 m .86783 .37623 L .87017 .38284 L .018 .027 0 r
F
.88135 .36206 m .87893 .35546 L .86783 .37623 L F
.28988 .84714 m .25665 .83689 L .26003 .84103 L .956 .072 0 r
F
.29283 .85105 m .28988 .84714 L .26003 .84103 L .934 .068 0 r
F
.65876 .12107 m .65577 .12916 L .66188 .13235 L .718 .205 0 r
F
.39276 .56754 m .37567 .56132 L .37606 .56365 L 1 .581 0 r
F
.3931 .56981 m .39276 .56754 L .37606 .56365 L 1 .566 0 r
F
.43146 .59217 m .41323 .58797 L .41363 .59002 L 1 .37 0 r
F
.43175 .59416 m .43146 .59217 L .41363 .59002 L 1 .353 0 r
F
.5601 .57461 m .54388 .57588 L .54346 .57805 L .588 .061 0 r
F
.5601 .57461 m .56062 .57241 L .54388 .57588 L F
.37696 .388 m .37044 .38095 L .36814 .38287 L 1 1 0 r
F
.37696 .388 m .37899 .3859 L .37044 .38095 L F
.58994 .88585 m .56226 .88615 L .56024 .88914 L .404 0 0 r
F
.58994 .88585 m .59262 .88278 L .56226 .88615 L F
.59608 .52457 m .58171 .52728 L .58162 .52982 L .443 .064 0 r
F
.59608 .52457 m .59618 .52201 L .58171 .52728 L F
.59732 .75451 m .57725 .76159 L .57576 .7651 L .21 0 0 r
F
.59732 .75451 m .59924 .75127 L .57725 .76159 L F
.705 .83654 m .68002 .83943 L .67673 .84359 L .255 0 0 r
F
.705 .83654 m .70877 .83224 L .68002 .83943 L F
.65018 .1233 m .64479 .11926 L .64654 .13215 L .207 .164 0 r
F
.36976 .55798 m .35191 .55122 L .35231 .55376 L 1 .629 0 r
F
.37012 .56045 m .36976 .55798 L .35231 .55376 L 1 .617 0 r
F
.7671 .43408 m .76083 .44237 L .7612 .44746 L 0 0 0 r
F
.7671 .43408 m .7664 .4291 L .76083 .44237 L F
.56381 .379 m .55389 .38106 L .5554 .3836 L .563 .478 0 r
F
.56545 .38147 m .56381 .379 L .5554 .3836 L .56 .476 0 r
F
.33763 .83164 m .30414 .82759 L .30687 .83136 L .943 .074 0 r
F
.33983 .83529 m .33763 .83164 L .30687 .83136 L .928 .071 0 r
F
.62455 .87526 m .59783 .87635 L .59525 .87962 L .359 0 0 r
F
.62455 .87526 m .62774 .8719 L .59783 .87635 L F
.46864 .60179 m .46863 .59992 L .45034 .59937 L .95 .209 0 r
F
.4868 .60157 m .46863 .59992 L .46864 .60179 L .884 .151 0 r
F
.4868 .60157 m .48695 .5997 L .46863 .59992 L F
.5674 .38762 m .55734 .38972 L .55881 .39218 L .541 .47 0 r
F
.569 .39001 m .5674 .38762 L .55881 .39218 L .539 .464 0 r
F
.34967 .52759 m .33344 .51925 L .33353 .522 L 1 .774 0 r
F
.3498 .53028 m .34967 .52759 L .33353 .522 L 1 .763 0 r
F
.60778 .47666 m .59471 .48001 L .5952 .4827 L .411 .106 0 r
F
.60778 .47666 m .60724 .47397 L .59471 .48001 L F
.60406 .46877 m .59143 .47203 L .59199 .47469 L .412 .125 0 r
F
.60406 .46877 m .60344 .46612 L .59143 .47203 L F
.89029 .53279 m .87335 .54444 L .87306 .5512 L 0 0 0 r
F
.89029 .53279 m .89066 .52594 L .87335 .54444 L F
.42596 .3549 m .42214 .35429 L .42018 .35598 L .898 .906 0 r
F
.42596 .3549 m .42769 .35303 L .42214 .35429 L F
.33703 .47397 m .32418 .46426 L .32354 .46714 L 1 .991 0 r
F
.33652 .47685 m .33703 .47397 L .32354 .46714 L 1 .981 0 r
F
.40676 .36881 m .40255 .36597 L .40046 .36772 L 1 1 0 r
F
.40676 .36881 m .40866 .36691 L .40255 .36597 L F
.08966 .61321 m .06602 .58986 L .06692 .59663 L 1 .598 0 r
F
.09061 .6198 m .08966 .61321 L .06692 .59663 L 1 .573 0 r
F
.56907 .6205 m .55223 .62328 L .55134 .62534 L .378 .01 0 r
F
.56907 .6205 m .57017 .61842 L .55223 .62328 L F
.59803 .53053 m .58329 .53319 L .58316 .53576 L .449 .063 0 r
F
.59803 .53053 m .59817 .52794 L .58329 .53319 L F
.59103 .60389 m .57531 .60746 L .57433 .60972 L .314 .002 0 r
F
.59103 .60389 m .59217 .60159 L .57531 .60746 L F
.61371 .5802 m .59944 .58457 L .59848 .5871 L .236 0 0 r
F
.61371 .5802 m .61479 .57764 L .59944 .58457 L F
.09857 .60338 m .07353 .58099 L .07449 .58758 L 1 .616 0 r
F
.09958 .60976 m .09857 .60338 L .07449 .58758 L 1 .593 0 r
F
.39082 .57795 m .37228 .57253 L .37279 .57489 L 1 .52 0 r
F
.39124 .58025 m .39082 .57795 L .37279 .57489 L 1 .507 0 r
F
.85942 .66661 m .83773 .67488 L .83575 .68119 L .051 0 0 r
F
.85942 .66661 m .86156 .66013 L .83773 .67488 L F
.35763 .60283 m .33907 .59433 L .33972 .59722 L 1 .552 0 r
F
.35825 .60562 m .35763 .60283 L .33972 .59722 L 1 .535 0 r
F
.58013 .56057 m .56442 .56246 L .56404 .56483 L .518 .059 0 r
F
.58013 .56057 m .58058 .55817 L .56442 .56246 L F
.69597 .37756 m .69259 .38181 L .69094 .38738 L 0 0 0 r
F
.69597 .37756 m .69751 .37202 L .69259 .38181 L F
.37375 .54452 m .35794 .53722 L .35813 .53971 L 1 .723 0 r
F
.37394 .54697 m .37375 .54452 L .35813 .53971 L 1 .71 0 r
F
.38135 .37987 m .37683 .37476 L .37456 .37666 L 1 1 0 r
F
.38135 .37987 m .38342 .37779 L .37683 .37476 L F
.31993 .51083 m .30746 .50015 L .30699 .50326 L 1 .959 0 r
F
.31956 .51397 m .31993 .51083 L .30699 .50326 L 1 .947 0 r
F
.081 .62332 m .05593 .59978 L .05708 .60668 L 1 .569 0 r
F
.08218 .63002 m .081 .62332 L .05708 .60668 L 1 .544 0 r
F
.442 .34164 m .43787 .31253 L .43805 .32163 L 1 .207 0 r
F
.43787 .31253 m .43669 .30422 L .43805 .32163 L F
.43805 .32163 m .44128 .33158 L .4382 .32938 L .958 .185 0 r
F
.43805 .32163 m .4382 .32938 L .4379 .32917 L F
.43669 .30422 m .4368 .30674 L .43805 .32163 L 1 .207 0 r
F
.43644 .30244 m .4368 .30898 L .43805 .32163 L F
.43697 .31071 m .44164 .32514 L .43805 .32163 L .934 .313 0 r
F
.43669 .30422 m .43644 .30244 L .4368 .30674 L 1 .207 0 r
F
.43644 .30244 m .4355 .29582 L .4368 .30898 L F
.4355 .29582 m .43954 .31509 L .43697 .31071 L .934 .313 0 r
F
.43954 .31509 m .44164 .32514 L .43697 .31071 L F
.43805 .32163 m .44164 .32514 L .44128 .33158 L .958 .185 0 r
F
.43724 .31701 m .44077 .32062 L .44073 .32886 L 1 .289 0 r
F
.43667 .31506 m .43719 .31577 L .43724 .31701 L F
.43719 .31577 m .44077 .32062 L .43724 .31701 L F
.43667 .31506 m .43724 .31701 L .43721 .32607 L F
.43724 .31701 m .44073 .32886 L .43776 .32651 L F
.43724 .31701 m .43776 .32651 L .43721 .32607 L F
.4312 .27369 m .44077 .32062 L .43667 .31506 L .967 .369 0 r
F
.4312 .27369 m .43793 .29161 L .44077 .32062 L F
.56217 .37652 m .55238 .37851 L .55389 .38106 L .565 .479 0 r
F
.56381 .379 m .56217 .37652 L .55389 .38106 L .563 .478 0 r
F
.19008 .78773 m .15801 .77232 L .16135 .77773 L 1 .167 0 r
F
.19316 .79289 m .19008 .78773 L .16135 .77773 L 1 .139 0 r
F
.35852 .50381 m .34501 .49556 L .3447 .49818 L 1 .918 0 r
F
.35827 .50643 m .35852 .50381 L .3447 .49818 L 1 .908 0 r
F
.50507 .60494 m .48712 .60407 L .48696 .60601 L .811 .093 0 r
F
.50507 .60494 m .50538 .603 L .48712 .60407 L F
.56578 .38524 m .55585 .38727 L .55734 .38972 L .542 .475 0 r
F
.5674 .38762 m .56578 .38524 L .55734 .38972 L .541 .47 0 r
F
.75834 .54077 m .74352 .5486 L .74282 .55327 L .039 0 0 r
F
.75834 .54077 m .75902 .53602 L .74352 .5486 L F
.52767 .64077 m .50908 .64203 L .50858 .64386 L .535 .028 0 r
F
.52767 .64077 m .52843 .63896 L .50908 .64203 L F
.47841 .34187 m .47152 .34441 L .47146 .3476 L 1 .954 0 r
F
.47841 .34187 m .47822 .33709 L .47152 .34441 L F
.42627 .64491 m .40527 .64099 L .40595 .64323 L 1 .173 0 r
F
.42676 .647 m .42627 .64491 L .40595 .64323 L .99 .152 0 r
F
.36777 .87687 m .33461 .87019 L .33727 .87349 L .815 .049 0 r
F
.36984 .87998 m .36777 .87687 L .33727 .87349 L .79 .044 0 r
F
.74805 .79384 m .72481 .79857 L .72154 .8032 L .164 0 0 r
F
.74805 .79384 m .7517 .78904 L .72481 .79857 L F
.46554 .89213 m .46547 .88951 L .43448 .88925 L .609 .019 0 r
F
.49578 .89142 m .46547 .88951 L .46554 .89213 L .547 .011 0 r
F
.49578 .89142 m .49643 .88882 L .46547 .88951 L F
.68675 .11267 m .68332 .1231 L .6898 .12621 L .309 .406 0 r
F
.68675 .11267 m .68027 .10998 L .68332 .1231 L F
.25371 .79625 m .22029 .78678 L .22347 .79136 L 1 .154 0 r
F
.25651 .80062 m .25371 .79625 L .22347 .79136 L 1 .13 0 r
F
.60464 .47142 m .59199 .47469 L .59252 .47735 L .406 .112 0 r
F
.60464 .47142 m .60406 .46877 L .59199 .47469 L F
.42828 .34764 m .42524 .3486 L .42314 .35002 L .615 .226 0 r
F
.5047 .60057 m .48695 .5997 L .4868 .60157 L .81 .087 0 r
F
.5047 .60057 m .50501 .5987 L .48695 .5997 L F
.60829 .47935 m .5952 .4827 L .59566 .4854 L .406 .094 0 r
F
.60829 .47935 m .60778 .47666 L .5952 .4827 L F
.37899 .3859 m .37282 .37913 L .37044 .38095 L 1 1 0 r
F
.37899 .3859 m .38106 .38387 L .37282 .37913 L F
.67444 .44276 m .66821 .44777 L .6672 .45172 L 0 0 0 r
F
.67444 .44276 m .67555 .43879 L .66821 .44777 L F
.13955 .71563 m .11088 .6965 L .1133 .70263 L 1 .359 0 r
F
.14187 .72153 m .13955 .71563 L .1133 .70263 L 1 .331 0 r
F
.43097 .59927 m .41216 .59569 L .41259 .59779 L 1 .354 0 r
F
.43126 .60133 m .43097 .59927 L .41259 .59779 L 1 .336 0 r
F
.41248 .58381 m .3947 .57867 L .39515 .58082 L 1 .456 0 r
F
.41284 .5859 m .41248 .58381 L .39515 .58082 L 1 .439 0 r
F
.69109 .66682 m .67263 .6718 L .67098 .67571 L .189 0 0 r
F
.69109 .66682 m .69306 .66294 L .67263 .6718 L F
.57859 .55675 m .56322 .55874 L .56285 .56108 L .508 .058 0 r
F
.57859 .55675 m .57902 .55439 L .56322 .55874 L F
.6254 .73147 m .60631 .73753 L .60464 .74108 L .196 0 0 r
F
.6254 .73147 m .6275 .72815 L .60631 .73753 L F
.79957 .74155 m .7776 .74801 L .77469 .75338 L .087 0 0 r
F
.79957 .74155 m .80275 .73601 L .7776 .74801 L F
.54182 .59267 m .52483 .59314 L .52443 .5952 L .666 .064 0 r
F
.54182 .59267 m .54235 .59059 L .52483 .59314 L F
.56051 .37402 m .55086 .37594 L .55238 .37851 L .567 .478 0 r
F
.56217 .37652 m .56051 .37402 L .55238 .37851 L .565 .479 0 r
F
.33652 .47685 m .32354 .46714 L .32295 .47002 L 1 .981 0 r
F
.33604 .47972 m .33652 .47685 L .32295 .47002 L 1 .971 0 r
F
.41137 .5914 m .39262 .58701 L .39312 .58922 L 1 .429 0 r
F
.41176 .59356 m .41137 .5914 L .39312 .58922 L 1 .413 0 r
F
.72695 .61611 m .70929 .62201 L .70794 .62626 L .144 0 0 r
F
.72695 .61611 m .72849 .6118 L .70929 .62201 L F
.56414 .38285 m .55435 .38481 L .55585 .38727 L .543 .479 0 r
F
.56578 .38524 m .56414 .38285 L .55585 .38727 L .542 .475 0 r
F
.59594 .52711 m .58162 .52982 L .5815 .53235 L .437 .062 0 r
F
.59594 .52711 m .59608 .52457 L .58162 .52982 L F
.65579 .50055 m .64645 .50599 L .64575 .5092 L 0 0 0 r
F
.65579 .50055 m .65654 .49735 L .64645 .50599 L F
.72994 .3227 m .72829 .31766 L .74407 .3186 L 1 .452 0 r
F
.54101 .5885 m .52425 .58906 L .52385 .59107 L .66 .063 0 r
F
.54101 .5885 m .54154 .58646 L .52425 .58906 L F
.89855 .54086 m .87962 .55235 L .87938 .55923 L 0 0 0 r
F
.89855 .54086 m .8988 .53385 L .87962 .55235 L F
.46813 .65104 m .46811 .6492 L .44763 .6496 L .813 .062 0 r
F
.48812 .64965 m .46811 .6492 L .46813 .65104 L .722 .05 0 r
F
.48812 .64965 m .48837 .64787 L .46811 .6492 L F
.88682 .36784 m .87313 .38211 L .87554 .38876 L .022 .029 0 r
F
.88682 .36784 m .88428 .36121 L .87313 .38211 L F
.41079 .35982 m .40722 .3577 L .40499 .35931 L .904 1 0 r
F
.41079 .35982 m .41282 .35805 L .40722 .3577 L F
.45 .6042 m .43126 .60133 L .43157 .60335 L 1 .282 0 r
F
.45016 .60617 m .45 .6042 L .43157 .60335 L .999 .264 0 r
F
.46859 .60641 m .45 .6042 L .45016 .60617 L .944 .216 0 r
F
.60518 .47407 m .59252 .47735 L .59301 .48001 L .401 .1 0 r
F
.60518 .47407 m .60464 .47142 L .59252 .47735 L F
.68348 .11826 m .68225 .1249 L .68848 .12836 L 0 .014 0 r
F
.68348 .11826 m .67919 .1119 L .68225 .1249 L F
.35827 .50643 m .3447 .49818 L .34443 .5008 L 1 .908 0 r
F
.35807 .50904 m .35827 .50643 L .34443 .5008 L 1 .897 0 r
F
.51937 .81096 m .49414 .81818 L .49368 .82154 L .389 .007 0 r
F
.51937 .81096 m .52031 .8077 L .49414 .81818 L F
.55884 .37149 m .54934 .37333 L .55086 .37594 L .568 .475 0 r
F
.56051 .37402 m .55884 .37149 L .55086 .37594 L .567 .478 0 r
F
.33528 .57064 m .31901 .56072 L .31931 .56378 L 1 .718 0 r
F
.33562 .57366 m .33528 .57064 L .31931 .56378 L 1 .703 0 r
F
.38342 .37779 m .37911 .3729 L .37683 .37476 L 1 1 0 r
F
.38342 .37779 m .38551 .37576 L .37911 .3729 L F
.56066 .58082 m .5443 .58199 L .54384 .58418 L .589 .06 0 r
F
.56066 .58082 m .56123 .57861 L .5443 .58199 L F
.31956 .51397 m .30699 .50326 L .30656 .50638 L 1 .947 0 r
F
.31923 .51711 m .31956 .51397 L .30656 .50638 L 1 .935 0 r
F
.3498 .53028 m .33353 .522 L .33367 .52473 L 1 .763 0 r
F
.34996 .53295 m .3498 .53028 L .33367 .52473 L 1 .751 0 r
F
.60876 .48204 m .59566 .4854 L .59608 .4881 L .4 .082 0 r
F
.60876 .48204 m .60829 .47935 L .59566 .4854 L F
.59784 .5331 m .58316 .53576 L .583 .53831 L .443 .061 0 r
F
.59784 .5331 m .59803 .53053 L .58316 .53576 L F
.4013 .89177 m .3682 .88642 L .37034 .88948 L .748 .039 0 r
F
.40279 .89465 m .4013 .89177 L .37034 .88948 L .722 .034 0 r
F
.43387 .89596 m .4013 .89177 L .40279 .89465 L .691 .031 0 r
F
.3931 .56981 m .37606 .56365 L .37648 .56595 L 1 .566 0 r
F
.39347 .57206 m .3931 .56981 L .37648 .56595 L 1 .55 0 r
F
.56248 .38047 m .55283 .38234 L .55435 .38481 L .544 .483 0 r
F
.56414 .38285 m .56248 .38047 L .55435 .38481 L .543 .479 0 r
F
.52311 .60122 m .50568 .60103 L .50538 .603 L .736 .069 0 r
F
.52311 .60122 m .52357 .59925 L .50568 .60103 L F
.32974 .87306 m .29606 .86484 L .29925 .8685 L .87 .057 0 r
F
.33239 .87652 m .32974 .87306 L .29925 .8685 L .845 .053 0 r
F
.37012 .56045 m .35231 .55376 L .35274 .55628 L 1 .617 0 r
F
.3705 .56291 m .37012 .56045 L .35274 .55628 L 1 .604 0 r
F
.14985 .7011 m .11992 .68376 L .12229 .68966 L 1 .394 0 r
F
.1521 .70674 m .14985 .7011 L .12229 .68966 L 1 .37 0 r
F
.65964 .2354 m .68252 .20733 L .6848 .2143 L 1 .444 0 r
F
.65964 .2354 m .65633 .23106 L .68252 .20733 L F
.70618 .30188 m .70867 .30257 L .70841 .30936 L .84 .151 0 r
F
.70618 .30188 m .70571 .29578 L .70867 .30257 L F
.63544 .54817 m .62327 .55329 L .62242 .55611 L .125 0 0 r
F
.63544 .54817 m .63635 .54533 L .62327 .55329 L F
.40658 .84036 m .37463 .84062 L .37637 .844 L .801 .058 0 r
F
.40775 .84367 m .40658 .84036 L .37637 .844 L .783 .055 0 r
F
.4373 .83812 m .40658 .84036 L .40775 .84367 L .718 .05 0 r
F
.54757 .63318 m .52991 .63522 L .52918 .63711 L .437 .017 0 r
F
.54757 .63318 m .54854 .63128 L .52991 .63522 L F
.40866 .36691 m .40463 .36421 L .40255 .36597 L 1 1 0 r
F
.40866 .36691 m .41056 .36503 L .40463 .36421 L F
.55954 .57678 m .54346 .57805 L .54301 .58019 L .581 .059 0 r
F
.55954 .57678 m .5601 .57461 L .54346 .57805 L F
.52255 .59693 m .50531 .59679 L .50501 .5987 L .733 .068 0 r
F
.52255 .59693 m .523 .59501 L .50531 .59679 L F
.37394 .54697 m .35813 .53971 L .35835 .54219 L 1 .71 0 r
F
.37416 .54941 m .37394 .54697 L .35835 .54219 L 1 .696 0 r
F
.65905 .85174 m .63393 .85418 L .63092 .85768 L .286 0 0 r
F
.65905 .85174 m .6626 .84812 L .63393 .85418 L F
.43467 .89869 m .43387 .89596 L .40279 .89465 L .665 .026 0 r
F
.46544 .89905 m .43387 .89596 L .43467 .89869 L .622 .021 0 r
F
.33604 .47972 m .32295 .47002 L .3224 .47291 L 1 .971 0 r
F
.3356 .48259 m .33604 .47972 L .3224 .47291 L 1 .961 0 r
F
.38106 .38387 m .37526 .37742 L .37282 .37913 L 1 1 0 r
F
.38106 .38387 m .38317 .3819 L .37526 .37742 L F
.55718 .36892 m .54781 .37068 L .54934 .37333 L .569 .47 0 r
F
.55884 .37149 m .55718 .36892 L .54934 .37333 L .568 .475 0 r
F
.52559 .88977 m .49643 .88882 L .49578 .89142 L .475 .001 0 r
F
.52559 .88977 m .52696 .88716 L .49643 .88882 L F
.60569 .47672 m .59301 .48001 L .59347 .48267 L .395 .087 0 r
F
.60569 .47672 m .60518 .47407 L .59301 .48001 L F
.54306 .2679 m .56344 .19642 L .55497 .23791 L 1 .951 0 r
F
.54306 .2679 m .55057 .231 L .56344 .19642 L F
.66497 .12358 m .66188 .13235 L .66787 .13572 L .294 .389 0 r
F
.66497 .12358 m .65876 .12107 L .66188 .13235 L F
.45034 .59937 m .43204 .59611 L .43235 .59804 L 1 .276 0 r
F
.45051 .60125 m .45034 .59937 L .43235 .59804 L 1 .258 0 r
F
.46864 .60179 m .45034 .59937 L .45051 .60125 L .95 .209 0 r
F
.76775 .43906 m .7612 .44746 L .76152 .45254 L 0 0 0 r
F
.76775 .43906 m .7671 .43408 L .7612 .44746 L F
.43175 .59416 m .41363 .59002 L .41405 .59203 L 1 .353 0 r
F
.43204 .59611 m .43175 .59416 L .41405 .59203 L 1 .335 0 r
F
.57966 .56295 m .56404 .56483 L .56364 .56719 L .511 .057 0 r
F
.57966 .56295 m .58013 .56057 L .56404 .56483 L F
.46859 .60833 m .46859 .60641 L .45016 .60617 L .937 .198 0 r
F
.48681 .60792 m .46859 .60641 L .46859 .60833 L .875 .141 0 r
F
.48681 .60792 m .48696 .60601 L .46859 .60641 L F
.56081 .37808 m .5513 .37987 L .55283 .38234 L .545 .484 0 r
F
.56248 .38047 m .56081 .37808 L .55283 .38234 L .544 .483 0 r
F
.29887 .81982 m .26531 .81332 L .26839 .81741 L 1 .082 0 r
F
.30147 .82374 m .29887 .81982 L .26839 .81741 L .989 .079 0 r
F
.88364 .3687 m .87017 .38284 L .87239 .38948 L .005 .023 0 r
F
.88364 .3687 m .88135 .36206 L .87017 .38284 L F
.58771 .87822 m .56065 .87895 L .55865 .88181 L .385 0 0 r
F
.58771 .87822 m .59036 .8753 L .56065 .87895 L F
.42769 .35303 m .42412 .35265 L .42214 .35429 L .842 .819 0 r
F
.42769 .35303 m .42944 .3512 L .42412 .35265 L F
.60919 .48473 m .59608 .4881 L .59647 .49079 L .395 .074 0 r
F
.60919 .48473 m .60876 .48204 L .59608 .4881 L F
.39124 .58025 m .37279 .57489 L .37332 .57722 L 1 .507 0 r
F
.39168 .58253 m .39124 .58025 L .37332 .57722 L 1 .492 0 r
F
.35807 .50904 m .34443 .5008 L .34419 .50342 L 1 .897 0 r
F
.35789 .51165 m .35807 .50904 L .34419 .50342 L 1 .887 0 r
F
.59577 .52964 m .5815 .53235 L .58135 .53487 L .43 .06 0 r
F
.59577 .52964 m .59594 .52711 L .5815 .53235 L F
.54958 .20809 m .55972 .16315 L .55709 .19267 L .73 .143 0 r
F
.70023 .82927 m .67612 .83271 L .67284 .83671 L .227 0 0 r
F
.70023 .82927 m .70398 .82515 L .67612 .83271 L F
.40461 .63871 m .384 .63346 L .3848 .63588 L 1 .271 0 r
F
.40527 .64099 m .40461 .63871 L .3848 .63588 L 1 .251 0 r
F
.55551 .36631 m .54629 .36798 L .54781 .37068 L .569 .462 0 r
F
.55718 .36892 m .55551 .36631 L .54781 .37068 L .569 .47 0 r
F
.38174 .626 m .36185 .61921 L .36266 .62186 L 1 .394 0 r
F
.38246 .62852 m .38174 .626 L .36266 .62186 L 1 .376 0 r
F
.62157 .8676 m .59553 .86916 L .59297 .87228 L .336 0 0 r
F
.62157 .8676 m .62475 .86439 L .59553 .86916 L F
.24301 .82995 m .20991 .81755 L .21352 .82224 L 1 .084 0 r
F
.24625 .83439 m .24301 .82995 L .21352 .82224 L .994 .08 0 r
F
.70926 .21953 m .71924 .21256 L .72083 .22018 L 1 .638 0 r
F
.70926 .21953 m .71303 .2063 L .71924 .21256 L F
.1349 .72663 m .10526 .70762 L .10792 .71379 L 1 .324 0 r
F
.13743 .73255 m .1349 .72663 L .10792 .71379 L 1 .295 0 r
F
.46865 .60363 m .46864 .60179 L .45051 .60125 L .943 .191 0 r
F
.48664 .6034 m .46864 .60179 L .46865 .60363 L .877 .134 0 r
F
.48664 .6034 m .4868 .60157 L .46864 .60179 L F
.38551 .37576 m .3814 .37108 L .37911 .3729 L 1 1 0 r
F
.38551 .37576 m .38762 .37377 L .3814 .37108 L F
.31923 .51711 m .30656 .50638 L .30617 .5095 L 1 .935 0 r
F
.31894 .52025 m .31923 .51711 L .30617 .5095 L 1 .923 0 r
F
.57812 .55909 m .56285 .56108 L .56246 .56339 L .501 .056 0 r
F
.57812 .55909 m .57859 .55675 L .56285 .56108 L F
.35825 .60562 m .33972 .59722 L .3404 .60008 L 1 .535 0 r
F
.35891 .60838 m .35825 .60562 L .3404 .60008 L 1 .518 0 r
F
.60615 .47937 m .59347 .48267 L .59389 .48533 L .389 .075 0 r
F
.60615 .47937 m .60569 .47672 L .59347 .48267 L F
.44763 .6496 m .42676 .647 L .42727 .64906 L .908 .075 0 r
F
.44791 .65152 m .44763 .6496 L .42727 .64906 L .894 .073 0 r
F
.46813 .65104 m .44763 .6496 L .44791 .65152 L .813 .062 0 r
F
.55912 .37568 m .54976 .37739 L .5513 .37987 L .545 .485 0 r
F
.56081 .37808 m .55912 .37568 L .5513 .37987 L .545 .484 0 r
F
.61261 .58273 m .59848 .5871 L .59749 .5896 L .23 0 0 r
F
.61261 .58273 m .61371 .5802 L .59848 .5871 L F
.3356 .48259 m .3224 .47291 L .32189 .47579 L 1 .961 0 r
F
.33521 .48546 m .3356 .48259 L .32189 .47579 L 1 .951 0 r
F
.85089 .66252 m .83097 .67129 L .82892 .67743 L 0 0 0 r
F
.85089 .66252 m .85309 .65623 L .83097 .67129 L F
.55385 .36364 m .54478 .3652 L .54629 .36798 L .569 .451 0 r
F
.55551 .36631 m .55385 .36364 L .54629 .36798 L .569 .462 0 r
F
.50755 .64737 m .48837 .64787 L .48812 .64965 L .618 .037 0 r
F
.50755 .64737 m .50807 .64564 L .48837 .64787 L F
.59762 .53566 m .583 .53831 L .58281 .54085 L .436 .059 0 r
F
.59762 .53566 m .59784 .5331 L .583 .53831 L F
.34996 .53295 m .33367 .52473 L .33383 .52746 L 1 .751 0 r
F
.35015 .53561 m .34996 .53295 L .33383 .52746 L 1 .739 0 r
F
.19529 .78204 m .16411 .76664 L .16734 .772 L 1 .173 0 r
F
.19828 .78714 m .19529 .78204 L .16734 .772 L 1 .145 0 r
F
.69317 .11548 m .6898 .12621 L .69622 .12944 L .296 .382 0 r
F
.69317 .11548 m .68675 .11267 L .6898 .12621 L F
.41284 .5859 m .39515 .58082 L .39563 .58295 L 1 .439 0 r
F
.41323 .58797 m .41284 .5859 L .39563 .58295 L 1 .422 0 r
F
.50475 .60684 m .48696 .60601 L .48681 .60792 L .803 .077 0 r
F
.50475 .60684 m .50507 .60494 L .48696 .60601 L F
.41282 .35805 m .40945 .35614 L .40722 .3577 L .867 .961 0 r
F
.41282 .35805 m .41486 .35633 L .40945 .35614 L F
.60958 .48742 m .59647 .49079 L .59682 .49348 L .389 .072 0 r
F
.60958 .48742 m .60919 .48473 L .59647 .49079 L F
.58986 .60616 m .57433 .60972 L .57332 .61195 L .307 0 0 r
F
.58986 .60616 m .59103 .60389 L .57433 .60972 L F
.43014 .34599 m .42735 .34724 L .42524 .3486 L .559 .217 0 r
F
.38317 .3819 m .37778 .37583 L .37526 .37742 L 1 1 0 r
F
.38317 .3819 m .38531 .38 L .37778 .37583 L F
.75759 .5455 m .74282 .55327 L .74208 .55792 L .034 0 0 r
F
.75759 .5455 m .75834 .54077 L .74282 .55327 L F
.65503 .50372 m .64575 .5092 L .64504 .51237 L 0 0 0 r
F
.65503 .50372 m .65579 .50055 L .64575 .5092 L F
.54125 .59472 m .52443 .5952 L .524 .59724 L .658 .062 0 r
F
.54125 .59472 m .54182 .59267 L .52443 .5952 L F
.43126 .60133 m .41259 .59779 L .41303 .59986 L 1 .336 0 r
F
.43157 .60335 m .43126 .60133 L .41303 .59986 L 1 .318 0 r
F
.50439 .60242 m .4868 .60157 L .48664 .6034 L .802 .074 0 r
F
.50439 .60242 m .5047 .60057 L .4868 .60157 L F
.67338 .44664 m .6672 .45172 L .66624 .45559 L 0 0 0 r
F
.67338 .44664 m .67444 .44276 L .6672 .45172 L F
.41176 .59356 m .39312 .58922 L .39365 .5914 L 1 .413 0 r
F
.41216 .59569 m .41176 .59356 L .39365 .5914 L 1 .396 0 r
F
.80344 .7529 m .78057 .75867 L .77757 .76414 L .117 0 0 r
F
.80344 .7529 m .80673 .74725 L .78057 .75867 L F
.65545 .70526 m .63703 .71054 L .63525 .71418 L .186 0 0 r
F
.65545 .70526 m .65762 .70176 L .63703 .71054 L F
.55221 .36089 m .54329 .36233 L .54478 .3652 L .567 .434 0 r
F
.55385 .36364 m .55221 .36089 L .54478 .3652 L .569 .451 0 r
F
.33562 .57366 m .31931 .56378 L .31965 .56684 L 1 .703 0 r
F
.336 .57666 m .33562 .57366 L .31965 .56684 L 1 .687 0 r
F
.55742 .37327 m .54821 .37488 L .54976 .37739 L .545 .484 0 r
F
.55912 .37568 m .55742 .37327 L .54976 .37739 L .545 .485 0 r
F
.35789 .51165 m .34419 .50342 L .34399 .50603 L 1 .887 0 r
F
.35775 .51425 m .35789 .51165 L .34399 .50603 L 1 .875 0 r
F
.56795 .62254 m .55134 .62534 L .55043 .62736 L .37 .006 0 r
F
.56795 .62254 m .56907 .6205 L .55134 .62534 L F
.37416 .54941 m .35835 .54219 L .3586 .54465 L 1 .696 0 r
F
.37441 .55183 m .37416 .54941 L .3586 .54465 L 1 .682 0 r
F
.41056 .36503 m .4067 .36244 L .40463 .36421 L 1 1 0 r
F
.41056 .36503 m .41247 .36316 L .4067 .36244 L F
.88981 .53963 m .87306 .5512 L .87265 .55793 L 0 0 0 r
F
.88981 .53963 m .89029 .53279 L .87306 .5512 L F
.54046 .5905 m .52385 .59107 L .52343 .59306 L .653 .061 0 r
F
.54046 .5905 m .54101 .5885 L .52385 .59107 L F
.60658 .48201 m .59389 .48533 L .59428 .48799 L .384 .073 0 r
F
.60658 .48201 m .60615 .47937 L .59389 .48533 L F
.3705 .56291 m .35274 .55628 L .35321 .55878 L 1 .604 0 r
F
.37091 .56534 m .3705 .56291 L .35321 .55878 L 1 .591 0 r
F
.39347 .57206 m .37648 .56595 L .37692 .56823 L 1 .55 0 r
F
.39385 .57429 m .39347 .57206 L .37692 .56823 L 1 .534 0 r
F
.7317 .32761 m .72994 .3227 L .74522 .32444 L 1 .399 0 r
F
.36537 .31172 m .36044 .29841 L .36285 .30981 L .798 .115 0 r
F
.36984 .32567 m .36537 .31172 L .36285 .30981 L .852 .121 0 r
F
.69443 .38295 m .69094 .38738 L .68931 .39278 L 0 0 0 r
F
.69443 .38295 m .69597 .37756 L .69094 .38738 L F
.56007 .58301 m .54384 .58418 L .54337 .58634 L .581 .057 0 r
F
.56007 .58301 m .56066 .58082 L .54384 .58418 L F
.55059 .35803 m .54182 .35933 L .54329 .36233 L .563 .413 0 r
F
.55221 .36089 m .55059 .35803 L .54329 .36233 L .567 .434 0 r
F
.88923 .37451 m .87554 .38876 L .87784 .39545 L .011 .026 0 r
F
.88923 .37451 m .88682 .36784 L .87554 .38876 L F
.40242 .88521 m .36984 .87998 L .37195 .88298 L .743 .038 0 r
F
.40388 .88803 m .40242 .88521 L .37195 .88298 L .718 .033 0 r
F
.43448 .88925 m .40242 .88521 L .40388 .88803 L .683 .03 0 r
F
.46619 .83395 m .46615 .83069 L .4373 .83812 L .606 .036 0 r
F
.4932 .82479 m .46615 .83069 L .46619 .83395 L .485 .022 0 r
F
.4932 .82479 m .49368 .82154 L .46615 .83069 L F
.33521 .48546 m .32189 .47579 L .32143 .47867 L 1 .951 0 r
F
.33485 .48832 m .33521 .48546 L .32143 .47867 L 1 .941 0 r
F
.59556 .53216 m .58135 .53487 L .58117 .53737 L .424 .058 0 r
F
.59556 .53216 m .59577 .52964 L .58135 .53487 L F
.38762 .37377 m .38371 .36929 L .3814 .37108 L 1 1 0 r
F
.38762 .37377 m .38974 .37182 L .38371 .36929 L F
.09061 .6198 m .06692 .59663 L .06793 .60337 L 1 .573 0 r
F
.09168 .62637 m .09061 .6198 L .06793 .60337 L 1 .548 0 r
F
.09958 .60976 m .07449 .58758 L .07556 .59415 L 1 .593 0 r
F
.1007 .61611 m .09958 .60976 L .07556 .59415 L 1 .57 0 r
F
.31894 .52025 m .30617 .5095 L .30583 .51262 L 1 .923 0 r
F
.31869 .52339 m .31894 .52025 L .30583 .51262 L 1 .91 0 r
F
.68697 .12569 m .68348 .11826 L .68848 .12836 L .655 .069 0 r
F
.68697 .12569 m .68848 .12836 L .69467 .13186 L F
.332 .86678 m .29891 .85858 L .30205 .86221 L .871 .057 0 r
F
.33461 .87019 m .332 .86678 L .30205 .86221 L .847 .053 0 r
F
.75017 .80538 m .72639 .80946 L .72303 .81418 L .186 0 0 r
F
.75017 .80538 m .75393 .80049 L .72639 .80946 L F
.45016 .60617 m .43157 .60335 L .43188 .60534 L .999 .264 0 r
F
.45033 .60811 m .45016 .60617 L .43188 .60534 L .992 .245 0 r
F
.46859 .60833 m .45016 .60617 L .45033 .60811 L .937 .198 0 r
F
.55897 .57892 m .54301 .58019 L .54254 .58231 L .574 .057 0 r
F
.55897 .57892 m .55954 .57678 L .54301 .58019 L F
.54422 .79624 m .52122 .80434 L .52031 .8077 L .298 0 0 r
F
.54422 .79624 m .54558 .79305 L .52122 .80434 L F
.55571 .37084 m .54666 .37234 L .54821 .37488 L .544 .48 0 r
F
.55742 .37327 m .55571 .37084 L .54821 .37488 L .545 .484 0 r
F
.60993 .49011 m .59682 .49348 L .59714 .49617 L .384 .071 0 r
F
.60993 .49011 m .60958 .48742 L .59682 .49348 L F
.57915 .5653 m .56364 .56719 L .56321 .56952 L .504 .055 0 r
F
.57915 .5653 m .57966 .56295 L .56364 .56719 L F
.549 .35503 m .5404 .35617 L .54182 .35933 L .557 .384 0 r
F
.55059 .35803 m .549 .35503 L .54182 .35933 L .563 .413 0 r
F
.43791 .84137 m .4373 .83812 L .40775 .84367 L .697 .045 0 r
F
.46619 .83395 m .4373 .83812 L .43791 .84137 L .606 .036 0 r
F
.63451 .55098 m .62242 .55611 L .62156 .5589 L .12 0 0 r
F
.63451 .55098 m .63544 .54817 L .62242 .55611 L F
.42676 .647 m .40595 .64323 L .40665 .64544 L .99 .152 0 r
F
.42727 .64906 m .42676 .647 L .40665 .64544 L .979 .13 0 r
F
.54747 .35186 m .53903 .35279 L .5404 .35617 L .549 .348 0 r
F
.54747 .35186 m .546 .34843 L .53903 .35279 L F
.43526 .8919 m .43448 .88925 L .40388 .88803 L .657 .025 0 r
F
.46554 .89213 m .43448 .88925 L .43526 .8919 L .609 .019 0 r
F
.549 .35503 m .54747 .35186 L .5404 .35617 L .557 .384 0 r
F
.08218 .63002 m .05708 .60668 L .05835 .61355 L 1 .544 0 r
F
.08347 .63669 m .08218 .63002 L .05835 .61355 L 1 .517 0 r
F
.72534 .62038 m .70794 .62626 L .70653 .63047 L .133 0 0 r
F
.72534 .62038 m .72695 .61611 L .70794 .62626 L F
.52265 .60316 m .50538 .603 L .50507 .60494 L .728 .067 0 r
F
.52265 .60316 m .52311 .60122 L .50538 .603 L F
.5269 .64253 m .50858 .64386 L .50807 .64564 L .517 .024 0 r
F
.5269 .64253 m .52767 .64077 L .50858 .64386 L F
.60697 .48466 m .59428 .48799 L .59464 .49064 L .38 .072 0 r
F
.60697 .48466 m .60658 .48201 L .59428 .48799 L F
.20556 .76288 m .17336 .75002 L .17643 .75518 L 1 .235 0 r
F
.20835 .76779 m .20556 .76288 L .17643 .75518 L 1 .211 0 r
F
.52209 .59882 m .50501 .5987 L .5047 .60057 L .725 .066 0 r
F
.52209 .59882 m .52255 .59693 L .50501 .5987 L F
.76834 .44402 m .76152 .45254 L .7618 .45759 L 0 0 0 r
F
.76834 .44402 m .76775 .43906 L .76152 .45254 L F
.35775 .51425 m .34399 .50603 L .34383 .50863 L 1 .875 0 r
F
.35764 .51685 m .35775 .51425 L .34383 .50863 L 1 .864 0 r
F
.59737 .53821 m .58281 .54085 L .58259 .54338 L .429 .057 0 r
F
.59737 .53821 m .59762 .53566 L .58281 .54085 L F
.38531 .38 m .38037 .37437 L .37778 .37583 L 1 1 0 r
F
.38531 .38 m .38748 .37816 L .38037 .37437 L F
.42944 .3512 m .42611 .35109 L .42412 .35265 L .774 .705 0 r
F
.42944 .3512 m .43119 .34943 L .42611 .35109 L F
.39168 .58253 m .37332 .57722 L .37388 .57953 L 1 .492 0 r
F
.39214 .58478 m .39168 .58253 L .37388 .57953 L 1 .477 0 r
F
.85716 .67305 m .83575 .68119 L .83366 .68745 L .042 0 0 r
F
.85716 .67305 m .85942 .66661 L .83575 .68119 L F
.67106 .12633 m .66787 .13572 L .67372 .13929 L .284 .361 0 r
F
.67106 .12633 m .66497 .12358 L .66787 .13572 L F
.28985 .85722 m .25642 .8472 L .25996 .85129 L .931 .068 0 r
F
.29292 .86107 m .28985 .85722 L .25996 .85129 L .907 .064 0 r
F
.57763 .5614 m .56246 .56339 L .56204 .56568 L .493 .054 0 r
F
.57763 .5614 m .57812 .55909 L .56246 .56339 L F
.35015 .53561 m .33383 .52746 L .33404 .53016 L 1 .739 0 r
F
.35037 .53825 m .35015 .53561 L .33404 .53016 L 1 .727 0 r
F
.89818 .54787 m .87938 .55923 L .87903 .5661 L 0 0 0 r
F
.89818 .54787 m .89855 .54086 L .87938 .55923 L F
.55399 .36838 m .5451 .36977 L .54666 .37234 L .542 .474 0 r
F
.55571 .37084 m .55399 .36838 L .54666 .37234 L .544 .48 0 r
F
.43204 .59611 m .41405 .59203 L .41448 .59401 L 1 .335 0 r
F
.43235 .59804 m .43204 .59611 L .41448 .59401 L 1 .317 0 r
F
.68904 .67065 m .67098 .67571 L .66926 .67957 L .173 0 0 r
F
.68904 .67065 m .69109 .66682 L .67098 .67571 L F
.45051 .60125 m .43235 .59804 L .43267 .59994 L 1 .258 0 r
F
.45068 .6031 m .45051 .60125 L .43267 .59994 L 1 .24 0 r
F
.46865 .60363 m .45051 .60125 L .45068 .6031 L .943 .191 0 r
F
.4686 .61022 m .46859 .60833 L .45033 .60811 L .93 .179 0 r
F
.48665 .6098 m .46859 .60833 L .4686 .61022 L .867 .123 0 r
F
.48665 .6098 m .48681 .60792 L .46859 .60833 L F
.33485 .48832 m .32143 .47867 L .32101 .48155 L 1 .941 0 r
F
.33453 .49117 m .33485 .48832 L .32101 .48155 L 1 .93 0 r
F
.61024 .49279 m .59714 .49617 L .59742 .49886 L .38 .069 0 r
F
.61024 .49279 m .60993 .49011 L .59714 .49617 L F
.8858 .37538 m .87239 .38948 L .87449 .39615 L 0 .019 0 r
F
.8858 .37538 m .88364 .3687 L .87239 .38948 L F
.24693 .82395 m .21457 .81154 L .21809 .81619 L 1 .085 0 r
F
.25009 .82835 m .24693 .82395 L .21809 .81619 L .998 .081 0 r
F
.56923 .77822 m .54818 .78638 L .5469 .78977 L .219 0 0 r
F
.56923 .77822 m .57095 .77508 L .54818 .78638 L F
.66331 .23918 m .6848 .2143 L .68704 .22107 L 1 .373 0 r
F
.66331 .23918 m .65964 .2354 L .6848 .2143 L F
.37463 .84062 m .34209 .83885 L .3444 .84233 L .865 .064 0 r
F
.37637 .844 m .37463 .84062 L .3444 .84233 L .848 .061 0 r
F
.46815 .65283 m .46813 .65104 L .44791 .65152 L .798 .059 0 r
F
.48786 .65138 m .46813 .65104 L .46815 .65283 L .705 .047 0 r
F
.48786 .65138 m .48812 .64965 L .46813 .65104 L F
.70644 .30797 m .70841 .30936 L .70795 .3161 L .817 .151 0 r
F
.70644 .30797 m .70618 .30188 L .70841 .30936 L F
.37441 .55183 m .3586 .54465 L .35889 .5471 L 1 .682 0 r
F
.37468 .55423 m .37441 .55183 L .35889 .5471 L 1 .667 0 r
F
.41486 .35633 m .41171 .35462 L .40945 .35614 L .825 .908 0 r
F
.41486 .35633 m .41691 .35467 L .41171 .35462 L F
.38974 .37182 m .38603 .36755 L .38371 .36929 L 1 1 0 r
F
.38974 .37182 m .39188 .36991 L .38603 .36755 L F
.41247 .36316 m .40877 .36068 L .4067 .36244 L .997 1 0 r
F
.41247 .36316 m .41438 .36132 L .40877 .36068 L F
.31869 .52339 m .30583 .51262 L .30553 .51574 L 1 .91 0 r
F
.31848 .52652 m .31869 .52339 L .30553 .51574 L 1 .897 0 r
F
.55227 .36588 m .54354 .36715 L .5451 .36977 L .539 .465 0 r
F
.55399 .36838 m .55227 .36588 L .5451 .36977 L .542 .474 0 r
F
.60733 .48731 m .59464 .49064 L .59496 .49329 L .377 .07 0 r
F
.60733 .48731 m .60697 .48466 L .59464 .49064 L F
.46866 .60544 m .46865 .60363 L .45068 .6031 L .936 .173 0 r
F
.48648 .60521 m .46865 .60363 L .46866 .60544 L .869 .116 0 r
F
.48648 .60521 m .48664 .6034 L .46865 .60363 L F
.35891 .60838 m .3404 .60008 L .34111 .60293 L 1 .518 0 r
F
.3596 .61113 m .35891 .60838 L .34111 .60293 L 1 .5 0 r
F
.59533 .75765 m .57576 .7651 L .57421 .76852 L .174 0 0 r
F
.59533 .75765 m .59732 .75451 L .57576 .7651 L F
.59532 .53466 m .58117 .53737 L .58096 .53985 L .417 .056 0 r
F
.59532 .53466 m .59556 .53216 L .58117 .53737 L F
.54658 .63503 m .52918 .63711 L .52843 .63896 L .422 .013 0 r
F
.54658 .63503 m .54757 .63318 L .52918 .63711 L F
.65427 .50685 m .64504 .51237 L .64432 .51551 L 0 0 0 r
F
.65427 .50685 m .65503 .50372 L .64504 .51237 L F
.336 .57666 m .31965 .56684 L .32004 .56988 L 1 .687 0 r
F
.33642 .57964 m .336 .57666 L .32004 .56988 L 1 .671 0 r
F
.41323 .58797 m .39563 .58295 L .39613 .58505 L 1 .422 0 r
F
.41363 .59002 m .41323 .58797 L .39613 .58505 L 1 .404 0 r
F
.38246 .62852 m .36266 .62186 L .36351 .62448 L 1 .376 0 r
F
.38322 .63101 m .38246 .62852 L .36351 .62448 L 1 .356 0 r
F
.14187 .72153 m .1133 .70263 L .11584 .70871 L 1 .331 0 r
F
.1443 .72737 m .14187 .72153 L .11584 .70871 L 1 .302 0 r
F
.37091 .56534 m .35321 .55878 L .3537 .56127 L 1 .591 0 r
F
.37134 .56776 m .37091 .56534 L .3537 .56127 L 1 .578 0 r
F
.61149 .58523 m .59749 .5896 L .59648 .59206 L .223 0 0 r
F
.61149 .58523 m .61261 .58273 L .59749 .5896 L F
.69953 .11842 m .69622 .12944 L .70257 .13279 L .283 .357 0 r
F
.69953 .11842 m .69317 .11548 L .69622 .12944 L F
.39385 .57429 m .37692 .56823 L .37739 .57049 L 1 .534 0 r
F
.39426 .57649 m .39385 .57429 L .37739 .57049 L 1 .517 0 r
F
.35764 .51685 m .34383 .50863 L .3437 .51123 L 1 .864 0 r
F
.35756 .51943 m .35764 .51685 L .3437 .51123 L 1 .852 0 r
F
.55056 .36333 m .542 .36445 L .54354 .36715 L .535 .452 0 r
F
.55227 .36588 m .55056 .36333 L .54354 .36715 L .539 .465 0 r
F
.41216 .59569 m .39365 .5914 L .3942 .59355 L 1 .396 0 r
F
.41259 .59779 m .41216 .59569 L .3942 .59355 L 1 .379 0 r
F
.40527 .64099 m .3848 .63588 L .38563 .63828 L 1 .251 0 r
F
.40595 .64323 m .40527 .64099 L .38563 .63828 L 1 .23 0 r
F
.54067 .59674 m .524 .59724 L .52357 .59925 L .65 .06 0 r
F
.54067 .59674 m .54125 .59472 L .524 .59724 L F
.67235 .45045 m .66624 .45559 L .66532 .45938 L 0 0 0 r
F
.67235 .45045 m .67338 .44664 L .66624 .45559 L F
.50441 .60871 m .48681 .60792 L .48665 .6098 L .794 .072 0 r
F
.50441 .60871 m .50475 .60684 L .48681 .60792 L F
.62324 .73471 m .60464 .74108 L .6029 .74455 L .164 0 0 r
F
.62324 .73471 m .6254 .73147 L .60464 .74108 L F
.38748 .37816 m .38303 .37305 L .38037 .37437 L 1 1 0 r
F
.38748 .37816 m .38966 .37637 L .38303 .37305 L F
.61052 .49548 m .59742 .49886 L .59767 .50154 L .377 .067 0 r
F
.61052 .49548 m .61024 .49279 L .59742 .49886 L F
.55946 .58517 m .54337 .58634 L .54287 .58848 L .573 .055 0 r
F
.55946 .58517 m .56007 .58301 L .54337 .58634 L F
.75678 .55022 m .74208 .55792 L .74127 .56255 L .028 0 0 r
F
.75678 .55022 m .75759 .5455 L .74208 .55792 L F
.43157 .60335 m .41303 .59986 L .41349 .6019 L 1 .318 0 r
F
.43188 .60534 m .43157 .60335 L .41349 .6019 L 1 .3 0 r
F
.33453 .49117 m .32101 .48155 L .32064 .48442 L 1 .93 0 r
F
.33425 .49402 m .33453 .49117 L .32064 .48442 L 1 .919 0 r
F
.53988 .59248 m .52343 .59306 L .523 .59501 L .645 .059 0 r
F
.53988 .59248 m .54046 .5905 L .52343 .59306 L F
.55611 .89481 m .52794 .89437 L .52656 .89711 L .438 0 0 r
F
.55611 .89481 m .55819 .89203 L .52794 .89437 L F
.57861 .56764 m .56321 .56952 L .56276 .57183 L .496 .053 0 r
F
.57861 .56764 m .57915 .5653 L .56321 .56952 L F
.50406 .60423 m .48664 .6034 L .48648 .60521 L .794 .071 0 r
F
.50406 .60423 m .50439 .60242 L .48664 .6034 L F
.79628 .74703 m .77469 .75338 L .77168 .75869 L .078 0 0 r
F
.79628 .74703 m .79957 .74155 L .77469 .75338 L F
.59707 .54074 m .58259 .54338 L .58233 .54589 L .422 .055 0 r
F
.59707 .54074 m .59737 .53821 L .58259 .54338 L F
.60764 .48995 m .59496 .49329 L .59525 .49594 L .373 .068 0 r
F
.60764 .48995 m .60733 .48731 L .59496 .49329 L F
.19316 .79289 m .16135 .77773 L .1648 .78308 L 1 .139 0 r
F
.19633 .79798 m .19316 .79289 L .1648 .78308 L 1 .111 0 r
F
.73354 .33243 m .7317 .32761 L .74637 .33017 L 1 .344 0 r
F
.70269 .23512 m .72083 .22018 L .72187 .22811 L 1 .941 0 r
F
.70269 .23512 m .70926 .21953 L .72083 .22018 L F
.35037 .53825 m .33404 .53016 L .33428 .53286 L 1 .727 0 r
F
.35062 .54088 m .35037 .53825 L .33428 .53286 L 1 .715 0 r
F
.55837 .58104 m .54254 .58231 L .54205 .5844 L .566 .055 0 r
F
.55837 .58104 m .55897 .57892 L .54254 .58231 L F
.58866 .60838 m .57332 .61195 L .57229 .61415 L .299 0 0 r
F
.58866 .60838 m .58986 .60616 L .57332 .61195 L F
.1521 .70674 m .12229 .68966 L .12477 .69552 L 1 .37 0 r
F
.15444 .71234 m .1521 .70674 L .12477 .69552 L 1 .345 0 r
F
.54886 .36071 m .54046 .36167 L .542 .36445 L .529 .434 0 r
F
.55056 .36333 m .54886 .36071 L .542 .36445 L .535 .452 0 r
F
.39188 .36991 m .38836 .36584 L .38603 .36755 L 1 1 0 r
F
.39188 .36991 m .39403 .36804 L .38836 .36584 L F
.63356 .55377 m .62156 .5589 L .62067 .56166 L .114 0 0 r
F
.63356 .55377 m .63451 .55098 L .62156 .5589 L F
.57711 .5637 m .56204 .56568 L .56159 .56795 L .486 .052 0 r
F
.57711 .5637 m .57763 .5614 L .56204 .56568 L F
.69492 .12573 m .69467 .13186 L .70087 .13536 L .342 .397 0 r
F
.69492 .12573 m .68697 .12569 L .69467 .13186 L F
.31848 .52652 m .30553 .51574 L .30528 .51887 L 1 .897 0 r
F
.31832 .52965 m .31848 .52652 L .30528 .51887 L 1 .883 0 r
F
.89153 .38123 m .87784 .39545 L .88002 .40217 L 0 .022 0 r
F
.89153 .38123 m .88923 .37451 L .87784 .39545 L F
.44791 .65152 m .42727 .64906 L .42779 .65108 L .894 .073 0 r
F
.44819 .65339 m .44791 .65152 L .42779 .65108 L .88 .07 0 r
F
.46815 .65283 m .44791 .65152 L .44819 .65339 L .798 .059 0 r
F
.25651 .80062 m .22347 .79136 L .22673 .79588 L 1 .13 0 r
F
.25937 .80492 m .25651 .80062 L .22673 .79588 L 1 .106 0 r
F
.74431 .79855 m .72154 .8032 L .71819 .80776 L .154 0 0 r
F
.74431 .79855 m .74805 .79384 L .72154 .8032 L F
.45033 .60811 m .43188 .60534 L .43222 .60729 L .992 .245 0 r
F
.4505 .61001 m .45033 .60811 L .43222 .60729 L .985 .226 0 r
F
.4686 .61022 m .45033 .60811 L .4505 .61001 L .93 .179 0 r
F
.70114 .84074 m .67673 .84359 L .67337 .84765 L .245 0 0 r
F
.70114 .84074 m .705 .83654 L .67673 .84359 L F
.76887 .44898 m .7618 .45759 L .76203 .46263 L 0 0 0 r
F
.76887 .44898 m .76834 .44402 L .7618 .45759 L F
.54717 .35799 m .53896 .35877 L .54046 .36167 L .521 .409 0 r
F
.54886 .36071 m .54717 .35799 L .54046 .36167 L .529 .434 0 r
F
.39214 .58478 m .37388 .57953 L .37447 .58182 L 1 .477 0 r
F
.39262 .58701 m .39214 .58478 L .37447 .58182 L 1 .462 0 r
F
.56681 .62454 m .55043 .62736 L .54949 .62934 L .362 .003 0 r
F
.56681 .62454 m .56795 .62254 L .55043 .62736 L F
.37468 .55423 m .35889 .5471 L .35921 .54952 L 1 .667 0 r
F
.37498 .55662 m .37468 .55423 L .35921 .54952 L 1 .652 0 r
F
.43119 .34943 m .42813 .34959 L .42611 .35109 L .709 .56 0 r
F
.43119 .34943 m .43296 .34772 L .42813 .34959 L F
.35756 .51943 m .3437 .51123 L .34361 .51383 L 1 .852 0 r
F
.35751 .522 m .35756 .51943 L .34361 .51383 L 1 .84 0 r
F
.50701 .64907 m .48812 .64965 L .48786 .65138 L .599 .033 0 r
F
.50701 .64907 m .50755 .64737 L .48812 .64965 L F
.59504 .53715 m .58096 .53985 L .58071 .54232 L .41 .054 0 r
F
.59504 .53715 m .59532 .53466 L .58096 .53985 L F
.3682 .88642 m .33509 .87987 L .33785 .88312 L .791 .045 0 r
F
.37034 .88948 m .3682 .88642 L .33785 .88312 L .765 .04 0 r
F
.29283 .85105 m .26003 .84103 L .2635 .84508 L .934 .068 0 r
F
.29584 .85486 m .29283 .85105 L .2635 .84508 L .911 .064 0 r
F
.65921 .86296 m .63396 .86487 L .63088 .86843 L .3 0 0 r
F
.65921 .86296 m .66286 .85928 L .63396 .86487 L F
.61075 .49816 m .59767 .50154 L .59788 .50421 L .373 .065 0 r
F
.61075 .49816 m .61052 .49548 L .59767 .50154 L F
.41438 .36132 m .41085 .35894 L .40877 .36068 L .983 1 0 r
F
.41438 .36132 m .4163 .3595 L .41085 .35894 L F
.33983 .83529 m .30687 .83136 L .30965 .83505 L .928 .071 0 r
F
.34209 .83885 m .33983 .83529 L .30965 .83505 L .911 .068 0 r
F
.88921 .54645 m .87265 .55793 L .87214 .56465 L 0 0 0 r
F
.88921 .54645 m .88981 .53963 L .87265 .55793 L F
.52216 .60508 m .50507 .60494 L .50475 .60684 L .72 .065 0 r
F
.52216 .60508 m .52265 .60316 L .50507 .60494 L F
.69288 .3882 m .68931 .39278 L .68772 .39802 L 0 0 0 r
F
.69288 .3882 m .69443 .38295 L .68931 .39278 L F
.52161 .60068 m .5047 .60057 L .50439 .60242 L .717 .064 0 r
F
.52161 .60068 m .52209 .59882 L .5047 .60057 L F
.60792 .49259 m .59525 .49594 L .5955 .49858 L .37 .066 0 r
F
.60792 .49259 m .60764 .48995 L .59525 .49594 L F
.33425 .49402 m .32064 .48442 L .32031 .48729 L 1 .919 0 r
F
.33401 .49686 m .33425 .49402 L .32031 .48729 L 1 .908 0 r
F
.658 .13644 m .65485 .12858 L .65515 .14465 L 0 0 0 r
F
.41691 .35467 m .41397 .35317 L .41171 .35462 L .778 .846 0 r
F
.41691 .35467 m .41898 .35306 L .41397 .35317 L F
.54552 .35515 m .53749 .3557 L .53896 .35877 L .51 .378 0 r
F
.54717 .35799 m .54552 .35515 L .53896 .35877 L .521 .409 0 r
F
.67701 .12931 m .67372 .13929 L .67942 .14306 L .274 .331 0 r
F
.67701 .12931 m .67106 .12633 L .67372 .13929 L F
.84858 .66877 m .82892 .67743 L .82677 .68352 L 0 0 0 r
F
.84858 .66877 m .85089 .66252 L .82892 .67743 L F
.43235 .59804 m .41448 .59401 L .41493 .59596 L 1 .317 0 r
F
.43267 .59994 m .43235 .59804 L .41493 .59596 L 1 .298 0 r
F
.38966 .37637 m .38573 .37186 L .38303 .37305 L 1 1 0 r
F
.38966 .37637 m .39185 .37462 L .38573 .37186 L F
.54236 .34891 m .53474 .34884 L .53607 .35242 L .478 .284 0 r
F
.54391 .35215 m .53607 .35242 L .53749 .3557 L .497 .336 0 r
F
.54552 .35515 m .54391 .35215 L .53749 .3557 L .51 .378 0 r
F
.45068 .6031 m .43267 .59994 L .433 .60181 L 1 .24 0 r
F
.45086 .60491 m .45068 .6031 L .433 .60181 L .996 .221 0 r
F
.46866 .60544 m .45068 .6031 L .45086 .60491 L .936 .173 0 r
F
.13743 .73255 m .10792 .71379 L .1107 .71991 L 1 .295 0 r
F
.14006 .73842 m .13743 .73255 L .1107 .71991 L 1 .267 0 r
F
.54391 .35215 m .54236 .34891 L .53607 .35242 L .497 .336 0 r
F
.33642 .57964 m .32004 .56988 L .32047 .57292 L 1 .671 0 r
F
.33687 .58261 m .33642 .57964 L .32047 .57292 L 1 .654 0 r
F
.37134 .56776 m .3537 .56127 L .35422 .56373 L 1 .578 0 r
F
.3718 .57016 m .37134 .56776 L .35422 .56373 L 1 .564 0 r
F
.72366 .62462 m .70653 .63047 L .70507 .63466 L .122 0 0 r
F
.72366 .62462 m .72534 .62038 L .70653 .63047 L F
.46551 .90165 m .46544 .89905 L .43467 .89869 L .596 .016 0 r
F
.49554 .90112 m .46544 .89905 L .46551 .90165 L .54 .01 0 r
F
.49554 .90112 m .49621 .89853 L .46544 .89905 L F
.65351 .50996 m .64432 .51551 L .64359 .51861 L 0 0 0 r
F
.65351 .50996 m .65427 .50685 L .64432 .51551 L F
.1007 .61611 m .07556 .59415 L .07675 .60069 L 1 .57 0 r
F
.10192 .62244 m .1007 .61611 L .07675 .60069 L 1 .546 0 r
F
.59674 .54326 m .58233 .54589 L .58205 .54838 L .415 .053 0 r
F
.59674 .54326 m .59707 .54074 L .58233 .54589 L F
.46861 .61207 m .4686 .61022 L .4505 .61001 L .922 .16 0 r
F
.48648 .61164 m .4686 .61022 L .46861 .61207 L .859 .105 0 r
F
.48648 .61164 m .48665 .6098 L .4686 .61022 L F
.09168 .62637 m .06793 .60337 L .06907 .6101 L 1 .548 0 r
F
.09286 .63292 m .09168 .62637 L .06907 .6101 L 1 .522 0 r
F
.88782 .3821 m .87449 .39615 L .87646 .40285 L 0 .015 0 r
F
.88782 .3821 m .8858 .37538 L .87449 .39615 L F
.39426 .57649 m .37739 .57049 L .37789 .57272 L 1 .517 0 r
F
.3947 .57867 m .39426 .57649 L .37789 .57272 L 1 .5 0 r
F
.39403 .36804 m .3907 .36416 L .38836 .36584 L 1 1 0 r
F
.39403 .36804 m .3962 .36621 L .3907 .36416 L F
.41363 .59002 m .39613 .58505 L .39665 .58712 L 1 .404 0 r
F
.41405 .59203 m .41363 .59002 L .39665 .58712 L 1 .386 0 r
F
.42727 .64906 m .40665 .64544 L .40738 .64761 L .979 .13 0 r
F
.42779 .65108 m .42727 .64906 L .40738 .64761 L .966 .109 0 r
F
.65321 .7087 m .63525 .71418 L .63341 .71777 L .161 0 0 r
F
.65321 .7087 m .65545 .70526 L .63525 .71418 L F
.35062 .54088 m .33428 .53286 L .33456 .53554 L 1 .715 0 r
F
.3509 .54349 m .35062 .54088 L .33456 .53554 L 1 .702 0 r
F
.54503 .28988 m .55911 .24182 L .55286 .27111 L 1 .924 0 r
F
.54503 .28988 m .54825 .27011 L .55911 .24182 L F
.3596 .61113 m .34111 .60293 L .34187 .60576 L 1 .5 0 r
F
.36031 .61385 m .3596 .61113 L .34187 .60576 L 1 .482 0 r
F
.31832 .52965 m .30528 .51887 L .30508 .522 L 1 .883 0 r
F
.31819 .53278 m .31832 .52965 L .30508 .522 L 1 .869 0 r
F
.61095 .50083 m .59788 .50421 L .59805 .50688 L .369 .064 0 r
F
.61095 .50083 m .61075 .49816 L .59788 .50421 L F
.57803 .56995 m .56276 .57183 L .56227 .57411 L .488 .051 0 r
F
.57803 .56995 m .57861 .56764 L .56276 .57183 L F
.35751 .522 m .34361 .51383 L .34356 .51641 L 1 .84 0 r
F
.3575 .52457 m .35751 .522 L .34356 .51641 L 1 .828 0 r
F
.60816 .49523 m .5955 .49858 L .59571 .50121 L .366 .064 0 r
F
.60816 .49523 m .60792 .49259 L .5955 .49858 L F
.52611 .64425 m .50807 .64564 L .50755 .64737 L .499 .02 0 r
F
.52611 .64425 m .5269 .64253 L .50807 .64564 L F
.46867 .60721 m .46866 .60544 L .45086 .60491 L .928 .154 0 r
F
.48632 .60698 m .46866 .60544 L .46867 .60721 L .861 .099 0 r
F
.48632 .60698 m .48648 .60521 L .46866 .60544 L F
.70582 .12148 m .70257 .13279 L .70885 .13626 L .27 .331 0 r
F
.70582 .12148 m .69953 .11842 L .70257 .13279 L F
.89768 .55487 m .87903 .5661 L .87856 .57296 L 0 0 0 r
F
.89768 .55487 m .89818 .54787 L .87903 .5661 L F
.62129 .87852 m .59525 .87962 L .59262 .88278 L .347 0 0 r
F
.62129 .87852 m .62455 .87526 L .59525 .87962 L F
.36707 .42636 m .35863 .41849 L .35726 .42086 L 0 .024 0 r
F
.66713 .24273 m .68704 .22107 L .68924 .22767 L 1 .323 0 r
F
.66713 .24273 m .66331 .23918 L .68704 .22107 L F
.33401 .49686 m .32031 .48729 L .32002 .49016 L 1 .908 0 r
F
.33381 .4997 m .33401 .49686 L .32002 .49016 L 1 .897 0 r
F
.08347 .63669 m .05835 .61355 L .05975 .6204 L 1 .517 0 r
F
.08488 .64334 m .08347 .63669 L .05975 .6204 L 1 .491 0 r
F
.55881 .5873 m .54287 .58848 L .54235 .59059 L .565 .053 0 r
F
.55881 .5873 m .55946 .58517 L .54287 .58848 L F
.61033 .5877 m .59648 .59206 L .59544 .5945 L .216 0 0 r
F
.61033 .5877 m .61149 .58523 L .59648 .59206 L F
.41259 .59779 m .3942 .59355 L .39477 .59567 L 1 .379 0 r
F
.41303 .59986 m .41259 .59779 L .39477 .59567 L 1 .361 0 r
F
.67136 .45418 m .66532 .45938 L .66442 .4631 L 0 0 0 r
F
.67136 .45418 m .67235 .45045 L .66532 .45938 L F
.54007 .59873 m .52357 .59925 L .52311 .60122 L .641 .058 0 r
F
.54007 .59873 m .54067 .59674 L .52357 .59925 L F
.55456 .8872 m .52696 .88716 L .52559 .88977 L .421 0 0 r
F
.55456 .8872 m .55662 .88456 L .52696 .88716 L F
.59473 .53962 m .58071 .54232 L .58043 .54477 L .403 .052 0 r
F
.59473 .53962 m .59504 .53715 L .58071 .54232 L F
.57655 .56597 m .56159 .56795 L .56112 .57019 L .478 .05 0 r
F
.57655 .56597 m .57711 .5637 L .56159 .56795 L F
.70651 .31404 m .70795 .3161 L .7073 .32275 L .792 .151 0 r
F
.70651 .31404 m .70644 .30797 L .70795 .3161 L F
.53929 .59442 m .523 .59501 L .52255 .59693 L .636 .057 0 r
F
.53929 .59442 m .53988 .59248 L .523 .59501 L F
.55774 .58313 m .54205 .5844 L .54154 .58646 L .558 .052 0 r
F
.55774 .58313 m .55837 .58104 L .54205 .5844 L F
.58722 .88881 m .56024 .88914 L .55819 .89203 L .392 0 0 r
F
.58722 .88881 m .58994 .88585 L .56024 .88914 L F
.68693 .67443 m .66926 .67957 L .66748 .6834 L .156 0 0 r
F
.68693 .67443 m .68904 .67065 L .66926 .67957 L F
.37498 .55662 m .35921 .54952 L .35956 .55193 L 1 .652 0 r
F
.37532 .55898 m .37498 .55662 L .35956 .55193 L 1 .636 0 r
F
.5184 .81411 m .49368 .82154 L .4932 .82479 L .368 0 0 r
F
.5184 .81411 m .51937 .81096 L .49368 .82154 L F
.38322 .63101 m .36351 .62448 L .36439 .62707 L 1 .356 0 r
F
.384 .63346 m .38322 .63101 L .36439 .62707 L 1 .337 0 r
F
.43188 .60534 m .41349 .6019 L .41397 .60391 L 1 .3 0 r
F
.43222 .60729 m .43188 .60534 L .41397 .60391 L 1 .281 0 r
F
.73544 .33717 m .73354 .33243 L .74753 .33582 L 1 .287 0 r
F
.50407 .61055 m .48665 .6098 L .48648 .61164 L .786 .07 0 r
F
.50407 .61055 m .50441 .60871 L .48665 .6098 L F
.4163 .3595 m .41295 .35724 L .41085 .35894 L .965 1 0 r
F
.4163 .3595 m .41823 .35772 L .41295 .35724 L F
.80005 .75849 m .77757 .76414 L .77449 .76955 L .108 0 0 r
F
.80005 .75849 m .80344 .7529 L .77757 .76414 L F
.19828 .78714 m .16734 .772 L .17067 .77728 L 1 .145 0 r
F
.20137 .79217 m .19828 .78714 L .17067 .77728 L 1 .117 0 r
F
.7559 .55491 m .74127 .56255 L .74041 .56715 L .022 0 0 r
F
.7559 .55491 m .75678 .55022 L .74127 .56255 L F
.39185 .37462 m .38843 .37072 L .38573 .37186 L .969 1 0 r
F
.39185 .37462 m .39403 .37289 L .38843 .37072 L F
.50372 .606 m .48648 .60521 L .48632 .60698 L .786 .069 0 r
F
.50372 .606 m .50406 .60423 L .48648 .60521 L F
.63258 .55653 m .62067 .56166 L .61975 .56439 L .109 0 0 r
F
.63258 .55653 m .63356 .55377 L .62067 .56166 L F
.30147 .82374 m .26839 .81741 L .27153 .82143 L .989 .079 0 r
F
.30414 .82759 m .30147 .82374 L .27153 .82143 L .973 .076 0 r
F
.52516 .89973 m .49621 .89853 L .49554 .90112 L .475 0 0 r
F
.52516 .89973 m .52656 .89711 L .49621 .89853 L F
.46817 .65458 m .46815 .65283 L .44819 .65339 L .782 .056 0 r
F
.4876 .65307 m .46815 .65283 L .46817 .65458 L .687 .044 0 r
F
.4876 .65307 m .48786 .65138 L .46815 .65283 L F
.85478 .67945 m .83366 .68745 L .83146 .69367 L .034 0 0 r
F
.85478 .67945 m .85716 .67305 L .83366 .68745 L F
.54557 .63684 m .52843 .63896 L .52767 .64077 L .413 .009 0 r
F
.54557 .63684 m .54658 .63503 L .52843 .63896 L F
.6111 .50351 m .59805 .50688 L .59819 .50954 L .366 .062 0 r
F
.6111 .50351 m .61095 .50083 L .59805 .50688 L F
.60836 .49786 m .59571 .50121 L .5959 .50384 L .362 .062 0 r
F
.60836 .49786 m .60816 .49523 L .59571 .50121 L F
.39262 .58701 m .37447 .58182 L .37509 .58408 L 1 .462 0 r
F
.39312 .58922 m .39262 .58701 L .37509 .58408 L 1 .445 0 r
F
.36984 .87998 m .33727 .87349 L .33998 .8767 L .79 .044 0 r
F
.37195 .88298 m .36984 .87998 L .33998 .8767 L .764 .04 0 r
F
.76934 .45394 m .76203 .46263 L .76221 .46764 L 0 0 0 r
F
.76934 .45394 m .76887 .44898 L .76203 .46263 L F
.70188 .1275 m .70087 .13536 L .70706 .13886 L .252 .333 0 r
F
.70188 .1275 m .69492 .12573 L .70087 .13536 L F
.43296 .34772 m .43016 .34817 L .42813 .34959 L .666 .385 0 r
F
.43296 .34772 m .43475 .34607 L .43016 .34817 L F
.41898 .35306 m .41625 .35177 L .41397 .35317 L .725 .771 0 r
F
.41898 .35306 m .42106 .35151 L .41625 .35177 L F
.3962 .36621 m .39304 .36252 L .3907 .36416 L .984 1 0 r
F
.3962 .36621 m .39838 .36442 L .39304 .36252 L F
.24625 .83439 m .21352 .82224 L .21722 .82685 L .994 .08 0 r
F
.24956 .83875 m .24625 .83439 L .21722 .82685 L .971 .076 0 r
F
.40595 .64323 m .38563 .63828 L .38649 .64064 L 1 .23 0 r
F
.40665 .64544 m .40595 .64323 L .38649 .64064 L 1 .209 0 r
F
.35399 .45632 m .34406 .44782 L .34309 .45036 L 1 1 0 r
F
.35314 .45891 m .35399 .45632 L .34309 .45036 L F
.59638 .54576 m .58205 .54838 L .58173 .55085 L .408 .051 0 r
F
.59638 .54576 m .59674 .54326 L .58205 .54838 L F
.3575 .52457 m .34356 .51641 L .34355 .51899 L 1 .828 0 r
F
.35752 .52712 m .3575 .52457 L .34355 .51899 L 1 .815 0 r
F
.8937 .38798 m .88002 .40217 L .88208 .40892 L 0 .019 0 r
F
.8937 .38798 m .89153 .38123 L .88002 .40217 L F
.58744 .61057 m .57229 .61415 L .57124 .6163 L .291 0 0 r
F
.58744 .61057 m .58866 .60838 L .57229 .61415 L F
.31819 .53278 m .30508 .522 L .30492 .52513 L 1 .869 0 r
F
.31812 .53591 m .31819 .53278 L .30492 .52513 L 1 .855 0 r
F
.6964 .83331 m .67284 .83671 L .6695 .8406 L .216 0 0 r
F
.6964 .83331 m .70023 .82927 L .67284 .83671 L F
.33381 .4997 m .32002 .49016 L .31977 .49302 L 1 .897 0 r
F
.33364 .50252 m .33381 .4997 L .31977 .49302 L 1 .886 0 r
F
.40775 .84367 m .37637 .844 L .37816 .84729 L .783 .055 0 r
F
.40896 .84689 m .40775 .84367 L .37816 .84729 L .764 .051 0 r
F
.43791 .84137 m .40775 .84367 L .40896 .84689 L .697 .045 0 r
F
.65543 .85525 m .63092 .85768 L .62786 .86109 L .273 0 0 r
F
.65543 .85525 m .65905 .85174 L .63092 .85768 L F
.4505 .61001 m .43222 .60729 L .43256 .60922 L .985 .226 0 r
F
.45069 .61188 m .4505 .61001 L .43256 .60922 L .977 .206 0 r
F
.46861 .61207 m .4505 .61001 L .45069 .61188 L .922 .16 0 r
F
.3718 .57016 m .35422 .56373 L .35477 .56618 L 1 .564 0 r
F
.37228 .57253 m .3718 .57016 L .35477 .56618 L 1 .55 0 r
F
.3509 .54349 m .33456 .53554 L .33487 .5382 L 1 .702 0 r
F
.35121 .54608 m .3509 .54349 L .33487 .5382 L 1 .689 0 r
F
.33687 .58261 m .32047 .57292 L .32094 .57594 L 1 .654 0 r
F
.33737 .58557 m .33687 .58261 L .32094 .57594 L 1 .637 0 r
F
.35314 .45891 m .34309 .45036 L .34216 .45291 L 1 1 0 r
F
.35233 .4615 m .35314 .45891 L .34216 .45291 L F
.52166 .60695 m .50475 .60684 L .50441 .60871 L .711 .062 0 r
F
.52166 .60695 m .52216 .60508 L .50475 .60684 L F
.65273 .51304 m .64359 .51861 L .64285 .52169 L 0 0 0 r
F
.65273 .51304 m .65351 .50996 L .64359 .51861 L F
.52111 .60251 m .50439 .60242 L .50406 .60423 L .709 .062 0 r
F
.52111 .60251 m .52161 .60068 L .50439 .60242 L F
.20835 .76779 m .17643 .75518 L .17958 .76027 L 1 .211 0 r
F
.21121 .77263 m .20835 .76779 L .17958 .76027 L 1 .186 0 r
F
.33239 .87652 m .29925 .8685 L .30251 .87207 L .845 .053 0 r
F
.33509 .87987 m .33239 .87652 L .30251 .87207 L .82 .048 0 r
F
.68282 .13252 m .67942 .14306 L .68494 .14707 L .261 .297 0 r
F
.68282 .13252 m .67701 .12931 L .67942 .14306 L F
.43267 .59994 m .41493 .59596 L .4154 .59789 L 1 .298 0 r
F
.433 .60181 m .43267 .59994 L .4154 .59789 L 1 .279 0 r
F
.46561 .89463 m .46554 .89213 L .43526 .8919 L .582 .014 0 r
F
.49512 .89391 m .46554 .89213 L .46561 .89463 L .521 .006 0 r
F
.49512 .89391 m .49578 .89142 L .46554 .89213 L F
.3947 .57867 m .37789 .57272 L .37842 .57493 L 1 .5 0 r
F
.39515 .58082 m .3947 .57867 L .37842 .57493 L 1 .483 0 r
F
.6818 .2573 m .6954 .24674 L .69725 .25293 L 1 .222 0 r
F
.6942 .2519 m .72187 .22811 L .72241 .23626 L 1 1 0 r
F
.6942 .2519 m .70269 .23512 L .72187 .22811 L F
.59438 .54208 m .58043 .54477 L .58013 .5472 L .396 .05 0 r
F
.59438 .54208 m .59473 .53962 L .58043 .54477 L F
.57743 .57224 m .56227 .57411 L .56176 .57638 L .48 .049 0 r
F
.57743 .57224 m .57803 .56995 L .56227 .57411 L F
.35233 .4615 m .34216 .45291 L .34127 .45547 L 1 1 0 r
F
.35156 .4641 m .35233 .4615 L .34127 .45547 L F
.60852 .50048 m .5959 .50384 L .59604 .50646 L .358 .061 0 r
F
.60852 .50048 m .60836 .49786 L .5959 .50384 L F
.61122 .50617 m .59819 .50954 L .5983 .5122 L .362 .06 0 r
F
.61122 .50617 m .6111 .50351 L .59819 .50954 L F
.45086 .60491 m .433 .60181 L .43335 .60364 L .996 .221 0 r
F
.45104 .60669 m .45086 .60491 L .43335 .60364 L .988 .201 0 r
F
.46867 .60721 m .45086 .60491 L .45104 .60669 L .928 .154 0 r
F
.56564 .6265 m .54949 .62934 L .54854 .63128 L .353 0 0 r
F
.56564 .6265 m .56681 .62454 L .54949 .62934 L F
.74632 .81019 m .72303 .81418 L .71959 .81882 L .177 0 0 r
F
.74632 .81019 m .75017 .80538 L .72303 .81418 L F
.39403 .37289 m .39103 .36952 L .38843 .37072 L .931 1 0 r
F
.39403 .37289 m .39619 .37118 L .39103 .36952 L F
.41405 .59203 m .39665 .58712 L .3972 .58916 L 1 .386 0 r
F
.41448 .59401 m .41405 .59203 L .3972 .58916 L 1 .367 0 r
F
.69133 .3933 m .68772 .39802 L .68616 .40309 L 0 0 0 r
F
.69133 .3933 m .69288 .3882 L .68772 .39802 L F
.1443 .72737 m .11584 .70871 L .11848 .71474 L 1 .302 0 r
F
.14682 .73316 m .1443 .72737 L .11848 .71474 L 1 .273 0 r
F
.37532 .55898 m .35956 .55193 L .35994 .55433 L 1 .636 0 r
F
.37567 .56132 m .37532 .55898 L .35994 .55433 L 1 .621 0 r
F
.44819 .65339 m .42779 .65108 L .42833 .65306 L .88 .07 0 r
F
.44849 .65523 m .44819 .65339 L .42833 .65306 L .865 .067 0 r
F
.46817 .65458 m .44819 .65339 L .44849 .65523 L .782 .056 0 r
F
.88849 .55326 m .87214 .56465 L .87151 .57136 L 0 0 0 r
F
.88849 .55326 m .88921 .54645 L .87214 .56465 L F
.57597 .56822 m .56112 .57019 L .56062 .57241 L .471 .048 0 r
F
.57597 .56822 m .57655 .56597 L .56112 .57019 L F
.41823 .35772 m .41506 .35558 L .41295 .35724 L .941 1 0 r
F
.41823 .35772 m .42018 .35598 L .41506 .35558 L F
.8897 .38886 m .87646 .40285 L .87831 .40958 L 0 .01 0 r
F
.8897 .38886 m .88782 .3821 L .87646 .40285 L F
.46862 .61389 m .46861 .61207 L .45069 .61188 L .914 .141 0 r
F
.48631 .61344 m .46861 .61207 L .46862 .61389 L .85 .087 0 r
F
.48631 .61344 m .48648 .61164 L .46861 .61207 L F
.35156 .4641 m .34127 .45547 L .34042 .45804 L 1 1 0 r
F
.35082 .4667 m .35156 .4641 L .34042 .45804 L F
.36031 .61385 m .34187 .60576 L .34266 .60857 L 1 .482 0 r
F
.36107 .61654 m .36031 .61385 L .34266 .60857 L 1 .463 0 r
F
.35752 .52712 m .34355 .51899 L .34357 .52156 L 1 .815 0 r
F
.35758 .52967 m .35752 .52712 L .34357 .52156 L 1 .801 0 r
F
.39838 .36442 m .39539 .36091 L .39304 .36252 L .963 1 0 r
F
.39838 .36442 m .40057 .36268 L .39539 .36091 L F
.40279 .89465 m .37034 .88948 L .37253 .89243 L .722 .034 0 r
F
.4043 .89742 m .40279 .89465 L .37253 .89243 L .695 .029 0 r
F
.43467 .89869 m .40279 .89465 L .4043 .89742 L .665 .026 0 r
F
.55815 .58941 m .54235 .59059 L .54182 .59267 L .556 .051 0 r
F
.55815 .58941 m .55881 .5873 L .54235 .59059 L F
.33364 .50252 m .31977 .49302 L .31957 .49587 L 1 .886 0 r
F
.33352 .50533 m .33364 .50252 L .31957 .49587 L 1 .874 0 r
F
.6704 .45784 m .66442 .4631 L .66356 .46675 L 0 0 0 r
F
.6704 .45784 m .67136 .45418 L .66442 .4631 L F
.71203 .12466 m .70885 .13626 L .71506 .13984 L .257 .305 0 r
F
.71203 .12466 m .70582 .12148 L .70885 .13626 L F
.50647 .65071 m .48786 .65138 L .4876 .65307 L .58 .029 0 r
F
.50647 .65071 m .50701 .64907 L .48786 .65138 L F
.61834 .8707 m .59297 .87228 L .59036 .8753 L .323 0 0 r
F
.61834 .8707 m .62157 .8676 L .59297 .87228 L F
.31812 .53591 m .30492 .52513 L .3048 .52826 L 1 .855 0 r
F
.31808 .53903 m .31812 .53591 L .3048 .52826 L 1 .841 0 r
F
.54282 .79931 m .52031 .8077 L .51937 .81096 L .268 0 0 r
F
.54282 .79931 m .54422 .79624 L .52031 .8077 L F
.41303 .59986 m .39477 .59567 L .39537 .59776 L 1 .361 0 r
F
.41349 .6019 m .41303 .59986 L .39537 .59776 L 1 .343 0 r
F
.55708 .58519 m .54154 .58646 L .54101 .5885 L .549 .05 0 r
F
.55708 .58519 m .55774 .58313 L .54154 .58646 L F
.15444 .71234 m .12477 .69552 L .12734 .70133 L 1 .345 0 r
F
.15687 .71789 m .15444 .71234 L .12734 .70133 L 1 .32 0 r
F
.46868 .60894 m .46867 .60721 L .45104 .60669 L .92 .135 0 r
F
.48615 .60871 m .46867 .60721 L .46868 .60894 L .853 .082 0 r
F
.48615 .60871 m .48632 .60698 L .46867 .60721 L F
.72192 .62882 m .70507 .63466 L .70354 .63881 L .111 0 0 r
F
.72192 .62882 m .72366 .62462 L .70507 .63466 L F
.58501 .88102 m .55865 .88181 L .55662 .88456 L .371 0 0 r
F
.58501 .88102 m .58771 .87822 L .55865 .88181 L F
.621 .73788 m .6029 .74455 L .6011 .74795 L .128 0 0 r
F
.621 .73788 m .62324 .73471 L .6029 .74455 L F
.59598 .54824 m .58173 .55085 L .58138 .55331 L .401 .049 0 r
F
.59598 .54824 m .59638 .54576 L .58173 .55085 L F
.53945 .60069 m .52311 .60122 L .52265 .60316 L .632 .055 0 r
F
.53945 .60069 m .54007 .59873 L .52311 .60122 L F
.59328 .76071 m .57421 .76852 L .57261 .77185 L .134 0 0 r
F
.59328 .76071 m .59533 .75765 L .57421 .76852 L F
.60914 .59014 m .59544 .5945 L .59438 .5969 L .209 0 0 r
F
.60914 .59014 m .61033 .5877 L .59544 .5945 L F
.35082 .4667 m .34042 .45804 L .3396 .46062 L 1 1 0 r
F
.35011 .46931 m .35082 .4667 L .3396 .46062 L F
.53868 .59634 m .52255 .59693 L .52209 .59882 L .628 .055 0 r
F
.53868 .59634 m .53929 .59442 L .52255 .59693 L F
.73737 .34186 m .73544 .33717 L .74871 .34138 L 1 .229 0 r
F
.43548 .90131 m .43467 .89869 L .4043 .89742 L .638 .021 0 r
F
.46551 .90165 m .43467 .89869 L .43548 .90131 L .596 .016 0 r
F
.60864 .5031 m .59604 .50646 L .59615 .50908 L .354 .059 0 r
F
.60864 .5031 m .60852 .50048 L .59604 .50646 L F
.52421 .89228 m .49578 .89142 L .49512 .89391 L .461 0 0 r
F
.52421 .89228 m .52559 .88977 L .49578 .89142 L F
.63158 .55927 m .61975 .56439 L .61881 .5671 L .103 0 0 r
F
.63158 .55927 m .63258 .55653 L .61975 .56439 L F
.35121 .54608 m .33487 .5382 L .33522 .54085 L 1 .689 0 r
F
.35155 .54866 m .35121 .54608 L .33522 .54085 L 1 .676 0 r
F
.42106 .35151 m .41854 .35043 L .41625 .35177 L .666 .681 0 r
F
.42106 .35151 m .42314 .35002 L .41854 .35043 L F
.56746 .78125 m .5469 .78977 L .54558 .79305 L .181 0 0 r
F
.56746 .78125 m .56923 .77822 L .5469 .78977 L F
.43222 .60729 m .41397 .60391 L .41446 .60589 L 1 .281 0 r
F
.43256 .60922 m .43222 .60729 L .41446 .60589 L 1 .261 0 r
F
.61129 .50883 m .5983 .5122 L .59837 .51485 L .358 .058 0 r
F
.61129 .50883 m .61122 .50617 L .5983 .5122 L F
.79289 .75244 m .77168 .75869 L .76858 .76392 L .068 0 0 r
F
.79289 .75244 m .79628 .74703 L .77168 .75869 L F
.67096 .24623 m .68924 .22767 L .69137 .23413 L 1 .287 0 r
F
.67096 .24623 m .66713 .24273 L .68924 .22767 L F
.59189 .40541 m .58222 .40861 L .5836 .41111 L .393 .296 0 r
F
.59335 .40787 m .5836 .41111 L .58495 .41363 L .389 .285 0 r
F
.59335 .40787 m .59189 .40541 L .5836 .41111 L F
.59479 .41034 m .58495 .41363 L .58628 .41616 L .386 .275 0 r
F
.59479 .41034 m .59335 .40787 L .58495 .41363 L F
.39312 .58922 m .37509 .58408 L .37573 .58632 L 1 .445 0 r
F
.39365 .5914 m .39312 .58922 L .37573 .58632 L 1 .429 0 r
F
.5904 .40297 m .58081 .40611 L .58222 .40861 L .397 .306 0 r
F
.59189 .40541 m .5904 .40297 L .58222 .40861 L .393 .296 0 r
F
.10192 .62244 m .07675 .60069 L .07806 .60721 L 1 .546 0 r
F
.10325 .62873 m .10192 .62244 L .07806 .60721 L 1 .522 0 r
F
.59619 .41282 m .58628 .41616 L .58757 .4187 L .384 .264 0 r
F
.59619 .41282 m .59479 .41034 L .58628 .41616 L F
.46624 .83712 m .46619 .83395 L .43791 .84137 L .581 .031 0 r
F
.49271 .82792 m .46619 .83395 L .46624 .83712 L .455 .016 0 r
F
.49271 .82792 m .4932 .82479 L .46619 .83395 L F
.58888 .40053 m .57937 .40362 L .58081 .40611 L .401 .315 0 r
F
.5904 .40297 m .58888 .40053 L .58081 .40611 L .397 .306 0 r
F
.76975 .45888 m .76221 .46764 L .76235 .47264 L 0 0 0 r
F
.76975 .45888 m .76934 .45394 L .76221 .46764 L F
.59757 .41531 m .58757 .4187 L .58884 .42125 L .381 .253 0 r
F
.59757 .41531 m .59619 .41282 L .58757 .4187 L F
.50372 .61236 m .48648 .61164 L .48631 .61344 L .776 .068 0 r
F
.50372 .61236 m .50407 .61055 L .48648 .61164 L F
.42779 .65108 m .40738 .64761 L .40811 .64975 L .966 .109 0 r
F
.42833 .65306 m .42779 .65108 L .40811 .64975 L .953 .088 0 r
F
.75495 .55958 m .74041 .56715 L .7395 .57173 L .016 0 0 r
F
.75495 .55958 m .7559 .55491 L .74041 .56715 L F
.58733 .39811 m .57791 .40114 L .57937 .40362 L .405 .324 0 r
F
.58888 .40053 m .58733 .39811 L .57937 .40362 L .401 .315 0 r
F
.84616 .67498 m .82677 .68352 L .82452 .68956 L 0 0 0 r
F
.84616 .67498 m .84858 .66877 L .82677 .68352 L F
.25009 .82835 m .21809 .81619 L .22169 .82076 L .998 .081 0 r
F
.25333 .83266 m .25009 .82835 L .22169 .82076 L .976 .077 0 r
F
.09286 .63292 m .06907 .6101 L .07032 .61681 L 1 .522 0 r
F
.09415 .63943 m .09286 .63292 L .07032 .61681 L 1 .495 0 r
F
.43475 .34607 m .43221 .34682 L .43016 .34817 L .612 .226 0 r
F
.59891 .41781 m .58884 .42125 L .59008 .4238 L .378 .241 0 r
F
.59891 .41781 m .59757 .41531 L .58884 .42125 L F
.35011 .46931 m .3396 .46062 L .33883 .46321 L 1 1 0 r
F
.34944 .47193 m .35011 .46931 L .33883 .46321 L F
.37228 .57253 m .35477 .56618 L .35535 .5686 L 1 .55 0 r
F
.37279 .57489 m .37228 .57253 L .35535 .5686 L 1 .535 0 r
F
.58575 .3957 m .57643 .39867 L .57791 .40114 L .408 .333 0 r
F
.58733 .39811 m .58575 .3957 L .57791 .40114 L .405 .324 0 r
F
.50337 .60775 m .48632 .60698 L .48615 .60871 L .777 .067 0 r
F
.50337 .60775 m .50372 .606 L .48632 .60698 L F
.39619 .37118 m .39345 .36812 L .39103 .36952 L .911 1 0 r
F
.39619 .37118 m .39834 .36946 L .39345 .36812 L F
.594 .54452 m .58013 .5472 L .57979 .54962 L .39 .048 0 r
F
.594 .54452 m .59438 .54208 L .58013 .5472 L F
.89706 .56186 m .87856 .57296 L .87796 .5798 L 0 0 0 r
F
.89706 .56186 m .89768 .55487 L .87856 .57296 L F
.384 .63346 m .36439 .62707 L .3653 .62964 L 1 .337 0 r
F
.3848 .63588 m .384 .63346 L .3653 .62964 L 1 .317 0 r
F
.60021 .42033 m .59008 .4238 L .59128 .42637 L .375 .229 0 r
F
.60021 .42033 m .59891 .41781 L .59008 .4238 L F
.70851 .12987 m .70706 .13886 L .71323 .14239 L .231 .301 0 r
F
.70851 .12987 m .70188 .1275 L .70706 .13886 L F
.33737 .58557 m .32094 .57594 L .32145 .57895 L 1 .637 0 r
F
.3379 .58851 m .33737 .58557 L .32145 .57895 L 1 .62 0 r
F
.58415 .39329 m .57492 .3962 L .57643 .39867 L .412 .341 0 r
F
.58575 .3957 m .58415 .39329 L .57643 .39867 L .408 .333 0 r
F
.43853 .84451 m .43791 .84137 L .40896 .84689 L .675 .041 0 r
F
.46624 .83712 m .43791 .84137 L .43853 .84451 L .581 .031 0 r
F
.65604 .15299 m .65771 .15355 L .6584 .16514 L .83 .176 0 r
F
.5253 .64593 m .50755 .64737 L .50701 .64907 L .479 .016 0 r
F
.5253 .64593 m .52611 .64425 L .50755 .64737 L F
.65195 .51609 m .64285 .52169 L .6421 .52474 L 0 0 0 r
F
.65195 .51609 m .65273 .51304 L .64285 .52169 L F
.60149 .42286 m .59128 .42637 L .59246 .42895 L .372 .217 0 r
F
.60149 .42286 m .60021 .42033 L .59128 .42637 L F
.7064 .32008 m .7073 .32275 L .70649 .32933 L .766 .151 0 r
F
.7064 .32008 m .70651 .31404 L .7073 .32275 L F
.33352 .50533 m .31957 .49587 L .31941 .49872 L 1 .874 0 r
F
.33343 .50814 m .33352 .50533 L .31941 .49872 L 1 .862 0 r
F
.58252 .3909 m .57339 .39374 L .57492 .3962 L .415 .349 0 r
F
.58415 .39329 m .58252 .3909 L .57492 .3962 L .412 .341 0 r
F
.33461 .87019 m .30205 .86221 L .30525 .86574 L .847 .053 0 r
F
.33727 .87349 m .33461 .87019 L .30525 .86574 L .821 .049 0 r
F
.35758 .52967 m .34357 .52156 L .34363 .52412 L 1 .801 0 r
F
.35767 .5322 m .35758 .52967 L .34363 .52412 L 1 .788 0 r
F
.19633 .79798 m .1648 .78308 L .16834 .78835 L 1 .111 0 r
F
.19959 .80299 m .19633 .79798 L .16834 .78835 L 1 .094 0 r
F
.3236 .44577 m .31592 .43582 L .31453 .43863 L 1 1 0 r
F
.32233 .44867 m .3236 .44577 L .31453 .43863 L F
.39515 .58082 m .37842 .57493 L .37897 .57712 L 1 .483 0 r
F
.39563 .58295 m .39515 .58082 L .37897 .57712 L 1 .465 0 r
F
.29292 .86107 m .25996 .85129 L .26357 .85528 L .907 .064 0 r
F
.29606 .86484 m .29292 .86107 L .26357 .85528 L .882 .059 0 r
F
.40057 .36268 m .39775 .35934 L .39539 .36091 L .941 1 0 r
F
.40057 .36268 m .40277 .36097 L .39775 .35934 L F
.60273 .4254 m .59246 .42895 L .5936 .43154 L .369 .205 0 r
F
.60273 .4254 m .60149 .42286 L .59246 .42895 L F
.58088 .38851 m .57184 .39129 L .57339 .39374 L .418 .356 0 r
F
.58252 .3909 m .58088 .38851 L .57339 .39374 L .415 .349 0 r
F
.89576 .39477 m .88208 .40892 L .88403 .4157 L 0 .015 0 r
F
.89576 .39477 m .8937 .38798 L .88208 .40892 L F
.5768 .57451 m .56176 .57638 L .56123 .57861 L .472 .047 0 r
F
.5768 .57451 m .57743 .57224 L .56176 .57638 L F
.37567 .56132 m .35994 .55433 L .36036 .5567 L 1 .621 0 r
F
.37606 .56365 m .37567 .56132 L .36036 .5567 L 1 .604 0 r
F
.34944 .47193 m .33883 .46321 L .33809 .4658 L 1 1 0 r
F
.3488 .47455 m .34944 .47193 L .33809 .4658 L F
.57921 .38612 m .57027 .38883 L .57184 .39129 L .421 .362 0 r
F
.58088 .38851 m .57921 .38612 L .57184 .39129 L .418 .356 0 r
F
.08488 .64334 m .05975 .6204 L .06127 .62722 L 1 .491 0 r
F
.0864 .64995 m .08488 .64334 L .06127 .62722 L 1 .463 0 r
F
.42018 .35598 m .4172 .35399 L .41506 .35558 L .91 1 0 r
F
.42018 .35598 m .42214 .35429 L .4172 .35399 L F
.31808 .53903 m .3048 .52826 L .30474 .53138 L 1 .841 0 r
F
.31808 .54215 m .31808 .53903 L .30474 .53138 L 1 .826 0 r
F
.60393 .42795 m .5936 .43154 L .59471 .43414 L .366 .193 0 r
F
.60393 .42795 m .60273 .4254 L .5936 .43154 L F
.45069 .61188 m .43256 .60922 L .43292 .6111 L .977 .206 0 r
F
.45088 .61372 m .45069 .61188 L .43292 .6111 L .969 .186 0 r
F
.46862 .61389 m .45069 .61188 L .45088 .61372 L .914 .141 0 r
F
.60872 .50571 m .59615 .50908 L .59623 .51168 L .351 .057 0 r
F
.60872 .50571 m .60864 .5031 L .59615 .50908 L F
.65091 .71208 m .63341 .71777 L .6315 .72129 L .134 0 0 r
F
.65091 .71208 m .65321 .7087 L .63341 .71777 L F
.14006 .73842 m .1107 .71991 L .11359 .72597 L 1 .267 0 r
F
.1428 .74423 m .14006 .73842 L .11359 .72597 L 1 .237 0 r
F
.58619 .61273 m .57124 .6163 L .57017 .61842 L .282 0 0 r
F
.58619 .61273 m .58744 .61057 L .57124 .6163 L F
.52114 .6088 m .50441 .60871 L .50407 .61055 L .701 .06 0 r
F
.52114 .6088 m .52166 .60695 L .50441 .60871 L F
.32233 .44867 m .31453 .43863 L .31318 .44145 L 1 1 0 r
F
.32111 .45158 m .32233 .44867 L .31318 .44145 L F
.433 .60181 m .4154 .59789 L .41589 .59978 L 1 .279 0 r
F
.43335 .60364 m .433 .60181 L .41589 .59978 L 1 .259 0 r
F
.68475 .67816 m .66748 .6834 L .66564 .68717 L .137 0 0 r
F
.68475 .67816 m .68693 .67443 L .66748 .6834 L F
.5206 .6043 m .50406 .60423 L .50372 .606 L .699 .059 0 r
F
.5206 .6043 m .52111 .60251 L .50406 .60423 L F
.61133 .51148 m .59837 .51485 L .5984 .51749 L .354 .056 0 r
F
.61133 .51148 m .61129 .50883 L .59837 .51485 L F
.57751 .38374 m .56868 .38638 L .57027 .38883 L .424 .368 0 r
F
.57921 .38612 m .57751 .38374 L .57027 .38883 L .421 .362 0 r
F
.57535 .57044 m .56062 .57241 L .5601 .57461 L .462 .046 0 r
F
.57535 .57044 m .57597 .56822 L .56062 .57241 L F
.33931 .42182 m .33054 .41181 L .32906 .4145 L 1 1 0 r
F
.68848 .13596 m .68494 .14707 L .69025 .15133 L .248 .26 0 r
F
.68848 .13596 m .68282 .13252 L .68494 .14707 L F
.37637 .844 m .3444 .84233 L .34676 .84572 L .848 .061 0 r
F
.37816 .84729 m .37637 .844 L .34676 .84572 L .829 .057 0 r
F
.60511 .43051 m .59471 .43414 L .59579 .43674 L .363 .181 0 r
F
.60511 .43051 m .60393 .42795 L .59471 .43414 L F
.54455 .63861 m .52767 .64077 L .5269 .64253 L .403 .005 0 r
F
.54455 .63861 m .54557 .63684 L .52767 .64077 L F
.59554 .55071 m .58138 .55331 L .58099 .55575 L .394 .047 0 r
F
.59554 .55071 m .59598 .54824 L .58138 .55331 L F
.41448 .59401 m .3972 .58916 L .39777 .59118 L 1 .367 0 r
F
.41493 .59596 m .41448 .59401 L .39777 .59118 L 1 .348 0 r
F
.40665 .64544 m .38649 .64064 L .38737 .64297 L 1 .209 0 r
F
.40738 .64761 m .40665 .64544 L .38737 .64297 L 1 .188 0 r
F
.5758 .38136 m .56708 .38393 L .56868 .38638 L .426 .373 0 r
F
.57751 .38374 m .5758 .38136 L .56868 .38638 L .424 .368 0 r
F
.25937 .80492 m .22673 .79588 L .23007 .80033 L 1 .106 0 r
F
.26231 .80916 m .25937 .80492 L .23007 .80033 L 1 .086 0 r
F
.40388 .88803 m .37195 .88298 L .3741 .88588 L .718 .033 0 r
F
.40538 .89074 m .40388 .88803 L .3741 .88588 L .69 .028 0 r
F
.43526 .8919 m .40388 .88803 L .40538 .89074 L .657 .025 0 r
F
.74048 .80318 m .71819 .80776 L .71476 .81224 L .143 0 0 r
F
.74048 .80318 m .74431 .79855 L .71819 .80776 L F
.3488 .47455 m .33809 .4658 L .33739 .4684 L 1 1 0 r
F
.3482 .47717 m .3488 .47455 L .33739 .4684 L F
.60624 .43308 m .59579 .43674 L .59683 .43936 L .36 .168 0 r
F
.60624 .43308 m .60511 .43051 L .59579 .43674 L F
.46819 .65628 m .46817 .65458 L .44849 .65523 L .765 .053 0 r
F
.48734 .65471 m .46817 .65458 L .46819 .65628 L .669 .04 0 r
F
.48734 .65471 m .4876 .65307 L .46817 .65458 L F
.59048 .40629 m .58092 .40945 L .58229 .41192 L .393 .296 0 r
F
.59192 .40872 m .58229 .41192 L .58363 .41441 L .389 .285 0 r
F
.59192 .40872 m .59048 .40629 L .58229 .41192 L F
.59334 .41116 m .58363 .41441 L .58494 .41691 L .385 .273 0 r
F
.59334 .41116 m .59192 .40872 L .58363 .41441 L F
.32111 .45158 m .31318 .44145 L .31187 .4443 L 1 1 0 r
F
.31993 .45452 m .32111 .45158 L .31187 .4443 L F
.589 .40388 m .57953 .40698 L .58092 .40945 L .397 .308 0 r
F
.59048 .40629 m .589 .40388 L .58092 .40945 L .393 .296 0 r
F
.45104 .60669 m .43335 .60364 L .4337 .60544 L .988 .201 0 r
F
.45123 .60844 m .45104 .60669 L .4337 .60544 L .98 .182 0 r
F
.46868 .60894 m .45104 .60669 L .45123 .60844 L .92 .135 0 r
F
.59472 .41362 m .58494 .41691 L .58621 .41942 L .383 .261 0 r
F
.59472 .41362 m .59334 .41116 L .58494 .41691 L F
.36984 .32567 m .36285 .30981 L .36473 .31965 L .852 .121 0 r
F
.37421 .33852 m .36984 .32567 L .36473 .31965 L .976 .129 0 r
F
.57407 .37898 m .56545 .38147 L .56708 .38393 L .428 .377 0 r
F
.5758 .38136 m .57407 .37898 L .56708 .38393 L .426 .373 0 r
F
.58748 .40148 m .5781 .40453 L .57953 .40698 L .401 .319 0 r
F
.589 .40388 m .58748 .40148 L .57953 .40698 L .397 .308 0 r
F
.35155 .54866 m .33522 .54085 L .3356 .54348 L 1 .676 0 r
F
.35191 .55122 m .35155 .54866 L .3356 .54348 L 1 .662 0 r
F
.66947 .46143 m .66356 .46675 L .66272 .47035 L 0 0 0 r
F
.66947 .46143 m .6704 .45784 L .66356 .46675 L F
.55745 .59148 m .54182 .59267 L .54125 .59472 L .547 .049 0 r
F
.55745 .59148 m .55815 .58941 L .54182 .59267 L F
.39834 .36946 m .39569 .3665 L .39345 .36812 L .919 1 0 r
F
.39834 .36946 m .40046 .36772 L .39569 .3665 L F
.59607 .41608 m .58621 .41942 L .58746 .42194 L .379 .248 0 r
F
.59607 .41608 m .59472 .41362 L .58621 .41942 L F
.58594 .3991 m .57665 .40208 L .5781 .40453 L .405 .329 0 r
F
.58748 .40148 m .58594 .3991 L .5781 .40453 L .401 .319 0 r
F
.59738 .41856 m .58746 .42194 L .58867 .42448 L .376 .236 0 r
F
.59738 .41856 m .59607 .41608 L .58746 .42194 L F
.55641 .58722 m .54101 .5885 L .54046 .5905 L .541 .048 0 r
F
.55641 .58722 m .55708 .58519 L .54101 .5885 L F
.60734 .43567 m .59683 .43936 L .59785 .44198 L .357 .155 0 r
F
.60734 .43567 m .60624 .43308 L .59683 .43936 L F
.33343 .50814 m .31941 .49872 L .31929 .50156 L 1 .862 0 r
F
.33337 .51093 m .33343 .50814 L .31929 .50156 L 1 .85 0 r
F
.58437 .39673 m .57517 .39965 L .57665 .40208 L .408 .339 0 r
F
.58594 .3991 m .58437 .39673 L .57665 .40208 L .405 .329 0 r
F
.57233 .37659 m .56381 .379 L .56545 .38147 L .43 .379 0 r
F
.57407 .37898 m .57233 .37659 L .56545 .38147 L .428 .377 0 r
F
.36107 .61654 m .34266 .60857 L .34349 .61136 L 1 .463 0 r
F
.36185 .61921 m .36107 .61654 L .34349 .61136 L 1 .445 0 r
F
.59866 .42106 m .58867 .42448 L .58985 .42702 L .373 .223 0 r
F
.59866 .42106 m .59738 .41856 L .58867 .42448 L F
.35767 .5322 m .34363 .52412 L .34373 .52667 L 1 .788 0 r
F
.35779 .53472 m .35767 .5322 L .34373 .52667 L 1 .774 0 r
F
.59358 .54694 m .57979 .54962 L .57942 .55202 L .385 .046 0 r
F
.59358 .54694 m .594 .54452 L .57979 .54962 L F
.89145 .39564 m .87831 .40958 L .88004 .41633 L 0 .005 0 r
F
.89145 .39564 m .8897 .38886 L .87831 .40958 L F
.71818 .12797 m .71506 .13984 L .72118 .14355 L .242 .278 0 r
F
.71818 .12797 m .71203 .12466 L .71506 .13984 L F
.58276 .39437 m .57367 .39723 L .57517 .39965 L .412 .349 0 r
F
.58437 .39673 m .58276 .39437 L .57517 .39965 L .408 .339 0 r
F
.43606 .89444 m .43526 .8919 L .40538 .89074 L .629 .02 0 r
F
.46561 .89463 m .43526 .8919 L .43606 .89444 L .582 .014 0 r
F
.41349 .6019 m .39537 .59776 L .39599 .59983 L 1 .343 0 r
F
.41397 .60391 m .41349 .6019 L .39599 .59983 L 1 .324 0 r
F
.6898 .39826 m .68616 .40309 L .68466 .40801 L 0 0 0 r
F
.6898 .39826 m .69133 .3933 L .68616 .40309 L F
.85228 .68581 m .83146 .69367 L .82914 .69983 L .025 0 0 r
F
.85228 .68581 m .85478 .67945 L .83146 .69367 L F
.46863 .61567 m .46862 .61389 L .45088 .61372 L .905 .121 0 r
F
.48614 .61521 m .46862 .61389 L .46863 .61567 L .841 .074 0 r
F
.48614 .61521 m .48631 .61344 L .46862 .61389 L F
.42314 .35002 m .42084 .34916 L .41854 .35043 L .631 .574 0 r
F
.42314 .35002 m .42524 .3486 L .42084 .34916 L F
.31993 .45452 m .31187 .4443 L .31062 .44717 L 1 1 0 r
F
.3188 .45747 m .31993 .45452 L .31062 .44717 L F
.3482 .47717 m .33739 .4684 L .33673 .471 L F
.34764 .47979 m .3482 .47717 L .33673 .471 L F
.73932 .34652 m .73737 .34186 L .74988 .34687 L 1 .172 0 r
F
.5999 .42356 m .58985 .42702 L .591 .42957 L .37 .21 0 r
F
.5999 .42356 m .59866 .42106 L .58985 .42702 L F
.60876 .50832 m .59623 .51168 L .59627 .51428 L .347 .055 0 r
F
.60876 .50832 m .60872 .50571 L .59623 .51168 L F
.57057 .37419 m .56217 .37652 L .56381 .379 L .431 .38 0 r
F
.57233 .37659 m .57057 .37419 L .56381 .379 L .43 .379 0 r
F
.40277 .36097 m .40012 .3578 L .39775 .35934 L .918 1 0 r
F
.40277 .36097 m .40499 .35931 L .40012 .3578 L F
.58113 .39202 m .57214 .39481 L .57367 .39723 L .415 .358 0 r
F
.58276 .39437 m .58113 .39202 L .57367 .39723 L .412 .349 0 r
F
.6084 .43826 m .59785 .44198 L .59882 .44462 L .353 .142 0 r
F
.6084 .43826 m .60734 .43567 L .59785 .44198 L F
.56445 .62842 m .54854 .63128 L .54757 .63318 L .343 0 0 r
F
.56445 .62842 m .56564 .6265 L .54854 .63128 L F
.5388 .60262 m .52265 .60316 L .52216 .60508 L .622 .053 0 r
F
.5388 .60262 m .53945 .60069 L .52265 .60316 L F
.53805 .59822 m .52209 .59882 L .52161 .60068 L .618 .052 0 r
F
.53805 .59822 m .53868 .59634 L .52209 .59882 L F
.63055 .56198 m .61881 .5671 L .61784 .56978 L .097 0 0 r
F
.63055 .56198 m .63158 .55927 L .61881 .5671 L F
.60111 .42608 m .591 .42957 L .59211 .43214 L .366 .196 0 r
F
.60111 .42608 m .5999 .42356 L .591 .42957 L F
.37279 .57489 m .35535 .5686 L .35596 .571 L 1 .535 0 r
F
.37332 .57722 m .37279 .57489 L .35596 .571 L 1 .519 0 r
F
.46869 .61065 m .46868 .60894 L .45123 .60844 L .911 .116 0 r
F
.48597 .61041 m .46868 .60894 L .46869 .61065 L .844 .073 0 r
F
.48597 .61041 m .48615 .60871 L .46868 .60894 L F
.57947 .38969 m .57058 .39241 L .57214 .39481 L .417 .366 0 r
F
.58113 .39202 m .57947 .38969 L .57214 .39481 L .415 .358 0 r
F
.61133 .51413 m .5984 .51749 L .5984 .52012 L .35 .054 0 r
F
.61133 .51413 m .61133 .51148 L .5984 .51749 L F
.39365 .5914 m .37573 .58632 L .37639 .58853 L 1 .429 0 r
F
.3942 .59355 m .39365 .5914 L .37639 .58853 L 1 .411 0 r
F
.5688 .37178 m .56051 .37402 L .56217 .37652 L .431 .38 0 r
F
.57057 .37419 m .5688 .37178 L .56217 .37652 L F
.60793 .59255 m .59438 .5969 L .59329 .59926 L .201 0 0 r
F
.60793 .59255 m .60914 .59014 L .59438 .5969 L F
.6972 .84485 m .67337 .84765 L .66994 .85162 L .234 0 0 r
F
.6972 .84485 m .70114 .84074 L .67337 .84765 L F
.77009 .46382 m .76235 .47264 L .76243 .47762 L 0 0 0 r
F
.77009 .46382 m .76975 .45888 L .76235 .47264 L F
.31808 .54215 m .30474 .53138 L .30471 .53451 L 1 .826 0 r
F
.31813 .54526 m .31808 .54215 L .30471 .53451 L 1 .811 0 r
F
.60227 .42861 m .59211 .43214 L .59319 .43471 L .363 .183 0 r
F
.60227 .42861 m .60111 .42608 L .59211 .43214 L F
.3379 .58851 m .32145 .57895 L .322 .58195 L 1 .62 0 r
F
.33847 .59143 m .3379 .58851 L .322 .58195 L 1 .603 0 r
F
.60943 .44087 m .59882 .44462 L .59977 .44726 L .35 .129 0 r
F
.60943 .44087 m .6084 .43826 L .59882 .44462 L F
.57779 .38737 m .569 .39001 L .57058 .39241 L .419 .374 0 r
F
.57947 .38969 m .57779 .38737 L .57058 .39241 L .417 .366 0 r
F
.68506 .26128 m .69725 .25293 L .69896 .25909 L 1 .201 0 r
F
.69203 .26536 m .69896 .25909 L .70053 .26523 L 1 .177 0 r
F
.70085 .28162 m .70316 .27746 L .7042 .28357 L .99 .113 0 r
F
.67485 .29777 m .69928 .27867 L .7003 .28197 L 1 .832 0 r
F
.69928 .27867 m .69945 .27854 L .69965 .27937 L F
.69928 .27867 m .69965 .27937 L .7003 .28197 L F
.7003 .28197 m .70082 .28146 L .70085 .28162 L F
.70012 .27802 m .70316 .27746 L .70085 .28162 L .99 .113 0 r
F
.69881 .27597 m .70193 .27135 L .70316 .27746 L 1 .111 0 r
F
.69945 .27854 m .70012 .27802 L .7003 .28197 L 1 .832 0 r
F
.70012 .27802 m .69881 .27597 L .70316 .27746 L .99 .113 0 r
F
.70012 .27802 m .72224 .26073 L .70175 .28056 L 1 .832 0 r
F
.70012 .27802 m .70175 .28056 L .7003 .28197 L F
.69788 .27641 m .69855 .27576 L .69865 .27592 L 1 .976 0 r
F
.69855 .27576 m .6986 .27572 L .69865 .27592 L F
.67607 .29046 m .69699 .27344 L .69788 .27641 L F
.69876 .27577 m .70193 .27135 L .69881 .27597 L 1 .111 0 r
F
.69785 .27273 m .70193 .27135 L .69865 .27592 L F
.6961 .27048 m .70053 .26523 L .70193 .27135 L 1 .145 0 r
F
.69699 .27344 m .69785 .27273 L .69788 .27641 L 1 .976 0 r
F
.69785 .27273 m .6961 .27048 L .70193 .27135 L 1 .111 0 r
F
.69785 .27273 m .72245 .25271 L .6995 .27485 L 1 .976 0 r
F
.69785 .27273 m .6995 .27485 L .69788 .27641 L F
.69413 .27117 m .69519 .27017 L .69535 .27037 L 1 1 0 r
F
.69519 .27017 m .69527 .2701 L .69535 .27037 L F
.67964 .28061 m .69337 .26906 L .69413 .27117 L F
.69463 .268 m .70053 .26523 L .69535 .27037 L 1 .145 0 r
F
.69337 .26906 m .69463 .268 L .69413 .27117 L 1 1 0 r
F
.69463 .268 m .69203 .26536 L .70053 .26523 L 1 .145 0 r
F
.69463 .268 m .72256 .24451 L .69601 .26941 L 1 1 0 r
F
.69463 .268 m .69601 .26941 L .69413 .27117 L F
.68589 .26765 m .689 .26497 L .68944 .2654 L F
.689 .26497 m .68921 .26479 L .68944 .2654 L F
.68506 .26128 m .6818 .2573 L .69725 .25293 L 1 .201 0 r
F
.68921 .26479 m .68506 .26128 L .69896 .25909 L 1 .177 0 r
F
.68921 .26479 m .6942 .2519 L .72241 .23626 L 1 1 0 r
F
.68589 .26765 m .6875 .26458 L .689 .26497 L F
.67834 .25347 m .69343 .24048 L .6954 .24674 L 1 .241 0 r
F
.6818 .2573 m .67834 .25347 L .6954 .24674 L 1 .222 0 r
F
.59541 .34866 m .68432 .26158 L .68589 .26765 L 1 1 0 r
F
.68405 .26135 m .6818 .2573 L .68506 .26128 L .442 0 0 r
F
.68726 .26433 m .68506 .26128 L .6875 .26458 L .456 0 0 r
F
.68432 .26158 m .68594 .26296 L .68589 .26765 L 1 1 0 r
F
.68594 .26296 m .68761 .26438 L .6875 .26458 L F
.68594 .26296 m .6875 .26458 L .68589 .26765 L F
.68432 .26158 m .68447 .26143 L .68594 .26296 L F
.68385 .26137 m .68369 .26105 L .68405 .26135 L .442 0 0 r
F
.68369 .26105 m .6818 .2573 L .68405 .26135 L F
.59541 .34866 m .60677 .33192 L .68385 .26137 L 1 1 0 r
F
.68447 .26143 m .68385 .26137 L .68506 .26128 L .456 0 0 r
F
.68447 .26143 m .68385 .26137 L .6942 .2519 L 1 1 0 r
F
.59541 .34866 m .68385 .26137 L .68447 .26143 L F
.60677 .33192 m .67779 .26025 L .68385 .26137 L F
.67779 .26025 m .6799 .25812 L .68385 .26137 L F
.68436 .26146 m .68385 .26137 L .68447 .26143 L .456 0 0 r
F
.67512 .26384 m .68385 .26137 L .68436 .26146 L F
.67472 .24979 m .69137 .23413 L .69343 .24048 L 1 .261 0 r
F
.67472 .24979 m .67096 .24623 L .69137 .23413 L F
.67834 .25347 m .67472 .24979 L .69343 .24048 L 1 .241 0 r
F
.6587 .26124 m .67472 .24979 L .67834 .25347 L .405 0 0 r
F
.66461 .26148 m .67834 .25347 L .6818 .2573 L .424 0 0 r
F
.66461 .26148 m .6587 .26124 L .67834 .25347 L F
.6799 .25812 m .66461 .26148 L .6786 .25808 L .442 0 0 r
F
.6799 .25812 m .6786 .25808 L .6818 .2573 L F
.6799 .25812 m .6818 .2573 L .68385 .26137 L F
.68385 .26137 m .68103 .25815 L .68407 .26117 L 1 1 0 r
F
.68103 .25815 m .68048 .25753 L .68109 .25816 L F
.68103 .25815 m .68109 .25816 L .68407 .26117 L F
.6799 .25812 m .69354 .22867 L .70269 .23512 L F
.60677 .33192 m .6658 .26167 L .6799 .25812 L F
.6658 .26167 m .66461 .26148 L .6799 .25812 L .442 0 0 r
F
.6658 .26167 m .69354 .22867 L .6799 .25812 L 1 1 0 r
F
.67007 .26237 m .6658 .26167 L .6799 .25812 L .442 0 0 r
F
.67512 .26384 m .67007 .26237 L .68385 .26137 L .456 0 0 r
F
.68436 .26146 m .68447 .26143 L .68743 .26456 L F
.68447 .26143 m .68506 .26128 L .68726 .26433 L F
.68447 .26143 m .68726 .26433 L .68743 .26456 L F
.68743 .26456 m .68726 .26433 L .6875 .26458 L F
.6875 .26458 m .68506 .26128 L .68921 .26479 L 1 .177 0 r
F
.68594 .26296 m .6942 .2519 L .68761 .26438 L 1 1 0 r
F
.68447 .26143 m .6942 .2519 L .68594 .26296 L F
.67007 .26237 m .6799 .25812 L .68385 .26137 L .442 0 0 r
F
.6799 .25812 m .68048 .25753 L .68385 .26137 L 1 1 0 r
F
.68407 .26117 m .70269 .23512 L .6942 .2519 L F
.68048 .25753 m .70269 .23512 L .68407 .26117 L F
.67992 .2626 m .68436 .26146 L .68743 .26456 L .456 0 0 r
F
.67512 .26384 m .67992 .2626 L .68812 .26542 L F
.67992 .2626 m .6875 .26458 L .68812 .26542 L F
.689 .26497 m .6875 .26458 L .68921 .26479 L 1 1 0 r
F
.6875 .26458 m .6942 .2519 L .68921 .26479 L F
.68812 .26542 m .6875 .26458 L .68921 .26479 L 1 .177 0 r
F
.67964 .28061 m .68589 .26765 L .68944 .2654 L 1 1 0 r
F
.69174 .26656 m .68944 .2654 L .69203 .26536 L 1 .145 0 r
F
.67964 .28061 m .68944 .2654 L .69463 .268 L 1 1 0 r
F
.69097 .26973 m .69203 .26536 L .69463 .268 L 1 .145 0 r
F
.68944 .2654 m .69154 .26401 L .69203 .26536 L 1 .177 0 r
F
.69154 .26401 m .69896 .25909 L .69203 .26536 L F
.69463 .268 m .68944 .2654 L .72256 .24451 L 1 1 0 r
F
.69153 .26741 m .68944 .2654 L .69174 .26656 L 1 .145 0 r
F
.69097 .26973 m .68812 .26542 L .68944 .2654 L F
.69097 .26973 m .68944 .2654 L .69153 .26741 L F
.67607 .29046 m .67964 .28061 L .69535 .27037 L 1 .976 0 r
F
.69585 .27085 m .69535 .27037 L .6961 .27048 L 1 .111 0 r
F
.67607 .29046 m .69535 .27037 L .69785 .27273 L 1 .976 0 r
F
.69359 .27418 m .6961 .27048 L .69785 .27273 L 1 .111 0 r
F
.69535 .27037 m .6959 .26982 L .6961 .27048 L 1 .145 0 r
F
.6959 .26982 m .70053 .26523 L .6961 .27048 L F
.69785 .27273 m .69535 .27037 L .72245 .25271 L 1 .976 0 r
F
.69579 .27093 m .69535 .27037 L .69585 .27085 L 1 .111 0 r
F
.69359 .27418 m .69097 .26973 L .69535 .27037 L F
.69359 .27418 m .69535 .27037 L .69579 .27093 L F
.67485 .29777 m .67607 .29046 L .69865 .27592 L 1 .832 0 r
F
.69874 .27604 m .69865 .27592 L .69881 .27597 L .99 .113 0 r
F
.67485 .29777 m .69865 .27592 L .70012 .27802 L 1 .832 0 r
F
.69597 .27878 m .69881 .27597 L .70012 .27802 L .99 .113 0 r
F
.69865 .27592 m .69876 .27577 L .69881 .27597 L 1 .111 0 r
F
.70012 .27802 m .69865 .27592 L .72224 .26073 L 1 .832 0 r
F
.69873 .27604 m .69865 .27592 L .69874 .27604 L .99 .113 0 r
F
.69597 .27878 m .69359 .27418 L .69865 .27592 L F
.69597 .27878 m .69865 .27592 L .69873 .27604 L F
.70188 .28355 m .70085 .28162 L .7042 .28357 L .911 .114 0 r
F
.67535 .30332 m .67485 .29777 L .70014 .28206 L 1 .694 0 r
F
.67535 .30332 m .70014 .28206 L .70019 .28218 L F
.67535 .30332 m .70085 .28162 L .70183 .28355 L F
.70176 .28776 m .70103 .28415 L .70244 .28735 L F
.67535 .30332 m .70057 .28449 L .70176 .28776 L F
.70057 .28449 m .70103 .28415 L .70176 .28776 L F
.70298 .29339 m .70241 .28972 L .70361 .29304 L 1 .577 0 r
F
.67704 .30771 m .70199 .29002 L .70298 .29339 L F
.70199 .29002 m .70241 .28972 L .70298 .29339 L F
.70392 .29892 m .7035 .29532 L .70448 .29864 L 1 .484 0 r
F
.67952 .31139 m .70313 .29556 L .70392 .29892 L F
.70313 .29556 m .7035 .29532 L .70392 .29892 L F
.70463 .30431 m .70435 .30088 L .7051 .30409 L 1 .411 0 r
F
.68252 .31464 m .70404 .30107 L .70463 .30431 L F
.70404 .30107 m .70435 .30088 L .70463 .30431 L F
.70516 .30951 m .70499 .30636 L .70554 .30935 L 1 .351 0 r
F
.68583 .31764 m .70476 .30651 L .70516 .30951 L F
.70476 .30651 m .70499 .30636 L .70516 .30951 L F
.70499 .30636 m .70552 .30605 L .70554 .30935 L F
.70554 .30935 m .70644 .30797 L .70651 .31404 L .753 .115 0 r
F
.70554 .30883 m .70644 .30797 L .70554 .30935 L F
.70545 .30869 m .70644 .30797 L .70545 .30892 L F
.7051 .30409 m .70618 .30188 L .70644 .30797 L .793 .115 0 r
F
.70435 .30088 m .70496 .30049 L .7051 .30409 L 1 .411 0 r
F
.70496 .30049 m .70514 .30071 L .7051 .30409 L .793 .115 0 r
F
.70514 .30071 m .70618 .30188 L .7051 .30409 L F
.7035 .29532 m .70419 .29486 L .70448 .29864 L 1 .484 0 r
F
.70448 .29864 m .70571 .29578 L .70618 .30188 L .828 .115 0 r
F
.70444 .29817 m .70571 .29578 L .70448 .29864 L F
.70427 .29747 m .70571 .29578 L .70434 .29837 L F
.70361 .29304 m .70505 .28968 L .70571 .29578 L .857 .115 0 r
F
.70241 .28972 m .70316 .28919 L .70361 .29304 L 1 .577 0 r
F
.70316 .28919 m .70341 .28925 L .70361 .29304 L .857 .115 0 r
F
.70341 .28925 m .70505 .28968 L .70361 .29304 L F
.70103 .28415 m .70183 .28355 L .70244 .28735 L 1 .694 0 r
F
.70244 .28735 m .7042 .28357 L .70505 .28968 L .911 .114 0 r
F
.70239 .28707 m .7042 .28357 L .70244 .28735 L F
.70174 .28355 m .7042 .28357 L .70231 .28724 L F
.70183 .28355 m .70085 .28162 L .70188 .28355 L F
.70183 .28355 m .72205 .26846 L .70244 .28735 L 1 .694 0 r
F
.70231 .28724 m .70239 .28707 L .70244 .28735 L .911 .114 0 r
F
.69812 .28352 m .70174 .28355 L .70231 .28724 L F
.70326 .28921 m .70244 .28735 L .70505 .28968 L .857 .115 0 r
F
.70318 .28919 m .70244 .28735 L .70326 .28921 L F
.70316 .28919 m .72201 .27582 L .70361 .29304 L 1 .577 0 r
F
.67704 .30771 m .67535 .30332 L .70176 .28776 L F
.67704 .30771 m .70176 .28776 L .70182 .28796 L F
.67704 .30771 m .70247 .28744 L .70316 .28919 L F
.70318 .28919 m .70299 .28876 L .70244 .28735 L .857 .115 0 r
F
.70247 .28744 m .703 .28703 L .70316 .28919 L 1 .577 0 r
F
.70299 .28876 m .70237 .28729 L .70244 .28735 L .857 .115 0 r
F
.67952 .31139 m .70304 .29358 L .7035 .29532 L 1 .484 0 r
F
.67952 .31139 m .67704 .30771 L .70361 .29304 L F
.70364 .29313 m .70361 .29304 L .70412 .29276 L F
.67952 .31139 m .70361 .29304 L .70364 .29313 L F
.70367 .29321 m .70361 .29304 L .70367 .29321 L .828 .115 0 r
F
.70171 .29335 m .70361 .29304 L .70367 .29321 L F
.70315 .29842 m .70171 .29335 L .70196 .29382 L .793 .115 0 r
F
.70315 .29842 m .70196 .29382 L .7043 .29829 L F
.68252 .31464 m .67952 .31139 L .70392 .29892 L 1 .411 0 r
F
.68252 .31464 m .70392 .29892 L .70435 .30088 L F
.68583 .31764 m .70466 .30451 L .70499 .30636 L 1 .351 0 r
F
.70517 .30439 m .7051 .30409 L .70522 .30443 L .753 .115 0 r
F
.68583 .31764 m .68252 .31464 L .7051 .30409 L 1 .351 0 r
F
.70512 .30419 m .7051 .30409 L .70558 .30386 L F
.68583 .31764 m .7051 .30409 L .70512 .30419 L F
.70516 .30438 m .7051 .30409 L .70517 .30439 L .753 .115 0 r
F
.70434 .30358 m .7051 .30409 L .70516 .30438 L F
.70529 .30882 m .70434 .30358 L .70446 .30419 L .713 .115 0 r
F
.70529 .30882 m .70446 .30419 L .70544 .30889 L F
.70602 .31194 m .70563 .30979 L .70651 .31404 L F
.70548 .31172 m .70591 .31149 L .70584 .31439 L 1 .302 0 r
F
.70591 .31149 m .70563 .30979 L .70602 .31194 L .713 .115 0 r
F
.69299 .32337 m .68935 .32053 L .70584 .31439 L 1 .261 0 r
F
.70589 .31491 m .70651 .31404 L .7064 .32008 L .713 .115 0 r
F
.70584 .31439 m .70592 .31434 L .70589 .31491 L F
.70592 .31434 m .70651 .31404 L .70589 .31491 L F
.69667 .32622 m .69299 .32337 L .70563 .31929 L 1 .226 0 r
F
.70622 .31735 m .70589 .31492 L .7064 .32008 L 0 0 0 r
F
.7061 .32608 m .7064 .32008 L .70642 .32247 L .741 .151 0 r
F
.7061 .32608 m .70642 .32247 L .70649 .32933 L F
.70582 .32921 m .7061 .32608 L .70563 .33204 L 0 0 0 r
F
.70035 .32911 m .69667 .32622 L .70574 .32376 L 1 .194 0 r
F
.70605 .31961 m .7064 .32008 L .7061 .32608 L 0 0 0 r
F
.70402 .33207 m .70035 .32911 L .70584 .32792 L 1 .166 0 r
F
.70604 .31916 m .70607 .31924 L .70605 .31961 L 0 0 0 r
F
.7062 .31702 m .7064 .32008 L .70604 .31916 L F
.70604 .31916 m .7254 .30709 L .72676 .31247 L 1 .261 0 r
F
.70611 .31798 m .7062 .31702 L .70604 .31916 L 0 0 0 r
F
.70618 .31675 m .7062 .31702 L .70604 .31874 L F
.70618 .31675 m .7254 .30709 L .70604 .31916 L 1 .261 0 r
F
.70583 .31692 m .70618 .31675 L .70604 .31916 L F
.70604 .31874 m .70611 .31798 L .70604 .31916 L 0 0 0 r
F
.7059 .31485 m .70584 .31439 L .70589 .31492 L F
.70602 .31562 m .70584 .31439 L .70635 .31419 L 1 .261 0 r
F
.7059 .31483 m .70584 .31439 L .7059 .31485 L 0 0 0 r
F
.70569 .31699 m .70584 .31439 L .70602 .31562 L 1 .261 0 r
F
.706 .31413 m .70584 .31439 L .7059 .31483 L 0 0 0 r
F
.70618 .31675 m .70589 .31492 L .70622 .31735 L F
.70569 .31699 m .70602 .31562 L .70618 .31675 L 1 .261 0 r
F
.70602 .31562 m .70635 .31419 L .70618 .31675 L F
.70586 .31394 m .70651 .31404 L .70584 .31439 L .713 .115 0 r
F
.70591 .31149 m .70651 .31404 L .70579 .31393 L F
.70584 .31439 m .72424 .30148 L .7254 .30709 L 1 .302 0 r
F
.706 .31413 m .7059 .31483 L .70618 .31675 L 0 0 0 r
F
.7059 .31483 m .70589 .31492 L .70618 .31675 L F
.706 .31413 m .70618 .31675 L .70604 .31874 L F
.70618 .31675 m .70635 .31419 L .7254 .30709 L 1 .261 0 r
F
.70634 .32203 m .70605 .31961 L .7061 .32608 L 0 0 0 r
F
.70635 .3218 m .70605 .31961 L .70634 .32203 L F
.70609 .3196 m .70605 .31961 L .70635 .3218 L F
.70686 .32645 m .70665 .3247 L .72829 .31766 L 1 .194 0 r
F
.70665 .3247 m .70652 .32355 L .70677 .32349 L F
.70665 .3247 m .70677 .32349 L .72829 .31766 L F
.70635 .3218 m .7061 .32608 L .70622 .32342 L 0 0 0 r
F
.69667 .32622 m .70635 .3218 L .7062 .32364 L 1 .226 0 r
F
.70635 .3218 m .70622 .32342 L .70622 .3233 L 0 0 0 r
F
.7062 .32364 m .72676 .31247 L .72829 .31766 L 1 .226 0 r
F
.70635 .3218 m .72676 .31247 L .7062 .32364 L F
.7063 .32475 m .7062 .32364 L .70652 .32355 L 1 .194 0 r
F
.70618 .32398 m .7061 .32608 L .70582 .32921 L 0 0 0 r
F
.7062 .32364 m .7062 .32377 L .70618 .32398 L F
.7062 .32377 m .7061 .32608 L .70618 .32398 L F
.70622 .32344 m .7061 .32608 L .7062 .32364 L F
.7061 .32608 m .70649 .32933 L .70551 .3358 L .741 .151 0 r
F
.70563 .33204 m .7061 .32608 L .70598 .32813 L .717 .151 0 r
F
.70563 .33204 m .70598 .32813 L .70551 .3358 L F
.70526 .33504 m .70551 .3358 L .70441 .34216 L F
.70563 .33204 m .7056 .3328 L .70526 .33504 L F
.7056 .3328 m .70551 .3358 L .70526 .33504 L F
.70499 .33794 m .70563 .33204 L .70441 .34216 L 0 0 0 r
F
.70499 .33794 m .70441 .34216 L .70318 .34841 L F
.7042 .34377 m .70499 .33794 L .70366 .34568 L F
.70337 .34756 m .70366 .34568 L .70318 .34841 L F
.7042 .34377 m .70366 .34568 L .70337 .34756 L F
.70532 .3355 m .70563 .33204 L .70499 .33794 L F
.70651 .33167 m .70499 .33794 L .7042 .34377 L F
.70647 .32956 m .70635 .32781 L .70694 .32768 L 1 .166 0 r
F
.70657 .33115 m .70635 .32781 L .70632 .32803 L 0 0 0 r
F
.70656 .33123 m .70632 .32803 L .70499 .33794 L F
.70657 .33115 m .70632 .32803 L .70656 .33123 L F
.70658 .33576 m .70661 .33482 L .7042 .34377 L F
.70661 .33482 m .70657 .33452 L .7042 .34377 L F
.70663 .33427 m .70651 .33167 L .7042 .34377 L F
.70656 .33123 m .70499 .33794 L .70651 .33167 L F
.70632 .32803 m .70563 .33204 L .70532 .3355 L F
.70671 .33336 m .70659 .33166 L .7317 .32761 L 1 .14 0 r
F
.70657 .33115 m .70694 .32768 L .72994 .3227 L 1 .166 0 r
F
.70764 .33511 m .70663 .33427 L .7317 .32761 L 1 .14 0 r
F
.70663 .33427 m .70627 .33397 L .70658 .33389 L F
.70663 .33427 m .70658 .33389 L .7317 .32761 L F
.70627 .33397 m .70633 .33345 L .7317 .32761 L F
.70635 .3218 m .70659 .31898 L .72676 .31247 L 1 .226 0 r
F
.70647 .32661 m .7062 .32364 L .70563 .33204 L 0 0 0 r
F
.70635 .32781 m .72829 .31766 L .72994 .3227 L 1 .194 0 r
F
.70636 .32769 m .70636 .3277 L .70635 .32781 L 0 0 0 r
F
.70647 .32661 m .70563 .33204 L .70638 .32758 L F
.70035 .32911 m .70647 .32661 L .70635 .32781 L 1 .194 0 r
F
.70647 .32661 m .72829 .31766 L .70635 .32781 L F
.70638 .32758 m .70636 .32769 L .70635 .32781 L 0 0 0 r
F
.70651 .33167 m .72994 .3227 L .7317 .32761 L 1 .166 0 r
F
.70654 .33142 m .70656 .33123 L .70651 .33167 L 0 0 0 r
F
.70657 .33115 m .70656 .33123 L .70653 .33157 L F
.70633 .32793 m .70563 .33204 L .70632 .32803 L F
.70636 .3277 m .70563 .33204 L .70635 .32781 L F
.70402 .33207 m .70657 .33115 L .70651 .33167 L 1 .166 0 r
F
.70657 .33115 m .72994 .3227 L .70651 .33167 L F
.70653 .33157 m .70654 .33142 L .70651 .33167 L 0 0 0 r
F
.7124 .31716 m .70677 .33032 L .70663 .33427 L F
.68193 .33783 m .70402 .33207 L .70663 .33427 L .59 .011 0 r
F
.70714 .33857 m .70702 .33799 L .70619 .3412 L 0 0 0 r
F
.70702 .33799 m .70652 .33663 L .70619 .3412 L F
.70678 .3352 m .70669 .33431 L .70764 .33511 L .59 .011 0 r
F
.70726 .34252 m .70619 .3412 L .7056 .34664 L 0 0 0 r
F
.70745 .34205 m .70695 .34171 L .70726 .34252 L F
.70695 .34171 m .70619 .3412 L .70726 .34252 L F
.7042 .34377 m .70318 .34841 L .70186 .35452 L F
.70327 .34954 m .7042 .34377 L .70186 .35452 L F
.70658 .33576 m .7042 .34377 L .70327 .34954 L F
.70619 .3412 m .70327 .34954 L .70222 .35522 L F
.70619 .3412 m .70658 .33576 L .70327 .34954 L F
.7056 .34664 m .70222 .35522 L .70105 .36081 L F
.7056 .34664 m .70619 .3412 L .70222 .35522 L F
.70482 .35205 m .7056 .34664 L .70105 .36081 L F
.70802 .34485 m .7056 .34664 L .70482 .35205 L F
.70908 .34661 m .70482 .35205 L .70387 .35743 L F
.70905 .3465 m .70482 .35205 L .70908 .34661 L F
.70895 .34515 m .70482 .35205 L .70907 .34647 L F
.70895 .34515 m .70929 .34513 L .70908 .34661 L .631 .018 0 r
F
.70929 .34513 m .71806 .34476 L .70939 .34655 L F
.70929 .34513 m .70939 .34655 L .70908 .34661 L F
.70961 .34956 m .70387 .35743 L .70276 .36277 L 0 0 0 r
F
.70908 .34661 m .71806 .34476 L .72137 .34817 L .631 .018 0 r
F
.70895 .34515 m .7086 .34413 L .71806 .34476 L F
.71119 .33823 m .73354 .33243 L .73544 .33717 L 1 .116 0 r
F
.71467 .34145 m .71119 .33823 L .73544 .33717 L 1 .094 0 r
F
.7079 .34139 m .71119 .33823 L .71467 .34145 L .61 .013 0 r
F
.70726 .34155 m .70619 .3412 L .70745 .34205 L 0 0 0 r
F
.70735 .33897 m .70619 .3412 L .7076 .34166 L F
.69598 .34328 m .69146 .34124 L .70771 .34139 L .621 .015 0 r
F
.70834 .34411 m .71467 .34145 L .71806 .34476 L F
.70821 .34276 m .70798 .34237 L .70834 .34411 L 0 0 0 r
F
.70798 .34237 m .70782 .34266 L .70807 .34333 L F
.70798 .34237 m .70807 .34333 L .70834 .34411 L F
.70782 .34266 m .7056 .34664 L .70834 .34411 L F
.70771 .34139 m .70767 .33877 L .7079 .34139 L .61 .013 0 r
F
.70767 .33877 m .71119 .33823 L .7079 .34139 L F
.70729 .33842 m .70764 .33511 L .71119 .33823 L .6 .012 0 r
F
.70718 .33843 m .70725 .33795 L .70729 .33842 L F
.70725 .33795 m .70764 .33511 L .70729 .33842 L F
.70764 .33511 m .7317 .32761 L .73354 .33243 L 1 .14 0 r
F
.71119 .33823 m .70764 .33511 L .73354 .33243 L 1 .116 0 r
F
.71334 .32739 m .71299 .32224 L .70718 .33843 L 0 0 0 r
F
.70743 .33881 m .70718 .33843 L .70619 .3412 L F
.70731 .33863 m .70718 .33843 L .70729 .33842 L .61 .013 0 r
F
.70743 .33881 m .70729 .33842 L .71119 .33823 L F
.70733 .33882 m .70729 .33842 L .70743 .33881 L F
.71334 .32739 m .70718 .33843 L .70743 .33881 L 0 0 0 r
F
.70733 .33882 m .70718 .33843 L .70731 .33863 L .61 .013 0 r
F
.70743 .33881 m .70767 .33877 L .70771 .34139 L F
.70805 .34056 m .70743 .33881 L .70771 .34139 L 0 0 0 r
F
.71334 .32739 m .70743 .33881 L .70805 .34056 L F
.71344 .3326 m .71334 .32739 L .70771 .34139 L F
.70814 .34209 m .70771 .34139 L .7056 .34664 L F
.70794 .34175 m .70771 .34139 L .7079 .34139 L .621 .015 0 r
F
.70814 .34209 m .7079 .34139 L .71467 .34145 L F
.70797 .34211 m .7079 .34139 L .70814 .34209 L F
.71344 .3326 m .70771 .34139 L .70814 .34209 L 0 0 0 r
F
.70797 .34211 m .70771 .34139 L .70794 .34175 L .621 .015 0 r
F
.69598 .34328 m .70814 .34209 L .70834 .34411 L F
.70814 .34209 m .71467 .34145 L .70834 .34411 L F
.70862 .34347 m .70821 .34276 L .70834 .34411 L 0 0 0 r
F
.71344 .3326 m .70814 .34209 L .70862 .34347 L F
.70814 .34209 m .70798 .34237 L .70862 .34347 L F
.7076 .34166 m .70726 .34155 L .70745 .34205 L F
.69598 .34328 m .70771 .34139 L .70797 .34211 L .621 .015 0 r
F
.70771 .34139 m .70735 .33897 L .70753 .34089 L 0 0 0 r
F
.70771 .34139 m .70753 .34089 L .7076 .34166 L F
.70743 .33881 m .70735 .33897 L .70771 .34139 L F
.69146 .34124 m .70743 .33881 L .70771 .34139 L .61 .013 0 r
F
.71293 .34315 m .7133 .33786 L .70908 .34661 L 0 0 0 r
F
.70985 .348 m .70908 .34661 L .70387 .35743 L F
.70949 .34734 m .70908 .34661 L .7094 .34665 L .641 .021 0 r
F
.70985 .348 m .7094 .34665 L .72137 .34817 L F
.70957 .348 m .7094 .34665 L .70985 .348 L F
.71293 .34315 m .70908 .34661 L .70985 .348 L 0 0 0 r
F
.70957 .348 m .70908 .34661 L .70949 .34734 L .641 .021 0 r
F
.70993 .34894 m .70953 .34851 L .70961 .34956 L 0 0 0 r
F
.71048 .35182 m .70276 .36277 L .70149 .36806 L F
.71029 .349 m .72137 .34817 L .72457 .35166 L .641 .021 0 r
F
.71028 .34891 m .72137 .34817 L .71029 .349 L F
.70985 .348 m .72137 .34817 L .70994 .34894 L F
.70993 .34888 m .70994 .34894 L .70993 .34894 L F
.70985 .348 m .70994 .34894 L .70993 .34888 L F
.71087 .3511 m .72457 .35166 L .72768 .35525 L .656 .025 0 r
F
.71084 .35069 m .71077 .35079 L .71094 .35099 L 0 0 0 r
F
.71077 .35079 m .71044 .35129 L .71085 .35104 L F
.71077 .35079 m .71085 .35104 L .71094 .35099 L F
.71151 .35379 m .71167 .35275 L .71048 .35182 L F
.71167 .35275 m .71157 .35255 L .72768 .35525 L .67 .029 0 r
F
.71167 .35275 m .7117 .35255 L .71152 .35245 L 0 0 0 r
F
.71167 .35275 m .71152 .35245 L .71048 .35182 L F
.71244 .3533 m .71167 .35275 L .72768 .35525 L .67 .029 0 r
F
.71167 .35275 m .71134 .35251 L .71157 .35255 L F
.71087 .3511 m .71044 .35129 L .71048 .35182 L 0 0 0 r
F
.71087 .35103 m .71044 .35129 L .71087 .3511 L F
.71157 .35255 m .71087 .3511 L .72768 .35525 L .67 .029 0 r
F
.71084 .35069 m .72457 .35166 L .71087 .3511 L .656 .025 0 r
F
.7117 .35255 m .71094 .35099 L .71087 .3511 L 0 0 0 r
F
.71152 .35245 m .71087 .3511 L .71048 .35182 L F
.7117 .35255 m .71087 .3511 L .71152 .35245 L F
.71134 .35251 m .71087 .3511 L .71157 .35255 L .67 .029 0 r
F
.71099 .35454 m .71048 .35182 L .70149 .36806 L 0 0 0 r
F
.71044 .35129 m .70276 .36277 L .71048 .35182 L F
.71084 .35069 m .70993 .34894 L .70276 .36277 L F
.70953 .34851 m .70387 .35743 L .70961 .34956 L F
.71134 .35251 m .70856 .35053 L .71087 .3511 L .67 .029 0 r
F
.70856 .35053 m .71084 .35069 L .71087 .3511 L .656 .025 0 r
F
.71094 .35099 m .71087 .35103 L .71087 .3511 L 0 0 0 r
F
.71084 .35069 m .71034 .34916 L .72457 .35166 L .656 .025 0 r
F
.71002 .3491 m .70994 .34894 L .72457 .35166 L F
.71233 .34847 m .71084 .35069 L .71094 .35099 L 0 0 0 r
F
.71084 .35069 m .71002 .3491 L .71034 .34916 L .656 .025 0 r
F
.71002 .3491 m .70993 .34894 L .70994 .34894 L F
.7117 .35255 m .71233 .34847 L .71094 .35099 L 0 0 0 r
F
.71151 .35379 m .71048 .35182 L .71099 .35454 L F
.70993 .34894 m .71028 .34891 L .71029 .349 L .641 .021 0 r
F
.7099 .34861 m .70981 .34859 L .70993 .34894 L 0 0 0 r
F
.70981 .34859 m .70953 .34851 L .70993 .34894 L F
.70985 .348 m .70953 .34851 L .71007 .34866 L F
.7133 .33786 m .71344 .3326 L .70834 .34411 L F
.70895 .34515 m .70834 .34411 L .70482 .35205 L F
.70866 .34465 m .70834 .34411 L .7086 .34413 L .631 .018 0 r
F
.70872 .34516 m .7086 .34413 L .70895 .34515 L F
.7133 .33786 m .70834 .34411 L .70895 .34515 L 0 0 0 r
F
.70872 .34516 m .70834 .34411 L .70866 .34465 L .631 .018 0 r
F
.70453 .34793 m .70985 .348 L .70993 .34894 L .641 .021 0 r
F
.71007 .34866 m .7099 .34861 L .70993 .34894 L 0 0 0 r
F
.71233 .34847 m .71293 .34315 L .70993 .34894 L F
.71233 .34847 m .70993 .34894 L .71084 .35069 L F
.71052 .35067 m .70993 .34894 L .71084 .35069 L .656 .025 0 r
F
.71017 .35064 m .7095 .34886 L .70993 .34894 L F
.71017 .35064 m .70993 .34894 L .71052 .35067 L F
.71293 .34315 m .70985 .348 L .71007 .34866 L 0 0 0 r
F
.70895 .34515 m .70907 .34647 L .7093 .34617 L F
.7079 .34452 m .7056 .34664 L .70802 .34485 L F
.70034 .34551 m .70895 .34515 L .70908 .34661 L .631 .018 0 r
F
.70934 .348 m .7088 .34658 L .70908 .34661 L .641 .021 0 r
F
.70934 .348 m .70908 .34661 L .70957 .348 L F
.7093 .34617 m .70905 .3465 L .70908 .34661 L 0 0 0 r
F
.7133 .33786 m .70895 .34515 L .7093 .34617 L F
.70856 .35053 m .70453 .34793 L .7095 .34886 L .656 .025 0 r
F
.70856 .35053 m .7095 .34886 L .71017 .35064 L F
.70834 .34411 m .7079 .34452 L .70802 .34485 L 0 0 0 r
F
.70861 .34516 m .70822 .3441 L .70834 .34411 L .631 .018 0 r
F
.70861 .34516 m .70834 .34411 L .70872 .34516 L F
.70453 .34793 m .70034 .34551 L .7088 .34658 L .641 .021 0 r
F
.70453 .34793 m .7088 .34658 L .70934 .348 L F
.70034 .34551 m .69598 .34328 L .70822 .3441 L .631 .018 0 r
F
.70034 .34551 m .70822 .3441 L .70861 .34516 L F
.70718 .33843 m .70679 .33532 L .70714 .33857 L 0 0 0 r
F
.70682 .3354 m .70679 .33532 L .70718 .33843 L F
.70702 .33799 m .70658 .33576 L .70652 .33663 L F
.70679 .33532 m .70658 .33576 L .70714 .33857 L F
.70676 .3352 m .70661 .33482 L .70658 .33576 L F
.71299 .32224 m .7124 .31716 L .70676 .3352 L F
.70681 .33528 m .70676 .3352 L .70658 .33576 L F
.70678 .33524 m .70676 .3352 L .70678 .3352 L .6 .012 0 r
F
.70679 .33529 m .70678 .3352 L .70681 .33528 L F
.71299 .32224 m .70676 .3352 L .70681 .33528 L 0 0 0 r
F
.70679 .33529 m .70676 .3352 L .70678 .33524 L .6 .012 0 r
F
.68678 .33942 m .70681 .33528 L .70718 .33843 L F
.70681 .33528 m .70764 .33511 L .70718 .33843 L F
.70756 .33739 m .70682 .3354 L .70718 .33843 L 0 0 0 r
F
.70681 .33528 m .70678 .3352 L .70764 .33511 L .6 .012 0 r
F
.71299 .32224 m .70681 .33528 L .70756 .33739 L 0 0 0 r
F
.70681 .33528 m .70679 .33532 L .70756 .33739 L F
.69146 .34124 m .68678 .33942 L .70718 .33843 L .61 .013 0 r
F
.69146 .34124 m .70718 .33843 L .70733 .33882 L F
.70676 .3352 m .70663 .33427 L .70669 .33431 L .59 .011 0 r
F
.70676 .3352 m .70669 .33431 L .70678 .3352 L F
.70668 .33462 m .70663 .33427 L .70661 .33482 L 0 0 0 r
F
.70661 .33482 m .70663 .33427 L .70657 .33452 L F
.68193 .33783 m .70663 .33427 L .70676 .3352 L .59 .011 0 r
F
.70668 .33462 m .70663 .33427 L .70668 .33462 L 0 0 0 r
F
.7124 .31716 m .70663 .33427 L .70668 .33462 L F
.7124 .31716 m .70661 .33482 L .70676 .3352 L F
.70669 .33531 m .70667 .33521 L .70676 .3352 L .6 .012 0 r
F
.70669 .33531 m .70676 .3352 L .70679 .33529 L F
.68678 .33942 m .68193 .33783 L .70667 .33521 L F
.68678 .33942 m .70667 .33521 L .70669 .33531 L F
.70652 .33183 m .70651 .33167 L .70659 .33166 L 1 .14 0 r
F
.70663 .33427 m .70677 .33032 L .70651 .33167 L 0 0 0 r
F
.7058 .33357 m .70597 .33176 L .70651 .33167 L 1 .14 0 r
F
.7058 .33357 m .70651 .33167 L .70652 .33183 L F
.7058 .33357 m .70659 .33166 L .70671 .33336 L F
.70601 .33135 m .70694 .32768 L .70657 .33115 L 1 .166 0 r
F
.70632 .32667 m .70652 .32355 L .70686 .32645 L 1 .194 0 r
F
.70593 .32683 m .70623 .32518 L .70632 .32667 L F
.70623 .32518 m .70652 .32355 L .70632 .32667 L F
.70677 .33032 m .70674 .32489 L .70638 .32758 L 0 0 0 r
F
.70642 .32825 m .70638 .32758 L .70635 .32781 L F
.70677 .33032 m .70638 .32758 L .70642 .32825 L F
.70677 .33032 m .70635 .32781 L .70657 .33115 L F
.70601 .33135 m .70635 .32781 L .70647 .32956 L 1 .166 0 r
F
.70677 .33032 m .70657 .33115 L .70653 .33157 L 0 0 0 r
F
.70627 .33397 m .7058 .33357 L .70633 .33345 L 1 .14 0 r
F
.7058 .33357 m .70402 .33207 L .70597 .33176 L F
.70635 .32781 m .70633 .32793 L .70632 .32803 L 0 0 0 r
F
.70622 .3233 m .70622 .32344 L .7062 .32364 L F
.7065 .32644 m .70622 .3233 L .7062 .32364 L F
.7065 .32644 m .7062 .32364 L .70647 .32661 L F
.70593 .32683 m .7062 .32364 L .7063 .32475 L 1 .194 0 r
F
.70554 .33152 m .70584 .32792 L .70635 .32781 L 1 .166 0 r
F
.70554 .33152 m .70635 .32781 L .70601 .33135 L F
.70674 .32489 m .70647 .32661 L .70638 .32758 L 0 0 0 r
F
.70616 .32018 m .70659 .31898 L .70635 .3218 L 1 .226 0 r
F
.70607 .31924 m .7064 .32008 L .70605 .31961 L 0 0 0 r
F
.70609 .3196 m .70604 .31916 L .70605 .31961 L F
.70616 .32018 m .70604 .31916 L .70659 .31898 L 1 .226 0 r
F
.70609 .3196 m .70604 .31916 L .70609 .3196 L 0 0 0 r
F
.70592 .32087 m .70604 .31916 L .70616 .32018 L 1 .226 0 r
F
.70649 .31949 m .70604 .31916 L .70609 .3196 L 0 0 0 r
F
.70649 .31949 m .70609 .3196 L .70635 .3218 L F
.70649 .31949 m .70635 .3218 L .70622 .3233 L F
.70674 .32489 m .70649 .31949 L .70622 .3233 L F
.70674 .32489 m .70622 .3233 L .7065 .32644 L F
.7061 .32191 m .70616 .32018 L .70635 .3218 L 1 .226 0 r
F
.70545 .32221 m .706 .32066 L .7061 .32191 L F
.706 .32066 m .70616 .32018 L .7061 .32191 L F
.70649 .31949 m .706 .31413 L .70604 .31916 L 0 0 0 r
F
.69299 .32337 m .70583 .31692 L .70604 .31916 L 1 .261 0 r
F
.70402 .33207 m .70584 .32792 L .70554 .33152 L 1 .166 0 r
F
.7055 .327 m .70574 .32376 L .7062 .32364 L 1 .194 0 r
F
.7055 .327 m .7062 .32364 L .70593 .32683 L F
.70035 .32911 m .70574 .32376 L .7055 .327 L F
.70545 .32221 m .70563 .31929 L .70604 .31916 L 1 .226 0 r
F
.70545 .32221 m .70604 .31916 L .70592 .32087 L F
.69667 .32622 m .70563 .31929 L .70545 .32221 L F
.69299 .32337 m .70584 .31439 L .70569 .31699 L 1 .261 0 r
F
.70579 .31393 m .70586 .31394 L .70584 .31439 L .713 .115 0 r
F
.68935 .32053 m .68583 .31764 L .70516 .30951 L 1 .302 0 r
F
.70519 .30972 m .70516 .30951 L .70603 .30914 L F
.68935 .32053 m .70516 .30951 L .70519 .30972 L F
.68935 .32053 m .70556 .30947 L .70591 .31149 L F
.7056 .30971 m .70563 .30979 L .70591 .31149 L .713 .115 0 r
F
.70561 .30972 m .70554 .30935 L .70563 .30979 L F
.70556 .30947 m .70603 .30914 L .70591 .31149 L 1 .302 0 r
F
.70558 .30965 m .7056 .30971 L .70591 .31149 L .713 .115 0 r
F
.70529 .30882 m .70591 .31149 L .70579 .31393 L F
.706 .31413 m .70529 .30882 L .70579 .31393 L 0 0 0 r
F
.70585 .31436 m .70579 .31393 L .70584 .31439 L F
.70591 .31149 m .70637 .31401 L .70584 .31439 L 1 .302 0 r
F
.706 .31413 m .70579 .31393 L .70585 .31436 L 0 0 0 r
F
.70591 .31149 m .70603 .30914 L .72424 .30148 L 1 .302 0 r
F
.70591 .31149 m .72424 .30148 L .70637 .31401 L F
.70529 .30882 m .70558 .30965 L .70591 .31149 L .713 .115 0 r
F
.70608 .31326 m .70529 .30882 L .706 .31413 L 0 0 0 r
F
.70455 .29887 m .70448 .29864 L .70461 .29889 L .793 .115 0 r
F
.70435 .30088 m .70392 .29892 L .70448 .29864 L 1 .411 0 r
F
.70454 .29887 m .70448 .29864 L .70455 .29887 L .793 .115 0 r
F
.70515 .30071 m .70461 .29889 L .70618 .30188 L F
.70435 .30088 m .70448 .29864 L .70496 .30049 L 1 .411 0 r
F
.70496 .30049 m .70461 .29889 L .70515 .30071 L .793 .115 0 r
F
.70315 .29842 m .70448 .29885 L .70496 .30049 L F
.70448 .29885 m .70461 .29889 L .70496 .30049 L F
.70496 .30049 m .72261 .28937 L .70583 .30347 L 1 .411 0 r
F
.70496 .30049 m .70583 .30347 L .7051 .30409 L F
.70496 .30049 m .70448 .29864 L .72261 .28937 L F
.70315 .29842 m .70448 .29864 L .70454 .29887 L .793 .115 0 r
F
.70552 .3093 m .70544 .30889 L .70554 .30935 L .713 .115 0 r
F
.70529 .30882 m .70544 .30889 L .70552 .3093 L F
.70544 .30589 m .70552 .30605 L .70545 .30869 L .753 .115 0 r
F
.70552 .30605 m .70644 .30797 L .70545 .30869 L F
.70568 .30638 m .70522 .30443 L .70644 .30797 L F
.70552 .30605 m .70522 .30443 L .70568 .30638 L F
.70508 .30601 m .70558 .30386 L .70507 .30632 L 1 .351 0 r
F
.70516 .30438 m .70522 .30443 L .70552 .30605 L .753 .115 0 r
F
.70466 .30451 m .70558 .30386 L .70499 .30636 L 1 .351 0 r
F
.70434 .30358 m .70516 .30438 L .70552 .30605 L .753 .115 0 r
F
.70507 .30632 m .70532 .30512 L .70552 .30605 L 1 .351 0 r
F
.70532 .30512 m .70558 .30386 L .70552 .30605 L F
.70552 .30605 m .70558 .30386 L .7233 .29559 L F
.70552 .30605 m .7233 .29559 L .70554 .30935 L F
.70545 .30892 m .70554 .30883 L .70554 .30935 L .753 .115 0 r
F
.70499 .30636 m .70508 .30601 L .70507 .30632 L 1 .351 0 r
F
.70434 .30358 m .70544 .30589 L .70545 .30892 L .753 .115 0 r
F
.70554 .30935 m .7233 .29559 L .72424 .30148 L 1 .351 0 r
F
.70529 .30882 m .70554 .30935 L .70561 .30972 L .713 .115 0 r
F
.7051 .30409 m .72261 .28937 L .7233 .29559 L 1 .411 0 r
F
.7074 .29791 m .70529 .30882 L .70608 .31326 L 0 0 0 r
F
.7053 .30801 m .70434 .30358 L .70529 .30882 L F
.70434 .30358 m .70333 .29896 L .70495 .30366 L .753 .115 0 r
F
.70504 .30405 m .70495 .30366 L .7051 .30409 L F
.70434 .30358 m .70495 .30366 L .70504 .30405 L F
.70419 .29486 m .70571 .29578 L .70427 .29747 L .828 .115 0 r
F
.70438 .29497 m .70374 .2932 L .70571 .29578 L F
.70419 .29486 m .70374 .2932 L .70438 .29497 L F
.70373 .29517 m .70392 .294 L .70419 .29486 L 1 .484 0 r
F
.70369 .29453 m .70412 .29276 L .70373 .29517 L F
.70367 .29321 m .70374 .2932 L .70419 .29486 L .828 .115 0 r
F
.70367 .29321 m .70361 .29304 L .70374 .2932 L F
.70304 .29358 m .70412 .29276 L .7035 .29532 L 1 .484 0 r
F
.70171 .29335 m .70367 .29321 L .70419 .29486 L .828 .115 0 r
F
.70392 .294 m .70412 .29276 L .70419 .29486 L 1 .484 0 r
F
.70419 .29486 m .70412 .29276 L .72218 .28279 L F
.70419 .29486 m .72218 .28279 L .70448 .29864 L F
.70315 .29842 m .70496 .30049 L .7051 .30409 L .793 .115 0 r
F
.70448 .29864 m .72218 .28279 L .72261 .28937 L 1 .484 0 r
F
.70549 .29344 m .70434 .30358 L .7053 .30801 L 0 0 0 r
F
.70434 .30358 m .70315 .29842 L .70333 .29896 L .753 .115 0 r
F
.70428 .30284 m .70315 .29842 L .70434 .30358 L 0 .002 0 r
F
.70171 .29335 m .70034 .28877 L .70345 .29282 L .828 .115 0 r
F
.70352 .29306 m .70345 .29282 L .70361 .29304 L F
.70171 .29335 m .70345 .29282 L .70352 .29306 L F
.70345 .29282 m .70316 .28919 L .70361 .29304 L .857 .115 0 r
F
.70004 .28838 m .70316 .28919 L .70345 .29282 L F
.7035 .29532 m .70369 .29453 L .70373 .29517 L 1 .484 0 r
F
.70315 .29842 m .7043 .29829 L .70439 .29862 L .793 .115 0 r
F
.70171 .29335 m .70408 .29479 L .70434 .29837 L .828 .115 0 r
F
.7033 .28914 m .70315 .29842 L .70428 .30284 L 0 .002 0 r
F
.70303 .29774 m .70171 .29335 L .70315 .29842 L 0 .008 0 r
F
.70004 .28838 m .69812 .28352 L .69849 .28384 L .857 .115 0 r
F
.70004 .28838 m .69849 .28384 L .70237 .28729 L F
.70171 .29335 m .70004 .28838 L .70034 .28877 L .828 .115 0 r
F
.70153 .29274 m .70004 .28838 L .70171 .29335 L 0 .013 0 r
F
.70182 .28796 m .70176 .28776 L .70244 .28735 L 1 .577 0 r
F
.70182 .28796 m .70244 .28735 L .70247 .28744 L F
.70004 .28838 m .70237 .28729 L .70299 .28876 L .857 .115 0 r
F
.70316 .28919 m .70299 .28876 L .70318 .28919 L F
.70004 .28838 m .70299 .28876 L .70316 .28919 L F
.70247 .28744 m .70244 .28735 L .703 .28703 L 1 .577 0 r
F
.70019 .28218 m .70014 .28206 L .70085 .28162 L 1 .694 0 r
F
.69812 .28352 m .70085 .28162 L .70183 .28355 L .911 .114 0 r
F
.69812 .28352 m .69597 .27878 L .70085 .28162 L F
.69809 .28112 m .70004 .28838 L .70153 .29274 L 0 .013 0 r
F
.70084 .28502 m .70171 .29335 L .70303 .29774 L 0 .008 0 r
F
.70316 .28919 m .703 .28703 L .72201 .27582 L 1 .577 0 r
F
.70439 .29862 m .7043 .29829 L .70448 .29864 L .793 .115 0 r
F
.70408 .29479 m .70419 .29486 L .70427 .29747 L .828 .115 0 r
F
.70434 .29837 m .70444 .29817 L .70448 .29864 L F
.68935 .32053 m .70548 .31172 L .70584 .31439 L 1 .302 0 r
F
.70361 .29304 m .72201 .27582 L .72218 .28279 L 1 .577 0 r
F
.70244 .28735 m .72205 .26846 L .72201 .27582 L 1 .694 0 r
F
.70183 .28355 m .70085 .28162 L .72205 .26846 L F
.69597 .27878 m .70012 .27802 L .70085 .28162 L .99 .113 0 r
F
.70085 .28162 m .72224 .26073 L .72205 .26846 L 1 .832 0 r
F
.70082 .28146 m .72224 .26073 L .70085 .28162 L F
.69359 .27418 m .69785 .27273 L .69865 .27592 L 1 .111 0 r
F
.69865 .27592 m .72245 .25271 L .72224 .26073 L 1 .976 0 r
F
.6986 .27572 m .72245 .25271 L .69865 .27592 L F
.69097 .26973 m .69463 .268 L .69535 .27037 L 1 .145 0 r
F
.69535 .27037 m .72256 .24451 L .72245 .25271 L 1 1 0 r
F
.69527 .2701 m .72256 .24451 L .69535 .27037 L F
.68812 .26542 m .68921 .26479 L .68944 .2654 L 1 .177 0 r
F
.68921 .26479 m .69896 .25909 L .68944 .2654 L F
.68944 .2654 m .72241 .23626 L .72256 .24451 L 1 1 0 r
F
.68921 .26479 m .72241 .23626 L .68944 .2654 L F
.88766 .56006 m .87151 .57136 L .87076 .57805 L 0 0 0 r
F
.88766 .56006 m .88849 .55326 L .87151 .57136 L F
.37606 .56365 m .36036 .5567 L .36081 .55905 L 1 .604 0 r
F
.37648 .56595 m .37606 .56365 L .36081 .55905 L 1 .587 0 r
F
.65115 .51911 m .6421 .52474 L .64133 .52776 L 0 0 0 r
F
.65115 .51911 m .65195 .51609 L .6421 .52474 L F
.3188 .45747 m .31062 .44717 L .3094 .45006 L 1 1 0 r
F
.3177 .46044 m .3188 .45747 L .3094 .45006 L F
.43655 .34449 m .43427 .34555 L .43221 .34682 L .544 .215 0 r
F
.43256 .60922 m .41446 .60589 L .41498 .60783 L 1 .261 0 r
F
.43292 .6111 m .43256 .60922 L .41498 .60783 L 1 .241 0 r
F
.79655 .76402 m .77449 .76955 L .7713 .77489 L .099 0 0 r
F
.79655 .76402 m .80005 .75849 L .77449 .76955 L F
.56702 .36935 m .55884 .37149 L .56051 .37402 L .431 .377 0 r
F
.5688 .37178 m .56702 .36935 L .56051 .37402 L .431 .38 0 r
F
.34209 .83885 m .30965 .83505 L .3125 .83866 L .911 .068 0 r
F
.3444 .84233 m .34209 .83885 L .3125 .83866 L .893 .064 0 r
F
.42214 .35429 m .41937 .35248 L .4172 .35399 L .87 .98 0 r
F
.42214 .35429 m .42412 .35265 L .41937 .35248 L F
.34764 .47979 m .33673 .471 L .33611 .47361 L 1 1 0 r
F
.34711 .48242 m .34764 .47979 L .33611 .47361 L F
.60341 .43115 m .59319 .43471 L .59424 .43729 L .359 .17 0 r
F
.60341 .43115 m .60227 .42861 L .59319 .43471 L F
.57607 .38505 m .5674 .38762 L .569 .39001 L .421 .381 0 r
F
.57779 .38737 m .57607 .38505 L .569 .39001 L .419 .374 0 r
F
.29584 .85486 m .2635 .84508 L .26703 .84904 L .911 .064 0 r
F
.29891 .85858 m .29584 .85486 L .26703 .84904 L .886 .06 0 r
F
.7201 .63299 m .70354 .63881 L .70195 .64293 L .099 0 0 r
F
.7201 .63299 m .72192 .62882 L .70354 .63881 L F
.39563 .58295 m .37897 .57712 L .37956 .57928 L 1 .465 0 r
F
.39613 .58505 m .39563 .58295 L .37956 .57928 L 1 .446 0 r
F
.57613 .57675 m .56123 .57861 L .56066 .58082 L .463 .045 0 r
F
.57613 .57675 m .5768 .57451 L .56123 .57861 L F
.44849 .65523 m .42833 .65306 L .42887 .65501 L .865 .067 0 r
F
.44879 .65702 m .44849 .65523 L .42887 .65501 L .85 .064 0 r
F
.46819 .65628 m .44849 .65523 L .44879 .65702 L .765 .053 0 r
F
.75393 .56423 m .7395 .57173 L .73852 .57629 L .009 0 0 r
F
.75393 .56423 m .75495 .55958 L .7395 .57173 L F
.56523 .36689 m .55718 .36892 L .55884 .37149 L .429 .372 0 r
F
.56702 .36935 m .56523 .36689 L .55884 .37149 L .431 .377 0 r
F
.71495 .13259 m .71323 .14239 L .71938 .14597 L .22 .276 0 r
F
.71495 .13259 m .70851 .12987 L .71323 .14239 L F
.50336 .61413 m .48631 .61344 L .48614 .61521 L .767 .065 0 r
F
.50336 .61413 m .50372 .61236 L .48631 .61344 L F
.61042 .44348 m .59977 .44726 L .60068 .4499 L .347 .116 0 r
F
.61042 .44348 m .60943 .44087 L .59977 .44726 L F
.40046 .36772 m .39782 .36472 L .39569 .3665 L .942 1 0 r
F
.40046 .36772 m .40255 .36597 L .39782 .36472 L F
.59507 .55316 m .58099 .55575 L .58058 .55817 L .388 .045 0 r
F
.59507 .55316 m .59554 .55071 L .58099 .55575 L F
.20137 .79217 m .17067 .77728 L .1741 .7825 L 1 .117 0 r
F
.20453 .79713 m .20137 .79217 L .1741 .7825 L 1 .095 0 r
F
.50301 .60945 m .48615 .60871 L .48597 .61041 L .768 .065 0 r
F
.50301 .60945 m .50337 .60775 L .48615 .60871 L F
.57434 .38275 m .56578 .38524 L .5674 .38762 L .422 .387 0 r
F
.57607 .38505 m .57434 .38275 L .5674 .38762 L .421 .381 0 r
F
.53827 .29746 m .55077 .25134 L .54493 .28046 L 1 .907 0 r
F
.53827 .29746 m .54011 .2811 L .55077 .25134 L F
.6045 .4337 m .59424 .43729 L .59526 .43988 L .356 .156 0 r
F
.6045 .4337 m .60341 .43115 L .59424 .43729 L F
.33337 .51093 m .31929 .50156 L .31922 .50439 L 1 .85 0 r
F
.33336 .51372 m .33337 .51093 L .31922 .50439 L 1 .837 0 r
F
.56344 .3644 m .55551 .36631 L .55718 .36892 L .427 .364 0 r
F
.56523 .36689 m .56344 .3644 L .55718 .36892 L .429 .372 0 r
F
.5747 .57264 m .5601 .57461 L .55954 .57678 L .454 .044 0 r
F
.5747 .57264 m .57535 .57044 L .5601 .57461 L F
.3177 .46044 m .3094 .45006 L .30823 .45297 L 1 1 0 r
F
.31665 .46343 m .3177 .46044 L .30823 .45297 L F
.55299 .34777 m .546 .34843 L .54747 .35186 L .368 .195 0 r
F
.55299 .34777 m .55141 .34443 L .546 .34843 L F
.50592 .65231 m .4876 .65307 L .48734 .65471 L .559 .025 0 r
F
.50592 .65231 m .50647 .65071 L .4876 .65307 L F
.6555 .86655 m .63088 .86843 L .62774 .8719 L .288 0 0 r
F
.6555 .86655 m .65921 .86296 L .63088 .86843 L F
.60877 .51092 m .59627 .51428 L .59627 .51687 L .342 .053 0 r
F
.60877 .51092 m .60876 .50832 L .59627 .51428 L F
.35779 .53472 m .34373 .52667 L .34386 .5292 L 1 .774 0 r
F
.35794 .53722 m .35779 .53472 L .34386 .5292 L 1 .759 0 r
F
.57258 .38046 m .56414 .38285 L .56578 .38524 L .423 .392 0 r
F
.57434 .38275 m .57258 .38046 L .56578 .38524 L .422 .387 0 r
F
.35191 .55122 m .3356 .54348 L .33602 .54609 L 1 .662 0 r
F
.35231 .55376 m .35191 .55122 L .33602 .54609 L 1 .648 0 r
F
.56165 .36186 m .55385 .36364 L .55551 .36631 L .422 .352 0 r
F
.56344 .3644 m .56165 .36186 L .55551 .36631 L .427 .364 0 r
F
.3848 .63588 m .3653 .62964 L .36624 .63218 L 1 .317 0 r
F
.38563 .63828 m .3848 .63588 L .36624 .63218 L 1 .297 0 r
F
.60556 .43626 m .59526 .43988 L .59623 .44248 L .352 .142 0 r
F
.60556 .43626 m .6045 .4337 L .59526 .43988 L F
.61137 .4461 m .60068 .4499 L .60155 .45256 L .343 .104 0 r
F
.61137 .4461 m .61042 .44348 L .60068 .4499 L F
.34711 .48242 m .33611 .47361 L .33553 .47622 L 1 1 0 r
F
.34662 .48505 m .34711 .48242 L .33553 .47622 L 1 .998 0 r
F
.36571 .38471 m .36196 .37821 L .35961 .38012 L 1 1 0 r
F
.36571 .38471 m .36789 .38263 L .36196 .37821 L F
.89769 .4016 m .88403 .4157 L .88586 .42251 L 0 .011 0 r
F
.89769 .4016 m .89576 .39477 L .88403 .4157 L F
.55987 .35926 m .55221 .36089 L .55385 .36364 L .416 .336 0 r
F
.56165 .36186 m .55987 .35926 L .55385 .36364 L .422 .352 0 r
F
.61128 .51676 m .5984 .52012 L .59836 .52274 L .346 .052 0 r
F
.61128 .51676 m .61133 .51413 L .5984 .52012 L F
.55465 .35088 m .54747 .35186 L .549 .35503 L .381 .245 0 r
F
.55465 .35088 m .55299 .34777 L .54747 .35186 L F
.59312 .54934 m .57942 .55202 L .57902 .55439 L .381 .044 0 r
F
.59312 .54934 m .59358 .54694 L .57942 .55202 L F
.40499 .35931 m .4025 .3563 L .40012 .3578 L .893 1 0 r
F
.40499 .35931 m .40722 .3577 L .4025 .3563 L F
.5708 .37816 m .56248 .38047 L .56414 .38285 L .423 .396 0 r
F
.57258 .38046 m .5708 .37816 L .56414 .38285 L .423 .392 0 r
F
.14682 .73316 m .11848 .71474 L .12124 .72072 L 1 .273 0 r
F
.14945 .73889 m .14682 .73316 L .12124 .72072 L 1 .244 0 r
F
.5581 .35658 m .55059 .35803 L .55221 .36089 L .407 .313 0 r
F
.55987 .35926 m .5581 .35658 L .55221 .36089 L .416 .336 0 r
F
.3659 .38488 m .37101 .38667 L .36912 .38867 L .005 0 0 r
F
.3659 .38488 m .36814 .38287 L .371 .38665 L F
.3659 .38488 m .371 .38665 L .37099 .38666 L F
.37416 .39604 m .3659 .38488 L .36912 .38867 L 0 0 0 r
F
.36789 .38263 m .36434 .37635 L .36196 .37821 L 1 1 0 r
F
.36907 .38861 m .36581 .38097 L .36386 .38293 L F
.36912 .38867 m .36909 .38858 L .36907 .38861 L F
.36909 .38858 m .36581 .38097 L .36907 .38861 L F
.37099 .38666 m .371 .38665 L .37101 .38667 L .005 0 0 r
F
.43335 .60364 m .41589 .59978 L .41639 .60164 L 1 .259 0 r
F
.4337 .60544 m .43335 .60364 L .41639 .60164 L 1 .239 0 r
F
.21121 .77263 m .17958 .76027 L .18282 .7653 L 1 .186 0 r
F
.21416 .77741 m .21121 .77263 L .18282 .7653 L 1 .161 0 r
F
.55636 .3538 m .549 .35503 L .55059 .35803 L .394 .284 0 r
F
.55636 .3538 m .55465 .35088 L .549 .35503 L F
.45088 .61372 m .43292 .6111 L .43329 .61296 L .969 .186 0 r
F
.45107 .61552 m .45088 .61372 L .43329 .61296 L .96 .166 0 r
F
.46863 .61567 m .45088 .61372 L .45107 .61552 L .905 .121 0 r
F
.41493 .59596 m .39777 .59118 L .39836 .59316 L 1 .348 0 r
F
.4154 .59789 m .41493 .59596 L .39836 .59316 L 1 .328 0 r
F
.5581 .35658 m .55636 .3538 L .55059 .35803 L .407 .313 0 r
F
.55399 .89748 m .52656 .89711 L .52516 .89973 L .425 0 0 r
F
.55399 .89748 m .55611 .89481 L .52656 .89711 L F
.10325 .62873 m .07806 .60721 L .07948 .6137 L 1 .522 0 r
F
.10469 .635 m .10325 .62873 L .07948 .6137 L 1 .497 0 r
F
.60658 .43883 m .59623 .44248 L .59718 .44508 L .348 .129 0 r
F
.60658 .43883 m .60556 .43626 L .59623 .44248 L F
.8963 .56883 m .87796 .5798 L .87726 .58663 L 0 0 0 r
F
.8963 .56883 m .89706 .56186 L .87796 .5798 L F
.52008 .60606 m .50372 .606 L .50337 .60775 L .69 .057 0 r
F
.52008 .60606 m .5206 .6043 L .50372 .606 L F
.42833 .65306 m .40811 .64975 L .40887 .65185 L .953 .088 0 r
F
.42887 .65501 m .42833 .65306 L .40887 .65185 L .939 .077 0 r
F
.52061 .61061 m .50407 .61055 L .50372 .61236 L .691 .057 0 r
F
.52061 .61061 m .52114 .6088 L .50407 .61055 L F
.31665 .46343 m .30823 .45297 L .30711 .4559 L 1 1 0 r
F
.31564 .46643 m .31665 .46343 L .30711 .4559 L F
.66857 .46497 m .66272 .47035 L .6619 .47389 L 0 0 0 r
F
.66857 .46497 m .66947 .46143 L .66272 .47035 L F
.61228 .44873 m .60155 .45256 L .60239 .45522 L .339 .091 0 r
F
.61228 .44873 m .61137 .4461 L .60155 .45256 L F
.69395 .13965 m .69025 .15133 L .69531 .1559 L .233 .219 0 r
F
.69395 .13965 m .68848 .13596 L .69025 .15133 L F
.569 .37588 m .56081 .37808 L .56248 .38047 L .423 .399 0 r
F
.5708 .37816 m .569 .37588 L .56248 .38047 L .423 .396 0 r
F
.31813 .54526 m .30471 .53451 L .30473 .53763 L 1 .811 0 r
F
.31822 .54837 m .31813 .54526 L .30473 .53763 L 1 .796 0 r
F
.15687 .71789 m .12734 .70133 L .13002 .70709 L 1 .32 0 r
F
.15939 .72338 m .15687 .71789 L .13002 .70709 L 1 .294 0 r
F
.09415 .63943 m .07032 .61681 L .0717 .62349 L 1 .495 0 r
F
.09556 .64592 m .09415 .63943 L .0717 .62349 L 1 .468 0 r
F
.55673 .59353 m .54125 .59472 L .54067 .59674 L .538 .046 0 r
F
.55673 .59353 m .55745 .59148 L .54125 .59472 L F
.58491 .61485 m .57017 .61842 L .56907 .6205 L .273 0 0 r
F
.58491 .61485 m .58619 .61273 L .57017 .61842 L F
.37034 .88948 m .33785 .88312 L .34066 .88627 L .765 .04 0 r
F
.37253 .89243 m .37034 .88948 L .34066 .88627 L .737 .035 0 r
F
.5557 .58923 m .54046 .5905 L .53988 .59248 L .532 .046 0 r
F
.5557 .58923 m .55641 .58722 L .54046 .5905 L F
.36789 .38263 m .37009 .3806 L .36434 .37635 L 1 1 0 r
F
.30414 .82759 m .27153 .82143 L .27475 .82537 L .973 .076 0 r
F
.30687 .83136 m .30414 .82759 L .27475 .82537 L .956 .073 0 r
F
.42524 .3486 m .42316 .34796 L .42084 .34916 L .594 .45 0 r
F
.42524 .3486 m .42735 .34724 L .42316 .34796 L F
.60756 .4414 m .59718 .44508 L .59809 .44769 L .344 .115 0 r
F
.60756 .4414 m .60658 .43883 L .59718 .44508 L F
.34662 .48505 m .33553 .47622 L .33498 .47884 L 1 .998 0 r
F
.34616 .48768 m .34662 .48505 L .33498 .47884 L 1 .988 0 r
F
.52448 .64756 m .50701 .64907 L .50647 .65071 L .459 .012 0 r
F
.52448 .64756 m .5253 .64593 L .50701 .64907 L F
.40255 .36597 m .39991 .36289 L .39782 .36472 L .967 1 0 r
F
.40255 .36597 m .40463 .36421 L .39991 .36289 L F
.56718 .37359 m .55912 .37568 L .56081 .37808 L .421 .399 0 r
F
.569 .37588 m .56718 .37359 L .56081 .37808 L .423 .399 0 r
F
.45123 .60844 m .4337 .60544 L .43407 .6072 L .98 .182 0 r
F
.45143 .61015 m .45123 .60844 L .43407 .6072 L .971 .161 0 r
F
.46869 .61065 m .45123 .60844 L .45143 .61015 L .911 .116 0 r
F
.37332 .57722 m .35596 .571 L .35661 .57338 L 1 .519 0 r
F
.37388 .57953 m .37332 .57722 L .35661 .57338 L 1 .503 0 r
F
.74128 .35114 m .73932 .34652 L .75107 .35229 L 1 .126 0 r
F
.33336 .51372 m .31922 .50439 L .31919 .50722 L 1 .837 0 r
F
.33338 .51649 m .33336 .51372 L .31919 .50722 L 1 .824 0 r
F
.61315 .45137 m .60239 .45522 L .60319 .45788 L .336 .079 0 r
F
.61315 .45137 m .61228 .44873 L .60239 .45522 L F
.5174 .81714 m .4932 .82479 L .49271 .82792 L .344 0 0 r
F
.5174 .81714 m .5184 .81411 L .4932 .82479 L F
.37648 .56595 m .36081 .55905 L .3613 .56139 L 1 .587 0 r
F
.37692 .56823 m .37648 .56595 L .3613 .56139 L 1 .57 0 r
F
.36814 .38287 m .37293 .38471 L .37101 .38667 L .006 0 0 r
F
.36814 .38287 m .37044 .38095 L .37291 .38468 L F
.36814 .38287 m .37291 .38468 L .3729 .38469 L F
.37092 .38658 m .36779 .37905 L .36581 .38097 L 1 1 0 r
F
.37101 .38667 m .37096 .38655 L .37092 .38658 L F
.37096 .38655 m .36779 .37905 L .37092 .38658 L F
.3729 .38469 m .37291 .38468 L .37293 .38471 L .006 0 0 r
F
.60873 .5135 m .59627 .51687 L .59624 .51945 L .338 .051 0 r
F
.60873 .5135 m .60877 .51092 L .59627 .51687 L F
.84363 .68115 m .82452 .68956 L .82216 .69556 L 0 0 0 r
F
.84363 .68115 m .84616 .67498 L .82452 .68956 L F
.31564 .46643 m .30711 .4559 L .30603 .45884 L 1 1 0 r
F
.31468 .46944 m .31564 .46643 L .30603 .45884 L F
.24956 .83875 m .21722 .82685 L .22101 .83137 L .971 .076 0 r
F
.25295 .84302 m .24956 .83875 L .22101 .83137 L .948 .072 0 r
F
.41397 .60391 m .39599 .59983 L .39663 .60187 L 1 .324 0 r
F
.41446 .60589 m .41397 .60391 L .39663 .60187 L 1 .304 0 r
F
.36185 .61921 m .34349 .61136 L .34436 .61413 L 1 .445 0 r
F
.36266 .62186 m .36185 .61921 L .34436 .61413 L 1 .426 0 r
F
.72424 .13141 m .72118 .14355 L .72721 .14737 L .228 .249 0 r
F
.72424 .13141 m .71818 .12797 L .72118 .14355 L F
.62949 .56466 m .61784 .56978 L .61685 .57243 L .091 0 0 r
F
.62949 .56466 m .63055 .56198 L .61784 .56978 L F
.42412 .35265 m .42157 .35105 L .41937 .35248 L .819 .919 0 r
F
.42412 .35265 m .42611 .35109 L .42157 .35105 L F
.6085 .44399 m .59809 .44769 L .59896 .45031 L .341 .101 0 r
F
.6085 .44399 m .60756 .4414 L .59809 .44769 L F
.56535 .37129 m .55742 .37327 L .55912 .37568 L .419 .398 0 r
F
.56718 .37359 m .56535 .37129 L .55912 .37568 L .421 .399 0 r
F
.6187 .74096 m .6011 .74795 L .59924 .75127 L .088 0 0 r
F
.6187 .74096 m .621 .73788 L .6011 .74795 L F
.3942 .59355 m .37639 .58853 L .37709 .59071 L 1 .411 0 r
F
.39477 .59567 m .3942 .59355 L .37709 .59071 L 1 .393 0 r
F
.33847 .59143 m .322 .58195 L .3226 .58493 L 1 .603 0 r
F
.33907 .59433 m .33847 .59143 L .3226 .58493 L 1 .585 0 r
F
.65033 .52211 m .64133 .52776 L .64055 .53076 L 0 0 0 r
F
.65033 .52211 m .65115 .51911 L .64133 .52776 L F
.35794 .53722 m .34386 .5292 L .34404 .53173 L 1 .759 0 r
F
.35813 .53971 m .35794 .53722 L .34404 .53173 L 1 .745 0 r
F
.32896 .44703 m .32992 .44418 L .31899 .4367 L 1 1 0 r
F
.77036 .46876 m .76243 .47762 L .76246 .48258 L 0 0 0 r
F
.77036 .46876 m .77009 .46382 L .76243 .47762 L F
.89305 .40246 m .88004 .41633 L .88164 .4231 L 0 .001 0 r
F
.89305 .40246 m .89145 .39564 L .88004 .41633 L F
.40738 .64761 m .38737 .64297 L .38828 .64527 L 1 .188 0 r
F
.40811 .64975 m .40738 .64761 L .38828 .64527 L 1 .167 0 r
F
.59456 .55559 m .58058 .55817 L .58013 .56057 L .384 .043 0 r
F
.59456 .55559 m .59507 .55316 L .58058 .55817 L F
.53739 .60007 m .52161 .60068 L .52111 .60251 L .609 .05 0 r
F
.53739 .60007 m .53805 .59822 L .52161 .60068 L F
.53814 .60451 m .52216 .60508 L .52166 .60695 L .612 .05 0 r
F
.53814 .60451 m .5388 .60262 L .52216 .60508 L F
.6112 .51939 m .59836 .52274 L .59828 .52535 L .342 .05 0 r
F
.6112 .51939 m .61128 .51676 L .59836 .52274 L F
.5435 .64034 m .5269 .64253 L .52611 .64425 L .393 .001 0 r
F
.5435 .64034 m .54455 .63861 L .5269 .64253 L F
.69249 .83725 m .6695 .8406 L .66608 .84441 L .204 0 0 r
F
.69249 .83725 m .6964 .83331 L .6695 .8406 L F
.37009 .3806 m .36675 .37454 L .36434 .37635 L 1 1 0 r
F
.37009 .3806 m .37232 .37861 L .36675 .37454 L F
.46865 .61741 m .46863 .61567 L .45107 .61552 L .895 .101 0 r
F
.48596 .61695 m .46863 .61567 L .46865 .61741 L .831 .072 0 r
F
.48596 .61695 m .48614 .61521 L .46863 .61567 L F
.0864 .64995 m .06127 .62722 L .06291 .63401 L 1 .463 0 r
F
.08804 .65652 m .0864 .64995 L .06291 .63401 L 1 .436 0 r
F
.57543 .57897 m .56066 .58082 L .56007 .58301 L .454 .042 0 r
F
.57543 .57897 m .57613 .57675 L .56066 .58082 L F
.6883 .40309 m .68466 .40801 L .6832 .41278 L 0 0 0 r
F
.6883 .40309 m .6898 .39826 L .68466 .40801 L F
.68251 .68183 m .66564 .68717 L .66373 .6909 L .117 0 0 r
F
.68251 .68183 m .68475 .67816 L .66564 .68717 L F
.74238 .81491 m .71959 .81882 L .71607 .82338 L .167 0 0 r
F
.74238 .81491 m .74632 .81019 L .71959 .81882 L F
.61399 .45402 m .60319 .45788 L .60396 .46055 L .332 .075 0 r
F
.61399 .45402 m .61315 .45137 L .60319 .45788 L F
.56351 .36898 m .55571 .37084 L .55742 .37327 L .415 .395 0 r
F
.56535 .37129 m .56351 .36898 L .55742 .37327 L .419 .398 0 r
F
.34616 .48768 m .33498 .47884 L .33448 .48146 L 1 .988 0 r
F
.34574 .49031 m .34616 .48768 L .33448 .48146 L 1 .977 0 r
F
.39613 .58505 m .37956 .57928 L .38017 .58141 L 1 .446 0 r
F
.39665 .58712 m .39613 .58505 L .38017 .58141 L 1 .427 0 r
F
.5503 .22229 m .55709 .19267 L .55057 .231 L 1 .791 0 r
F
.5503 .22229 m .54958 .20809 L .55709 .19267 L F
.43634 .34435 m .43841 .34323 L .43818 .34329 L .463 .212 0 r
F
.43836 .34297 m .43634 .34435 L .43451 .3454 L .464 .201 0 r
F
.43634 .34435 m .43818 .34329 L .43514 .34421 L .463 .212 0 r
F
.43451 .3454 m .43634 .34435 L .43427 .34555 L .464 .201 0 r
F
.6094 .44659 m .59896 .45031 L .5998 .45293 L .337 .088 0 r
F
.6094 .44659 m .6085 .44399 L .59896 .45031 L F
.40722 .3577 m .40489 .35485 L .4025 .3563 L .866 1 0 r
F
.40722 .3577 m .40945 .35614 L .40489 .35485 L F
.60669 .59493 m .59329 .59926 L .59217 .60159 L .193 0 0 r
F
.60669 .59493 m .60793 .59255 L .59329 .59926 L F
.4687 .61231 m .46869 .61065 L .45143 .61015 L .902 .097 0 r
F
.48579 .61208 m .46869 .61065 L .4687 .61231 L .835 .071 0 r
F
.48579 .61208 m .48597 .61041 L .46869 .61065 L F
.35231 .55376 m .33602 .54609 L .33648 .54869 L 1 .648 0 r
F
.35274 .55628 m .35231 .55376 L .33648 .54869 L 1 .633 0 r
F
.7894 .75779 m .76858 .76392 L .76539 .76909 L .058 0 0 r
F
.7894 .75779 m .79289 .75244 L .76858 .76392 L F
.61797 .88168 m .59262 .88278 L .58994 .88585 L .335 0 0 r
F
.61797 .88168 m .62129 .87852 L .59262 .88278 L F
.31468 .46944 m .30603 .45884 L .305 .4618 L 1 1 0 r
F
.31376 .47246 m .31468 .46944 L .305 .4618 L F
.57403 .57482 m .55954 .57678 L .55897 .57892 L .445 .041 0 r
F
.57403 .57482 m .5747 .57264 L .55954 .57678 L F
.59263 .55173 m .57902 .55439 L .57859 .55675 L .377 .042 0 r
F
.59263 .55173 m .59312 .54934 L .57902 .55439 L F
.37044 .38095 m .37488 .38277 L .37293 .38471 L .004 0 0 r
F
.37044 .38095 m .37282 .37913 L .37486 .38275 L F
.37044 .38095 m .37486 .38275 L .37485 .38276 L F
.37281 .38458 m .36979 .37714 L .36779 .37905 L 1 1 0 r
F
.37293 .38471 m .37286 .38454 L .37281 .38458 L F
.37286 .38454 m .36979 .37714 L .37281 .38458 L F
.37485 .38276 m .37486 .38275 L .37488 .38277 L .004 0 0 r
F
.59117 .76367 m .57261 .77185 L .57095 .77508 L .089 0 0 r
F
.59117 .76367 m .59328 .76071 L .57261 .77185 L F
.56165 .36666 m .55399 .36838 L .55571 .37084 L .41 .389 0 r
F
.56351 .36898 m .56165 .36666 L .55571 .37084 L .415 .395 0 r
F
.43292 .6111 m .41498 .60783 L .41551 .60975 L 1 .241 0 r
F
.43329 .61296 m .43292 .6111 L .41551 .60975 L 1 .22 0 r
F
.46822 .65794 m .46819 .65628 L .44879 .65702 L .747 .049 0 r
F
.48707 .6563 m .46819 .65628 L .46822 .65794 L .649 .036 0 r
F
.48707 .6563 m .48734 .65471 L .46819 .65628 L F
.32896 .44703 m .31899 .4367 L .31795 .43954 L 1 1 0 r
F
.32805 .44989 m .32896 .44703 L .31795 .43954 L F
.64853 .71538 m .6315 .72129 L .62954 .72475 L .104 0 0 r
F
.64853 .71538 m .65091 .71208 L .6315 .72129 L F
.72126 .13554 m .71938 .14597 L .72548 .14962 L .21 .252 0 r
F
.72126 .13554 m .71495 .13259 L .71938 .14597 L F
.46558 .90414 m .46551 .90165 L .43548 .90131 L .568 .011 0 r
F
.49486 .90361 m .46551 .90165 L .46558 .90414 L .514 .004 0 r
F
.49486 .90361 m .49554 .90112 L .46551 .90165 L F
.56324 .6303 m .54757 .63318 L .54658 .63503 L .333 0 0 r
F
.56324 .6303 m .56445 .62842 L .54757 .63318 L F
.31822 .54837 m .30473 .53763 L .3048 .54075 L 1 .796 0 r
F
.31835 .55147 m .31822 .54837 L .3048 .54075 L 1 .78 0 r
F
.61478 .45667 m .60396 .46055 L .60469 .46323 L .328 .074 0 r
F
.61478 .45667 m .61399 .45402 L .60396 .46055 L F
.40463 .36421 m .40201 .36104 L .39991 .36289 L .985 1 0 r
F
.40463 .36421 m .4067 .36244 L .40201 .36104 L F
.37232 .37861 m .36918 .37278 L .36675 .37454 L 1 1 0 r
F
.37232 .37861 m .37456 .37666 L .36918 .37278 L F
.61027 .44919 m .5998 .45293 L .6006 .45556 L .332 .077 0 r
F
.61027 .44919 m .6094 .44659 L .5998 .45293 L F
.65174 .85867 m .62786 .86109 L .62475 .86439 L .26 0 0 r
F
.65174 .85867 m .65543 .85525 L .62786 .86109 L F
.55979 .36431 m .55227 .36588 L .55399 .36838 L .403 .379 0 r
F
.56165 .36666 m .55979 .36431 L .55399 .36838 L .41 .389 0 r
F
.75284 .56885 m .73852 .57629 L .73748 .58082 L .002 0 0 r
F
.75284 .56885 m .75393 .56423 L .73852 .57629 L F
.60866 .51608 m .59624 .51945 L .59618 .52201 L .334 .049 0 r
F
.60866 .51608 m .60873 .5135 L .59624 .51945 L F
.40896 .84689 m .37816 .84729 L .37998 .85049 L .764 .051 0 r
F
.41019 .85 m .40896 .84689 L .37998 .85049 L .744 .047 0 r
F
.43853 .84451 m .40896 .84689 L .41019 .85 L .675 .041 0 r
F
.33338 .51649 m .31919 .50722 L .3192 .51003 L 1 .824 0 r
F
.33344 .51925 m .33338 .51649 L .3192 .51003 L 1 .811 0 r
F
.50298 .61586 m .48614 .61521 L .48596 .61695 L .756 .063 0 r
F
.50298 .61586 m .50336 .61413 L .48614 .61521 L F
.50264 .61113 m .48597 .61041 L .48579 .61208 L .758 .062 0 r
F
.50264 .61113 m .50301 .60945 L .48597 .61041 L F
.34574 .49031 m .33448 .48146 L .33402 .48408 L 1 .977 0 r
F
.34536 .49293 m .34574 .49031 L .33402 .48408 L 1 .967 0 r
F
.58445 .89166 m .55819 .89203 L .55611 .89481 L .38 0 0 r
F
.58445 .89166 m .58722 .88881 L .55819 .89203 L F
.1428 .74423 m .11359 .72597 L .11659 .73197 L 1 .237 0 r
F
.14564 .74998 m .1428 .74423 L .11659 .73197 L 1 .208 0 r
F
.31376 .47246 m .305 .4618 L .30401 .46477 L 1 1 0 r
F
.31288 .4755 m .31376 .47246 L .30401 .46477 L F
.55793 .36193 m .55056 .36333 L .55227 .36588 L .395 .365 0 r
F
.55979 .36431 m .55793 .36193 L .55227 .36588 L .403 .379 0 r
F
.55246 .88974 m .52559 .88977 L .52421 .89228 L .407 0 0 r
F
.55246 .88974 m .55456 .8872 L .52559 .88977 L F
.88672 .56684 m .87076 .57805 L .86991 .58471 L 0 0 0 r
F
.88672 .56684 m .88766 .56006 L .87076 .57805 L F
.32805 .44989 m .31795 .43954 L .31696 .44239 L 1 1 0 r
F
.32719 .45276 m .32805 .44989 L .31696 .44239 L F
.66768 .46845 m .6619 .47389 L .66111 .47737 L 0 0 0 r
F
.66768 .46845 m .66857 .46497 L .6619 .47389 L F
.58944 .27896 m .6584 .16514 L .65701 .17943 L 1 .971 0 r
F
.58944 .27896 m .65604 .15299 L .6584 .16514 L F
.37195 .88298 m .33998 .8767 L .34274 .87981 L .764 .04 0 r
F
.3741 .88588 m .37195 .88298 L .34274 .87981 L .737 .035 0 r
F
.61108 .52201 m .59828 .52535 L .59817 .52794 L .338 .048 0 r
F
.61108 .52201 m .6112 .51939 L .59828 .52535 L F
.61109 .4518 m .6006 .45556 L .60136 .4582 L .328 .075 0 r
F
.61109 .4518 m .61027 .44919 L .6006 .45556 L F
.71822 .63712 m .70195 .64293 L .7003 .64701 L .085 0 0 r
F
.71822 .63712 m .7201 .63299 L .70195 .64293 L F
.35813 .53971 m .34404 .53173 L .34425 .53424 L 1 .745 0 r
F
.35835 .54219 m .35813 .53971 L .34425 .53424 L 1 .729 0 r
F
.56564 .78418 m .54558 .79305 L .54422 .79624 L .139 0 0 r
F
.56564 .78418 m .56746 .78125 L .54558 .79305 L F
.61554 .45933 m .60469 .46323 L .60538 .46591 L .324 .072 0 r
F
.61554 .45933 m .61478 .45667 L .60469 .46323 L F
.4154 .59789 m .39836 .59316 L .39897 .59512 L 1 .328 0 r
F
.41589 .59978 m .4154 .59789 L .39897 .59512 L 1 .308 0 r
F
.54137 .80227 m .51937 .81096 L .5184 .81411 L .235 0 0 r
F
.54137 .80227 m .54282 .79931 L .51937 .81096 L F
.37282 .37913 m .37686 .38088 L .37488 .38277 L 0 0 0 r
F
.37282 .37913 m .37526 .37742 L .37685 .38085 L F
.37282 .37913 m .37685 .38085 L .37683 .38087 L F
.37473 .38261 m .37182 .37527 L .36979 .37714 L 1 1 0 r
F
.37488 .38277 m .37479 .38256 L .37473 .38261 L F
.37479 .38256 m .37182 .37527 L .37473 .38261 L F
.37683 .38087 m .37685 .38085 L .37686 .38088 L 0 0 0 r
F
.55607 .35949 m .54886 .36071 L .55056 .36333 L .387 .346 0 r
F
.55793 .36193 m .55607 .35949 L .55056 .36333 L .395 .365 0 r
F
.8995 .40847 m .88586 .42251 L .88758 .42935 L 0 .008 0 r
F
.8995 .40847 m .89769 .4016 L .88586 .42251 L F
.37692 .56823 m .3613 .56139 L .36181 .5637 L 1 .57 0 r
F
.37739 .57049 m .37692 .56823 L .36181 .5637 L 1 .552 0 r
F
.42735 .34724 m .42548 .34683 L .42316 .34796 L .551 .313 0 r
F
.42735 .34724 m .42947 .34596 L .42548 .34683 L F
.4337 .60544 m .41639 .60164 L .41691 .60346 L 1 .239 0 r
F
.43407 .6072 m .4337 .60544 L .41691 .60346 L 1 .218 0 r
F
.84966 .69212 m .82914 .69983 L .82672 .70595 L .015 0 0 r
F
.84966 .69212 m .85228 .68581 L .82914 .69983 L F
.37456 .37666 m .37163 .37107 L .36918 .37278 L 1 1 0 r
F
.37456 .37666 m .37683 .37476 L .37163 .37107 L F
.19959 .80299 m .16834 .78835 L .17199 .79354 L 1 .094 0 r
F
.20294 .80792 m .19959 .80299 L .17199 .79354 L 1 .091 0 r
F
.33509 .87987 m .30251 .87207 L .30584 .87554 L .82 .048 0 r
F
.33785 .88312 m .33509 .87987 L .30584 .87554 L .792 .044 0 r
F
.55598 .59555 m .54067 .59674 L .54007 .59873 L .528 .044 0 r
F
.55598 .59555 m .55673 .59353 L .54067 .59674 L F
.37388 .57953 m .35661 .57338 L .35728 .57574 L 1 .503 0 r
F
.37447 .58182 m .37388 .57953 L .35728 .57574 L 1 .487 0 r
F
.55497 .5912 m .53988 .59248 L .53929 .59442 L .522 .043 0 r
F
.55497 .5912 m .5557 .58923 L .53988 .59248 L F
.38563 .63828 m .36624 .63218 L .36721 .6347 L 1 .297 0 r
F
.38649 .64064 m .38563 .63828 L .36721 .6347 L 1 .277 0 r
F
.55422 .35699 m .54717 .35799 L .54886 .36071 L .378 .321 0 r
F
.55607 .35949 m .55422 .35699 L .54886 .36071 L .387 .346 0 r
F
.59401 .558 m .58013 .56057 L .57966 .56295 L .379 .04 0 r
F
.59401 .558 m .59456 .55559 L .58013 .56057 L F
.51954 .60778 m .50337 .60775 L .50301 .60945 L .68 .055 0 r
F
.51954 .60778 m .52008 .60606 L .50337 .60775 L F
.42611 .35109 m .42379 .34971 L .42157 .35105 L .756 .836 0 r
F
.42611 .35109 m .42813 .34959 L .42379 .34971 L F
.45107 .61552 m .43329 .61296 L .43367 .61478 L .96 .166 0 r
F
.45128 .61728 m .45107 .61552 L .43367 .61478 L .951 .145 0 r
F
.46865 .61741 m .45107 .61552 L .45128 .61728 L .895 .101 0 r
F
.52006 .61239 m .50372 .61236 L .50336 .61413 L .68 .055 0 r
F
.52006 .61239 m .52061 .61061 L .50372 .61236 L F
.54882 .34884 m .54236 .34891 L .54391 .35215 L .334 .189 0 r
F
.54882 .34884 m .54712 .34576 L .54236 .34891 L F
.74322 .35575 m .74128 .35114 L .75225 .35764 L .969 .123 0 r
F
.25333 .83266 m .22169 .82076 L .22538 .82524 L .976 .077 0 r
F
.25665 .83689 m .25333 .83266 L .22538 .82524 L .953 .073 0 r
F
.40945 .35614 m .4073 .35345 L .40489 .35485 L .837 .981 0 r
F
.40945 .35614 m .41171 .35462 L .4073 .35345 L F
.55239 .35441 m .54552 .35515 L .54717 .35799 L .367 .288 0 r
F
.55422 .35699 m .55239 .35441 L .54717 .35799 L .378 .321 0 r
F
.44879 .65702 m .42887 .65501 L .42943 .65691 L .85 .064 0 r
F
.44909 .65877 m .44879 .65702 L .42943 .65691 L .833 .061 0 r
F
.46822 .65794 m .44879 .65702 L .44909 .65877 L .747 .049 0 r
F
.61188 .45441 m .60136 .4582 L .60209 .46084 L .324 .073 0 r
F
.61188 .45441 m .61109 .4518 L .60136 .4582 L F
.34536 .49293 m .33402 .48408 L .3336 .4867 L 1 .967 0 r
F
.34501 .49556 m .34536 .49293 L .3336 .4867 L 1 .956 0 r
F
.31288 .4755 m .30401 .46477 L .30307 .46776 L 1 1 0 r
F
.31205 .47855 m .31288 .4755 L .30307 .46776 L F
.32719 .45276 m .31696 .44239 L .31603 .44525 L F
.32637 .45563 m .32719 .45276 L .31603 .44525 L F
.64951 .52509 m .64055 .53076 L .63975 .53372 L 0 0 0 r
F
.64951 .52509 m .65033 .52211 L .64055 .53076 L F
.55058 .3517 m .54391 .35215 L .54552 .35515 L .352 .244 0 r
F
.55058 .3517 m .54882 .34884 L .54391 .35215 L F
.55239 .35441 m .55058 .3517 L .54552 .35515 L .367 .288 0 r
F
.52374 .90224 m .49554 .90112 L .49486 .90361 L .462 0 0 r
F
.52374 .90224 m .52516 .89973 L .49554 .90112 L F
.69922 .14362 m .69531 .1559 L .70006 .16082 L .215 .172 0 r
F
.69922 .14362 m .69395 .13965 L .69531 .1559 L F
.61625 .462 m .60538 .46591 L .60604 .46859 L .32 .07 0 r
F
.61625 .462 m .61554 .45933 L .60538 .46591 L F
.4067 .36244 m .40412 .35923 L .40201 .36104 L .994 1 0 r
F
.4067 .36244 m .40877 .36068 L .40412 .35923 L F
.33907 .59433 m .3226 .58493 L .32324 .5879 L 1 .585 0 r
F
.33972 .59722 m .33907 .59433 L .32324 .5879 L 1 .567 0 r
F
.35274 .55628 m .33648 .54869 L .33697 .55127 L 1 .633 0 r
F
.35321 .55878 m .35274 .55628 L .33697 .55127 L 1 .618 0 r
F
.6284 .56732 m .61685 .57243 L .61583 .57505 L .084 0 0 r
F
.6284 .56732 m .62949 .56466 L .61685 .57243 L F
.60855 .51865 m .59618 .52201 L .59608 .52457 L .33 .046 0 r
F
.60855 .51865 m .60866 .51608 L .59618 .52201 L F
.59211 .55409 m .57859 .55675 L .57812 .55909 L .372 .039 0 r
F
.59211 .55409 m .59263 .55173 L .57859 .55675 L F
.39477 .59567 m .37709 .59071 L .37781 .59287 L 1 .393 0 r
F
.39537 .59776 m .39477 .59567 L .37781 .59287 L 1 .375 0 r
F
.77057 .47369 m .76246 .48258 L .76244 .48752 L 0 0 0 r
F
.77057 .47369 m .77036 .46876 L .76246 .48258 L F
.50536 .65386 m .48734 .65471 L .48707 .6563 L .538 .021 0 r
F
.50536 .65386 m .50592 .65231 L .48734 .65471 L F
.5747 .58116 m .56007 .58301 L .55946 .58517 L .445 .04 0 r
F
.5747 .58116 m .57543 .57897 L .56007 .58301 L F
.41446 .60589 m .39663 .60187 L .39729 .60387 L 1 .304 0 r
F
.41498 .60783 m .41446 .60589 L .39729 .60387 L 1 .284 0 r
F
.45143 .61015 m .43407 .6072 L .43445 .60894 L .971 .161 0 r
F
.45163 .61183 m .45143 .61015 L .43445 .60894 L .962 .141 0 r
F
.4687 .61231 m .45143 .61015 L .45163 .61183 L .902 .097 0 r
F
.33344 .51925 m .3192 .51003 L .31925 .51284 L 1 .811 0 r
F
.33353 .522 m .33344 .51925 L .31925 .51284 L 1 .798 0 r
F
.58361 .61693 m .56907 .6205 L .56795 .62254 L .264 0 0 r
F
.58361 .61693 m .58491 .61485 L .56907 .6205 L F
.31835 .55147 m .3048 .54075 L .30492 .54387 L 1 .78 0 r
F
.31853 .55456 m .31835 .55147 L .30492 .54387 L 1 .764 0 r
F
.37683 .37476 m .37409 .3694 L .37163 .37107 L 1 1 0 r
F
.37683 .37476 m .37911 .3729 L .37409 .3694 L F
.73022 .13498 m .72721 .14737 L .73315 .15132 L .212 .219 0 r
F
.73022 .13498 m .72424 .13141 L .72721 .14737 L F
.39665 .58712 m .38017 .58141 L .3808 .58352 L 1 .427 0 r
F
.3972 .58916 m .39665 .58712 L .3808 .58352 L 1 .407 0 r
F
.36266 .62186 m .34436 .61413 L .34526 .61688 L 1 .426 0 r
F
.36351 .62448 m .36266 .62186 L .34526 .61688 L 1 .407 0 r
F
.37526 .37742 m .37888 .37903 L .37686 .38088 L 0 0 0 r
F
.37526 .37742 m .37778 .37583 L .37887 .37899 L F
.37526 .37742 m .37887 .37899 L .37884 .37901 L F
.37667 .38066 m .37387 .37341 L .37182 .37527 L 1 1 0 r
F
.37686 .38088 m .37675 .3806 L .37667 .38066 L F
.37675 .3806 m .37387 .37341 L .37667 .38066 L F
.37884 .37901 m .37887 .37899 L .37888 .37903 L 0 0 0 r
F
.89542 .5758 m .87726 .58663 L .87643 .59344 L F
.89542 .5758 m .8963 .56883 L .87726 .58663 L F
.61262 .45703 m .60209 .46084 L .60278 .46348 L .32 .071 0 r
F
.61262 .45703 m .61188 .45441 L .60209 .46084 L F
.57332 .57697 m .55897 .57892 L .55837 .58104 L .437 .039 0 r
F
.57332 .57697 m .57403 .57482 L .55897 .57892 L F
.26231 .80916 m .23007 .80033 L .23348 .8047 L 1 .086 0 r
F
.26531 .81332 m .26231 .80916 L .23348 .8047 L 1 .083 0 r
F
.53672 .60189 m .52111 .60251 L .5206 .6043 L .599 .047 0 r
F
.53672 .60189 m .53739 .60007 L .52111 .60251 L F
.73656 .80773 m .71476 .81224 L .71125 .81663 L .132 0 0 r
F
.73656 .80773 m .74048 .80318 L .71476 .81224 L F
.53745 .60638 m .52166 .60695 L .52114 .6088 L .602 .048 0 r
F
.53745 .60638 m .53814 .60451 L .52166 .60695 L F
.61506 .8737 m .59036 .8753 L .58771 .87822 L .309 0 0 r
F
.61506 .8737 m .61834 .8707 L .59036 .8753 L F
.42887 .65501 m .40887 .65185 L .40965 .65391 L .939 .077 0 r
F
.42943 .65691 m .42887 .65501 L .40965 .65391 L .925 .074 0 r
F
.61091 .52462 m .59817 .52794 L .59803 .53053 L .334 .046 0 r
F
.61091 .52462 m .61108 .52201 L .59817 .52794 L F
.32637 .45563 m .31603 .44525 L .31513 .44811 L 1 1 0 r
F
.32559 .4585 m .32637 .45563 L .31513 .44811 L F
.10469 .635 m .07948 .6137 L .08101 .62016 L 1 .497 0 r
F
.10622 .64122 m .10469 .635 L .08101 .62016 L 1 .471 0 r
F
.61692 .46467 m .60604 .46859 L .60666 .47128 L .316 .068 0 r
F
.61692 .46467 m .61625 .462 L .60604 .46859 L F
.46628 .84017 m .46624 .83712 L .43853 .84451 L .554 .026 0 r
F
.4922 .83094 m .46624 .83712 L .46628 .84017 L .426 .01 0 r
F
.4922 .83094 m .49271 .82792 L .46624 .83712 L F
.89451 .40931 m .88164 .4231 L .88311 .4299 L 0 0 0 r
F
.89451 .40931 m .89305 .40246 L .88164 .4231 L F
.31205 .47855 m .30307 .46776 L .30218 .47077 L 1 1 0 r
F
.31126 .48161 m .31205 .47855 L .30218 .47077 L F
.46568 .89703 m .46561 .89463 L .43606 .89444 L .553 .009 0 r
F
.49445 .8963 m .46561 .89463 L .46568 .89703 L .494 .001 0 r
F
.49445 .8963 m .49512 .89391 L .46561 .89463 L F
.34501 .49556 m .3336 .4867 L .33321 .48932 L 1 .956 0 r
F
.3447 .49818 m .34501 .49556 L .33321 .48932 L 1 .944 0 r
F
.35835 .54219 m .34425 .53424 L .34449 .53674 L 1 .729 0 r
F
.3586 .54465 m .35835 .54219 L .34449 .53674 L 1 .714 0 r
F
.46866 .61912 m .46865 .61741 L .45128 .61728 L .885 .082 0 r
F
.48577 .61865 m .46865 .61741 L .46866 .61912 L .821 .069 0 r
F
.48577 .61865 m .48596 .61695 L .46865 .61741 L F
.68682 .40778 m .6832 .41278 L .6818 .41741 L 0 0 0 r
F
.68682 .40778 m .6883 .40309 L .6832 .41278 L F
.60541 .59727 m .59217 .60159 L .59103 .60389 L .185 0 0 r
F
.60541 .59727 m .60669 .59493 L .59217 .60159 L F
.09556 .64592 m .0717 .62349 L .07321 .63015 L 1 .468 0 r
F
.09707 .65237 m .09556 .64592 L .07321 .63015 L 1 .44 0 r
F
.79294 .76947 m .7713 .77489 L .76802 .78016 L .089 0 0 r
F
.79294 .76947 m .79655 .76402 L .7713 .77489 L F
.61333 .45966 m .60278 .46348 L .60344 .46612 L .316 .069 0 r
F
.61333 .45966 m .61262 .45703 L .60278 .46348 L F
.46872 .61394 m .4687 .61231 L .45163 .61183 L .893 .078 0 r
F
.48561 .61371 m .4687 .61231 L .46872 .61394 L .825 .069 0 r
F
.48561 .61371 m .48579 .61208 L .4687 .61231 L F
.29606 .86484 m .26357 .85528 L .26726 .85919 L .882 .059 0 r
F
.29925 .8685 m .29606 .86484 L .26726 .85919 L .856 .055 0 r
F
.52365 .64914 m .50647 .65071 L .50592 .65231 L .438 .008 0 r
F
.52365 .64914 m .52448 .64756 L .50647 .65071 L F
.37911 .3729 m .37656 .36777 L .37409 .3694 L 1 1 0 r
F
.37911 .3729 m .3814 .37108 L .37656 .36777 L F
.43917 .84755 m .43853 .84451 L .41019 .85 L .652 .037 0 r
F
.46628 .84017 m .43853 .84451 L .43917 .84755 L .554 .026 0 r
F
.72745 .13868 m .72548 .14962 L .73152 .15337 L .199 .229 0 r
F
.72745 .13868 m .72126 .13554 L .72548 .14962 L F
.43329 .61296 m .41551 .60975 L .41606 .61162 L 1 .22 0 r
F
.43367 .61478 m .43329 .61296 L .41606 .61162 L 1 .199 0 r
F
.40877 .36068 m .40627 .35745 L .40412 .35923 L .994 1 0 r
F
.40877 .36068 m .41085 .35894 L .40627 .35745 L F
.58227 .88373 m .55662 .88456 L .55456 .8872 L .357 0 0 r
F
.58227 .88373 m .58501 .88102 L .55662 .88456 L F
.4043 .89742 m .37253 .89243 L .37475 .89527 L .695 .029 0 r
F
.40584 .90009 m .4043 .89742 L .37475 .89527 L .666 .024 0 r
F
.43548 .90131 m .4043 .89742 L .40584 .90009 L .638 .021 0 r
F
.66682 .47188 m .66111 .47737 L .66032 .48081 L 0 0 0 r
F
.66682 .47188 m .66768 .46845 L .66111 .47737 L F
.40811 .64975 m .38828 .64527 L .38921 .64754 L 1 .167 0 r
F
.40887 .65185 m .40811 .64975 L .38921 .64754 L 1 .145 0 r
F
.41171 .35462 m .40972 .35211 L .4073 .35345 L .803 .947 0 r
F
.41171 .35462 m .41397 .35317 L .40972 .35211 L F
.37739 .57049 m .36181 .5637 L .36236 .56599 L 1 .552 0 r
F
.37789 .57272 m .37739 .57049 L .36236 .56599 L 1 .534 0 r
F
.61756 .46734 m .60666 .47128 L .60724 .47397 L .312 .066 0 r
F
.61756 .46734 m .61692 .46467 L .60666 .47128 L F
.32559 .4585 m .31513 .44811 L .31429 .45098 L 1 1 0 r
F
.32486 .46138 m .32559 .4585 L .31429 .45098 L F
.6084 .52121 m .59608 .52457 L .59594 .52711 L .325 .044 0 r
F
.6084 .52121 m .60855 .51865 L .59608 .52457 L F
.59343 .56039 m .57966 .56295 L .57915 .5653 L .374 .038 0 r
F
.59343 .56039 m .59401 .558 L .57966 .56295 L F
.33727 .87349 m .30525 .86574 L .30851 .86917 L .821 .049 0 r
F
.33998 .8767 m .33727 .87349 L .30851 .86917 L .794 .044 0 r
F
.14945 .73889 m .12124 .72072 L .12411 .72665 L 1 .244 0 r
F
.15218 .74457 m .14945 .73889 L .12411 .72665 L 1 .215 0 r
F
.37778 .37583 m .38093 .37721 L .37888 .37903 L 0 0 0 r
F
.37778 .37583 m .38037 .37437 L .38093 .37721 L F
.31126 .48161 m .30218 .47077 L .30133 .47378 L 1 1 0 r
F
.31052 .48468 m .31126 .48161 L .30133 .47378 L F
.54244 .64202 m .52611 .64425 L .5253 .64593 L .382 0 0 r
F
.54244 .64202 m .5435 .64034 L .52611 .64425 L F
.75168 .57345 m .73748 .58082 L .73639 .58533 L 0 0 0 r
F
.75168 .57345 m .75284 .56885 L .73748 .58082 L F
.42813 .34959 m .42604 .34846 L .42379 .34971 L .681 .725 0 r
F
.42813 .34959 m .43016 .34817 L .42604 .34846 L F
.15939 .72338 m .13002 .70709 L .1328 .7128 L 1 .294 0 r
F
.16201 .72882 m .15939 .72338 L .1328 .7128 L 1 .268 0 r
F
.3447 .49818 m .33321 .48932 L .33287 .49194 L 1 .944 0 r
F
.34443 .5008 m .3447 .49818 L .33287 .49194 L 1 .932 0 r
F
.33353 .522 m .31925 .51284 L .31934 .51563 L 1 .798 0 r
F
.33367 .52473 m .33353 .522 L .31934 .51563 L 1 .784 0 r
F
.42947 .34596 m .42781 .34577 L .42548 .34683 L .5 .217 0 r
F
.37447 .58182 m .35728 .57574 L .35799 .57807 L 1 .487 0 r
F
.37509 .58408 m .37447 .58182 L .35799 .57807 L 1 .469 0 r
F
.37816 .84729 m .34676 .84572 L .34917 .84903 L .829 .057 0 r
F
.37998 .85049 m .37816 .84729 L .34917 .84903 L .81 .054 0 r
F
.61399 .46229 m .60344 .46612 L .60406 .46877 L .311 .067 0 r
F
.61399 .46229 m .61333 .45966 L .60344 .46612 L F
.20453 .79713 m .1741 .7825 L .17763 .78765 L 1 .095 0 r
F
.20779 .80201 m .20453 .79713 L .17763 .78765 L 1 .092 0 r
F
.50226 .61276 m .48579 .61208 L .48561 .61371 L .748 .06 0 r
F
.50226 .61276 m .50264 .61113 L .48579 .61208 L F
.5026 .61756 m .48596 .61695 L .48577 .61865 L .745 .06 0 r
F
.5026 .61756 m .50298 .61586 L .48596 .61695 L F
.41589 .59978 m .39897 .59512 L .3996 .59704 L 1 .308 0 r
F
.41639 .60164 m .41589 .59978 L .3996 .59704 L 1 .287 0 r
F
.35321 .55878 m .33697 .55127 L .3375 .55383 L 1 .618 0 r
F
.3537 .56127 m .35321 .55878 L .3375 .55383 L 1 .603 0 r
F
.84099 .68726 m .82216 .69556 L .8197 .7015 L 0 0 0 r
F
.84099 .68726 m .84363 .68115 L .82216 .69556 L F
.59155 .55644 m .57812 .55909 L .57763 .5614 L .368 .037 0 r
F
.59155 .55644 m .59211 .55409 L .57812 .55909 L F
.74515 .36036 m .74322 .35575 L .75342 .36294 L .913 .119 0 r
F
.31853 .55456 m .30492 .54387 L .30507 .54698 L 1 .764 0 r
F
.31875 .55764 m .31853 .55456 L .30507 .54698 L 1 .748 0 r
F
.61071 .52721 m .59803 .53053 L .59784 .5331 L .329 .043 0 r
F
.61071 .52721 m .61091 .52462 L .59803 .53053 L F
.64866 .52804 m .63975 .53372 L .63893 .53667 L 0 0 0 r
F
.64866 .52804 m .64951 .52509 L .63975 .53372 L F
.68019 .68545 m .66373 .6909 L .66176 .69457 L .096 0 0 r
F
.68019 .68545 m .68251 .68183 L .66373 .6909 L F
.55521 .59753 m .54007 .59873 L .53945 .60069 L .518 .041 0 r
F
.55521 .59753 m .55598 .59555 L .54007 .59873 L F
.55422 .59315 m .53929 .59442 L .53868 .59634 L .512 .041 0 r
F
.55422 .59315 m .55497 .5912 L .53929 .59442 L F
.08804 .65652 m .06291 .63401 L .06468 .64077 L 1 .436 0 r
F
.08979 .66306 m .08804 .65652 L .06468 .64077 L 1 .407 0 r
F
.3814 .37108 m .37904 .36618 L .37656 .36777 L 1 1 0 r
F
.3814 .37108 m .38371 .36929 L .37904 .36618 L F
.5228 .89467 m .49512 .89391 L .49445 .8963 L .447 0 0 r
F
.5228 .89467 m .52421 .89228 L .49512 .89391 L F
.562 .63214 m .54658 .63503 L .54557 .63684 L .322 0 0 r
F
.562 .63214 m .56324 .6303 L .54658 .63503 L F
.4363 .90382 m .43548 .90131 L .40584 .90009 L .609 .016 0 r
F
.46558 .90414 m .43548 .90131 L .4363 .90382 L .568 .011 0 r
F
.61815 .47002 m .60724 .47397 L .60778 .47666 L .308 .064 0 r
F
.61815 .47002 m .61756 .46734 L .60724 .47397 L F
.21416 .77741 m .18282 .7653 L .18615 .77027 L 1 .161 0 r
F
.21718 .78213 m .21416 .77741 L .18615 .77027 L 1 .136 0 r
F
.43407 .6072 m .41691 .60346 L .41745 .60526 L 1 .218 0 r
F
.43445 .60894 m .43407 .6072 L .41745 .60526 L 1 .197 0 r
F
.32486 .46138 m .31429 .45098 L .3135 .45386 L 1 1 0 r
F
.32418 .46426 m .32486 .46138 L .3135 .45386 L F
.90118 .41536 m .88758 .42935 L .88918 .43621 L 0 .004 0 r
F
.90118 .41536 m .8995 .40847 L .88758 .42935 L F
.33972 .59722 m .32324 .5879 L .32392 .59086 L 1 .567 0 r
F
.3404 .60008 m .33972 .59722 L .32392 .59086 L 1 .549 0 r
F
.3586 .54465 m .34449 .53674 L .34478 .53923 L 1 .714 0 r
F
.35889 .5471 m .3586 .54465 L .34478 .53923 L 1 .697 0 r
F
.46824 .65956 m .46822 .65794 L .44909 .65877 L .727 .046 0 r
F
.4868 .65785 m .46822 .65794 L .46824 .65956 L .627 .032 0 r
F
.4868 .65785 m .48707 .6563 L .46822 .65794 L F
.57395 .58332 m .55946 .58517 L .55881 .5873 L .436 .037 0 r
F
.57395 .58332 m .5747 .58116 L .55946 .58517 L F
.51899 .60947 m .50301 .60945 L .50264 .61113 L .669 .052 0 r
F
.51899 .60947 m .51954 .60778 L .50301 .60945 L F
.69319 .84887 m .66994 .85162 L .66643 .8555 L .223 0 0 r
F
.69319 .84887 m .6972 .84485 L .66994 .85162 L F
.31052 .48468 m .30133 .47378 L .30053 .47681 L 1 1 0 r
F
.30982 .48776 m .31052 .48468 L .30053 .47681 L F
.61462 .46492 m .60406 .46877 L .60464 .47142 L .307 .065 0 r
F
.61462 .46492 m .61399 .46229 L .60406 .46877 L F
.62728 .56995 m .61583 .57505 L .61479 .57764 L .077 0 0 r
F
.62728 .56995 m .6284 .56732 L .61583 .57505 L F
.77072 .47861 m .76244 .48752 L .76236 .49244 L 0 0 0 r
F
.77072 .47861 m .77057 .47369 L .76244 .48752 L F
.5195 .61413 m .50336 .61413 L .50298 .61586 L .669 .052 0 r
F
.5195 .61413 m .52006 .61239 L .50336 .61413 L F
.41085 .35894 m .40845 .35574 L .40627 .35745 L .985 1 0 r
F
.41085 .35894 m .41295 .35724 L .40845 .35574 L F
.45128 .61728 m .43367 .61478 L .43406 .61656 L .951 .145 0 r
F
.45149 .619 m .45128 .61728 L .43406 .61656 L .941 .124 0 r
F
.46866 .61912 m .45128 .61728 L .45149 .619 L .885 .082 0 r
F
.39537 .59776 m .37781 .59287 L .37855 .595 L 1 .375 0 r
F
.39599 .59983 m .39537 .59776 L .37855 .595 L 1 .355 0 r
F
.57258 .57909 m .55837 .58104 L .55774 .58313 L .427 .036 0 r
F
.57258 .57909 m .57332 .57697 L .55837 .58104 L F
.71626 .6412 m .7003 .64701 L .69859 .65105 L .072 0 0 r
F
.71626 .6412 m .71822 .63712 L .7003 .64701 L F
.3972 .58916 m .3808 .58352 L .38147 .5856 L 1 .407 0 r
F
.39777 .59118 m .3972 .58916 L .38147 .5856 L 1 .387 0 r
F
.88566 .57361 m .86991 .58471 L .86894 .59135 L 0 0 0 r
F
.88566 .57361 m .88672 .56684 L .86991 .58471 L F
.34443 .5008 m .33287 .49194 L .33257 .49456 L 1 .932 0 r
F
.34419 .50342 m .34443 .5008 L .33257 .49456 L 1 .92 0 r
F
.60821 .52376 m .59594 .52711 L .59577 .52964 L .32 .042 0 r
F
.60821 .52376 m .6084 .52121 L .59594 .52711 L F
.38649 .64064 m .36721 .6347 L .36821 .63719 L 1 .277 0 r
F
.38737 .64297 m .38649 .64064 L .36821 .63719 L 1 .256 0 r
F
.38037 .37437 m .38301 .37543 L .38093 .37721 L 0 0 0 r
F
.38037 .37437 m .38303 .37305 L .38301 .37543 L F
.41498 .60783 m .39729 .60387 L .39797 .60585 L 1 .284 0 r
F
.41551 .60975 m .41498 .60783 L .39797 .60585 L 1 .263 0 r
F
.61633 .74395 m .59924 .75127 L .59732 .75451 L .044 0 0 r
F
.61633 .74395 m .6187 .74096 L .59924 .75127 L F
.6187 .4727 m .60778 .47666 L .60829 .47935 L .304 .062 0 r
F
.6187 .4727 m .61815 .47002 L .60778 .47666 L F
.3444 .84233 m .3125 .83866 L .31541 .84218 L .893 .064 0 r
F
.34676 .84572 m .3444 .84233 L .31541 .84218 L .875 .061 0 r
F
.38371 .36929 m .38153 .36461 L .37904 .36618 L .994 1 0 r
F
.38371 .36929 m .38603 .36755 L .38153 .36461 L F
.70422 .14792 m .70006 .16082 L .70441 .16618 L .194 .117 0 r
F
.70422 .14792 m .69922 .14362 L .70006 .16082 L F
.41397 .35317 m .41215 .35083 L .40972 .35211 L .765 .906 0 r
F
.41397 .35317 m .41625 .35177 L .41215 .35083 L F
.73609 .1387 m .73315 .15132 L .73899 .1554 L .194 .187 0 r
F
.73609 .1387 m .73022 .13498 L .73315 .15132 L F
.45163 .61183 m .43445 .60894 L .43484 .61063 L .962 .141 0 r
F
.45184 .61347 m .45163 .61183 L .43484 .61063 L .952 .12 0 r
F
.46872 .61394 m .45163 .61183 L .45184 .61347 L .893 .078 0 r
F
.64608 .71862 m .62954 .72475 L .6275 .72815 L .07 0 0 r
F
.64608 .71862 m .64853 .71538 L .62954 .72475 L F
.32418 .46426 m .3135 .45386 L .31275 .45674 L 1 1 0 r
F
.32354 .46714 m .32418 .46426 L .31275 .45674 L F
.29891 .85858 m .26703 .84904 L .27064 .85291 L .886 .06 0 r
F
.30205 .86221 m .29891 .85858 L .27064 .85291 L .86 .056 0 r
F
.36351 .62448 m .34526 .61688 L .3462 .61961 L 1 .407 0 r
F
.36439 .62707 m .36351 .62448 L .3462 .61961 L 1 .387 0 r
F
.33367 .52473 m .31934 .51563 L .31948 .51841 L 1 .784 0 r
F
.33383 .52746 m .33367 .52473 L .31948 .51841 L 1 .77 0 r
F
.53603 .60367 m .5206 .6043 L .52008 .60606 L .588 .045 0 r
F
.53603 .60367 m .53672 .60189 L .5206 .6043 L F
.54836 .31154 m .55002 .29744 L .54891 .30912 L .95 .189 0 r
F
.54836 .31154 m .54834 .30282 L .55002 .29744 L F
.6152 .46755 m .60464 .47142 L .60518 .47407 L .302 .063 0 r
F
.6152 .46755 m .61462 .46492 L .60464 .47142 L F
.37421 .33852 m .36473 .31965 L .36592 .32788 L .976 .129 0 r
F
.37803 .34972 m .37421 .33852 L .36592 .32788 L 1 .291 0 r
F
.40538 .89074 m .3741 .88588 L .37629 .88867 L .69 .028 0 r
F
.4069 .89335 m .40538 .89074 L .37629 .88867 L .661 .023 0 r
F
.43606 .89444 m .40538 .89074 L .4069 .89335 L .629 .02 0 r
F
.53674 .60821 m .52114 .6088 L .52061 .61061 L .591 .045 0 r
F
.53674 .60821 m .53745 .60638 L .52114 .6088 L F
.59281 .56275 m .57915 .5653 L .57861 .56764 L .37 .036 0 r
F
.59281 .56275 m .59343 .56039 L .57915 .5653 L F
.37789 .57272 m .36236 .56599 L .36294 .56826 L 1 .534 0 r
F
.37842 .57493 m .37789 .57272 L .36294 .56826 L 1 .515 0 r
F
.61046 .5298 m .59784 .5331 L .59762 .53566 L .324 .041 0 r
F
.61046 .5298 m .61071 .52721 L .59784 .5331 L F
.58228 .61897 m .56795 .62254 L .56681 .62454 L .254 0 0 r
F
.58228 .61897 m .58361 .61693 L .56795 .62254 L F
.30982 .48776 m .30053 .47681 L .29977 .47985 L 1 1 0 r
F
.30916 .49085 m .30982 .48776 L .29977 .47985 L 1 .995 0 r
F
.66598 .47526 m .66032 .48081 L .65955 .4842 L 0 0 0 r
F
.66598 .47526 m .66682 .47188 L .66032 .48081 L F
.78581 .76306 m .76539 .76909 L .76211 .77419 L .048 0 0 r
F
.78581 .76306 m .7894 .75779 L .76539 .76909 L F
.89582 .41617 m .88311 .4299 L .88446 .43671 L 0 0 0 r
F
.89582 .41617 m .89451 .40931 L .88311 .4299 L F
.44909 .65877 m .42943 .65691 L .43 .65877 L .833 .061 0 r
F
.4494 .66048 m .44909 .65877 L .43 .65877 L .816 .058 0 r
F
.46824 .65956 m .44909 .65877 L .4494 .66048 L .727 .046 0 r
F
.31875 .55764 m .30507 .54698 L .30528 .55009 L 1 .748 0 r
F
.31901 .56072 m .31875 .55764 L .30528 .55009 L 1 .731 0 r
F
.34419 .50342 m .33257 .49456 L .33231 .49718 L 1 .92 0 r
F
.34399 .50603 m .34419 .50342 L .33231 .49718 L 1 .908 0 r
F
.43016 .34817 m .4283 .3473 L .42604 .34846 L .625 .584 0 r
F
.43016 .34817 m .43221 .34682 L .4283 .3473 L F
.60411 .59959 m .59103 .60389 L .58986 .60616 L .176 0 0 r
F
.60411 .59959 m .60541 .59727 L .59103 .60389 L F
.3537 .56127 m .3375 .55383 L .33806 .55637 L 1 .603 0 r
F
.35422 .56373 m .3537 .56127 L .33806 .55637 L 1 .587 0 r
F
.59096 .55877 m .57763 .5614 L .57711 .5637 L .363 .035 0 r
F
.59096 .55877 m .59155 .55644 L .57763 .5614 L F
.68537 .41235 m .6818 .41741 L .68044 .42192 L 0 0 0 r
F
.68537 .41235 m .68682 .40778 L .6818 .41741 L F
.61921 .47538 m .60829 .47935 L .60876 .48204 L .299 .06 0 r
F
.61921 .47538 m .6187 .4727 L .60829 .47935 L F
.73355 .14198 m .73152 .15337 L .73751 .1572 L .187 .204 0 r
F
.73355 .14198 m .72745 .13868 L .73152 .15337 L F
.46867 .62079 m .46866 .61912 L .45149 .619 L .875 .074 0 r
F
.48558 .62031 m .46866 .61912 L .46867 .62079 L .81 .067 0 r
F
.48558 .62031 m .48577 .61865 L .46866 .61912 L F
.35889 .5471 m .34478 .53923 L .3451 .5417 L 1 .697 0 r
F
.35921 .54952 m .35889 .5471 L .3451 .5417 L 1 .681 0 r
F
.38603 .36755 m .38401 .36307 L .38153 .36461 L .976 1 0 r
F
.38603 .36755 m .38836 .36584 L .38401 .36307 L F
.41295 .35724 m .41068 .35411 L .40845 .35574 L .968 1 0 r
F
.41295 .35724 m .41506 .35558 L .41068 .35411 L F
.37509 .58408 m .35799 .57807 L .35873 .58038 L 1 .469 0 r
F
.37573 .58632 m .37509 .58408 L .35873 .58038 L 1 .452 0 r
F
.30687 .83136 m .27475 .82537 L .27803 .82923 L .956 .073 0 r
F
.30965 .83505 m .30687 .83136 L .27803 .82923 L .938 .07 0 r
F
.84693 .69837 m .82672 .70595 L .82419 .71202 L .006 0 0 r
F
.84693 .69837 m .84966 .69212 L .82672 .70595 L F
.14564 .74998 m .11659 .73197 L .11971 .73792 L 1 .208 0 r
F
.14858 .75566 m .14564 .74998 L .11971 .73792 L 1 .179 0 r
F
.4316 .34474 m .43014 .34477 L .42781 .34577 L .442 .209 0 r
F
.61574 .47019 m .60518 .47407 L .60569 .47672 L .297 .061 0 r
F
.61574 .47019 m .6152 .46755 L .60518 .47407 L F
.32354 .46714 m .31275 .45674 L .31205 .45963 L 1 1 0 r
F
.32295 .47002 m .32354 .46714 L .31205 .45963 L F
.46873 .61554 m .46872 .61394 L .45184 .61347 L .882 .074 0 r
F
.48542 .6153 m .46872 .61394 L .46873 .61554 L .814 .066 0 r
F
.48542 .6153 m .48561 .61371 L .46872 .61394 L F
.65171 .87003 m .62774 .8719 L .62455 .87526 L .276 0 0 r
F
.65171 .87003 m .6555 .86655 L .62774 .8719 L F
.89442 .58275 m .87643 .59344 L .87548 .60023 L 0 0 0 r
F
.89442 .58275 m .89542 .5758 L .87643 .59344 L F
.43367 .61478 m .41606 .61162 L .41662 .61347 L 1 .199 0 r
F
.43406 .61656 m .43367 .61478 L .41662 .61347 L 1 .178 0 r
F
.64779 .53097 m .63893 .53667 L .63809 .53958 L 0 0 0 r
F
.64779 .53097 m .64866 .52804 L .63893 .53667 L F
.43688 .89688 m .43606 .89444 L .4069 .89335 L .6 .015 0 r
F
.46568 .89703 m .43606 .89444 L .43688 .89688 L .553 .009 0 r
F
.50479 .65537 m .48707 .6563 L .4868 .65785 L .515 .016 0 r
F
.50479 .65537 m .50536 .65386 L .48707 .6563 L F
.60798 .5263 m .59577 .52964 L .59556 .53216 L .316 .04 0 r
F
.60798 .5263 m .60821 .52376 L .59577 .52964 L F
.589 .76652 m .57095 .77508 L .56923 .77822 L .038 0 0 r
F
.589 .76652 m .59117 .76367 L .57095 .77508 L F
.53191 .31104 m .54011 .2811 L .53827 .29746 L 1 .696 0 r
F
.5384 .29283 m .55497 .23791 L .54825 .27011 L 1 .96 0 r
F
.5384 .29283 m .54306 .2679 L .55497 .23791 L F
.74706 .36496 m .75459 .3682 L .75574 .37341 L .867 .116 0 r
F
.74706 .36496 m .74515 .36036 L .75459 .3682 L F
.38303 .37305 m .38511 .37368 L .38301 .37543 L 0 0 0 r
F
.38303 .37305 m .38573 .37186 L .38511 .37368 L F
.25295 .84302 m .22101 .83137 L .22488 .8358 L .948 .072 0 r
F
.25642 .8472 m .25295 .84302 L .22488 .8358 L .923 .068 0 r
F
.73834 .81955 m .71607 .82338 L .71246 .82785 L .157 0 0 r
F
.73834 .81955 m .74238 .81491 L .71607 .82338 L F
.42943 .65691 m .40965 .65391 L .41045 .65594 L .925 .074 0 r
F
.43 .65877 m .42943 .65691 L .41045 .65594 L .91 .071 0 r
F
.30916 .49085 m .29977 .47985 L .29907 .4829 L 1 .995 0 r
F
.30855 .49394 m .30916 .49085 L .29907 .4829 L 1 .982 0 r
F
.41639 .60164 m .3996 .59704 L .40026 .59894 L 1 .287 0 r
F
.41691 .60346 m .41639 .60164 L .40026 .59894 L 1 .265 0 r
F
.75045 .57803 m .73639 .58533 L .73523 .58981 L 0 0 0 r
F
.75045 .57803 m .75168 .57345 L .73639 .58533 L F
.10622 .64122 m .08101 .62016 L .08266 .6266 L 1 .471 0 r
F
.10787 .64742 m .10622 .64122 L .08266 .6266 L 1 .446 0 r
F
.55344 .59506 m .53868 .59634 L .53805 .59822 L .502 .038 0 r
F
.55344 .59506 m .55422 .59315 L .53868 .59634 L F
.55441 .59949 m .53945 .60069 L .5388 .60262 L .507 .039 0 r
F
.55441 .59949 m .55521 .59753 L .53945 .60069 L F
.3404 .60008 m .32392 .59086 L .32464 .59381 L 1 .549 0 r
F
.34111 .60293 m .3404 .60008 L .32464 .59381 L 1 .531 0 r
F
.61968 .47807 m .60876 .48204 L .60919 .48473 L .295 .058 0 r
F
.61968 .47807 m .61921 .47538 L .60876 .48204 L F
.41625 .35177 m .41461 .34961 L .41215 .35083 L .721 .856 0 r
F
.41625 .35177 m .41854 .35043 L .41461 .34961 L F
.57316 .58546 m .55881 .5873 L .55815 .58941 L .426 .035 0 r
F
.57316 .58546 m .57395 .58332 L .55881 .5873 L F
.33383 .52746 m .31948 .51841 L .31965 .52119 L 1 .77 0 r
F
.33404 .53016 m .33383 .52746 L .31965 .52119 L 1 .756 0 r
F
.50188 .61437 m .48561 .61371 L .48542 .6153 L .737 .057 0 r
F
.50188 .61437 m .50226 .61276 L .48561 .61371 L F
.34399 .50603 m .33231 .49718 L .33209 .4998 L 1 .908 0 r
F
.34383 .50863 m .34399 .50603 L .33209 .4998 L 1 .895 0 r
F
.50221 .61922 m .48577 .61865 L .48558 .62031 L .734 .058 0 r
F
.50221 .61922 m .5026 .61756 L .48577 .61865 L F
.57182 .58119 m .55774 .58313 L .55708 .58519 L .418 .034 0 r
F
.57182 .58119 m .57258 .57909 L .55774 .58313 L F
.61625 .47283 m .60569 .47672 L .60615 .47937 L .293 .059 0 r
F
.61625 .47283 m .61574 .47019 L .60569 .47672 L F
.68851 .8411 m .66608 .84441 L .6626 .84812 L .191 0 0 r
F
.68851 .8411 m .69249 .83725 L .66608 .84441 L F
.51637 .82006 m .49271 .82792 L .4922 .83094 L .318 0 0 r
F
.51637 .82006 m .5174 .81714 L .49271 .82792 L F
.40887 .65185 m .38921 .64754 L .39016 .64977 L 1 .145 0 r
F
.40965 .65391 m .40887 .65185 L .39016 .64977 L 1 .124 0 r
F
.38836 .36584 m .38648 .36155 L .38401 .36307 L .958 1 0 r
F
.38836 .36584 m .3907 .36416 L .38648 .36155 L F
.61018 .53237 m .59762 .53566 L .59737 .53821 L .32 .039 0 r
F
.61018 .53237 m .61046 .5298 L .59762 .53566 L F
.77079 .48353 m .76236 .49244 L .76223 .49735 L 0 0 0 r
F
.77079 .48353 m .77072 .47861 L .76236 .49244 L F
.62613 .57256 m .61479 .57764 L .61371 .5802 L .07 0 0 r
F
.62613 .57256 m .62728 .56995 L .61479 .57764 L F
.09707 .65237 m .07321 .63015 L .07483 .63677 L 1 .44 0 r
F
.09871 .65879 m .09707 .65237 L .07483 .63677 L 1 .412 0 r
F
.32295 .47002 m .31205 .45963 L .3114 .46252 L 1 1 0 r
F
.3224 .47291 m .32295 .47002 L .3114 .46252 L 1 .994 0 r
F
.43445 .60894 m .41745 .60526 L .418 .60702 L 1 .197 0 r
F
.43484 .61063 m .43445 .60894 L .418 .60702 L 1 .175 0 r
F
.5228 .65067 m .50592 .65231 L .50536 .65386 L .427 .003 0 r
F
.5228 .65067 m .52365 .64914 L .50592 .65231 L F
.39777 .59118 m .38147 .5856 L .38216 .58765 L 1 .387 0 r
F
.39836 .59316 m .39777 .59118 L .38216 .58765 L 1 .366 0 r
F
.39599 .59983 m .37855 .595 L .37932 .59711 L 1 .355 0 r
F
.39663 .60187 m .39599 .59983 L .37932 .59711 L 1 .335 0 r
F
.90274 .42229 m .88918 .43621 L .89066 .44309 L 0 0 0 r
F
.90274 .42229 m .90118 .41536 L .88918 .43621 L F
.59216 .5651 m .57861 .56764 L .57803 .56995 L .365 .033 0 r
F
.59216 .5651 m .59281 .56275 L .57861 .56764 L F
.54135 .64365 m .5253 .64593 L .52448 .64756 L .37 0 0 r
F
.54135 .64365 m .54244 .64202 L .5253 .64593 L F
.51842 .61113 m .50264 .61113 L .50226 .61276 L .658 .049 0 r
F
.51842 .61113 m .51899 .60947 L .50264 .61113 L F
.41506 .35558 m .41295 .35257 L .41068 .35411 L .942 1 0 r
F
.41506 .35558 m .4172 .35399 L .41295 .35257 L F
.37842 .57493 m .36294 .56826 L .36356 .57051 L 1 .515 0 r
F
.37897 .57712 m .37842 .57493 L .36356 .57051 L 1 .495 0 r
F
.20294 .80792 m .17199 .79354 L .17573 .79866 L 1 .091 0 r
F
.20638 .81278 m .20294 .80792 L .17573 .79866 L 1 .087 0 r
F
.51892 .61584 m .50298 .61586 L .5026 .61756 L .657 .05 0 r
F
.51892 .61584 m .5195 .61413 L .50298 .61586 L F
.30855 .49394 m .29907 .4829 L .2984 .48596 L 1 .982 0 r
F
.30798 .49704 m .30855 .49394 L .2984 .48596 L 1 .969 0 r
F
.31901 .56072 m .30528 .55009 L .30553 .5532 L 1 .731 0 r
F
.31931 .56378 m .31901 .56072 L .30553 .5532 L 1 .714 0 r
F
.56074 .63394 m .54557 .63684 L .54455 .63861 L .311 0 0 r
F
.56074 .63394 m .562 .63214 L .54557 .63684 L F
.35921 .54952 m .3451 .5417 L .34546 .54416 L 1 .681 0 r
F
.35956 .55193 m .35921 .54952 L .34546 .54416 L 1 .664 0 r
F
.45149 .619 m .43406 .61656 L .43447 .61831 L .941 .124 0 r
F
.4517 .62069 m .45149 .619 L .43447 .61831 L .931 .102 0 r
F
.46867 .62079 m .45149 .619 L .4517 .62069 L .875 .074 0 r
F
.62011 .48076 m .60919 .48473 L .60958 .48742 L .29 .056 0 r
F
.62011 .48076 m .61968 .47807 L .60919 .48473 L F
.66515 .4786 m .65955 .4842 L .65879 .48754 L 0 0 0 r
F
.66515 .4786 m .66598 .47526 L .65955 .4842 L F
.41551 .60975 m .39797 .60585 L .39868 .60779 L 1 .263 0 r
F
.41606 .61162 m .41551 .60975 L .39868 .60779 L 1 .242 0 r
F
.60771 .52882 m .59556 .53216 L .59532 .53466 L .311 .037 0 r
F
.60771 .52882 m .60798 .5263 L .59556 .53216 L F
.59033 .56107 m .57711 .5637 L .57655 .56597 L .358 .032 0 r
F
.59033 .56107 m .59096 .55877 L .57711 .5637 L F
.35422 .56373 m .33806 .55637 L .33866 .5589 L 1 .587 0 r
F
.35477 .56618 m .35422 .56373 L .33866 .5589 L 1 .57 0 r
F
.56376 .787 m .54422 .79624 L .54282 .79931 L .092 0 0 r
F
.56376 .787 m .56564 .78418 L .54422 .79624 L F
.61671 .47547 m .60615 .47937 L .60658 .48201 L .288 .057 0 r
F
.61671 .47547 m .61625 .47283 L .60615 .47937 L F
.38573 .37186 m .38718 .3719 L .38511 .37368 L 0 0 0 r
F
.38573 .37186 m .38843 .37072 L .38718 .3719 L F
.37253 .89243 m .34066 .88627 L .34352 .88931 L .737 .035 0 r
F
.37475 .89527 m .37253 .89243 L .34352 .88931 L .708 .03 0 r
F
.43221 .34682 m .43058 .34622 L .4283 .3473 L .577 .42 0 r
F
.43221 .34682 m .43427 .34555 L .43058 .34622 L F
.56909 .3198 m .65701 .17943 L .65447 .19467 L 1 1 0 r
F
.56909 .3198 m .58944 .27896 L .65701 .17943 L F
.3907 .36416 m .38895 .36005 L .38648 .36155 L .942 1 0 r
F
.3907 .36416 m .39304 .36252 L .38895 .36005 L F
.74186 .14257 m .73899 .1554 L .74472 .15961 L .173 .15 0 r
F
.74186 .14257 m .73609 .1387 L .73899 .1554 L F
.34383 .50863 m .33209 .4998 L .33191 .50241 L 1 .895 0 r
F
.3437 .51123 m .34383 .50863 L .33191 .50241 L 1 .881 0 r
F
.53532 .60542 m .52008 .60606 L .51954 .60778 L .577 .042 0 r
F
.53532 .60542 m .53603 .60367 L .52008 .60606 L F
.3224 .47291 m .3114 .46252 L .3108 .46541 L 1 .994 0 r
F
.32189 .47579 m .3224 .47291 L .3108 .46541 L 1 .983 0 r
F
.55184 .90004 m .52516 .89973 L .52374 .90224 L .412 0 0 r
F
.55184 .90004 m .55399 .89748 L .52516 .89973 L F
.45184 .61347 m .43484 .61063 L .43524 .6123 L .952 .12 0 r
F
.45205 .61508 m .45184 .61347 L .43524 .6123 L .942 .099 0 r
F
.46873 .61554 m .45184 .61347 L .45205 .61508 L .882 .074 0 r
F
.83972 .25376 m .83222 .26853 L .8363 .27435 L .034 .058 0 r
F
.36439 .62707 m .3462 .61961 L .34717 .62232 L 1 .387 0 r
F
.3653 .62964 m .36439 .62707 L .34717 .62232 L 1 .368 0 r
F
.38737 .64297 m .36821 .63719 L .36924 .63965 L 1 .256 0 r
F
.38828 .64527 m .38737 .64297 L .36924 .63965 L 1 .235 0 r
F
.6778 .68901 m .66176 .69457 L .65973 .69819 L .072 0 0 r
F
.6778 .68901 m .68019 .68545 L .66176 .69457 L F
.53601 .61 m .52061 .61061 L .52006 .61239 L .579 .042 0 r
F
.53601 .61 m .53674 .60821 L .52061 .61061 L F
.71424 .64524 m .69859 .65105 L .69681 .65505 L .057 0 0 r
F
.71424 .64524 m .71626 .6412 L .69859 .65105 L F
.08979 .66306 m .06468 .64077 L .06657 .6475 L 1 .407 0 r
F
.09166 .66955 m .08979 .66306 L .06657 .6475 L 1 .378 0 r
F
.37573 .58632 m .35873 .58038 L .35949 .58267 L 1 .452 0 r
F
.37639 .58853 m .37573 .58632 L .35949 .58267 L 1 .433 0 r
F
.70889 .15261 m .70441 .16618 L .70823 .1721 L .166 .084 0 r
F
.70889 .15261 m .70422 .14792 L .70441 .16618 L F
.33404 .53016 m .31965 .52119 L .31987 .52394 L 1 .756 0 r
F
.33428 .53286 m .33404 .53016 L .31987 .52394 L 1 .741 0 r
F
.64691 .53387 m .63809 .53958 L .63723 .54247 L 0 0 0 r
F
.64691 .53387 m .64779 .53097 L .63809 .53958 L F
.53987 .80512 m .5184 .81411 L .5174 .81714 L .197 0 0 r
F
.53987 .80512 m .54137 .80227 L .5184 .81411 L F
.88449 .58035 m .86894 .59135 L .86786 .59797 L 0 0 0 r
F
.88449 .58035 m .88566 .57361 L .86894 .59135 L F
.25665 .83689 m .22538 .82524 L .22916 .82964 L .953 .073 0 r
F
.26003 .84103 m .25665 .83689 L .22916 .82964 L .928 .069 0 r
F
.83823 .69333 m .8197 .7015 L .81714 .70739 L 0 0 0 r
F
.83823 .69333 m .84099 .68726 L .8197 .7015 L F
.64799 .86199 m .62475 .86439 L .62157 .8676 L .246 0 0 r
F
.64799 .86199 m .65174 .85867 L .62475 .86439 L F
.43373 .3436 m .43247 .34383 L .43014 .34477 L .378 .199 0 r
F
.16201 .72882 m .1328 .7128 L .13568 .71845 L 1 .268 0 r
F
.16471 .73421 m .16201 .72882 L .13568 .71845 L 1 .242 0 r
F
.46827 .66113 m .46824 .65956 L .4494 .66048 L .707 .042 0 r
F
.48652 .65935 m .46824 .65956 L .46827 .66113 L .605 .028 0 r
F
.48652 .65935 m .4868 .65785 L .46824 .65956 L F
.60986 .53493 m .59737 .53821 L .59707 .54074 L .315 .036 0 r
F
.60986 .53493 m .61018 .53237 L .59737 .53821 L F
.41854 .35043 m .41708 .34848 L .41461 .34961 L .671 .795 0 r
F
.41854 .35043 m .42084 .34916 L .41708 .34848 L F
.15218 .74457 m .12411 .72665 L .12709 .73251 L 1 .215 0 r
F
.15501 .75018 m .15218 .74457 L .12709 .73251 L 1 .186 0 r
F
.78924 .77485 m .76802 .78016 L .76464 .78536 L .08 0 0 r
F
.78924 .77485 m .79294 .76947 L .76802 .78016 L F
.55346 .3374 m .5486 .33662 L .54993 .34075 L .131 .05 0 r
F
.55346 .3374 m .55194 .33358 L .5486 .33662 L F
.74892 .36956 m .75574 .37341 L .75688 .37858 L .848 .113 0 r
F
.74892 .36956 m .74706 .36496 L .75574 .37341 L F
.62049 .48344 m .60958 .48742 L .60993 .49011 L .286 .054 0 r
F
.62049 .48344 m .62011 .48076 L .60958 .48742 L F
.68395 .41679 m .68044 .42192 L .67915 .4263 L 0 0 0 r
F
.68395 .41679 m .68537 .41235 L .68044 .42192 L F
.30798 .49704 m .2984 .48596 L .29779 .48903 L 1 .969 0 r
F
.30746 .50015 m .30798 .49704 L .29779 .48903 L 1 .956 0 r
F
.73956 .14544 m .73751 .1572 L .74342 .16113 L .175 .18 0 r
F
.73956 .14544 m .73355 .14198 L .73751 .1572 L F
.89699 .42307 m .88446 .43671 L .88569 .44354 L 0 0 0 r
F
.89699 .42307 m .89582 .41617 L .88446 .43671 L F
.61713 .47811 m .60658 .48201 L .60697 .48466 L .283 .055 0 r
F
.61713 .47811 m .61671 .47547 L .60658 .48201 L F
.60278 .60186 m .58986 .60616 L .58866 .60838 L .167 0 0 r
F
.60278 .60186 m .60411 .59959 L .58986 .60616 L F
.6146 .88474 m .58994 .88585 L .58722 .88881 L .322 0 0 r
F
.6146 .88474 m .61797 .88168 L .58994 .88585 L F
.41019 .85 m .37998 .85049 L .38185 .8536 L .744 .047 0 r
F
.41145 .85302 m .41019 .85 L .38185 .8536 L .722 .043 0 r
F
.43917 .84755 m .41019 .85 L .41145 .85302 L .652 .037 0 r
F
.58093 .62098 m .56681 .62454 L .56564 .6265 L .243 0 0 r
F
.58093 .62098 m .58228 .61897 L .56681 .62454 L F
.26531 .81332 m .23348 .8047 L .23697 .809 L 1 .083 0 r
F
.26839 .81741 m .26531 .81332 L .23697 .809 L .998 .08 0 r
F
.73255 .8122 m .71125 .81663 L .70765 .82093 L .121 0 0 r
F
.73255 .8122 m .73656 .80773 L .71125 .81663 L F
.4172 .35399 m .41527 .35113 L .41295 .35257 L .907 1 0 r
F
.4172 .35399 m .41937 .35248 L .41527 .35113 L F
.39304 .36252 m .39142 .35856 L .38895 .36005 L .927 1 0 r
F
.39304 .36252 m .39539 .36091 L .39142 .35856 L F
.46869 .62243 m .46867 .62079 L .4517 .62069 L .863 .071 0 r
F
.48539 .62193 m .46867 .62079 L .46869 .62243 L .798 .064 0 r
F
.48539 .62193 m .48558 .62031 L .46867 .62079 L F
.32189 .47579 m .3108 .46541 L .31024 .46831 L 1 .983 0 r
F
.32143 .47867 m .32189 .47579 L .31024 .46831 L 1 .972 0 r
F
.43406 .61656 m .41662 .61347 L .41721 .61528 L 1 .178 0 r
F
.43447 .61831 m .43406 .61656 L .41721 .61528 L .99 .156 0 r
F
.57234 .58757 m .55815 .58941 L .55745 .59148 L .416 .032 0 r
F
.57234 .58757 m .57316 .58546 L .55815 .58941 L F
.46875 .6171 m .46873 .61554 L .45205 .61508 L .871 .071 0 r
F
.48523 .61686 m .46873 .61554 L .46875 .6171 L .803 .064 0 r
F
.48523 .61686 m .48542 .6153 L .46873 .61554 L F
.34111 .60293 m .32464 .59381 L .3254 .59674 L 1 .531 0 r
F
.34187 .60576 m .34111 .60293 L .3254 .59674 L 1 .512 0 r
F
.3437 .51123 m .33191 .50241 L .33177 .50502 L 1 .881 0 r
F
.34361 .51383 m .3437 .51123 L .33177 .50502 L 1 .868 0 r
F
.55264 .59694 m .53805 .59822 L .53739 .60007 L .491 .035 0 r
F
.55264 .59694 m .55344 .59506 L .53805 .59822 L F
.57102 .58326 m .55708 .58519 L .55641 .58722 L .408 .031 0 r
F
.57102 .58326 m .57182 .58119 L .55708 .58519 L F
.41691 .60346 m .40026 .59894 L .40094 .6008 L 1 .265 0 r
F
.41745 .60526 m .41691 .60346 L .40094 .6008 L 1 .243 0 r
F
.6074 .53133 m .59532 .53466 L .59504 .53715 L .306 .035 0 r
F
.6074 .53133 m .60771 .52882 L .59532 .53466 L F
.55359 .60141 m .5388 .60262 L .53814 .60451 L .496 .036 0 r
F
.55359 .60141 m .55441 .59949 L .5388 .60262 L F
.35956 .55193 m .34546 .54416 L .34586 .5466 L 1 .664 0 r
F
.35994 .55433 m .35956 .55193 L .34586 .5466 L 1 .646 0 r
F
.59147 .56743 m .57803 .56995 L .57743 .57224 L .36 .031 0 r
F
.59147 .56743 m .59216 .5651 L .57803 .56995 L F
.31931 .56378 m .30553 .5532 L .30582 .5563 L 1 .714 0 r
F
.31965 .56684 m .31931 .56378 L .30582 .5563 L 1 .696 0 r
F
.38843 .37072 m .38906 .36987 L .38718 .3719 L .364 .197 0 r
F
.38843 .37072 m .39103 .36952 L .38906 .36987 L F
.74915 .58258 m .73523 .58981 L .73401 .59427 L 0 0 0 r
F
.74915 .58258 m .75045 .57803 L .73523 .58981 L F
.77079 .48844 m .76223 .49735 L .76204 .50225 L F
.77079 .48844 m .77079 .48353 L .76223 .49735 L F
.62496 .57513 m .61371 .5802 L .61261 .58273 L .063 0 0 r
F
.62496 .57513 m .62613 .57256 L .61371 .5802 L F
.39836 .59316 m .38216 .58765 L .38288 .58967 L 1 .366 0 r
F
.39897 .59512 m .39836 .59316 L .38288 .58967 L 1 .344 0 r
F
.36146 .41381 m .35528 .40573 L .35371 .40798 L 1 1 0 r
F
.36146 .41381 m .36293 .41151 L .35528 .40573 L F
.36003 .41614 m .36146 .41381 L .35371 .40798 L F
.36293 .41151 m .35689 .4035 L .35528 .40573 L F
.36293 .41151 m .36444 .40922 L .35689 .4035 L F
.36003 .41614 m .35371 .40798 L .35217 .41025 L F
.37897 .57712 m .36356 .57051 L .3642 .57273 L 1 .495 0 r
F
.37956 .57928 m .37897 .57712 L .3642 .57273 L 1 .475 0 r
F
.36444 .40922 m .35853 .4013 L .35689 .4035 L 1 1 0 r
F
.36444 .40922 m .36597 .40696 L .35853 .4013 L F
.62083 .48613 m .60993 .49011 L .61024 .49279 L .281 .052 0 r
F
.62083 .48613 m .62049 .48344 L .60993 .49011 L F
.61751 .48075 m .60697 .48466 L .60733 .48731 L .278 .053 0 r
F
.61751 .48075 m .61713 .47811 L .60697 .48466 L F
.35863 .41849 m .35217 .41025 L .35067 .41254 L 1 1 0 r
F
.20779 .80201 m .17763 .78765 L .18125 .79271 L 1 .092 0 r
F
.21114 .80682 m .20779 .80201 L .18125 .79271 L 1 .088 0 r
F
.58966 .56335 m .57655 .56597 L .57597 .56822 L .353 .03 0 r
F
.58966 .56335 m .59033 .56107 L .57655 .56597 L F
.36597 .40696 m .36021 .39913 L .35853 .4013 L 1 1 0 r
F
.36597 .40696 m .36754 .40472 L .36021 .39913 L F
.5551 .34083 m .54993 .34075 L .55141 .34443 L .185 .065 0 r
F
.5551 .34083 m .55346 .3374 L .54993 .34075 L F
.35726 .42086 m .35067 .41254 L .34921 .41486 L 1 1 0 r
F
.39663 .60187 m .37932 .59711 L .38012 .59918 L 1 .335 0 r
F
.39729 .60387 m .39663 .60187 L .38012 .59918 L 1 .315 0 r
F
.21718 .78213 m .18615 .77027 L .18957 .77517 L 1 .136 0 r
F
.22029 .78678 m .21718 .78213 L .18957 .77517 L 1 .111 0 r
F
.35477 .56618 m .33866 .5589 L .3393 .5614 L 1 .57 0 r
F
.35535 .5686 m .35477 .56618 L .3393 .5614 L 1 .554 0 r
F
.30746 .50015 m .29779 .48903 L .29722 .49211 L 1 .956 0 r
F
.30699 .50326 m .30746 .50015 L .29722 .49211 L 1 .942 0 r
F
.33785 .88312 m .30584 .87554 L .30922 .87891 L .792 .044 0 r
F
.34066 .88627 m .33785 .88312 L .30922 .87891 L .763 .039 0 r
F
.66433 .4819 m .65879 .48754 L .65804 .49085 L 0 0 0 r
F
.66433 .4819 m .66515 .4786 L .65879 .48754 L F
.4494 .66048 m .43 .65877 L .43059 .66059 L .816 .058 0 r
F
.44972 .66214 m .4494 .66048 L .43059 .66059 L .797 .054 0 r
F
.46827 .66113 m .4494 .66048 L .44972 .66214 L .707 .042 0 r
F
.36754 .40472 m .36193 .39698 L .36021 .39913 L 1 1 0 r
F
.36754 .40472 m .36915 .40251 L .36193 .39698 L F
.89328 .58968 m .87548 .60023 L .87441 .607 L 0 0 0 r
F
.89328 .58968 m .89442 .58275 L .87548 .60023 L F
.35593 .42324 m .34921 .41486 L .34778 .41719 L 1 1 0 r
F
.35463 .42565 m .35593 .42324 L .34778 .41719 L F
.50148 .61593 m .48542 .6153 L .48523 .61686 L .725 .055 0 r
F
.50148 .61593 m .50188 .61437 L .48542 .6153 L F
.3741 .88588 m .34274 .87981 L .34555 .88282 L .737 .035 0 r
F
.37629 .88867 m .3741 .88588 L .34555 .88282 L .707 .03 0 r
F
.64357 .72177 m .6275 .72815 L .6254 .73147 L .034 0 0 r
F
.64357 .72177 m .64608 .71862 L .6275 .72815 L F
.33428 .53286 m .31987 .52394 L .32013 .52669 L 1 .741 0 r
F
.33456 .53554 m .33428 .53286 L .32013 .52669 L 1 .726 0 r
F
.43484 .61063 m .418 .60702 L .41857 .60875 L 1 .175 0 r
F
.43524 .6123 m .43484 .61063 L .41857 .60875 L 1 .153 0 r
F
.50181 .62084 m .48558 .62031 L .48539 .62193 L .721 .055 0 r
F
.50181 .62084 m .50221 .61922 L .48558 .62031 L F
.58163 .8944 m .55611 .89481 L .55399 .89748 L .366 0 0 r
F
.58163 .8944 m .58445 .89166 L .55611 .89481 L F
.36915 .40251 m .36367 .39486 L .36193 .39698 L 1 1 0 r
F
.36915 .40251 m .37079 .40033 L .36367 .39486 L F
.35463 .42565 m .34778 .41719 L .34639 .41954 L F
.39539 .36091 m .39388 .35709 L .39142 .35856 L .912 1 0 r
F
.39539 .36091 m .39775 .35934 L .39388 .35709 L F
.60949 .53747 m .59707 .54074 L .59674 .54326 L .31 .034 0 r
F
.60949 .53747 m .60986 .53493 L .59707 .54074 L F
.32143 .47867 m .31024 .46831 L .30973 .4712 L 1 .972 0 r
F
.32101 .48155 m .32143 .47867 L .30973 .4712 L 1 .96 0 r
F
.43427 .34555 m .43286 .34519 L .43058 .34622 L .523 .25 0 r
F
.43427 .34555 m .43634 .34435 L .43286 .34519 L F
.46566 .90652 m .46558 .90414 L .4363 .90382 L .539 .006 0 r
F
.49417 .90599 m .46558 .90414 L .46566 .90652 L .49 0 0 r
F
.49417 .90599 m .49486 .90361 L .46558 .90414 L F
.37079 .40033 m .36546 .39277 L .36367 .39486 L 1 1 0 r
F
.37079 .40033 m .37246 .39817 L .36546 .39277 L F
.35337 .42807 m .34639 .41954 L .34504 .42192 L F
.55033 .89216 m .52421 .89228 L .5228 .89467 L .392 0 0 r
F
.55033 .89216 m .55246 .88974 L .52421 .89228 L F
.50421 .65683 m .4868 .65785 L .48652 .65935 L .491 .012 0 r
F
.50421 .65683 m .50479 .65537 L .4868 .65785 L F
.90418 .42925 m .89066 .44309 L .89202 .45 L 0 0 0 r
F
.90418 .42925 m .90274 .42229 L .89066 .44309 L F
.43 .65877 m .41045 .65594 L .41126 .65793 L .91 .071 0 r
F
.43059 .66059 m .43 .65877 L .41126 .65793 L .894 .068 0 r
F
.42084 .34916 m .41956 .34741 L .41708 .34848 L .616 .72 0 r
F
.42084 .34916 m .42316 .34796 L .41956 .34741 L F
.51784 .61275 m .50226 .61276 L .50188 .61437 L .646 .047 0 r
F
.51784 .61275 m .51842 .61113 L .50226 .61276 L F
.6139 .74685 m .59732 .75451 L .59533 .75765 L 0 0 0 r
F
.6139 .74685 m .61633 .74395 L .59732 .75451 L F
.34361 .51383 m .33177 .50502 L .33167 .50762 L 1 .868 0 r
F
.34356 .51641 m .34361 .51383 L .33167 .50762 L 1 .853 0 r
F
.41937 .35248 m .41763 .34982 L .41527 .35113 L .862 1 0 r
F
.41937 .35248 m .42157 .35105 L .41763 .34982 L F
.37246 .39817 m .36727 .3907 L .36546 .39277 L 1 1 0 r
F
.37246 .39817 m .37416 .39604 L .36727 .3907 L F
.41606 .61162 m .39868 .60779 L .39941 .6097 L 1 .242 0 r
F
.41662 .61347 m .41606 .61162 L .39941 .6097 L 1 .22 0 r
F
.46634 .84311 m .46628 .84017 L .43917 .84755 L .526 .021 0 r
F
.49169 .83385 m .46628 .84017 L .46634 .84311 L .407 .003 0 r
F
.49169 .83385 m .4922 .83094 L .46628 .84017 L F
.646 .53676 m .63723 .54247 L .63635 .54533 L 0 0 0 r
F
.646 .53676 m .64691 .53387 L .63723 .54247 L F
.55684 .34398 m .55141 .34443 L .55299 .34777 L .225 .076 0 r
F
.55684 .34398 m .5551 .34083 L .55141 .34443 L F
.51833 .61751 m .5026 .61756 L .50221 .61922 L .645 .047 0 r
F
.51833 .61751 m .51892 .61584 L .5026 .61756 L F
.10787 .64742 m .08266 .6266 L .08443 .633 L 1 .446 0 r
F
.10962 .65358 m .10787 .64742 L .08443 .633 L 1 .42 0 r
F
.61784 .48339 m .60733 .48731 L .60764 .48995 L .273 .05 0 r
F
.61784 .48339 m .61751 .48075 L .60733 .48731 L F
.40965 .65391 m .39016 .64977 L .39114 .65198 L 1 .124 0 r
F
.41045 .65594 m .40965 .65391 L .39114 .65198 L .992 .103 0 r
F
.37639 .58853 m .35949 .58267 L .36029 .58493 L 1 .433 0 r
F
.37709 .59071 m .37639 .58853 L .36029 .58493 L 1 .414 0 r
F
.84408 .70458 m .82419 .71202 L .82155 .71803 L 0 0 0 r
F
.84408 .70458 m .84693 .69837 L .82419 .71202 L F
.62113 .48882 m .61024 .49279 L .61052 .49548 L .276 .05 0 r
F
.62113 .48882 m .62083 .48613 L .61024 .49279 L F
.4517 .62069 m .43447 .61831 L .43489 .62002 L .931 .102 0 r
F
.45193 .62234 m .4517 .62069 L .43489 .62002 L .92 .082 0 r
F
.46869 .62243 m .4517 .62069 L .45193 .62234 L .863 .071 0 r
F
.37416 .39604 m .36912 .38867 L .36727 .3907 L 0 0 0 r
F
.60706 .53383 m .59504 .53715 L .59473 .53962 L .301 .033 0 r
F
.60706 .53383 m .6074 .53133 L .59504 .53715 L F
.84381 .2595 m .8363 .27435 L .84026 .28023 L .02 .054 0 r
F
.84381 .2595 m .83972 .25376 L .8363 .27435 L F
.29925 .8685 m .26726 .85919 L .27102 .86299 L .856 .055 0 r
F
.30251 .87207 m .29925 .8685 L .27102 .86299 L .828 .05 0 r
F
.53458 .60714 m .51954 .60778 L .51899 .60947 L .566 .039 0 r
F
.53458 .60714 m .53532 .60542 L .51954 .60778 L F
.75075 .37417 m .75688 .37858 L .75799 .38373 L .826 .109 0 r
F
.75075 .37417 m .74892 .36956 L .75688 .37858 L F
.74747 .14663 m .74472 .15961 L .75034 .16394 L .146 .106 0 r
F
.74747 .14663 m .74186 .14257 L .74472 .15961 L F
.39103 .36952 m .3907 .36746 L .38906 .36987 L .592 .423 0 r
F
.39103 .36952 m .39345 .36812 L .3907 .36746 L F
.43586 .34252 m .43481 .34296 L .43247 .34383 L .309 .186 0 r
F
.30699 .50326 m .29722 .49211 L .2967 .4952 L 1 .942 0 r
F
.30656 .50638 m .30699 .50326 L .2967 .4952 L 1 .928 0 r
F
.78213 .76827 m .76211 .77419 L .75873 .77922 L .037 0 0 r
F
.78213 .76827 m .78581 .76306 L .76211 .77419 L F
.61172 .87659 m .58771 .87822 L .58501 .88102 L .294 0 0 r
F
.61172 .87659 m .61506 .8737 L .58771 .87822 L F
.53527 .61176 m .52006 .61239 L .5195 .61413 L .567 .04 0 r
F
.53527 .61176 m .53601 .61 L .52006 .61239 L F
.35994 .55433 m .34586 .5466 L .34629 .54902 L 1 .646 0 r
F
.36036 .5567 m .35994 .55433 L .34629 .54902 L 1 .628 0 r
F
.3653 .62964 m .34717 .62232 L .34818 .625 L 1 .368 0 r
F
.36624 .63218 m .3653 .62964 L .34818 .625 L 1 .348 0 r
F
.52194 .65216 m .50536 .65386 L .50479 .65537 L .414 0 0 r
F
.52194 .65216 m .5228 .65067 L .50536 .65386 L F
.09871 .65879 m .07483 .63677 L .07658 .64337 L 1 .412 0 r
F
.10045 .66518 m .09871 .65879 L .07658 .64337 L 1 .383 0 r
F
.45205 .61508 m .43524 .6123 L .43565 .61392 L .942 .099 0 r
F
.45228 .61665 m .45205 .61508 L .43565 .61392 L .93 .079 0 r
F
.46875 .6171 m .45205 .61508 L .45228 .61665 L .871 .071 0 r
F
.55863 .34691 m .55299 .34777 L .55465 .35088 L .254 .094 0 r
F
.55863 .34691 m .55684 .34398 L .55299 .34777 L F
.39775 .35934 m .39634 .35564 L .39388 .35709 L .898 1 0 r
F
.39775 .35934 m .40012 .3578 L .39634 .35564 L F
.54025 .64524 m .52448 .64756 L .52365 .64914 L .357 0 0 r
F
.54025 .64524 m .54135 .64365 L .52448 .64756 L F
.43982 .85049 m .43917 .84755 L .41145 .85302 L .627 .032 0 r
F
.46634 .84311 m .43917 .84755 L .43982 .85049 L .526 .021 0 r
F
.55946 .63569 m .54455 .63861 L .5435 .64034 L .299 0 0 r
F
.55946 .63569 m .56074 .63394 L .54455 .63861 L F
.14858 .75566 m .11971 .73792 L .12293 .7438 L 1 .179 0 r
F
.15162 .76128 m .14858 .75566 L .12293 .7438 L 1 .149 0 r
F
.32101 .48155 m .30973 .4712 L .30927 .4741 L 1 .96 0 r
F
.32064 .48442 m .32101 .48155 L .30927 .4741 L 1 .947 0 r
F
.31965 .56684 m .30582 .5563 L .30616 .55939 L 1 .696 0 r
F
.32004 .56988 m .31965 .56684 L .30616 .55939 L 1 .679 0 r
F
.68257 .42113 m .67915 .4263 L .6779 .43057 L 0 0 0 r
F
.68122 .42535 m .68257 .42113 L .68256 .42115 L F
.68122 .42535 m .68256 .42115 L .6779 .43057 L F
.67991 .42947 m .68122 .42535 L .68121 .42538 L F
.67991 .42947 m .68121 .42538 L .6767 .43473 L F
.67864 .4335 m .67991 .42947 L .6799 .4295 L F
.67864 .4335 m .6799 .4295 L .67555 .43879 L F
.6774 .43743 m .67864 .4335 L .67862 .43353 L F
.6774 .43743 m .67862 .43353 L .67444 .44276 L F
.6762 .44128 m .6774 .43743 L .67739 .43747 L F
.6762 .44128 m .67739 .43747 L .67338 .44664 L F
.67504 .44504 m .6762 .44128 L .67619 .44131 L F
.67504 .44504 m .67619 .44131 L .67235 .45045 L F
.67391 .44873 m .67504 .44504 L .67502 .44508 L F
.67391 .44873 m .67502 .44508 L .67136 .45418 L F
.67281 .45236 m .67391 .44873 L .67389 .44877 L F
.67281 .45236 m .67389 .44877 L .6704 .45784 L F
.67174 .45591 m .67281 .45236 L .6728 .45239 L F
.67174 .45591 m .6728 .45239 L .66947 .46143 L F
.6707 .45941 m .67174 .45591 L .67173 .45594 L F
.6707 .45941 m .67173 .45594 L .66857 .46497 L F
.66969 .46284 m .6707 .45941 L .67069 .45944 L F
.66969 .46284 m .67069 .45944 L .66768 .46845 L F
.66871 .46623 m .66969 .46284 L .66969 .46287 L F
.66871 .46623 m .66969 .46287 L .66682 .47188 L F
.66776 .46956 m .66871 .46623 L .6687 .46625 L F
.66776 .46956 m .6687 .46625 L .66598 .47526 L F
.66682 .47285 m .66776 .46956 L .66775 .46958 L F
.66682 .47285 m .66775 .46958 L .66515 .4786 L F
.66682 .47285 m .66515 .4786 L .66433 .4819 L F
.66591 .47607 m .66682 .47285 L .66592 .47609 L .916 .341 0 r
F
.66871 .46623 m .66682 .47188 L .66598 .47526 L 0 0 0 r
F
.66776 .46956 m .66598 .47526 L .66515 .4786 L F
.66465 .46715 m .66682 .47285 L .66591 .47607 L .916 .341 0 r
F
.66682 .47282 m .66776 .46956 L .66682 .47285 L .897 .31 0 r
F
.66969 .46284 m .66768 .46845 L .66682 .47188 L 0 0 0 r
F
.66581 .46389 m .66776 .46956 L .66682 .47282 L .897 .31 0 r
F
.66775 .46953 m .66871 .46623 L .66776 .46956 L .886 .275 0 r
F
.6707 .45941 m .66857 .46497 L .66768 .46845 L 0 0 0 r
F
.66702 .46059 m .66871 .46623 L .66775 .46953 L .886 .275 0 r
F
.66871 .4662 m .66969 .46284 L .66871 .46623 L .873 .236 0 r
F
.67174 .45591 m .66947 .46143 L .66857 .46497 L 0 0 0 r
F
.66828 .45722 m .66969 .46284 L .66871 .4662 L .873 .236 0 r
F
.66969 .46281 m .6707 .45941 L .66969 .46284 L .86 .211 0 r
F
.67281 .45236 m .6704 .45784 L .66947 .46143 L 0 0 0 r
F
.66958 .45379 m .6707 .45941 L .66969 .46281 L .86 .211 0 r
F
.6707 .45937 m .67174 .45591 L .6707 .45941 L .845 .209 0 r
F
.67504 .44504 m .67235 .45045 L .67136 .45418 L 0 0 0 r
F
.67391 .44873 m .67136 .45418 L .6704 .45784 L F
.67092 .4503 m .67174 .45591 L .6707 .45937 L .845 .209 0 r
F
.67174 .45588 m .67281 .45236 L .67174 .45591 L .829 .207 0 r
F
.6762 .44128 m .67338 .44664 L .67235 .45045 L 0 0 0 r
F
.6723 .44673 m .67281 .45236 L .67174 .45588 L .829 .207 0 r
F
.67281 .45232 m .67391 .44873 L .67281 .45236 L .812 .205 0 r
F
.6774 .43743 m .67444 .44276 L .67338 .44664 L 0 0 0 r
F
.67372 .44309 m .67391 .44873 L .67281 .45232 L .812 .205 0 r
F
.67391 .4487 m .67504 .44504 L .67391 .44873 L .794 .202 0 r
F
.67864 .4335 m .67555 .43879 L .67444 .44276 L 0 0 0 r
F
.67518 .43937 m .67504 .44504 L .67391 .4487 L .794 .202 0 r
F
.67504 .44501 m .6762 .44128 L .67504 .44504 L .776 .199 0 r
F
.67991 .42947 m .6767 .43473 L .67555 .43879 L 0 0 0 r
F
.67666 .43557 m .6762 .44128 L .67504 .44501 L .776 .199 0 r
F
.67621 .44124 m .6774 .43743 L .6762 .44128 L .757 .196 0 r
F
.67817 .43168 m .6774 .43743 L .67621 .44124 L F
.67741 .43739 m .67864 .4335 L .6774 .43743 L .738 .192 0 r
F
.68122 .42535 m .6779 .43057 L .6767 .43473 L 0 0 0 r
F
.67971 .4277 m .67864 .4335 L .67741 .43739 L .738 .192 0 r
F
.67865 .43347 m .67991 .42947 L .67864 .4335 L .72 .189 0 r
F
.68127 .42362 m .67991 .42947 L .67865 .43347 L F
.67992 .42945 m .68122 .42535 L .67991 .42947 L .702 .185 0 r
F
.68257 .42113 m .68394 .4168 L .67915 .4263 L 0 0 0 r
F
.68285 .41945 m .68122 .42535 L .67992 .42945 L .702 .185 0 r
F
.68122 .42534 m .68257 .42113 L .68122 .42535 L .685 .181 0 r
F
.68445 .41517 m .68257 .42113 L .68122 .42534 L F
.68257 .42113 m .68395 .41679 L .68394 .4168 L 0 0 0 r
F
.59075 .56973 m .57743 .57224 L .5768 .57451 L .354 .028 0 r
F
.59075 .56973 m .59147 .56743 L .57743 .57224 L F
.74549 .14903 m .74342 .16113 L .74926 .16516 L .162 .155 0 r
F
.74549 .14903 m .73956 .14544 L .74342 .16113 L F
.54912 .31804 m .54836 .31154 L .54891 .30912 L .837 .145 0 r
F
.57148 .58965 m .55745 .59148 L .55673 .59353 L .406 .029 0 r
F
.57148 .58965 m .57234 .58757 L .55745 .59148 L F
.5223 .90464 m .49486 .90361 L .49417 .90599 L .448 0 0 r
F
.5223 .90464 m .52374 .90224 L .49486 .90361 L F
.38828 .64527 m .36924 .63965 L .37031 .64208 L 1 .235 0 r
F
.38921 .64754 m .38828 .64527 L .37031 .64208 L 1 .214 0 r
F
.57019 .5853 m .55641 .58722 L .5557 .58923 L .4 .029 0 r
F
.57019 .5853 m .57102 .58326 L .55641 .58722 L F
.37998 .85049 m .34917 .84903 L .35163 .85224 L .81 .054 0 r
F
.38185 .8536 m .37998 .85049 L .35163 .85224 L .789 .05 0 r
F
.33456 .53554 m .32013 .52669 L .32043 .52942 L 1 .726 0 r
F
.33487 .5382 m .33456 .53554 L .32043 .52942 L 1 .711 0 r
F
.56046 .34969 m .55465 .35088 L .55636 .3538 L .275 .14 0 r
F
.56046 .34969 m .55863 .34691 L .55465 .35088 L F
.34356 .51641 m .33167 .50762 L .33161 .51022 L 1 .853 0 r
F
.34355 .51899 m .34356 .51641 L .33161 .51022 L 1 .839 0 r
F
.61814 .48603 m .60764 .48995 L .60792 .49259 L .267 .048 0 r
F
.61814 .48603 m .61784 .48339 L .60764 .48995 L F
.34187 .60576 m .3254 .59674 L .3262 .59965 L 1 .512 0 r
F
.34266 .60857 m .34187 .60576 L .3262 .59965 L 1 .493 0 r
F
.60142 .60411 m .58866 .60838 L .58744 .61057 L .157 0 0 r
F
.60142 .60411 m .60278 .60186 L .58866 .60838 L F
.58896 .56561 m .57597 .56822 L .57535 .57044 L .348 .027 0 r
F
.58896 .56561 m .58966 .56335 L .57597 .56822 L F
.62139 .4915 m .61052 .49548 L .61075 .49816 L .271 .047 0 r
F
.62139 .4915 m .62113 .48882 L .61052 .49548 L F
.60908 .54 m .59674 .54326 L .59638 .54576 L .305 .032 0 r
F
.60908 .54 m .60949 .53747 L .59674 .54326 L F
.33998 .8767 m .30851 .86917 L .31183 .87251 L .794 .044 0 r
F
.34274 .87981 m .33998 .8767 L .31183 .87251 L .766 .039 0 r
F
.89801 .42998 m .88569 .44354 L .88679 .45038 L 0 0 0 r
F
.89801 .42998 m .89699 .42307 L .88569 .44354 L F
.71214 .64924 m .69681 .65505 L .69497 .65902 L .041 0 0 r
F
.71214 .64924 m .71424 .64524 L .69681 .65505 L F
.37956 .57928 m .3642 .57273 L .36488 .57493 L 1 .475 0 r
F
.38017 .58141 m .37956 .57928 L .36488 .57493 L 1 .454 0 r
F
.68909 .8528 m .66643 .8555 L .66286 .85928 L .212 0 0 r
F
.68909 .8528 m .69319 .84887 L .66643 .8555 L F
.71311 .15783 m .70823 .1721 L .71135 .17875 L .127 .07 0 r
F
.71311 .15783 m .70889 .15261 L .70823 .1721 L F
.55181 .59879 m .53739 .60007 L .53672 .60189 L .48 .033 0 r
F
.55181 .59879 m .55264 .59694 L .53739 .60007 L F
.35535 .5686 m .3393 .5614 L .33997 .56388 L 1 .554 0 r
F
.35596 .571 m .35535 .5686 L .33997 .56388 L 1 .536 0 r
F
.56233 .35234 m .55636 .3538 L .5581 .35658 L .291 .176 0 r
F
.56233 .35234 m .56046 .34969 L .55636 .3538 L F
.66353 .48515 m .65804 .49085 L .65729 .49412 L 0 0 0 r
F
.66353 .48515 m .66433 .4819 L .65804 .49085 L F
.41745 .60526 m .40094 .6008 L .40163 .60263 L 1 .243 0 r
F
.418 .60702 m .41745 .60526 L .40163 .60263 L 1 .22 0 r
F
.55274 .6033 m .53814 .60451 L .53745 .60638 L .484 .033 0 r
F
.55274 .6033 m .55359 .60141 L .53814 .60451 L F
.77072 .49334 m .76204 .50225 L .76179 .50712 L 0 0 0 r
F
.77072 .49334 m .77079 .48844 L .76204 .50225 L F
.57954 .62294 m .56564 .6265 L .56445 .62842 L .232 0 0 r
F
.57954 .62294 m .58093 .62098 L .56564 .6265 L F
.39897 .59512 m .38288 .58967 L .38362 .59167 L 1 .344 0 r
F
.3996 .59704 m .39897 .59512 L .38362 .59167 L 1 .322 0 r
F
.42157 .35105 m .42004 .34864 L .41763 .34982 L .803 .976 0 r
F
.42157 .35105 m .42379 .34971 L .42004 .34864 L F
.62375 .57768 m .61261 .58273 L .61149 .58523 L .055 0 0 r
F
.62375 .57768 m .62496 .57513 L .61261 .58273 L F
.5642 .35491 m .5581 .35658 L .55987 .35926 L .302 .204 0 r
F
.5642 .35491 m .56233 .35234 L .5581 .35658 L F
.43447 .61831 m .41721 .61528 L .41781 .61706 L .99 .156 0 r
F
.43489 .62002 m .43447 .61831 L .41781 .61706 L .979 .133 0 r
F
.39345 .36812 m .39239 .36507 L .3907 .36746 L .82 .866 0 r
F
.39345 .36812 m .39569 .3665 L .39239 .36507 L F
.88321 .58707 m .86786 .59797 L .86666 .60457 L 0 0 0 r
F
.88321 .58707 m .88449 .58035 L .86786 .59797 L F
.4687 .62402 m .46869 .62243 L .45193 .62234 L .851 .069 0 r
F
.48519 .62352 m .46869 .62243 L .4687 .62402 L .786 .061 0 r
F
.48519 .62352 m .48539 .62193 L .46869 .62243 L F
.30656 .50638 m .2967 .4952 L .29622 .49829 L 1 .928 0 r
F
.30617 .5095 m .30656 .50638 L .29622 .49829 L 1 .913 0 r
F
.57948 .88632 m .55456 .8872 L .55246 .88974 L .341 0 0 r
F
.57948 .88632 m .58227 .88373 L .55456 .8872 L F
.42316 .34796 m .42206 .34643 L .41956 .34741 L .581 .629 0 r
F
.42316 .34796 m .42548 .34683 L .42206 .34643 L F
.46876 .61862 m .46875 .6171 L .45228 .61665 L .86 .069 0 r
F
.48504 .61837 m .46875 .6171 L .46876 .61862 L .791 .061 0 r
F
.48504 .61837 m .48523 .61686 L .46875 .6171 L F
.46575 .89933 m .46568 .89703 L .43688 .89688 L .524 .003 0 r
F
.49377 .89857 m .46568 .89703 L .46575 .89933 L .478 0 0 r
F
.49377 .89857 m .49445 .8963 L .46568 .89703 L F
.56609 .35741 m .55987 .35926 L .56165 .36186 L .311 .224 0 r
F
.56609 .35741 m .5642 .35491 L .55987 .35926 L F
.40012 .3578 m .39881 .35422 L .39634 .35564 L .884 1 0 r
F
.40012 .3578 m .4025 .3563 L .39881 .35422 L F
.70327 .34954 m .70186 .35452 L .70047 .3605 L 0 0 0 r
F
.58676 .76927 m .56923 .77822 L .56746 .78125 L F
.58676 .76927 m .589 .76652 L .56923 .77822 L F
.56798 .35985 m .56165 .36186 L .56344 .3644 L .316 .238 0 r
F
.56798 .35985 m .56609 .35741 L .56165 .36186 L F
.60667 .53631 m .59473 .53962 L .59438 .54208 L .296 .03 0 r
F
.60667 .53631 m .60706 .53383 L .59473 .53962 L F
.67533 .69251 m .65973 .69819 L .65762 .70176 L .047 0 0 r
F
.67533 .69251 m .6778 .68901 L .65973 .69819 L F
.32064 .48442 m .30927 .4741 L .30885 .47699 L 1 .947 0 r
F
.32031 .48729 m .32064 .48442 L .30885 .47699 L 1 .935 0 r
F
.39729 .60387 m .38012 .59918 L .38095 .60123 L 1 .315 0 r
F
.39797 .60585 m .39729 .60387 L .38095 .60123 L 1 .294 0 r
F
.56987 .36224 m .56344 .3644 L .56523 .36689 L .32 .248 0 r
F
.56987 .36224 m .56798 .35985 L .56344 .3644 L F
.57176 .36461 m .56523 .36689 L .56702 .36935 L .323 .255 0 r
F
.57176 .36461 m .56987 .36224 L .56523 .36689 L F
.34676 .84572 m .31541 .84218 L .31838 .84563 L .875 .061 0 r
F
.34917 .84903 m .34676 .84572 L .31838 .84563 L .855 .057 0 r
F
.57363 .36695 m .56702 .36935 L .5688 .37178 L .324 .258 0 r
F
.57363 .36695 m .57176 .36461 L .56702 .36935 L F
.74778 .5871 m .73401 .59427 L .73273 .5987 L 0 0 0 r
F
.74778 .5871 m .74915 .58258 L .73401 .59427 L F
.5755 .36928 m .5688 .37178 L .57057 .37419 L .325 .26 0 r
F
.5755 .36928 m .57363 .36695 L .5688 .37178 L F
.57735 .37159 m .57057 .37419 L .57233 .37659 L .325 .259 0 r
F
.57735 .37159 m .5755 .36928 L .57057 .37419 L F
.57919 .37389 m .57233 .37659 L .57407 .37898 L .324 .257 0 r
F
.57919 .37389 m .57735 .37159 L .57233 .37659 L F
.43634 .34435 m .43514 .34421 L .43286 .34519 L .463 .212 0 r
F
.58101 .37619 m .57407 .37898 L .5758 .38136 L .323 .254 0 r
F
.58101 .37619 m .57919 .37389 L .57407 .37898 L F
.58281 .37848 m .5758 .38136 L .57751 .38374 L .322 .249 0 r
F
.58281 .37848 m .58101 .37619 L .5758 .38136 L F
.09166 .66955 m .06657 .6475 L .06859 .65419 L 1 .378 0 r
F
.09364 .67601 m .09166 .66955 L .06859 .65419 L 1 .349 0 r
F
.5846 .38078 m .57751 .38374 L .57921 .38612 L .32 .244 0 r
F
.5846 .38078 m .58281 .37848 L .57751 .38374 L F
.40584 .90009 m .37475 .89527 L .37701 .89801 L .666 .024 0 r
F
.40741 .90265 m .40584 .90009 L .37701 .89801 L .636 .019 0 r
F
.4363 .90382 m .40584 .90009 L .40741 .90265 L .609 .016 0 r
F
.58636 .38308 m .57921 .38612 L .58088 .38851 L .318 .238 0 r
F
.58636 .38308 m .5846 .38078 L .57921 .38612 L F
.46829 .66265 m .46827 .66113 L .44972 .66214 L .685 .038 0 r
F
.48624 .6608 m .46827 .66113 L .46829 .66265 L .581 .023 0 r
F
.48624 .6608 m .48652 .65935 L .46827 .66113 L F
.61839 .48866 m .60792 .49259 L .60816 .49523 L .262 .046 0 r
F
.61839 .48866 m .61814 .48603 L .60792 .49259 L F
.58811 .38539 m .58088 .38851 L .58252 .3909 L .316 .231 0 r
F
.58811 .38539 m .58636 .38308 L .58088 .38851 L F
.64507 .53962 m .63635 .54533 L .63544 .54817 L 0 0 0 r
F
.64507 .53962 m .646 .53676 L .63635 .54533 L F
.30205 .86221 m .27064 .85291 L .27433 .85669 L .86 .056 0 r
F
.30525 .86574 m .30205 .86221 L .27433 .85669 L .833 .051 0 r
F
.58983 .3877 m .58252 .3909 L .58415 .39329 L .314 .223 0 r
F
.58983 .3877 m .58811 .38539 L .58252 .3909 L F
.6216 .49418 m .61075 .49816 L .61095 .50083 L .266 .045 0 r
F
.6216 .49418 m .62139 .4915 L .61075 .49816 L F
.73421 .8241 m .71246 .82785 L .70877 .83224 L .146 0 0 r
F
.73421 .8241 m .73834 .81955 L .71246 .82785 L F
.36036 .5567 m .34629 .54902 L .34676 .55143 L 1 .628 0 r
F
.36081 .55905 m .36036 .5567 L .34676 .55143 L 1 .609 0 r
F
.34355 .51899 m .33161 .51022 L .33159 .51281 L 1 .839 0 r
F
.34357 .52156 m .34355 .51899 L .33159 .51281 L 1 .824 0 r
F
.43524 .6123 m .41857 .60875 L .41916 .61044 L 1 .153 0 r
F
.43565 .61392 m .43524 .6123 L .41916 .61044 L .993 .13 0 r
F
.59152 .39003 m .58415 .39329 L .58575 .3957 L .312 .215 0 r
F
.59152 .39003 m .58983 .3877 L .58415 .39329 L F
.50107 .61746 m .48523 .61686 L .48504 .61837 L .713 .052 0 r
F
.50107 .61746 m .50148 .61593 L .48523 .61686 L F
.30965 .83505 m .27803 .82923 L .28138 .83302 L .938 .07 0 r
F
.3125 .83866 m .30965 .83505 L .28138 .83302 L .919 .066 0 r
F
.37803 .34972 m .36592 .32788 L .3664 .33463 L 1 .291 0 r
F
.38012 .35786 m .37803 .34972 L .3664 .33463 L 1 .583 0 r
F
.37709 .59071 m .36029 .58493 L .36112 .58716 L 1 .414 0 r
F
.37781 .59287 m .37709 .59071 L .36112 .58716 L 1 .395 0 r
F
.59319 .39236 m .58575 .3957 L .58733 .39811 L .309 .206 0 r
F
.59319 .39236 m .59152 .39003 L .58575 .3957 L F
.83537 .69935 m .81714 .70739 L .81447 .71323 L 0 0 0 r
F
.83537 .69935 m .83823 .69333 L .81714 .70739 L F
.39569 .3665 m .39422 .36283 L .39239 .36507 L .977 1 0 r
F
.39569 .3665 m .39782 .36472 L .39422 .36283 L F
.75253 .37879 m .75799 .38373 L .75907 .38884 L .804 .106 0 r
F
.75253 .37879 m .75075 .37417 L .75799 .38373 L F
.50139 .62243 m .48539 .62193 L .48519 .62352 L .709 .052 0 r
F
.50139 .62243 m .50181 .62084 L .48539 .62193 L F
.59484 .3947 m .58733 .39811 L .58888 .40053 L .307 .197 0 r
F
.59484 .3947 m .59319 .39236 L .58733 .39811 L F
.34309 .45036 m .33528 .44139 L .33424 .44389 L 1 1 0 r
F
.34216 .45291 m .34309 .45036 L .33424 .44389 L F
.33487 .5382 m .32043 .52942 L .32077 .53214 L 1 .711 0 r
F
.33522 .54085 m .33487 .5382 L .32077 .53214 L 1 .695 0 r
F
.32004 .56988 m .30616 .55939 L .30655 .56248 L 1 .679 0 r
F
.32047 .57292 m .32004 .56988 L .30655 .56248 L 1 .661 0 r
F
.25642 .8472 m .22488 .8358 L .22884 .84014 L .923 .068 0 r
F
.25996 .85129 m .25642 .8472 L .22884 .84014 L .897 .064 0 r
F
.16471 .73421 m .13568 .71845 L .13866 .72405 L 1 .242 0 r
F
.1675 .73954 m .16471 .73421 L .13866 .72405 L 1 .216 0 r
F
.59645 .39706 m .58888 .40053 L .5904 .40297 L .304 .187 0 r
F
.59645 .39706 m .59484 .3947 L .58888 .40053 L F
.53098 .30377 m .54565 .25137 L .54011 .2811 L 1 .864 0 r
F
.53098 .30377 m .53272 .28729 L .54565 .25137 L F
.51724 .61433 m .50188 .61437 L .50148 .61593 L .634 .044 0 r
F
.51724 .61433 m .51784 .61275 L .50188 .61437 L F
.41662 .61347 m .39941 .6097 L .40016 .61158 L 1 .22 0 r
F
.41721 .61528 m .41662 .61347 L .40016 .61158 L 1 .198 0 r
F
.60864 .54252 m .59638 .54576 L .59598 .54824 L .3 .029 0 r
F
.60864 .54252 m .60908 .54 L .59638 .54576 L F
.90548 .43623 m .89202 .45 L .89326 .45692 L 0 0 0 r
F
.90548 .43623 m .90418 .42925 L .89202 .45 L F
.4025 .3563 m .4013 .35284 L .39881 .35422 L .868 1 0 r
F
.4025 .3563 m .40489 .35485 L .4013 .35284 L F
.30617 .5095 m .29622 .49829 L .2958 .50139 L 1 .913 0 r
F
.30583 .51262 m .30617 .5095 L .2958 .50139 L 1 .899 0 r
F
.55027 .34297 m .54551 .34239 L .54712 .34576 L .134 .066 0 r
F
.55027 .34297 m .54848 .33988 L .54551 .34239 L F
.58999 .57201 m .5768 .57451 L .57613 .57675 L .349 .025 0 r
F
.58999 .57201 m .59075 .56973 L .5768 .57451 L F
.84779 .26531 m .84026 .28023 L .84412 .28618 L .006 .05 0 r
F
.84779 .26531 m .84381 .2595 L .84026 .28023 L F
.59804 .39943 m .5904 .40297 L .59189 .40541 L .301 .176 0 r
F
.59804 .39943 m .59645 .39706 L .5904 .40297 L F
.32031 .48729 m .30885 .47699 L .30848 .47989 L 1 .935 0 r
F
.32002 .49016 m .32031 .48729 L .30848 .47989 L 1 .922 0 r
F
.52137 .89695 m .49445 .8963 L .49377 .89857 L .431 0 0 r
F
.52137 .89695 m .5228 .89467 L .49445 .8963 L F
.20638 .81278 m .17573 .79866 L .17956 .8037 L 1 .087 0 r
F
.20991 .81755 m .20638 .81278 L .17956 .8037 L .985 .083 0 r
F
.15501 .75018 m .12709 .73251 L .13018 .73832 L 1 .186 0 r
F
.15794 .75573 m .15501 .75018 L .13018 .73832 L 1 .156 0 r
F
.51772 .61914 m .50221 .61922 L .50181 .62084 L .632 .044 0 r
F
.51772 .61914 m .51833 .61751 L .50221 .61922 L F
.89202 .59659 m .87441 .607 L .87322 .61374 L 0 0 0 r
F
.89202 .59659 m .89328 .58968 L .87441 .607 L F
.53383 .60882 m .51899 .60947 L .51842 .61113 L .554 .036 0 r
F
.53383 .60882 m .53458 .60714 L .51899 .60947 L F
.58823 .56785 m .57535 .57044 L .5747 .57264 L .342 .024 0 r
F
.58823 .56785 m .58896 .56561 L .57535 .57044 L F
.5996 .40181 m .59189 .40541 L .59335 .40787 L .298 .165 0 r
F
.5996 .40181 m .59804 .39943 L .59189 .40541 L F
.6186 .4913 m .60816 .49523 L .60836 .49786 L .257 .043 0 r
F
.6186 .4913 m .61839 .48866 L .60816 .49523 L F
.43714 .90622 m .4363 .90382 L .40741 .90265 L .579 .011 0 r
F
.46566 .90652 m .4363 .90382 L .43714 .90622 L .539 .006 0 r
F
.53831 .3073 m .54493 .28046 L .54241 .29798 L 1 .833 0 r
F
.53831 .3073 m .53827 .29746 L .54493 .28046 L F
.34216 .45291 m .33424 .44389 L .33324 .44641 L 1 1 0 r
F
.34127 .45547 m .34216 .45291 L .33324 .44641 L F
.42379 .34971 m .42249 .34759 L .42004 .34864 L .73 .895 0 r
F
.42379 .34971 m .42604 .34846 L .42249 .34759 L F
.75286 .15096 m .74747 .14663 L .75034 .16394 L .103 .091 0 r
F
.35596 .571 m .33997 .56388 L .34067 .56634 L 1 .536 0 r
F
.35661 .57338 m .35596 .571 L .34067 .56634 L 1 .518 0 r
F
.45193 .62234 m .43489 .62002 L .43532 .6217 L .92 .082 0 r
F
.45216 .62396 m .45193 .62234 L .43532 .6217 L .908 .075 0 r
F
.4687 .62402 m .45193 .62234 L .45216 .62396 L .851 .069 0 r
F
.39782 .36472 m .39616 .36072 L .39422 .36283 L 1 1 0 r
F
.39782 .36472 m .39991 .36289 L .39616 .36072 L F
.44972 .66214 m .43059 .66059 L .43118 .66236 L .797 .054 0 r
F
.45005 .66376 m .44972 .66214 L .43118 .66236 L .777 .051 0 r
F
.46829 .66265 m .44972 .66214 L .45005 .66376 L .685 .038 0 r
F
.56934 .58731 m .5557 .58923 L .55497 .5912 L .395 .026 0 r
F
.56934 .58731 m .57019 .5853 L .5557 .58923 L F
.5706 .5917 m .55673 .59353 L .55598 .59555 L .399 .027 0 r
F
.5706 .5917 m .57148 .58965 L .55673 .59353 L F
.38017 .58141 m .36488 .57493 L .36559 .57711 L 1 .454 0 r
F
.3808 .58352 m .38017 .58141 L .36559 .57711 L 1 .433 0 r
F
.62177 .49686 m .61095 .50083 L .6111 .50351 L .261 .043 0 r
F
.62177 .49686 m .6216 .49418 L .61095 .50083 L F
.60625 .53878 m .59438 .54208 L .594 .54452 L .29 .028 0 r
F
.60625 .53878 m .60667 .53631 L .59438 .54208 L F
.60112 .40421 m .59335 .40787 L .59479 .41034 L .295 .154 0 r
F
.60112 .40421 m .5996 .40181 L .59335 .40787 L F
.5345 .61349 m .5195 .61413 L .51892 .61584 L .554 .037 0 r
F
.5345 .61349 m .53527 .61176 L .5195 .61413 L F
.66273 .48838 m .65729 .49412 L .65654 .49735 L 0 0 0 r
F
.66273 .48838 m .66353 .48515 L .65729 .49412 L F
.55212 .34581 m .54712 .34576 L .54882 .34884 L .181 .078 0 r
F
.55212 .34581 m .55027 .34297 L .54712 .34576 L F
.68444 .84485 m .6626 .84812 L .65905 .85174 L .178 0 0 r
F
.68444 .84485 m .68851 .8411 L .6626 .84812 L F
.36624 .63218 m .34818 .625 L .34923 .62767 L 1 .348 0 r
F
.36721 .6347 m .36624 .63218 L .34923 .62767 L 1 .328 0 r
F
.64786 .87341 m .62455 .87526 L .62129 .87852 L .264 0 0 r
F
.64786 .87341 m .65171 .87003 L .62455 .87526 L F
.42548 .34683 m .42456 .34551 L .42206 .34643 L .546 .525 0 r
F
.42548 .34683 m .42781 .34577 L .42456 .34551 L F
.34266 .60857 m .3262 .59965 L .32705 .60255 L 1 .493 0 r
F
.34349 .61136 m .34266 .60857 L .32705 .60255 L 1 .474 0 r
F
.78542 .78016 m .76464 .78536 L .76116 .79048 L .07 0 0 r
F
.78542 .78016 m .78924 .77485 L .76464 .78536 L F
.58132 .37985 m .57434 .38275 L .57607 .38505 L .333 .286 0 r
F
.58315 .38206 m .57607 .38505 L .57779 .38737 L .332 .278 0 r
F
.58315 .38206 m .58132 .37985 L .57607 .38505 L F
.58495 .38428 m .57779 .38737 L .57947 .38969 L .331 .27 0 r
F
.58495 .38428 m .58315 .38206 L .57779 .38737 L F
.34357 .52156 m .33159 .51281 L .33162 .51539 L 1 .824 0 r
F
.34363 .52412 m .34357 .52156 L .33162 .51539 L 1 .808 0 r
F
.45228 .61665 m .43565 .61392 L .43607 .61551 L .93 .079 0 r
F
.4525 .61818 m .45228 .61665 L .43607 .61551 L .919 .075 0 r
F
.46876 .61862 m .45228 .61665 L .4525 .61818 L .86 .069 0 r
F
.57947 .37766 m .57258 .38046 L .57434 .38275 L .334 .292 0 r
F
.58132 .37985 m .57947 .37766 L .57434 .38275 L .333 .286 0 r
F
.58672 .38652 m .57947 .38969 L .58113 .39202 L .329 .261 0 r
F
.58672 .38652 m .58495 .38428 L .57947 .38969 L F
.60262 .40661 m .59479 .41034 L .59619 .41282 L .291 .143 0 r
F
.60262 .40661 m .60112 .40421 L .59479 .41034 L F
.57759 .37547 m .5708 .37816 L .57258 .38046 L .334 .297 0 r
F
.57947 .37766 m .57759 .37547 L .57258 .38046 L .334 .292 0 r
F
.58846 .38878 m .58113 .39202 L .58276 .39437 L .326 .25 0 r
F
.58846 .38878 m .58672 .38652 L .58113 .39202 L F
.57569 .3733 m .569 .37588 L .5708 .37816 L .333 .3 0 r
F
.57759 .37547 m .57569 .3733 L .5708 .37816 L .334 .297 0 r
F
.43059 .66059 m .41126 .65793 L .41209 .65989 L .894 .068 0 r
F
.43118 .66236 m .43059 .66059 L .41209 .65989 L .877 .065 0 r
F
.75133 .15275 m .74926 .16516 L .75503 .16929 L .149 .131 0 r
F
.75133 .15275 m .74549 .14903 L .74926 .16516 L F
.34127 .45547 m .33324 .44641 L .33228 .44894 L 1 1 0 r
F
.34042 .45804 m .34127 .45547 L .33228 .44894 L F
.59017 .39105 m .58276 .39437 L .58437 .39673 L .324 .239 0 r
F
.59017 .39105 m .58846 .38878 L .58276 .39437 L F
.41045 .65594 m .39114 .65198 L .39215 .65415 L .992 .103 0 r
F
.41126 .65793 m .41045 .65594 L .39215 .65415 L .978 .083 0 r
F
.57377 .37113 m .56718 .37359 L .569 .37588 L .331 .302 0 r
F
.57569 .3733 m .57377 .37113 L .569 .37588 L .333 .3 0 r
F
.55403 .34847 m .54882 .34884 L .55058 .3517 L .217 .094 0 r
F
.55403 .34847 m .55212 .34581 L .54882 .34884 L F
.59185 .39333 m .58437 .39673 L .58594 .3991 L .321 .228 0 r
F
.59185 .39333 m .59017 .39105 L .58437 .39673 L F
.57183 .36896 m .56535 .37129 L .56718 .37359 L .329 .301 0 r
F
.57377 .37113 m .57183 .36896 L .56718 .37359 L .331 .302 0 r
F
.50362 .65824 m .48652 .65935 L .48624 .6608 L .466 .007 0 r
F
.50362 .65824 m .50421 .65683 L .48652 .65935 L F
.55096 .60061 m .53672 .60189 L .53603 .60367 L .469 .03 0 r
F
.55096 .60061 m .55181 .59879 L .53672 .60189 L F
.56183 .7897 m .54282 .79931 L .54137 .80227 L .038 0 0 r
F
.56183 .7897 m .56376 .787 L .54282 .79931 L F
.77058 .49823 m .76179 .50712 L .76148 .51198 L 0 0 0 r
F
.77058 .49823 m .77072 .49334 L .76179 .50712 L F
.4069 .89335 m .37629 .88867 L .37851 .89137 L .661 .023 0 r
F
.40844 .89585 m .4069 .89335 L .37851 .89137 L .631 .018 0 r
F
.43688 .89688 m .4069 .89335 L .40844 .89585 L .6 .015 0 r
F
.60408 .40904 m .59619 .41282 L .59757 .41531 L .288 .131 0 r
F
.60408 .40904 m .60262 .40661 L .59619 .41282 L F
.56987 .36679 m .56351 .36898 L .56535 .37129 L .326 .298 0 r
F
.57183 .36896 m .56987 .36679 L .56535 .37129 L .329 .301 0 r
F
.3996 .59704 m .38362 .59167 L .3844 .59363 L 1 .322 0 r
F
.40026 .59894 m .3996 .59704 L .3844 .59363 L 1 .3 0 r
F
.59349 .39564 m .58594 .3991 L .58748 .40148 L .318 .216 0 r
F
.59349 .39564 m .59185 .39333 L .58594 .3991 L F
.60003 .60632 m .58744 .61057 L .58619 .61273 L .147 0 0 r
F
.60003 .60632 m .60142 .60411 L .58744 .61057 L F
.40489 .35485 m .40379 .3515 L .4013 .35284 L .85 1 0 r
F
.40489 .35485 m .4073 .35345 L .40379 .3515 L F
.51532 .82286 m .4922 .83094 L .49169 .83385 L .289 0 0 r
F
.51532 .82286 m .51637 .82006 L .4922 .83094 L F
.56789 .36462 m .56165 .36666 L .56351 .36898 L .321 .292 0 r
F
.56987 .36679 m .56789 .36462 L .56351 .36898 L .326 .298 0 r
F
.10962 .65358 m .08443 .633 L .08631 .63936 L 1 .42 0 r
F
.11147 .65969 m .10962 .65358 L .08631 .63936 L 1 .393 0 r
F
.62251 .5802 m .61149 .58523 L .61033 .5877 L .047 0 0 r
F
.62251 .5802 m .62375 .57768 L .61149 .58523 L F
.39991 .36289 m .39819 .35872 L .39616 .36072 L 1 1 0 r
F
.39991 .36289 m .40201 .36104 L .39819 .35872 L F
.55598 .35098 m .55058 .3517 L .55239 .35441 L .245 .147 0 r
F
.55598 .35098 m .55403 .34847 L .55058 .3517 L F
.36081 .55905 m .34676 .55143 L .34727 .55382 L 1 .609 0 r
F
.3613 .56139 m .36081 .55905 L .34727 .55382 L 1 .59 0 r
F
.55187 .60516 m .53745 .60638 L .53674 .60821 L .472 .03 0 r
F
.55187 .60516 m .55274 .6033 L .53745 .60638 L F
.56591 .36244 m .55979 .36431 L .56165 .36666 L .315 .282 0 r
F
.56789 .36462 m .56591 .36244 L .56165 .36666 L .321 .292 0 r
F
.59511 .39796 m .58748 .40148 L .589 .40388 L .314 .203 0 r
F
.59511 .39796 m .59349 .39564 L .58748 .40148 L F
.418 .60702 m .40163 .60263 L .40235 .60442 L 1 .22 0 r
F
.41857 .60875 m .418 .60702 L .40235 .60442 L 1 .197 0 r
F
.30583 .51262 m .2958 .50139 L .29542 .5045 L 1 .899 0 r
F
.30553 .51574 m .30583 .51262 L .29542 .5045 L 1 .883 0 r
F
.3483 .38658 m .34174 .37564 L .33972 .37806 L 1 1 0 r
F
.3483 .38658 m .35037 .38428 L .34174 .37564 L F
.34627 .38893 m .3483 .38658 L .33972 .37806 L F
.35037 .38428 m .3438 .37326 L .34174 .37564 L F
.35037 .38428 m .35251 .38204 L .3438 .37326 L F
.32002 .49016 m .30848 .47989 L .30816 .48278 L 1 .922 0 r
F
.31977 .49302 m .32002 .49016 L .30816 .48278 L 1 .909 0 r
F
.56392 .36023 m .55793 .36193 L .55979 .36431 L .306 .268 0 r
F
.56591 .36244 m .56392 .36023 L .55979 .36431 L .315 .282 0 r
F
.64098 .72485 m .6254 .73147 L .62324 .73471 L 0 0 0 r
F
.64098 .72485 m .64357 .72177 L .6254 .73147 L F
.34627 .38893 m .33972 .37806 L .33774 .3805 L 1 1 0 r
F
.34431 .39132 m .34627 .38893 L .33774 .3805 L F
.55795 .35339 m .55239 .35441 L .55422 .35699 L .266 .189 0 r
F
.55795 .35339 m .55598 .35098 L .55239 .35441 L F
.55816 .6374 m .5435 .64034 L .54244 .64202 L .286 0 0 r
F
.55816 .6374 m .55946 .63569 L .5435 .64034 L F
.60551 .41148 m .59757 .41531 L .59891 .41781 L .284 .119 0 r
F
.60551 .41148 m .60408 .40904 L .59757 .41531 L F
.56192 .358 m .55607 .35949 L .55793 .36193 L .296 .248 0 r
F
.56392 .36023 m .56192 .358 L .55793 .36193 L .306 .268 0 r
F
.35251 .38204 m .3459 .3709 L .3438 .37326 L 1 1 0 r
F
.35251 .38204 m .35471 .37986 L .3459 .3709 L F
.61877 .49393 m .60836 .49786 L .60852 .50048 L .251 .041 0 r
F
.61877 .49393 m .6186 .4913 L .60836 .49786 L F
.89889 .4369 m .88679 .45038 L .88776 .45723 L 0 0 0 r
F
.89889 .4369 m .89801 .42998 L .88679 .45038 L F
.43841 .34323 m .43742 .34329 L .43514 .34421 L .397 .202 0 r
F
.55993 .35572 m .55422 .35699 L .55607 .35949 L .283 .223 0 r
F
.55993 .35572 m .55795 .35339 L .55422 .35699 L F
.56192 .358 m .55993 .35572 L .55607 .35949 L .296 .248 0 r
F
.34431 .39132 m .33774 .3805 L .3358 .38297 L 1 1 0 r
F
.3424 .39376 m .34431 .39132 L .3358 .38297 L F
.59668 .4003 m .589 .40388 L .59048 .40629 L .311 .19 0 r
F
.59668 .4003 m .59511 .39796 L .589 .40388 L F
.34042 .45804 m .33228 .44894 L .33137 .45148 L 1 1 0 r
F
.3396 .46062 m .34042 .45804 L .33137 .45148 L F
.33522 .54085 m .32077 .53214 L .32115 .53485 L 1 .695 0 r
F
.3356 .54348 m .33522 .54085 L .32115 .53485 L 1 .679 0 r
F
.38921 .64754 m .37031 .64208 L .3714 .64449 L 1 .214 0 r
F
.39016 .64977 m .38921 .64754 L .3714 .64449 L 1 .194 0 r
F
.64412 .54245 m .63544 .54817 L .63451 .55098 L 0 0 0 r
F
.64412 .54245 m .64507 .53962 L .63544 .54817 L F
.3424 .39376 m .3358 .38297 L .3339 .38547 L 1 1 0 r
F
.34055 .39624 m .3424 .39376 L .3339 .38547 L F
.53913 .64678 m .52365 .64914 L .5228 .65067 L .343 0 0 r
F
.53913 .64678 m .54025 .64524 L .52365 .64914 L F
.60815 .54501 m .59598 .54824 L .59554 .55071 L .294 .027 0 r
F
.60815 .54501 m .60864 .54252 L .59598 .54824 L F
.39797 .60585 m .38095 .60123 L .3818 .60324 L 1 .294 0 r
F
.39868 .60779 m .39797 .60585 L .3818 .60324 L 1 .272 0 r
F
.59822 .40265 m .59048 .40629 L .59192 .40872 L .307 .177 0 r
F
.59822 .40265 m .59668 .4003 L .59048 .40629 L F
.26839 .81741 m .23697 .809 L .24054 .81323 L .998 .08 0 r
F
.27153 .82143 m .26839 .81741 L .24054 .81323 L .98 .076 0 r
F
.6219 .49954 m .6111 .50351 L .61122 .50617 L .256 .04 0 r
F
.6219 .49954 m .62177 .49686 L .6111 .50351 L F
.52107 .6536 m .50479 .65537 L .50421 .65683 L .4 0 0 r
F
.52107 .6536 m .52194 .65216 L .50479 .65537 L F
.43489 .62002 m .41781 .61706 L .41843 .6188 L .979 .133 0 r
F
.43532 .6217 m .43489 .62002 L .41843 .6188 L .968 .111 0 r
F
.58052 .30738 m .65447 .19467 L .65253 .20809 L .393 .03 0 r
F
.58052 .30738 m .56909 .3198 L .65447 .19467 L F
.6069 .41393 m .59891 .41781 L .60021 .42033 L .28 .107 0 r
F
.6069 .41393 m .60551 .41148 L .59891 .41781 L F
.72846 .81658 m .70765 .82093 L .70398 .82515 L .109 0 0 r
F
.72846 .81658 m .73255 .8122 L .70765 .82093 L F
.34055 .39624 m .3339 .38547 L .33206 .38799 L 1 1 0 r
F
.33874 .39875 m .34055 .39624 L .33206 .38799 L F
.32047 .57292 m .30655 .56248 L .30698 .56555 L 1 .661 0 r
F
.32094 .57594 m .32047 .57292 L .30698 .56555 L 1 .642 0 r
F
.26003 .84103 m .22916 .82964 L .23302 .83395 L .928 .069 0 r
F
.2635 .84508 m .26003 .84103 L .23302 .83395 L .902 .065 0 r
F
.10045 .66518 m .07658 .64337 L .07844 .64994 L 1 .383 0 r
F
.10231 .67152 m .10045 .66518 L .07844 .64994 L 1 .354 0 r
F
.57814 .62486 m .56445 .62842 L .56324 .6303 L .22 0 0 r
F
.57814 .62486 m .57954 .62294 L .56445 .62842 L F
.59973 .40502 m .59192 .40872 L .59334 .41116 L .303 .163 0 r
F
.59973 .40502 m .59822 .40265 L .59192 .40872 L F
.46878 .6201 m .46876 .61862 L .4525 .61818 L .847 .066 0 r
F
.48483 .61986 m .46876 .61862 L .46878 .6201 L .779 .058 0 r
F
.48483 .61986 m .48504 .61837 L .46876 .61862 L F
.84111 .71074 m .82155 .71803 L .8188 .72399 L 0 0 0 r
F
.84111 .71074 m .84408 .70458 L .82155 .71803 L F
.70997 .6532 m .69497 .65902 L .69306 .66294 L .025 0 0 r
F
.70997 .6532 m .71214 .64924 L .69497 .65902 L F
.46872 .62558 m .4687 .62402 L .45216 .62396 L .839 .066 0 r
F
.48498 .62507 m .4687 .62402 L .46872 .62558 L .772 .058 0 r
F
.48498 .62507 m .48519 .62352 L .4687 .62402 L F
.75425 .38342 m .75907 .38884 L .76013 .39393 L .781 .103 0 r
F
.75425 .38342 m .75253 .37879 L .75907 .38884 L F
.40201 .36104 m .4003 .35681 L .39819 .35872 L 1 1 0 r
F
.40201 .36104 m .40412 .35923 L .4003 .35681 L F
.22029 .78678 m .18957 .77517 L .19307 .78 L 1 .111 0 r
F
.22347 .79136 m .22029 .78678 L .19307 .78 L 1 .091 0 r
F
.37781 .59287 m .36112 .58716 L .36198 .58937 L 1 .395 0 r
F
.37855 .595 m .37781 .59287 L .36198 .58937 L 1 .374 0 r
F
.33874 .39875 m .33206 .38799 L .33025 .39055 L 1 1 0 r
F
.337 .4013 m .33874 .39875 L .33025 .39055 L F
.74633 .59159 m .73273 .5987 L .73138 .60309 L 0 0 0 r
F
.74633 .59159 m .74778 .5871 L .73273 .5987 L F
.71666 .1638 m .71135 .17875 L .71349 .18639 L .063 .048 0 r
F
.71666 .1638 m .71311 .15783 L .71135 .17875 L F
.34363 .52412 m .33162 .51539 L .33168 .51797 L 1 .808 0 r
F
.34373 .52667 m .34363 .52412 L .33168 .51797 L 1 .792 0 r
F
.60826 .4164 m .60021 .42033 L .60149 .42286 L .277 .095 0 r
F
.60826 .4164 m .6069 .41393 L .60021 .42033 L F
.42604 .34846 m .42497 .34667 L .42249 .34759 L .644 .781 0 r
F
.42604 .34846 m .4283 .3473 L .42497 .34667 L F
.3396 .46062 m .33137 .45148 L .33049 .45403 L 1 1 0 r
F
.33883 .46321 m .3396 .46062 L .33049 .45403 L F
.58919 .57426 m .57613 .57675 L .57543 .57897 L .343 .023 0 r
F
.58919 .57426 m .58999 .57201 L .57613 .57675 L F
.70222 .35522 m .70047 .3605 L .69901 .36633 L 0 0 0 r
F
.70222 .35522 m .70327 .34954 L .70047 .3605 L F
.6012 .40741 m .59334 .41116 L .59472 .41362 L .299 .15 0 r
F
.6012 .40741 m .59973 .40502 L .59334 .41116 L F
.60579 .54123 m .594 .54452 L .59358 .54694 L .285 .025 0 r
F
.60579 .54123 m .60625 .53878 L .594 .54452 L F
.53834 .80785 m .5174 .81714 L .51637 .82006 L .156 0 0 r
F
.53834 .80785 m .53987 .80512 L .5174 .81714 L F
.4377 .89921 m .43688 .89688 L .40844 .89585 L .569 .009 0 r
F
.46575 .89933 m .43688 .89688 L .4377 .89921 L .524 .003 0 r
F
.21114 .80682 m .18125 .79271 L .18497 .79771 L 1 .088 0 r
F
.21457 .81154 m .21114 .80682 L .18497 .79771 L .99 .084 0 r
F
.337 .4013 m .33025 .39055 L .3285 .39313 L 1 1 0 r
F
.33531 .40389 m .337 .4013 L .3285 .39313 L F
.58746 .57006 m .5747 .57264 L .57403 .57482 L .337 .022 0 r
F
.58746 .57006 m .58823 .56785 L .5747 .57264 L F
.4073 .35345 m .40631 .35022 L .40379 .3515 L .829 1 0 r
F
.4073 .35345 m .40972 .35211 L .40631 .35022 L F
.43565 .61392 m .41916 .61044 L .41976 .61209 L .993 .13 0 r
F
.43607 .61551 m .43565 .61392 L .41976 .61209 L .981 .108 0 r
F
.61139 .74966 m .59533 .75765 L .59328 .76071 L 0 0 0 r
F
.61139 .74966 m .6139 .74685 L .59533 .75765 L F
.60263 .40982 m .59472 .41362 L .59607 .41608 L .294 .136 0 r
F
.60263 .40982 m .6012 .40741 L .59472 .41362 L F
.88182 .59378 m .86666 .60457 L .86536 .61114 L 0 0 0 r
F
.88182 .59378 m .88321 .58707 L .86666 .60457 L F
.60959 .41888 m .60149 .42286 L .60273 .4254 L .273 .083 0 r
F
.60959 .41888 m .60826 .4164 L .60149 .42286 L F
.6189 .49655 m .60852 .50048 L .60864 .5031 L .246 .039 0 r
F
.6189 .49655 m .61877 .49393 L .60852 .50048 L F
.35661 .57338 m .34067 .56634 L .34142 .56878 L 1 .518 0 r
F
.35728 .57574 m .35661 .57338 L .34142 .56878 L 1 .5 0 r
F
.31977 .49302 m .30816 .48278 L .30789 .48567 L 1 .909 0 r
F
.31957 .49587 m .31977 .49302 L .30789 .48567 L 1 .895 0 r
F
.30553 .51574 m .29542 .5045 L .29508 .50761 L 1 .883 0 r
F
.30528 .51887 m .30553 .51574 L .29508 .50761 L 1 .868 0 r
F
.42781 .34577 m .42707 .34465 L .42456 .34551 L .507 .413 0 r
F
.42781 .34577 m .43014 .34477 L .42707 .34465 L F
.50066 .61895 m .48504 .61837 L .48483 .61986 L .7 .049 0 r
F
.50066 .61895 m .50107 .61746 L .48504 .61837 L F
.66193 .49156 m .65654 .49735 L .65579 .50055 L 0 0 0 r
F
.66193 .49156 m .66273 .48838 L .65654 .49735 L F
.33531 .40389 m .3285 .39313 L .32679 .39573 L 1 1 0 r
F
.33367 .4065 m .33531 .40389 L .32679 .39573 L F
.40412 .35923 m .40248 .35499 L .4003 .35681 L F
.40412 .35923 m .40627 .35745 L .40248 .35499 L F
.3808 .58352 m .36559 .57711 L .36633 .57926 L 1 .433 0 r
F
.38147 .5856 m .3808 .58352 L .36633 .57926 L 1 .411 0 r
F
.60403 .41224 m .59607 .41608 L .59738 .41856 L .29 .121 0 r
F
.60403 .41224 m .60263 .40982 L .59607 .41608 L F
.3641 .37186 m .35662 .35921 L .35449 .36158 L 1 1 0 r
F
.3641 .37186 m .3666 .37006 L .35662 .35921 L F
.33883 .46321 m .33049 .45403 L .32965 .45659 L F
.33809 .4658 m .33883 .46321 L .32965 .45659 L F
.85166 .27119 m .84412 .28618 L .84787 .29219 L 0 .047 0 r
F
.85166 .27119 m .84779 .26531 L .84412 .28618 L F
.41721 .61528 m .40016 .61158 L .40094 .61343 L 1 .198 0 r
F
.41781 .61706 m .41721 .61528 L .40094 .61343 L 1 .175 0 r
F
.62199 .50221 m .61122 .50617 L .61129 .50883 L .251 .038 0 r
F
.62199 .50221 m .6219 .49954 L .61122 .50617 L F
.50097 .62397 m .48519 .62352 L .48498 .62507 L .695 .049 0 r
F
.50097 .62397 m .50139 .62243 L .48519 .62352 L F
.56846 .5893 m .55497 .5912 L .55422 .59315 L .389 .023 0 r
F
.56846 .5893 m .56934 .58731 L .55497 .5912 L F
.61088 .42137 m .60273 .4254 L .60393 .42795 L .268 .079 0 r
F
.61088 .42137 m .60959 .41888 L .60273 .4254 L F
.64417 .8652 m .62157 .8676 L .61834 .8707 L .232 0 0 r
F
.64417 .8652 m .64799 .86199 L .62157 .8676 L F
.56969 .59372 m .55598 .59555 L .55521 .59753 L .393 .024 0 r
F
.56969 .59372 m .5706 .5917 L .55598 .59555 L F
.51663 .61588 m .50148 .61593 L .50107 .61746 L .621 .041 0 r
F
.51663 .61588 m .51724 .61433 L .50148 .61593 L F
.15162 .76128 m .12293 .7438 L .12627 .74962 L 1 .149 0 r
F
.15476 .76683 m .15162 .76128 L .12627 .74962 L 1 .121 0 r
F
.77834 .7734 m .75873 .77922 L .75526 .78417 L .027 0 0 r
F
.77834 .7734 m .78213 .76827 L .75873 .77922 L F
.90667 .44324 m .89326 .45692 L .89438 .46386 L 0 0 0 r
F
.90667 .44324 m .90548 .43623 L .89326 .45692 L F
.33367 .4065 m .32679 .39573 L .32513 .39836 L 1 1 0 r
F
.342 .39717 m .33849 .38864 L .33633 .39083 L F
.342 .39717 m .34407 .39488 L .33849 .38864 L F
.33997 .39951 m .342 .39717 L .33633 .39083 L F
.3613 .56139 m .34727 .55382 L .34781 .55619 L 1 .59 0 r
F
.36181 .5637 m .3613 .56139 L .34781 .55619 L 1 .57 0 r
F
.34407 .39488 m .3407 .38649 L .33849 .38864 L 1 1 0 r
F
.34407 .39488 m .34618 .39263 L .3407 .38649 L F
.33997 .39951 m .33633 .39083 L .33421 .39307 L F
.33798 .40188 m .33997 .39951 L .33421 .39307 L F
.60539 .41468 m .59738 .41856 L .59866 .42106 L .285 .107 0 r
F
.60539 .41468 m .60403 .41224 L .59738 .41856 L F
.34618 .39263 m .34295 .3844 L .3407 .38649 L 1 1 0 r
F
.34618 .39263 m .34833 .39043 L .34295 .3844 L F
.6728 .69595 m .65762 .70176 L .65545 .70526 L .02 0 0 r
F
.6728 .69595 m .67533 .69251 L .65762 .70176 L F
.53306 .61046 m .51842 .61113 L .51784 .61275 L .541 .033 0 r
F
.53306 .61046 m .53383 .60882 L .51842 .61113 L F
.33798 .40188 m .33421 .39307 L .33214 .39535 L 1 1 0 r
F
.33603 .4043 m .33798 .40188 L .33214 .39535 L F
.3356 .54348 m .32115 .53485 L .32158 .53754 L 1 .679 0 r
F
.33602 .54609 m .3356 .54348 L .32158 .53754 L 1 .662 0 r
F
.34833 .39043 m .34524 .38235 L .34295 .3844 L 1 1 0 r
F
.34833 .39043 m .35051 .38827 L .34524 .38235 L F
.34349 .61136 m .32705 .60255 L .32793 .60544 L 1 .474 0 r
F
.34436 .61413 m .34349 .61136 L .32793 .60544 L 1 .454 0 r
F
.3666 .37006 m .35871 .35677 L .35662 .35921 L 1 .983 0 r
F
.3666 .37006 m .36916 .36837 L .35871 .35677 L F
.33603 .4043 m .33214 .39535 L .33011 .39768 L 1 1 0 r
F
.33412 .40675 m .33603 .4043 L .33011 .39768 L F
.5171 .62073 m .50181 .62084 L .50139 .62243 L .618 .041 0 r
F
.5171 .62073 m .51772 .61914 L .50181 .62084 L F
.60763 .5475 m .59554 .55071 L .59507 .55316 L .288 .024 0 r
F
.60763 .5475 m .60815 .54501 L .59554 .55071 L F
.41145 .85302 m .38185 .8536 L .38377 .85661 L .722 .043 0 r
F
.41275 .85594 m .41145 .85302 L .38377 .85661 L .699 .039 0 r
F
.43982 .85049 m .41145 .85302 L .41275 .85594 L .627 .032 0 r
F
.61213 .42388 m .60393 .42795 L .60511 .43051 L .264 .077 0 r
F
.61213 .42388 m .61088 .42137 L .60393 .42795 L F
.35051 .38827 m .34758 .38037 L .34524 .38235 L 1 1 0 r
F
.35051 .38827 m .35273 .38616 L .34758 .38037 L F
.46832 .66413 m .46829 .66265 L .45005 .66376 L .662 .034 0 r
F
.48596 .66221 m .46829 .66265 L .46832 .66413 L .556 .019 0 r
F
.48596 .66221 m .48624 .6608 L .46829 .66265 L F
.09364 .67601 m .06859 .65419 L .07073 .66084 L 1 .349 0 r
F
.09573 .68242 m .09364 .67601 L .07073 .66084 L 1 .32 0 r
F
.33412 .40675 m .33011 .39768 L .32813 .40004 L 1 1 0 r
F
.33225 .40923 m .33412 .40675 L .32813 .40004 L F
.37475 .89527 m .34352 .88931 L .34643 .89225 L .708 .03 0 r
F
.37701 .89801 m .37475 .89527 L .34643 .89225 L .677 .025 0 r
F
.34373 .52667 m .33168 .51797 L .33179 .52053 L 1 .792 0 r
F
.34386 .5292 m .34373 .52667 L .33179 .52053 L 1 .776 0 r
F
.60671 .41713 m .59866 .42106 L .5999 .42356 L .28 .093 0 r
F
.60671 .41713 m .60539 .41468 L .59866 .42106 L F
.53371 .61518 m .51892 .61584 L .51833 .61751 L .54 .033 0 r
F
.53371 .61518 m .5345 .61349 L .51892 .61584 L F
.33809 .4658 m .32965 .45659 L .32886 .45916 L 1 1 0 r
F
.33739 .4684 m .33809 .4658 L .32886 .45916 L F
.40627 .35745 m .40472 .35326 L .40248 .35499 L F
.40627 .35745 m .40845 .35574 L .40472 .35326 L F
.35273 .38616 m .34996 .37844 L .34758 .38037 L F
.35273 .38616 m .35499 .3841 L .34996 .37844 L F
.77037 .50311 m .76148 .51198 L .76111 .51682 L 0 0 0 r
F
.77037 .50311 m .77058 .49823 L .76148 .51198 L F
.40972 .35211 m .40885 .34902 L .40631 .35022 L .802 .983 0 r
F
.40972 .35211 m .41215 .35083 L .40885 .34902 L F
.45216 .62396 m .43532 .6217 L .43576 .62333 L .908 .075 0 r
F
.45239 .62553 m .45216 .62396 L .43576 .62333 L .895 .072 0 r
F
.46872 .62558 m .45216 .62396 L .45239 .62553 L .839 .066 0 r
F
.33225 .40923 m .32813 .40004 L .32619 .40245 L 1 1 0 r
F
.40026 .59894 m .3844 .59363 L .38519 .59557 L 1 .3 0 r
F
.40094 .6008 m .40026 .59894 L .38519 .59557 L 1 .276 0 r
F
.36721 .6347 m .34923 .62767 L .35031 .63031 L 1 .328 0 r
F
.36821 .63719 m .36721 .6347 L .35031 .63031 L 1 .308 0 r
F
.61899 .49917 m .60864 .5031 L .60872 .50571 L .24 .036 0 r
F
.61899 .49917 m .6189 .49655 L .60864 .5031 L F
.55008 .6024 m .53603 .60367 L .53532 .60542 L .457 .027 0 r
F
.55008 .6024 m .55096 .60061 L .53603 .60367 L F
.64314 .54527 m .63451 .55098 L .63356 .55377 L 0 0 0 r
F
.64314 .54527 m .64412 .54245 L .63451 .55098 L F
.75708 .1566 m .75133 .15275 L .75503 .16929 L .135 .108 0 r
F
.62125 .5827 m .61033 .5877 L .60914 .59014 L .039 0 0 r
F
.62125 .5827 m .62251 .5802 L .61033 .5877 L F
.44049 .34217 m .43971 .34242 L .43742 .34329 L .322 .189 0 r
F
.35499 .3841 m .35239 .37657 L .34996 .37844 L 1 1 0 r
F
.35499 .3841 m .35728 .38209 L .35239 .37657 L F
.32094 .57594 m .30698 .56555 L .30745 .56863 L 1 .642 0 r
F
.32145 .57895 m .32094 .57594 L .30745 .56863 L 1 .624 0 r
F
.31957 .49587 m .30789 .48567 L .30766 .48855 L 1 .895 0 r
F
.31941 .49872 m .31957 .49587 L .30766 .48855 L 1 .881 0 r
F
.60528 .54366 m .59358 .54694 L .59312 .54934 L .279 .022 0 r
F
.60528 .54366 m .60579 .54123 L .59358 .54694 L F
.4525 .61818 m .43607 .61551 L .4365 .61707 L .919 .075 0 r
F
.45273 .61967 m .4525 .61818 L .4365 .61707 L .906 .072 0 r
F
.46878 .6201 m .4525 .61818 L .45273 .61967 L .847 .066 0 r
F
.61334 .42641 m .60511 .43051 L .60624 .43308 L .26 .076 0 r
F
.61334 .42641 m .61213 .42388 L .60511 .43051 L F
.36916 .36837 m .3607 .35419 L .35871 .35677 L 1 .938 0 r
F
.36916 .36837 m .37178 .36676 L .3607 .35419 L F
.60799 .41959 m .5999 .42356 L .60111 .42608 L .275 .08 0 r
F
.60799 .41959 m .60671 .41713 L .5999 .42356 L F
.61117 .88768 m .58722 .88881 L .58445 .89166 L .308 0 0 r
F
.61117 .88768 m .6146 .88474 L .58722 .88881 L F
.4283 .3473 m .42745 .34583 L .42497 .34667 L .579 .642 0 r
F
.4283 .3473 m .43058 .34622 L .42745 .34583 L F
.30528 .51887 m .29508 .50761 L .2948 .51073 L 1 .868 0 r
F
.30508 .522 m .30528 .51887 L .2948 .51073 L 1 .851 0 r
F
.55097 .60699 m .53674 .60821 L .53601 .61 L .459 .027 0 r
F
.55097 .60699 m .55187 .60516 L .53674 .60821 L F
.89063 .60348 m .87322 .61374 L .87192 .62046 L 0 0 0 r
F
.89063 .60348 m .89202 .59659 L .87322 .61374 L F
.35728 .38209 m .35486 .37476 L .35239 .37657 L 1 1 0 r
F
.35728 .38209 m .35961 .38012 L .35486 .37476 L F
.41857 .60875 m .40235 .60442 L .4031 .60619 L 1 .197 0 r
F
.41916 .61044 m .41857 .60875 L .4031 .60619 L 1 .173 0 r
F
.62203 .50488 m .61129 .50883 L .61133 .51148 L .245 .036 0 r
F
.62203 .50488 m .62199 .50221 L .61129 .50883 L F
.59861 .60849 m .58619 .61273 L .58491 .61485 L .137 0 0 r
F
.59861 .60849 m .60003 .60632 L .58619 .61273 L F
.54965 .90249 m .52374 .90224 L .5223 .90464 L .397 0 0 r
F
.54965 .90249 m .55184 .90004 L .52374 .90224 L F
.75592 .38807 m .76013 .39393 L .76115 .399 L .758 .1 0 r
F
.75592 .38807 m .75425 .38342 L .76013 .39393 L F
.8324 .70531 m .81447 .71323 L .81169 .71901 L 0 0 0 r
F
.8324 .70531 m .83537 .69935 L .81447 .71323 L F
.33739 .4684 m .32886 .45916 L .32811 .46174 L 1 1 0 r
F
.33673 .471 m .33739 .4684 L .32811 .46174 L F
.58836 .57649 m .57543 .57897 L .5747 .58116 L .338 .02 0 r
F
.58836 .57649 m .58919 .57426 L .57543 .57897 L F
.60923 .42207 m .60111 .42608 L .60227 .42861 L .27 .078 0 r
F
.60923 .42207 m .60799 .41959 L .60111 .42608 L F
.39868 .60779 m .3818 .60324 L .38268 .60522 L 1 .272 0 r
F
.39941 .6097 m .39868 .60779 L .38268 .60522 L 1 .25 0 r
F
.61452 .42894 m .60624 .43308 L .60734 .43567 L .255 .074 0 r
F
.61452 .42894 m .61334 .42641 L .60624 .43308 L F
.35961 .38012 m .35737 .37302 L .35486 .37476 L 1 1 0 r
F
.35961 .38012 m .36196 .37821 L .35737 .37302 L F
.37855 .595 m .36198 .58937 L .36287 .59155 L 1 .374 0 r
F
.37932 .59711 m .37855 .595 L .36287 .59155 L 1 .353 0 r
F
.40845 .35574 m .40701 .35163 L .40472 .35326 L 1 1 0 r
F
.40845 .35574 m .41068 .35411 L .40701 .35163 L F
.58666 .57225 m .57403 .57482 L .57332 .57697 L .331 .019 0 r
F
.58666 .57225 m .58746 .57006 L .57403 .57482 L F
.37178 .36676 m .36254 .35139 L .3607 .35419 L 1 .889 0 r
F
.37178 .36676 m .37443 .36524 L .36254 .35139 L F
.89962 .44384 m .88776 .45723 L .88861 .46409 L 0 0 0 r
F
.89962 .44384 m .89889 .4369 L .88776 .45723 L F
.54577 .25116 m .55057 .231 L .54306 .2679 L .958 .283 0 r
F
.54577 .25116 m .5503 .22229 L .55057 .231 L F
.45005 .66376 m .43118 .66236 L .43179 .6641 L .777 .051 0 r
F
.45038 .66533 m .45005 .66376 L .43179 .6641 L .757 .047 0 r
F
.46832 .66413 m .45005 .66376 L .45038 .66533 L .662 .034 0 r
F
.43014 .34477 m .42957 .34384 L .42707 .34465 L .465 .301 0 r
F
.43014 .34477 m .43247 .34383 L .42957 .34384 L F
.35728 .57574 m .34142 .56878 L .34219 .57119 L 1 .5 0 r
F
.35799 .57807 m .35728 .57574 L .34219 .57119 L 1 .481 0 r
F
.41126 .65793 m .39215 .65415 L .39318 .65629 L .978 .083 0 r
F
.41209 .65989 m .41126 .65793 L .39318 .65629 L .963 .077 0 r
F
.66114 .49472 m .65579 .50055 L .65503 .50372 L 0 0 0 r
F
.66114 .49472 m .66193 .49156 L .65579 .50055 L F
.38012 .35786 m .3664 .33463 L .3662 .3401 L 1 .583 0 r
F
.37932 .36176 m .38012 .35786 L .3662 .3401 L 1 .803 0 r
F
.1675 .73954 m .13866 .72405 L .14174 .7296 L 1 .216 0 r
F
.17039 .74481 m .1675 .73954 L .14174 .7296 L 1 .189 0 r
F
.36196 .37821 m .35992 .37134 L .35737 .37302 L 1 1 0 r
F
.36196 .37821 m .36434 .37635 L .35992 .37134 L F
.61043 .42457 m .60227 .42861 L .60341 .43115 L .265 .076 0 r
F
.61043 .42457 m .60923 .42207 L .60227 .42861 L F
.43532 .6217 m .41843 .6188 L .41907 .6205 L .968 .111 0 r
F
.43576 .62333 m .43532 .6217 L .41907 .6205 L .955 .088 0 r
F
.34066 .88627 m .30922 .87891 L .31267 .88217 L .763 .039 0 r
F
.34352 .88931 m .34066 .88627 L .31267 .88217 L .733 .034 0 r
F
.43118 .66236 m .41209 .65989 L .41294 .6618 L .877 .065 0 r
F
.43179 .6641 m .43118 .66236 L .41294 .6618 L .86 .062 0 r
F
.34386 .5292 m .33179 .52053 L .33194 .52309 L 1 .776 0 r
F
.34404 .53173 m .34386 .5292 L .33194 .52309 L 1 .759 0 r
F
.41215 .35083 m .41142 .34789 L .40885 .34902 L .77 .956 0 r
F
.41215 .35083 m .41461 .34961 L .41142 .34789 L F
.61903 .50178 m .60872 .50571 L .60876 .50832 L .234 .034 0 r
F
.61903 .50178 m .61899 .49917 L .60872 .50571 L F
.61565 .43149 m .60734 .43567 L .6084 .43826 L .251 .072 0 r
F
.61565 .43149 m .61452 .42894 L .60734 .43567 L F
.36181 .5637 m .34781 .55619 L .3484 .55854 L 1 .57 0 r
F
.36236 .56599 m .36181 .5637 L .3484 .55854 L 1 .549 0 r
F
.39016 .64977 m .3714 .64449 L .37252 .64687 L 1 .194 0 r
F
.39114 .65198 m .39016 .64977 L .37252 .64687 L 1 .173 0 r
F
.33602 .54609 m .32158 .53754 L .32204 .54021 L 1 .662 0 r
F
.33648 .54869 m .33602 .54609 L .32204 .54021 L 1 .645 0 r
F
.38147 .5856 m .36633 .57926 L .36711 .58138 L 1 .411 0 r
F
.38216 .58765 m .38147 .5856 L .36711 .58138 L 1 .389 0 r
F
.55684 .63906 m .54244 .64202 L .54135 .64365 L .272 0 0 r
F
.55684 .63906 m .55816 .6374 L .54244 .64202 L F
.33673 .471 m .32811 .46174 L .3274 .46432 L 1 1 0 r
F
.33611 .47361 m .33673 .471 L .3274 .46432 L F
.58446 .77191 m .56746 .78125 L .56564 .78418 L 0 0 0 r
F
.58446 .77191 m .58676 .76927 L .56746 .78125 L F
.4688 .62154 m .46878 .6201 L .45273 .61967 L .834 .063 0 r
F
.48463 .6213 m .46878 .6201 L .4688 .62154 L .766 .055 0 r
F
.48463 .6213 m .48483 .61986 L .46878 .6201 L F
.74481 .59605 m .73138 .60309 L .72997 .60746 L 0 0 0 r
F
.74481 .59605 m .74633 .59159 L .73138 .60309 L F
.60706 .54996 m .59507 .55316 L .59456 .55559 L .283 .021 0 r
F
.60706 .54996 m .60763 .5475 L .59507 .55316 L F
.31941 .49872 m .30766 .48855 L .30748 .49143 L 1 .881 0 r
F
.31929 .50156 m .31941 .49872 L .30748 .49143 L 1 .867 0 r
F
.46639 .84594 m .46634 .84311 L .43982 .85049 L .495 .015 0 r
F
.49115 .83664 m .46634 .84311 L .46639 .84594 L .386 0 0 r
F
.49115 .83664 m .49169 .83385 L .46634 .84311 L F
.30251 .87207 m .27102 .86299 L .27486 .8667 L .828 .05 0 r
F
.30584 .87554 m .30251 .87207 L .27486 .8667 L .799 .046 0 r
F
.36434 .37635 m .36251 .36974 L .35992 .37134 L 1 1 0 r
F
.36434 .37635 m .36675 .37454 L .36251 .36974 L F
.50303 .6596 m .48624 .6608 L .48596 .66221 L .446 .002 0 r
F
.50303 .6596 m .50362 .65824 L .48624 .6608 L F
.46874 .6271 m .46872 .62558 L .45239 .62553 L .825 .063 0 r
F
.48477 .62657 m .46872 .62558 L .46874 .6271 L .759 .055 0 r
F
.48477 .62657 m .48498 .62507 L .46872 .62558 L F
.5767 .62675 m .56324 .6303 L .562 .63214 L .208 0 0 r
F
.5767 .62675 m .57814 .62486 L .56324 .6303 L F
.37443 .36524 m .36415 .34824 L .36254 .35139 L 1 .84 0 r
F
.37443 .36524 m .37704 .3637 L .36415 .34824 L F
.11147 .65969 m .08631 .63936 L .0883 .64569 L 1 .393 0 r
F
.11343 .66577 m .11147 .65969 L .0883 .64569 L 1 .366 0 r
F
.15794 .75573 m .13018 .73832 L .13338 .74407 L 1 .156 0 r
F
.16098 .76122 m .15794 .75573 L .13338 .74407 L 1 .128 0 r
F
.37629 .88867 m .34555 .88282 L .34841 .88572 L .707 .03 0 r
F
.37851 .89137 m .37629 .88867 L .34841 .88572 L .677 .025 0 r
F
.61159 .42707 m .60341 .43115 L .6045 .4337 L .26 .074 0 r
F
.61159 .42707 m .61043 .42457 L .60341 .43115 L F
.56754 .59125 m .55422 .59315 L .55344 .59506 L .383 .02 0 r
F
.56754 .59125 m .56846 .5893 L .55422 .59315 L F
.30508 .522 m .2948 .51073 L .29456 .51385 L 1 .851 0 r
F
.30492 .52513 m .30508 .522 L .29456 .51385 L 1 .835 0 r
F
.62203 .50754 m .61133 .51148 L .61133 .51413 L .24 .033 0 r
F
.62203 .50754 m .62203 .50488 L .61133 .51148 L F
.70105 .36081 m .69901 .36633 L .69751 .37202 L 0 0 0 r
F
.70105 .36081 m .70222 .35522 L .69901 .36633 L F
.41068 .35411 m .40937 .3501 L .40701 .35163 L .997 1 0 r
F
.41068 .35411 m .41295 .35257 L .40937 .3501 L F
.43607 .61551 m .41976 .61209 L .42038 .61371 L .981 .108 0 r
F
.4365 .61707 m .43607 .61551 L .42038 .61371 L .968 .085 0 r
F
.56875 .59572 m .55521 .59753 L .55441 .59949 L .387 .021 0 r
F
.56875 .59572 m .56969 .59372 L .55521 .59753 L F
.61675 .43405 m .6084 .43826 L .60943 .44087 L .246 .07 0 r
F
.61675 .43405 m .61565 .43149 L .6084 .43826 L F
.538 .64828 m .5228 .65067 L .52194 .65216 L .328 0 0 r
F
.538 .64828 m .53913 .64678 L .5228 .65067 L F
.60474 .54608 m .59312 .54934 L .59263 .55173 L .273 .02 0 r
F
.60474 .54608 m .60528 .54366 L .59312 .54934 L F
.70773 .6571 m .69306 .66294 L .69109 .66682 L .007 0 0 r
F
.70773 .6571 m .70997 .6532 L .69306 .66294 L F
.36675 .37454 m .36514 .36821 L .36251 .36974 L 1 1 0 r
F
.36675 .37454 m .36918 .37278 L .36514 .36821 L F
.85542 .27715 m .84787 .29219 L .85151 .29827 L 0 .043 0 r
F
.85542 .27715 m .85166 .27119 L .84787 .29219 L F
.68491 .85662 m .66286 .85928 L .65921 .86296 L .2 0 0 r
F
.68491 .85662 m .68909 .8528 L .66286 .85928 L F
.57877 .89703 m .55399 .89748 L .55184 .90004 L .351 0 0 r
F
.57877 .89703 m .58163 .8944 L .55399 .89748 L F
.52018 .655 m .50421 .65683 L .50362 .65824 L .385 0 0 r
F
.52018 .655 m .52107 .6536 L .50421 .65683 L F
.41781 .61706 m .40094 .61343 L .40173 .61524 L 1 .175 0 r
F
.41843 .6188 m .41781 .61706 L .40173 .61524 L 1 .151 0 r
F
.50023 .6204 m .48483 .61986 L .48463 .6213 L .686 .046 0 r
F
.50023 .6204 m .50066 .61895 L .48483 .61986 L F
.43058 .34622 m .42993 .345 L .42745 .34583 L .538 .507 0 r
F
.43058 .34622 m .43286 .34519 L .42993 .345 L F
.61271 .42959 m .6045 .4337 L .60556 .43626 L .254 .072 0 r
F
.61271 .42959 m .61159 .42707 L .6045 .4337 L F
.33611 .47361 m .3274 .46432 L .32673 .46691 L 1 1 0 r
F
.33553 .47622 m .33611 .47361 L .32673 .46691 L F
.34436 .61413 m .32793 .60544 L .32885 .6083 L 1 .454 0 r
F
.34526 .61688 m .34436 .61413 L .32885 .6083 L 1 .435 0 r
F
.32145 .57895 m .30745 .56863 L .30797 .57169 L 1 .624 0 r
F
.322 .58195 m .32145 .57895 L .30797 .57169 L 1 .605 0 r
F
.4405 .85332 m .43982 .85049 L .41275 .85594 L .601 .027 0 r
F
.46639 .84594 m .43982 .85049 L .4405 .85332 L .495 .015 0 r
F
.72999 .82856 m .70877 .83224 L .705 .83654 L .135 0 0 r
F
.72999 .82856 m .73421 .8241 L .70877 .83224 L F
.37704 .3637 m .36541 .34455 L .36415 .34824 L 1 .809 0 r
F
.37704 .3637 m .37932 .36176 L .36541 .34455 L F
.64214 .54806 m .63356 .55377 L .63258 .55653 L 0 0 0 r
F
.64214 .54806 m .64314 .54527 L .63356 .55377 L F
.38185 .8536 m .35163 .85224 L .35414 .85537 L .789 .05 0 r
F
.38377 .85661 m .38185 .8536 L .35414 .85537 L .768 .046 0 r
F
.10231 .67152 m .07844 .64994 L .08043 .65647 L 1 .354 0 r
F
.10429 .67783 m .10231 .67152 L .08043 .65647 L 1 .324 0 r
F
.51601 .61738 m .50107 .61746 L .50066 .61895 L .607 .038 0 r
F
.51601 .61738 m .51663 .61588 L .50107 .61746 L F
.36918 .37278 m .3678 .36674 L .36514 .36821 L 1 1 0 r
F
.36918 .37278 m .37163 .37107 L .3678 .36674 L F
.60832 .87937 m .58501 .88102 L .58227 .88373 L .278 0 0 r
F
.60832 .87937 m .61172 .87659 L .58501 .88102 L F
.61781 .43662 m .60943 .44087 L .61042 .44348 L .241 .067 0 r
F
.61781 .43662 m .61675 .43405 L .60943 .44087 L F
.53228 .61207 m .51784 .61275 L .51724 .61433 L .527 .03 0 r
F
.53228 .61207 m .53306 .61046 L .51784 .61275 L F
.77008 .50799 m .76111 .51682 L .76069 .52165 L 0 0 0 r
F
.77008 .50799 m .77037 .50311 L .76111 .51682 L F
.50054 .62548 m .48498 .62507 L .48477 .62657 L .68 .046 0 r
F
.50054 .62548 m .50097 .62397 L .48498 .62507 L F
.61904 .50439 m .60876 .50832 L .60877 .51092 L .228 .031 0 r
F
.61904 .50439 m .61903 .50178 L .60876 .50832 L F
.54817 .89448 m .5228 .89467 L .52137 .89695 L .375 0 0 r
F
.54817 .89448 m .55033 .89216 L .5228 .89467 L F
.71914 .17097 m .71349 .18639 L .71424 .19541 L 0 .011 0 r
F
.71914 .17097 m .71666 .1638 L .71349 .18639 L F
.90772 .45027 m .89438 .46386 L .89537 .47082 L 0 0 0 r
F
.90772 .45027 m .90667 .44324 L .89438 .46386 L F
.37932 .36176 m .3662 .3401 L .36541 .34455 L 1 .803 0 r
F
.63832 .72784 m .62324 .73471 L .621 .73788 L 0 0 0 r
F
.63832 .72784 m .64098 .72485 L .62324 .73471 L F
.41461 .34961 m .41402 .34687 L .41142 .34789 L .73 .92 0 r
F
.41461 .34961 m .41708 .34848 L .41402 .34687 L F
.40094 .6008 m .38519 .59557 L .38602 .59747 L 1 .276 0 r
F
.40163 .60263 m .40094 .6008 L .38602 .59747 L 1 .252 0 r
F
.88031 .60046 m .86536 .61114 L .86394 .61768 L 0 0 0 r
F
.88031 .60046 m .88182 .59378 L .86536 .61114 L F
.20991 .81755 m .17956 .8037 L .1835 .80866 L .985 .083 0 r
F
.21352 .82224 m .20991 .81755 L .1835 .80866 L .96 .079 0 r
F
.34404 .53173 m .33194 .52309 L .33212 .52564 L 1 .759 0 r
F
.34425 .53424 m .34404 .53173 L .33212 .52564 L 1 .741 0 r
F
.78151 .78539 m .76116 .79048 L .75759 .79552 L .06 0 0 r
F
.78151 .78539 m .78542 .78016 L .76116 .79048 L F
.61379 .43212 m .60556 .43626 L .60658 .43883 L .248 .07 0 r
F
.61379 .43212 m .61271 .42959 L .60556 .43626 L F
.61995 .58516 m .60914 .59014 L .60793 .59255 L .03 0 0 r
F
.61995 .58516 m .62125 .5827 L .60914 .59014 L F
.41295 .35257 m .41179 .3487 L .40937 .3501 L .962 1 0 r
F
.41295 .35257 m .41527 .35113 L .41179 .3487 L F
.31929 .50156 m .30748 .49143 L .30734 .49431 L 1 .867 0 r
F
.31922 .50439 m .31929 .50156 L .30734 .49431 L 1 .852 0 r
F
.54918 .60415 m .53532 .60542 L .53458 .60714 L .444 .024 0 r
F
.54918 .60415 m .55008 .6024 L .53532 .60542 L F
.75753 .39273 m .76115 .399 L .76214 .40405 L .735 .098 0 r
F
.75753 .39273 m .75592 .38807 L .76115 .399 L F
.51646 .62229 m .50139 .62243 L .50097 .62397 L .603 .037 0 r
F
.51646 .62229 m .5171 .62073 L .50139 .62243 L F
.58749 .5787 m .5747 .58116 L .57395 .58332 L .331 .017 0 r
F
.58749 .5787 m .58836 .57649 L .5747 .58116 L F
.5329 .61683 m .51833 .61751 L .51772 .61914 L .526 .03 0 r
F
.5329 .61683 m .53371 .61518 L .51833 .61751 L F
.46573 .90878 m .46566 .90652 L .43714 .90622 L .51 0 0 r
F
.49347 .90825 m .46566 .90652 L .46573 .90878 L .475 0 0 r
F
.49347 .90825 m .49417 .90599 L .46566 .90652 L F
.34917 .84903 m .31838 .84563 L .3214 .84899 L .855 .057 0 r
F
.35163 .85224 m .34917 .84903 L .3214 .84899 L .834 .054 0 r
F
.3125 .83866 m .28138 .83302 L .28479 .83672 L .919 .066 0 r
F
.31541 .84218 m .3125 .83866 L .28479 .83672 L .899 .063 0 r
F
.58583 .57442 m .57332 .57697 L .57258 .57909 L .325 .016 0 r
F
.58583 .57442 m .58666 .57225 L .57332 .57697 L F
.34274 .87981 m .31183 .87251 L .31521 .87575 L .766 .039 0 r
F
.34555 .88282 m .34274 .87981 L .31521 .87575 L .736 .034 0 r
F
.37163 .37107 m .37048 .36535 L .3678 .36674 L .998 1 0 r
F
.37163 .37107 m .37409 .3694 L .37048 .36535 L F
.83802 .71684 m .8188 .72399 L .81594 .7299 L 0 0 0 r
F
.83802 .71684 m .84111 .71074 L .8188 .72399 L F
.43247 .34383 m .43207 .34307 L .42957 .34384 L .423 .208 0 r
F
.43247 .34383 m .43481 .34296 L .43207 .34307 L F
.62198 .51019 m .61133 .51413 L .61128 .51676 L .234 .031 0 r
F
.62198 .51019 m .62203 .50754 L .61133 .51413 L F
.33553 .47622 m .32673 .46691 L .3261 .46951 L 1 1 0 r
F
.33498 .47884 m .33553 .47622 L .3261 .46951 L F
.61882 .43921 m .61042 .44348 L .61137 .4461 L .236 .065 0 r
F
.61882 .43921 m .61781 .43662 L .61042 .44348 L F
.33648 .54869 m .32204 .54021 L .32255 .54287 L 1 .645 0 r
F
.33697 .55127 m .33648 .54869 L .32255 .54287 L 1 .627 0 r
F
.55004 .60878 m .53601 .61 L .53527 .61176 L .446 .024 0 r
F
.55004 .60878 m .55097 .60699 L .53601 .61 L F
.66035 .49784 m .65503 .50372 L .65427 .50685 L 0 0 0 r
F
.66035 .49784 m .66114 .49472 L .65503 .50372 L F
.36821 .63719 m .35031 .63031 L .35143 .63293 L 1 .308 0 r
F
.36924 .63965 m .36821 .63719 L .35143 .63293 L 1 .288 0 r
F
.30492 .52513 m .29456 .51385 L .29437 .51697 L 1 .835 0 r
F
.3048 .52826 m .30492 .52513 L .29437 .51697 L 1 .818 0 r
F
.35799 .57807 m .34219 .57119 L .343 .57359 L 1 .481 0 r
F
.35873 .58038 m .35799 .57807 L .343 .57359 L 1 .461 0 r
F
.45239 .62553 m .43576 .62333 L .43621 .62493 L .895 .072 0 r
F
.45264 .62706 m .45239 .62553 L .43621 .62493 L .882 .069 0 r
F
.46874 .6271 m .45239 .62553 L .45264 .62706 L .825 .063 0 r
F
.25996 .85129 m .22884 .84014 L .23288 .8444 L .897 .064 0 r
F
.26357 .85528 m .25996 .85129 L .23288 .8444 L .869 .059 0 r
F
.36236 .56599 m .3484 .55854 L .34901 .56087 L 1 .549 0 r
F
.36294 .56826 m .36236 .56599 L .34901 .56087 L 1 .528 0 r
F
.60646 .55241 m .59456 .55559 L .59401 .558 L .277 .018 0 r
F
.60646 .55241 m .60706 .54996 L .59456 .55559 L F
.37932 .59711 m .36287 .59155 L .36379 .59371 L 1 .353 0 r
F
.38012 .59918 m .37932 .59711 L .36379 .59371 L 1 .332 0 r
F
.41916 .61044 m .4031 .60619 L .40386 .60792 L 1 .173 0 r
F
.41976 .61209 m .41916 .61044 L .40386 .60792 L 1 .149 0 r
F
.30525 .86574 m .27433 .85669 L .27808 .86037 L .833 .051 0 r
F
.30851 .86917 m .30525 .86574 L .27808 .86037 L .804 .046 0 r
F
.61483 .43467 m .60658 .43883 L .60756 .4414 L .243 .068 0 r
F
.61483 .43467 m .61379 .43212 L .60658 .43883 L F
.45273 .61967 m .4365 .61707 L .43695 .61858 L .906 .072 0 r
F
.45297 .62113 m .45273 .61967 L .43695 .61858 L .892 .069 0 r
F
.4688 .62154 m .45273 .61967 L .45297 .62113 L .834 .063 0 r
F
.39941 .6097 m .38268 .60522 L .38359 .60718 L 1 .25 0 r
F
.40016 .61158 m .39941 .6097 L .38359 .60718 L 1 .227 0 r
F
.59716 .61063 m .58491 .61485 L .58361 .61693 L .126 0 0 r
F
.59716 .61063 m .59861 .60849 L .58491 .61485 L F
.37409 .3694 m .37318 .364 L .37048 .36535 L .97 1 0 r
F
.37409 .3694 m .37656 .36777 L .37318 .364 L F
.60416 .54848 m .59263 .55173 L .59211 .55409 L .268 .017 0 r
F
.60416 .54848 m .60474 .54608 L .59263 .55173 L F
.38216 .58765 m .36711 .58138 L .36791 .58348 L 1 .389 0 r
F
.38288 .58967 m .38216 .58765 L .36791 .58348 L 1 .365 0 r
F
.6198 .4418 m .61137 .4461 L .61228 .44873 L .231 .063 0 r
F
.6198 .4418 m .61882 .43921 L .61137 .4461 L F
.619 .50699 m .60877 .51092 L .60873 .5135 L .222 .029 0 r
F
.619 .50699 m .61904 .50439 L .60877 .51092 L F
.67019 .69932 m .65545 .70526 L .65321 .7087 L 0 0 0 r
F
.67019 .69932 m .6728 .69595 L .65545 .70526 L F
.41527 .35113 m .41427 .34745 L .41179 .3487 L .918 1 0 r
F
.41527 .35113 m .41763 .34982 L .41427 .34745 L F
.33498 .47884 m .3261 .46951 L .32552 .47212 L 1 1 0 r
F
.33448 .48146 m .33498 .47884 L .32552 .47212 L 1 .992 0 r
F
.61582 .43722 m .60756 .4414 L .6085 .44399 L .237 .065 0 r
F
.61582 .43722 m .61483 .43467 L .60756 .4414 L F
.46835 .66555 m .46832 .66413 L .45038 .66533 L .637 .029 0 r
F
.48567 .66356 m .46832 .66413 L .46835 .66555 L .529 .014 0 r
F
.48567 .66356 m .48596 .66221 L .46832 .66413 L F
.41708 .34848 m .41665 .34595 L .41402 .34687 L .681 .869 0 r
F
.41708 .34848 m .41956 .34741 L .41665 .34595 L F
.22347 .79136 m .19307 .78 L .19666 .78477 L 1 .091 0 r
F
.22673 .79588 m .22347 .79136 L .19666 .78477 L 1 .088 0 r
F
.37656 .36777 m .37588 .3627 L .37318 .364 L .94 1 0 r
F
.37656 .36777 m .37904 .36618 L .37588 .3627 L F
.90021 .45079 m .88861 .46409 L .88933 .47096 L 0 0 0 r
F
.90021 .45079 m .89962 .44384 L .88861 .46409 L F
.43286 .34519 m .43238 .34414 L .42993 .345 L .506 .409 0 r
F
.43286 .34519 m .43514 .34421 L .43238 .34414 L F
.31592 .43582 m .31075 .42558 L .30926 .4283 L .286 .384 0 r
F
.57665 .8888 m .55246 .88974 L .55033 .89216 L .324 0 0 r
F
.57665 .8888 m .57948 .88632 L .55246 .88974 L F
.09573 .68242 m .07073 .66084 L .07299 .66745 L 1 .32 0 r
F
.09794 .68879 m .09573 .68242 L .07299 .66745 L 1 .29 0 r
F
.31922 .50439 m .30734 .49431 L .30725 .49718 L 1 .852 0 r
F
.31919 .50722 m .31922 .50439 L .30725 .49718 L 1 .837 0 r
F
.52083 .90693 m .49417 .90599 L .49347 .90825 L .433 0 0 r
F
.52083 .90693 m .5223 .90464 L .49417 .90599 L F
.5666 .59317 m .55344 .59506 L .55264 .59694 L .377 .017 0 r
F
.5666 .59317 m .56754 .59125 L .55344 .59506 L F
.34425 .53424 m .33212 .52564 L .33235 .52818 L 1 .741 0 r
F
.34449 .53674 m .34425 .53424 L .33235 .52818 L 1 .723 0 r
F
.55985 .79228 m .54137 .80227 L .53987 .80512 L 0 0 0 r
F
.55985 .79228 m .56183 .7897 L .54137 .80227 L F
.6803 .8485 m .65905 .85174 L .65543 .85525 L .164 0 0 r
F
.6803 .8485 m .68444 .84485 L .65905 .85174 L F
.43576 .62333 m .41907 .6205 L .41972 .62217 L .955 .088 0 r
F
.43621 .62493 m .43576 .62333 L .41972 .62217 L .942 .077 0 r
F
.88912 .61035 m .87192 .62046 L .87049 .62715 L 0 0 0 r
F
.88912 .61035 m .89063 .60348 L .87192 .62046 L F
.322 .58195 m .30797 .57169 L .30853 .57475 L 1 .605 0 r
F
.3226 .58493 m .322 .58195 L .30853 .57475 L 1 .586 0 r
F
.62189 .51284 m .61128 .51676 L .6112 .51939 L .228 .028 0 r
F
.62189 .51284 m .62198 .51019 L .61128 .51676 L F
.60882 .75235 m .59328 .76071 L .59117 .76367 L 0 0 0 r
F
.60882 .75235 m .61139 .74966 L .59328 .76071 L F
.56778 .59768 m .55441 .59949 L .55359 .60141 L .38 .017 0 r
F
.56778 .59768 m .56875 .59572 L .55441 .59949 L F
.62073 .44441 m .61228 .44873 L .61315 .45137 L .225 .061 0 r
F
.62073 .44441 m .6198 .4418 L .61228 .44873 L F
.59128 .29697 m .65253 .20809 L .6523 .21828 L .397 .028 0 r
F
.59128 .29697 m .58052 .30738 L .65253 .20809 L F
.27153 .82143 m .24054 .81323 L .24419 .81739 L .98 .076 0 r
F
.27475 .82537 m .27153 .82143 L .24419 .81739 L .96 .073 0 r
F
.72427 .82086 m .70398 .82515 L .70023 .82927 L .097 0 0 r
F
.72427 .82086 m .72846 .81658 L .70398 .82515 L F
.74322 .60048 m .72997 .60746 L .72849 .6118 L 0 0 0 r
F
.74322 .60048 m .74481 .59605 L .72997 .60746 L F
.64111 .55083 m .63258 .55653 L .63158 .55927 L F
.64111 .55083 m .64214 .54806 L .63258 .55653 L F
.61678 .43978 m .6085 .44399 L .6094 .44659 L .231 .063 0 r
F
.61678 .43978 m .61582 .43722 L .6085 .44399 L F
.21457 .81154 m .18497 .79771 L .18879 .80263 L .99 .084 0 r
F
.21809 .81619 m .21457 .81154 L .18879 .80263 L .966 .08 0 r
F
.3048 .52826 m .29437 .51697 L .29422 .5201 L 1 .818 0 r
F
.30474 .53138 m .3048 .52826 L .29422 .5201 L 1 .801 0 r
F
.15476 .76683 m .12627 .74962 L .12971 .75537 L 1 .121 0 r
F
.15801 .77232 m .15476 .76683 L .12971 .75537 L 1 .103 0 r
F
.46881 .62295 m .4688 .62154 L .45297 .62113 L .82 .06 0 r
F
.48442 .6227 m .4688 .62154 L .46881 .62295 L .751 .052 0 r
F
.48442 .6227 m .48463 .6213 L .4688 .62154 L F
.37904 .36618 m .37856 .36142 L .37588 .3627 L .911 1 0 r
F
.37904 .36618 m .38153 .36461 L .37856 .36142 L F
.31453 .43863 m .30926 .4283 L .30782 .43104 L 1 1 0 r
F
.31318 .44145 m .31453 .43863 L .30782 .43104 L F
.46583 .90151 m .46575 .89933 L .4377 .89921 L .501 0 0 r
F
.49308 .90074 m .46575 .89933 L .46583 .90151 L .462 0 0 r
F
.49308 .90074 m .49377 .89857 L .46575 .89933 L F
.85906 .28317 m .85151 .29827 L .85504 .3044 L 0 .038 0 r
F
.85906 .28317 m .85542 .27715 L .85151 .29827 L F
.51173 .33179 m .50801 .3268 L .50926 .33321 L .201 .048 0 r
F
.51173 .33179 m .51031 .32582 L .50801 .3268 L F
.46875 .62857 m .46874 .6271 L .45264 .62706 L .811 .06 0 r
F
.48456 .62804 m .46874 .6271 L .46875 .62857 L .744 .052 0 r
F
.48456 .62804 m .48477 .62657 L .46874 .6271 L F
.33448 .48146 m .32552 .47212 L .32498 .47472 L 1 .992 0 r
F
.33402 .48408 m .33448 .48146 L .32498 .47472 L 1 .979 0 r
F
.4365 .61707 m .42038 .61371 L .42101 .6153 L .968 .085 0 r
F
.43695 .61858 m .4365 .61707 L .42101 .6153 L .955 .077 0 r
F
.39114 .65198 m .37252 .64687 L .37367 .64923 L 1 .173 0 r
F
.39215 .65415 m .39114 .65198 L .37367 .64923 L 1 .152 0 r
F
.41209 .65989 m .39318 .65629 L .39423 .65839 L .963 .077 0 r
F
.41294 .6618 m .41209 .65989 L .39423 .65839 L .948 .075 0 r
F
.34526 .61688 m .32885 .6083 L .32982 .61116 L 1 .435 0 r
F
.3462 .61961 m .34526 .61688 L .32982 .61116 L 1 .415 0 r
F
.69979 .3663 m .69751 .37202 L .69597 .37756 L 0 0 0 r
F
.69979 .3663 m .70105 .36081 L .69751 .37202 L F
.57524 .62859 m .562 .63214 L .56074 .63394 L .195 0 0 r
F
.57524 .62859 m .5767 .62675 L .562 .63214 L F
.33697 .55127 m .32255 .54287 L .32309 .54551 L 1 .627 0 r
F
.3375 .55383 m .33697 .55127 L .32309 .54551 L 1 .609 0 r
F
.40741 .90265 m .37701 .89801 L .37931 .90063 L .636 .019 0 r
F
.40901 .90509 m .40741 .90265 L .37931 .90063 L .604 .013 0 r
F
.43714 .90622 m .40741 .90265 L .40901 .90509 L .579 .011 0 r
F
.77445 .77845 m .75526 .78417 L .7517 .78904 L .016 0 0 r
F
.77445 .77845 m .77834 .7734 L .75526 .78417 L F
.76972 .51285 m .76069 .52165 L .76019 .52646 L 0 0 0 r
F
.76972 .51285 m .77008 .50799 L .76069 .52165 L F
.55549 .64068 m .54135 .64365 L .54025 .64524 L .257 0 0 r
F
.55549 .64068 m .55684 .63906 L .54135 .64365 L F
.58659 .58088 m .57395 .58332 L .57316 .58546 L .325 .014 0 r
F
.58659 .58088 m .58749 .5787 L .57395 .58332 L F
.75907 .39741 m .76214 .40405 L .76308 .40909 L .713 .095 0 r
F
.75907 .39741 m .75753 .39273 L .76214 .40405 L F
.43481 .34296 m .43456 .34235 L .43207 .34307 L .377 .202 0 r
F
.61892 .50959 m .60873 .5135 L .60866 .51608 L .216 .026 0 r
F
.61892 .50959 m .619 .50699 L .60873 .5135 L F
.60581 .55483 m .59401 .558 L .59343 .56039 L .271 .016 0 r
F
.60581 .55483 m .60646 .55241 L .59401 .558 L F
.2635 .84508 m .23302 .83395 L .23696 .83817 L .902 .065 0 r
F
.26703 .84904 m .2635 .84508 L .23696 .83817 L .875 .06 0 r
F
.55525 .33449 m .55194 .33358 L .55346 .3374 L 0 .025 0 r
F
.55525 .33449 m .55347 .33118 L .55194 .33358 L F
.58496 .57655 m .57258 .57909 L .57182 .58119 L .319 .013 0 r
F
.58496 .57655 m .58583 .57442 L .57258 .57909 L F
.41763 .34982 m .41683 .34639 L .41427 .34745 L .862 1 0 r
F
.41763 .34982 m .42004 .34864 L .41683 .34639 L F
.41843 .6188 m .40173 .61524 L .40255 .61701 L 1 .151 0 r
F
.41907 .6205 m .41843 .6188 L .40255 .61701 L 1 .128 0 r
F
.62163 .44703 m .61315 .45137 L .61399 .45402 L .22 .059 0 r
F
.62163 .44703 m .62073 .44441 L .61315 .45137 L F
.64394 .87669 m .62129 .87852 L .61797 .88168 L .25 0 0 r
F
.64394 .87669 m .64786 .87341 L .62129 .87852 L F
.45038 .66533 m .43179 .6641 L .43241 .6658 L .757 .047 0 r
F
.45072 .66686 m .45038 .66533 L .43241 .6658 L .735 .043 0 r
F
.46835 .66555 m .45038 .66533 L .45072 .66686 L .637 .029 0 r
F
.65956 .50094 m .65427 .50685 L .65351 .50996 L 0 0 0 r
F
.65956 .50094 m .66035 .49784 L .65427 .50685 L F
.36294 .56826 m .34901 .56087 L .34967 .56318 L 1 .528 0 r
F
.36356 .57051 m .36294 .56826 L .34967 .56318 L 1 .506 0 r
F
.38153 .36461 m .38121 .36013 L .37856 .36142 L .884 1 0 r
F
.38153 .36461 m .38401 .36307 L .38121 .36013 L F
.43179 .6641 m .41294 .6618 L .41381 .66368 L .86 .062 0 r
F
.43241 .6658 m .43179 .6641 L .41381 .66368 L .841 .058 0 r
F
.40163 .60263 m .38602 .59747 L .38687 .59935 L 1 .252 0 r
F
.40235 .60442 m .40163 .60263 L .38687 .59935 L 1 .228 0 r
F
.82932 .71122 m .81169 .71901 L .80882 .72474 L 0 0 0 r
F
.82932 .71122 m .8324 .70531 L .81169 .71901 L F
.61769 .44236 m .6094 .44659 L .61027 .44919 L .225 .061 0 r
F
.61769 .44236 m .61678 .43978 L .6094 .44659 L F
.51423 .82555 m .49169 .83385 L .49115 .83664 L .257 0 0 r
F
.51423 .82555 m .51532 .82286 L .49169 .83385 L F
.4998 .62181 m .48463 .6213 L .48442 .6227 L .671 .043 0 r
F
.4998 .62181 m .50023 .6204 L .48463 .6213 L F
.61861 .58759 m .60793 .59255 L .60669 .59493 L .021 0 0 r
F
.61861 .58759 m .61995 .58516 L .60793 .59255 L F
.35873 .58038 m .343 .57359 L .34385 .57596 L 1 .461 0 r
F
.35949 .58267 m .35873 .58038 L .34385 .57596 L 1 .441 0 r
F
.31318 .44145 m .30782 .43104 L .30643 .43381 L 1 1 0 r
F
.31187 .4443 m .31318 .44145 L .30643 .43381 L F
.53386 .31491 m .53827 .29746 L .53831 .3073 L 1 .538 0 r
F
.53701 .30655 m .54825 .27011 L .54503 .28988 L 1 .896 0 r
F
.53663 .30396 m .53191 .31104 L .53827 .29746 L 1 .538 0 r
F
.53386 .31491 m .53272 .31264 L .53663 .30396 L F
.53272 .31264 m .53191 .31104 L .53663 .30396 L F
.53191 .31104 m .53098 .30377 L .54011 .2811 L 1 .696 0 r
F
.52597 .32152 m .53098 .30377 L .53191 .31104 L .504 .047 0 r
F
.53223 .31677 m .53064 .31591 L .53234 .31538 L .481 .029 0 r
F
.53223 .31677 m .53234 .31538 L .53386 .31491 L F
.53062 .32525 m .52557 .33098 L .53223 .31677 L .381 .028 0 r
F
.53064 .31591 m .53272 .31264 L .53386 .31491 L .481 .029 0 r
F
.53612 .3177 m .53445 .31563 L .53831 .3073 L 1 .389 0 r
F
.53445 .31563 m .53386 .31491 L .53544 .3122 L F
.53445 .31563 m .53544 .3122 L .53831 .3073 L F
.53183 .3217 m .53223 .31677 L .53263 .31691 L .381 .028 0 r
F
.53338 .31717 m .53223 .31677 L .53386 .31491 L .411 0 0 r
F
.53183 .3217 m .53289 .31536 L .53338 .31717 L .381 .028 0 r
F
.53062 .32525 m .53223 .31677 L .53183 .3217 L F
.52557 .33098 m .53064 .31591 L .53223 .31677 L 1 .68 0 r
F
.53731 .31428 m .53701 .30655 L .53781 .31345 L .381 .028 0 r
F
.53369 .31738 m .53386 .31491 L .53445 .31563 L .411 0 0 r
F
.53062 .32525 m .53293 .31849 L .5349 .31822 L .381 .028 0 r
F
.53293 .31849 m .53338 .31717 L .5349 .31822 L F
.53442 .32325 m .53184 .32461 L .53499 .31872 L .455 .025 0 r
F
.5361 .31806 m .5349 .31822 L .53612 .3177 L .31 0 0 r
F
.53532 .32064 m .53499 .31872 L .53522 .31828 L .455 .025 0 r
F
.53608 .31845 m .5349 .31822 L .5361 .31806 L .31 0 0 r
F
.5349 .31822 m .53445 .31563 L .53612 .3177 L .411 0 0 r
F
.53608 .31845 m .53522 .31828 L .53781 .31345 L .455 .025 0 r
F
.53532 .32064 m .53522 .31828 L .53608 .31845 L F
.53184 .32461 m .5326 .32201 L .53781 .31345 L F
.53604 .31921 m .5349 .31822 L .53608 .31845 L .31 0 0 r
F
.53442 .32325 m .53499 .31872 L .53532 .32064 L .455 .025 0 r
F
.53604 .31921 m .53298 .31905 L .5349 .31822 L .31 0 0 r
F
.53354 .31774 m .53359 .31731 L .53369 .31738 L .411 0 0 r
F
.53359 .31731 m .53386 .31491 L .53369 .31738 L F
.53338 .31717 m .53386 .31491 L .53354 .31774 L F
.53298 .31905 m .53445 .31563 L .5349 .31822 L F
.5349 .31822 m .53338 .31717 L .53731 .31428 L .381 .028 0 r
F
.53338 .31717 m .53701 .30655 L .53731 .31428 L F
.53256 .31777 m .52965 .31969 L .53223 .31677 L .411 0 0 r
F
.53298 .31905 m .53005 .31962 L .53256 .31777 L F
.53005 .31962 m .52965 .31969 L .53256 .31777 L F
.53298 .31905 m .53223 .31677 L .53338 .31717 L F
.53263 .31691 m .53223 .31677 L .53289 .31536 L .381 .028 0 r
F
.53338 .31717 m .53289 .31536 L .53701 .30655 L F
.53298 .31905 m .53338 .31717 L .53354 .31774 L .411 0 0 r
F
.53184 .32461 m .53062 .32525 L .5326 .32201 L .455 .025 0 r
F
.53223 .31677 m .5384 .29283 L .53701 .30655 L 1 .68 0 r
F
.53064 .31591 m .53191 .31104 L .53272 .31264 L .481 .029 0 r
F
.53064 .31591 m .5384 .29283 L .53223 .31677 L 1 .68 0 r
F
.52965 .31969 m .53064 .31591 L .53223 .31677 L .481 .029 0 r
F
.53064 .31591 m .52597 .32152 L .53191 .31104 L F
.52885 .32124 m .52976 .31773 L .53064 .31591 L 1 .68 0 r
F
.52855 .32024 m .52597 .32152 L .53064 .31591 L .481 .029 0 r
F
.52735 .32457 m .53762 .28755 L .52885 .32124 L 1 .68 0 r
F
.52965 .31969 m .52855 .32024 L .53064 .31591 L .481 .029 0 r
F
.52976 .31773 m .52995 .31699 L .53064 .31591 L 1 .68 0 r
F
.53064 .31591 m .53762 .28755 L .5384 .29283 L F
.52995 .31699 m .53762 .28755 L .53064 .31591 L F
.52557 .33098 m .52735 .32457 L .52885 .32124 L F
.53701 .30655 m .5384 .29283 L .54825 .27011 L 1 .896 0 r
F
.53147 .61365 m .51724 .61433 L .51663 .61588 L .513 .027 0 r
F
.53147 .61365 m .53228 .61207 L .51724 .61433 L F
.60355 .55086 m .59211 .55409 L .59155 .55644 L .261 .014 0 r
F
.60355 .55086 m .60416 .54848 L .59211 .55409 L F
.41275 .34551 m .41397 .34255 L .41141 .3438 L .947 1 0 r
F
.41402 .34687 m .41665 .34595 L .41644 .34572 L .77 .994 0 r
F
.41402 .34687 m .41644 .34572 L .4154 .34566 L F
.40923 .34556 m .41141 .3438 L .40891 .34516 L .99 1 0 r
F
.41142 .34789 m .41402 .34687 L .41311 .3459 L .809 1 0 r
F
.41142 .34789 m .41311 .3459 L .41262 .34585 L F
.41156 .34576 m .41279 .34556 L .4127 .34545 L .99 1 0 r
F
.41156 .34566 m .4127 .34545 L .41141 .3438 L F
.41416 .34559 m .41397 .34255 L .41275 .34551 L .947 1 0 r
F
.4154 .34566 m .41644 .34572 L .41593 .34519 L .77 .994 0 r
F
.41427 .34745 m .41683 .34639 L .41593 .34519 L .947 1 0 r
F
.41414 .34527 m .41593 .34519 L .41397 .34255 L F
.41593 .34519 m .41657 .3414 L .41397 .34255 L .892 1 0 r
F
.41627 .34517 m .41657 .3414 L .41593 .34519 L F
.41665 .34595 m .41677 .34525 L .41593 .34519 L .711 .944 0 r
F
.41678 .34553 m .41677 .34525 L .41624 .3456 L .892 1 0 r
F
.41677 .34525 m .41657 .3414 L .41627 .34521 L F
.41677 .34525 m .41627 .34521 L .41624 .3456 L F
.41677 .34525 m .41679 .34515 L .41593 .34519 L .711 .944 0 r
F
.41956 .34741 m .41931 .34521 L .41665 .34595 L .621 .798 0 r
F
.41931 .34521 m .41931 .34515 L .41894 .34526 L F
.41931 .34521 m .41894 .34526 L .41665 .34595 L F
.41956 .34741 m .42206 .34643 L .41931 .34515 L F
.41665 .34595 m .41931 .34515 L .41883 .34465 L .711 .944 0 r
F
.41683 .34639 m .41947 .34557 L .41883 .34465 L .892 1 0 r
F
.41674 .34463 m .41883 .34465 L .41657 .3414 L F
.41883 .34465 m .41917 .34028 L .41657 .3414 L .826 .928 0 r
F
.41931 .34515 m .41942 .34475 L .41883 .34465 L .612 .839 0 r
F
.41947 .34557 m .41942 .34475 L .41883 .34465 L .826 .928 0 r
F
.41942 .34475 m .41917 .34028 L .41883 .34465 L F
.41942 .34475 m .41945 .34466 L .41883 .34465 L .612 .839 0 r
F
.42206 .34643 m .42198 .34445 L .41931 .34515 L .564 .706 0 r
F
.42206 .34643 m .42456 .34551 L .42198 .34445 L F
.41931 .34515 m .42198 .34445 L .42155 .34404 L .612 .839 0 r
F
.41947 .34557 m .42221 .34508 L .42155 .34404 L .826 .928 0 r
F
.41938 .34389 m .42155 .34404 L .41917 .34028 L F
.42155 .34404 m .42162 .3387 L .41917 .34028 L .781 .791 0 r
F
.42198 .34445 m .42213 .34419 L .42155 .34404 L .488 .561 0 r
F
.42221 .34508 m .42213 .34419 L .42155 .34404 L .781 .791 0 r
F
.42213 .34419 m .42162 .3387 L .42155 .34404 L F
.42456 .34551 m .42465 .3438 L .42198 .34445 L .528 .601 0 r
F
.42456 .34551 m .42707 .34465 L .42465 .3438 L F
.42198 .34445 m .42465 .3438 L .42427 .34354 L .488 .561 0 r
F
.42221 .34508 m .42504 .34495 L .42427 .34354 L .781 .791 0 r
F
.42209 .34375 m .42427 .34354 L .42162 .3387 L F
.42427 .34354 m .42343 .33512 L .42162 .3387 L .849 .693 0 r
F
.42465 .3438 m .42482 .34361 L .42427 .34354 L .415 .311 0 r
F
.42504 .34495 m .42482 .34361 L .42427 .34354 L .849 .693 0 r
F
.42482 .34361 m .42343 .33512 L .42427 .34354 L F
.42707 .34465 m .4273 .34315 L .42465 .3438 L .498 .514 0 r
F
.42707 .34465 m .42957 .34384 L .4273 .34315 L F
.42465 .3438 m .4273 .34315 L .42705 .34303 L .415 .311 0 r
F
.42504 .34495 m .42776 .3446 L .42705 .34303 L .849 .693 0 r
F
.42482 .34361 m .42705 .34303 L .42343 .33512 L F
.42465 .3438 m .42705 .34303 L .42482 .34361 L .415 .311 0 r
F
.42504 .34495 m .42705 .34303 L .42482 .34361 L .849 .693 0 r
F
.42482 .34361 m .42705 .34303 L .42586 .34248 L .415 .311 0 r
F
.42482 .34361 m .42496 .34347 L .42427 .34354 L F
.42427 .34354 m .42586 .34248 L .42301 .34266 L F
.42496 .34347 m .42586 .34248 L .42427 .34354 L F
.42213 .34419 m .42427 .34354 L .42209 .34375 L .781 .791 0 r
F
.42198 .34445 m .42427 .34354 L .42213 .34419 L .488 .561 0 r
F
.42221 .34508 m .42427 .34354 L .42213 .34419 L .781 .791 0 r
F
.42213 .34419 m .42427 .34354 L .42301 .34266 L .488 .561 0 r
F
.42213 .34419 m .42219 .34409 L .42155 .34404 L F
.42155 .34404 m .42301 .34266 L .42004 .34261 L F
.42219 .34409 m .42301 .34266 L .42155 .34404 L F
.41942 .34475 m .42155 .34404 L .41938 .34389 L .826 .928 0 r
F
.41931 .34515 m .42155 .34404 L .41942 .34475 L .612 .839 0 r
F
.41947 .34557 m .42155 .34404 L .41942 .34475 L .826 .928 0 r
F
.41942 .34475 m .42155 .34404 L .42004 .34261 L .612 .839 0 r
F
.41883 .34465 m .42004 .34261 L .41716 .34291 L F
.41945 .34466 m .42004 .34261 L .41883 .34465 L F
.41677 .34525 m .41883 .34465 L .41674 .34463 L .892 1 0 r
F
.41665 .34595 m .41883 .34465 L .41677 .34525 L .711 .944 0 r
F
.41683 .34639 m .41883 .34465 L .41677 .34525 L .892 1 0 r
F
.41677 .34525 m .41883 .34465 L .41716 .34291 L .711 .944 0 r
F
.41593 .34519 m .41716 .34291 L .41437 .34352 L F
.41679 .34515 m .41716 .34291 L .41593 .34519 L F
.41416 .34559 m .41593 .34519 L .41414 .34527 L .947 1 0 r
F
.41402 .34687 m .41593 .34519 L .41416 .34559 L .77 .994 0 r
F
.41427 .34745 m .41593 .34519 L .41416 .34559 L .947 1 0 r
F
.41416 .34559 m .41593 .34519 L .41419 .3453 L .77 .994 0 r
F
.41279 .34556 m .41437 .34352 L .41166 .34436 L F
.41328 .34557 m .41416 .34559 L .41327 .34554 L .947 1 0 r
F
.41402 .34687 m .41416 .34559 L .41279 .34556 L .77 .994 0 r
F
.41427 .34745 m .41416 .34559 L .41328 .34557 L .947 1 0 r
F
.41416 .34559 m .41417 .34545 L .41279 .34556 L .77 .994 0 r
F
.41279 .34556 m .41327 .34554 L .41275 .34551 L .947 1 0 r
F
.41417 .34545 m .41437 .34352 L .41279 .34556 L .77 .994 0 r
F
.41156 .34576 m .41209 .34562 L .41156 .34566 L .99 1 0 r
F
.41209 .34562 m .4127 .34545 L .41156 .34566 L F
.40944 .34581 m .41156 .34576 L .40923 .34556 L F
.40984 .34623 m .41027 .34579 L .40944 .34581 L .809 1 0 r
F
.41142 .34789 m .41156 .34576 L .40984 .34623 L F
.41156 .34576 m .41141 .3438 L .40923 .34556 L .99 1 0 r
F
.41156 .34576 m .41166 .34436 L .40984 .34623 L .809 1 0 r
F
.41142 .34789 m .41279 .34556 L .41156 .34576 L F
.40885 .34902 m .41142 .34789 L .40953 .34591 L .837 1 0 r
F
.40937 .3501 m .41179 .3487 L .40944 .34581 L 1 1 0 r
F
.40898 .34586 m .40944 .34581 L .40891 .34516 L F
.40898 .34586 m .40953 .34591 L .40944 .34581 L .837 1 0 r
F
.40885 .34902 m .40953 .34591 L .40898 .34586 L F
.40937 .3501 m .40944 .34581 L .40898 .34586 L 1 1 0 r
F
.40898 .34586 m .40944 .34581 L .409 .34535 L .837 1 0 r
F
.40631 .35022 m .40885 .34902 L .40638 .34647 L .855 1 0 r
F
.40898 .34586 m .40891 .34516 L .40789 .34577 L 1 1 0 r
F
.40885 .34902 m .40898 .34586 L .40638 .34647 L .837 1 0 r
F
.40898 .34586 m .40789 .34577 L .40757 .34596 L 1 1 0 r
F
.40898 .34586 m .409 .34535 L .40757 .34596 L .837 1 0 r
F
.40898 .34586 m .40757 .34596 L .40638 .34647 L F
.40898 .34586 m .40757 .34596 L .40646 .34662 L 1 1 0 r
F
.40937 .3501 m .40898 .34586 L .40646 .34662 L F
.41179 .3487 m .41156 .34576 L .40944 .34581 L .99 1 0 r
F
.40944 .34581 m .41166 .34436 L .409 .34535 L .809 1 0 r
F
.41027 .34579 m .41166 .34436 L .40944 .34581 L F
.41156 .34576 m .41279 .34556 L .41157 .34562 L F
.41262 .34585 m .41311 .3459 L .41279 .34556 L F
.41179 .3487 m .41427 .34745 L .41279 .34556 L .99 1 0 r
F
.41179 .3487 m .41279 .34556 L .41156 .34576 L F
.41157 .34562 m .41279 .34556 L .41166 .34436 L .809 1 0 r
F
.41427 .34745 m .41327 .34554 L .41279 .34556 L .947 1 0 r
F
.41419 .3453 m .41593 .34519 L .41437 .34352 L .77 .994 0 r
F
.41624 .3456 m .41627 .34517 L .41593 .34519 L .892 1 0 r
F
.41683 .34639 m .41678 .34553 L .41624 .3456 L F
.51537 .61885 m .50066 .61895 L .50023 .6204 L .593 .034 0 r
F
.51537 .61885 m .51601 .61738 L .50066 .61895 L F
.31919 .50722 m .30725 .49718 L .30721 .50004 L 1 .837 0 r
F
.3192 .51003 m .31919 .50722 L .30721 .50004 L 1 .821 0 r
F
.54826 .60587 m .53458 .60714 L .53383 .60882 L .431 .02 0 r
F
.54826 .60587 m .54918 .60415 L .53458 .60714 L F
.70542 .66096 m .69109 .66682 L .68904 .67065 L 0 0 0 r
F
.70542 .66096 m .70773 .6571 L .69109 .66682 L F
.34449 .53674 m .33235 .52818 L .33262 .5307 L 1 .723 0 r
F
.34478 .53923 m .34449 .53674 L .33262 .5307 L 1 .704 0 r
F
.62176 .51548 m .6112 .51939 L .61108 .52201 L .222 .025 0 r
F
.62176 .51548 m .62189 .51284 L .6112 .51939 L F
.11343 .66577 m .0883 .64569 L .0904 .65199 L 1 .366 0 r
F
.11549 .67181 m .11343 .66577 L .0904 .65199 L 1 .339 0 r
F
.50242 .66091 m .48596 .66221 L .48567 .66356 L .431 0 0 r
F
.50242 .66091 m .50303 .6596 L .48596 .66221 L F
.5001 .62695 m .48477 .62657 L .48456 .62804 L .665 .042 0 r
F
.5001 .62695 m .50054 .62548 L .48477 .62657 L F
.33402 .48408 m .32498 .47472 L .32448 .47734 L 1 .979 0 r
F
.3336 .4867 m .33402 .48408 L .32448 .47734 L 1 .966 0 r
F
.38012 .59918 m .36379 .59371 L .36474 .59583 L 1 .332 0 r
F
.38095 .60123 m .38012 .59918 L .36474 .59583 L 1 .31 0 r
F
.90865 .45732 m .89537 .47082 L .89625 .47779 L 0 0 0 r
F
.90865 .45732 m .90772 .45027 L .89537 .47082 L F
.53684 .64973 m .52194 .65216 L .52107 .6536 L .312 0 0 r
F
.53684 .64973 m .538 .64828 L .52194 .65216 L F
.52002 .34277 m .51491 .34256 L .51685 .3451 L .438 .439 0 r
F
.52215 .34493 m .52002 .34277 L .51685 .3451 L .469 .501 0 r
F
.38401 .36307 m .38381 .35881 L .38121 .36013 L .864 .982 0 r
F
.38401 .36307 m .38648 .36155 L .38381 .35881 L F
.62248 .44965 m .61399 .45402 L .61478 .45667 L .215 .056 0 r
F
.62248 .44965 m .62163 .44703 L .61399 .45402 L F
.53208 .61845 m .51772 .61914 L .5171 .62073 L .511 .027 0 r
F
.53208 .61845 m .5329 .61683 L .51772 .61914 L F
.53677 .81046 m .51637 .82006 L .51532 .82286 L .109 0 0 r
F
.53677 .81046 m .53834 .80785 L .51637 .82006 L F
.61856 .44494 m .61027 .44919 L .61109 .4518 L .219 .058 0 r
F
.61856 .44494 m .61769 .44236 L .61027 .44919 L F
.54909 .61053 m .53527 .61176 L .5345 .61349 L .433 .02 0 r
F
.54909 .61053 m .55004 .60878 L .53527 .61176 L F
.38288 .58967 m .36791 .58348 L .36875 .58555 L 1 .365 0 r
F
.38362 .59167 m .38288 .58967 L .36875 .58555 L 1 .341 0 r
F
.51581 .62381 m .50097 .62397 L .50054 .62548 L .588 .034 0 r
F
.51581 .62381 m .51646 .62229 L .50097 .62397 L F
.17039 .74481 m .14174 .7296 L .14491 .73508 L 1 .189 0 r
F
.17336 .75002 m .17039 .74481 L .14491 .73508 L 1 .163 0 r
F
.43514 .34421 m .43481 .34328 L .43238 .34414 L .478 .34 0 r
F
.43514 .34421 m .43742 .34329 L .43481 .34328 L F
.51992 .89912 m .49377 .89857 L .49308 .90074 L .415 0 0 r
F
.51992 .89912 m .52137 .89695 L .49377 .89857 L F
.31187 .4443 m .30643 .43381 L .30508 .4366 L 1 1 0 r
F
.31062 .44717 m .31187 .4443 L .30508 .4366 L F
.30474 .53138 m .29422 .5201 L .29413 .52323 L 1 .801 0 r
F
.30471 .53451 m .30474 .53138 L .29413 .52323 L 1 .783 0 r
F
.41976 .61209 m .40386 .60792 L .40464 .60961 L 1 .149 0 r
F
.42038 .61371 m .41976 .61209 L .40464 .60961 L 1 .125 0 r
F
.51928 .65634 m .50362 .65824 L .50303 .6596 L .369 0 0 r
F
.51928 .65634 m .52018 .655 L .50362 .65824 L F
.40016 .61158 m .38359 .60718 L .38452 .6091 L 1 .227 0 r
F
.40094 .61343 m .40016 .61158 L .38452 .6091 L 1 .203 0 r
F
.31899 .4367 m .31118 .42573 L .31005 .42856 L 1 1 0 r
F
.31795 .43954 m .31899 .4367 L .31005 .42856 L F
.36924 .63965 m .35143 .63293 L .35258 .63553 L 1 .288 0 r
F
.37031 .64208 m .36924 .63965 L .35258 .63553 L 1 .267 0 r
F
.55711 .33753 m .55346 .3374 L .5551 .34083 L 0 .046 0 r
F
.55711 .33753 m .55525 .33449 L .55346 .3374 L F
.43799 .90851 m .43714 .90622 L .40901 .90509 L .548 .005 0 r
F
.46573 .90878 m .43714 .90622 L .43799 .90851 L .51 0 0 r
F
.49763 .32352 m .49714 .30659 L .50116 .27864 L 1 .774 0 r
F
.51592 .33757 m .51402 .33412 L .5113 .33601 L .352 .213 0 r
F
.61879 .51217 m .60866 .51608 L .60855 .51865 L .21 .023 0 r
F
.61879 .51217 m .61892 .50959 L .60866 .51608 L F
.42004 .34864 m .41947 .34557 L .41683 .34639 L .787 1 0 r
F
.42004 .34864 m .42249 .34759 L .41947 .34557 L F
.3226 .58493 m .30853 .57475 L .30914 .57779 L 1 .586 0 r
F
.32324 .5879 m .3226 .58493 L .30914 .57779 L 1 .567 0 r
F
.45264 .62706 m .43621 .62493 L .43668 .62649 L .882 .069 0 r
F
.45288 .62856 m .45264 .62706 L .43668 .62649 L .867 .066 0 r
F
.46875 .62857 m .45264 .62706 L .45288 .62856 L .811 .06 0 r
F
.59567 .61273 m .58361 .61693 L .58228 .61897 L .114 0 0 r
F
.59567 .61273 m .59716 .61063 L .58361 .61693 L F
.87869 .60711 m .86394 .61768 L .86241 .62419 L 0 0 0 r
F
.87869 .60711 m .88031 .60046 L .86394 .61768 L F
.38648 .36155 m .38636 .35744 L .38381 .35881 L .854 .969 0 r
F
.38648 .36155 m .38895 .36005 L .38636 .35744 L F
.45297 .62113 m .43695 .61858 L .4374 .62006 L .892 .069 0 r
F
.45322 .62255 m .45297 .62113 L .4374 .62006 L .878 .066 0 r
F
.46881 .62295 m .45297 .62113 L .45322 .62255 L .82 .06 0 r
F
.10429 .67783 m .08043 .65647 L .08255 .66297 L 1 .324 0 r
F
.10637 .6841 m .10429 .67783 L .08255 .66297 L 1 .295 0 r
F
.62329 .45229 m .61478 .45667 L .61554 .45933 L .209 .054 0 r
F
.62329 .45229 m .62248 .44965 L .61478 .45667 L F
.56563 .59506 m .55264 .59694 L .55181 .59879 L .37 .014 0 r
F
.56563 .59506 m .5666 .59317 L .55264 .59694 L F
.40844 .89585 m .37851 .89137 L .38078 .89395 L .631 .018 0 r
F
.41002 .89824 m .40844 .89585 L .38078 .89395 L .599 .013 0 r
F
.4377 .89921 m .40844 .89585 L .41002 .89824 L .569 .009 0 r
F
.61939 .44753 m .61109 .4518 L .61188 .45441 L .212 .056 0 r
F
.61939 .44753 m .61856 .44494 L .61109 .4518 L F
.3336 .4867 m .32448 .47734 L .32402 .47995 L 1 .966 0 r
F
.33321 .48932 m .3336 .4867 L .32402 .47995 L 1 .953 0 r
F
.16098 .76122 m .13338 .74407 L .13669 .74976 L 1 .128 0 r
F
.16411 .76664 m .16098 .76122 L .13669 .74976 L 1 .104 0 r
F
.3375 .55383 m .32309 .54551 L .32368 .54813 L 1 .609 0 r
F
.33806 .55637 m .3375 .55383 L .32368 .54813 L 1 .591 0 r
F
.64005 .55358 m .63158 .55927 L .63055 .56198 L 0 0 0 r
F
.64005 .55358 m .64111 .55083 L .63158 .55927 L F
.31062 .44717 m .30508 .4366 L .30377 .43941 L 1 1 0 r
F
.3094 .45006 m .31062 .44717 L .30377 .43941 L F
.51352 .33584 m .50926 .33321 L .51088 .33753 L .288 .079 0 r
F
.51352 .33584 m .51173 .33179 L .50926 .33321 L F
.5459 .31526 m .54834 .30282 L .54836 .31154 L 1 .617 0 r
F
.5459 .31526 m .54468 .3097 L .54834 .30282 L F
.60513 .55724 m .59343 .56039 L .59281 .56275 L .264 .013 0 r
F
.60513 .55724 m .60581 .55483 L .59343 .56039 L F
.56678 .59961 m .55359 .60141 L .55274 .6033 L .373 .014 0 r
F
.56678 .59961 m .56778 .59768 L .55359 .60141 L F
.3192 .51003 m .30721 .50004 L .30721 .50289 L 1 .821 0 r
F
.31925 .51284 m .3192 .51003 L .30721 .50289 L 1 .805 0 r
F
.62158 .51811 m .61108 .52201 L .61091 .52462 L .216 .023 0 r
F
.62158 .51811 m .62176 .51548 L .61108 .52201 L F
.31795 .43954 m .31005 .42856 L .30898 .43139 L 1 1 0 r
F
.31696 .44239 m .31795 .43954 L .30898 .43139 L F
.38895 .36005 m .38886 .35604 L .38636 .35744 L .852 .97 0 r
F
.38895 .36005 m .39142 .35856 L .38886 .35604 L F
.71959 .18036 m .71914 .17097 L .71424 .19541 L 0 0 0 r
F
.36356 .57051 m .34967 .56318 L .35036 .56547 L 1 .506 0 r
F
.3642 .57273 m .36356 .57051 L .35036 .56547 L 1 .484 0 r
F
.65877 .50401 m .65351 .50996 L .65273 .51304 L 0 0 0 r
F
.65877 .50401 m .65956 .50094 L .65351 .50996 L F
.60289 .55322 m .59155 .55644 L .59096 .55877 L .255 .011 0 r
F
.60289 .55322 m .60355 .55086 L .59155 .55644 L F
.34478 .53923 m .33262 .5307 L .33294 .53322 L 1 .704 0 r
F
.3451 .5417 m .34478 .53923 L .33294 .53322 L 1 .685 0 r
F
.55901 .34037 m .5551 .34083 L .55684 .34398 L .057 .061 0 r
F
.55901 .34037 m .55711 .33753 L .5551 .34083 L F
.64029 .8683 m .61834 .8707 L .61506 .8737 L .216 0 0 r
F
.64029 .8683 m .64417 .8652 L .61834 .8707 L F
.90065 .45775 m .88933 .47096 L .88992 .47784 L 0 0 0 r
F
.90065 .45775 m .90021 .45079 L .88933 .47096 L F
.58406 .57867 m .57182 .58119 L .57102 .58326 L .313 .01 0 r
F
.58406 .57867 m .58496 .57655 L .57182 .58119 L F
.86339 .28887 m .85635 .3038 L .8599 .30996 L 0 .036 0 r
F
.58566 .58303 m .57316 .58546 L .57234 .58757 L .318 .011 0 r
F
.58566 .58303 m .58659 .58088 L .57316 .58546 L F
.7612 .4044 m .76308 .40909 L .76399 .41411 L .691 .094 0 r
F
.76096 .40357 m .76108 .40388 L .7612 .4044 L F
.76108 .40388 m .76308 .40909 L .7612 .4044 L F
.76195 .40682 m .76054 .40211 L .76399 .41411 L 0 0 0 r
F
.76195 .40682 m .76399 .41411 L .76484 .41911 L F
.76328 .41155 m .76195 .40682 L .76463 .41823 L F
.76478 .41881 m .76463 .41823 L .76484 .41911 L F
.76328 .41155 m .76463 .41823 L .76478 .41881 L F
.76328 .41155 m .76484 .41911 L .76565 .42411 L F
.76454 .4163 m .76328 .41155 L .76538 .42269 L F
.76555 .42346 m .76538 .42269 L .76565 .42411 L F
.76454 .4163 m .76538 .42269 L .76555 .42346 L F
.76054 .40211 m .76072 .40258 L .76096 .40357 L .691 .094 0 r
F
.76072 .40258 m .76308 .40909 L .76096 .40357 L F
.76054 .40211 m .75907 .39741 L .76308 .40909 L F
.51549 .33894 m .51352 .33584 L .51088 .33753 L .348 .248 0 r
F
.43621 .62493 m .41972 .62217 L .42039 .62379 L .942 .077 0 r
F
.43668 .62649 m .43621 .62493 L .42039 .62379 L .928 .074 0 r
F
.62405 .45493 m .61554 .45933 L .61625 .462 L .203 .052 0 r
F
.62405 .45493 m .62329 .45229 L .61554 .45933 L F
.62017 .45012 m .61188 .45441 L .61262 .45703 L .206 .053 0 r
F
.62017 .45012 m .61939 .44753 L .61188 .45441 L F
.3462 .61961 m .32982 .61116 L .33083 .614 L 1 .415 0 r
F
.34717 .62232 m .3462 .61961 L .33083 .614 L 1 .396 0 r
F
.63558 .73073 m .621 .73788 L .6187 .74096 L 0 0 0 r
F
.63558 .73073 m .63832 .72784 L .621 .73788 L F
.3094 .45006 m .30377 .43941 L .30251 .44224 L 1 1 0 r
F
.30823 .45297 m .3094 .45006 L .30251 .44224 L F
.35949 .58267 m .34385 .57596 L .34474 .5783 L 1 .441 0 r
F
.36029 .58493 m .35949 .58267 L .34474 .5783 L 1 .42 0 r
F
.76928 .5177 m .76019 .52646 L .75964 .53125 L 0 0 0 r
F
.76928 .5177 m .76972 .51285 L .76019 .52646 L F
.74155 .60488 m .72849 .6118 L .72695 .61611 L F
.74155 .60488 m .74322 .60048 L .72849 .6118 L F
.5821 .77443 m .56564 .78418 L .56376 .787 L F
.5821 .77443 m .58446 .77191 L .56564 .78418 L F
.86258 .28927 m .85504 .3044 L .85845 .3106 L 0 .034 0 r
F
.86258 .28927 m .85906 .28317 L .85504 .3044 L F
.30471 .53451 m .29413 .52323 L .29408 .52636 L 1 .783 0 r
F
.30473 .53763 m .30471 .53451 L .29408 .52636 L 1 .765 0 r
F
.33321 .48932 m .32402 .47995 L .32361 .48257 L 1 .953 0 r
F
.33287 .49194 m .33321 .48932 L .32361 .48257 L 1 .939 0 r
F
.39142 .35856 m .39134 .35461 L .38886 .35604 L .856 .98 0 r
F
.39142 .35856 m .39388 .35709 L .39134 .35461 L F
.61863 .51475 m .60855 .51865 L .6084 .52121 L .204 .021 0 r
F
.61863 .51475 m .61879 .51217 L .60855 .51865 L F
.83482 .72288 m .81594 .7299 L .81298 .73574 L 0 0 0 r
F
.83482 .72288 m .83802 .71684 L .81594 .7299 L F
.42249 .34759 m .42221 .34508 L .41947 .34557 L .674 .894 0 r
F
.42249 .34759 m .42497 .34667 L .42221 .34508 L F
.46883 .62432 m .46881 .62295 L .45322 .62255 L .805 .057 0 r
F
.48421 .62407 m .46881 .62295 L .46883 .62432 L .736 .049 0 r
F
.48421 .62407 m .48442 .6227 L .46881 .62295 L F
.41275 .85594 m .38377 .85661 L .38572 .85953 L .699 .039 0 r
F
.41407 .85876 m .41275 .85594 L .38572 .85953 L .674 .034 0 r
F
.4405 .85332 m .41275 .85594 L .41407 .85876 L .601 .027 0 r
F
.43695 .61858 m .42101 .6153 L .42166 .61685 L .955 .077 0 r
F
.4374 .62006 m .43695 .61858 L .42166 .61685 L .94 .074 0 r
F
.40235 .60442 m .38687 .59935 L .38775 .60119 L 1 .228 0 r
F
.4031 .60619 m .40235 .60442 L .38775 .60119 L 1 .202 0 r
F
.31696 .44239 m .30898 .43139 L .30795 .43424 L 1 1 0 r
F
.31603 .44525 m .31696 .44239 L .30795 .43424 L F
.69844 .37169 m .69597 .37756 L .69443 .38295 L 0 0 0 r
F
.69844 .37169 m .69979 .3663 L .69597 .37756 L F
.61725 .59 m .60669 .59493 L .60541 .59727 L .012 0 0 r
F
.61725 .59 m .61861 .58759 L .60669 .59493 L F
.43742 .34329 m .43725 .34247 L .43481 .34328 L .442 .259 0 r
F
.43742 .34329 m .43971 .34242 L .43725 .34247 L F
.56095 .34306 m .55684 .34398 L .55863 .34691 L .107 .071 0 r
F
.56095 .34306 m .55901 .34037 L .55684 .34398 L F
.43855 .90143 m .4377 .89921 L .41002 .89824 L .538 .003 0 r
F
.46583 .90151 m .4377 .89921 L .43855 .90143 L .501 0 0 r
F
.66751 .70261 m .65321 .7087 L .65091 .71208 L 0 0 0 r
F
.66751 .70261 m .67019 .69932 L .65321 .7087 L F
.46877 .63001 m .46875 .62857 L .45288 .62856 L .795 .056 0 r
F
.48434 .62947 m .46875 .62857 L .46877 .63001 L .728 .049 0 r
F
.48434 .62947 m .48456 .62804 L .46875 .62857 L F
.41907 .6205 m .40255 .61701 L .40339 .61875 L 1 .128 0 r
F
.41972 .62217 m .41907 .6205 L .40339 .61875 L .994 .104 0 r
F
.46838 .66694 m .46835 .66555 L .45072 .66686 L .612 .025 0 r
F
.48538 .66487 m .46835 .66555 L .46838 .66694 L .501 .009 0 r
F
.48538 .66487 m .48567 .66356 L .46835 .66555 L F
.88747 .61719 m .87049 .62715 L .86894 .63381 L 0 0 0 r
F
.88747 .61719 m .88912 .61035 L .87049 .62715 L F
.62092 .45273 m .61262 .45703 L .61333 .45966 L .199 .051 0 r
F
.62092 .45273 m .62017 .45012 L .61262 .45703 L F
.62478 .45758 m .61625 .462 L .61692 .46467 L .198 .049 0 r
F
.62478 .45758 m .62405 .45493 L .61625 .462 L F
.38095 .60123 m .36474 .59583 L .36573 .59793 L 1 .31 0 r
F
.3818 .60324 m .38095 .60123 L .36573 .59793 L 1 .287 0 r
F
.57375 .63039 m .56074 .63394 L .55946 .63569 L .181 0 0 r
F
.57375 .63039 m .57524 .62859 L .56074 .63394 L F
.38362 .59167 m .36875 .58555 L .36962 .58759 L 1 .341 0 r
F
.3844 .59363 m .38362 .59167 L .36962 .58759 L 1 .317 0 r
F
.30823 .45297 m .30251 .44224 L .3013 .44509 L 1 1 0 r
F
.30711 .4559 m .30823 .45297 L .3013 .44509 L F
.39215 .65415 m .37367 .64923 L .37485 .65156 L 1 .152 0 r
F
.39318 .65629 m .39215 .65415 L .37485 .65156 L 1 .131 0 r
F
.54731 .60755 m .53383 .60882 L .53306 .61046 L .418 .017 0 r
F
.54731 .60755 m .54826 .60587 L .53383 .60882 L F
.39388 .35709 m .39381 .35317 L .39134 .35461 L .862 .996 0 r
F
.39388 .35709 m .39634 .35564 L .39381 .35317 L F
.31925 .51284 m .30721 .50289 L .30726 .50574 L 1 .805 0 r
F
.31934 .51563 m .31925 .51284 L .30726 .50574 L 1 .789 0 r
F
.77749 .79055 m .75759 .79552 L .75393 .80049 L .05 0 0 r
F
.77749 .79055 m .78151 .78539 L .75759 .79552 L F
.53064 .61519 m .51663 .61588 L .51601 .61738 L .499 .024 0 r
F
.53064 .61519 m .53147 .61365 L .51663 .61588 L F
.62136 .52073 m .61091 .52462 L .61071 .52721 L .21 .02 0 r
F
.62136 .52073 m .62158 .51811 L .61091 .52462 L F
.09794 .68879 m .07299 .66745 L .07538 .67402 L 1 .29 0 r
F
.10027 .69512 m .09794 .68879 L .07538 .67402 L 1 .26 0 r
F
.49936 .62318 m .48442 .6227 L .48421 .62407 L .656 .039 0 r
F
.49936 .62318 m .4998 .62181 L .48442 .6227 L F
.32324 .5879 m .30914 .57779 L .3098 .58083 L 1 .567 0 r
F
.32392 .59086 m .32324 .5879 L .3098 .58083 L 1 .547 0 r
F
.33806 .55637 m .32368 .54813 L .32431 .55074 L 1 .591 0 r
F
.33866 .5589 m .33806 .55637 L .32431 .55074 L 1 .571 0 r
F
.51472 .62029 m .50023 .6204 L .4998 .62181 L .577 .031 0 r
F
.51472 .62029 m .51537 .61885 L .50023 .6204 L F
.56291 .34564 m .55863 .34691 L .56046 .34969 L .142 .078 0 r
F
.56291 .34564 m .56095 .34306 L .55863 .34691 L F
.41294 .6618 m .39423 .65839 L .3953 .66047 L .948 .075 0 r
F
.41381 .66368 m .41294 .6618 L .3953 .66047 L .932 .072 0 r
F
.55412 .64226 m .54025 .64524 L .53913 .64678 L .241 0 0 r
F
.55412 .64226 m .55549 .64068 L .54025 .64524 L F
.33287 .49194 m .32361 .48257 L .32324 .48519 L 1 .939 0 r
F
.33257 .49456 m .33287 .49194 L .32324 .48519 L 1 .924 0 r
F
.54989 .3377 m .54681 .33644 L .54848 .33988 L 0 .024 0 r
F
.54989 .3377 m .54803 .33466 L .54681 .33644 L F
.6044 .55963 m .59281 .56275 L .59216 .5651 L .258 .01 0 r
F
.6044 .55963 m .60513 .55724 L .59281 .56275 L F
.3451 .5417 m .33294 .53322 L .33329 .53572 L 1 .685 0 r
F
.34546 .54416 m .3451 .5417 L .33329 .53572 L 1 .665 0 r
F
.54812 .61225 m .5345 .61349 L .53371 .61518 L .419 .017 0 r
F
.54812 .61225 m .54909 .61053 L .5345 .61349 L F
.37701 .89801 m .34643 .89225 L .34939 .89508 L .677 .025 0 r
F
.37931 .90063 m .37701 .89801 L .34939 .89508 L .645 .019 0 r
F
.21352 .82224 m .1835 .80866 L .18753 .81353 L .96 .079 0 r
F
.21722 .82685 m .21352 .82224 L .18753 .81353 L .934 .074 0 r
F
.72568 .83293 m .705 .83654 L .70114 .84074 L .124 0 0 r
F
.72568 .83293 m .72999 .82856 L .705 .83654 L F
.31603 .44525 m .30795 .43424 L .30697 .4371 L 1 1 0 r
F
.31513 .44811 m .31603 .44525 L .30697 .4371 L F
.44077 .32062 m .44394 .33069 L .44073 .32886 L 1 .233 0 r
F
.44077 .32062 m .4444 .32483 L .44394 .33069 L F
.77384 .16884 m .77187 .18227 L .77731 .18679 L .09 .093 0 r
F
.77384 .16884 m .76834 .16464 L .77187 .18227 L F
.53123 .62003 m .5171 .62073 L .51646 .62229 L .496 .023 0 r
F
.53123 .62003 m .53208 .61845 L .5171 .62073 L F
.90944 .46439 m .89625 .47779 L .897 .48478 L 0 0 0 r
F
.90944 .46439 m .90865 .45732 L .89625 .47779 L F
.76801 .17484 m .77181 .18232 L .77704 .18706 L .279 .281 0 r
F
.76801 .17484 m .75916 .17441 L .77181 .18232 L F
.60769 .89052 m .58445 .89166 L .58163 .8944 L .294 0 0 r
F
.60769 .89052 m .61117 .88768 L .58445 .89166 L F
.39634 .35564 m .39628 .35174 L .39381 .35317 L .869 1 0 r
F
.39634 .35564 m .39881 .35422 L .39628 .35174 L F
.40094 .61343 m .38452 .6091 L .38548 .61099 L 1 .203 0 r
F
.40173 .61524 m .40094 .61343 L .38548 .61099 L 1 .179 0 r
F
.63896 .5563 m .63055 .56198 L .62949 .56466 L 0 0 0 r
F
.63896 .5563 m .64005 .55358 L .63055 .56198 L F
.49964 .62837 m .48456 .62804 L .48434 .62947 L .648 .039 0 r
F
.49964 .62837 m .5001 .62695 L .48456 .62804 L F
.6022 .55556 m .59096 .55877 L .59033 .56107 L .249 .008 0 r
F
.6022 .55556 m .60289 .55322 L .59096 .55877 L F
.62162 .45534 m .61333 .45966 L .61399 .46229 L .192 .048 0 r
F
.62162 .45534 m .62092 .45273 L .61333 .45966 L F
.42038 .61371 m .40464 .60961 L .40545 .61127 L 1 .125 0 r
F
.42101 .6153 m .42038 .61371 L .40545 .61127 L 1 .1 0 r
F
.61842 .51732 m .6084 .52121 L .60821 .52376 L .197 .018 0 r
F
.61842 .51732 m .61863 .51475 L .6084 .52121 L F
.62546 .46023 m .61692 .46467 L .61756 .46734 L .192 .047 0 r
F
.62546 .46023 m .62478 .45758 L .61692 .46467 L F
.30711 .4559 m .3013 .44509 L .30014 .44796 L 1 1 0 r
F
.30603 .45884 m .30711 .4559 L .30014 .44796 L F
.3642 .57273 m .35036 .56547 L .35109 .56773 L 1 .484 0 r
F
.36488 .57493 m .3642 .57273 L .35109 .56773 L 1 .461 0 r
F
.65797 .50706 m .65273 .51304 L .65195 .51609 L 0 0 0 r
F
.65797 .50706 m .65877 .50401 L .65273 .51304 L F
.56487 .34813 m .56046 .34969 L .56233 .35234 L .166 .083 0 r
F
.56487 .34813 m .56291 .34564 L .56046 .34969 L F
.51514 .62529 m .50054 .62548 L .5001 .62695 L .572 .03 0 r
F
.51514 .62529 m .51581 .62381 L .50054 .62548 L F
.56463 .59692 m .55181 .59879 L .55096 .60061 L .363 .011 0 r
F
.56463 .59692 m .56563 .59506 L .55181 .59879 L F
.30473 .53763 m .29408 .52636 L .29407 .52949 L 1 .765 0 r
F
.3048 .54075 m .30473 .53763 L .29407 .52949 L 1 .747 0 r
F
.70303 .66476 m .68904 .67065 L .68693 .67443 L 0 0 0 r
F
.70303 .66476 m .70542 .66096 L .68904 .67065 L F
.43241 .6658 m .41381 .66368 L .4147 .66552 L .841 .058 0 r
F
.43304 .66745 m .43241 .6658 L .4147 .66552 L .822 .055 0 r
F
.45072 .66686 m .43241 .6658 L .43304 .66745 L .735 .043 0 r
F
.30584 .87554 m .27486 .8667 L .27877 .87031 L .799 .046 0 r
F
.30922 .87891 m .30584 .87554 L .27877 .87031 L .769 .041 0 r
F
.42497 .34667 m .42504 .34495 L .42221 .34508 L .529 .613 0 r
F
.42497 .34667 m .42745 .34583 L .42504 .34495 L F
.45106 .66834 m .45072 .66686 L .43304 .66745 L .712 .039 0 r
F
.46838 .66694 m .45072 .66686 L .45106 .66834 L .612 .025 0 r
F
.68066 .86035 m .65921 .86296 L .6555 .86655 L .187 0 0 r
F
.68066 .86035 m .68491 .85662 L .65921 .86296 L F
.60166 .28794 m .6523 .21828 L .65373 .22562 L .385 .021 0 r
F
.60166 .28794 m .59128 .29697 L .6523 .21828 L F
.37031 .64208 m .35258 .63553 L .35377 .63811 L 1 .267 0 r
F
.3714 .64449 m .37031 .64208 L .35377 .63811 L 1 .247 0 r
F
.59416 .61479 m .58228 .61897 L .58093 .62098 L .102 0 0 r
F
.59416 .61479 m .59567 .61273 L .58228 .61897 L F
.58312 .58075 m .57102 .58326 L .57019 .5853 L .306 .007 0 r
F
.58312 .58075 m .58406 .57867 L .57102 .58326 L F
.56575 .6015 m .55274 .6033 L .55187 .60516 L .366 .011 0 r
F
.56575 .6015 m .56678 .59961 L .55274 .6033 L F
.58469 .58515 m .57234 .58757 L .57148 .58965 L .312 .008 0 r
F
.58469 .58515 m .58566 .58303 L .57234 .58757 L F
.46644 .84866 m .46639 .84594 L .4405 .85332 L .464 .009 0 r
F
.49061 .83932 m .46639 .84594 L .46644 .84866 L .363 0 0 r
F
.49061 .83932 m .49115 .83664 L .46639 .84594 L F
.34352 .88931 m .31267 .88217 L .31618 .88533 L .733 .034 0 r
F
.34643 .89225 m .34352 .88931 L .31618 .88533 L .701 .029 0 r
F
.39881 .35422 m .39877 .35033 L .39628 .35174 L .872 1 0 r
F
.39881 .35422 m .4013 .35284 L .39877 .35033 L F
.53567 .65113 m .52107 .6536 L .52018 .655 L .295 0 0 r
F
.53567 .65113 m .53684 .64973 L .52107 .6536 L F
.56684 .35056 m .56233 .35234 L .5642 .35491 L .182 .086 0 r
F
.56684 .35056 m .56487 .34813 L .56233 .35234 L F
.55182 .34047 m .54848 .33988 L .55027 .34297 L 0 .045 0 r
F
.55182 .34047 m .54989 .3377 L .54848 .33988 L F
.45322 .62255 m .4374 .62006 L .43787 .6215 L .878 .066 0 r
F
.45347 .62393 m .45322 .62255 L .43787 .6215 L .862 .063 0 r
F
.46883 .62432 m .45322 .62255 L .45347 .62393 L .805 .057 0 r
F
.22673 .79588 m .19666 .78477 L .20034 .78947 L 1 .088 0 r
F
.23007 .80033 m .22673 .79588 L .20034 .78947 L 1 .085 0 r
F
.45288 .62856 m .43668 .62649 L .43716 .62801 L .867 .066 0 r
F
.45314 .63001 m .45288 .62856 L .43716 .62801 L .852 .063 0 r
F
.46877 .63001 m .45288 .62856 L .45314 .63001 L .795 .056 0 r
F
.31513 .44811 m .30697 .4371 L .30604 .43996 L 1 1 0 r
F
.31429 .45098 m .31513 .44811 L .30604 .43996 L F
.33257 .49456 m .32324 .48519 L .32292 .48781 L 1 .924 0 r
F
.33231 .49718 m .33257 .49456 L .32292 .48781 L 1 .909 0 r
F
.36029 .58493 m .34474 .5783 L .34565 .58062 L 1 .42 0 r
F
.36112 .58716 m .36029 .58493 L .34565 .58062 L 1 .398 0 r
F
.31934 .51563 m .30726 .50574 L .30735 .50858 L 1 .789 0 r
F
.31948 .51841 m .31934 .51563 L .30735 .50858 L 1 .772 0 r
F
.11549 .67181 m .0904 .65199 L .09262 .65824 L 1 .339 0 r
F
.11765 .67781 m .11549 .67181 L .09262 .65824 L 1 .312 0 r
F
.52979 .28947 m .53936 .25229 L .53272 .28729 L 1 .428 0 r
F
.52979 .28947 m .53986 .242 L .53936 .25229 L F
.62227 .45795 m .61399 .46229 L .61462 .46492 L .186 .046 0 r
F
.62227 .45795 m .62162 .45534 L .61399 .46229 L F
.15801 .77232 m .12971 .75537 L .13327 .76106 L 1 .103 0 r
F
.16135 .77773 m .15801 .77232 L .13327 .76106 L 1 .099 0 r
F
.5018 .66217 m .48567 .66356 L .48538 .66487 L .415 0 0 r
F
.5018 .66217 m .50242 .66091 L .48567 .66356 L F
.82612 .71708 m .80882 .72474 L .80584 .7304 L 0 0 0 r
F
.82612 .71708 m .82932 .71122 L .80882 .72474 L F
.6211 .52334 m .61071 .52721 L .61046 .5298 L .203 .017 0 r
F
.6211 .52334 m .62136 .52073 L .61071 .52721 L F
.60618 .75494 m .59117 .76367 L .589 .76652 L 0 0 0 r
F
.60618 .75494 m .60882 .75235 L .59117 .76367 L F
.31541 .84218 m .28479 .83672 L .28828 .84035 L .899 .063 0 r
F
.31838 .84563 m .31541 .84218 L .28828 .84035 L .878 .059 0 r
F
.62609 .4629 m .61756 .46734 L .61815 .47002 L .186 .044 0 r
F
.62609 .4629 m .62546 .46023 L .61756 .46734 L F
.30603 .45884 m .30014 .44796 L .29902 .45085 L 1 1 0 r
F
.305 .4618 m .30603 .45884 L .29902 .45085 L F
.54743 .90482 m .5223 .90464 L .52083 .90693 L .381 0 0 r
F
.54743 .90482 m .54965 .90249 L .5223 .90464 L F
.56881 .35293 m .5642 .35491 L .56609 .35741 L .193 .088 0 r
F
.56881 .35293 m .56684 .35056 L .5642 .35491 L F
.86695 .29498 m .8599 .30996 L .86334 .31618 L 0 .032 0 r
F
.86695 .29498 m .86339 .28887 L .8599 .30996 L F
.76876 .52254 m .75964 .53125 L .75902 .53602 L 0 0 0 r
F
.76876 .52254 m .76928 .5177 L .75964 .53125 L F
.34717 .62232 m .33083 .614 L .33187 .61682 L 1 .396 0 r
F
.34818 .625 m .34717 .62232 L .33187 .61682 L 1 .376 0 r
F
.36727 .3907 m .36386 .38293 L .36194 .38491 L 1 1 0 r
F
.36727 .3907 m .36912 .38867 L .36386 .38293 L F
.36546 .39277 m .36727 .3907 L .36194 .38491 L F
.36546 .39277 m .36194 .38491 L .36006 .38692 L F
.36367 .39486 m .36546 .39277 L .36006 .38692 L F
.26357 .85528 m .23288 .8444 L .23701 .84856 L .869 .059 0 r
F
.26726 .85919 m .26357 .85528 L .23701 .84856 L .84 .054 0 r
F
.36912 .38867 m .37101 .38667 L .36581 .38097 L 1 1 0 r
F
.51836 .65764 m .50303 .6596 L .50242 .66091 L .351 0 0 r
F
.51836 .65764 m .51928 .65634 L .50303 .6596 L F
.36367 .39486 m .36006 .38692 L .3582 .38896 L 1 1 0 r
F
.36193 .39698 m .36367 .39486 L .3582 .38896 L F
.87696 .61374 m .86241 .62419 L .86077 .63066 L 0 0 0 r
F
.87696 .61374 m .87869 .60711 L .86241 .62419 L F
.37101 .38667 m .37293 .38471 L .36779 .37905 L 1 1 0 r
F
.38377 .85661 m .35414 .85537 L .3567 .85841 L .768 .046 0 r
F
.38572 .85953 m .38377 .85661 L .3567 .85841 L .745 .041 0 r
F
.4274 .32358 m .43052 .32355 L .42906 .32276 L .225 .174 0 r
F
.4013 .35284 m .40127 .34898 L .39877 .35033 L .872 1 0 r
F
.4013 .35284 m .40379 .3515 L .40127 .34898 L F
.36193 .39698 m .3582 .38896 L .35638 .39102 L 1 1 0 r
F
.36021 .39913 m .36193 .39698 L .35638 .39102 L F
.34546 .54416 m .33329 .53572 L .33368 .53821 L 1 .665 0 r
F
.34586 .5466 m .34546 .54416 L .33368 .53821 L 1 .645 0 r
F
.37293 .38471 m .37488 .38277 L .36979 .37714 L 1 1 0 r
F
.55381 .34304 m .55027 .34297 L .55212 .34581 L 0 .061 0 r
F
.55381 .34304 m .55182 .34047 L .55027 .34297 L F
.37851 .89137 m .34841 .88572 L .35132 .88852 L .677 .025 0 r
F
.38078 .89395 m .37851 .89137 L .35132 .88852 L .645 .019 0 r
F
.90095 .46471 m .88992 .47784 L .89039 .48471 L 0 0 0 r
F
.90095 .46471 m .90065 .45775 L .88992 .47784 L F
.57077 .35526 m .56609 .35741 L .56798 .35985 L .2 .098 0 r
F
.57077 .35526 m .56881 .35293 L .56609 .35741 L F
.44118 .85604 m .4405 .85332 L .41407 .85876 L .573 .022 0 r
F
.46644 .84866 m .4405 .85332 L .44118 .85604 L .464 .009 0 r
F
.35163 .85224 m .3214 .84899 L .32449 .85227 L .834 .054 0 r
F
.35414 .85537 m .35163 .85224 L .32449 .85227 L .813 .05 0 r
F
.36021 .39913 m .35638 .39102 L .35459 .39311 L 1 1 0 r
F
.35853 .4013 m .36021 .39913 L .35459 .39311 L F
.61818 .51987 m .60821 .52376 L .60798 .5263 L .191 .015 0 r
F
.61818 .51987 m .61842 .51732 L .60821 .52376 L F
.86598 .29544 m .85845 .3106 L .86174 .31685 L 0 .03 0 r
F
.86598 .29544 m .86258 .28927 L .85845 .3106 L F
.33866 .5589 m .32431 .55074 L .32497 .55332 L 1 .571 0 r
F
.3393 .5614 m .33866 .5589 L .32497 .55332 L 1 .552 0 r
F
.77046 .78343 m .7517 .78904 L .74805 .79384 L .004 0 0 r
F
.77046 .78343 m .77445 .77845 L .7517 .78904 L F
.37488 .38277 m .37686 .38088 L .37182 .37527 L 1 1 0 r
F
.4031 .60619 m .38775 .60119 L .38865 .603 L 1 .202 0 r
F
.40386 .60792 m .4031 .60619 L .38865 .603 L 1 .177 0 r
F
.61585 .59237 m .60541 .59727 L .60411 .59959 L .002 0 0 r
F
.61585 .59237 m .61725 .59 L .60541 .59727 L F
.43668 .62649 m .42039 .62379 L .42108 .62539 L .928 .074 0 r
F
.43716 .62801 m .43668 .62649 L .42108 .62539 L .914 .071 0 r
F
.35853 .4013 m .35459 .39311 L .35284 .39523 L 1 1 0 r
F
.35689 .4035 m .35853 .4013 L .35284 .39523 L F
.21809 .81619 m .18879 .80263 L .19271 .80746 L .966 .08 0 r
F
.22169 .82076 m .21809 .81619 L .19271 .80746 L .94 .076 0 r
F
.60364 .562 m .59216 .5651 L .59147 .56743 L .251 .007 0 r
F
.60364 .562 m .6044 .55963 L .59216 .5651 L F
.37686 .38088 m .37888 .37903 L .37387 .37341 L 1 1 0 r
F
.31429 .45098 m .30604 .43996 L .30515 .44284 L F
.3135 .45386 m .31429 .45098 L .30515 .44284 L F
.73981 .60925 m .72695 .61611 L .72534 .62038 L 0 0 0 r
F
.73981 .60925 m .74155 .60488 L .72695 .61611 L F
.3844 .59363 m .36962 .58759 L .37052 .5896 L 1 .317 0 r
F
.38519 .59557 m .3844 .59363 L .37052 .5896 L 1 .292 0 r
F
.62288 .46057 m .61462 .46492 L .6152 .46755 L .179 .043 0 r
F
.62288 .46057 m .62227 .45795 L .61462 .46492 L F
.32392 .59086 m .3098 .58083 L .3105 .58386 L 1 .547 0 r
F
.32464 .59381 m .32392 .59086 L .3105 .58386 L 1 .527 0 r
F
.3048 .54075 m .29407 .52949 L .29412 .53263 L 1 .747 0 r
F
.30492 .54387 m .3048 .54075 L .29412 .53263 L 1 .729 0 r
F
.35689 .4035 m .35284 .39523 L .35112 .39737 L 1 1 0 r
F
.35528 .40573 m .35689 .4035 L .35112 .39737 L F
.3818 .60324 m .36573 .59793 L .36674 .6 L 1 .287 0 r
F
.38268 .60522 m .3818 .60324 L .36674 .6 L 1 .263 0 r
F
.57272 .35756 m .56798 .35985 L .56987 .36224 L .205 .105 0 r
F
.57272 .35756 m .57077 .35526 L .56798 .35985 L F
.10637 .6841 m .08255 .66297 L .08478 .66943 L 1 .295 0 r
F
.10857 .69032 m .10637 .6841 L .08478 .66943 L 1 .265 0 r
F
.42745 .34583 m .42776 .3446 L .42504 .34495 L .458 .345 0 r
F
.42745 .34583 m .42993 .345 L .42776 .3446 L F
.27475 .82537 m .24419 .81739 L .24792 .82147 L .96 .073 0 r
F
.27803 .82923 m .27475 .82537 L .24792 .82147 L .94 .069 0 r
F
.33231 .49718 m .32292 .48781 L .32263 .49043 L 1 .909 0 r
F
.33209 .4998 m .33231 .49718 L .32263 .49043 L 1 .894 0 r
F
.37888 .37903 m .37594 .37157 L .37387 .37341 L 1 1 0 r
F
.37888 .37903 m .38093 .37721 L .37594 .37157 L F
.60147 .55788 m .59033 .56107 L .58966 .56335 L .242 .005 0 r
F
.60147 .55788 m .6022 .55556 L .59033 .56107 L F
.305 .4618 m .29902 .45085 L .29795 .45376 L 1 1 0 r
F
.30401 .46477 m .305 .4618 L .29795 .45376 L F
.62668 .46557 m .61815 .47002 L .6187 .4727 L .179 .042 0 r
F
.62668 .46557 m .62609 .4629 L .61815 .47002 L F
.72 .82506 m .70023 .82927 L .6964 .83331 L .084 0 0 r
F
.72 .82506 m .72427 .82086 L .70023 .82927 L F
.17336 .75002 m .14491 .73508 L .14819 .74051 L 1 .163 0 r
F
.17643 .75518 m .17336 .75002 L .14819 .74051 L 1 .137 0 r
F
.30851 .86917 m .27808 .86037 L .28191 .86396 L .804 .046 0 r
F
.31183 .87251 m .30851 .86917 L .28191 .86396 L .774 .041 0 r
F
.4374 .62006 m .42166 .61685 L .42233 .61836 L .94 .074 0 r
F
.43787 .6215 m .4374 .62006 L .42233 .61836 L .925 .071 0 r
F
.55584 .34546 m .55212 .34581 L .55403 .34847 L .048 .072 0 r
F
.55584 .34546 m .55381 .34304 L .55212 .34581 L F
.69702 .37697 m .69443 .38295 L .69288 .3882 L 0 0 0 r
F
.69702 .37697 m .69844 .37169 L .69443 .38295 L F
.60487 .88205 m .58227 .88373 L .57948 .88632 L .261 0 0 r
F
.60487 .88205 m .60832 .87937 L .58227 .88373 L F
.35528 .40573 m .35112 .39737 L .34944 .39954 L 1 1 0 r
F
.35371 .40798 m .35528 .40573 L .34944 .39954 L F
.55781 .79473 m .53987 .80512 L .53834 .80785 L 0 0 0 r
F
.55781 .79473 m .55985 .79228 L .53987 .80512 L F
.40379 .3515 m .40381 .34768 L .40127 .34898 L .867 1 0 r
F
.40379 .3515 m .40631 .35022 L .40381 .34768 L F
.54753 .31956 m .54836 .31154 L .54912 .31804 L 1 .357 0 r
F
.54753 .31956 m .5459 .31526 L .54836 .31154 L F
.46885 .62564 m .46883 .62432 L .45347 .62393 L .789 .053 0 r
F
.48399 .62539 m .46883 .62432 L .46885 .62564 L .72 .045 0 r
F
.48399 .62539 m .48421 .62407 L .46883 .62432 L F
.38093 .37721 m .37802 .36974 L .37594 .37157 L 1 1 0 r
F
.38093 .37721 m .38301 .37543 L .37802 .36974 L F
.41972 .62217 m .40339 .61875 L .40425 .62046 L .994 .104 0 r
F
.42039 .62379 m .41972 .62217 L .40425 .62046 L .98 .081 0 r
F
.54634 .6092 m .53306 .61046 L .53228 .61207 L .411 .014 0 r
F
.54634 .6092 m .54731 .60755 L .53306 .61046 L F
.57466 .35984 m .56987 .36224 L .57176 .36461 L .207 .109 0 r
F
.57466 .35984 m .57272 .35756 L .56987 .36224 L F
.65716 .51008 m .65195 .51609 L .65115 .51911 L 0 0 0 r
F
.65716 .51008 m .65797 .50706 L .65195 .51609 L F
.36488 .57493 m .35109 .56773 L .35185 .56998 L 1 .461 0 r
F
.36559 .57711 m .36488 .57493 L .35185 .56998 L 1 .437 0 r
F
.34555 .88282 m .31521 .87575 L .31865 .87889 L .736 .034 0 r
F
.34841 .88572 m .34555 .88282 L .31865 .87889 L .705 .029 0 r
F
.57586 .89955 m .55184 .90004 L .54965 .90249 L .336 0 0 r
F
.57586 .89955 m .57877 .89703 L .55184 .90004 L F
.63785 .559 m .62949 .56466 L .6284 .56732 L 0 0 0 r
F
.63785 .559 m .63896 .5563 L .62949 .56466 L F
.35371 .40798 m .34944 .39954 L .34779 .40173 L 1 1 0 r
F
.35217 .41025 m .35371 .40798 L .34779 .40173 L F
.31948 .51841 m .30735 .50858 L .30749 .51141 L 1 .772 0 r
F
.31965 .52119 m .31948 .51841 L .30749 .51141 L 1 .755 0 r
F
.39422 .36283 m .39273 .35678 L .39059 .35864 L 1 1 0 r
F
.39422 .36283 m .39616 .36072 L .39273 .35678 L F
.39239 .36507 m .39422 .36283 L .39059 .35864 L F
.38301 .37543 m .3801 .36791 L .37802 .36974 L F
.38301 .37543 m .38511 .37368 L .3801 .36791 L F
.39616 .36072 m .39491 .35496 L .39273 .35678 L F
.39616 .36072 m .39819 .35872 L .39491 .35496 L F
.62079 .52594 m .61046 .5298 L .61018 .53237 L .197 .014 0 r
F
.62079 .52594 m .6211 .52334 L .61046 .5298 L F
.5298 .61669 m .51601 .61738 L .51537 .61885 L .483 .02 0 r
F
.5298 .61669 m .53064 .61519 L .51601 .61738 L F
.5579 .34776 m .55403 .34847 L .55598 .35098 L .09 .081 0 r
F
.5579 .34776 m .55584 .34546 L .55403 .34847 L F
.51583 .33279 m .51236 .32947 L .51402 .33412 L .024 .04 0 r
F
.51583 .33279 m .51397 .3287 L .51236 .32947 L F
.51332 .33103 m .51031 .32582 L .51173 .33179 L 0 0 0 r
F
.51332 .33103 m .51163 .32597 L .51031 .32582 L F
.46879 .63141 m .46877 .63001 L .45314 .63001 L .779 .053 0 r
F
.48412 .63085 m .46877 .63001 L .46879 .63141 L .711 .045 0 r
F
.48412 .63085 m .48434 .62947 L .46877 .63001 L F
.67609 .85205 m .65543 .85525 L .65174 .85867 L .15 0 0 r
F
.67609 .85205 m .6803 .8485 L .65543 .85525 L F
.39239 .36507 m .39059 .35864 L .38847 .3605 L 1 1 0 r
F
.3907 .36746 m .39239 .36507 L .38847 .3605 L F
.57659 .36209 m .57176 .36461 L .57363 .36695 L .208 .111 0 r
F
.57659 .36209 m .57466 .35984 L .57176 .36461 L F
.35217 .41025 m .34779 .40173 L .34618 .40394 L 1 1 0 r
F
.35067 .41254 m .35217 .41025 L .34618 .40394 L F
.42703 .34299 m .42495 .33025 L .42343 .33512 L .905 .636 0 r
F
.42776 .3446 m .42744 .34296 L .42703 .34299 L F
.4274 .34297 m .42495 .33025 L .42703 .34299 L F
.42744 .34296 m .42495 .33025 L .4274 .34297 L F
.42957 .34384 m .42983 .34279 L .4273 .34315 L .479 .469 0 r
F
.42983 .34279 m .42991 .34246 L .42822 .34291 L F
.42983 .34279 m .42822 .34291 L .4273 .34315 L F
.42957 .34384 m .43207 .34307 L .42991 .34246 L F
.42776 .3446 m .43026 .34364 L .42976 .34237 L .905 .636 0 r
F
.42744 .34296 m .42976 .34237 L .42495 .33025 L F
.4273 .34315 m .42991 .34246 L .42976 .34237 L .477 .487 0 r
F
.4273 .34315 m .42976 .34237 L .42744 .34296 L F
.42776 .3446 m .42976 .34237 L .42744 .34296 L .905 .636 0 r
F
.42744 .34296 m .42976 .34237 L .42846 .34162 L .477 .487 0 r
F
.42705 .34303 m .42846 .34162 L .42586 .34248 L F
.4273 .34315 m .42744 .34296 L .42705 .34303 L F
.42744 .34296 m .42846 .34162 L .42705 .34303 L F
.42744 .34296 m .42744 .34296 L .4274 .34297 L .905 .636 0 r
F
.39819 .35872 m .39713 .35318 L .39491 .35496 L 1 1 0 r
F
.39819 .35872 m .4003 .35681 L .39713 .35318 L F
.62345 .4632 m .6152 .46755 L .61574 .47019 L .172 .04 0 r
F
.62345 .4632 m .62288 .46057 L .6152 .46755 L F
.57224 .63215 m .55946 .63569 L .55816 .6374 L .166 0 0 r
F
.57224 .63215 m .57375 .63039 L .55946 .63569 L F
.3135 .45386 m .30515 .44284 L .30432 .44572 L 1 1 0 r
F
.31275 .45674 m .3135 .45386 L .30432 .44572 L F
.54712 .61394 m .53371 .61518 L .5329 .61683 L .411 .013 0 r
F
.54712 .61394 m .54812 .61225 L .53371 .61518 L F
.38511 .37368 m .38219 .36608 L .3801 .36791 L 1 1 0 r
F
.38511 .37368 m .38718 .3719 L .38219 .36608 L F
.3907 .36746 m .38847 .3605 L .38637 .36237 L F
.38906 .36987 m .3907 .36746 L .38637 .36237 L F
.58215 .58281 m .57019 .5853 L .56934 .58731 L .299 .004 0 r
F
.58215 .58281 m .58312 .58075 L .57019 .5853 L F
.5636 .59875 m .55096 .60061 L .55008 .6024 L .356 .007 0 r
F
.5636 .59875 m .56463 .59692 L .55096 .60061 L F
.4003 .35681 m .39939 .35145 L .39713 .35318 L 1 1 0 r
F
.4003 .35681 m .40248 .35499 L .39939 .35145 L F
.49891 .62452 m .48421 .62407 L .48399 .62539 L .639 .036 0 r
F
.49891 .62452 m .49936 .62318 L .48421 .62407 L F
.55998 .34997 m .55598 .35098 L .55795 .35339 L .123 .088 0 r
F
.55998 .34997 m .5579 .34776 L .55598 .35098 L F
.51405 .62168 m .4998 .62181 L .49936 .62318 L .561 .027 0 r
F
.51405 .62168 m .51472 .62029 L .4998 .62181 L F
.5785 .36433 m .57363 .36695 L .5755 .36928 L .208 .111 0 r
F
.5785 .36433 m .57659 .36209 L .57363 .36695 L F
.30401 .46477 m .29795 .45376 L .29692 .45669 L 1 1 0 r
F
.30307 .46776 m .30401 .46477 L .29692 .45669 L 1 .991 0 r
F
.40631 .35022 m .40638 .34647 L .40381 .34768 L .855 1 0 r
F
.40173 .61524 m .38548 .61099 L .38647 .61284 L 1 .179 0 r
F
.40255 .61701 m .40173 .61524 L .38647 .61284 L 1 .154 0 r
F
.35067 .41254 m .34618 .40394 L .34461 .40618 L 1 1 0 r
F
.34921 .41486 m .35067 .41254 L .34461 .40618 L F
.58368 .58725 m .57148 .58965 L .5706 .5917 L .304 .004 0 r
F
.58368 .58725 m .58469 .58515 L .57148 .58965 L F
.62723 .46824 m .6187 .4727 L .61921 .47538 L .173 .039 0 r
F
.62723 .46824 m .62668 .46557 L .6187 .4727 L F
.16411 .76664 m .13669 .74976 L .1401 .75539 L 1 .104 0 r
F
.16734 .772 m .16411 .76664 L .1401 .75539 L 1 .101 0 r
F
.54597 .89668 m .52137 .89695 L .51992 .89912 L .357 0 0 r
F
.54597 .89668 m .54817 .89448 L .52137 .89695 L F
.39318 .65629 m .37485 .65156 L .37606 .65386 L 1 .131 0 r
F
.39423 .65839 m .39318 .65629 L .37606 .65386 L 1 .111 0 r
F
.61789 .52242 m .60798 .5263 L .60771 .52882 L .184 .012 0 r
F
.61789 .52242 m .61818 .51987 L .60798 .5263 L F
.77925 .17314 m .77731 .18679 L .78267 .19141 L .075 .089 0 r
F
.77925 .17314 m .77384 .16884 L .77731 .18679 L F
.26703 .84904 m .23696 .83817 L .24099 .84231 L .875 .06 0 r
F
.27064 .85291 m .26703 .84904 L .24099 .84231 L .847 .056 0 r
F
.38718 .3719 m .38428 .36423 L .38219 .36608 L 1 1 0 r
F
.38718 .3719 m .38906 .36987 L .38428 .36423 L F
.42101 .6153 m .40545 .61127 L .40627 .6129 L 1 .1 0 r
F
.42166 .61685 m .42101 .6153 L .40627 .6129 L .993 .081 0 r
F
.38906 .36987 m .38637 .36237 L .38428 .36423 L 1 1 0 r
F
.33209 .4998 m .32263 .49043 L .32239 .49304 L 1 .894 0 r
F
.33191 .50241 m .33209 .4998 L .32239 .49304 L 1 .878 0 r
F
.34586 .5466 m .33368 .53821 L .33412 .54068 L 1 .645 0 r
F
.34629 .54902 m .34586 .5466 L .33412 .54068 L 1 .624 0 r
F
.53036 .62157 m .51646 .62229 L .51581 .62381 L .48 .02 0 r
F
.53036 .62157 m .53123 .62003 L .51646 .62229 L F
.77478 .17761 m .77704 .18706 L .78224 .19181 L .079 .124 0 r
F
.77478 .17761 m .76801 .17484 L .77704 .18706 L F
.43052 .32355 m .43188 .32143 L .42906 .32276 L 0 0 0 r
F
.40248 .35499 m .4017 .34977 L .39939 .35145 L 1 1 0 r
F
.40248 .35499 m .40472 .35326 L .4017 .34977 L F
.36112 .58716 m .34565 .58062 L .34661 .58292 L 1 .398 0 r
F
.36198 .58937 m .36112 .58716 L .34661 .58292 L 1 .376 0 r
F
.56207 .35211 m .55795 .35339 L .55993 .35572 L .15 .093 0 r
F
.56207 .35211 m .55998 .34997 L .55795 .35339 L F
.8857 .624 m .86894 .63381 L .86728 .64044 L 0 0 0 r
F
.8857 .624 m .88747 .61719 L .86894 .63381 L F
.56469 .60337 m .55187 .60516 L .55097 .60699 L .359 .007 0 r
F
.56469 .60337 m .56575 .6015 L .55187 .60516 L F
.58041 .36656 m .5755 .36928 L .57735 .37159 L .207 .109 0 r
F
.58041 .36656 m .5785 .36433 L .5755 .36928 L F
.34921 .41486 m .34461 .40618 L .34307 .40844 L 1 1 0 r
F
.34778 .41719 m .34921 .41486 L .34307 .40844 L F
.91011 .47148 m .897 .48478 L .89763 .49177 L 0 0 0 r
F
.91011 .47148 m .90944 .46439 L .897 .48478 L F
.71522 .19505 m .71959 .18036 L .71303 .2063 L .746 .184 0 r
F
.49918 .62976 m .48434 .62947 L .48412 .63085 L .631 .035 0 r
F
.49918 .62976 m .49964 .62837 L .48434 .62947 L F
.56417 .35419 m .55993 .35572 L .56192 .358 L .172 .111 0 r
F
.56417 .35419 m .56207 .35211 L .55993 .35572 L F
.55273 .64378 m .53913 .64678 L .538 .64828 L .225 0 0 r
F
.55273 .64378 m .55412 .64226 L .53913 .64678 L F
.42993 .345 m .43026 .34364 L .42776 .3446 L .497 .465 0 r
F
.42993 .345 m .43238 .34414 L .43026 .34364 L F
.3393 .5614 m .32497 .55332 L .32568 .55589 L 1 .552 0 r
F
.33997 .56388 m .3393 .5614 L .32568 .55589 L 1 .532 0 r
F
.46841 .66827 m .46838 .66694 L .45106 .66834 L .584 .02 0 r
F
.48508 .66613 m .46838 .66694 L .46841 .66827 L .472 .003 0 r
F
.48508 .66613 m .48538 .66487 L .46838 .66694 L F
.30492 .54387 m .29412 .53263 L .29421 .53576 L 1 .729 0 r
F
.30507 .54698 m .30492 .54387 L .29421 .53576 L 1 .71 0 r
F
.51446 .62673 m .5001 .62695 L .49964 .62837 L .554 .027 0 r
F
.51446 .62673 m .51514 .62529 L .5001 .62695 L F
.66476 .70584 m .65091 .71208 L .64853 .71538 L 0 0 0 r
F
.66476 .70584 m .66751 .70261 L .65091 .71208 L F
.5823 .36878 m .57735 .37159 L .57919 .37389 L .205 .107 0 r
F
.5823 .36878 m .58041 .36656 L .57735 .37159 L F
.40472 .35326 m .40405 .34816 L .4017 .34977 L 1 1 0 r
F
.40472 .35326 m .40701 .35163 L .40405 .34816 L F
.59262 .61682 m .58093 .62098 L .57954 .62294 L .09 0 0 r
F
.59262 .61682 m .59416 .61479 L .58093 .62098 L F
.41381 .66368 m .3953 .66047 L .3964 .66251 L .932 .072 0 r
F
.4147 .66552 m .41381 .66368 L .3964 .66251 L .916 .069 0 r
F
.34778 .41719 m .34307 .40844 L .34158 .41072 L 1 1 0 r
F
.34639 .41954 m .34778 .41719 L .34158 .41072 L F
.52683 .34441 m .52215 .34493 L .52431 .34694 L .373 .45 0 r
F
.52912 .34616 m .52683 .34441 L .52431 .34694 L .39 .486 0 r
F
.83151 .72886 m .81298 .73574 L .80991 .74152 L 0 0 0 r
F
.83151 .72886 m .83482 .72288 L .81298 .73574 L F
.63278 .73354 m .6187 .74096 L .61633 .74395 L F
.63278 .73354 m .63558 .73073 L .6187 .74096 L F
.62398 .46583 m .61574 .47019 L .61625 .47283 L .164 .037 0 r
F
.62398 .46583 m .62345 .4632 L .61574 .47019 L F
.3714 .64449 m .35377 .63811 L .35499 .64067 L 1 .247 0 r
F
.37252 .64687 m .3714 .64449 L .35499 .64067 L 1 .227 0 r
F
.56628 .35625 m .56192 .358 L .56392 .36023 L .19 .136 0 r
F
.56628 .35625 m .56417 .35419 L .56192 .358 L F
.60283 .56434 m .59147 .56743 L .59075 .56973 L .244 .004 0 r
F
.60283 .56434 m .60364 .562 L .59147 .56743 L F
.46581 .91093 m .46573 .90878 L .43799 .90851 L .494 0 0 r
F
.49276 .9104 m .46573 .90878 L .46581 .91093 L .459 0 0 r
F
.49276 .9104 m .49347 .90825 L .46573 .90878 L F
.31275 .45674 m .30432 .44572 L .30354 .44861 L 1 1 0 r
F
.31205 .45963 m .31275 .45674 L .30354 .44861 L F
.76817 .52736 m .75902 .53602 L .75834 .54077 L 0 0 0 r
F
.76817 .52736 m .76876 .52254 L .75902 .53602 L F
.58417 .37099 m .57919 .37389 L .58101 .37619 L .204 .104 0 r
F
.58417 .37099 m .5823 .36878 L .57919 .37389 L F
.6007 .56018 m .58966 .56335 L .58896 .56561 L .235 .002 0 r
F
.6007 .56018 m .60147 .55788 L .58966 .56335 L F
.30307 .46776 m .29692 .45669 L .29594 .45963 L 1 .991 0 r
F
.30218 .47077 m .30307 .46776 L .29594 .45963 L 1 .976 0 r
F
.31965 .52119 m .30749 .51141 L .30768 .51424 L 1 .755 0 r
F
.31987 .52394 m .31965 .52119 L .30768 .51424 L 1 .737 0 r
F
.56838 .35827 m .56392 .36023 L .56591 .36244 L .204 .156 0 r
F
.56838 .35827 m .56628 .35625 L .56392 .36023 L F
.62774 .47092 m .61921 .47538 L .61968 .47807 L .167 .037 0 r
F
.62774 .47092 m .62723 .46824 L .61921 .47538 L F
.62044 .52853 m .61018 .53237 L .60986 .53493 L .19 .011 0 r
F
.62044 .52853 m .62079 .52594 L .61018 .53237 L F
.43329 .32221 m .43721 .32607 L .43695 .32983 L 1 .107 0 r
F
.40701 .35163 m .40646 .34662 L .40405 .34816 L 1 1 0 r
F
.40701 .35163 m .40937 .3501 L .40646 .34662 L F
.10027 .69512 m .07538 .67402 L .07788 .68054 L 1 .26 0 r
F
.10271 .70139 m .10027 .69512 L .07788 .68054 L 1 .229 0 r
F
.45347 .62393 m .43787 .6215 L .43834 .62291 L .862 .063 0 r
F
.45372 .62527 m .45347 .62393 L .43834 .62291 L .846 .06 0 r
F
.46885 .62564 m .45347 .62393 L .45372 .62527 L .789 .053 0 r
F
.34639 .41954 m .34158 .41072 L .34012 .41302 L 1 1 0 r
F
.34504 .42192 m .34639 .41954 L .34012 .41302 L F
.52454 .34257 m .52002 .34277 L .52215 .34493 L .349 .395 0 r
F
.52683 .34441 m .52454 .34257 L .52215 .34493 L .373 .45 0 r
F
.34818 .625 m .33187 .61682 L .33296 .61962 L 1 .376 0 r
F
.34923 .62767 m .34818 .625 L .33296 .61962 L 1 .356 0 r
F
.70056 .66851 m .68693 .67443 L .68475 .67816 L 0 0 0 r
F
.70056 .66851 m .70303 .66476 L .68693 .67443 L F
.32464 .59381 m .3105 .58386 L .31124 .58688 L 1 .527 0 r
F
.3254 .59674 m .32464 .59381 L .31124 .58688 L 1 .508 0 r
F
.8704 .30115 m .86334 .31618 L .86667 .32245 L 0 .028 0 r
F
.8704 .30115 m .86695 .29498 L .86334 .31618 L F
.57047 .36029 m .56591 .36244 L .56789 .36462 L .215 .171 0 r
F
.57047 .36029 m .56838 .35827 L .56591 .36244 L F
.45314 .63001 m .43716 .62801 L .43765 .62949 L .852 .063 0 r
F
.4534 .63143 m .45314 .63001 L .43765 .62949 L .835 .059 0 r
F
.46879 .63141 m .45314 .63001 L .4534 .63143 L .779 .053 0 r
F
.51789 .33588 m .51402 .33412 L .51592 .33757 L .167 .078 0 r
F
.51789 .33588 m .51583 .33279 L .51402 .33412 L F
.58603 .3732 m .58101 .37619 L .58281 .37848 L .202 .1 0 r
F
.58603 .3732 m .58417 .37099 L .58101 .37619 L F
.43251 .34176 m .42908 .32285 L .43017 .33279 L .857 .529 0 r
F
.43242 .3417 m .43017 .33279 L .42678 .32592 L .827 1 0 r
F
.43207 .34307 m .43251 .34176 L .43233 .34181 L .465 .453 0 r
F
.43122 .34283 m .43208 .34204 L .42991 .34246 L F
.43208 .34204 m .43233 .34181 L .43074 .34224 L F
.43208 .34204 m .43074 .34224 L .42991 .34246 L F
.42976 .34237 m .42678 .32592 L .42495 .33025 L .894 .579 0 r
F
.42976 .34237 m .42678 .32592 L .42976 .34237 L F
.43001 .34234 m .42678 .32592 L .42976 .34238 L F
.43207 .34307 m .43233 .34181 L .43122 .34283 L .465 .453 0 r
F
.42991 .34246 m .43251 .34176 L .43242 .3417 L .538 .698 0 r
F
.43189 .34183 m .43242 .3417 L .4323 .34137 L .894 .579 0 r
F
.43 .34231 m .4323 .34137 L .42678 .32592 L F
.42991 .34246 m .43242 .3417 L .43 .34231 L .538 .698 0 r
F
.43026 .34364 m .4323 .34137 L .43 .34231 L .894 .579 0 r
F
.43 .34231 m .43242 .3417 L .43103 .34065 L .538 .698 0 r
F
.43026 .34364 m .43273 .34257 L .43242 .3417 L .894 .579 0 r
F
.43026 .34364 m .43242 .3417 L .43189 .34183 L F
.42976 .34237 m .43103 .34065 L .42846 .34162 L .538 .698 0 r
F
.42991 .34246 m .43 .34231 L .42976 .34237 L F
.43 .34231 m .43103 .34065 L .42976 .34237 L F
.42976 .34238 m .42976 .34237 L .42976 .34237 L .894 .579 0 r
F
.43026 .34364 m .43001 .34234 L .42976 .34238 L F
.43242 .3417 m .43017 .33279 L .43103 .34065 L .857 .529 0 r
F
.43251 .34176 m .43017 .33279 L .43242 .3417 L F
.43251 .34176 m .43511 .34113 L .42908 .32285 L F
.43243 .34172 m .43364 .33982 L .43017 .33279 L .827 1 0 r
F
.43243 .34172 m .43017 .33279 L .43242 .3417 L F
.43207 .34307 m .43456 .34235 L .43251 .34176 L .465 .453 0 r
F
.43456 .34235 m .43511 .34113 L .43251 .34176 L .445 .422 0 r
F
.43273 .34257 m .43327 .34095 L .43243 .34172 L .827 1 0 r
F
.43327 .34095 m .43364 .33982 L .43243 .34172 L F
.51312 .82811 m .49115 .83664 L .49061 .83932 L .222 0 0 r
F
.51312 .82811 m .51423 .82555 L .49115 .83664 L F
.38519 .59557 m .37052 .5896 L .37144 .59158 L 1 .292 0 r
F
.38602 .59747 m .38519 .59557 L .37144 .59158 L 1 .266 0 r
F
.33191 .50241 m .32239 .49304 L .3222 .49566 L 1 .878 0 r
F
.33177 .50502 m .33191 .50241 L .3222 .49566 L 1 .861 0 r
F
.57377 .89117 m .55033 .89216 L .54817 .89448 L .306 0 0 r
F
.57377 .89117 m .57665 .8888 L .55033 .89216 L F
.65634 .51308 m .65115 .51911 L .65033 .52211 L 0 0 0 r
F
.65634 .51308 m .65716 .51008 L .65115 .51911 L F
.57256 .3623 m .56789 .36462 L .56987 .36679 L .224 .181 0 r
F
.57256 .3623 m .57047 .36029 L .56789 .36462 L F
.61159 .2803 m .65373 .22562 L .65633 .23106 L .371 .014 0 r
F
.61159 .2803 m .60166 .28794 L .65373 .22562 L F
.63995 .87986 m .61797 .88168 L .6146 .88474 L .236 0 0 r
F
.63995 .87986 m .64394 .87669 L .61797 .88168 L F
.61442 .59471 m .60411 .59959 L .60278 .60186 L 0 0 0 r
F
.61442 .59471 m .61585 .59237 L .60411 .59959 L F
.36559 .57711 m .35185 .56998 L .35265 .5722 L 1 .437 0 r
F
.36633 .57926 m .36559 .57711 L .35265 .5722 L 1 .413 0 r
F
.40386 .60792 m .38865 .603 L .38958 .60477 L 1 .177 0 r
F
.40464 .60961 m .40386 .60792 L .38958 .60477 L 1 .151 0 r
F
.53515 .81294 m .51532 .82286 L .51423 .82555 L .057 0 0 r
F
.53515 .81294 m .53677 .81046 L .51532 .82286 L F
.34504 .42192 m .34012 .41302 L .3387 .41535 L 1 1 0 r
F
.43304 .66745 m .4147 .66552 L .4156 .66733 L .822 .055 0 r
F
.43369 .66906 m .43304 .66745 L .4156 .66733 L .802 .052 0 r
F
.45106 .66834 m .43304 .66745 L .43369 .66906 L .712 .039 0 r
F
.61755 .52495 m .60771 .52882 L .6074 .53133 L .177 .009 0 r
F
.61755 .52495 m .61789 .52242 L .60771 .52882 L F
.5153 .33457 m .51173 .33179 L .51352 .33584 L .044 .053 0 r
F
.5153 .33457 m .51332 .33103 L .51173 .33179 L F
.57463 .3643 m .56987 .36679 L .57183 .36896 L .231 .188 0 r
F
.57463 .3643 m .57256 .3623 L .56987 .36679 L F
.86926 .30167 m .86174 .31685 L .86491 .32316 L 0 .026 0 r
F
.86926 .30167 m .86598 .29544 L .86174 .31685 L F
.58788 .3754 m .58281 .37848 L .5846 .38078 L .2 .096 0 r
F
.58788 .3754 m .58603 .3732 L .58281 .37848 L F
.38268 .60522 m .36674 .6 L .36778 .60204 L 1 .263 0 r
F
.38359 .60718 m .38268 .60522 L .36778 .60204 L 1 .239 0 r
F
.52005 .33841 m .51592 .33757 L .51793 .34036 L .256 .19 0 r
F
.52005 .33841 m .51789 .33588 L .51592 .33757 L F
.6367 .56168 m .6284 .56732 L .62728 .56995 L 0 0 0 r
F
.6367 .56168 m .63785 .559 L .6284 .56732 L F
.45141 .66978 m .45106 .66834 L .43369 .66906 L .688 .035 0 r
F
.46841 .66827 m .45106 .66834 L .45141 .66978 L .584 .02 0 r
F
.62446 .46846 m .61625 .47283 L .61671 .47547 L .157 .035 0 r
F
.62446 .46846 m .62398 .46583 L .61625 .47283 L F
.51062 .32 m .51221 .29889 L .51165 .31587 L 1 .768 0 r
F
.51062 .32 m .50967 .31029 L .51221 .29889 L F
.57668 .36632 m .57183 .36896 L .57377 .37113 L .236 .191 0 r
F
.57668 .36632 m .57463 .3643 L .57183 .36896 L F
.53448 .65248 m .52018 .655 L .51928 .65634 L .277 0 0 r
F
.53448 .65248 m .53567 .65113 L .52018 .655 L F
.34629 .54902 m .33412 .54068 L .33459 .54314 L 1 .624 0 r
F
.34676 .55143 m .34629 .54902 L .33459 .54314 L 1 .602 0 r
F
.90112 .47167 m .89039 .48471 L .89074 .49159 L 0 0 0 r
F
.90112 .47167 m .90095 .46471 L .89039 .48471 L F
.31205 .45963 m .30354 .44861 L .3028 .45151 L 1 1 0 r
F
.3114 .46252 m .31205 .45963 L .3028 .45151 L 1 .993 0 r
F
.5897 .37761 m .5846 .38078 L .58636 .38308 L .198 .092 0 r
F
.5897 .37761 m .58788 .3754 L .5846 .38078 L F
.30218 .47077 m .29594 .45963 L .29501 .46259 L 1 .976 0 r
F
.30133 .47378 m .30218 .47077 L .29501 .46259 L 1 .961 0 r
F
.57871 .36834 m .57377 .37113 L .57569 .3733 L .239 .191 0 r
F
.57871 .36834 m .57668 .36632 L .57377 .37113 L F
.34372 .42431 m .3387 .41535 L .33732 .41769 L 1 1 0 r
F
.62819 .4736 m .61968 .47807 L .62011 .48076 L .16 .034 0 r
F
.62819 .4736 m .62774 .47092 L .61968 .47807 L F
.73799 .61358 m .72534 .62038 L .72366 .62462 L 0 0 0 r
F
.73799 .61358 m .73981 .60925 L .72534 .62038 L F
.43716 .62801 m .42108 .62539 L .42178 .62694 L .914 .071 0 r
F
.43765 .62949 m .43716 .62801 L .42178 .62694 L .898 .067 0 r
F
.51934 .9091 m .49347 .90825 L .49276 .9104 L .416 0 0 r
F
.51934 .9091 m .52083 .90693 L .49347 .90825 L F
.43238 .34414 m .43273 .34257 L .43026 .34364 L .542 .632 0 r
F
.43238 .34414 m .43481 .34328 L .43273 .34257 L F
.69554 .38214 m .69288 .3882 L .69133 .3933 L 0 0 0 r
F
.69554 .38214 m .69702 .37697 L .69288 .3882 L F
.57967 .77683 m .56376 .787 L .56183 .7897 L F
.57967 .77683 m .5821 .77443 L .56376 .787 L F
.11765 .67781 m .09262 .65824 L .09495 .66446 L 1 .312 0 r
F
.11992 .68376 m .11765 .67781 L .09495 .66446 L 1 .284 0 r
F
.58115 .58484 m .56934 .58731 L .56846 .5893 L .292 0 0 r
F
.58115 .58484 m .58215 .58281 L .56934 .58731 L F
.54535 .61081 m .53228 .61207 L .53147 .61365 L .403 .01 0 r
F
.54535 .61081 m .54634 .6092 L .53228 .61207 L F
.58071 .37037 m .57569 .3733 L .57759 .37547 L .241 .189 0 r
F
.58071 .37037 m .57871 .36834 L .57569 .3733 L F
.76454 .4163 m .76565 .42411 L .7664 .4291 L 0 0 0 r
F
.77337 .79562 m .75393 .80049 L .75017 .80538 L .039 0 0 r
F
.77337 .79562 m .77749 .79055 L .75393 .80049 L F
.54938 .32312 m .54753 .31956 L .54912 .31804 L .943 .111 0 r
F
.43787 .6215 m .42233 .61836 L .42301 .61983 L .925 .071 0 r
F
.43834 .62291 m .43787 .6215 L .42301 .61983 L .909 .068 0 r
F
.59151 .37983 m .58636 .38308 L .58811 .38539 L .196 .088 0 r
F
.59151 .37983 m .5897 .37761 L .58636 .38308 L F
.30507 .54698 m .29421 .53576 L .29435 .5389 L 1 .71 0 r
F
.30528 .55009 m .30507 .54698 L .29435 .5389 L 1 .69 0 r
F
.50118 .66338 m .48538 .66487 L .48508 .66613 L .397 0 0 r
F
.50118 .66338 m .5018 .66217 L .48538 .66487 L F
.87511 .62034 m .86077 .63066 L .85902 .63711 L 0 0 0 r
F
.87511 .62034 m .87696 .61374 L .86077 .63066 L F
.58265 .58931 m .5706 .5917 L .56969 .59372 L .297 .001 0 r
F
.58265 .58931 m .58368 .58725 L .5706 .5917 L F
.51743 .33732 m .51352 .33584 L .51549 .33894 L .181 .087 0 r
F
.51743 .33732 m .5153 .33457 L .51352 .33584 L F
.42039 .62379 m .40425 .62046 L .40513 .62213 L .98 .081 0 r
F
.42108 .62539 m .42039 .62379 L .40513 .62213 L .965 .077 0 r
F
.5827 .37242 m .57759 .37547 L .57947 .37766 L .242 .184 0 r
F
.5827 .37242 m .58071 .37037 L .57759 .37547 L F
.34245 .42672 m .33732 .41769 L .33597 .42005 L 1 1 0 r
F
.51964 .33962 m .51549 .33894 L .51756 .3415 L .265 .233 0 r
F
.52189 .34166 m .51964 .33962 L .51756 .3415 L .318 .344 0 r
F
.33177 .50502 m .3222 .49566 L .32205 .49828 L 1 .861 0 r
F
.33167 .50762 m .33177 .50502 L .32205 .49828 L 1 .844 0 r
F
.31987 .52394 m .30768 .51424 L .30791 .51705 L 1 .737 0 r
F
.32013 .52669 m .31987 .52394 L .30791 .51705 L 1 .719 0 r
F
.56255 .60055 m .55008 .6024 L .54918 .60415 L .349 .004 0 r
F
.56255 .60055 m .5636 .59875 L .55008 .6024 L F
.40901 .90509 m .37931 .90063 L .38165 .90315 L .604 .013 0 r
F
.41063 .90743 m .40901 .90509 L .38165 .90315 L .571 .007 0 r
F
.43799 .90851 m .40901 .90509 L .41063 .90743 L .548 .005 0 r
F
.46591 .90358 m .46583 .90151 L .43855 .90143 L .484 0 0 r
F
.49238 .90279 m .46583 .90151 L .46591 .90358 L .445 0 0 r
F
.49238 .90279 m .49308 .90074 L .46583 .90151 L F
.33997 .56388 m .32568 .55589 L .32643 .55844 L 1 .532 0 r
F
.34067 .56634 m .33997 .56388 L .32643 .55844 L 1 .511 0 r
F
.36198 .58937 m .34661 .58292 L .3476 .58519 L 1 .376 0 r
F
.36287 .59155 m .36198 .58937 L .3476 .58519 L 1 .353 0 r
F
.46887 .62693 m .46885 .62564 L .45372 .62527 L .772 .05 0 r
F
.48377 .62668 m .46885 .62564 L .46887 .62693 L .703 .042 0 r
F
.48377 .62668 m .48399 .62539 L .46885 .62564 L F
.51964 .33962 m .51743 .33732 L .51549 .33894 L .265 .233 0 r
F
.51743 .65888 m .50242 .66091 L .5018 .66217 L .332 0 0 r
F
.51743 .65888 m .51836 .65764 L .50242 .66091 L F
.62004 .5311 m .60986 .53493 L .60949 .53747 L .183 .008 0 r
F
.62004 .5311 m .62044 .52853 L .60986 .53493 L F
.5933 .38205 m .58811 .38539 L .58983 .3877 L .194 .087 0 r
F
.5933 .38205 m .59151 .37983 L .58811 .38539 L F
.52893 .61815 m .51537 .61885 L .51472 .62029 L .468 .017 0 r
F
.52893 .61815 m .5298 .61669 L .51537 .61885 L F
.58465 .37449 m .57947 .37766 L .58132 .37985 L .241 .178 0 r
F
.58465 .37449 m .5827 .37242 L .57947 .37766 L F
.6249 .47109 m .61671 .47547 L .61713 .47811 L .15 .032 0 r
F
.6249 .47109 m .62446 .46846 L .61671 .47547 L F
.60199 .56666 m .59075 .56973 L .58999 .57201 L .237 0 0 r
F
.60199 .56666 m .60283 .56434 L .59075 .56973 L F
.5461 .61558 m .5329 .61683 L .53208 .61845 L .403 .01 0 r
F
.5461 .61558 m .54712 .61394 L .5329 .61683 L F
.82282 .72287 m .80584 .7304 L .80275 .73601 L 0 0 0 r
F
.82282 .72287 m .82612 .71708 L .80584 .7304 L F
.59989 .56246 m .58896 .56561 L .58823 .56785 L .228 0 0 r
F
.59989 .56246 m .6007 .56018 L .58896 .56561 L F
.40255 .61701 m .38647 .61284 L .38748 .61467 L 1 .154 0 r
F
.40339 .61875 m .40255 .61701 L .38748 .61467 L 1 .13 0 r
F
.58658 .37658 m .58132 .37985 L .58315 .38206 L .24 .17 0 r
F
.58658 .37658 m .58465 .37449 L .58132 .37985 L F
.5636 .6052 m .55097 .60699 L .55004 .60878 L .351 .004 0 r
F
.5636 .6052 m .56469 .60337 L .55097 .60699 L F
.30133 .47378 m .29501 .46259 L .29413 .46557 L 1 .961 0 r
F
.30053 .47681 m .30133 .47378 L .29413 .46557 L 1 .946 0 r
F
.3114 .46252 m .3028 .45151 L .30212 .45441 L 1 .993 0 r
F
.3108 .46541 m .3114 .46252 L .30212 .45441 L 1 .979 0 r
F
.34121 .42914 m .33597 .42005 L .33467 .42243 L 1 1 0 r
F
.46881 .63276 m .46879 .63141 L .4534 .63143 L .761 .05 0 r
F
.4839 .6322 m .46879 .63141 L .46881 .63276 L .693 .041 0 r
F
.4839 .6322 m .48412 .63085 L .46879 .63141 L F
.59506 .38427 m .58983 .3877 L .59152 .39003 L .192 .086 0 r
F
.59506 .38427 m .5933 .38205 L .58983 .3877 L F
.62861 .47628 m .62011 .48076 L .62049 .48344 L .153 .031 0 r
F
.62861 .47628 m .62819 .4736 L .62011 .48076 L F
.61718 .52748 m .6074 .53133 L .60706 .53383 L .17 .006 0 r
F
.61718 .52748 m .61755 .52495 L .6074 .53133 L F
.42166 .61685 m .40627 .6129 L .40712 .61449 L .993 .081 0 r
F
.42233 .61836 m .42166 .61685 L .40712 .61449 L .977 .078 0 r
F
.78458 .17755 m .78267 .19141 L .78795 .19612 L .059 .085 0 r
F
.78458 .17755 m .77925 .17314 L .78267 .19141 L F
.51337 .62303 m .49936 .62318 L .49891 .62452 L .544 .024 0 r
F
.51337 .62303 m .51405 .62168 L .49936 .62318 L F
.58847 .37868 m .58315 .38206 L .58495 .38428 L .238 .161 0 r
F
.58847 .37868 m .58658 .37658 L .58315 .38206 L F
.21722 .82685 m .18753 .81353 L .19166 .81832 L .934 .074 0 r
F
.22101 .83137 m .21722 .82685 L .19166 .81832 L .907 .07 0 r
F
.5707 .63387 m .55816 .6374 L .55684 .63906 L .151 0 0 r
F
.5707 .63387 m .57224 .63215 L .55816 .6374 L F
.49845 .62581 m .48399 .62539 L .48377 .62668 L .622 .032 0 r
F
.49845 .62581 m .49891 .62452 L .48399 .62539 L F
.78089 .18112 m .78224 .19181 L .78741 .1966 L .025 .103 0 r
F
.78089 .18112 m .77478 .17761 L .78224 .19181 L F
.10857 .69032 m .08478 .66943 L .08713 .67584 L 1 .265 0 r
F
.11088 .6965 m .10857 .69032 L .08713 .67584 L 1 .235 0 r
F
.52948 .62307 m .51581 .62381 L .51514 .62529 L .463 .016 0 r
F
.52948 .62307 m .53036 .62157 L .51581 .62381 L F
.65551 .51606 m .65033 .52211 L .64951 .52509 L 0 0 0 r
F
.65551 .51606 m .65634 .51308 L .65033 .52211 L F
.63634 .8713 m .61506 .8737 L .61172 .87659 L .2 0 0 r
F
.63634 .8713 m .64029 .8683 L .61506 .8737 L F
.16135 .77773 m .13327 .76106 L .13693 .76667 L 1 .099 0 r
F
.1648 .78308 m .16135 .77773 L .13693 .76667 L 1 .095 0 r
F
.5968 .38651 m .59152 .39003 L .59319 .39236 L .189 .085 0 r
F
.5968 .38651 m .59506 .38427 L .59152 .39003 L F
.53781 .31345 m .53701 .30655 L .54503 .28988 L 1 .734 0 r
F
.3254 .59674 m .31124 .58688 L .31203 .58989 L 1 .508 0 r
F
.3262 .59965 m .3254 .59674 L .31203 .58989 L 1 .488 0 r
F
.59034 .38081 m .58495 .38428 L .58672 .38652 L .236 .15 0 r
F
.59034 .38081 m .58847 .37868 L .58495 .38428 L F
.36633 .57926 m .35265 .5722 L .35349 .5744 L 1 .413 0 r
F
.36711 .58138 m .36633 .57926 L .35349 .5744 L 1 .388 0 r
F
.34676 .55143 m .33459 .54314 L .33511 .54558 L 1 .602 0 r
F
.34727 .55382 m .34676 .55143 L .33511 .54558 L 1 .58 0 r
F
.43481 .34328 m .43525 .34166 L .43273 .34257 L .546 .691 0 r
F
.43481 .34328 m .43725 .34247 L .43525 .34166 L F
.7675 .53217 m .75834 .54077 L .75759 .5455 L 0 0 0 r
F
.7675 .53217 m .76817 .52736 L .75834 .54077 L F
.72129 .83721 m .70114 .84074 L .6972 .84485 L .112 0 0 r
F
.72129 .83721 m .72568 .83293 L .70114 .84074 L F
.23007 .80033 m .20034 .78947 L .20411 .79409 L 1 .085 0 r
F
.23348 .8047 m .23007 .80033 L .20411 .79409 L .994 .081 0 r
F
.91065 .47858 m .89763 .49177 L .89814 .49878 L 0 0 0 r
F
.91065 .47858 m .91011 .47148 L .89763 .49177 L F
.39423 .65839 m .37606 .65386 L .3773 .65613 L 1 .111 0 r
F
.3953 .66047 m .39423 .65839 L .3773 .65613 L 1 .092 0 r
F
.62529 .47373 m .61713 .47811 L .61751 .48075 L .142 .029 0 r
F
.62529 .47373 m .6249 .47109 L .61713 .47811 L F
.33167 .50762 m .32205 .49828 L .32194 .50089 L 1 .844 0 r
F
.33161 .51022 m .33167 .50762 L .32194 .50089 L 1 .827 0 r
F
.59105 .61881 m .57954 .62294 L .57814 .62486 L .076 0 0 r
F
.59105 .61881 m .59262 .61682 L .57954 .62294 L F
.38602 .59747 m .37144 .59158 L .3724 .59354 L 1 .266 0 r
F
.38687 .59935 m .38602 .59747 L .3724 .59354 L 1 .24 0 r
F
.59217 .38296 m .58672 .38652 L .58846 .38878 L .233 .139 0 r
F
.59217 .38296 m .59034 .38081 L .58672 .38652 L F
.51845 .90118 m .49308 .90074 L .49238 .90279 L .397 0 0 r
F
.51845 .90118 m .51992 .89912 L .49308 .90074 L F
.59852 .38876 m .59319 .39236 L .59484 .3947 L .186 .084 0 r
F
.59852 .38876 m .5968 .38651 L .59319 .39236 L F
.60346 .75742 m .589 .76652 L .58676 .76927 L 0 0 0 r
F
.60346 .75742 m .60618 .75494 L .589 .76652 L F
.49871 .63111 m .48412 .63085 L .4839 .6322 L .612 .031 0 r
F
.49871 .63111 m .49918 .62976 L .48412 .63085 L F
.51376 .62812 m .49964 .62837 L .49918 .62976 L .536 .023 0 r
F
.51376 .62812 m .51446 .62673 L .49964 .62837 L F
.34923 .62767 m .33296 .61962 L .33408 .62241 L 1 .356 0 r
F
.35031 .63031 m .34923 .62767 L .33408 .62241 L 1 .336 0 r
F
.30528 .55009 m .29435 .5389 L .29454 .54203 L 1 .69 0 r
F
.30553 .5532 m .30528 .55009 L .29454 .54203 L 1 .671 0 r
F
.63552 .56433 m .62728 .56995 L .62613 .57256 L 0 0 0 r
F
.63552 .56433 m .6367 .56168 L .62728 .56995 L F
.37252 .64687 m .35499 .64067 L .35625 .6432 L 1 .227 0 r
F
.37367 .64923 m .37252 .64687 L .35625 .6432 L 1 .207 0 r
F
.30053 .47681 m .29413 .46557 L .29329 .46855 L 1 .946 0 r
F
.29977 .47985 m .30053 .47681 L .29329 .46855 L 1 .93 0 r
F
.3108 .46541 m .30212 .45441 L .30148 .45731 L 1 .979 0 r
F
.31024 .46831 m .3108 .46541 L .30148 .45731 L 1 .965 0 r
F
.17643 .75518 m .14819 .74051 L .15157 .74588 L 1 .137 0 r
F
.17958 .76027 m .17643 .75518 L .15157 .74588 L 1 .111 0 r
F
.32013 .52669 m .30791 .51705 L .30819 .51985 L 1 .719 0 r
F
.32043 .52942 m .32013 .52669 L .30819 .51985 L 1 .7 0 r
F
.62898 .47897 m .62049 .48344 L .62083 .48613 L .146 .029 0 r
F
.62898 .47897 m .62861 .47628 L .62049 .48344 L F
.87373 .30739 m .86667 .32245 L .86989 .32878 L 0 .024 0 r
F
.87373 .30739 m .8704 .30115 L .86667 .32245 L F
.61296 .59702 m .60278 .60186 L .60142 .60411 L 0 0 0 r
F
.61296 .59702 m .61442 .59471 L .60278 .60186 L F
.41002 .89824 m .38078 .89395 L .38308 .89643 L .599 .013 0 r
F
.41161 .90053 m .41002 .89824 L .38308 .89643 L .567 .007 0 r
F
.43855 .90143 m .41002 .89824 L .41161 .90053 L .538 .003 0 r
F
.59397 .38513 m .58846 .38878 L .59017 .39105 L .229 .127 0 r
F
.59397 .38513 m .59217 .38296 L .58846 .38878 L F
.43886 .91068 m .43799 .90851 L .41063 .90743 L .522 0 0 r
F
.46581 .91093 m .43799 .90851 L .43886 .91068 L .494 0 0 r
F
.6196 .53367 m .60949 .53747 L .60908 .54 L .176 .005 0 r
F
.6196 .53367 m .62004 .5311 L .60949 .53747 L F
.40464 .60961 m .38958 .60477 L .39053 .60652 L 1 .151 0 r
F
.40545 .61127 m .40464 .60961 L .39053 .60652 L 1 .125 0 r
F
.60021 .39102 m .59484 .3947 L .59645 .39706 L .183 .082 0 r
F
.60021 .39102 m .59852 .38876 L .59484 .3947 L F
.38359 .60718 m .36778 .60204 L .36886 .60404 L 1 .239 0 r
F
.38452 .6091 m .38359 .60718 L .36886 .60404 L 1 .215 0 r
F
.41407 .85876 m .38572 .85953 L .38771 .86236 L .674 .034 0 r
F
.41542 .86148 m .41407 .85876 L .38771 .86236 L .649 .029 0 r
F
.44118 .85604 m .41407 .85876 L .41542 .86148 L .573 .022 0 r
F
.55131 .64527 m .538 .64828 L .53684 .64973 L .207 0 0 r
F
.55131 .64527 m .55273 .64378 L .538 .64828 L F
.88381 .63079 m .86728 .64044 L .86549 .64704 L 0 0 0 r
F
.88381 .63079 m .8857 .624 L .86728 .64044 L F
.76638 .78833 m .74805 .79384 L .74431 .79855 L F
.76638 .78833 m .77046 .78343 L .74805 .79384 L F
.45372 .62527 m .43834 .62291 L .43883 .62427 L .846 .06 0 r
F
.45398 .62657 m .45372 .62527 L .43883 .62427 L .828 .056 0 r
F
.46887 .62693 m .45372 .62527 L .45398 .62657 L .772 .05 0 r
F
.62097 .27405 m .65633 .23106 L .65964 .2354 L .363 .006 0 r
F
.62097 .27405 m .61159 .2803 L .65633 .23106 L F
.76573 .42106 m .7664 .4291 L .7671 .43408 L 0 0 0 r
F
.76573 .42106 m .76454 .4163 L .7664 .4291 L F
.59573 .38732 m .59017 .39105 L .59185 .39333 L .225 .114 0 r
F
.59573 .38732 m .59397 .38513 L .59017 .39105 L F
.58011 .58684 m .56846 .5893 L .56754 .59125 L .284 0 0 r
F
.58011 .58684 m .58115 .58484 L .56846 .5893 L F
.34067 .56634 m .32643 .55844 L .32722 .56096 L 1 .511 0 r
F
.34142 .56878 m .34067 .56634 L .32722 .56096 L 1 .489 0 r
F
.87241 .30796 m .86491 .32316 L .86796 .32952 L 0 .021 0 r
F
.87241 .30796 m .86926 .30167 L .86491 .32316 L F
.4534 .63143 m .43765 .62949 L .43815 .63093 L .835 .059 0 r
F
.45367 .6328 m .4534 .63143 L .43815 .63093 L .818 .056 0 r
F
.46881 .63276 m .4534 .63143 L .45367 .6328 L .761 .05 0 r
F
.61676 .52999 m .60706 .53383 L .60667 .53631 L .163 .003 0 r
F
.61676 .52999 m .61718 .52748 L .60706 .53383 L F
.4147 .66552 m .3964 .66251 L .39753 .66452 L .916 .069 0 r
F
.4156 .66733 m .4147 .66552 L .39753 .66452 L .899 .066 0 r
F
.60187 .3933 m .59645 .39706 L .59804 .39943 L .18 .081 0 r
F
.60187 .3933 m .60021 .39102 L .59645 .39706 L F
.58157 .59135 m .56969 .59372 L .56875 .59572 L .289 0 0 r
F
.58157 .59135 m .58265 .58931 L .56969 .59372 L F
.62564 .47636 m .61751 .48075 L .61784 .48339 L .134 .026 0 r
F
.62564 .47636 m .62529 .47373 L .61751 .48075 L F
.60111 .56896 m .58999 .57201 L .58919 .57426 L .23 0 0 r
F
.60111 .56896 m .60199 .56666 L .58999 .57201 L F
.59904 .56472 m .58823 .56785 L .58746 .57006 L .221 0 0 r
F
.59904 .56472 m .59989 .56246 L .58823 .56785 L F
.59746 .38953 m .59185 .39333 L .59349 .39564 L .22 .101 0 r
F
.59746 .38953 m .59573 .38732 L .59185 .39333 L F
.36287 .59155 m .3476 .58519 L .34862 .58744 L 1 .353 0 r
F
.36379 .59371 m .36287 .59155 L .34862 .58744 L 1 .33 0 r
F
.46844 .66955 m .46841 .66827 L .45141 .66978 L .556 .015 0 r
F
.48478 .66734 m .46841 .66827 L .46844 .66955 L .453 0 0 r
F
.48478 .66734 m .48508 .66613 L .46841 .66827 L F
.22169 .82076 m .19271 .80746 L .19671 .81222 L .94 .076 0 r
F
.22538 .82524 m .22169 .82076 L .19671 .81222 L .914 .071 0 r
F
.69802 .6722 m .68475 .67816 L .68251 .68183 L 0 0 0 r
F
.69802 .6722 m .70056 .66851 L .68475 .67816 L F
.69402 .3872 m .69133 .3933 L .6898 .39826 L F
.69402 .3872 m .69554 .38214 L .69133 .3933 L F
.67633 .86398 m .6555 .86655 L .65171 .87003 L .174 0 0 r
F
.67633 .86398 m .68066 .86035 L .6555 .86655 L F
.33161 .51022 m .32194 .50089 L .32188 .5035 L 1 .827 0 r
F
.33159 .51281 m .33161 .51022 L .32188 .5035 L 1 .808 0 r
F
.66193 .70898 m .64853 .71538 L .64608 .71862 L 0 0 0 r
F
.66193 .70898 m .66476 .70584 L .64853 .71538 L F
.54433 .61238 m .53147 .61365 L .53064 .61519 L .395 .006 0 r
F
.54433 .61238 m .54535 .61081 L .53147 .61365 L F
.29977 .47985 m .29329 .46855 L .2925 .47156 L 1 .93 0 r
F
.29907 .4829 m .29977 .47985 L .2925 .47156 L 1 .913 0 r
F
.6035 .39559 m .59804 .39943 L .5996 .40181 L .176 .079 0 r
F
.6035 .39559 m .60187 .3933 L .59804 .39943 L F
.56146 .60231 m .54918 .60415 L .54826 .60587 L .341 0 0 r
F
.56146 .60231 m .56255 .60055 L .54918 .60415 L F
.4379 .32917 m .44097 .33494 L .43887 .3382 L .943 .074 0 r
F
.4379 .32917 m .44128 .33158 L .44097 .33494 L F
.43721 .32607 m .44059 .33314 L .43695 .32983 L .98 .114 0 r
F
.43721 .32607 m .44073 .32886 L .44059 .33314 L F
.6293 .48165 m .62083 .48613 L .62113 .48882 L .139 .026 0 r
F
.6293 .48165 m .62898 .47897 L .62083 .48613 L F
.73609 .61787 m .72366 .62462 L .72192 .62882 L 0 0 0 r
F
.73609 .61787 m .73799 .61358 L .72366 .62462 L F
.90116 .47863 m .89074 .49159 L .89097 .49847 L F
.90116 .47863 m .90112 .47167 L .89074 .49159 L F
.31024 .46831 m .30148 .45731 L .3009 .46022 L 1 .965 0 r
F
.30973 .4712 m .31024 .46831 L .3009 .46022 L 1 .95 0 r
F
.16734 .772 m .1401 .75539 L .14363 .76094 L 1 .101 0 r
F
.17067 .77728 m .16734 .772 L .14363 .76094 L 1 .097 0 r
F
.59915 .39176 m .59349 .39564 L .59511 .39796 L .215 .088 0 r
F
.59915 .39176 m .59746 .38953 L .59349 .39564 L F
.31838 .84563 m .28828 .84035 L .29183 .84389 L .878 .059 0 r
F
.3214 .84899 m .31838 .84563 L .29183 .84389 L .856 .055 0 r
F
.34727 .55382 m .33511 .54558 L .33566 .54801 L 1 .58 0 r
F
.34781 .55619 m .34727 .55382 L .33566 .54801 L 1 .557 0 r
F
.43765 .62949 m .42178 .62694 L .4225 .62845 L .898 .067 0 r
F
.43815 .63093 m .43765 .62949 L .4225 .62845 L .881 .064 0 r
F
.30922 .87891 m .27877 .87031 L .28275 .87382 L .769 .041 0 r
F
.31267 .88217 m .30922 .87891 L .28275 .87382 L .737 .035 0 r
F
.65467 .51901 m .64951 .52509 L .64866 .52804 L 0 0 0 r
F
.65467 .51901 m .65551 .51606 L .64951 .52509 L F
.43834 .62291 m .42301 .61983 L .4237 .62127 L .909 .068 0 r
F
.43883 .62427 m .43834 .62291 L .4237 .62127 L .891 .064 0 r
F
.26726 .85919 m .23701 .84856 L .24122 .85262 L .84 .054 0 r
F
.27102 .86299 m .26726 .85919 L .24122 .85262 L .81 .05 0 r
F
.42108 .62539 m .40513 .62213 L .40603 .62376 L .965 .077 0 r
F
.42178 .62694 m .42108 .62539 L .40603 .62376 L .949 .074 0 r
F
.27803 .82923 m .24792 .82147 L .25172 .82547 L .94 .069 0 r
F
.28138 .83302 m .27803 .82923 L .25172 .82547 L .919 .066 0 r
F
.10271 .70139 m .07788 .68054 L .08051 .68702 L 1 .229 0 r
F
.10526 .70762 m .10271 .70139 L .08051 .68702 L 1 .199 0 r
F
.82807 .73478 m .80991 .74152 L .80673 .74725 L 0 0 0 r
F
.82807 .73478 m .83151 .72886 L .80991 .74152 L F
.71565 .82916 m .6964 .83331 L .69249 .83725 L .071 0 0 r
F
.71565 .82916 m .72 .82506 L .6964 .83331 L F
.60511 .3979 m .5996 .40181 L .60112 .40421 L .173 .077 0 r
F
.60511 .3979 m .6035 .39559 L .5996 .40181 L F
.56248 .60699 m .55004 .60878 L .54909 .61053 L .343 0 0 r
F
.56248 .60699 m .5636 .6052 L .55004 .60878 L F
.32043 .52942 m .30819 .51985 L .30851 .52263 L 1 .7 0 r
F
.32077 .53214 m .32043 .52942 L .30851 .52263 L 1 .681 0 r
F
.43369 .66906 m .4156 .66733 L .41652 .6691 L .802 .052 0 r
F
.43434 .67063 m .43369 .66906 L .41652 .6691 L .78 .048 0 r
F
.45141 .66978 m .43369 .66906 L .43434 .67063 L .688 .035 0 r
F
.36711 .58138 m .35349 .5744 L .35436 .57657 L 1 .388 0 r
F
.36791 .58348 m .36711 .58138 L .35436 .57657 L 1 .362 0 r
F
.60081 .39401 m .59511 .39796 L .59668 .4003 L .21 .084 0 r
F
.60081 .39401 m .59915 .39176 L .59511 .39796 L F
.30553 .5532 m .29454 .54203 L .29477 .54516 L 1 .671 0 r
F
.30582 .5563 m .30553 .5532 L .29477 .54516 L 1 .651 0 r
F
.52805 .61957 m .51472 .62029 L .51405 .62168 L .451 .013 0 r
F
.52805 .61957 m .52893 .61815 L .51472 .62029 L F
.3262 .59965 m .31203 .58989 L .31286 .59289 L 1 .488 0 r
F
.32705 .60255 m .3262 .59965 L .31286 .59289 L 1 .468 0 r
F
.54506 .61719 m .53208 .61845 L .53123 .62003 L .394 .006 0 r
F
.54506 .61719 m .5461 .61558 L .53208 .61845 L F
.33528 .44139 m .32983 .43211 L .32869 .43456 L .173 .191 0 r
F
.53327 .65379 m .51928 .65634 L .51836 .65764 L .257 0 0 r
F
.53327 .65379 m .53448 .65248 L .51928 .65634 L F
.4394 .90354 m .43855 .90143 L .41161 .90053 L .516 0 0 r
F
.46591 .90358 m .43855 .90143 L .4394 .90354 L .484 0 0 r
F
.61912 .53621 m .60908 .54 L .60864 .54252 L .169 .002 0 r
F
.61912 .53621 m .6196 .53367 L .60908 .54 L F
.6299 .73624 m .61633 .74395 L .6139 .74685 L 0 0 0 r
F
.6299 .73624 m .63278 .73354 L .61633 .74395 L F
.40339 .61875 m .38748 .61467 L .38851 .61645 L 1 .13 0 r
F
.40425 .62046 m .40339 .61875 L .38851 .61645 L 1 .105 0 r
F
.62595 .479 m .61784 .48339 L .61814 .48603 L .127 .023 0 r
F
.62595 .479 m .62564 .47636 L .61784 .48339 L F
.46889 .62818 m .46887 .62693 L .45398 .62657 L .754 .046 0 r
F
.48355 .62792 m .46887 .62693 L .46889 .62818 L .685 .038 0 r
F
.48355 .62792 m .48377 .62668 L .46887 .62693 L F
.60415 .89324 m .58163 .8944 L .57877 .89703 L .278 0 0 r
F
.60415 .89324 m .60769 .89052 L .58163 .8944 L F
.4665 .85127 m .46644 .84866 L .44118 .85604 L .438 .003 0 r
F
.49005 .84188 m .46644 .84866 L .4665 .85127 L .338 0 0 r
F
.49005 .84188 m .49061 .83932 L .46644 .84866 L F
.54414 .32673 m .54329 .32269 L .54467 .32735 L .805 .095 0 r
F
.54414 .32673 m .54234 .32317 L .54329 .32269 L F
.45177 .67117 m .45141 .66978 L .43434 .67063 L .662 .03 0 r
F
.46844 .66955 m .45141 .66978 L .45177 .67117 L .556 .015 0 r
F
.37931 .90063 m .34939 .89508 L .3524 .8978 L .645 .019 0 r
F
.38165 .90315 m .37931 .90063 L .3524 .8978 L .612 .014 0 r
F
.60668 .40023 m .60112 .40421 L .60262 .40661 L .168 .075 0 r
F
.60668 .40023 m .60511 .3979 L .60112 .40421 L F
.42233 .61836 m .40712 .61449 L .40798 .61604 L .977 .078 0 r
F
.42301 .61983 m .42233 .61836 L .40798 .61604 L .96 .074 0 r
F
.60242 .39629 m .59668 .4003 L .59822 .40265 L .204 .082 0 r
F
.60242 .39629 m .60081 .39401 L .59668 .4003 L F
.61631 .53248 m .60667 .53631 L .60625 .53878 L .155 0 0 r
F
.61631 .53248 m .61676 .52999 L .60667 .53631 L F
.55572 .79706 m .53834 .80785 L .53677 .81046 L 0 0 0 r
F
.55572 .79706 m .55781 .79473 L .53834 .80785 L F
.76676 .53697 m .75759 .5455 L .75678 .55022 L F
.76676 .53697 m .7675 .53217 L .75759 .5455 L F
.53762 .28755 m .54306 .2679 L .5384 .29283 L .875 .196 0 r
F
.53762 .28755 m .54577 .25116 L .54306 .2679 L F
.29907 .4829 m .2925 .47156 L .29176 .47457 L 1 .913 0 r
F
.2984 .48596 m .29907 .4829 L .29176 .47457 L 1 .896 0 r
F
.55342 .32908 m .55181 .32747 L .55347 .33118 L 0 0 0 r
F
.5499 .33741 m .54803 .33466 L .54989 .3377 L 0 .006 0 r
F
.54993 .33553 m .54951 .33534 L .5499 .33741 L F
.54951 .33534 m .54803 .33466 L .5499 .33741 L F
.55342 .32908 m .54934 .33472 L .55181 .32747 L 0 0 0 r
F
.54951 .33534 m .54934 .33472 L .54803 .33466 L 0 .006 0 r
F
.54993 .33553 m .54934 .33472 L .54951 .33534 L F
.54934 .33472 m .54801 .33407 L .54806 .33399 L 0 0 0 r
F
.54934 .33472 m .54806 .33399 L .55181 .32747 L F
.54895 .33233 m .54876 .33266 L .54938 .33465 L 1 .825 0 r
F
.54876 .33266 m .54871 .33276 L .54934 .33472 L F
.54871 .33276 m .54796 .33283 L .54934 .33472 L 0 .004 0 r
F
.54934 .33472 m .54801 .33407 L .54803 .33466 L 0 .006 0 r
F
.54934 .33472 m .54106 .34614 L .54801 .33407 L 0 0 0 r
F
.54934 .33472 m .54796 .33283 L .54801 .33407 L 0 .006 0 r
F
.54871 .33276 m .54106 .34614 L .54934 .33472 L 1 .825 0 r
F
.54876 .33266 m .54934 .33472 L .54938 .33465 L F
.549 .33273 m .54871 .33276 L .54934 .33472 L 0 .004 0 r
F
.54973 .33494 m .54934 .33472 L .54993 .33553 L F
.54895 .33233 m .54938 .33465 L .55342 .32908 L 1 .825 0 r
F
.549 .33273 m .54934 .33472 L .54973 .33494 L 0 .004 0 r
F
.5521 .32682 m .54895 .33233 L .55342 .32908 L 1 .825 0 r
F
.33159 .51281 m .32188 .5035 L .32186 .50611 L 1 .808 0 r
F
.33162 .51539 m .33159 .51281 L .32186 .50611 L 1 .79 0 r
F
.78982 .18207 m .78795 .19612 L .79314 .20092 L .043 .081 0 r
F
.78982 .18207 m .78458 .17755 L .78795 .19612 L F
.38687 .59935 m .3724 .59354 L .37339 .59546 L 1 .24 0 r
F
.38775 .60119 m .38687 .59935 L .37339 .59546 L 1 .213 0 r
F
.63431 .56696 m .62613 .57256 L .62496 .57513 L 0 0 0 r
F
.63431 .56696 m .63552 .56433 L .62613 .57256 L F
.87315 .62691 m .85902 .63711 L .85715 .64352 L F
.87315 .62691 m .87511 .62034 L .85902 .63711 L F
.62958 .48434 m .62113 .48882 L .62139 .4915 L .132 .023 0 r
F
.62958 .48434 m .6293 .48165 L .62113 .48882 L F
.34643 .89225 m .31618 .88533 L .31974 .88839 L .701 .029 0 r
F
.34939 .89508 m .34643 .89225 L .31974 .88839 L .668 .023 0 r
F
.35414 .85537 m .32449 .85227 L .32764 .85546 L .813 .05 0 r
F
.3567 .85841 m .35414 .85537 L .32764 .85546 L .79 .046 0 r
F
.30973 .4712 m .3009 .46022 L .30036 .46314 L 1 .95 0 r
F
.30927 .4741 m .30973 .4712 L .30036 .46314 L 1 .935 0 r
F
.11992 .68376 m .09495 .66446 L .0974 .67063 L 1 .284 0 r
F
.12229 .68966 m .11992 .68376 L .0974 .67063 L 1 .256 0 r
F
.78666 .18503 m .78741 .1966 L .79255 .20143 L .003 .092 0 r
F
.78666 .18503 m .78089 .18112 L .78741 .1966 L F
.69354 .22867 m .70926 .21953 L .70269 .23512 L 1 .871 0 r
F
.69354 .22867 m .71522 .19505 L .70926 .21953 L F
.46884 .63407 m .46881 .63276 L .45367 .6328 L .743 .046 0 r
F
.48367 .6335 m .46881 .63276 L .46884 .63407 L .674 .038 0 r
F
.48367 .6335 m .4839 .6322 L .46881 .63276 L F
.51268 .62435 m .49891 .62452 L .49845 .62581 L .526 .02 0 r
F
.51268 .62435 m .51337 .62303 L .49891 .62452 L F
.33424 .44389 m .32869 .43456 L .3276 .43703 L 1 1 0 r
F
.33324 .44641 m .33424 .44389 L .3276 .43703 L F
.52857 .62453 m .51514 .62529 L .51446 .62673 L .445 .012 0 r
F
.52857 .62453 m .52948 .62307 L .51514 .62529 L F
.34142 .56878 m .32722 .56096 L .32804 .56347 L 1 .489 0 r
F
.34219 .57119 m .34142 .56878 L .32804 .56347 L 1 .468 0 r
F
.38572 .85953 m .3567 .85841 L .35932 .86136 L .745 .041 0 r
F
.38771 .86236 m .38572 .85953 L .35932 .86136 L .721 .037 0 r
F
.49798 .62707 m .48377 .62668 L .48355 .62792 L .603 .028 0 r
F
.49798 .62707 m .49845 .62581 L .48377 .62668 L F
.50055 .66454 m .48508 .66613 L .48478 .66734 L .377 0 0 r
F
.50055 .66454 m .50118 .66338 L .48508 .66613 L F
.604 .39858 m .59822 .40265 L .59973 .40502 L .198 .08 0 r
F
.604 .39858 m .60242 .39629 L .59822 .40265 L F
.60821 .40257 m .60262 .40661 L .60408 .40904 L .164 .073 0 r
F
.60821 .40257 m .60668 .40023 L .60262 .40661 L F
.56913 .63554 m .55684 .63906 L .55549 .64068 L .134 0 0 r
F
.56913 .63554 m .5707 .63387 L .55684 .63906 L F
.76683 .42584 m .7671 .43408 L .76775 .43906 L 0 0 0 r
F
.76683 .42584 m .76573 .42106 L .7671 .43408 L F
.35031 .63031 m .33408 .62241 L .33524 .62519 L 1 .336 0 r
F
.35143 .63293 m .35031 .63031 L .33524 .62519 L 1 .317 0 r
F
.51649 .66007 m .5018 .66217 L .50118 .66338 L .312 0 0 r
F
.51649 .66007 m .51743 .65888 L .5018 .66217 L F
.60019 .57124 m .58919 .57426 L .58836 .57649 L .222 0 0 r
F
.60019 .57124 m .60111 .56896 L .58919 .57426 L F
.61146 .59929 m .60142 .60411 L .60003 .60632 L 0 0 0 r
F
.61146 .59929 m .61296 .59702 L .60142 .60411 L F
.59816 .56695 m .58746 .57006 L .58666 .57225 L .213 0 0 r
F
.59816 .56695 m .59904 .56472 L .58746 .57006 L F
.58945 .62075 m .57814 .62486 L .5767 .62675 L .063 0 0 r
F
.58945 .62075 m .59105 .61881 L .57814 .62486 L F
.57905 .58881 m .56754 .59125 L .5666 .59317 L .276 0 0 r
F
.57905 .58881 m .58011 .58684 L .56754 .59125 L F
.31183 .87251 m .28191 .86396 L .2858 .86745 L .774 .041 0 r
F
.31521 .87575 m .31183 .87251 L .2858 .86745 L .743 .036 0 r
F
.38452 .6091 m .36886 .60404 L .36996 .60602 L 1 .215 0 r
F
.38548 .61099 m .38452 .6091 L .36996 .60602 L 1 .19 0 r
F
.62621 .48163 m .61814 .48603 L .61839 .48866 L .119 .02 0 r
F
.62621 .48163 m .62595 .479 L .61814 .48603 L F
.6718 .8555 m .65174 .85867 L .64799 .86199 L .134 0 0 r
F
.6718 .8555 m .67609 .85205 L .65174 .85867 L F
.91106 .4857 m .89814 .49878 L .89852 .50579 L 0 0 0 r
F
.91106 .4857 m .91065 .47858 L .89814 .49878 L F
.44189 .85866 m .44118 .85604 L .41542 .86148 L .544 .017 0 r
F
.4665 .85127 m .44118 .85604 L .44189 .85866 L .438 .003 0 r
F
.40545 .61127 m .39053 .60652 L .39151 .60823 L 1 .125 0 r
F
.40627 .6129 m .40545 .61127 L .39151 .60823 L 1 .099 0 r
F
.34781 .55619 m .33566 .54801 L .33626 .55042 L 1 .557 0 r
F
.3484 .55854 m .34781 .55619 L .33626 .55042 L 1 .533 0 r
F
.62973 .26919 m .65964 .2354 L .66331 .23918 L .36 0 0 r
F
.62973 .26919 m .62097 .27405 L .65964 .2354 L F
.87695 .3137 m .86989 .32878 L .87299 .33517 L 0 .02 0 r
F
.87695 .3137 m .87373 .30739 L .86989 .32878 L F
.27064 .85291 m .24099 .84231 L .2451 .84635 L .847 .056 0 r
F
.27433 .85669 m .27064 .85291 L .2451 .84635 L .818 .051 0 r
F
.60554 .4009 m .59973 .40502 L .6012 .40741 L .192 .078 0 r
F
.60554 .4009 m .604 .39858 L .59973 .40502 L F
.33324 .44641 m .3276 .43703 L .32655 .43951 L 1 1 0 r
F
.33228 .44894 m .33324 .44641 L .32655 .43951 L F
.58047 .59336 m .56875 .59572 L .56778 .59768 L .281 0 0 r
F
.58047 .59336 m .58157 .59135 L .56875 .59572 L F
.60972 .40493 m .60408 .40904 L .60551 .41148 L .159 .071 0 r
F
.60972 .40493 m .60821 .40257 L .60408 .40904 L F
.51305 .62948 m .49918 .62976 L .49871 .63111 L .517 .019 0 r
F
.51305 .62948 m .51376 .62812 L .49918 .62976 L F
.36379 .59371 m .34862 .58744 L .34968 .58965 L 1 .33 0 r
F
.36474 .59583 m .36379 .59371 L .34968 .58965 L 1 .306 0 r
F
.49823 .63241 m .4839 .6322 L .48367 .6335 L .593 .027 0 r
F
.49823 .63241 m .49871 .63111 L .4839 .6322 L F
.37367 .64923 m .35625 .6432 L .35754 .64572 L 1 .207 0 r
F
.37485 .65156 m .37367 .64923 L .35754 .64572 L 1 .188 0 r
F
.51404 .33068 m .51163 .32597 L .51332 .33103 L 0 0 0 r
F
.51404 .33068 m .51207 .32671 L .51163 .32597 L F
.32077 .53214 m .30851 .52263 L .30888 .52541 L 1 .681 0 r
F
.32115 .53485 m .32077 .53214 L .30888 .52541 L 1 .661 0 r
F
.3953 .66047 m .3773 .65613 L .37857 .65838 L 1 .092 0 r
F
.3964 .66251 m .3953 .66047 L .37857 .65838 L .995 .081 0 r
F
.65381 .52195 m .64866 .52804 L .64779 .53097 L 0 0 0 r
F
.65381 .52195 m .65467 .51901 L .64866 .52804 L F
.2984 .48596 m .29176 .47457 L .29107 .4776 L 1 .896 0 r
F
.29779 .48903 m .2984 .48596 L .29107 .4776 L 1 .879 0 r
F
.6186 .53875 m .60864 .54252 L .60815 .54501 L .161 0 0 r
F
.6186 .53875 m .61912 .53621 L .60864 .54252 L F
.62981 .48703 m .62139 .4915 L .6216 .49418 L .125 .02 0 r
F
.62981 .48703 m .62958 .48434 L .62139 .4915 L F
.30582 .5563 m .29477 .54516 L .29505 .54829 L 1 .651 0 r
F
.30616 .55939 m .30582 .5563 L .29505 .54829 L 1 .631 0 r
F
.87544 .31432 m .86796 .32952 L .87089 .33593 L 0 .016 0 r
F
.87544 .31432 m .87241 .30796 L .86796 .32952 L F
.30927 .4741 m .30036 .46314 L .29987 .46605 L 1 .935 0 r
F
.30885 .47699 m .30927 .4741 L .29987 .46605 L 1 .919 0 r
F
.33162 .51539 m .32186 .50611 L .32188 .50871 L 1 .79 0 r
F
.33168 .51797 m .33162 .51539 L .32188 .50871 L 1 .77 0 r
F
.38078 .89395 m .35132 .88852 L .35427 .89122 L .645 .019 0 r
F
.38308 .89643 m .38078 .89395 L .35427 .89122 L .612 .014 0 r
F
.81941 .72861 m .80275 .73601 L .79957 .74155 L 0 0 0 r
F
.81941 .72861 m .82282 .72287 L .80275 .73601 L F
.51673 .33187 m .51397 .3287 L .51583 .33279 L F
.51673 .33187 m .51465 .32853 L .51397 .3287 L F
.60704 .40324 m .6012 .40741 L .60263 .40982 L .186 .075 0 r
F
.60704 .40324 m .60554 .4009 L .6012 .40741 L F
.5555 .33174 m .55347 .33118 L .55525 .33449 L 0 .017 0 r
F
.5555 .33174 m .55342 .32908 L .55347 .33118 L F
.11088 .6965 m .08713 .67584 L .08961 .68222 L 1 .235 0 r
F
.1133 .70263 m .11088 .6965 L .08961 .68222 L 1 .205 0 r
F
.45398 .62657 m .43883 .62427 L .43933 .62559 L .828 .056 0 r
F
.45425 .62783 m .45398 .62657 L .43933 .62559 L .81 .052 0 r
F
.46889 .62818 m .45398 .62657 L .45425 .62783 L .754 .046 0 r
F
.61119 .4073 m .60551 .41148 L .6069 .41393 L .154 .069 0 r
F
.61119 .4073 m .60972 .40493 L .60551 .41148 L F
.61581 .53497 m .60625 .53878 L .60579 .54123 L .148 0 0 r
F
.61581 .53497 m .61631 .53248 L .60625 .53878 L F
.69246 .39215 m .6898 .39826 L .6883 .40309 L 0 0 0 r
F
.69246 .39215 m .69402 .3872 L .6898 .39826 L F
.60137 .88461 m .57948 .88632 L .57665 .8888 L .243 0 0 r
F
.60137 .88461 m .60487 .88205 L .57948 .88632 L F
.34841 .88572 m .31865 .87889 L .32215 .88192 L .705 .029 0 r
F
.35132 .88852 m .34841 .88572 L .32215 .88192 L .673 .024 0 r
F
.54518 .90704 m .52083 .90693 L .51934 .9091 L .364 0 0 r
F
.54518 .90704 m .54743 .90482 L .52083 .90693 L F
.56035 .60404 m .54826 .60587 L .54731 .60755 L .333 0 0 r
F
.56035 .60404 m .56146 .60231 L .54826 .60587 L F
.33228 .44894 m .32655 .43951 L .32554 .442 L 1 1 0 r
F
.33137 .45148 m .33228 .44894 L .32554 .442 L F
.36791 .58348 m .35436 .57657 L .35526 .57872 L 1 .362 0 r
F
.36875 .58555 m .36791 .58348 L .35526 .57872 L 1 .336 0 r
F
.54602 .32991 m .54467 .32735 L .54628 .33126 L .636 .054 0 r
F
.54602 .32991 m .54414 .32673 L .54467 .32735 L F
.45367 .6328 m .43815 .63093 L .43866 .63233 L .818 .056 0 r
F
.45394 .63413 m .45367 .6328 L .43866 .63233 L .799 .052 0 r
F
.46884 .63407 m .45367 .6328 L .45394 .63413 L .743 .046 0 r
F
.54329 .61392 m .53064 .61519 L .5298 .61669 L .387 .003 0 r
F
.54329 .61392 m .54433 .61238 L .53064 .61519 L F
.76915 .80062 m .75017 .80538 L .74632 .81019 L .028 0 0 r
F
.76915 .80062 m .77337 .79562 L .75017 .80538 L F
.54988 .6467 m .53684 .64973 L .53567 .65113 L .188 0 0 r
F
.54988 .6467 m .55131 .64527 L .53684 .64973 L F
.62643 .48427 m .61839 .48866 L .6186 .4913 L .111 .017 0 r
F
.62643 .48427 m .62621 .48163 L .61839 .48866 L F
.32705 .60255 m .31286 .59289 L .31373 .59588 L 1 .468 0 r
F
.32793 .60544 m .32705 .60255 L .31373 .59588 L 1 .447 0 r
F
.6085 .40559 m .60263 .40982 L .60403 .41224 L .179 .073 0 r
F
.6085 .40559 m .60704 .40324 L .60263 .40982 L F
.43511 .34113 m .43268 .32462 L .42908 .32285 L .935 .162 0 r
F
.88178 .63754 m .86549 .64704 L .86359 .6536 L 0 0 0 r
F
.88178 .63754 m .88381 .63079 L .86549 .64704 L F
.61262 .4097 m .6069 .41393 L .60826 .4164 L .149 .067 0 r
F
.61262 .4097 m .61119 .4073 L .6069 .41393 L F
.73412 .62212 m .72192 .62882 L .7201 .63299 L 0 0 0 r
F
.73412 .62212 m .73609 .61787 L .72192 .62882 L F
.56133 .60875 m .54909 .61053 L .54812 .61225 L .334 0 0 r
F
.56133 .60875 m .56248 .60699 L .54909 .61053 L F
.57719 .77909 m .56183 .7897 L .55985 .79228 L 0 0 0 r
F
.57719 .77909 m .57967 .77683 L .56183 .7897 L F
.44128 .33158 m .44329 .33231 L .44097 .33494 L .262 0 0 r
F
.44073 .32886 m .44326 .33216 L .44059 .33314 L .772 .041 0 r
F
.44073 .32886 m .44394 .33069 L .44326 .33216 L F
.90107 .48558 m .89097 .49847 L .89107 .50535 L 0 0 0 r
F
.90107 .48558 m .90116 .47863 L .89097 .49847 L F
.34219 .57119 m .32804 .56347 L .32891 .56595 L 1 .468 0 r
F
.343 .57359 m .34219 .57119 L .32891 .56595 L 1 .445 0 r
F
.29779 .48903 m .29107 .4776 L .29042 .48064 L 1 .879 0 r
F
.29722 .49211 m .29779 .48903 L .29042 .48064 L 1 .861 0 r
F
.4156 .66733 m .39753 .66452 L .39867 .6665 L .899 .066 0 r
F
.41652 .6691 m .4156 .66733 L .39867 .6665 L .881 .063 0 r
F
.33137 .45148 m .32554 .442 L .32457 .44451 L 1 1 0 r
F
.33049 .45403 m .33137 .45148 L .32457 .44451 L F
.63307 .56957 m .62496 .57513 L .62375 .57768 L 0 0 0 r
F
.63307 .56957 m .63431 .56696 L .62496 .57513 L F
.43815 .63093 m .4225 .62845 L .42323 .62993 L .881 .064 0 r
F
.43866 .63233 m .43815 .63093 L .42323 .62993 L .863 .061 0 r
F
.62999 .48972 m .6216 .49418 L .62177 .49686 L .118 .017 0 r
F
.62999 .48972 m .62981 .48703 L .6216 .49418 L F
.43883 .62427 m .4237 .62127 L .42441 .62266 L .891 .064 0 r
F
.43933 .62559 m .43883 .62427 L .42441 .62266 L .873 .061 0 r
F
.42178 .62694 m .40603 .62376 L .40696 .62535 L .949 .074 0 r
F
.4225 .62845 m .42178 .62694 L .40696 .62535 L .933 .071 0 r
F
.57291 .90195 m .54965 .90249 L .54743 .90482 L .319 0 0 r
F
.57291 .90195 m .57586 .89955 L .54965 .90249 L F
.30885 .47699 m .29987 .46605 L .29943 .46897 L 1 .919 0 r
F
.30848 .47989 m .30885 .47699 L .29943 .46897 L 1 .903 0 r
F
.40425 .62046 m .38851 .61645 L .38957 .61821 L 1 .105 0 r
F
.40513 .62213 m .40425 .62046 L .38957 .61821 L 1 .082 0 r
F
.60992 .40797 m .60403 .41224 L .60539 .41468 L .172 .07 0 r
F
.60992 .40797 m .6085 .40559 L .60403 .41224 L F
.54399 .61877 m .53123 .62003 L .53036 .62157 L .385 .002 0 r
F
.54399 .61877 m .54506 .61719 L .53123 .62003 L F
.1648 .78308 m .13693 .76667 L .1407 .77222 L 1 .095 0 r
F
.16834 .78835 m .1648 .78308 L .1407 .77222 L .982 .091 0 r
F
.69541 .67583 m .68251 .68183 L .68019 .68545 L 0 0 0 r
F
.69541 .67583 m .69802 .6722 L .68251 .68183 L F
.51895 .33449 m .51583 .33279 L .51789 .33588 L 0 .058 0 r
F
.51895 .33449 m .51673 .33187 L .51583 .33279 L F
.38775 .60119 m .37339 .59546 L .37441 .59736 L 1 .213 0 r
F
.38865 .603 m .38775 .60119 L .37441 .59736 L 1 .185 0 r
F
.59724 .56916 m .58666 .57225 L .58583 .57442 L .205 0 0 r
F
.59724 .56916 m .59816 .56695 L .58666 .57225 L F
.3484 .55854 m .33626 .55042 L .3369 .55281 L 1 .533 0 r
F
.34901 .56087 m .3484 .55854 L .3369 .55281 L 1 .509 0 r
F
.5576 .33427 m .55525 .33449 L .55711 .33753 L 0 .041 0 r
F
.5576 .33427 m .5555 .33174 L .55525 .33449 L F
.52716 .62095 m .51405 .62168 L .51337 .62303 L .435 .009 0 r
F
.52716 .62095 m .52805 .61957 L .51405 .62168 L F
.59923 .57349 m .58836 .57649 L .58749 .5787 L .214 0 0 r
F
.59923 .57349 m .60019 .57124 L .58836 .57649 L F
.76593 .54175 m .75678 .55022 L .7559 .55491 L 0 0 0 r
F
.76593 .54175 m .76676 .53697 L .75678 .55022 L F
.33168 .51797 m .32188 .50871 L .32195 .5113 L 1 .77 0 r
F
.33179 .52053 m .33168 .51797 L .32195 .5113 L 1 .75 0 r
F
.61401 .41211 m .60826 .4164 L .60959 .41888 L .144 .065 0 r
F
.61401 .41211 m .61262 .4097 L .60826 .4164 L F
.32115 .53485 m .30888 .52541 L .30929 .52817 L 1 .661 0 r
F
.32158 .53754 m .32115 .53485 L .30929 .52817 L 1 .641 0 r
F
.76786 .43064 m .76775 .43906 L .76834 .44402 L 0 0 0 r
F
.76786 .43064 m .76683 .42584 L .76775 .43906 L F
.51621 .33359 m .51332 .33103 L .5153 .33457 L 0 .023 0 r
F
.51621 .33359 m .51404 .33068 L .51332 .33103 L F
.53349 .81529 m .51423 .82555 L .51312 .82811 L 0 0 0 r
F
.53349 .81529 m .53515 .81294 L .51423 .82555 L F
.61803 .54127 m .60815 .54501 L .60763 .5475 L .154 0 0 r
F
.61803 .54127 m .6186 .53875 L .60815 .54501 L F
.17958 .76027 m .15157 .74588 L .15504 .75118 L 1 .111 0 r
F
.18282 .7653 m .17958 .76027 L .15504 .75118 L 1 .098 0 r
F
.42301 .61983 m .40798 .61604 L .40887 .61756 L .96 .074 0 r
F
.4237 .62127 m .42301 .61983 L .40887 .61756 L .942 .071 0 r
F
.6266 .4869 m .6186 .4913 L .61877 .49393 L .102 .014 0 r
F
.6266 .4869 m .62643 .48427 L .6186 .4913 L F
.57795 .59075 m .5666 .59317 L .56563 .59506 L .268 0 0 r
F
.57795 .59075 m .57905 .58881 L .5666 .59317 L F
.46847 .67079 m .46844 .66955 L .45177 .67117 L .525 .009 0 r
F
.48447 .66849 m .46844 .66955 L .46847 .67079 L .435 0 0 r
F
.48447 .66849 m .48478 .66734 L .46844 .66955 L F
.46892 .62938 m .46889 .62818 L .45425 .62783 L .734 .042 0 r
F
.48332 .62912 m .46889 .62818 L .46892 .62938 L .666 .034 0 r
F
.48332 .62912 m .48355 .62792 L .46889 .62818 L F
.53312 .34504 m .52912 .34616 L .53142 .34785 L .33 .424 0 r
F
.53551 .34652 m .53312 .34504 L .53142 .34785 L .343 .446 0 r
F
.51198 .83055 m .49061 .83932 L .49005 .84188 L .183 0 0 r
F
.51198 .83055 m .51312 .82811 L .49061 .83932 L F
.30616 .55939 m .29505 .54829 L .29538 .55142 L 1 .631 0 r
F
.30655 .56248 m .30616 .55939 L .29538 .55142 L 1 .61 0 r
F
.6113 .41036 m .60539 .41468 L .60671 .41713 L .165 .068 0 r
F
.6113 .41036 m .60992 .40797 L .60539 .41468 L F
.61527 .53743 m .60579 .54123 L .60528 .54366 L .14 0 0 r
F
.61527 .53743 m .61581 .53497 L .60579 .54123 L F
.65294 .52487 m .64779 .53097 L .64691 .53387 L 0 0 0 r
F
.65294 .52487 m .65381 .52195 L .64779 .53097 L F
.33049 .45403 m .32457 .44451 L .32365 .44703 L 1 1 0 r
F
.32965 .45659 m .33049 .45403 L .32365 .44703 L F
.79497 .18669 m .79314 .20092 L .79823 .20582 L .026 .077 0 r
F
.79497 .18669 m .78982 .18207 L .79314 .20092 L F
.52124 .33667 m .51789 .33588 L .52005 .33841 L .089 .09 0 r
F
.52124 .33667 m .51895 .33449 L .51789 .33588 L F
.54796 .33283 m .54602 .32991 L .54628 .33126 L 0 0 0 r
F
.23348 .8047 m .20411 .79409 L .20796 .79865 L .994 .081 0 r
F
.23697 .809 m .23348 .8047 L .20796 .79865 L .973 .078 0 r
F
.63786 .26561 m .66331 .23918 L .66713 .24273 L .364 0 0 r
F
.63786 .26561 m .62973 .26919 L .66331 .23918 L F
.53073 .34353 m .52683 .34441 L .52912 .34616 L .311 .39 0 r
F
.53312 .34504 m .53073 .34353 L .52912 .34616 L .33 .424 0 r
F
.22101 .83137 m .19166 .81832 L .19588 .82303 L .907 .07 0 r
F
.22488 .8358 m .22101 .83137 L .19588 .82303 L .879 .065 0 r
F
.65902 .71204 m .64608 .71862 L .64357 .72177 L 0 0 0 r
F
.65902 .71204 m .66193 .70898 L .64608 .71862 L F
.54375 .89876 m .51992 .89912 L .51845 .90118 L .338 0 0 r
F
.54375 .89876 m .54597 .89668 L .51992 .89912 L F
.60994 .60154 m .60003 .60632 L .59861 .60849 L 0 0 0 r
F
.60994 .60154 m .61146 .59929 L .60003 .60632 L F
.79221 .18919 m .79255 .20143 L .79763 .20632 L 0 .084 0 r
F
.79221 .18919 m .78666 .18503 L .79255 .20143 L F
.61537 .41454 m .60959 .41888 L .61088 .42137 L .138 .063 0 r
F
.61537 .41454 m .61401 .41211 L .60959 .41888 L F
.57933 .59533 m .56778 .59768 L .56678 .59961 L .273 0 0 r
F
.57933 .59533 m .58047 .59336 L .56778 .59768 L F
.6359 .88292 m .6146 .88474 L .61117 .88768 L .221 0 0 r
F
.6359 .88292 m .63995 .87986 L .6146 .88474 L F
.38548 .61099 m .36996 .60602 L .3711 .60796 L 1 .19 0 r
F
.38647 .61284 m .38548 .61099 L .3711 .60796 L 1 .164 0 r
F
.60068 .75977 m .58676 .76927 L .58446 .77191 L 0 0 0 r
F
.57464 .78122 m .55985 .79228 L .55781 .79473 L F
.57203 .7832 m .57464 .78122 L .55971 .7932 L .467 .2 0 r
F
.5604 .79263 m .55971 .7932 L .55781 .79473 L F
.57203 .7832 m .55971 .7932 L .5604 .79263 L F
.56458 .78924 m .55781 .79473 L .55572 .79706 L F
.57464 .78122 m .57719 .77909 L .56555 .78794 L 0 0 0 r
F
.57464 .78122 m .56555 .78794 L .56537 .7881 L F
.57464 .78122 m .56379 .78927 L .56392 .78923 L F
.56935 .78503 m .57203 .7832 L .55572 .79706 L .546 .214 0 r
F
.5673 .78688 m .56501 .78886 L .56516 .78881 L F
.56935 .78503 m .56651 .78754 L .5673 .78688 L F
.56651 .78754 m .56501 .78886 L .5673 .78688 L F
.56516 .78881 m .55572 .79706 L .55357 .79924 L F
.56501 .78886 m .55572 .79706 L .56516 .78881 L F
.55357 .79924 m .53677 .81046 L .53515 .81294 L 0 0 0 r
F
.55357 .79924 m .55572 .79706 L .53677 .81046 L F
.55138 .80129 m .55357 .79924 L .53515 .81294 L F
.56056 .7925 m .55357 .79924 L .55138 .80129 L .619 .225 0 r
F
.56662 .7867 m .5611 .79201 L .56056 .7925 L F
.5611 .79201 m .55357 .79924 L .56056 .7925 L F
.56537 .7881 m .56555 .78794 L .56379 .78927 L 0 0 0 r
F
.56392 .78923 m .56379 .78927 L .55985 .79228 L F
.58072 .77548 m .57719 .77909 L .57464 .78122 L .619 .227 0 r
F
.59345 .76471 m .59477 .76359 L .58676 .76927 L 0 0 0 r
F
.59783 .76199 m .58446 .77191 L .5821 .77443 L F
.59783 .76199 m .60068 .75977 L .58845 .76892 L F
.59783 .76199 m .58845 .76892 L .58841 .76897 L F
.59783 .76199 m .58651 .77038 L .58713 .76993 L F
.59491 .76408 m .59783 .76199 L .5821 .77443 L .481 .204 0 r
F
.59276 .76588 m .5821 .77443 L .57967 .77683 L F
.59206 .76638 m .5821 .77443 L .59276 .76588 L F
.59491 .76408 m .59206 .76638 L .59276 .76588 L F
.59192 .76602 m .59491 .76408 L .57967 .77683 L .553 .217 0 r
F
.58776 .76971 m .57967 .77683 L .57719 .77909 L F
.59192 .76602 m .58784 .76962 L .58776 .76971 L F
.58784 .76962 m .57967 .77683 L .58776 .76971 L F
.58841 .76897 m .58845 .76892 L .58651 .77038 L 0 0 0 r
F
.58713 .76993 m .58651 .77038 L .58446 .77191 L F
.58885 .76781 m .58232 .77412 L .58072 .77548 L .619 .227 0 r
F
.58232 .77412 m .57719 .77909 L .58072 .77548 L F
.60068 .75977 m .60346 .75742 L .59477 .76359 L 0 0 0 r
F
.60068 .75977 m .59477 .76359 L .59345 .76471 L F
.52833 .34198 m .52454 .34257 L .52683 .34441 L .284 .341 0 r
F
.53073 .34353 m .52833 .34198 L .52683 .34441 L .311 .39 0 r
F
.36474 .59583 m .34968 .58965 L .35077 .59184 L 1 .306 0 r
F
.36573 .59793 m .36474 .59583 L .35077 .59184 L 1 .281 0 r
F
.35143 .63293 m .33524 .62519 L .33645 .62795 L 1 .317 0 r
F
.35258 .63553 m .35143 .63293 L .33645 .62795 L 1 .297 0 r
F
.52358 .3386 m .52005 .33841 L .52228 .3406 L .184 .168 0 r
F
.52358 .3386 m .52124 .33667 L .52005 .33841 L F
.51197 .62562 m .49845 .62581 L .49798 .62707 L .507 .016 0 r
F
.51197 .62562 m .51268 .62435 L .49845 .62581 L F
.52765 .62595 m .51446 .62673 L .51376 .62812 L .431 .008 0 r
F
.52765 .62595 m .52857 .62453 L .51446 .62673 L F
.53205 .65504 m .51836 .65764 L .51743 .65888 L .236 0 0 r
F
.53205 .65504 m .53327 .65379 L .51836 .65764 L F
.29722 .49211 m .29042 .48064 L .28982 .48369 L 1 .861 0 r
F
.2967 .4952 m .29722 .49211 L .28982 .48369 L 1 .843 0 r
F
.63013 .4924 m .62177 .49686 L .6219 .49954 L .11 .014 0 r
F
.63013 .4924 m .62999 .48972 L .62177 .49686 L F
.40627 .6129 m .39151 .60823 L .39251 .6099 L 1 .099 0 r
F
.40712 .61449 m .40627 .6129 L .39251 .6099 L 1 .083 0 r
F
.43434 .67063 m .41652 .6691 L .41746 .67083 L .78 .048 0 r
F
.43501 .67216 m .43434 .67063 L .41746 .67083 L .758 .044 0 r
F
.45177 .67117 m .43434 .67063 L .43501 .67216 L .662 .03 0 r
F
.46886 .63534 m .46884 .63407 L .45394 .63413 L .723 .042 0 r
F
.48343 .63476 m .46884 .63407 L .46886 .63534 L .654 .034 0 r
F
.48343 .63476 m .48367 .6335 L .46884 .63407 L F
.51849 .33592 m .5153 .33457 L .51743 .33732 L 0 .073 0 r
F
.51849 .33592 m .51621 .33359 L .5153 .33457 L F
.55969 .33671 m .55711 .33753 L .55901 .34037 L 0 .056 0 r
F
.55969 .33671 m .5576 .33427 L .55711 .33753 L F
.4975 .62828 m .48355 .62792 L .48332 .62912 L .584 .024 0 r
F
.4975 .62828 m .49798 .62707 L .48355 .62792 L F
.58782 .62266 m .5767 .62675 L .57524 .62859 L .048 0 0 r
F
.58782 .62266 m .58945 .62075 L .5767 .62675 L F
.7622 .79315 m .74431 .79855 L .74048 .80318 L 0 0 0 r
F
.7622 .79315 m .76638 .78833 L .74431 .79855 L F
.61264 .41277 m .60671 .41713 L .60799 .41959 L .157 .065 0 r
F
.61264 .41277 m .6113 .41036 L .60671 .41713 L F
.30848 .47989 m .29943 .46897 L .29904 .47189 L 1 .903 0 r
F
.30816 .48278 m .30848 .47989 L .29904 .47189 L 1 .886 0 r
F
.10526 .70762 m .08051 .68702 L .08326 .69345 L 1 .199 0 r
F
.10792 .71379 m .10526 .70762 L .08326 .69345 L 1 .169 0 r
F
.88005 .32006 m .87299 .33517 L .87599 .34161 L 0 .015 0 r
F
.88005 .32006 m .87695 .3137 L .87299 .33517 L F
.36875 .58555 m .35526 .57872 L .3562 .58084 L 1 .336 0 r
F
.36962 .58759 m .36875 .58555 L .3562 .58084 L 1 .309 0 r
F
.56754 .63716 m .55549 .64068 L .55412 .64226 L .117 0 0 r
F
.56754 .63716 m .56913 .63554 L .55549 .64068 L F
.32965 .45659 m .32365 .44703 L .32277 .44957 L 1 1 0 r
F
.32886 .45916 m .32965 .45659 L .32277 .44957 L F
.61669 .41698 m .61088 .42137 L .61213 .42388 L .132 .06 0 r
F
.61669 .41698 m .61537 .41454 L .61088 .42137 L F
.5124 .32522 m .51062 .32 L .51165 .31587 L 1 .477 0 r
F
.7168 .8414 m .6972 .84485 L .69319 .84887 L .1 0 0 r
F
.7168 .8414 m .72129 .83721 L .6972 .84485 L F
.33179 .52053 m .32195 .5113 L .32206 .51389 L 1 .75 0 r
F
.33194 .52309 m .33179 .52053 L .32206 .51389 L 1 .73 0 r
F
.87108 .63344 m .85715 .64352 L .85518 .64989 L 0 0 0 r
F
.87108 .63344 m .87315 .62691 L .85715 .64352 L F
.45213 .67252 m .45177 .67117 L .43501 .67216 L .635 .026 0 r
F
.46847 .67079 m .45177 .67117 L .45213 .67252 L .525 .009 0 r
F
.52082 .3379 m .51743 .33732 L .51964 .33962 L .122 .1 0 r
F
.52082 .3379 m .51849 .33592 L .51743 .33732 L F
.91133 .49283 m .89852 .50579 L .89878 .5128 L 0 0 0 r
F
.91133 .49283 m .91106 .4857 L .89852 .50579 L F
.62673 .48953 m .61877 .49393 L .6189 .49655 L .094 .011 0 r
F
.62673 .48953 m .6266 .4869 L .61877 .49393 L F
.82453 .74064 m .80673 .74725 L .80344 .7529 L 0 0 0 r
F
.82453 .74064 m .82807 .73478 L .80673 .74725 L F
.52319 .33966 m .51964 .33962 L .52189 .34166 L .208 .219 0 r
F
.52558 .3413 m .52319 .33966 L .52189 .34166 L .262 .311 0 r
F
.52319 .33966 m .52082 .3379 L .51964 .33962 L .208 .219 0 r
F
.57086 .89342 m .54817 .89448 L .54597 .89668 L .287 0 0 r
F
.57086 .89342 m .57377 .89117 L .54817 .89448 L F
.32793 .60544 m .31373 .59588 L .31465 .59886 L 1 .447 0 r
F
.32885 .6083 m .32793 .60544 L .31465 .59886 L 1 .427 0 r
F
.69088 .39698 m .6883 .40309 L .68682 .40778 L 0 0 0 r
F
.69088 .39698 m .69246 .39215 L .6883 .40309 L F
.17067 .77728 m .14363 .76094 L .14726 .76643 L 1 .097 0 r
F
.1741 .7825 m .17067 .77728 L .14726 .76643 L .988 .093 0 r
F
.55922 .60573 m .54731 .60755 L .54634 .6092 L .324 0 0 r
F
.55922 .60573 m .56035 .60404 L .54731 .60755 L F
.87834 .32073 m .87089 .33593 L .8737 .34239 L 0 .012 0 r
F
.87834 .32073 m .87544 .31432 L .87089 .33593 L F
.51233 .6308 m .49871 .63111 L .49823 .63241 L .497 .014 0 r
F
.51233 .6308 m .51305 .62948 L .49871 .63111 L F
.61394 .4152 m .60799 .41959 L .60923 .42207 L .149 .062 0 r
F
.61394 .4152 m .61264 .41277 L .60799 .41959 L F
.12229 .68966 m .0974 .67063 L .09995 .67676 L 1 .256 0 r
F
.12477 .69552 m .12229 .68966 L .09995 .67676 L 1 .228 0 r
F
.343 .57359 m .32891 .56595 L .32982 .56841 L 1 .445 0 r
F
.34385 .57596 m .343 .57359 L .32982 .56841 L 1 .422 0 r
F
.37485 .65156 m .35754 .64572 L .35886 .64822 L 1 .188 0 r
F
.37606 .65386 m .37485 .65156 L .35886 .64822 L 1 .168 0 r
F
.32158 .53754 m .30929 .52817 L .30975 .53092 L 1 .641 0 r
F
.32204 .54021 m .32158 .53754 L .30975 .53092 L 1 .62 0 r
F
.34901 .56087 m .3369 .55281 L .33758 .55519 L 1 .509 0 r
F
.34967 .56318 m .34901 .56087 L .33758 .55519 L 1 .484 0 r
F
.46589 .91296 m .46581 .91093 L .43886 .91068 L .477 0 0 r
F
.49204 .91244 m .46581 .91093 L .46589 .91296 L .442 0 0 r
F
.49204 .91244 m .49276 .9104 L .46581 .91093 L F
.49774 .63367 m .48367 .6335 L .48343 .63476 L .572 .023 0 r
F
.49774 .63367 m .49823 .63241 L .48367 .6335 L F
.61741 .54377 m .60763 .5475 L .60706 .54996 L .146 0 0 r
F
.61741 .54377 m .61803 .54127 L .60763 .5475 L F
.56178 .3391 m .55901 .34037 L .56095 .34306 L 0 .065 0 r
F
.56178 .3391 m .55969 .33671 L .55901 .34037 L F
.59628 .57135 m .58583 .57442 L .58496 .57655 L .197 0 0 r
F
.59628 .57135 m .59724 .56916 L .58583 .57442 L F
.43273 .34257 m .43525 .34166 L .43364 .33982 L .827 1 0 r
F
.61797 .41945 m .61213 .42388 L .61334 .42641 L .126 .058 0 r
F
.61797 .41945 m .61669 .41698 L .61213 .42388 L F
.49991 .66565 m .48478 .66734 L .48447 .66849 L .356 0 0 r
F
.49991 .66565 m .50055 .66454 L .48478 .66734 L F
.63179 .57214 m .62375 .57768 L .62251 .5802 L 0 0 0 r
F
.63179 .57214 m .63307 .56957 L .62375 .57768 L F
.62694 .73884 m .6139 .74685 L .61139 .74966 L F
.62694 .73884 m .6299 .73624 L .6139 .74685 L F
.54223 .61542 m .5298 .61669 L .52893 .61815 L .378 0 0 r
F
.54223 .61542 m .54329 .61392 L .5298 .61669 L F
.51554 .66122 m .50118 .66338 L .50055 .66454 L .29 0 0 r
F
.51554 .66122 m .51649 .66007 L .50118 .66338 L F
.59823 .57572 m .58749 .5787 L .58659 .58088 L .206 0 0 r
F
.59823 .57572 m .59923 .57349 L .58749 .5787 L F
.61468 .53988 m .60528 .54366 L .60474 .54608 L .132 0 0 r
F
.61468 .53988 m .61527 .53743 L .60528 .54366 L F
.32886 .45916 m .32277 .44957 L .32193 .45211 L 1 1 0 r
F
.32811 .46174 m .32886 .45916 L .32193 .45211 L F
.45425 .62783 m .43933 .62559 L .43984 .62688 L .81 .052 0 r
F
.45452 .62904 m .45425 .62783 L .43984 .62688 L .79 .049 0 r
F
.46892 .62938 m .45425 .62783 L .45452 .62904 L .734 .042 0 r
F
.2967 .4952 m .28982 .48369 L .28927 .48675 L 1 .843 0 r
F
.29622 .49829 m .2967 .4952 L .28927 .48675 L 1 .824 0 r
F
.63023 .49509 m .6219 .49954 L .62199 .50221 L .102 .011 0 r
F
.63023 .49509 m .63013 .4924 L .6219 .49954 L F
.3964 .66251 m .37857 .65838 L .37986 .66061 L .995 .081 0 r
F
.39753 .66452 m .3964 .66251 L .37986 .66061 L .981 .078 0 r
F
.22538 .82524 m .19671 .81222 L .20082 .81689 L .914 .071 0 r
F
.22916 .82964 m .22538 .82524 L .20082 .81689 L .886 .067 0 r
F
.30655 .56248 m .29538 .55142 L .29576 .55454 L 1 .61 0 r
F
.30698 .56555 m .30655 .56248 L .29576 .55454 L 1 .59 0 r
F
.56016 .61048 m .54812 .61225 L .54712 .61394 L .325 0 0 r
F
.56016 .61048 m .56133 .60875 L .54812 .61225 L F
.30816 .48278 m .29904 .47189 L .2987 .4748 L 1 .886 0 r
F
.30789 .48567 m .30816 .48278 L .2987 .4748 L 1 .869 0 r
F
.61519 .41764 m .60923 .42207 L .61043 .42457 L .142 .059 0 r
F
.61519 .41764 m .61394 .4152 L .60923 .42207 L F
.76881 .43545 m .76834 .44402 L .76887 .44898 L 0 0 0 r
F
.76881 .43545 m .76786 .43064 L .76834 .44402 L F
.38865 .603 m .37441 .59736 L .37546 .59922 L 1 .185 0 r
F
.38958 .60477 m .38865 .603 L .37546 .59922 L 1 .158 0 r
F
.65204 .52776 m .64691 .53387 L .646 .53676 L 0 0 0 r
F
.65204 .52776 m .65294 .52487 L .64691 .53387 L F
.45394 .63413 m .43866 .63233 L .43918 .63369 L .799 .052 0 r
F
.45422 .63542 m .45394 .63413 L .43918 .63369 L .779 .048 0 r
F
.46886 .63534 m .45394 .63413 L .45422 .63542 L .723 .042 0 r
F
.63233 .87419 m .61172 .87659 L .60832 .87937 L .182 0 0 r
F
.63233 .87419 m .63634 .8713 L .61172 .87659 L F
.62682 .49216 m .6189 .49655 L .61899 .49917 L .086 .008 0 r
F
.62682 .49216 m .62673 .48953 L .6189 .49655 L F
.76502 .54651 m .7559 .55491 L .75495 .55958 L 0 0 0 r
F
.76502 .54651 m .76593 .54175 L .7559 .55491 L F
.61921 .42192 m .61334 .42641 L .61452 .42894 L .119 .055 0 r
F
.61921 .42192 m .61797 .41945 L .61334 .42641 L F
.57682 .59266 m .56563 .59506 L .56463 .59692 L .26 0 0 r
F
.57682 .59266 m .57795 .59075 L .56563 .59506 L F
.73207 .62634 m .7201 .63299 L .71822 .63712 L 0 0 0 r
F
.73207 .62634 m .73412 .62212 L .7201 .63299 L F
.33194 .52309 m .32206 .51389 L .32222 .51647 L 1 .73 0 r
F
.33212 .52564 m .33194 .52309 L .32222 .51647 L 1 .708 0 r
F
.56385 .34144 m .56095 .34306 L .56291 .34564 L .03 .07 0 r
F
.56385 .34144 m .56178 .3391 L .56095 .34306 L F
.55193 .33806 m .54989 .3377 L .55182 .34047 L 0 .024 0 r
F
.55193 .33806 m .54993 .33553 L .54989 .3377 L F
.40513 .62213 m .38957 .61821 L .39066 .61992 L 1 .082 0 r
F
.40603 .62376 m .40513 .62213 L .39066 .61992 L .99 .079 0 r
F
.64537 .26318 m .66713 .24273 L .67096 .24623 L .373 0 0 r
F
.64537 .26318 m .63786 .26561 L .66713 .24273 L F
.54289 .6203 m .53036 .62157 L .52948 .62307 L .376 0 0 r
F
.54289 .6203 m .54399 .61877 L .53036 .62157 L F
.54842 .64808 m .53567 .65113 L .53448 .65248 L .167 0 0 r
F
.54842 .64808 m .54988 .6467 L .53567 .65113 L F
.43525 .34166 m .43623 .33891 L .43364 .33982 L 0 0 0 r
F
.32811 .46174 m .32193 .45211 L .32114 .45467 L 1 1 0 r
F
.3274 .46432 m .32811 .46174 L .32114 .45467 L 1 .997 0 r
F
.4225 .62845 m .40696 .62535 L .4079 .62691 L .933 .071 0 r
F
.42323 .62993 m .4225 .62845 L .4079 .62691 L .915 .067 0 r
F
.90087 .49254 m .89107 .50535 L .89105 .51222 L 0 0 0 r
F
.90087 .49254 m .90107 .48558 L .89107 .50535 L F
.43933 .62559 m .42441 .62266 L .42514 .62402 L .873 .061 0 r
F
.43984 .62688 m .43933 .62559 L .42514 .62402 L .853 .057 0 r
F
.51783 .91116 m .49276 .9104 L .49204 .91244 L .398 0 0 r
F
.51783 .91116 m .51934 .9091 L .49276 .9104 L F
.6164 .4201 m .61043 .42457 L .61159 .42707 L .133 .057 0 r
F
.6164 .4201 m .61519 .41764 L .61043 .42457 L F
.43866 .63233 m .42323 .62993 L .42399 .63136 L .863 .061 0 r
F
.43918 .63369 m .43866 .63233 L .42399 .63136 L .844 .057 0 r
F
.52624 .6223 m .51337 .62303 L .51268 .62435 L .426 .005 0 r
F
.52624 .6223 m .52716 .62095 L .51337 .62303 L F
.1133 .70263 m .08961 .68222 L .0922 .68855 L 1 .205 0 r
F
.11584 .70871 m .1133 .70263 L .0922 .68855 L 1 .175 0 r
F
.57815 .59728 m .56678 .59961 L .56575 .6015 L .264 0 0 r
F
.57815 .59728 m .57933 .59533 L .56678 .59961 L F
.36573 .59793 m .35077 .59184 L .3519 .594 L 1 .281 0 r
F
.36674 .6 m .36573 .59793 L .3519 .594 L 1 .256 0 r
F
.41063 .90743 m .38165 .90315 L .38402 .90556 L .571 .007 0 r
F
.41228 .90965 m .41063 .90743 L .38402 .90556 L .542 .001 0 r
F
.43886 .91068 m .41063 .90743 L .41228 .90965 L .522 0 0 r
F
.28138 .83302 m .25172 .82547 L .25559 .82939 L .919 .066 0 r
F
.28479 .83672 m .28138 .83302 L .25559 .82939 L .896 .062 0 r
F
.71121 .83317 m .69249 .83725 L .68851 .8411 L .057 0 0 r
F
.71121 .83317 m .71565 .82916 L .69249 .83725 L F
.4237 .62127 m .40887 .61756 L .40977 .61904 L .942 .071 0 r
F
.42441 .62266 m .4237 .62127 L .40977 .61904 L .923 .067 0 r
F
.46599 .90553 m .46591 .90358 L .4394 .90354 L .466 0 0 r
F
.49167 .90473 m .46591 .90358 L .46599 .90553 L .426 0 0 r
F
.49167 .90473 m .49238 .90279 L .46591 .90358 L F
.60837 .60375 m .59861 .60849 L .59716 .61063 L 0 0 0 r
F
.60837 .60375 m .60994 .60154 L .59861 .60849 L F
.29622 .49829 m .28927 .48675 L .28877 .48982 L 1 .824 0 r
F
.2958 .50139 m .29622 .49829 L .28877 .48982 L 1 .805 0 r
F
.63027 .49777 m .62199 .50221 L .62203 .50488 L .094 .008 0 r
F
.63027 .49777 m .63023 .49509 L .62199 .50221 L F
.62041 .42442 m .61452 .42894 L .61565 .43149 L .112 .053 0 r
F
.62041 .42442 m .61921 .42192 L .61452 .42894 L F
.36962 .58759 m .3562 .58084 L .35718 .58293 L 1 .309 0 r
F
.37052 .5896 m .36962 .58759 L .35718 .58293 L 1 .282 0 r
F
.32204 .54021 m .30975 .53092 L .31025 .53366 L 1 .62 0 r
F
.32255 .54287 m .32204 .54021 L .31025 .53366 L 1 .599 0 r
F
.38647 .61284 m .3711 .60796 L .37226 .60988 L 1 .164 0 r
F
.38748 .61467 m .38647 .61284 L .37226 .60988 L 1 .139 0 r
F
.87963 .64425 m .86359 .6536 L .86156 .66013 L 0 0 0 r
F
.87963 .64425 m .88178 .63754 L .86359 .6536 L F
.81589 .73428 m .79957 .74155 L .79628 .74703 L F
.81589 .73428 m .81941 .72861 L .79957 .74155 L F
.61676 .54626 m .60706 .54996 L .60646 .55241 L .138 0 0 r
F
.61676 .54626 m .61741 .54377 L .60706 .54996 L F
.67192 .8675 m .65171 .87003 L .64786 .87341 L .16 0 0 r
F
.67192 .8675 m .67633 .86398 L .65171 .87003 L F
.3214 .84899 m .29183 .84389 L .29545 .84735 L .856 .055 0 r
F
.32449 .85227 m .3214 .84899 L .29545 .84735 L .833 .051 0 r
F
.56589 .34375 m .56291 .34564 L .56487 .34813 L .053 .073 0 r
F
.56589 .34375 m .56385 .34144 L .56291 .34564 L F
.30789 .48567 m .2987 .4748 L .29841 .47772 L 1 .869 0 r
F
.30766 .48855 m .30789 .48567 L .29841 .47772 L 1 .852 0 r
F
.34967 .56318 m .33758 .55519 L .33829 .55754 L 1 .484 0 r
F
.35036 .56547 m .34967 .56318 L .33829 .55754 L 1 .458 0 r
F
.80003 .19141 m .79823 .20582 L .80324 .2108 L .01 .073 0 r
F
.80003 .19141 m .79497 .18669 L .79823 .20582 L F
.35258 .63553 m .33645 .62795 L .33769 .63069 L 1 .297 0 r
F
.35377 .63811 m .35258 .63553 L .33769 .63069 L 1 .278 0 r
F
.41652 .6691 m .39867 .6665 L .39984 .66845 L .881 .063 0 r
F
.41746 .67083 m .41652 .6691 L .39984 .66845 L .863 .06 0 r
F
.69272 .6794 m .68019 .68545 L .6778 .68901 L 0 0 0 r
F
.69272 .6794 m .69541 .67583 L .68019 .68545 L F
.55397 .34044 m .55182 .34047 L .55381 .34304 L 0 .038 0 r
F
.55397 .34044 m .55193 .33806 L .55182 .34047 L F
.41542 .86148 m .38771 .86236 L .38974 .86509 L .649 .029 0 r
F
.4168 .8641 m .41542 .86148 L .38974 .86509 L .622 .025 0 r
F
.44189 .85866 m .41542 .86148 L .4168 .8641 L .544 .017 0 r
F
.61406 .54232 m .60474 .54608 L .60416 .54848 L .124 0 0 r
F
.61406 .54232 m .61468 .53988 L .60474 .54608 L F
.46894 .63054 m .46892 .62938 L .45452 .62904 L .714 .038 0 r
F
.48308 .63029 m .46892 .62938 L .46894 .63054 L .645 .03 0 r
F
.48308 .63029 m .48332 .62912 L .46892 .62938 L F
.27102 .86299 m .24122 .85262 L .24551 .85659 L .81 .05 0 r
F
.27486 .8667 m .27102 .86299 L .24551 .85659 L .779 .045 0 r
F
.40712 .61449 m .39251 .6099 L .39354 .61154 L 1 .083 0 r
F
.40798 .61604 m .40712 .61449 L .39354 .61154 L .997 .08 0 r
F
.61757 .42258 m .61159 .42707 L .61271 .42959 L .125 .054 0 r
F
.61757 .42258 m .6164 .4201 L .61159 .42707 L F
.79758 .19356 m .79763 .20632 L .80265 .21128 L 0 .078 0 r
F
.79758 .19356 m .79221 .18919 L .79763 .20632 L F
.34385 .57596 m .32982 .56841 L .33076 .57085 L 1 .422 0 r
F
.34474 .5783 m .34385 .57596 L .33076 .57085 L 1 .398 0 r
F
.3274 .46432 m .32114 .45467 L .32039 .45723 L 1 .997 0 r
F
.32673 .46691 m .3274 .46432 L .32039 .45723 L 1 .983 0 r
F
.5118 .32752 m .51052 .3205 L .51207 .32671 L 1 .296 0 r
F
.5118 .32752 m .50981 .32334 L .51052 .3205 L F
.62686 .49478 m .61899 .49917 L .61903 .50178 L .077 .004 0 r
F
.62686 .49478 m .62682 .49216 L .61899 .49917 L F
.32885 .6083 m .31465 .59886 L .31561 .60183 L 1 .427 0 r
F
.32982 .61116 m .32885 .6083 L .31561 .60183 L 1 .407 0 r
F
.59529 .57351 m .58496 .57655 L .58406 .57867 L .189 0 0 r
F
.59529 .57351 m .59628 .57135 L .58496 .57655 L F
.52671 .62733 m .51376 .62812 L .51305 .62948 L .421 .003 0 r
F
.52671 .62733 m .52765 .62595 L .51376 .62812 L F
.30698 .56555 m .29576 .55454 L .29618 .55767 L 1 .59 0 r
F
.30745 .56863 m .30698 .56555 L .29618 .55767 L 1 .569 0 r
F
.51125 .62685 m .49798 .62707 L .4975 .62828 L .487 .011 0 r
F
.51125 .62685 m .51197 .62562 L .49798 .62707 L F
.33212 .52564 m .32222 .51647 L .32242 .51904 L 1 .708 0 r
F
.33235 .52818 m .33212 .52564 L .32242 .51904 L 1 .686 0 r
F
.62157 .42693 m .61565 .43149 L .61675 .43405 L .105 .05 0 r
F
.62157 .42693 m .62041 .42442 L .61565 .43149 L F
.58616 .62453 m .57524 .62859 L .57375 .63039 L .033 0 0 r
F
.58616 .62453 m .58782 .62266 L .57524 .62859 L F
.88303 .32649 m .87599 .34161 L .87887 .34809 L 0 .011 0 r
F
.88303 .32649 m .88005 .32006 L .87599 .34161 L F
.59719 .57792 m .58659 .58088 L .58566 .58303 L .197 0 0 r
F
.59719 .57792 m .59823 .57572 L .58659 .58088 L F
.68928 .40169 m .68682 .40778 L .68537 .41235 L 0 0 0 r
F
.68928 .40169 m .69088 .39698 L .68682 .40778 L F
.54207 .31949 m .54468 .3097 L .5459 .31526 L 1 .319 0 r
F
.56792 .34603 m .56487 .34813 L .56684 .35056 L .067 .075 0 r
F
.56792 .34603 m .56589 .34375 L .56487 .34813 L F
.31267 .88217 m .28275 .87382 L .2868 .87722 L .737 .035 0 r
F
.31618 .88533 m .31267 .88217 L .2868 .87722 L .704 .03 0 r
F
.55805 .60739 m .54634 .6092 L .54535 .61081 L .315 0 0 r
F
.55805 .60739 m .55922 .60573 L .54634 .6092 L F
.63048 .5747 m .62251 .5802 L .62125 .5827 L 0 0 0 r
F
.63048 .5747 m .63179 .57214 L .62251 .5802 L F
.49702 .62945 m .48332 .62912 L .48308 .63029 L .563 .02 0 r
F
.49702 .62945 m .4975 .62828 L .48332 .62912 L F
.65113 .53064 m .646 .53676 L .64507 .53962 L 0 0 0 r
F
.65113 .53064 m .65204 .52776 L .646 .53676 L F
.46888 .63656 m .46886 .63534 L .45422 .63542 L .701 .038 0 r
F
.48319 .63598 m .46886 .63534 L .46888 .63656 L .633 .029 0 r
F
.48319 .63598 m .48343 .63476 L .46886 .63534 L F
.55603 .34268 m .55381 .34304 L .55584 .34546 L 0 .05 0 r
F
.55603 .34268 m .55397 .34044 L .55381 .34304 L F
.61869 .42507 m .61271 .42959 L .61379 .43212 L .116 .051 0 r
F
.61869 .42507 m .61757 .42258 L .61271 .42959 L F
.51696 .90312 m .49238 .90279 L .49167 .90473 L .377 0 0 r
F
.51696 .90312 m .51845 .90118 L .49238 .90279 L F
.41161 .90053 m .38308 .89643 L .38541 .8988 L .567 .007 0 r
F
.41324 .9027 m .41161 .90053 L .38541 .8988 L .539 .001 0 r
F
.4394 .90354 m .41161 .90053 L .41324 .9027 L .516 0 0 r
F
.63028 .50044 m .62203 .50488 L .62203 .50754 L .086 .005 0 r
F
.63028 .50044 m .63027 .49777 L .62203 .50488 L F
.88111 .32721 m .8737 .34239 L .87638 .3489 L 0 .007 0 r
F
.88111 .32721 m .87834 .32073 L .8737 .34239 L F
.2958 .50139 m .28877 .48982 L .28831 .4929 L 1 .805 0 r
F
.29542 .5045 m .2958 .50139 L .28831 .4929 L 1 .785 0 r
F
.4685 .67198 m .46847 .67079 L .45213 .67252 L .494 .004 0 r
F
.48416 .6696 m .46847 .67079 L .4685 .67198 L .416 0 0 r
F
.48416 .6696 m .48447 .66849 L .46847 .67079 L F
.76968 .44027 m .76887 .44898 L .76934 .45394 L 0 0 0 r
F
.76968 .44027 m .76881 .43545 L .76887 .44898 L F
.56592 .63874 m .55412 .64226 L .55273 .64378 L .098 0 0 r
F
.56592 .63874 m .56754 .63716 L .55412 .64226 L F
.32673 .46691 m .32039 .45723 L .31969 .4598 L 1 .983 0 r
F
.3261 .46951 m .32673 .46691 L .31969 .4598 L 1 .968 0 r
F
.91148 .49997 m .89878 .5128 L .89891 .51982 L 0 0 0 r
F
.91148 .49997 m .91133 .49283 L .89878 .5128 L F
.30766 .48855 m .29841 .47772 L .29816 .48064 L 1 .852 0 r
F
.30748 .49143 m .30766 .48855 L .29816 .48064 L 1 .833 0 r
F
.5308 .65624 m .51743 .65888 L .51649 .66007 L .213 0 0 r
F
.5308 .65624 m .53205 .65504 L .51743 .65888 L F
.51453 .32859 m .51285 .32378 L .51465 .32853 L .914 .098 0 r
F
.51453 .32859 m .5124 .32522 L .51285 .32378 L F
.62268 .42945 m .61675 .43405 L .61781 .43662 L .098 .048 0 r
F
.62268 .42945 m .62157 .42693 L .61675 .43405 L F
.76483 .80553 m .74632 .81019 L .74238 .81491 L .017 0 0 r
F
.76483 .80553 m .76915 .80062 L .74632 .81019 L F
.49679 .32647 m .495 .31908 L .49714 .30659 L 1 .633 0 r
F
.38958 .60477 m .37546 .59922 L .37654 .60105 L 1 .158 0 r
F
.39053 .60652 m .38958 .60477 L .37654 .60105 L 1 .13 0 r
F
.54115 .61689 m .52893 .61815 L .52805 .61957 L .368 0 0 r
F
.54115 .61689 m .54223 .61542 L .52893 .61815 L F
.56992 .34829 m .56684 .35056 L .56881 .35293 L .073 .075 0 r
F
.56992 .34829 m .56792 .34603 L .56684 .35056 L F
.55896 .61217 m .54712 .61394 L .5461 .61558 L .315 0 0 r
F
.55896 .61217 m .56016 .61048 L .54712 .61394 L F
.37606 .65386 m .35886 .64822 L .36022 .65069 L 1 .168 0 r
F
.3773 .65613 m .37606 .65386 L .36022 .65069 L 1 .15 0 r
F
.43974 .91273 m .43886 .91068 L .41228 .90965 L .504 0 0 r
F
.46589 .91296 m .43886 .91068 L .43974 .91273 L .477 0 0 r
F
.51159 .63207 m .49823 .63241 L .49774 .63367 L .476 .01 0 r
F
.51159 .63207 m .51233 .6308 L .49823 .63241 L F
.65604 .71501 m .64357 .72177 L .64098 .72485 L 0 0 0 r
F
.65604 .71501 m .65902 .71204 L .64357 .72177 L F
.62686 .4974 m .61903 .50178 L .61904 .50439 L .069 .001 0 r
F
.62686 .4974 m .62686 .49478 L .61903 .50178 L F
.32255 .54287 m .31025 .53366 L .3108 .53638 L 1 .599 0 r
F
.32309 .54551 m .32255 .54287 L .3108 .53638 L 1 .577 0 r
F
.6523 .26177 m .67096 .24623 L .67472 .24979 L .387 0 0 r
F
.6523 .26177 m .64537 .26318 L .67096 .24623 L F
.57565 .59454 m .56463 .59692 L .5636 .59875 L .251 0 0 r
F
.57565 .59454 m .57682 .59266 L .56463 .59692 L F
.3567 .85841 m .32764 .85546 L .33084 .85856 L .79 .046 0 r
F
.35932 .86136 m .3567 .85841 L .33084 .85856 L .766 .041 0 r
F
.43501 .67216 m .41746 .67083 L .41841 .67253 L .758 .044 0 r
F
.43569 .67365 m .43501 .67216 L .41841 .67253 L .735 .04 0 r
F
.45213 .67252 m .43501 .67216 L .43569 .67365 L .635 .026 0 r
F
.55813 .3448 m .55584 .34546 L .5579 .34776 L 0 .06 0 r
F
.55813 .3448 m .55603 .34268 L .55584 .34546 L F
.27433 .85669 m .2451 .84635 L .24929 .8503 L .818 .051 0 r
F
.27808 .86037 m .27433 .85669 L .24929 .8503 L .787 .046 0 r
F
.18282 .7653 m .15504 .75118 L .15861 .75643 L 1 .098 0 r
F
.18615 .77027 m .18282 .7653 L .15861 .75643 L 1 .095 0 r
F
.16834 .78835 m .1407 .77222 L .14458 .7777 L .982 .091 0 r
F
.17199 .79354 m .16834 .78835 L .14458 .7777 L .957 .087 0 r
F
.61977 .42757 m .61379 .43212 L .61483 .43467 L .108 .048 0 r
F
.61977 .42757 m .61869 .42507 L .61379 .43212 L F
.61606 .54873 m .60646 .55241 L .60581 .55483 L .129 0 0 r
F
.61606 .54873 m .61676 .54626 L .60646 .55241 L F
.49724 .63489 m .48343 .63476 L .48319 .63598 L .55 .019 0 r
F
.49724 .63489 m .49774 .63367 L .48343 .63476 L F
.86889 .63995 m .85518 .64989 L .85309 .65623 L 0 0 0 r
F
.86889 .63995 m .87108 .63344 L .85518 .64989 L F
.46656 .85376 m .4665 .85127 L .44189 .85866 L .418 0 0 r
F
.48949 .84432 m .4665 .85127 L .46656 .85376 L .31 0 0 r
F
.48949 .84432 m .49005 .84188 L .4665 .85127 L F
.76404 .55125 m .75495 .55958 L .75393 .56423 L 0 0 0 r
F
.76404 .55125 m .76502 .54651 L .75495 .55958 L F
.66744 .85885 m .64799 .86199 L .64417 .8652 L .118 0 0 r
F
.66744 .85885 m .6718 .8555 L .64799 .86199 L F
.52159 .32581 m .53272 .28729 L .53098 .30377 L 1 .777 0 r
F
.52159 .32581 m .52979 .28947 L .53272 .28729 L F
.6134 .54474 m .60416 .54848 L .60355 .55086 L .115 0 0 r
F
.6134 .54474 m .61406 .54232 L .60416 .54848 L F
.45452 .62904 m .43984 .62688 L .44035 .62812 L .79 .049 0 r
F
.4548 .63022 m .45452 .62904 L .44035 .62812 L .769 .045 0 r
F
.46894 .63054 m .45452 .62904 L .4548 .63022 L .714 .038 0 r
F
.35036 .56547 m .33829 .55754 L .33905 .55988 L 1 .458 0 r
F
.35109 .56773 m .35036 .56547 L .33905 .55988 L 1 .432 0 r
F
.33235 .52818 m .32242 .51904 L .32267 .52161 L 1 .686 0 r
F
.33262 .5307 m .33235 .52818 L .32267 .52161 L 1 .664 0 r
F
.36674 .6 m .3519 .594 L .35306 .59614 L 1 .256 0 r
F
.36778 .60204 m .36674 .6 L .35306 .59614 L 1 .231 0 r
F
.57695 .59919 m .56575 .6015 L .56469 .60337 L .255 0 0 r
F
.57695 .59919 m .57815 .59728 L .56575 .6015 L F
.37052 .5896 m .35718 .58293 L .35819 .585 L 1 .282 0 r
F
.37144 .59158 m .37052 .5896 L .35819 .585 L 1 .254 0 r
F
.10792 .71379 m .08326 .69345 L .08614 .69984 L 1 .169 0 r
F
.1107 .71991 m .10792 .71379 L .08614 .69984 L 1 .14 0 r
F
.3261 .46951 m .31969 .4598 L .31903 .46239 L 1 .968 0 r
F
.32552 .47212 m .3261 .46951 L .31903 .46239 L 1 .952 0 r
F
.62376 .43199 m .61781 .43662 L .61882 .43921 L .091 .045 0 r
F
.62376 .43199 m .62268 .42945 L .61781 .43662 L F
.4525 .67382 m .45213 .67252 L .43569 .67365 L .607 .021 0 r
F
.4685 .67198 m .45213 .67252 L .4525 .67382 L .494 .004 0 r
F
.31521 .87575 m .2858 .86745 L .28977 .87084 L .743 .036 0 r
F
.31865 .87889 m .31521 .87575 L .28977 .87084 L .711 .031 0 r
F
.57189 .35054 m .56881 .35293 L .57077 .35526 L .073 .075 0 r
F
.57189 .35054 m .56992 .34829 L .56881 .35293 L F
.38771 .86236 m .35932 .86136 L .36198 .86422 L .721 .037 0 r
F
.38974 .86509 m .38771 .86236 L .36198 .86422 L .696 .033 0 r
F
.56027 .34683 m .5579 .34776 L .55998 .34997 L 0 .07 0 r
F
.56027 .34683 m .55813 .3448 L .5579 .34776 L F
.40603 .62376 m .39066 .61992 L .39177 .62161 L .99 .079 0 r
F
.40696 .62535 m .40603 .62376 L .39177 .62161 L .972 .076 0 r
F
.60055 .89585 m .57877 .89703 L .57586 .89955 L .261 0 0 r
F
.60055 .89585 m .60415 .89324 L .57877 .89703 L F
.39753 .66452 m .37986 .66061 L .38119 .66281 L .981 .078 0 r
F
.39867 .6665 m .39753 .66452 L .38119 .66281 L .966 .075 0 r
F
.34474 .5783 m .33076 .57085 L .33175 .57327 L 1 .398 0 r
F
.34565 .58062 m .34474 .5783 L .33175 .57327 L 1 .374 0 r
F
.54178 .62179 m .52948 .62307 L .52857 .62453 L .365 0 0 r
F
.54178 .62179 m .54289 .6203 L .52948 .62307 L F
.63023 .50312 m .62203 .50754 L .62198 .51019 L .078 .001 0 r
F
.63023 .50312 m .63028 .50044 L .62203 .50754 L F
.72994 .63051 m .71822 .63712 L .71626 .6412 L 0 0 0 r
F
.72994 .63051 m .73207 .62634 L .71822 .63712 L F
.12477 .69552 m .09995 .67676 L .10262 .68284 L 1 .228 0 r
F
.12734 .70133 m .12477 .69552 L .10262 .68284 L 1 .2 0 r
F
.45422 .63542 m .43918 .63369 L .43971 .635 L .779 .048 0 r
F
.4545 .63666 m .45422 .63542 L .43971 .635 L .758 .044 0 r
F
.46888 .63656 m .45422 .63542 L .4545 .63666 L .701 .038 0 r
F
.30745 .56863 m .29618 .55767 L .29665 .56078 L 1 .569 0 r
F
.30797 .57169 m .30745 .56863 L .29665 .56078 L 1 .548 0 r
F
.29542 .5045 m .28831 .4929 L .2879 .49599 L 1 .785 0 r
F
.29508 .50761 m .29542 .5045 L .2879 .49599 L 1 .765 0 r
F
.34939 .89508 m .31974 .88839 L .32337 .89134 L .668 .023 0 r
F
.3524 .8978 m .34939 .89508 L .32337 .89134 L .634 .017 0 r
F
.6208 .43009 m .61483 .43467 L .61582 .43722 L .099 .045 0 r
F
.6208 .43009 m .61977 .42757 L .61483 .43467 L F
.59425 .57564 m .58406 .57867 L .58312 .58075 L .18 0 0 r
F
.59425 .57564 m .59529 .57351 L .58406 .57867 L F
.60678 .60592 m .59716 .61063 L .59567 .61273 L 0 0 0 r
F
.60678 .60592 m .60837 .60375 L .59716 .61063 L F
.38748 .61467 m .37226 .60988 L .37346 .61176 L 1 .139 0 r
F
.38851 .61645 m .38748 .61467 L .37346 .61176 L 1 .113 0 r
F
.42323 .62993 m .4079 .62691 L .40887 .62842 L .915 .067 0 r
F
.42399 .63136 m .42323 .62993 L .40887 .62842 L .896 .064 0 r
F
.30748 .49143 m .29816 .48064 L .29797 .48355 L 1 .833 0 r
F
.30734 .49431 m .30748 .49143 L .29797 .48355 L 1 .815 0 r
F
.50858 .32572 m .50846 .32069 L .50981 .32334 L 1 .531 0 r
F
.50846 .32069 m .50836 .31611 L .50883 .31845 L F
.50846 .32069 m .50883 .31845 L .50981 .32334 L F
.50858 .32572 m .50659 .32143 L .50836 .31611 L F
.51094 .32803 m .50858 .32572 L .50981 .32334 L 1 .13 0 r
F
.50673 .32835 m .50659 .32143 L .50858 .32572 L 1 .477 0 r
F
.51022 .32783 m .50858 .32572 L .50992 .32703 L .383 0 0 r
F
.51022 .32783 m .50992 .32703 L .51094 .32803 L F
.51094 .32803 m .51054 .32636 L .5118 .32752 L 1 .13 0 r
F
.51054 .32636 m .50981 .32334 L .51075 .32531 L F
.51054 .32636 m .51075 .32531 L .5118 .32752 L F
.51182 .32808 m .51022 .32783 L .51094 .32803 L 0 .124 0 r
F
.51234 .32835 m .5118 .32752 L .51249 .32843 L .678 .031 0 r
F
.51335 .32991 m .51094 .32803 L .5118 .32752 L F
.51233 .32811 m .51172 .32803 L .51182 .32808 L 0 .124 0 r
F
.51172 .32803 m .51022 .32783 L .51182 .32808 L F
.51335 .32991 m .51234 .32835 L .51401 .33044 L .678 .031 0 r
F
.51234 .32835 m .51249 .32843 L .51401 .33044 L F
.51236 .32812 m .51094 .32803 L .51335 .32991 L 0 .124 0 r
F
.51233 .32811 m .51094 .32803 L .51236 .32812 L F
.51235 .32814 m .51047 .32848 L .5109 .32754 L .305 0 0 r
F
.51233 .32811 m .5109 .32754 L .51128 .32673 L F
.51235 .32814 m .5109 .32754 L .51233 .32811 L F
.51401 .33044 m .51207 .32671 L .51389 .33037 L .762 .068 0 r
F
.51401 .33044 m .51389 .33037 L .51404 .33068 L F
.51572 .33175 m .51413 .33051 L .51401 .33044 L 0 .026 0 r
F
.51413 .33051 m .51335 .32991 L .51401 .33044 L F
.51401 .33044 m .5118 .32752 L .51207 .32671 L .762 .068 0 r
F
.51235 .32814 m .51128 .32673 L .51371 .32862 L .305 0 0 r
F
.51236 .32811 m .51233 .32811 L .51236 .32812 L 0 .124 0 r
F
.51022 .32783 m .50912 .32344 L .51128 .32673 L .925 .087 0 r
F
.5097 .32739 m .50858 .32572 L .51022 .32783 L .383 0 0 r
F
.50933 .32707 m .50912 .32344 L .51022 .32783 L .925 .087 0 r
F
.51236 .32811 m .50967 .32768 L .51022 .32783 L 0 .124 0 r
F
.51236 .32811 m .51022 .32783 L .51233 .32811 L F
.51047 .32848 m .51023 .32786 L .51026 .32784 L .305 0 0 r
F
.51074 .3279 m .51026 .32784 L .51128 .32673 L F
.51047 .32848 m .51026 .32784 L .51074 .3279 L F
.51023 .32786 m .51022 .32783 L .51025 .32781 L F
.51023 .32786 m .51025 .32781 L .51128 .32673 L F
.51047 .32848 m .50942 .32867 L .51022 .32783 L F
.50942 .32867 m .50933 .32707 L .51022 .32783 L .925 .087 0 r
F
.50995 .32776 m .5097 .32739 L .51022 .32783 L .383 0 0 r
F
.50967 .32768 m .50933 .32707 L .50995 .32776 L F
.50933 .32707 m .50858 .32572 L .50995 .32776 L F
.50933 .32707 m .50673 .32835 L .50858 .32572 L F
.50811 .32804 m .50673 .32835 L .50933 .32707 L F
.50942 .32867 m .50814 .32575 L .50933 .32707 L .925 .087 0 r
F
.50967 .32768 m .50811 .32804 L .50933 .32707 L .383 0 0 r
F
.50888 .32743 m .50732 .32766 L .50814 .32575 L .925 .087 0 r
F
.50942 .32867 m .50811 .32804 L .50888 .32743 L F
.50811 .32804 m .50732 .32766 L .50888 .32743 L F
.50933 .32707 m .50814 .32575 L .50912 .32344 L F
.50732 .32766 m .50693 .32747 L .50753 .32636 L F
.50732 .32766 m .50753 .32636 L .50912 .32344 L F
.50912 .32344 m .50967 .31029 L .51062 .32 L 1 .661 0 r
F
.50912 .32344 m .50754 .31713 L .50967 .31029 L F
.43984 .62688 m .42514 .62402 L .42588 .62534 L .853 .057 0 r
F
.44035 .62812 m .43984 .62688 L .42588 .62534 L .832 .053 0 r
F
.51457 .66231 m .50055 .66454 L .49991 .66565 L .266 0 0 r
F
.51457 .66231 m .51554 .66122 L .50055 .66454 L F
.38165 .90315 m .3524 .8978 L .35545 .90041 L .612 .014 0 r
F
.38402 .90556 m .38165 .90315 L .35545 .90041 L .577 .008 0 r
F
.52531 .6236 m .51268 .62435 L .51197 .62562 L .416 0 0 r
F
.52531 .6236 m .52624 .6223 L .51268 .62435 L F
.59612 .58009 m .58566 .58303 L .58469 .58515 L .189 0 0 r
F
.59612 .58009 m .59719 .57792 L .58566 .58303 L F
.90055 .49948 m .89105 .51222 L .89092 .51908 L 0 0 0 r
F
.90055 .49948 m .90087 .49254 L .89105 .51222 L F
.49926 .66671 m .48447 .66849 L .48416 .6696 L .334 0 0 r
F
.49926 .66671 m .49991 .66565 L .48447 .66849 L F
.62682 .50001 m .61904 .50439 L .619 .50699 L .06 0 0 r
F
.62682 .50001 m .62686 .4974 L .61904 .50439 L F
.23697 .809 m .20796 .79865 L .21189 .80313 L .973 .078 0 r
F
.24054 .81323 m .23697 .809 L .21189 .80313 L .951 .074 0 r
F
.56243 .34877 m .55998 .34997 L .56207 .35211 L 0 .078 0 r
F
.56243 .34877 m .56027 .34683 L .55998 .34997 L F
.57385 .35278 m .57077 .35526 L .57272 .35756 L .07 .074 0 r
F
.57385 .35278 m .57189 .35054 L .57077 .35526 L F
.32982 .61116 m .31561 .60183 L .31661 .60479 L 1 .407 0 r
F
.33083 .614 m .32982 .61116 L .31661 .60479 L 1 .387 0 r
F
.42441 .62266 m .40977 .61904 L .4107 .62048 L .923 .067 0 r
F
.42514 .62402 m .42441 .62266 L .4107 .62048 L .903 .064 0 r
F
.43918 .63369 m .42399 .63136 L .42475 .63275 L .844 .057 0 r
F
.43971 .635 m .43918 .63369 L .42475 .63275 L .823 .053 0 r
F
.82087 .74644 m .80344 .7529 L .80005 .75849 L 0 0 0 r
F
.82087 .74644 m .82453 .74064 L .80344 .7529 L F
.65019 .5335 m .64507 .53962 L .64412 .54245 L F
.65019 .5335 m .65113 .53064 L .64507 .53962 L F
.62479 .43455 m .61882 .43921 L .6198 .4418 L .084 .042 0 r
F
.62479 .43455 m .62376 .43199 L .61882 .43921 L F
.44027 .90554 m .4394 .90354 L .41324 .9027 L .498 0 0 r
F
.46599 .90553 m .4394 .90354 L .44027 .90554 L .466 0 0 r
F
.44261 .86117 m .44189 .85866 L .4168 .8641 L .514 .011 0 r
F
.46656 .85376 m .44189 .85866 L .44261 .86117 L .418 0 0 r
F
.35377 .63811 m .33769 .63069 L .33897 .63342 L 1 .278 0 r
F
.35499 .64067 m .35377 .63811 L .33897 .63342 L 1 .259 0 r
F
.40798 .61604 m .39354 .61154 L .39459 .61314 L .997 .08 0 r
F
.40887 .61756 m .40798 .61604 L .39459 .61314 L .978 .076 0 r
F
.32552 .47212 m .31903 .46239 L .31841 .46497 L 1 .952 0 r
F
.32498 .47472 m .32552 .47212 L .31841 .46497 L 1 .936 0 r
F
.54695 .64942 m .53448 .65248 L .53327 .65379 L .145 0 0 r
F
.54695 .64942 m .54842 .64808 L .53448 .65248 L F
.62914 .57722 m .62125 .5827 L .61995 .58516 L 0 0 0 r
F
.62914 .57722 m .63048 .5747 L .62125 .5827 L F
.75792 .79788 m .74048 .80318 L .73656 .80773 L F
.75792 .79788 m .7622 .79315 L .74048 .80318 L F
.80499 .19623 m .80324 .2108 L .80814 .21588 L 0 .069 0 r
F
.80499 .19623 m .80003 .19141 L .80324 .2108 L F
.51681 .33113 m .51465 .32853 L .51673 .33187 L .57 .019 0 r
F
.51681 .33113 m .51453 .32859 L .51465 .32853 L F
.68767 .40629 m .68537 .41235 L .68395 .41679 L 0 0 0 r
F
.68767 .40629 m .68928 .40169 L .68537 .41235 L F
.62179 .43262 m .61582 .43722 L .61678 .43978 L .089 .042 0 r
F
.62179 .43262 m .6208 .43009 L .61582 .43722 L F
.32309 .54551 m .3108 .53638 L .31139 .53908 L 1 .577 0 r
F
.32368 .54813 m .32309 .54551 L .31139 .53908 L 1 .555 0 r
F
.22488 .8358 m .19588 .82303 L .2002 .82765 L .879 .065 0 r
F
.22884 .84014 m .22488 .8358 L .2002 .82765 L .85 .061 0 r
F
.1741 .7825 m .14726 .76643 L .151 .77186 L .988 .093 0 r
F
.17763 .78765 m .1741 .7825 L .151 .77186 L .962 .088 0 r
F
.80281 .19809 m .80265 .21128 L .80759 .21631 L 0 .073 0 r
F
.80281 .19809 m .79758 .19356 L .80265 .21128 L F
.54458 .32142 m .5459 .31526 L .54753 .31956 L 1 .09 0 r
F
.54458 .32142 m .54207 .31949 L .5459 .31526 L F
.5646 .35065 m .56207 .35211 L .56417 .35419 L .012 .084 0 r
F
.5646 .35065 m .56243 .34877 L .56207 .35211 L F
.77046 .4451 m .76934 .45394 L .76975 .45888 L 0 0 0 r
F
.77046 .4451 m .76968 .44027 L .76934 .45394 L F
.61532 .55118 m .60581 .55483 L .60513 .55724 L .121 0 0 r
F
.61532 .55118 m .61606 .54873 L .60581 .55483 L F
.33262 .5307 m .32267 .52161 L .32296 .52416 L 1 .664 0 r
F
.33294 .53322 m .33262 .5307 L .32296 .52416 L 1 .641 0 r
F
.57578 .355 m .57272 .35756 L .57466 .35984 L .064 .073 0 r
F
.57578 .355 m .57385 .35278 L .57272 .35756 L F
.55686 .60902 m .54535 .61081 L .54433 .61238 L .305 0 0 r
F
.55686 .60902 m .55805 .60739 L .54535 .61081 L F
.61269 .54714 m .60355 .55086 L .60289 .55322 L .107 0 0 r
F
.61269 .54714 m .6134 .54474 L .60355 .55086 L F
.46896 .63167 m .46894 .63054 L .4548 .63022 L .692 .034 0 r
F
.48285 .63141 m .46894 .63054 L .46896 .63167 L .623 .026 0 r
F
.48285 .63141 m .48308 .63029 L .46894 .63054 L F
.62392 .74132 m .61139 .74966 L .60882 .75235 L 0 0 0 r
F
.62392 .74132 m .62694 .73884 L .61139 .74966 L F
.8859 .33298 m .87887 .34809 L .88163 .35463 L 0 .007 0 r
F
.8859 .33298 m .88303 .32649 L .87887 .34809 L F
.48896 .31952 m .48556 .32428 L .48698 .31022 L .822 .286 0 r
F
.63014 .50578 m .62198 .51019 L .62189 .51284 L .07 0 0 r
F
.63014 .50578 m .63023 .50312 L .62198 .51019 L F
.58446 .62636 m .57375 .63039 L .57224 .63215 L .017 0 0 r
F
.58446 .62636 m .58616 .62453 L .57375 .63039 L F
.66592 .47609 m .66433 .4819 L .66353 .48515 L .684 .171 0 r
F
.66592 .47609 m .66682 .47285 L .66433 .4819 L F
.52575 .62867 m .51305 .62948 L .51233 .6308 L .41 0 0 r
F
.52575 .62867 m .52671 .62733 L .51305 .62948 L F
.62578 .43712 m .6198 .4418 L .62073 .44441 L .076 .039 0 r
F
.62578 .43712 m .62479 .43455 L .6198 .4418 L F
.29508 .50761 m .2879 .49599 L .28754 .49909 L 1 .765 0 r
F
.2948 .51073 m .29508 .50761 L .28754 .49909 L 1 .745 0 r
F
.35132 .88852 m .32215 .88192 L .32571 .88485 L .673 .024 0 r
F
.35427 .89122 m .35132 .88852 L .32571 .88485 L .639 .018 0 r
F
.35109 .56773 m .33905 .55988 L .33985 .56219 L 1 .432 0 r
F
.35185 .56998 m .35109 .56773 L .33985 .56219 L 1 .405 0 r
F
.6587 .26124 m .6523 .26177 L .67472 .24979 L .405 0 0 r
F
.51052 .62805 m .4975 .62828 L .49702 .62945 L .467 .007 0 r
F
.51052 .62805 m .51125 .62685 L .4975 .62828 L F
.5668 .35249 m .56417 .35419 L .56628 .35625 L .042 .089 0 r
F
.5668 .35249 m .5646 .35065 L .56417 .35419 L F
.87735 .65094 m .86156 .66013 L .85942 .66661 L 0 0 0 r
F
.87735 .65094 m .87963 .64425 L .86156 .66013 L F
.11584 .70871 m .0922 .68855 L .09492 .69484 L 1 .175 0 r
F
.11848 .71474 m .11584 .70871 L .09492 .69484 L 1 .146 0 r
F
.59781 .88705 m .57665 .8888 L .57377 .89117 L .223 0 0 r
F
.59781 .88705 m .60137 .88461 L .57665 .8888 L F
.30734 .49431 m .29797 .48355 L .29782 .48646 L 1 .815 0 r
F
.30725 .49718 m .30734 .49431 L .29782 .48646 L 1 .796 0 r
F
.68995 .6829 m .6778 .68901 L .67533 .69251 L 0 0 0 r
F
.68995 .6829 m .69272 .6794 L .6778 .68901 L F
.57446 .59639 m .5636 .59875 L .56255 .60055 L .242 0 0 r
F
.57446 .59639 m .57565 .59454 L .5636 .59875 L F
.39053 .60652 m .37654 .60105 L .37765 .60285 L 1 .13 0 r
F
.39151 .60823 m .39053 .60652 L .37765 .60285 L 1 .103 0 r
F
.38308 .89643 m .35427 .89122 L .35728 .89381 L .612 .014 0 r
F
.38541 .8988 m .38308 .89643 L .35728 .89381 L .578 .008 0 r
F
.32498 .47472 m .31841 .46497 L .31784 .46757 L 1 .936 0 r
F
.32448 .47734 m .32498 .47472 L .31784 .46757 L 1 .919 0 r
F
.62673 .50262 m .619 .50699 L .61892 .50959 L .051 0 0 r
F
.62673 .50262 m .62682 .50001 L .619 .50699 L F
.62274 .43516 m .61678 .43978 L .61769 .44236 L .08 .039 0 r
F
.62274 .43516 m .62179 .43262 L .61678 .43978 L F
.41746 .67083 m .39984 .66845 L .40103 .67037 L .863 .06 0 r
F
.41841 .67253 m .41746 .67083 L .40103 .67037 L .844 .057 0 r
F
.57769 .35721 m .57466 .35984 L .57659 .36209 L .057 .072 0 r
F
.57769 .35721 m .57578 .355 L .57466 .35984 L F
.88374 .33374 m .87638 .3489 L .87893 .35546 L 0 .002 0 r
F
.88374 .33374 m .88111 .32721 L .87638 .3489 L F
.5318 .81751 m .51312 .82811 L .51198 .83055 L 0 0 0 r
F
.5318 .81751 m .53349 .81529 L .51312 .82811 L F
.49652 .63058 m .48308 .63029 L .48285 .63141 L .541 .015 0 r
F
.49652 .63058 m .49702 .62945 L .48308 .63029 L F
.55772 .61382 m .5461 .61558 L .54506 .61719 L .305 0 0 r
F
.55772 .61382 m .55896 .61217 L .5461 .61558 L F
.30797 .57169 m .29665 .56078 L .29717 .5639 L 1 .548 0 r
F
.30853 .57475 m .30797 .57169 L .29717 .5639 L 1 .527 0 r
F
.51915 .33323 m .51673 .33187 L .51895 .33449 L 0 .046 0 r
F
.51915 .33323 m .51681 .33113 L .51673 .33187 L F
.37144 .59158 m .35819 .585 L .35924 .58704 L 1 .254 0 r
F
.3724 .59354 m .37144 .59158 L .35924 .58704 L 1 .225 0 r
F
.56899 .3543 m .56628 .35625 L .56838 .35827 L .068 .093 0 r
F
.56899 .3543 m .5668 .35249 L .56628 .35625 L F
.51632 .33274 m .51404 .33068 L .51621 .33359 L 0 .01 0 r
F
.51632 .33274 m .51401 .33044 L .51404 .33068 L F
.4689 .63775 m .46888 .63656 L .4545 .63666 L .679 .033 0 r
F
.48295 .63715 m .46888 .63656 L .4689 .63775 L .61 .025 0 r
F
.48295 .63715 m .48319 .63598 L .46888 .63656 L F
.34565 .58062 m .33175 .57327 L .33277 .57566 L 1 .374 0 r
F
.34661 .58292 m .34565 .58062 L .33277 .57566 L 1 .349 0 r
F
.71222 .84549 m .69319 .84887 L .68909 .8528 L .087 0 0 r
F
.71222 .84549 m .7168 .8414 L .69319 .84887 L F
.54004 .61831 m .52805 .61957 L .52716 .62095 L .358 0 0 r
F
.54004 .61831 m .54115 .61689 L .52805 .61957 L F
.36778 .60204 m .35306 .59614 L .35425 .59824 L 1 .231 0 r
F
.36886 .60404 m .36778 .60204 L .35425 .59824 L 1 .205 0 r
F
.76297 .55597 m .75393 .56423 L .75284 .56885 L 0 0 0 r
F
.76297 .55597 m .76404 .55125 L .75393 .56423 L F
.57571 .60107 m .56469 .60337 L .5636 .6052 L .245 0 0 r
F
.57571 .60107 m .57695 .59919 L .56469 .60337 L F
.91149 .50711 m .89891 .51982 L .89891 .52683 L 0 0 0 r
F
.91149 .50711 m .91148 .49997 L .89891 .51982 L F
.62672 .4397 m .62073 .44441 L .62163 .44703 L .068 .036 0 r
F
.62672 .4397 m .62578 .43712 L .62073 .44441 L F
.59319 .57775 m .58312 .58075 L .58215 .58281 L .171 0 0 r
F
.59319 .57775 m .59425 .57564 L .58312 .58075 L F
.56428 .64028 m .55273 .64378 L .55131 .64527 L .079 0 0 r
F
.56428 .64028 m .56592 .63874 L .55273 .64378 L F
.81227 .73989 m .79628 .74703 L .79289 .75244 L 0 0 0 r
F
.81227 .73989 m .81589 .73428 L .79628 .74703 L F
.57958 .3594 m .57659 .36209 L .5785 .36433 L .05 .071 0 r
F
.57958 .3594 m .57769 .35721 L .57659 .36209 L F
.22916 .82964 m .20082 .81689 L .20501 .82148 L .886 .067 0 r
F
.23302 .83395 m .22916 .82964 L .20501 .82148 L .857 .062 0 r
F
.57118 .3561 m .56838 .35827 L .57047 .36029 L .089 .095 0 r
F
.57118 .3561 m .56899 .3543 L .56838 .35827 L F
.51082 .83286 m .49005 .84188 L .48949 .84432 L .14 0 0 r
F
.51082 .83286 m .51198 .83055 L .49005 .84188 L F
.64923 .53634 m .64412 .54245 L .64314 .54527 L 0 0 0 r
F
.64923 .53634 m .65019 .5335 L .64412 .54245 L F
.3773 .65613 m .36022 .65069 L .36161 .65315 L 1 .15 0 r
F
.37857 .65838 m .3773 .65613 L .36161 .65315 L 1 .131 0 r
F
.51084 .6333 m .49774 .63367 L .49724 .63489 L .454 .005 0 r
F
.51084 .6333 m .51159 .63207 L .49774 .63367 L F
.595 .58224 m .58469 .58515 L .58368 .58725 L .18 0 0 r
F
.595 .58224 m .59612 .58009 L .58469 .58515 L F
.33294 .53322 m .32296 .52416 L .32329 .52671 L 1 .641 0 r
F
.33329 .53572 m .33294 .53322 L .32329 .52671 L 1 .617 0 r
F
.62364 .43772 m .61769 .44236 L .61856 .44494 L .07 .035 0 r
F
.62364 .43772 m .62274 .43516 L .61769 .44236 L F
.54289 .90914 m .51934 .9091 L .51783 .91116 L .346 0 0 r
F
.54289 .90914 m .54518 .90704 L .51934 .9091 L F
.63 .50845 m .62189 .51284 L .62176 .51548 L .061 0 0 r
F
.63 .50845 m .63014 .50578 L .62189 .51284 L F
.32368 .54813 m .31139 .53908 L .31203 .54177 L 1 .555 0 r
F
.32431 .55074 m .32368 .54813 L .31203 .54177 L 1 .532 0 r
F
.32448 .47734 m .31784 .46757 L .31731 .47017 L 1 .919 0 r
F
.32402 .47995 m .32448 .47734 L .31731 .47017 L 1 .902 0 r
F
.52153 .33508 m .51895 .33449 L .52124 .33667 L 0 .082 0 r
F
.52153 .33508 m .51915 .33323 L .51895 .33449 L F
.71467 .34145 m .73544 .33717 L .73737 .34186 L 1 .094 0 r
F
.2948 .51073 m .28754 .49909 L .28723 .5022 L 1 .745 0 r
F
.29456 .51385 m .2948 .51073 L .28723 .5022 L 1 .724 0 r
F
.61453 .55361 m .60513 .55724 L .6044 .55963 L .112 0 0 r
F
.61453 .55361 m .61532 .55118 L .60513 .55724 L F
.49674 .63606 m .48319 .63598 L .48295 .63715 L .527 .014 0 r
F
.49674 .63606 m .49724 .63489 L .48319 .63598 L F
.4548 .63022 m .44035 .62812 L .44088 .62932 L .769 .045 0 r
F
.45508 .63136 m .4548 .63022 L .44088 .62932 L .746 .04 0 r
F
.46896 .63167 m .4548 .63022 L .45508 .63136 L .692 .034 0 r
F
.40696 .62535 m .39177 .62161 L .39291 .62325 L .972 .076 0 r
F
.4079 .62691 m .40696 .62535 L .39291 .62325 L .954 .072 0 r
F
.60515 .60806 m .59567 .61273 L .59416 .61479 L 0 0 0 r
F
.60515 .60806 m .60678 .60592 L .59567 .61273 L F
.61194 .54953 m .60289 .55322 L .6022 .55556 L .098 0 0 r
F
.61194 .54953 m .61269 .54714 L .60289 .55322 L F
.33083 .614 m .31661 .60479 L .31766 .60774 L 1 .387 0 r
F
.33187 .61682 m .33083 .614 L .31766 .60774 L 1 .367 0 r
F
.51869 .33466 m .51621 .33359 L .51849 .33592 L 0 .063 0 r
F
.51869 .33466 m .51632 .33274 L .51621 .33359 L F
.63178 .88588 m .61117 .88768 L .60769 .89052 L .206 0 0 r
F
.63178 .88588 m .6359 .88292 L .61117 .88768 L F
.30725 .49718 m .29782 .48646 L .29773 .48937 L 1 .796 0 r
F
.30721 .50004 m .30725 .49718 L .29773 .48937 L 1 .776 0 r
F
.57336 .35791 m .57047 .36029 L .57256 .3623 L .105 .097 0 r
F
.57336 .35791 m .57118 .3561 L .57047 .36029 L F
.52954 .65739 m .51649 .66007 L .51554 .66122 L .188 0 0 r
F
.52954 .65739 m .5308 .65624 L .51649 .66007 L F
.38851 .61645 m .37346 .61176 L .37468 .6136 L 1 .113 0 r
F
.38957 .61821 m .38851 .61645 L .37468 .6136 L 1 .089 0 r
F
.54712 .32321 m .54753 .31956 L .54938 .32312 L .834 .054 0 r
F
.54712 .32321 m .54458 .32142 L .54753 .31956 L F
.58146 .36158 m .5785 .36433 L .58041 .36656 L .042 .07 0 r
F
.58146 .36158 m .57958 .3594 L .5785 .36433 L F
.6266 .50522 m .61892 .50959 L .61879 .51217 L .042 0 0 r
F
.6266 .50522 m .62673 .50262 L .61892 .50959 L F
.54064 .62325 m .52857 .62453 L .52765 .62595 L .354 0 0 r
F
.54064 .62325 m .54178 .62179 L .52857 .62453 L F
.62776 .57972 m .61995 .58516 L .61861 .58759 L 0 0 0 r
F
.62776 .57972 m .62914 .57722 L .61995 .58516 L F
.62762 .44229 m .62163 .44703 L .62248 .44965 L .06 .033 0 r
F
.62762 .44229 m .62672 .4397 L .62163 .44703 L F
.46854 .67312 m .4685 .67198 L .4525 .67382 L .469 0 0 r
F
.48385 .67066 m .4685 .67198 L .46854 .67312 L .394 0 0 r
F
.48385 .67066 m .48416 .6696 L .4685 .67198 L F
.55961 .90541 m .54743 .90482 L .54518 .90704 L .301 0 0 r
F
.56031 .90449 m .54743 .90482 L .55961 .90541 L F
.56991 .90424 m .57291 .90195 L .56127 .90326 L F
.56031 .90449 m .56127 .90326 L .54743 .90482 L F
.56991 .90424 m .56127 .90326 L .56031 .90449 L F
.55769 .90746 m .54518 .90704 L .54289 .90914 L .282 0 0 r
F
.56688 .90641 m .55843 .90666 L .55769 .90746 L F
.55843 .90666 m .54518 .90704 L .55769 .90746 L F
.56688 .90641 m .56991 .90424 L .55961 .90541 L F
.55843 .90666 m .55961 .90541 L .54518 .90704 L F
.56688 .90641 m .55961 .90541 L .55843 .90666 L F
.55494 .90948 m .54289 .90914 L .54057 .91113 L .262 0 0 r
F
.55501 .90941 m .54289 .90914 L .55494 .90948 L F
.55628 .90871 m .54289 .90914 L .55551 .90942 L F
.56078 .90807 m .56688 .90641 L .55691 .90755 L F
.56137 .90815 m .56189 .90798 L .56078 .90807 L F
.56189 .90798 m .56688 .90641 L .56078 .90807 L F
.58699 .9102 m .58062 .90656 L .56484 .91333 L .789 .047 0 r
F
.56486 .90776 m .56688 .90641 L .56137 .90815 L .262 0 0 r
F
.56991 .90424 m .56031 .90449 L .55961 .90541 L .301 0 0 r
F
.58428 .90208 m .57291 .90195 L .56991 .90424 L .225 0 0 r
F
.59319 .90074 m .5853 .90121 L .58428 .90208 L F
.5853 .90121 m .57291 .90195 L .58428 .90208 L F
.5969 .89835 m .57586 .89955 L .57291 .90195 L .244 0 0 r
F
.59319 .90074 m .5969 .89835 L .58692 .89985 L .225 0 0 r
F
.5853 .90121 m .58692 .89985 L .57291 .90195 L F
.59319 .90074 m .58692 .89985 L .5853 .90121 L F
.58139 .90422 m .56991 .90424 L .56688 .90641 L .205 0 0 r
F
.58242 .90345 m .56991 .90424 L .58139 .90422 L F
.58144 .90419 m .58144 .90419 L .58161 .9043 L .69 .249 0 r
F
.58143 .90418 m .58142 .90418 L .58161 .9043 L F
.59084 .90802 m .58281 .90366 L .58166 .90433 L F
.58281 .90366 m .58258 .90353 L .58169 .9043 L F
.58281 .90366 m .58169 .9043 L .58166 .90433 L F
.58062 .90656 m .57894 .9056 L .56486 .90776 L .789 .047 0 r
F
.57894 .9056 m .58139 .90422 L .56688 .90641 L .184 0 0 r
F
.58242 .90345 m .58428 .90208 L .56991 .90424 L .205 0 0 r
F
.57894 .9056 m .56489 .89758 L .56486 .90774 L .789 .047 0 r
F
.58062 .90656 m .56486 .90776 L .56484 .91333 L F
.56484 .91333 m .56486 .90776 L .55714 .90918 L .77 .307 0 r
F
.5969 .89835 m .60055 .89585 L .57586 .89955 L .244 0 0 r
F
.58242 .90345 m .59055 .89159 L .5679 .89556 L .69 .249 0 r
F
.59084 .90802 m .59074 .90222 L .58328 .90391 L F
.61517 .89303 m .60415 .89324 L .60055 .89585 L .172 0 0 r
F
.62335 .89145 m .61647 .89209 L .61517 .89303 L F
.61647 .89209 m .60415 .89324 L .61517 .89303 L F
.61195 .90412 m .61644 .9017 L .6078 .89833 L .759 .046 0 r
F
.61195 .90412 m .60419 .89958 L .59084 .90802 L F
.60419 .89958 m .60073 .89994 L .60166 .90007 L .114 0 0 r
F
.60419 .89958 m .59074 .90222 L .59084 .90802 L .759 .046 0 r
F
.60326 .9003 m .60073 .89994 L .58944 .903 L .114 0 0 r
F
.60073 .89994 m .59319 .90074 L .59074 .90222 L F
.60073 .89994 m .59074 .90222 L .58944 .903 L F
.58763 .90268 m .59319 .90074 L .58428 .90208 L .205 0 0 r
F
.59074 .90222 m .59319 .90074 L .58763 .90268 L F
.61904 .89406 m .60055 .89585 L .5969 .89835 L .153 0 0 r
F
.60706 .89804 m .5969 .89835 L .59319 .90074 L .134 0 0 r
F
.60706 .89804 m .60837 .89723 L .60747 .89777 L .598 .181 0 r
F
.6084 .89725 m .60837 .89723 L .60706 .89804 L F
.6276 .88872 m .60769 .89052 L .60415 .89324 L .189 0 0 r
F
.6276 .88872 m .63178 .88588 L .60769 .89052 L F
.62335 .89145 m .6276 .88872 L .60415 .89324 L .172 0 0 r
F
.61904 .89406 m .62335 .89145 L .60055 .89585 L .153 0 0 r
F
.60832 .8972 m .61904 .89406 L .61061 .8957 L .134 0 0 r
F
.60832 .8972 m .61061 .8957 L .5969 .89835 L F
.60832 .8972 m .5969 .89835 L .60706 .89804 L F
.60729 .89787 m .59421 .88938 L .60703 .89803 L .598 .181 0 r
F
.60837 .89723 m .60832 .8972 L .60729 .89787 L F
.60832 .8972 m .59421 .88938 L .60729 .89787 L F
.60832 .8972 m .61567 .88461 L .59421 .88938 L F
.61644 .9017 m .61617 .89571 L .60916 .89767 L F
.63608 .89704 m .62875 .89258 L .61644 .9017 L .715 .042 0 r
F
.62875 .89258 m .62564 .89305 L .62147 .89439 L .027 0 0 r
F
.62564 .89305 m .61904 .89406 L .61617 .89571 L F
.62875 .89258 m .61617 .89571 L .61644 .9017 L .715 .042 0 r
F
.62564 .89305 m .61617 .89571 L .61467 .89656 L .027 0 0 r
F
.61617 .89571 m .61904 .89406 L .60832 .8972 L .134 0 0 r
F
.63618 .88829 m .6276 .88872 L .62335 .89145 L .064 0 0 r
F
.64391 .88638 m .63767 .88728 L .63618 .88829 L F
.63767 .88728 m .6276 .88872 L .63618 .88829 L F
.64876 .88351 m .63178 .88588 L .6276 .88872 L .082 0 0 r
F
.64391 .88638 m .64876 .88351 L .64011 .88564 L .064 0 0 r
F
.63767 .88728 m .64011 .88564 L .6276 .88872 L F
.64391 .88638 m .64011 .88564 L .63767 .88728 L F
.63201 .89086 m .62335 .89145 L .61904 .89406 L .046 0 0 r
F
.63347 .88995 m .62335 .89145 L .63201 .89086 L F
.63222 .89093 m .63207 .89083 L .63221 .89094 L .488 .103 0 r
F
.63207 .89083 m .63207 .89083 L .63221 .89094 L F
.63206 .89082 m .63205 .89082 L .63221 .89094 L F
.63221 .89094 m .63206 .89083 L .63201 .89086 L F
.63225 .89095 m .63222 .89093 L .63221 .89094 L F
.64113 .89435 m .63361 .89003 L .63225 .89095 L F
.63347 .88995 m .63618 .88829 L .62335 .89145 L .046 0 0 r
F
.63361 .89003 m .61993 .88218 L .63225 .89095 L .488 .103 0 r
F
.65824 .87744 m .63995 .87986 L .6359 .88292 L .115 0 0 r
F
.65354 .88053 m .6359 .88292 L .63178 .88588 L .099 0 0 r
F
.65354 .88053 m .65824 .87744 L .6359 .88292 L F
.64876 .88351 m .65354 .88053 L .63178 .88588 L .082 0 0 r
F
.63347 .88995 m .63976 .87661 L .61993 .88218 L .488 .103 0 r
F
.64113 .89435 m .64065 .88821 L .63427 .89041 L F
.65885 .88893 m .65211 .88458 L .64113 .89435 L .657 .036 0 r
F
.65211 .88458 m .64943 .88517 L .64536 .88672 L 0 0 0 r
F
.64943 .88517 m .64391 .88638 L .64065 .88821 L F
.65211 .88458 m .64065 .88821 L .64113 .89435 L .657 .036 0 r
F
.64943 .88517 m .64065 .88821 L .63899 .88914 L 0 0 0 r
F
.63803 .88885 m .64391 .88638 L .63618 .88829 L .046 0 0 r
F
.64065 .88821 m .64391 .88638 L .63803 .88885 L F
.66288 .87423 m .64394 .87669 L .63995 .87986 L .131 0 0 r
F
.65824 .87744 m .66288 .87423 L .63995 .87986 L .115 0 0 r
F
.66044 .87984 m .65354 .88053 L .64876 .88351 L 0 0 0 r
F
.66728 .87769 m .66212 .87876 L .66044 .87984 L F
.66212 .87876 m .65354 .88053 L .66044 .87984 L F
.66744 .87092 m .64786 .87341 L .64394 .87669 L .146 0 0 r
F
.66288 .87423 m .66744 .87092 L .64394 .87669 L .131 0 0 r
F
.65571 .88267 m .64876 .88351 L .64391 .88638 L 0 0 0 r
F
.66438 .88595 m .65746 .88176 L .65594 .88275 L .371 .067 0 r
F
.65734 .88169 m .64876 .88351 L .65571 .88267 L 0 0 0 r
F
.6726 .87454 m .65824 .87744 L .65354 .88053 L F
.65746 .88176 m .65744 .88175 L .65594 .88275 L .371 .067 0 r
F
.66212 .87876 m .66495 .87695 L .65354 .88053 L 0 0 0 r
F
.65734 .88169 m .66044 .87984 L .64876 .88351 L F
.66744 .87092 m .67192 .8675 L .64786 .87341 L .146 0 0 r
F
.67784 .87129 m .66288 .87423 L .65824 .87744 L 0 0 0 r
F
.6726 .87454 m .67784 .87129 L .65824 .87744 L F
.65734 .88169 m .66231 .8676 L .64455 .87394 L .371 .067 0 r
F
.66438 .88595 m .66367 .87972 L .65808 .88214 L F
.67971 .87981 m .67371 .8756 L .66438 .88595 L .275 .052 0 r
F
.67371 .8756 m .67157 .87629 L .66768 .87807 L 0 0 0 r
F
.67157 .87629 m .66728 .87769 L .66367 .87972 L F
.67371 .8756 m .66367 .87972 L .66438 .88595 L .275 .052 0 r
F
.67157 .87629 m .66367 .87972 L .66189 .88072 L 0 0 0 r
F
.6614 .88042 m .66728 .87769 L .66044 .87984 L F
.66367 .87972 m .66728 .87769 L .6614 .88042 L F
.66728 .87769 m .6726 .87454 L .66495 .87695 L F
.66728 .87769 m .66495 .87695 L .66212 .87876 L F
.683 .86792 m .66744 .87092 L .66288 .87423 L .003 0 0 r
F
.67784 .87129 m .683 .86792 L .66288 .87423 L 0 0 0 r
F
.68283 .87132 m .6726 .87454 L .66728 .87769 L F
.69179 .87319 m .68809 .87006 L .67971 .87981 L .515 .02 0 r
F
.67006 .87679 m .68283 .87132 L .66728 .87769 L 0 0 0 r
F
.67553 .87474 m .68283 .87132 L .67006 .87679 L F
.67431 .87602 m .67885 .87351 L .67371 .8756 L .275 .052 0 r
F
.67971 .87981 m .67885 .87351 L .67431 .87602 L F
.67696 .87454 m .67885 .87351 L .67371 .8756 L 0 0 0 r
F
.67885 .87351 m .67893 .87346 L .67371 .8756 L F
.67371 .8756 m .67553 .87474 L .67006 .87679 L F
.67893 .87346 m .68283 .87132 L .67371 .8756 L F
.69799 .85717 m .68066 .86035 L .67633 .86398 L .047 0 0 r
F
.69307 .86086 m .67633 .86398 L .67192 .8675 L .033 0 0 r
F
.69307 .86086 m .69799 .85717 L .67633 .86398 L F
.68808 .86444 m .67192 .8675 L .66744 .87092 L .018 0 0 r
F
.68808 .86444 m .69307 .86086 L .67192 .8675 L F
.683 .86792 m .68808 .86444 L .66744 .87092 L .003 0 0 r
F
.69432 .86455 m .683 .86792 L .67784 .87129 L 0 0 0 r
F
.68862 .86799 m .67784 .87129 L .6726 .87454 L F
.68862 .86799 m .69432 .86455 L .67784 .87129 L F
.68283 .87132 m .68862 .86799 L .6726 .87454 L F
.67885 .87351 m .67709 .86072 L .67371 .8756 L .275 .052 0 r
F
.69113 .86671 m .68862 .86799 L .68283 .87132 L 0 0 0 r
F
.69812 .86969 m .69303 .86568 L .69113 .86671 L .154 .033 0 r
F
.69303 .86568 m .69299 .86564 L .69113 .86671 L F
.70756 .84948 m .68909 .8528 L .68491 .85662 L .074 0 0 r
F
.70756 .84948 m .71222 .84549 L .68909 .8528 L F
.70282 .85337 m .68491 .85662 L .68066 .86035 L .061 0 0 r
F
.70282 .85337 m .70756 .84948 L .68491 .85662 L F
.69799 .85717 m .70282 .85337 L .68066 .86035 L .047 0 0 r
F
.71093 .85356 m .69799 .85717 L .69307 .86086 L 0 0 0 r
F
.70548 .85733 m .69307 .86086 L .68808 .86444 L F
.70548 .85733 m .71093 .85356 L .69307 .86086 L F
.69995 .86099 m .68808 .86444 L .683 .86792 L F
.69995 .86099 m .70548 .85733 L .68808 .86444 L F
.69394 .85099 m .68282 .85513 L .67781 .85842 L F
.69394 .85099 m .69939 .84752 L .68282 .85513 L F
.69432 .86455 m .69995 .86099 L .683 .86792 L F
.68841 .85435 m .67781 .85842 L .67272 .86159 L F
.68841 .85435 m .69394 .85099 L .67781 .85842 L F
.68279 .8576 m .68841 .85435 L .67272 .86159 L F
.70658 .84306 m .69939 .84752 L .69394 .85099 L F
.69939 .84752 m .68775 .85173 L .68282 .85513 L F
.69939 .84752 m .70475 .84393 L .68775 .85173 L F
.70069 .84663 m .69394 .85099 L .68841 .85435 L .382 .193 0 r
F
.70069 .84663 m .70658 .84306 L .69394 .85099 L F
.70738 .85732 m .69995 .86099 L .69432 .86455 L 0 0 0 r
F
.69471 .85009 m .68841 .85435 L .68279 .8576 L .392 .196 0 r
F
.69471 .85009 m .70069 .84663 L .68841 .85435 L F
.69723 .86322 m .69432 .86455 L .68862 .86799 L 0 0 0 r
F
.70128 .86097 m .69908 .8621 L .69723 .86322 L F
.69908 .8621 m .69432 .86455 L .69723 .86322 L F
.69179 .87319 m .69812 .86969 L .69131 .86678 L .515 .02 0 r
F
.68688 .86903 m .69113 .86671 L .68283 .87132 L .346 .189 0 r
F
.69299 .86564 m .68862 .86799 L .69113 .86671 L 0 0 0 r
F
.68688 .86903 m .69113 .86671 L .69112 .86671 L .515 .02 0 r
F
.70697 .86247 m .70408 .85954 L .69812 .86969 L 0 .005 0 r
F
.69398 .86507 m .70128 .86097 L .69687 .86342 L 0 0 0 r
F
.69462 .86472 m .70128 .86097 L .69398 .86507 L F
.69702 .86341 m .70128 .86097 L .69299 .86564 L F
.71629 .84968 m .70282 .85337 L .69799 .85717 L F
.71093 .85356 m .71629 .84968 L .69799 .85717 L F
.71339 .85355 m .70548 .85733 L .69995 .86099 L F
.70738 .85732 m .71339 .85355 L .69995 .86099 L F
.70128 .86097 m .70738 .85732 L .69432 .86455 L F
.71931 .84968 m .71093 .85356 L .70548 .85733 L F
.71339 .85355 m .71931 .84968 L .70548 .85733 L F
.7103 .85358 m .70738 .85732 L .70128 .86097 L .476 .209 0 r
F
.70302 .85848 m .69471 .85009 L .69702 .86341 L 0 .005 0 r
F
.69299 .86564 m .69687 .86342 L .68862 .86799 L 0 0 0 r
F
.69299 .86564 m .69462 .86472 L .69398 .86507 L F
.69702 .86341 m .69471 .85009 L .69299 .86564 L .154 .033 0 r
F
.72157 .8457 m .70756 .84948 L .70282 .85337 L 0 0 0 r
F
.71629 .84968 m .72157 .8457 L .70282 .85337 L F
.71004 .84024 m .69738 .84461 L .69261 .84822 L F
.71004 .84024 m .71523 .83645 L .69738 .84461 L F
.70475 .84393 m .69261 .84822 L .68775 .85173 L F
.70475 .84393 m .71004 .84024 L .69261 .84822 L F
.71239 .83938 m .70475 .84393 L .69939 .84752 L F
.70658 .84306 m .71239 .83938 L .69939 .84752 L F
.71523 .83645 m .70207 .8409 L .69738 .84461 L F
.71811 .83558 m .71004 .84024 L .70475 .84393 L F
.71239 .83938 m .71811 .83558 L .70475 .84393 L F
.70931 .83857 m .70658 .84306 L .70069 .84663 L .524 .216 0 r
F
.70305 .84226 m .70069 .84663 L .69471 .85009 L .526 .218 0 r
F
.70305 .84226 m .70931 .83857 L .70069 .84663 L F
.70302 .85848 m .70305 .84226 L .69471 .85009 L 0 .005 0 r
F
.70208 .85982 m .7103 .85358 L .70128 .86097 L .479 .211 0 r
F
.70302 .85848 m .70439 .85755 L .70208 .85982 L F
.70439 .85755 m .7103 .85358 L .70208 .85982 L F
.70576 .85621 m .7103 .85358 L .70302 .85848 L F
.72514 .8457 m .71629 .84968 L .71093 .85356 L 0 0 0 r
F
.71931 .84968 m .72514 .8457 L .71093 .85356 L F
.7167 .8497 m .71339 .85355 L .70738 .85732 L .473 .208 0 r
F
.7103 .85358 m .7167 .8497 L .70738 .85732 L .476 .209 0 r
F
.72675 .84162 m .71222 .84549 L .70756 .84948 L 0 0 0 r
F
.72157 .8457 m .72675 .84162 L .70756 .84948 L F
.73088 .84161 m .72157 .8457 L .71629 .84968 L F
.72514 .8457 m .73088 .84161 L .71629 .84968 L F
.71542 .84592 m .7167 .8497 L .7103 .85358 L .601 .264 0 r
F
.7092 .85103 m .70305 .84226 L .70576 .85621 L 0 0 0 r
F
.70576 .85621 m .70305 .84226 L .70302 .85848 L 0 .005 0 r
F
.70668 .83709 m .68851 .8411 L .68444 .84485 L .043 0 0 r
F
.70668 .83709 m .71121 .83317 L .68851 .8411 L F
.70207 .8409 m .70668 .83709 L .68444 .84485 L .028 0 0 r
F
.72535 .82854 m .71121 .83317 L .70668 .83709 L 0 0 0 r
F
.72034 .83254 m .70668 .83709 L .70207 .8409 L F
.72034 .83254 m .72535 .82854 L .70668 .83709 L F
.71523 .83645 m .72034 .83254 L .70207 .8409 L F
.72374 .83168 m .71523 .83645 L .71004 .84024 L F
.71811 .83558 m .72374 .83168 L .71004 .84024 L F
.71547 .83476 m .71239 .83938 L .70658 .84306 L .522 .215 0 r
F
.70931 .83857 m .71547 .83476 L .70658 .84306 L .524 .216 0 r
F
.70764 .83427 m .70931 .83857 L .70305 .84226 L .634 .383 0 r
F
.7092 .85103 m .70764 .83427 L .70305 .84226 L 0 0 0 r
F
.70976 .85233 m .71542 .84592 L .7103 .85358 L .598 .285 0 r
F
.7092 .85103 m .71033 .8501 L .70976 .85233 L F
.71033 .8501 m .71542 .84592 L .70976 .85233 L F
.71067 .84877 m .71542 .84592 L .7092 .85103 L F
.73028 .82444 m .71565 .82916 L .71121 .83317 L 0 0 0 r
F
.72535 .82854 m .73028 .82444 L .71121 .83317 L F
.71407 .83032 m .71547 .83476 L .70931 .83857 L .639 .363 0 r
F
.70764 .83427 m .71407 .83032 L .70931 .83857 L .634 .383 0 r
F
.71132 .84342 m .70764 .83427 L .71067 .84877 L 0 0 0 r
F
.71067 .84877 m .70764 .83427 L .7092 .85103 L F
.70966 .8424 m .71132 .84342 L .70873 .84993 L .687 .601 0 r
F
.73184 .83743 m .7168 .8414 L .71222 .84549 L 0 0 0 r
F
.72675 .84162 m .73184 .83743 L .71222 .84549 L F
.70832 .82628 m .71407 .83032 L .7112 .83208 L .729 .674 0 r
F
.70832 .82628 m .7112 .83208 L .70764 .83427 L F
.71132 .84342 m .70832 .82628 L .70764 .83427 L 0 0 0 r
F
.70646 .83487 m .70923 .83577 L .70966 .8424 L .83 .857 0 r
F
.71132 .84342 m .71222 .84249 L .71333 .84465 L .687 .601 0 r
F
.71156 .84122 m .70832 .82628 L .71132 .84342 L 0 0 0 r
F
.70966 .8424 m .71156 .84121 L .71132 .84342 L .687 .601 0 r
F
.71156 .84121 m .71645 .83813 L .71132 .84342 L F
.71156 .84122 m .71156 .84122 L .71132 .84342 L 0 0 0 r
F
.71156 .84121 m .70832 .82628 L .71156 .84122 L F
.70923 .83577 m .70832 .82628 L .71156 .84121 L .78 .121 0 r
F
.70923 .83577 m .71159 .84119 L .71156 .84121 L .83 .857 0 r
F
.70923 .83577 m .71156 .84121 L .70966 .8424 L F
.70934 .83688 m .70923 .83577 L .71156 .84121 L .78 .121 0 r
F
.71132 .84342 m .71542 .84592 L .71075 .84873 L .687 .601 0 r
F
.71288 .84729 m .71156 .84121 L .71132 .84342 L 0 0 0 r
F
.71132 .84342 m .71075 .84873 L .71067 .84877 L .687 .601 0 r
F
.71132 .84342 m .71067 .84877 L .70873 .84993 L F
.71176 .8445 m .71132 .84342 L .71067 .84877 L 0 0 0 r
F
.71288 .84729 m .71176 .8445 L .71196 .85496 L F
.71176 .8445 m .71067 .84877 L .71196 .85496 L F
.7096 .83959 m .70934 .83688 L .71288 .84729 L .78 .121 0 r
F
.71156 .84121 m .71156 .84121 L .71156 .84122 L 0 0 0 r
F
.70934 .83688 m .71156 .84121 L .71288 .84729 L .78 .121 0 r
F
.71333 .84465 m .71645 .83813 L .71542 .84592 L .687 .601 0 r
F
.71222 .84249 m .71645 .83813 L .71333 .84465 L F
.71157 .84113 m .71645 .83813 L .71159 .84119 L .83 .857 0 r
F
.70923 .83577 m .71173 .83659 L .71157 .84113 L F
.72928 .82766 m .72034 .83254 L .71523 .83645 L 0 0 0 r
F
.72374 .83168 m .72928 .82766 L .71523 .83645 L F
.72155 .83084 m .71811 .83558 L .71239 .83938 L .519 .214 0 r
F
.71547 .83476 m .72155 .83084 L .71239 .83938 L .522 .215 0 r
F
.71173 .83659 m .71645 .83813 L .71157 .84113 L .83 .857 0 r
F
.70923 .83577 m .70543 .82043 L .70832 .82628 L .78 .121 0 r
F
.70923 .83577 m .71322 .83032 L .71645 .83813 L .83 .857 0 r
F
.70646 .83487 m .7083 .83363 L .70923 .83577 L F
.7083 .83363 m .70543 .82043 L .70923 .83577 L .78 .121 0 r
F
.7083 .83363 m .71322 .83032 L .70923 .83577 L .83 .857 0 r
F
.7083 .83364 m .7083 .83363 L .70923 .83577 L .78 .121 0 r
F
.7096 .83959 m .7083 .83364 L .70923 .83577 L F
.70543 .82043 m .70499 .81842 L .70832 .82628 L F
.71196 .85496 m .71067 .84877 L .7092 .85103 L 0 0 0 r
F
.70873 .84993 m .71067 .84877 L .7092 .85103 L .598 .285 0 r
F
.70873 .84993 m .7092 .85103 L .70381 .85734 L F
.7092 .85103 m .7103 .85358 L .70576 .85621 L F
.7092 .85103 m .70576 .85621 L .70381 .85734 L F
.70995 .8521 m .7092 .85103 L .70576 .85621 L 0 0 0 r
F
.71196 .85496 m .70995 .8521 L .70697 .86247 L F
.70995 .8521 m .70576 .85621 L .70697 .86247 L F
.70697 .86247 m .70576 .85621 L .70302 .85848 L 0 .005 0 r
F
.70381 .85734 m .70576 .85621 L .70302 .85848 L .479 .211 0 r
F
.70381 .85734 m .70302 .85848 L .6951 .86451 L F
.70302 .85848 m .70128 .86097 L .69702 .86341 L F
.70302 .85848 m .69702 .86341 L .6951 .86451 L F
.70408 .85954 m .70302 .85848 L .69702 .86341 L 0 .005 0 r
F
.70408 .85954 m .69702 .86341 L .69812 .86969 L F
.69113 .86671 m .68279 .8576 L .67709 .86072 L .154 .033 0 r
F
.69113 .86671 m .69113 .86671 L .69113 .86671 L F
.69113 .86671 m .68279 .8576 L .69113 .86671 L F
.69299 .86564 m .69471 .85009 L .68279 .8576 L F
.69812 .86969 m .69702 .86341 L .69299 .86564 L F
.6951 .86451 m .69702 .86341 L .69299 .86564 L 0 0 0 r
F
.68688 .86903 m .69112 .86671 L .67709 .86072 L .515 .02 0 r
F
.68688 .86903 m .67709 .86072 L .67885 .87351 L F
.68486 .87014 m .68688 .86903 L .67696 .87454 L .346 .189 0 r
F
.68883 .86793 m .68688 .86903 L .68486 .87014 L F
.687 .86896 m .69113 .86671 L .68688 .86903 L F
.68717 .86928 m .69131 .86678 L .69113 .86671 L .515 .02 0 r
F
.68717 .86928 m .69113 .86671 L .68688 .86903 L F
.69179 .87319 m .69131 .86678 L .68717 .86928 L F
.6951 .86451 m .69299 .86564 L .69113 .86671 L 0 0 0 r
F
.69299 .86564 m .68279 .8576 L .69113 .86671 L .154 .033 0 r
F
.68883 .86793 m .6951 .86451 L .69113 .86671 L .346 .189 0 r
F
.68883 .86793 m .69113 .86671 L .687 .86896 L F
.68688 .86903 m .68554 .86979 L .682 .87175 L F
.68554 .86979 m .68283 .87132 L .67885 .87351 L F
.68809 .87006 m .68688 .86903 L .67885 .87351 L .515 .02 0 r
F
.68688 .86903 m .682 .87175 L .67696 .87454 L .346 .189 0 r
F
.68554 .86979 m .67885 .87351 L .67696 .87454 L F
.67371 .8756 m .67709 .86072 L .66231 .8676 L .275 .052 0 r
F
.68809 .87006 m .67885 .87351 L .67971 .87981 L .515 .02 0 r
F
.67371 .8756 m .66231 .8676 L .66367 .87971 L .275 .052 0 r
F
.67371 .8756 m .66367 .87971 L .66367 .87972 L F
.67696 .87454 m .67371 .8756 L .66189 .88072 L 0 0 0 r
F
.67371 .8756 m .66768 .87807 L .66189 .88072 L F
.65808 .88214 m .66367 .87972 L .65734 .88169 L .371 .067 0 r
F
.66189 .88072 m .66044 .87984 L .65734 .88169 L 0 0 0 r
F
.66367 .87972 m .66231 .8676 L .65734 .88169 L .371 .067 0 r
F
.66189 .88072 m .66367 .87972 L .6614 .88042 L 0 0 0 r
F
.65594 .88275 m .65578 .88263 L .65571 .88267 L .371 .067 0 r
F
.65885 .88893 m .66438 .88595 L .65593 .88275 L .657 .036 0 r
F
.65885 .88893 m .65593 .88275 L .65579 .88282 L F
.65885 .88893 m .65571 .88267 L .65211 .88458 L F
.65087 .88643 m .65642 .88364 L .65024 .88559 L 0 0 0 r
F
.64658 .88741 m .65024 .88559 L .63899 .88914 L F
.65087 .88643 m .65024 .88559 L .64658 .88741 L F
.65579 .88282 m .65593 .88275 L .65571 .88267 L .657 .036 0 r
F
.65211 .88458 m .65571 .88267 L .64391 .88638 L 0 0 0 r
F
.65211 .88458 m .65571 .88267 L .63976 .87661 L .657 .036 0 r
F
.65235 .88453 m .65571 .88267 L .65211 .88458 L 0 0 0 r
F
.65642 .88364 m .66189 .88072 L .65571 .88267 L F
.65642 .88364 m .65571 .88267 L .65235 .88453 L F
.65744 .88175 m .6574 .88173 L .65591 .88273 L .371 .067 0 r
F
.6574 .88173 m .65734 .88169 L .65691 .882 L F
.6574 .88173 m .65691 .882 L .65591 .88273 L F
.65734 .88169 m .64455 .87394 L .65577 .88262 L F
.65734 .88169 m .65577 .88262 L .65591 .88273 L F
.65744 .88175 m .65591 .88273 L .65594 .88275 L F
.66189 .88072 m .65734 .88169 L .65571 .88267 L 0 0 0 r
F
.65571 .88267 m .64455 .87394 L .63976 .87661 L .371 .067 0 r
F
.65578 .88263 m .64455 .87394 L .65571 .88267 L F
.65211 .88458 m .63976 .87661 L .64065 .88821 L .657 .036 0 r
F
.65642 .88364 m .65211 .88458 L .63899 .88914 L 0 0 0 r
F
.65211 .88458 m .64536 .88672 L .63899 .88914 L F
.63427 .89041 m .64065 .88821 L .63347 .88995 L .488 .103 0 r
F
.63899 .88914 m .63618 .88829 L .63347 .88995 L .046 0 0 r
F
.64065 .88821 m .63976 .87661 L .63347 .88995 L .488 .103 0 r
F
.63899 .88914 m .64065 .88821 L .63803 .88885 L .046 0 0 r
F
.63608 .89704 m .64113 .89435 L .63224 .89095 L .715 .042 0 r
F
.63608 .89704 m .63224 .89095 L .63211 .89102 L F
.63608 .89704 m .63201 .89086 L .62875 .89258 L F
.62895 .89429 m .634 .89177 L .62702 .8935 L .007 0 0 r
F
.6237 .89513 m .62702 .8935 L .61467 .89656 L F
.62895 .89429 m .62702 .8935 L .6237 .89513 L F
.63211 .89102 m .63224 .89095 L .63201 .89086 L .715 .042 0 r
F
.62875 .89258 m .63201 .89086 L .61904 .89406 L .027 0 0 r
F
.62875 .89258 m .63201 .89086 L .61567 .88461 L .715 .042 0 r
F
.62905 .89253 m .63201 .89086 L .62875 .89258 L .027 0 0 r
F
.634 .89177 m .63899 .88914 L .63201 .89086 L F
.634 .89177 m .63201 .89086 L .62905 .89253 L F
.63207 .89083 m .63206 .89082 L .63207 .89083 L .488 .103 0 r
F
.63206 .89082 m .61993 .88218 L .63205 .89082 L F
.63899 .88914 m .63347 .88995 L .63201 .89086 L .046 0 0 r
F
.63201 .89086 m .61993 .88218 L .61567 .88461 L .488 .103 0 r
F
.63206 .89083 m .61993 .88218 L .63201 .89086 L F
.62875 .89258 m .61567 .88461 L .61617 .89571 L .715 .042 0 r
F
.634 .89177 m .62875 .89258 L .61467 .89656 L .027 0 0 r
F
.62875 .89258 m .62147 .89439 L .61467 .89656 L F
.60916 .89767 m .61617 .89571 L .60832 .8972 L .598 .181 0 r
F
.61617 .89571 m .61567 .88461 L .60832 .8972 L F
.61467 .89656 m .61617 .89571 L .60832 .8972 L .134 0 0 r
F
.6085 .89718 m .60832 .8972 L .60706 .89804 L F
.60706 .89804 m .60747 .89777 L .60703 .89803 L .598 .181 0 r
F
.61644 .9017 m .60868 .8974 L .60731 .89814 L F
.60522 .90018 m .6078 .89833 L .60706 .89804 L .759 .046 0 r
F
.60522 .90018 m .60706 .89804 L .60699 .89808 L F
.60522 .90018 m .607 .89808 L .60419 .89958 L F
.60419 .89958 m .60706 .89804 L .59319 .90074 L .114 0 0 r
F
.607 .89808 m .60703 .89803 L .60419 .89958 L .759 .046 0 r
F
.60452 .89954 m .60706 .89804 L .60419 .89958 L .114 0 0 r
F
.61195 .90412 m .6078 .89833 L .60522 .90018 L .759 .046 0 r
F
.60574 .9012 m .61024 .89894 L .60326 .9003 L .093 0 0 r
F
.60049 .90178 m .60326 .9003 L .58944 .903 L F
.60574 .9012 m .60326 .9003 L .60049 .90178 L F
.60731 .89814 m .6084 .89725 L .60706 .89804 L .598 .181 0 r
F
.60868 .8974 m .6084 .89725 L .60731 .89814 L F
.61024 .89894 m .61467 .89656 L .60706 .89804 L .114 0 0 r
F
.61024 .89894 m .60706 .89804 L .60452 .89954 L F
.61467 .89656 m .6085 .89718 L .60706 .89804 L .134 0 0 r
F
.60699 .89808 m .60706 .89804 L .60703 .89803 L .759 .046 0 r
F
.60419 .89958 m .59055 .89159 L .59074 .90222 L F
.60419 .89958 m .60166 .90007 L .60294 .90026 L .114 0 0 r
F
.60452 .89954 m .60419 .89958 L .60326 .9003 L F
.60419 .89958 m .60294 .90026 L .60326 .9003 L F
.60419 .89958 m .60703 .89803 L .59055 .89159 L .759 .046 0 r
F
.60703 .89803 m .59421 .88938 L .59055 .89159 L .598 .181 0 r
F
.61024 .89894 m .60452 .89954 L .60326 .9003 L .114 0 0 r
F
.58328 .90391 m .59074 .90222 L .58242 .90345 L .69 .249 0 r
F
.58944 .903 m .58428 .90208 L .58242 .90345 L .205 0 0 r
F
.59074 .90222 m .59055 .89159 L .58242 .90345 L .69 .249 0 r
F
.58944 .903 m .59074 .90222 L .58763 .90268 L .205 0 0 r
F
.58699 .9102 m .59084 .90802 L .58136 .90421 L .789 .047 0 r
F
.57894 .9056 m .58136 .90421 L .56489 .89758 L F
.57354 .90843 m .56379 .90847 L .56067 .9104 L .162 0 0 r
F
.57931 .90581 m .58149 .90434 L .57898 .90563 L .789 .047 0 r
F
.58699 .9102 m .58181 .90468 L .57931 .90581 L F
.58181 .90468 m .58149 .90434 L .57931 .90581 L F
.57785 .90908 m .58177 .90717 L .57354 .90843 L .139 0 0 r
F
.57095 .90961 m .57354 .90843 L .56067 .9104 L F
.57785 .90908 m .57354 .90843 L .57095 .90961 L F
.58177 .90717 m .57505 .90766 L .57354 .90843 L .162 0 0 r
F
.57505 .90766 m .56379 .90847 L .57354 .90843 L F
.57898 .90563 m .58136 .90421 L .57894 .9056 L .789 .047 0 r
F
.58149 .90434 m .58136 .90421 L .57898 .90563 L F
.5776 .90637 m .57522 .90585 L .56379 .90847 L .184 0 0 r
F
.58563 .90515 m .57894 .9056 L .5776 .90637 L F
.57894 .9056 m .57522 .90585 L .5776 .90637 L F
.57522 .90585 m .56688 .90641 L .56486 .90776 L F
.57522 .90585 m .56486 .90776 L .56379 .90847 L F
.55714 .90918 m .56486 .90776 L .55628 .90871 L .77 .307 0 r
F
.57894 .9056 m .56486 .90774 L .56486 .90776 L .789 .047 0 r
F
.5793 .90557 m .57936 .90554 L .57894 .9056 L .184 0 0 r
F
.57936 .90554 m .58139 .90422 L .57894 .9056 L F
.58177 .90717 m .58563 .90515 L .57825 .90627 L .162 0 0 r
F
.57593 .90759 m .57825 .90627 L .56379 .90847 L F
.58177 .90717 m .57825 .90627 L .57593 .90759 L F
.58258 .90353 m .5679 .89556 L .58166 .90433 L .69 .249 0 r
F
.58563 .90515 m .58944 .903 L .58139 .90422 L .184 0 0 r
F
.58162 .9043 m .58144 .90419 L .58161 .9043 L .69 .249 0 r
F
.58161 .9043 m .58143 .90419 L .58139 .90422 L F
.58166 .90433 m .58162 .9043 L .58161 .9043 L F
.58563 .90515 m .58139 .90422 L .5793 .90557 L .184 0 0 r
F
.58144 .90419 m .58143 .90418 L .58144 .90419 L .69 .249 0 r
F
.58143 .90418 m .5679 .89556 L .58142 .90418 L F
.58944 .903 m .58242 .90345 L .58139 .90422 L .205 0 0 r
F
.58139 .90422 m .5679 .89556 L .56489 .89758 L .69 .249 0 r
F
.58143 .90419 m .5679 .89556 L .58139 .90422 L F
.55569 .90873 m .55691 .90755 L .54289 .90914 L .262 0 0 r
F
.55628 .90871 m .55691 .90755 L .55569 .90873 L F
.56379 .90847 m .5575 .90763 L .55628 .90871 L F
.5575 .90763 m .55691 .90755 L .55628 .90871 L F
.55686 .90902 m .55637 .90876 L .5563 .90975 L .77 .307 0 r
F
.55637 .90876 m .55628 .90883 L .5563 .90975 L F
.55628 .90871 m .55559 .90932 L .5563 .90975 L F
.55573 .9095 m .54149 .90073 L .55573 .90951 L F
.55583 .90948 m .54149 .90073 L .55578 .90953 L F
.55622 .9097 m .54149 .90073 L .55621 .90971 L F
.56484 .91333 m .55686 .90902 L .5563 .90975 L F
.56067 .9104 m .56379 .90847 L .55551 .90942 L .24 0 0 r
F
.5535 .91066 m .55494 .90948 L .54057 .91113 L F
.55272 .91132 m .54057 .91113 L .53822 .91299 L F
.5535 .91066 m .54057 .91113 L .55272 .91132 L F
.55294 .91141 m .55276 .91129 L .55293 .91141 L .799 .046 0 r
F
.55276 .91129 m .5392 .90258 L .55275 .9113 L F
.55276 .91129 m .55275 .9113 L .55293 .91141 L F
.56168 .91528 m .55389 .91089 L .55298 .91144 L F
.55389 .91089 m .55367 .91076 L .55301 .91141 L F
.55389 .91089 m .55301 .91141 L .55298 .91144 L F
.56168 .91528 m .56484 .91333 L .55551 .90942 L F
.55434 .91014 m .55551 .90942 L .55494 .90948 L .24 0 0 r
F
.55388 .91065 m .55494 .90948 L .5535 .91066 L F
.55551 .90942 m .55501 .90941 L .55494 .90948 L .262 0 0 r
F
.5535 .91066 m .55551 .90942 L .5392 .90258 L .799 .046 0 r
F
.54057 .91113 m .51783 .91116 L .51629 .9131 L .326 0 0 r
F
.54057 .91113 m .54289 .90914 L .51783 .91116 L F
.5293 .91372 m .51629 .9131 L .51474 .91492 L .305 0 0 r
F
.53822 .91299 m .52976 .91303 L .5293 .91372 L F
.52976 .91303 m .51629 .9131 L .5293 .91372 L F
.53822 .91299 m .54057 .91113 L .53051 .91194 L F
.52976 .91303 m .53051 .91194 L .51629 .9131 L F
.53822 .91299 m .53051 .91194 L .52976 .91303 L F
.52725 .91545 m .51474 .91492 L .51316 .91661 L .283 0 0 r
F
.5273 .91538 m .51474 .91492 L .52725 .91545 L F
.52835 .9148 m .51474 .91492 L .52784 .9154 L F
.51629 .9131 m .51783 .91116 L .49204 .91244 L .379 0 0 r
F
.53272 .91434 m .53822 .91299 L .5285 .91379 L .283 0 0 r
F
.53328 .91441 m .53371 .91429 L .53272 .91434 L F
.53371 .91429 m .53822 .91299 L .53272 .91434 L F
.55848 .91711 m .55216 .91337 L .53652 .91942 L .804 .047 0 r
F
.53665 .91414 m .53822 .91299 L .53328 .91441 L .283 0 0 r
F
.55216 .91337 m .55067 .91249 L .53665 .91414 L .804 .047 0 r
F
.55216 .91337 m .53665 .91414 L .53652 .91942 L F
.53652 .91942 m .53665 .91414 L .52911 .91523 L .838 .348 0 r
F
.54904 .9132 m .54526 .91313 L .53583 .91474 L .217 0 0 r
F
.54526 .91313 m .54384 .9131 L .5416 .91356 L F
.54526 .91313 m .5416 .91356 L .53583 .91474 L F
.54384 .9131 m .53822 .91299 L .53665 .91414 L F
.54384 .9131 m .53665 .91414 L .53583 .91474 L F
.56168 .91528 m .55563 .90953 L .55355 .91069 L .799 .046 0 r
F
.54957 .91314 m .55029 .91251 L .54904 .9132 L .217 0 0 r
F
.55848 .91711 m .56168 .91528 L .55272 .91132 L .804 .047 0 r
F
.55271 .91133 m .55272 .91132 L .55269 .91131 L F
.55848 .91711 m .55272 .91132 L .55271 .91133 L F
.55067 .91249 m .55272 .91132 L .53822 .91299 L .217 0 0 r
F
.55072 .91252 m .55269 .91131 L .55067 .91249 L .804 .047 0 r
F
.55848 .91711 m .55317 .91179 L .55105 .91272 L F
.55105 .91547 m .55429 .9139 L .54617 .91486 L .167 0 0 r
F
.54397 .91582 m .54617 .91486 L .53341 .91636 L F
.55105 .91547 m .54617 .91486 L .54397 .91582 L F
.55105 .91272 m .55282 .91144 L .55072 .91252 L .804 .047 0 r
F
.55317 .91179 m .55282 .91144 L .55105 .91272 L F
.55282 .91144 m .55269 .91131 L .55072 .91252 L F
.54617 .91486 m .53583 .91474 L .53341 .91636 L .193 0 0 r
F
.55429 .9139 m .54742 .91421 L .54617 .91486 L F
.54742 .91421 m .53583 .91474 L .54617 .91486 L F
.55106 .91248 m .55272 .91132 L .55067 .91249 L .217 0 0 r
F
.5575 .91221 m .55067 .91249 L .54957 .91314 L F
.55067 .91249 m .55029 .91251 L .54957 .91314 L F
.55067 .91249 m .55269 .91131 L .53688 .90432 L .804 .047 0 r
F
.55029 .91251 m .53822 .91299 L .54904 .9132 L .217 0 0 r
F
.55067 .91249 m .53688 .90432 L .53665 .91414 L .804 .047 0 r
F
.52772 .91481 m .5285 .91379 L .51474 .91492 L .283 0 0 r
F
.52911 .91523 m .52948 .91471 L .52835 .9148 L .838 .348 0 r
F
.52835 .9148 m .5285 .91379 L .52772 .91481 L .283 0 0 r
F
.53328 .91441 m .52917 .91388 L .52835 .9148 L F
.53665 .91414 m .53688 .90432 L .52948 .91471 L .838 .348 0 r
F
.53665 .91414 m .52948 .91471 L .52911 .91523 L F
.53583 .91474 m .53328 .91441 L .52835 .9148 L .283 0 0 r
F
.52917 .91388 m .5285 .91379 L .52835 .9148 L F
.52806 .91549 m .51391 .90666 L .52805 .9155 L .838 .348 0 r
F
.53652 .91942 m .52852 .9149 L .52811 .91552 L F
.53341 .91636 m .53583 .91474 L .52784 .9154 L .259 0 0 r
F
.52628 .91645 m .52725 .91545 L .51316 .91661 L F
.52576 .917 m .51316 .91661 L .51157 .91819 L F
.52628 .91645 m .51316 .91661 L .52576 .917 L F
.52597 .91709 m .52579 .91698 L .52597 .9171 L .784 .043 0 r
F
.52579 .91698 m .51236 .90824 L .52579 .91698 L F
.52579 .91698 m .52579 .91698 L .52597 .9171 L F
.53408 .92105 m .52645 .91655 L .52602 .91713 L F
.52645 .91655 m .51236 .90824 L .52602 .91713 L F
.49131 .91435 m .49204 .91244 L .46589 .91296 L .423 0 0 r
F
.51629 .9131 m .49204 .91244 L .49131 .91435 L .379 0 0 r
F
.51474 .91492 m .49131 .91435 L .49057 .91615 L .359 0 0 r
F
.51474 .91492 m .51629 .9131 L .49131 .91435 L F
.51316 .91661 m .49057 .91615 L .48982 .91782 L .337 0 0 r
F
.51316 .91661 m .51474 .91492 L .49057 .91615 L F
.50311 .91864 m .48982 .91782 L .48907 .91938 L .314 0 0 r
F
.51157 .91819 m .50328 .91805 L .50311 .91864 L F
.50328 .91805 m .48982 .91782 L .50311 .91864 L F
.49131 .91435 m .46589 .91296 L .46597 .91488 L .423 0 0 r
F
.49057 .91615 m .49131 .91435 L .46597 .91488 L .403 0 0 r
F
.51157 .91819 m .51316 .91661 L .50357 .91711 L .314 0 0 r
F
.50328 .91805 m .50357 .91711 L .48982 .91782 L F
.51157 .91819 m .50357 .91711 L .50328 .91805 L F
.50184 .92008 m .48907 .91938 L .4883 .92081 L .289 0 0 r
F
.50186 .92002 m .48907 .91938 L .50184 .92008 L F
.50265 .91955 m .48907 .91938 L .50242 .92005 L F
.50682 .91925 m .51157 .91819 L .50232 .91868 L F
.50734 .91931 m .50767 .91922 L .50682 .91925 L F
.50767 .91922 m .51157 .91819 L .50682 .91925 L F
.53161 .92256 m .52547 .91877 L .51034 .9241 L .784 .042 0 r
F
.51049 .91915 m .51157 .91819 L .50734 .91931 L .289 0 0 r
F
.52547 .91877 m .52418 .91797 L .51049 .91915 L .784 .042 0 r
F
.52547 .91877 m .51049 .91915 L .51034 .9241 L F
.51034 .9241 m .51049 .91915 L .50331 .91994 L .899 .381 0 r
F
.52281 .91855 m .51893 .91842 L .50995 .91964 L .233 0 0 r
F
.51893 .91842 m .51754 .91838 L .51549 .91872 L F
.51893 .91842 m .51549 .91872 L .50995 .91964 L F
.51754 .91838 m .51157 .91819 L .51049 .91915 L F
.51754 .91838 m .51049 .91915 L .50995 .91964 L F
.52377 .91798 m .51157 .91819 L .52281 .91855 L F
.52418 .91797 m .52576 .917 L .51157 .91819 L F
.52068 .9199 m .50995 .91964 L .50831 .92097 L .206 0 0 r
F
.53161 .92256 m .53408 .92105 L .52601 .91712 L .784 .042 0 r
F
.52599 .91714 m .52601 .91712 L .52593 .91708 L F
.53161 .92256 m .52601 .91712 L .52599 .91714 L F
.53161 .92256 m .52593 .91708 L .52587 .91711 L F
.53161 .92256 m .52573 .91698 L .52418 .91797 L F
.53408 .92105 m .53652 .91942 L .52801 .91548 L .784 .043 0 r
F
.53408 .92105 m .52801 .91548 L .52796 .91551 L F
.53408 .92105 m .52784 .9154 L .52628 .91645 L F
.52849 .91923 m .53097 .91785 L .52334 .9185 L .206 0 0 r
F
.52165 .91938 m .52334 .9185 L .50995 .91964 L F
.52849 .91923 m .52334 .9185 L .52165 .91938 L F
.52849 .91923 m .52165 .91938 L .52068 .9199 L F
.52165 .91938 m .50995 .91964 L .52068 .9199 L F
.52587 .91711 m .52593 .91708 L .52573 .91698 L .784 .042 0 r
F
.52418 .91797 m .52573 .91698 L .51079 .90971 L F
.52334 .9185 m .52377 .91798 L .52281 .91855 L .233 0 0 r
F
.53097 .91785 m .52418 .91797 L .52334 .9185 L F
.52418 .91797 m .52377 .91798 L .52334 .9185 L F
.52459 .91797 m .52462 .91793 L .52418 .91797 L F
.52462 .91793 m .52576 .917 L .52418 .91797 L F
.52418 .91797 m .51079 .90971 L .5105 .91913 L .784 .042 0 r
F
.52418 .91797 m .5105 .91913 L .51049 .91915 L F
.50201 .91954 m .50232 .91868 L .48907 .91938 L .289 0 0 r
F
.50331 .91994 m .50363 .9195 L .50265 .91955 L .899 .381 0 r
F
.50265 .91955 m .50232 .91868 L .50201 .91954 L .289 0 0 r
F
.50734 .91931 m .50305 .91877 L .50265 .91955 L F
.51049 .91915 m .51079 .90971 L .50363 .9195 L .899 .381 0 r
F
.51049 .91915 m .50363 .9195 L .50331 .91994 L F
.50995 .91964 m .50734 .91931 L .50265 .91955 L .289 0 0 r
F
.50305 .91877 m .50232 .91868 L .50265 .91955 L F
.50263 .92015 m .48874 .91131 L .50263 .92015 L .899 .381 0 r
F
.51034 .9241 m .50283 .91965 L .50268 .92018 L F
.50831 .92097 m .50995 .91964 L .50242 .92005 L .262 0 0 r
F
.50136 .92091 m .50184 .92008 L .4883 .92081 L F
.50112 .92136 m .4883 .92081 L .48752 .92211 L F
.50869 .92543 m .50153 .92102 L .50138 .9215 L .72 .033 0 r
F
.50136 .92091 m .4883 .92081 L .50112 .92136 L .262 0 0 r
F
.50153 .92102 m .50145 .92097 L .50138 .9215 L .72 .033 0 r
F
.50145 .92097 m .48799 .91266 L .50114 .92134 L F
.50145 .92097 m .50114 .92134 L .50138 .9215 L F
.49057 .91615 m .46597 .91488 L .46606 .91668 L .403 0 0 r
F
.48982 .91782 m .46606 .91668 L .46615 .91835 L .381 0 0 r
F
.48982 .91782 m .49057 .91615 L .46606 .91668 L F
.48907 .91938 m .46615 .91835 L .46624 .91991 L .358 0 0 r
F
.48907 .91938 m .48982 .91782 L .46615 .91835 L F
.4883 .92081 m .46624 .91991 L .46633 .92134 L .333 0 0 r
F
.4883 .92081 m .48907 .91938 L .46624 .91991 L F
.47968 .92231 m .46633 .92134 L .46642 .92265 L .307 0 0 r
F
.48752 .92211 m .47955 .92182 L .47968 .92231 L F
.47955 .92182 m .46633 .92134 L .47968 .92231 L F
.48752 .92211 m .4883 .92081 L .47934 .92103 L F
.47955 .92182 m .47934 .92103 L .46633 .92134 L F
.48752 .92211 m .47934 .92103 L .47955 .92182 L F
.47923 .92349 m .46642 .92265 L .46652 .92383 L .278 0 0 r
F
.47921 .92344 m .46642 .92265 L .47923 .92349 L F
.47975 .92307 m .46642 .92265 L .47981 .92348 L F
.48363 .92291 m .48752 .92211 L .4789 .92233 L F
.4841 .92297 m .48434 .92291 L .48363 .92291 L F
.48434 .92291 m .48752 .92211 L .48363 .92291 L F
.50701 .92664 m .50115 .92286 L .48688 .92751 L .71 .033 0 r
F
.487 .9229 m .48752 .92211 L .4841 .92297 L .278 0 0 r
F
.50115 .92286 m .50005 .92215 L .487 .9229 L .71 .033 0 r
F
.50115 .92286 m .487 .9229 L .48688 .92751 L F
.48688 .92751 m .487 .9229 L .48031 .92342 L .955 .406 0 r
F
.49897 .9226 m .49508 .92244 L .48674 .92329 L .233 0 0 r
F
.49508 .92244 m .49376 .92238 L .49194 .92262 L F
.49508 .92244 m .49194 .92262 L .48674 .92329 L F
.49376 .92238 m .48752 .92211 L .487 .9229 L F
.49376 .92238 m .487 .9229 L .48674 .92329 L F
.49964 .92215 m .48752 .92211 L .49897 .9226 L F
.50005 .92215 m .50112 .92136 L .48752 .92211 L F
.49764 .92367 m .48674 .92329 L .48594 .92435 L .203 0 0 r
F
.50701 .92664 m .50869 .92543 L .50137 .92149 L .71 .033 0 r
F
.50134 .92151 m .50137 .92149 L .50128 .92145 L F
.50701 .92664 m .50137 .92149 L .50134 .92151 L F
.50701 .92664 m .50128 .92145 L .50124 .92147 L F
.50701 .92664 m .50109 .92135 L .50005 .92215 L F
.50869 .92543 m .51034 .9241 L .50259 .92013 L .72 .033 0 r
F
.50869 .92543 m .50259 .92013 L .50255 .92016 L F
.50869 .92543 m .50242 .92005 L .50136 .92091 L F
.50498 .92324 m .50666 .92217 L .4995 .92257 L .203 0 0 r
F
.49831 .92326 m .4995 .92257 L .48674 .92329 L F
.50498 .92324 m .4995 .92257 L .49831 .92326 L F
.50498 .92324 m .49831 .92326 L .49764 .92367 L F
.49831 .92326 m .48674 .92329 L .49764 .92367 L F
.50124 .92147 m .50128 .92145 L .50109 .92135 L .71 .033 0 r
F
.50005 .92215 m .50109 .92135 L .48722 .91388 L F
.4995 .92257 m .49964 .92215 L .49897 .9226 L .233 0 0 r
F
.50666 .92217 m .50005 .92215 L .4995 .92257 L F
.50005 .92215 m .49964 .92215 L .4995 .92257 L F
.50048 .92215 m .5005 .92212 L .50005 .92215 L F
.5005 .92212 m .50112 .92136 L .50005 .92215 L F
.50005 .92215 m .48722 .91388 L .487 .92288 L .71 .033 0 r
F
.50005 .92215 m .487 .92288 L .487 .9229 L F
.4791 .92305 m .4789 .92233 L .46642 .92265 L .278 0 0 r
F
.47975 .92307 m .4789 .92233 L .4791 .92305 L F
.4841 .92297 m .4797 .92243 L .47975 .92307 L F
.487 .9229 m .48722 .91388 L .48057 .92305 L .955 .406 0 r
F
.487 .9229 m .48057 .92305 L .48031 .92342 L F
.48674 .92329 m .4841 .92297 L .47975 .92307 L .278 0 0 r
F
.4797 .92243 m .4789 .92233 L .47975 .92307 L F
.47979 .92347 m .46651 .91483 L .4666 .91596 L .955 .406 0 r
F
.47981 .92348 m .47979 .92347 L .47979 .92347 L F
.47979 .92347 m .46651 .91483 L .47979 .92347 L F
.47975 .92307 m .48722 .91388 L .46651 .91483 L F
.48031 .92342 m .48057 .92305 L .47975 .92307 L F
.48057 .92305 m .48722 .91388 L .47975 .92307 L F
.48674 .92329 m .487 .9229 L .4841 .92297 L .278 0 0 r
F
.47877 .92455 m .46652 .92383 L .46661 .92489 L .248 0 0 r
F
.47875 .9245 m .46652 .92383 L .47877 .92455 L F
.4793 .92417 m .46652 .92383 L .47935 .92453 L F
.48 .92359 m .47981 .92346 L .47981 .92348 L .955 .406 0 r
F
.47981 .92346 m .4798 .92346 L .47981 .92348 L F
.48 .92359 m .46651 .91483 L .48 .92359 L F
.48688 .92751 m .47993 .92318 L .48006 .92362 L F
.47993 .92318 m .46651 .91483 L .48006 .92362 L F
.48594 .92435 m .48674 .92329 L .47981 .92348 L .248 0 0 r
F
.47807 .92548 m .46661 .92489 L .46671 .92582 L .217 0 0 r
F
.48608 .92856 m .48688 .92751 L .48004 .92361 L .634 .017 0 r
F
.48003 .92363 m .48004 .92361 L .47996 .92357 L F
.48608 .92856 m .48004 .92361 L .48003 .92363 L F
.48608 .92856 m .47996 .92357 L .47994 .92359 L F
.48608 .92856 m .47981 .92348 L .4793 .92417 L F
.47953 .92464 m .47935 .92452 L .47935 .92453 L F
.47935 .92452 m .47934 .92452 L .47935 .92453 L F
.47953 .92464 m .47935 .92451 L .47953 .92464 L F
.47864 .92415 m .47845 .92351 L .46652 .92383 L .248 0 0 r
F
.4793 .92417 m .47845 .92351 L .47864 .92415 L F
.48594 .92435 m .47924 .9236 L .4793 .92417 L F
.47924 .9236 m .47845 .92351 L .4793 .92417 L F
.47935 .92451 m .47933 .9245 L .47935 .92452 L .634 .017 0 r
F
.47933 .9245 m .4666 .91596 L .47933 .92451 L F
.47933 .9245 m .47933 .92451 L .47935 .92452 L F
.47935 .92451 m .47935 .92452 L .47953 .92464 L F
.47841 .92513 m .47879 .92478 L .46661 .92489 L .217 0 0 r
F
.47879 .92478 m .47905 .92454 L .47877 .92455 L F
.47879 .92478 m .47877 .92455 L .46661 .92489 L F
.48527 .92948 m .479 .92525 L .47911 .9256 L .629 .015 0 r
F
.47883 .92514 m .47879 .92478 L .47841 .92513 L .217 0 0 r
F
.479 .92525 m .47883 .92514 L .47911 .9256 L .629 .015 0 r
F
.47883 .92514 m .47841 .92513 L .47888 .92546 L .217 0 0 r
F
.47883 .92514 m .4667 .91697 L .47888 .92544 L .629 .015 0 r
F
.47883 .92514 m .47888 .92544 L .47911 .9256 L F
.47888 .92546 m .47841 .92513 L .47807 .92548 L .217 0 0 r
F
.48608 .92856 m .47947 .92428 L .47959 .92468 L .634 .017 0 r
F
.46615 .91835 m .46606 .91668 L .44155 .9165 L .416 0 0 r
F
.46615 .91835 m .44155 .9165 L .44247 .9182 L F
.46624 .91991 m .46615 .91835 L .44247 .9182 L .393 0 0 r
F
.46624 .91991 m .44247 .9182 L .44341 .91978 L F
.46633 .92134 m .46624 .91991 L .44341 .91978 L .368 0 0 r
F
.46633 .92134 m .44341 .91978 L .44436 .92124 L F
.46642 .92265 m .46633 .92134 L .44436 .92124 L .342 0 0 r
F
.46642 .92265 m .44436 .92124 L .44532 .92257 L F
.46652 .92383 m .46642 .92265 L .44532 .92257 L .313 0 0 r
F
.46652 .92383 m .44532 .92257 L .44629 .92378 L F
.46661 .92489 m .46652 .92383 L .44629 .92378 L .283 0 0 r
F
.46661 .92489 m .44629 .92378 L .44728 .92487 L F
.46671 .92582 m .46661 .92489 L .44728 .92487 L .252 0 0 r
F
.45992 .92582 m .44728 .92487 L .44828 .92582 L F
.46671 .92582 m .45947 .92546 L .45992 .92582 L F
.45947 .92546 m .44728 .92487 L .45992 .92582 L F
.46454 .92635 m .46671 .92582 L .45992 .92582 L .218 0 0 r
F
.46056 .92635 m .45992 .92582 L .44828 .92582 L F
.46677 .93056 m .46678 .92636 L .46097 .92662 L 1 .41 0 r
F
.46678 .92636 m .46115 .92635 L .46097 .92662 L F
.48445 .93027 m .47835 .92598 L .46677 .93056 L .623 .014 0 r
F
.47397 .92612 m .47288 .92608 L .47145 .9262 L .183 0 0 r
F
.47288 .92608 m .46671 .92582 L .46678 .92636 L F
.47708 .92648 m .46678 .92636 L .46677 .93056 L .623 .014 0 r
F
.47835 .92598 m .46701 .92635 L .47708 .92648 L F
.46701 .92635 m .46678 .92636 L .47708 .92648 L F
.46097 .92662 m .46115 .92635 L .46056 .92635 L 1 .41 0 r
F
.46677 .93056 m .46074 .92647 L .46113 .92678 L F
.46692 .92729 m .46681 .92662 L .46091 .92663 L .183 0 0 r
F
.46688 .93122 m .46677 .93056 L .46112 .92677 L .52 0 0 r
F
.46688 .93122 m .46112 .92677 L .46112 .92679 L F
.46688 .93122 m .46091 .92663 L .46099 .92707 L F
.46099 .92707 m .46091 .92663 L .46035 .92663 L .183 0 0 r
F
.46099 .92707 m .46035 .92663 L .4493 .92665 L F
.46091 .92663 m .45767 .92623 L .4493 .92665 L .218 0 0 r
F
.46056 .92635 m .45767 .92623 L .46091 .92663 L F
.46099 .92707 m .46091 .92663 L .44967 .9191 L .52 0 0 r
F
.46099 .92707 m .44987 .91924 L .45068 .91979 L F
.46688 .93122 m .46107 .92713 L .46133 .92731 L F
.46133 .92731 m .46071 .92727 L .46077 .92731 L .183 0 0 r
F
.46107 .92713 m .46099 .92707 L .46133 .92731 L .52 0 0 r
F
.46099 .92707 m .4493 .92665 L .46133 .92731 L .183 0 0 r
F
.46692 .92729 m .46122 .92708 L .46133 .92731 L F
.46122 .92708 m .46099 .92707 L .46133 .92731 L F
.46698 .93174 m .46688 .93122 L .46154 .92745 L .504 0 0 r
F
.46698 .93174 m .46154 .92745 L .46154 .92747 L F
.46698 .93174 m .46133 .92731 L .46158 .92778 L F
.46099 .92707 m .45129 .92024 L .46133 .92731 L .52 0 0 r
F
.45129 .92024 m .44967 .9191 L .46133 .92731 L F
.45126 .92022 m .44967 .9191 L .45126 .92021 L F
.45126 .92022 m .45126 .92021 L .46099 .92707 L F
.46132 .9273 m .45126 .92022 L .46099 .92707 L F
.46133 .92731 m .46132 .9273 L .46132 .9273 L F
.46132 .9273 m .44967 .9191 L .46132 .9273 L F
.46134 .92733 m .46133 .92731 L .46105 .92731 L .147 0 0 r
F
.46138 .92734 m .46133 .92731 L .46134 .92733 L F
.46101 .92765 m .46103 .92745 L .45032 .92735 L F
.46103 .92745 m .46105 .92731 L .46077 .92731 L F
.46103 .92745 m .46077 .92731 L .45032 .92735 L F
.46142 .92767 m .46133 .92731 L .45068 .91979 L .504 0 0 r
F
.46158 .92778 m .46133 .92731 L .46142 .92767 L F
.46154 .92747 m .46154 .92745 L .46133 .92731 L F
.46702 .92782 m .46105 .92731 L .46103 .92745 L .147 0 0 r
F
.46142 .92767 m .46103 .92745 L .46101 .92765 L F
.46702 .92782 m .46103 .92745 L .46142 .92767 L F
.46698 .93174 m .46158 .92778 L .46197 .92801 L .504 0 0 r
F
.46702 .92782 m .46165 .92767 L .46176 .92786 L .147 0 0 r
F
.46165 .92767 m .46142 .92767 L .46176 .92786 L F
.46197 .92801 m .46175 .92785 L .46176 .92786 L .504 0 0 r
F
.46709 .93214 m .46698 .93174 L .46196 .928 L .489 0 0 r
F
.46709 .93214 m .46196 .928 L .46196 .92801 L F
.46709 .93214 m .46176 .92786 L .46201 .92825 L F
.45171 .92055 m .45068 .91979 L .45171 .92054 L .504 0 0 r
F
.45171 .92055 m .45171 .92054 L .46197 .92801 L F
.46158 .92778 m .45171 .92055 L .46197 .92801 L F
.46176 .92786 m .45032 .92735 L .45136 .92792 L .147 0 0 r
F
.46175 .92785 m .46174 .92785 L .46176 .92786 L .504 0 0 r
F
.46142 .92767 m .45032 .92735 L .46176 .92786 L .147 0 0 r
F
.46173 .92783 m .45068 .91979 L .46175 .92784 L .504 0 0 r
F
.46089 .92662 m .44868 .91829 L .44967 .9191 L 1 .41 0 r
F
.46175 .92785 m .45068 .91979 L .4517 .92036 L .504 0 0 r
F
.46175 .92784 m .45068 .91979 L .46175 .92785 L F
.45994 .92809 m .46148 .92786 L .45136 .92792 L .11 0 0 r
F
.46144 .92812 m .46145 .92807 L .45994 .92809 L F
.46145 .92807 m .46148 .92786 L .45994 .92809 L F
.45767 .92623 m .44828 .92582 L .44863 .92611 L .218 0 0 r
F
.44436 .92124 m .44341 .91978 L .4209 .91899 L .394 0 0 r
F
.44436 .92124 m .4209 .91899 L .4227 .9205 L F
.44532 .92257 m .44436 .92124 L .4227 .9205 L .367 0 0 r
F
.44532 .92257 m .4227 .9205 L .42452 .92189 L F
.44629 .92378 m .44532 .92257 L .42452 .92189 L .339 0 0 r
F
.44629 .92378 m .42452 .92189 L .42637 .92315 L F
.44728 .92487 m .44629 .92378 L .42637 .92315 L .308 0 0 r
F
.44728 .92487 m .42637 .92315 L .42824 .92428 L F
.44828 .92582 m .44728 .92487 L .42824 .92428 L .276 0 0 r
F
.44828 .92582 m .42824 .92428 L .43013 .92529 L F
.4493 .92665 m .44828 .92582 L .43013 .92529 L .243 0 0 r
F
.4493 .92665 m .43013 .92529 L .43205 .92618 L F
.45032 .92735 m .4493 .92665 L .43205 .92618 L .208 0 0 r
F
.45032 .92735 m .43205 .92618 L .43398 .92693 L F
.45136 .92792 m .45032 .92735 L .43398 .92693 L .172 0 0 r
F
.44567 .92779 m .43398 .92693 L .43594 .92755 L F
.45136 .92792 m .44489 .92755 L .44567 .92779 L F
.44489 .92755 m .43398 .92693 L .44567 .92779 L F
.44692 .92809 m .45136 .92792 L .44567 .92779 L .135 0 0 r
F
.44692 .92809 m .44567 .92779 L .43594 .92755 L F
.44692 .92809 m .4517 .92036 L .43651 .92044 L 1 .397 0 r
F
.45208 .92822 m .45136 .92792 L .44692 .92809 L .135 0 0 r
F
.44724 .9281 m .4517 .92036 L .44692 .92809 L 1 .397 0 r
F
.45226 .93201 m .45208 .92821 L .44715 .92826 L F
.45208 .92821 m .45208 .92819 L .45167 .9282 L F
.45208 .92821 m .45167 .9282 L .44715 .92826 L F
.44715 .92826 m .44724 .9281 L .44692 .92809 L F
.45226 .93201 m .44709 .92821 L .44776 .92842 L F
.46077 .92731 m .4493 .92665 L .45032 .92735 L .183 0 0 r
F
.46071 .92727 m .4493 .92665 L .46077 .92731 L F
.45767 .92623 m .44863 .92611 L .4493 .92665 L .218 0 0 r
F
.46709 .93214 m .46185 .92813 L .45226 .93201 L .489 0 0 r
F
.46185 .92813 m .45208 .92822 L .45226 .93201 L F
.46713 .92823 m .46185 .92813 L .45241 .92836 L .11 0 0 r
F
.46185 .92813 m .45136 .92792 L .45208 .92822 L F
.46185 .92813 m .45208 .92822 L .45241 .92836 L F
.46185 .92813 m .46148 .92786 L .46144 .92812 L F
.46713 .92823 m .46521 .9281 L .46185 .92813 L F
.46196 .92801 m .46196 .928 L .46176 .92786 L .489 0 0 r
F
.46177 .92788 m .46148 .92786 L .46185 .92813 L .11 0 0 r
F
.46174 .92785 m .46173 .92783 L .46176 .92786 L .504 0 0 r
F
.46173 .92783 m .46175 .92784 L .46176 .92786 L F
.46176 .92786 m .46175 .92784 L .46175 .92785 L F
.46181 .92788 m .46176 .92786 L .46148 .92786 L .11 0 0 r
F
.46185 .92813 m .46176 .92786 L .4517 .92036 L .489 0 0 r
F
.46201 .92825 m .46176 .92786 L .46185 .92813 L F
.46521 .9281 m .46177 .92788 L .46185 .92813 L .11 0 0 r
F
.46185 .92813 m .4517 .92036 L .45208 .92819 L .489 0 0 r
F
.46185 .92813 m .45208 .92819 L .45208 .92822 L F
.45208 .92819 m .4517 .92036 L .44715 .92826 L 1 .397 0 r
F
.45347 .92867 m .45241 .92836 L .44756 .92826 L .097 0 0 r
F
.44709 .92821 m .447 .92815 L .44776 .92842 L 1 .397 0 r
F
.44776 .92842 m .44751 .92823 L .44755 .92825 L F
.4672 .93239 m .46709 .93214 L .45226 .93201 L .077 0 0 r
F
.4672 .93239 m .45226 .93201 L .45333 .9323 L F
.45347 .92867 m .44756 .92826 L .44876 .92848 L .097 0 0 r
F
.45241 .92836 m .44692 .92809 L .44756 .92826 L .135 0 0 r
F
.44836 .92816 m .44831 .92813 L .44692 .92809 L F
.45241 .92836 m .44831 .92813 L .44836 .92816 L F
.45241 .92836 m .45208 .92822 L .44831 .92813 L F
.45333 .9323 m .44837 .92852 L .44894 .92858 L 0 .046 0 r
F
.45333 .9323 m .45226 .93201 L .44775 .92841 L F
.45333 .9323 m .44775 .92841 L .44779 .92841 L F
.45333 .9323 m .44756 .92826 L .44829 .92846 L F
.44894 .92858 m .43792 .92805 L .43992 .92842 L .097 0 0 r
F
.46731 .93252 m .4672 .93239 L .45333 .9323 L .038 0 0 r
F
.46731 .93252 m .45333 .9323 L .45441 .93245 L F
.45347 .92867 m .44852 .92847 L .44894 .92858 L .097 0 0 r
F
.45455 .92884 m .45347 .92867 L .44894 .92858 L .058 0 0 r
F
.45455 .92884 m .44894 .92858 L .44905 .9286 L F
.45455 .92884 m .449 .92859 L .44929 .92864 L F
.45441 .93245 m .44894 .92858 L .44983 .92882 L 0 .047 0 r
F
.45455 .92884 m .44893 .92863 L .44967 .9287 L .058 0 0 r
F
.44967 .9287 m .44894 .92858 L .44042 .92137 L 0 .047 0 r
F
.44983 .92882 m .44894 .92858 L .44967 .9287 L F
.44929 .92864 m .44867 .92858 L .44893 .92863 L .058 0 0 r
F
.449 .92859 m .44867 .92858 L .44929 .92864 L F
.44967 .9287 m .44893 .92863 L .44926 .92869 L F
.45441 .93245 m .44975 .92876 L .45032 .92878 L 0 .047 0 r
F
.45441 .93245 m .45333 .9323 L .44911 .92873 L F
.45441 .93245 m .44911 .92873 L .44915 .92873 L F
.45032 .92878 m .43992 .92842 L .44194 .92865 L .058 0 0 r
F
.46503 .93249 m .46731 .93252 L .45441 .93245 L .001 .139 0 r
F
.46743 .9325 m .4674 .9325 L .46503 .93249 L F
.4674 .9325 m .46731 .93252 L .46503 .93249 L F
.46743 .9325 m .45441 .93245 L .4555 .93247 L F
.4555 .93247 m .45441 .93245 L .45049 .92893 L 0 .048 0 r
F
.45053 .92893 m .45049 .92893 L .45032 .92878 L F
.4555 .93247 m .45049 .92893 L .45053 .92893 L F
.45384 .92885 m .45455 .92884 L .45032 .92878 L .019 0 0 r
F
.45563 .92889 m .45526 .92887 L .45384 .92885 L F
.45526 .92887 m .45455 .92884 L .45384 .92885 L F
.4555 .93247 m .45032 .92878 L .45122 .92893 L 0 .048 0 r
F
.45452 .93244 m .45043 .9288 L .44378 .93209 L F
.45043 .9288 m .45042 .9288 L .44378 .93209 L F
.45107 .92881 m .44978 .92879 L .44333 .92872 L .019 0 0 r
F
.44978 .92879 m .44194 .92865 L .44333 .92872 L F
.45455 .92884 m .44991 .92871 L .45032 .92878 L .058 0 0 r
F
.44991 .92871 m .44967 .9287 L .45032 .92878 L F
.44967 .9287 m .44042 .92137 L .45032 .92878 L 0 .047 0 r
F
.45031 .92877 m .44042 .92137 L .4424 .92166 L F
.4503 .92877 m .44042 .92137 L .45031 .92877 L F
.44837 .92852 m .44829 .92846 L .44894 .92858 L 0 .046 0 r
F
.44829 .92846 m .43792 .92805 L .44894 .92858 L .097 0 0 r
F
.44852 .92847 m .44829 .92846 L .44894 .92858 L F
.44829 .92846 m .43845 .92097 L .44894 .92858 L 0 .046 0 r
F
.44894 .92858 m .43863 .9211 L .44042 .92137 L F
.43863 .9211 m .43845 .92097 L .44042 .92137 L F
.44876 .92848 m .44756 .92826 L .44829 .92846 L .097 0 0 r
F
.44829 .92846 m .44756 .92826 L .43845 .92097 L 0 .046 0 r
F
.44692 .92809 m .43651 .92044 L .44752 .92825 L 1 .397 0 r
F
.44755 .92825 m .4367 .92057 L .43845 .92097 L F
.4367 .92057 m .43651 .92044 L .43845 .92097 L F
.44751 .92823 m .43651 .92044 L .44755 .92825 L F
.44023 .92137 m .43845 .92097 L .42459 .92064 L .121 0 0 r
F
.44042 .92137 m .43845 .92097 L .44023 .92137 L F
.44223 .92166 m .44042 .92137 L .42745 .92115 L .086 0 0 r
F
.4424 .92166 m .44042 .92137 L .44223 .92166 L F
.44779 .92841 m .44775 .92841 L .44756 .92826 L 0 .046 0 r
F
.44829 .92846 m .44756 .92826 L .43792 .92805 L .097 0 0 r
F
.447 .92815 m .44692 .92809 L .44714 .92818 L 1 .397 0 r
F
.447 .92815 m .44714 .92818 L .44776 .92842 L F
.44692 .92809 m .44752 .92825 L .44776 .92842 L F
.44756 .92826 m .44692 .92809 L .43792 .92805 L .135 0 0 r
F
.44692 .92809 m .43594 .92755 L .43721 .92787 L F
.44692 .92809 m .43721 .92787 L .43792 .92805 L F
.43992 .92842 m .43792 .92805 L .42388 .92731 L .112 0 0 r
F
.43992 .92842 m .42388 .92731 L .42679 .92776 L F
.44194 .92865 m .43992 .92842 L .42679 .92776 L .074 0 0 r
F
.43736 .92843 m .42679 .92776 L .42973 .92808 L F
.44194 .92865 m .43624 .92831 L .43736 .92843 L F
.43624 .92831 m .42679 .92776 L .43736 .92843 L F
.43924 .92853 m .44194 .92865 L .43736 .92843 L .036 0 0 r
F
.43924 .92853 m .43736 .92843 L .42973 .92808 L F
.43924 .92853 m .4424 .92166 L .43034 .92154 L 1 .359 0 r
F
.4395 .92854 m .4424 .92166 L .43924 .92853 L F
.44333 .92872 m .44194 .92865 L .43924 .92853 L .036 0 0 r
F
.44975 .92876 m .44967 .9287 L .45032 .92878 L 0 .047 0 r
F
.44915 .92873 m .44911 .92873 L .44894 .92858 L F
.44967 .9287 m .43992 .92842 L .45032 .92878 L .058 0 0 r
F
.44333 .92872 m .44333 .92869 L .43944 .92868 L 1 .359 0 r
F
.44978 .92879 m .45006 .92878 L .44194 .92865 L .019 0 0 r
F
.44926 .92869 m .44867 .92858 L .43992 .92842 L .058 0 0 r
F
.44333 .92869 m .43946 .92863 L .43944 .92868 L 1 .359 0 r
F
.43944 .92868 m .4395 .92854 L .43924 .92853 L F
.4394 .92865 m .43924 .92853 L .44036 .92876 L F
.44274 .92868 m .4395 .92854 L .43946 .92863 L F
.45043 .9288 m .44333 .92869 L .44333 .92871 L 0 .048 0 r
F
.45001 .92901 m .44333 .92871 L .44378 .93209 L F
.45043 .9288 m .44333 .92871 L .45001 .92901 L F
.44378 .93209 m .44333 .92872 L .43944 .92868 L 1 .359 0 r
F
.44585 .93203 m .44378 .93209 L .44019 .92859 L 0 .076 0 r
F
.44398 .92875 m .43947 .92854 L .44019 .92859 L .036 0 0 r
F
.44333 .92869 m .4424 .92166 L .4395 .92854 L 1 .359 0 r
F
.44333 .92869 m .4395 .92854 L .44274 .92868 L F
.44398 .92875 m .44333 .92872 L .43924 .92853 L .036 0 0 r
F
.45066 .9288 m .45059 .9288 L .44978 .92879 L .019 0 0 r
F
.45059 .9288 m .45006 .92878 L .44978 .92879 L F
.45032 .92878 m .4503 .92877 L .45031 .92877 L 0 .047 0 r
F
.45044 .92878 m .45032 .92878 L .45006 .92878 L .019 0 0 r
F
.45375 .92885 m .45032 .92878 L .45044 .92878 L F
.45563 .92889 m .45384 .92885 L .45375 .92885 L F
.45384 .92885 m .45032 .92878 L .45375 .92885 L F
.45547 .93244 m .45107 .92881 L .45452 .93244 L 0 .048 0 r
F
.45122 .92893 m .45032 .92878 L .45029 .92875 L F
.45563 .92889 m .45006 .92878 L .45066 .9288 L .019 0 0 r
F
.45107 .92881 m .45029 .92875 L .4424 .92166 L 0 .048 0 r
F
.45122 .92893 m .45029 .92875 L .45107 .92881 L F
.45107 .92881 m .45043 .9288 L .45452 .93244 L F
.45146 .92884 m .45107 .92881 L .44398 .92875 L .019 0 0 r
F
.45563 .92889 m .45107 .92881 L .45146 .92884 L F
.45107 .92881 m .4424 .92166 L .45043 .9288 L 0 .048 0 r
F
.44905 .9286 m .44894 .92858 L .44867 .92858 L .058 0 0 r
F
.45043 .9288 m .4424 .92166 L .44333 .92869 L 0 .048 0 r
F
.44604 .92873 m .44398 .92875 L .44019 .92859 L .002 .139 0 r
F
.44159 .92857 m .44019 .92859 L .44016 .92856 L 0 .076 0 r
F
.44159 .92857 m .44016 .92856 L .43326 .92181 L F
.43947 .92854 m .43924 .92853 L .44019 .92859 L .036 0 0 r
F
.43924 .92853 m .43034 .92154 L .44013 .92859 L 1 .359 0 r
F
.44018 .92858 m .43051 .92166 L .43326 .92181 L F
.43051 .92166 m .43034 .92154 L .43326 .92181 L F
.44011 .92857 m .43034 .92154 L .44018 .92858 L F
.42452 .92189 m .4227 .9205 L .40168 .91914 L .383 0 0 r
F
.44255 .92859 m .43326 .92181 L .4362 .92197 L 0 .076 0 r
F
.44604 .92873 m .44019 .92859 L .44159 .92857 L .002 .139 0 r
F
.44585 .93203 m .44159 .92857 L .44255 .92859 L 0 .076 0 r
F
.44159 .92857 m .43326 .92181 L .44255 .92859 L F
.44255 .92859 m .44159 .92857 L .44231 .92858 L .002 .139 0 r
F
.44795 .93184 m .44585 .93203 L .44255 .92859 L 0 .076 0 r
F
.44623 .92858 m .44604 .92873 L .44255 .92859 L .039 .146 0 r
F
.44812 .92858 m .44255 .92859 L .44397 .92849 L F
.44604 .92873 m .44183 .92858 L .44255 .92859 L .002 .139 0 r
F
.45107 .92881 m .44333 .92872 L .44398 .92875 L .019 0 0 r
F
.45043 .9288 m .45043 .9288 L .45042 .9288 L 0 .048 0 r
F
.45208 .92878 m .45146 .92884 L .44398 .92875 L .02 .142 0 r
F
.45672 .9288 m .44398 .92875 L .44604 .92873 L F
.44795 .93184 m .44255 .92859 L .44411 .92862 L 0 .076 0 r
F
.44585 .93203 m .44019 .92859 L .44175 .9287 L F
.44378 .93209 m .4394 .92865 L .44036 .92876 L 1 .359 0 r
F
.44795 .93184 m .44397 .92849 L .4385 .9313 L 0 .076 0 r
F
.44397 .92849 m .44255 .92859 L .44252 .92855 L F
.44397 .92849 m .44252 .92855 L .4362 .92197 L F
.43792 .92805 m .43594 .92755 L .42099 .92673 L .149 0 0 r
F
.43792 .92805 m .42099 .92673 L .42388 .92731 L F
.44397 .92849 m .4362 .92197 L .43775 .92825 L 0 .076 0 r
F
.44397 .92849 m .43775 .92825 L .43776 .92828 L F
.44174 .92842 m .44129 .92841 L .43776 .92828 L .039 .146 0 r
F
.44129 .92841 m .4357 .92833 L .43776 .92828 L F
.43398 .92693 m .43205 .92618 L .41532 .9252 L .222 0 0 r
F
.43398 .92693 m .41532 .9252 L .41814 .92603 L F
.43594 .92755 m .43398 .92693 L .41814 .92603 L .186 0 0 r
F
.43594 .92755 m .41814 .92603 L .42099 .92673 L F
.43443 .92804 m .4362 .92197 L .42647 .92168 L 1 .31 0 r
F
.43461 .92805 m .43461 .92805 L .43443 .92804 L F
.43461 .92805 m .4362 .92197 L .43443 .92804 L F
.43776 .92828 m .4357 .92833 L .43443 .92804 L .029 .143 0 r
F
.43776 .92828 m .4362 .92197 L .43458 .92816 L 1 .31 0 r
F
.43569 .92805 m .43443 .92804 L .43568 .92804 L F
.43872 .92826 m .43467 .92805 L .43569 .92805 L .029 .143 0 r
F
.43467 .92805 m .43443 .92804 L .43569 .92805 L F
.43872 .92826 m .43776 .92828 L .43443 .92804 L F
.43443 .92804 m .4357 .92833 L .43194 .92805 L F
.44397 .92849 m .4357 .92833 L .44469 .92846 L .039 .146 0 r
F
.44397 .92849 m .44255 .92859 L .4357 .92833 L F
.44231 .92858 m .4327 .92826 L .4357 .92833 L .002 .139 0 r
F
.44159 .92857 m .4327 .92826 L .44231 .92858 L F
.44019 .92859 m .43924 .92853 L .4327 .92826 L .036 0 0 r
F
.43924 .92853 m .43164 .9282 L .4327 .92826 L F
.44159 .92857 m .44019 .92859 L .4327 .92826 L .002 .139 0 r
F
.43924 .92853 m .42973 .92808 L .43164 .9282 L .036 0 0 r
F
.42973 .92808 m .42679 .92776 L .4143 .92671 L .079 0 0 r
F
.42973 .92808 m .4143 .92671 L .41812 .92713 L F
.4357 .92833 m .4327 .92826 L .42197 .92743 L 0 .137 0 r
F
.4357 .92833 m .42197 .92743 L .42587 .9276 L F
.4385 .9313 m .43776 .92828 L .43458 .92816 L 1 .31 0 r
F
.44411 .92862 m .44255 .92859 L .44397 .92849 L 0 .076 0 r
F
.44183 .92858 m .44159 .92857 L .44255 .92859 L .002 .139 0 r
F
.44175 .9287 m .44019 .92859 L .44159 .92857 L 0 .076 0 r
F
.43924 .92853 m .44013 .92859 L .44036 .92876 L 1 .359 0 r
F
.44036 .92876 m .44011 .92857 L .44018 .92858 L F
.44397 .92849 m .43776 .92828 L .4385 .9313 L 0 .076 0 r
F
.44157 .93105 m .4385 .9313 L .43569 .92805 L .129 .096 0 r
F
.44177 .92807 m .43872 .92826 L .43569 .92805 L .063 .15 0 r
F
.43775 .92793 m .43569 .92805 L .43566 .92801 L .129 .096 0 r
F
.43775 .92793 m .43566 .92801 L .43033 .92186 L F
.43568 .92804 m .42647 .92168 L .43033 .92186 L 1 .31 0 r
F
.43443 .92804 m .42647 .92168 L .43568 .92804 L F
.43903 .9279 m .43033 .92186 L .43422 .92194 L .129 .096 0 r
F
.44177 .92807 m .438 .92794 L .43903 .9279 L .063 .15 0 r
F
.438 .92794 m .43775 .92793 L .43903 .9279 L F
.44177 .92807 m .43569 .92805 L .43775 .92793 L F
.44469 .92846 m .44174 .92842 L .43872 .92826 L .039 .146 0 r
F
.44174 .92842 m .43776 .92828 L .43872 .92826 L F
.45021 .9283 m .44812 .92858 L .43872 .92826 L .076 .152 0 r
F
.45021 .9283 m .43872 .92826 L .44177 .92807 L F
.44467 .93068 m .44157 .93105 L .43903 .9279 L .147 .094 0 r
F
.44484 .92776 m .44177 .92807 L .43903 .9279 L .096 .155 0 r
F
.4411 .92769 m .43903 .9279 L .43899 .92785 L .147 .094 0 r
F
.4411 .92769 m .43899 .92785 L .43422 .92194 L F
.43775 .92793 m .43033 .92186 L .43903 .9279 L .129 .096 0 r
F
.44239 .92762 m .43422 .92194 L .43814 .92192 L .147 .094 0 r
F
.44484 .92776 m .44136 .9277 L .44239 .92762 L .096 .155 0 r
F
.44136 .9277 m .4411 .92769 L .44239 .92762 L F
.44484 .92776 m .43903 .9279 L .4411 .92769 L F
.44812 .92858 m .44397 .92849 L .44469 .92846 L .039 .146 0 r
F
.45233 .92789 m .45021 .9283 L .44177 .92807 L .11 .158 0 r
F
.45233 .92789 m .44177 .92807 L .44484 .92776 L F
.44779 .93018 m .44467 .93068 L .44239 .92762 L .162 .091 0 r
F
.44603 .92743 m .44484 .92776 L .44239 .92762 L .125 .16 0 r
F
.44686 .92748 m .44484 .92776 L .44603 .92743 L F
.44794 .92733 m .44239 .92762 L .44447 .92734 L F
.46735 .92865 m .46724 .92851 L .45347 .92867 L .032 0 0 r
F
.46735 .92865 m .45347 .92867 L .45455 .92884 L F
.45783 .92858 m .45672 .9288 L .44604 .92873 L .059 .15 0 r
F
.46724 .92851 m .45241 .92836 L .45347 .92867 L .071 0 0 r
F
.45783 .92858 m .44604 .92873 L .44812 .92858 L .059 .15 0 r
F
.45446 .92737 m .45233 .92789 L .44484 .92776 L .143 .164 0 r
F
.45446 .92737 m .45027 .92754 L .44794 .92733 L F
.45027 .92754 m .44484 .92776 L .44686 .92748 L F
.45027 .92754 m .44686 .92748 L .44794 .92733 L F
.44358 .92819 m .44239 .92762 L .44454 .92747 L .162 .091 0 r
F
.44467 .93068 m .4411 .92769 L .44239 .92762 L .147 .094 0 r
F
.44467 .93068 m .43903 .9279 L .44124 .92782 L F
.44779 .93018 m .44458 .92744 L .44157 .92971 L .162 .091 0 r
F
.44462 .92747 m .44239 .92762 L .44447 .92734 L F
.44458 .92744 m .44447 .92734 L .44436 .92743 L F
.44458 .92744 m .44436 .92743 L .44157 .92971 L F
.44447 .92734 m .44239 .92762 L .44235 .92757 L F
.44447 .92734 m .44235 .92757 L .43814 .92192 L F
.4411 .92769 m .43422 .92194 L .44239 .92762 L .147 .094 0 r
F
.44447 .92734 m .43814 .92192 L .44043 .92712 L .162 .091 0 r
F
.44447 .92734 m .44043 .92712 L .44045 .92716 L F
.44296 .92728 m .44274 .92728 L .44045 .92716 L .125 .16 0 r
F
.44274 .92728 m .43773 .92737 L .44045 .92716 L F
.43604 .92197 m .43326 .92181 L .42264 .92139 L .041 0 0 r
F
.4362 .92197 m .43326 .92181 L .43604 .92197 L F
.43326 .92181 m .43034 .92154 L .41885 .92099 L .073 0 0 r
F
.43326 .92181 m .41885 .92099 L .42264 .92139 L F
.4362 .92197 m .42264 .92139 L .42647 .92168 L .041 0 0 r
F
.42452 .92189 m .40168 .91914 L .40434 .9206 L .383 0 0 r
F
.42264 .92139 m .40812 .92005 L .41274 .92059 L .081 0 0 r
F
.42647 .92168 m .42264 .92139 L .41274 .92059 L 0 .128 0 r
F
.42647 .92168 m .41274 .92059 L .41739 .92103 L F
.42264 .92139 m .41885 .92099 L .40812 .92005 L .081 0 0 r
F
.43033 .92186 m .42647 .92168 L .41739 .92103 L 0 .134 0 r
F
.43033 .92186 m .41739 .92103 L .42208 .92135 L F
.43422 .92194 m .43033 .92186 L .42208 .92135 L .001 .138 0 r
F
.43422 .92194 m .42208 .92135 L .42681 .92158 L F
.43814 .92192 m .43422 .92194 L .42681 .92158 L .022 .143 0 r
F
.43814 .92192 m .42681 .92158 L .43158 .92171 L F
.43813 .92696 m .43773 .92737 L .43112 .92676 L .117 .158 0 r
F
.44045 .92716 m .43773 .92737 L .43813 .92696 L F
.44045 .92716 m .44044 .92714 L .43825 .92705 L 1 .177 0 r
F
.44044 .92714 m .43814 .92192 L .43825 .92697 L F
.44044 .92714 m .43825 .92697 L .43825 .92705 L F
.43813 .92696 m .43814 .92192 L .43158 .92171 L F
.43825 .92697 m .43814 .92192 L .43813 .92696 L F
.43973 .9269 m .43158 .92171 L .43638 .92176 L F
.44175 .92706 m .43841 .92697 L .43973 .9269 L .117 .158 0 r
F
.43841 .92697 m .43813 .92696 L .43973 .9269 L F
.44175 .92706 m .44045 .92716 L .43813 .92696 L F
.44447 .92734 m .43773 .92737 L .44557 .92723 L .125 .16 0 r
F
.44447 .92734 m .44239 .92762 L .43773 .92737 L F
.44217 .92761 m .43375 .92757 L .43773 .92737 L .096 .155 0 r
F
.4411 .92769 m .43375 .92757 L .44217 .92761 L F
.4411 .92769 m .43903 .9279 L .43375 .92757 L F
.44124 .92782 m .43903 .9279 L .4411 .92769 L .147 .094 0 r
F
.44157 .92971 m .44045 .92716 L .43825 .92705 L 1 .177 0 r
F
.44239 .92762 m .4411 .92769 L .44217 .92761 L .096 .155 0 r
F
.44447 .92734 m .44045 .92716 L .44157 .92971 L .162 .091 0 r
F
.44564 .92921 m .44157 .92971 L .43973 .9269 L .287 .235 0 r
F
.44579 .92665 m .44175 .92706 L .43973 .9269 L .14 .162 0 r
F
.44243 .92663 m .43973 .9269 L .43969 .92684 L .287 .235 0 r
F
.44243 .92663 m .43969 .92684 L .43638 .92176 L F
.43813 .92696 m .43158 .92171 L .43973 .9269 L 1 .177 0 r
F
.45151 .92036 m .45068 .91979 L .43458 .91979 L .164 0 0 r
F
.46597 .91488 m .46589 .91296 L .43974 .91273 L .458 0 0 r
F
.44261 .86117 m .4168 .8641 L .41821 .86662 L .514 .011 0 r
F
.43974 .91273 m .41228 .90965 L .41395 .91175 L .504 0 0 r
F
.46662 .85615 m .46656 .85376 L .44261 .86117 L .397 0 0 r
F
.44027 .90554 m .41324 .9027 L .41488 .90476 L .498 0 0 r
F
.44064 .91468 m .43974 .91273 L .41395 .91175 L .485 0 0 r
F
.46597 .91488 m .43974 .91273 L .44064 .91468 L .458 0 0 r
F
.44335 .86358 m .44261 .86117 L .41821 .86662 L .482 .006 0 r
F
.46662 .85615 m .44261 .86117 L .44335 .86358 L .397 0 0 r
F
.44115 .90743 m .44027 .90554 L .41488 .90476 L .478 0 0 r
F
.44335 .86358 m .41821 .86662 L .41965 .86904 L .482 .006 0 r
F
.44064 .91468 m .41395 .91175 L .41565 .91374 L .485 0 0 r
F
.44115 .90743 m .41488 .90476 L .41656 .90671 L .478 0 0 r
F
.4441 .86587 m .44335 .86358 L .41965 .86904 L .457 0 0 r
F
.44155 .9165 m .44064 .91468 L .41565 .91374 L .465 0 0 r
F
.44205 .9092 m .44115 .90743 L .41656 .90671 L .458 0 0 r
F
.4441 .86587 m .41965 .86904 L .42111 .87135 L .457 0 0 r
F
.44155 .9165 m .41565 .91374 L .41738 .91561 L .465 0 0 r
F
.44487 .86807 m .4441 .86587 L .42111 .87135 L .438 0 0 r
F
.44205 .9092 m .41656 .90671 L .41825 .90855 L .458 0 0 r
F
.44247 .9182 m .44155 .9165 L .41738 .91561 L .443 0 0 r
F
.44296 .91085 m .44205 .9092 L .41825 .90855 L .435 0 0 r
F
.44487 .86807 m .42111 .87135 L .4226 .87356 L .438 0 0 r
F
.44565 .87015 m .44487 .86807 L .4226 .87356 L .418 0 0 r
F
.44247 .9182 m .41738 .91561 L .41913 .91736 L .443 0 0 r
F
.44296 .91085 m .41825 .90855 L .41998 .91027 L .435 0 0 r
F
.44341 .91978 m .44247 .9182 L .41913 .91736 L .419 0 0 r
F
.44388 .91239 m .44296 .91085 L .41998 .91027 L .412 0 0 r
F
.44565 .87015 m .4226 .87356 L .42412 .87568 L .418 0 0 r
F
.44645 .87213 m .44565 .87015 L .42412 .87568 L .396 0 0 r
F
.44341 .91978 m .41913 .91736 L .4209 .91899 L .419 0 0 r
F
.44388 .91239 m .41998 .91027 L .42172 .91188 L .412 0 0 r
F
.44645 .87213 m .42412 .87568 L .42566 .87768 L .396 0 0 r
F
.44481 .91381 m .44388 .91239 L .42172 .91188 L .386 0 0 r
F
.44726 .87401 m .44645 .87213 L .42566 .87768 L .373 0 0 r
F
.44481 .91381 m .42172 .91188 L .42349 .91337 L .386 0 0 r
F
.44726 .87401 m .42566 .87768 L .42723 .87959 L .373 0 0 r
F
.46606 .91668 m .46597 .91488 L .44064 .91468 L .438 0 0 r
F
.46606 .91668 m .44064 .91468 L .44155 .9165 L F
.44576 .91511 m .44481 .91381 L .42349 .91337 L .359 0 0 r
F
.44809 .87578 m .44726 .87401 L .42723 .87959 L .349 0 0 r
F
.44576 .91511 m .42349 .91337 L .42528 .91474 L .359 0 0 r
F
.44809 .87578 m .42723 .87959 L .42883 .8814 L .349 0 0 r
F
.44672 .91629 m .44576 .91511 L .42528 .91474 L .33 0 0 r
F
.44893 .87744 m .44809 .87578 L .42883 .8814 L .323 0 0 r
F
.44672 .91629 m .42528 .91474 L .4271 .91599 L .33 0 0 r
F
.44893 .87744 m .42883 .8814 L .43045 .88311 L .323 0 0 r
F
.44769 .91735 m .44672 .91629 L .4271 .91599 L .3 0 0 r
F
.44978 .87901 m .44893 .87744 L .43045 .88311 L .296 0 0 r
F
.44978 .87901 m .43045 .88311 L .43209 .88472 L F
.44769 .91735 m .4271 .91599 L .42894 .91712 L .3 0 0 r
F
.45065 .88047 m .44978 .87901 L .43209 .88472 L .268 0 0 r
F
.44868 .91829 m .44769 .91735 L .42894 .91712 L F
.45065 .88047 m .43209 .88472 L .43376 .88624 L F
.44868 .91829 m .42894 .91712 L .4308 .91813 L F
.45152 .88184 m .45065 .88047 L .43376 .88624 L .239 0 0 r
F
.44967 .9191 m .44868 .91829 L .4308 .91813 L .235 0 0 r
F
.45152 .88184 m .43376 .88624 L .43545 .88766 L .239 0 0 r
F
.44967 .9191 m .4308 .91813 L .43268 .91902 L .235 0 0 r
F
.45242 .88312 m .45152 .88184 L .43545 .88766 L .209 0 0 r
F
.44987 .91924 m .44967 .9191 L .45068 .91979 L .52 0 0 r
F
.45068 .91979 m .44967 .9191 L .43268 .91902 L .2 0 0 r
F
.45242 .88312 m .43545 .88766 L .43717 .88899 L .209 0 0 r
F
.45068 .91979 m .43268 .91902 L .43458 .91979 L .2 0 0 r
F
.46454 .92635 m .45992 .92582 L .46056 .92635 L .218 0 0 r
F
.46056 .92635 m .4668 .91785 L .44868 .91829 L 1 .41 0 r
F
.46607 .90737 m .46599 .90553 L .44027 .90554 L .447 0 0 r
F
.46607 .90737 m .44027 .90554 L .44115 .90743 L F
.46615 .9091 m .46607 .90737 L .44115 .90743 L .426 0 0 r
F
.46615 .9091 m .44115 .90743 L .44205 .9092 L F
.46624 .91071 m .46615 .9091 L .44205 .9092 L .403 0 0 r
F
.46624 .91071 m .44205 .9092 L .44296 .91085 L F
.46633 .9122 m .46624 .91071 L .44296 .91085 L .379 0 0 r
F
.46633 .9122 m .44296 .91085 L .44388 .91239 L F
.46642 .91358 m .46633 .9122 L .44388 .91239 L .353 0 0 r
F
.46642 .91358 m .44388 .91239 L .44481 .91381 L F
.46651 .91483 m .46642 .91358 L .44481 .91381 L .325 0 0 r
F
.46651 .91483 m .44481 .91381 L .44576 .91511 L F
.4666 .91596 m .46651 .91483 L .44576 .91511 L .296 0 0 r
F
.4666 .91596 m .44576 .91511 L .44672 .91629 L F
.4667 .91697 m .4666 .91596 L .44672 .91629 L .265 0 0 r
F
.4667 .91697 m .44672 .91629 L .44769 .91735 L F
.4668 .91785 m .4667 .91697 L .44769 .91735 L .232 0 0 r
F
.4668 .91785 m .44769 .91735 L .44868 .91829 L F
.45332 .88431 m .45242 .88312 L .45121 .88358 L .178 0 0 r
F
.45332 .88431 m .45121 .88358 L .45173 .88423 L F
.45332 .88431 m .44976 .88414 L .45119 .88492 L F
.46669 .85842 m .46662 .85615 L .44335 .86358 L .375 0 0 r
F
.46669 .85842 m .44335 .86358 L .4441 .86587 L F
.46675 .86058 m .46669 .85842 L .4441 .86587 L .35 0 0 r
F
.46675 .86058 m .4441 .86587 L .44487 .86807 L F
.46682 .86263 m .46675 .86058 L .44487 .86807 L .323 0 0 r
F
.46682 .86263 m .44487 .86807 L .44565 .87015 L F
.46689 .86456 m .46682 .86263 L .44565 .87015 L .294 0 0 r
F
.46689 .86456 m .44565 .87015 L .44645 .87213 L F
.46697 .86639 m .46689 .86456 L .44645 .87213 L .263 0 0 r
F
.46697 .86639 m .44645 .87213 L .44726 .87401 L F
.46704 .8681 m .46697 .86639 L .44726 .87401 L .23 0 0 r
F
.46704 .8681 m .44726 .87401 L .44809 .87578 L F
.46712 .8697 m .46704 .8681 L .44809 .87578 L .195 0 0 r
F
.46712 .8697 m .44809 .87578 L .44893 .87744 L F
.4672 .8712 m .46712 .8697 L .44893 .87744 L .158 0 0 r
F
.4672 .8712 m .44893 .87744 L .44978 .87901 L F
.46728 .87258 m .4672 .8712 L .46401 .87263 L .118 0 0 r
F
.46475 .87351 m .46401 .87263 L .44978 .87901 L F
.46728 .87258 m .46401 .87263 L .46475 .87351 L F
.46418 .87405 m .44978 .87901 L .45065 .88047 L F
.46728 .87258 m .46401 .87378 L .46418 .87405 L F
.46401 .87378 m .44978 .87901 L .46418 .87405 L F
.47145 .9262 m .46678 .92636 L .46681 .92662 L .183 0 0 r
F
.47288 .92608 m .46678 .92636 L .47145 .9262 L F
.47794 .92597 m .46671 .92582 L .4776 .92628 L F
.46678 .92636 m .46671 .92582 L .46454 .92635 L .218 0 0 r
F
.46627 .92636 m .4668 .91785 L .46115 .92635 L 1 .41 0 r
F
.46678 .92636 m .46678 .92633 L .46627 .92636 L F
.47579 .92594 m .47888 .92546 L .46671 .92582 L .183 0 0 r
F
.47841 .92513 m .46661 .92489 L .47807 .92548 L .217 0 0 r
F
.46678 .92633 m .4668 .91785 L .46627 .92636 L 1 .41 0 r
F
.47835 .92598 m .47851 .92583 L .47579 .92594 L .183 0 0 r
F
.47851 .92583 m .47888 .92546 L .47579 .92594 L F
.47712 .92694 m .46681 .92662 L .46692 .92729 L .148 0 0 r
F
.48445 .93027 m .48527 .92948 L .4791 .92559 L .623 .014 0 r
F
.47908 .9256 m .4791 .92559 L .47901 .92554 L F
.48445 .93027 m .4791 .92559 L .47908 .9256 L F
.48445 .93027 m .47901 .92554 L .47898 .92555 L F
.48445 .93027 m .47884 .92543 L .47835 .92598 L F
.48527 .92948 m .48608 .92856 L .47949 .92462 L .629 .015 0 r
F
.48527 .92948 m .47949 .92462 L .47947 .92463 L F
.48527 .92948 m .47935 .92453 L .47883 .92514 L F
.48351 .92673 m .48433 .92606 L .4781 .92626 L .148 0 0 r
F
.47746 .92669 m .4781 .92626 L .46681 .92662 L F
.48351 .92673 m .4781 .92626 L .47746 .92669 L F
.48351 .92673 m .47746 .92669 L .47712 .92694 L F
.47746 .92669 m .46681 .92662 L .47712 .92694 L F
.47898 .92555 m .47901 .92554 L .47884 .92543 L .623 .014 0 r
F
.47835 .92598 m .47884 .92543 L .4668 .91785 L F
.4781 .92626 m .47794 .92597 L .4776 .92628 L .183 0 0 r
F
.48433 .92606 m .47835 .92598 L .4781 .92626 L F
.47835 .92598 m .47794 .92597 L .4781 .92626 L F
.4788 .92599 m .47881 .92597 L .47835 .92598 L F
.47881 .92597 m .47888 .92546 L .47835 .92598 L F
.47835 .92598 m .4668 .91785 L .46678 .92633 L .623 .014 0 r
F
.47835 .92598 m .46678 .92633 L .46678 .92636 L F
.479 .92494 m .47905 .92454 L .47879 .92478 L .217 0 0 r
F
.47914 .92478 m .47905 .92454 L .479 .92494 L F
.47934 .92457 m .47935 .92453 L .47905 .92454 L F
.47935 .92453 m .47875 .9245 L .47877 .92455 L .248 0 0 r
F
.47883 .92514 m .47935 .92453 L .4667 .91697 L .629 .015 0 r
F
.47886 .92543 m .4667 .91697 L .47886 .92543 L F
.47886 .92545 m .4667 .91697 L .4668 .91785 L F
.47886 .92543 m .4667 .91697 L .47886 .92545 L F
.47968 .92365 m .47981 .92348 L .47845 .92351 L .248 0 0 r
F
.47981 .92348 m .47921 .92344 L .47923 .92349 L .278 0 0 r
F
.4793 .92417 m .47981 .92348 L .4666 .91596 L .634 .017 0 r
F
.47935 .92453 m .4666 .91596 L .4667 .91697 L F
.47934 .92452 m .4666 .91596 L .47935 .92453 L F
.47947 .92428 m .4666 .91596 L .47959 .92468 L F
.4798 .92346 m .46651 .91483 L .47981 .92348 L .955 .406 0 r
F
.49095 .90655 m .46599 .90553 L .46607 .90737 L .406 0 0 r
F
.49095 .90655 m .49167 .90473 L .46599 .90553 L F
.4889 .84664 m .46656 .85376 L .46662 .85615 L .28 0 0 r
F
.4889 .84664 m .48949 .84432 L .46656 .85376 L F
.48831 .84885 m .46662 .85615 L .46669 .85842 L .247 0 0 r
F
.48831 .84885 m .4889 .84664 L .46662 .85615 L F
.49023 .90825 m .46607 .90737 L .46615 .9091 L .385 0 0 r
F
.49023 .90825 m .49095 .90655 L .46607 .90737 L F
.48771 .85093 m .46669 .85842 L .46675 .86058 L .211 0 0 r
F
.48771 .85093 m .48831 .84885 L .46669 .85842 L F
.48949 .90984 m .46615 .9091 L .46624 .91071 L .361 0 0 r
F
.48949 .90984 m .49023 .90825 L .46615 .9091 L F
.4871 .85289 m .46675 .86058 L .46682 .86263 L .171 0 0 r
F
.4871 .85289 m .48771 .85093 L .46675 .86058 L F
.48874 .91131 m .46624 .91071 L .46633 .9122 L .336 0 0 r
F
.48874 .91131 m .48949 .90984 L .46624 .91071 L F
.48647 .85474 m .46682 .86263 L .46689 .86456 L .128 0 0 r
F
.48647 .85474 m .4871 .85289 L .46682 .86263 L F
.48799 .91266 m .46633 .9122 L .46642 .91358 L .309 0 0 r
F
.48799 .91266 m .48874 .91131 L .46633 .9122 L F
.48584 .85646 m .46689 .86456 L .46697 .86639 L .082 0 0 r
F
.48584 .85646 m .48647 .85474 L .46689 .86456 L F
.48722 .91388 m .46642 .91358 L .46651 .91483 L .281 0 0 r
F
.48722 .91388 m .48799 .91266 L .46642 .91358 L F
.48519 .85806 m .46697 .86639 L .46704 .8681 L .032 0 0 r
F
.48519 .85806 m .48584 .85646 L .46697 .86639 L F
.48236 .86055 m .48519 .85806 L .48227 .85967 L 0 0 0 r
F
.48237 .8606 m .48249 .86049 L .48236 .86055 L F
.48249 .86049 m .48519 .85806 L .48236 .86055 L F
.5018 .92055 m .50242 .92005 L .50184 .92008 L .262 0 0 r
F
.50178 .92092 m .50184 .92008 L .50136 .92091 L F
.50242 .92005 m .50186 .92002 L .50184 .92008 L .289 0 0 r
F
.50136 .92091 m .50242 .92005 L .48799 .91266 L .72 .033 0 r
F
.50114 .92134 m .48799 .91266 L .50113 .92135 L F
.50111 .92136 m .48799 .91266 L .48722 .91388 L F
.50112 .92134 m .48799 .91266 L .50111 .92136 L F
.50265 .91955 m .48874 .91131 L .50242 .92001 L .899 .381 0 r
F
.50265 .91955 m .51079 .90971 L .48874 .91131 L F
.50242 .92005 m .48874 .91131 L .48799 .91266 L F
.50243 .92003 m .48874 .91131 L .50242 .92005 L F
.51545 .90495 m .49167 .90473 L .49095 .90655 L .356 0 0 r
F
.51545 .90495 m .51696 .90312 L .49167 .90473 L F
.51391 .90666 m .49095 .90655 L .49023 .90825 L .333 0 0 r
F
.51391 .90666 m .51545 .90495 L .49095 .90655 L F
.51236 .90824 m .49023 .90825 L .48949 .90984 L .309 0 0 r
F
.51236 .90824 m .51391 .90666 L .49023 .90825 L F
.51079 .90971 m .48949 .90984 L .48874 .91131 L .282 0 0 r
F
.51079 .90971 m .51236 .90824 L .48949 .90984 L F
.50596 .91337 m .49876 .85179 L .48645 .91499 L 1 .456 0 r
F
.48462 .85935 m .48519 .85806 L .48237 .8606 L 0 0 0 r
F
.50963 .83505 m .48949 .84432 L .4889 .84664 L .092 0 0 r
F
.50963 .83505 m .51082 .83286 L .48949 .84432 L F
.50842 .83711 m .4889 .84664 L .48831 .84885 L .039 0 0 r
F
.50842 .83711 m .50963 .83505 L .4889 .84664 L F
.50718 .83903 m .48831 .84885 L .48771 .85093 L 0 0 0 r
F
.50718 .83903 m .50842 .83711 L .48831 .84885 L F
.50591 .84082 m .48771 .85093 L .4871 .85289 L F
.50591 .84082 m .50718 .83903 L .48771 .85093 L F
.50463 .84248 m .4871 .85289 L .48647 .85474 L F
.50463 .84248 m .50591 .84082 L .4871 .85289 L F
.50071 .84586 m .48647 .85474 L .48584 .85646 L F
.5092 .91106 m .5008 .84573 L .50071 .84586 L .934 .633 0 r
F
.5008 .84573 m .50079 .84561 L .50071 .84586 L F
.50363 .9195 m .51079 .90971 L .50265 .91955 L .899 .381 0 r
F
.52693 .91601 m .52784 .9154 L .52725 .91545 L .259 0 0 r
F
.52668 .91644 m .52725 .91545 L .52628 .91645 L F
.52784 .9154 m .5273 .91538 L .52725 .91545 L .283 0 0 r
F
.52628 .91645 m .52784 .9154 L .51236 .90824 L .784 .043 0 r
F
.52575 .91699 m .51236 .90824 L .51079 .90971 L F
.52577 .91697 m .51236 .90824 L .52575 .91699 L F
.52835 .9148 m .51391 .90666 L .52785 .91536 L .838 .348 0 r
F
.52835 .9148 m .53688 .90432 L .51391 .90666 L F
.52784 .9154 m .51391 .90666 L .51236 .90824 L F
.52785 .91538 m .51391 .90666 L .52784 .9154 L F
.54149 .90073 m .51845 .90118 L .51696 .90312 L .317 0 0 r
F
.54149 .90073 m .54375 .89876 L .51845 .90118 L F
.5392 .90258 m .51696 .90312 L .51545 .90495 L .294 0 0 r
F
.5392 .90258 m .54149 .90073 L .51696 .90312 L F
.53688 .90432 m .51545 .90495 L .51391 .90666 L .27 0 0 r
F
.53688 .90432 m .5392 .90258 L .51545 .90495 L F
.52973 .90878 m .51693 .83487 L .5092 .91106 L 1 .692 0 r
F
.50082 .84556 m .50463 .84248 L .50129 .84473 L 0 0 0 r
F
.50101 .84543 m .50463 .84248 L .50082 .84556 L F
.50352 .84377 m .50463 .84248 L .50079 .84561 L F
.53006 .81959 m .51198 .83055 L .51082 .83286 L F
.53006 .81959 m .5318 .81751 L .51198 .83055 L F
.52829 .82154 m .51082 .83286 L .50963 .83505 L F
.52829 .82154 m .53006 .81959 L .51082 .83286 L F
.52648 .82333 m .50963 .83505 L .50842 .83711 L F
.52648 .82333 m .52829 .82154 L .50963 .83505 L F
.52463 .82498 m .50842 .83711 L .50718 .83903 L F
.52463 .82498 m .52648 .82333 L .51183 .8345 L F
.51222 .83426 m .51183 .8345 L .50842 .83711 L F
.52463 .82498 m .51183 .8345 L .51222 .83426 L F
.50204 .67108 m .49232 .6743 L .49159 .67474 L F
.50204 .67108 m .50314 .67067 L .50314 .67067 L F
.50204 .67108 m .50314 .67067 L .49232 .6743 L F
.50092 .67143 m .50204 .67108 L .49159 .67474 L .256 .181 0 r
F
.50094 .67149 m .50204 .67108 L .50092 .67143 L 1 .785 0 r
F
.55628 .90871 m .56489 .89758 L .54149 .90073 L .77 .307 0 r
F
.5679 .89556 m .54597 .89668 L .54375 .89876 L .266 0 0 r
F
.5679 .89556 m .57086 .89342 L .54597 .89668 L F
.55138 .80129 m .53515 .81294 L .53349 .81529 L 0 0 0 r
F
.54913 .80319 m .53349 .81529 L .5318 .81751 L F
.54913 .80319 m .55138 .80129 L .53722 .81237 L F
.54913 .80319 m .53722 .81237 L .53736 .81228 L F
.54913 .80319 m .53545 .81376 L .53627 .81314 L F
.54684 .80493 m .54913 .80319 L .53519 .81471 L .485 .202 0 r
F
.53543 .81447 m .53519 .81471 L .5318 .81751 L F
.54684 .80493 m .53519 .81471 L .53543 .81447 L F
.53168 .81818 m .5318 .81751 L .53006 .81959 L F
.54469 .80681 m .53529 .81461 L .53168 .81818 L F
.53529 .81461 m .5318 .81751 L .53168 .81818 L F
.54373 .80753 m .5318 .81751 L .54469 .80681 L F
.54684 .80493 m .54373 .80753 L .54469 .80681 L F
.54449 .80651 m .54684 .80493 L .54235 .80886 L .565 .216 0 r
F
.54098 .8097 m .54235 .80886 L .53006 .81959 L F
.54449 .80651 m .54235 .80886 L .54098 .8097 L F
.53627 .81314 m .53545 .81376 L .53349 .81529 L 0 0 0 r
F
.5231 .82619 m .50092 .67143 L .51992 .82875 L .874 .594 0 r
F
.53644 .81255 m .52648 .82333 L .52463 .82498 L .703 .374 0 r
F
.5365 .81249 m .52648 .82333 L .53644 .81255 L F
.53682 .81221 m .50204 .67108 L .53644 .81255 L 1 .785 0 r
F
.53682 .81221 m .53857 .81059 L .50204 .67108 L F
.53719 .81182 m .53682 .81221 L .53685 .81211 L .703 .374 0 r
F
.53682 .81221 m .52648 .82333 L .53642 .81258 L F
.54038 .81033 m .53006 .81959 L .52829 .82154 L .565 .216 0 r
F
.56489 .89758 m .54375 .89876 L .54149 .90073 L .243 0 0 r
F
.56489 .89758 m .5679 .89556 L .54375 .89876 L F
.55565 .90291 m .55877 .90126 L .53685 .81418 L 1 .786 0 r
F
.54005 .81054 m .53006 .81959 L .54038 .81033 L .565 .216 0 r
F
.54449 .80651 m .54005 .81054 L .54038 .81033 L F
.51607 .66591 m .50639 .66907 L .50532 .66967 L 0 0 0 r
F
.51608 .6659 m .51607 .6659 L .51607 .66591 L F
.51607 .6659 m .50639 .66907 L .51607 .66591 L F
.51465 .66644 m .50532 .66967 L .50424 .6702 L F
.51321 .66691 m .51465 .66644 L .50424 .6702 L .265 .182 0 r
F
.51334 .66729 m .51465 .66644 L .51321 .66691 L .737 .497 0 r
F
.59421 .88938 m .57377 .89117 L .57086 .89342 L .202 0 0 r
F
.59421 .88938 m .59781 .88705 L .57377 .89117 L F
.59055 .89159 m .57086 .89342 L .5679 .89556 L .179 0 0 r
F
.59055 .89159 m .59421 .88938 L .57086 .89342 L F
.56662 .7867 m .56935 .78503 L .55357 .79924 L .619 .225 0 r
F
.56383 .7882 m .55138 .80129 L .54913 .80319 L .683 .368 0 r
F
.56383 .7882 m .56662 .7867 L .55138 .80129 L F
.5571 .79374 m .54913 .80319 L .54684 .80493 L .736 .577 0 r
F
.56097 .78952 m .55771 .79328 L .5571 .79374 L F
.55771 .79328 m .54913 .80319 L .5571 .79374 L F
.55467 .79461 m .54684 .80493 L .54449 .80651 L .846 .764 0 r
F
.55468 .7946 m .55446 .79392 L .55467 .79461 L .737 .497 0 r
F
.55446 .79392 m .5147 .6666 L .55446 .79393 L F
.55446 .79392 m .55446 .79393 L .55467 .79461 L F
.54264 .80761 m .5426 .80743 L .53912 .81087 L .81 .552 0 r
F
.51465 .66644 m .51608 .6659 L .50532 .66967 L 0 0 0 r
F
.5426 .80743 m .51321 .66691 L .53912 .81087 L .81 .552 0 r
F
.54186 .80835 m .54449 .80651 L .54111 .80965 L .638 .226 0 r
F
.54188 .80831 m .54194 .80827 L .54186 .80835 L F
.54194 .80827 m .54449 .80651 L .54186 .80835 L F
.56486 .90776 m .56489 .89758 L .55628 .90871 L .77 .307 0 r
F
.56097 .78952 m .56383 .7882 L .56037 .79172 L .736 .577 0 r
F
.55819 .79273 m .56037 .79172 L .54913 .80319 L F
.56097 .78952 m .56037 .79172 L .55819 .79273 L F
.55524 .79423 m .54684 .80493 L .55467 .79461 L .846 .764 0 r
F
.51749 .66531 m .50746 .66843 L .50639 .66907 L 0 0 0 r
F
.51749 .66531 m .51889 .66466 L .50746 .66843 L F
.52936 .66066 m .52028 .66395 L .51889 .66466 L F
.52936 .66066 m .53106 .65991 L .52028 .66395 L F
.51608 .6659 m .51749 .66531 L .50639 .66907 L F
.52765 .66134 m .51889 .66466 L .51749 .66531 L F
.52765 .66134 m .52936 .66066 L .51889 .66466 L F
.52592 .66196 m .52765 .66134 L .52765 .66134 L .28 .184 0 r
F
.52592 .66196 m .52765 .66134 L .51749 .66531 L F
.51764 .66525 m .51749 .66531 L .51608 .6659 L F
.52418 .66252 m .52592 .66196 L .51608 .6659 L .321 .192 0 r
F
.5242 .66258 m .52592 .66196 L .52418 .66252 L .653 .436 0 r
F
.62826 .87697 m .60832 .87937 L .60487 .88205 L .163 0 0 r
F
.62826 .87697 m .63233 .87419 L .60832 .87937 L F
.62412 .87963 m .60487 .88205 L .60137 .88461 L .144 0 0 r
F
.62412 .87963 m .62826 .87697 L .60487 .88205 L F
.61993 .88218 m .60137 .88461 L .59781 .88705 L .123 0 0 r
F
.61993 .88218 m .62412 .87963 L .60137 .88461 L F
.61567 .88461 m .59781 .88705 L .59421 .88938 L .1 0 0 r
F
.61567 .88461 m .61993 .88218 L .59781 .88705 L F
.58252 .77089 m .57203 .7832 L .56935 .78503 L .729 .622 0 r
F
.57926 .77216 m .56935 .78503 L .56662 .7867 L .833 .801 0 r
F
.57926 .77216 m .58252 .77089 L .56935 .78503 L F
.57222 .77782 m .56662 .7867 L .56383 .7882 L .926 .947 0 r
F
.57592 .77324 m .57306 .77737 L .57222 .77782 L F
.57306 .77737 m .56662 .7867 L .57222 .77782 L F
.56923 .77849 m .56383 .7882 L .56097 .78952 L 1 1 0 r
F
.56924 .77849 m .569 .77784 L .56923 .77849 L .653 .436 0 r
F
.569 .77784 m .52592 .66196 L .56899 .77784 L F
.569 .77784 m .56899 .77784 L .56923 .77849 L F
.55883 .79035 m .52418 .66252 L .55524 .79423 L .737 .497 0 r
F
.57004 .77813 m .56383 .7882 L .56923 .77849 L 1 1 0 r
F
.57592 .77324 m .57926 .77216 L .56662 .7867 L .926 .947 0 r
F
.53439 .65825 m .52434 .66147 L .523 .66235 L 0 0 0 r
F
.53439 .65825 m .53603 .65734 L .52434 .66147 L F
.53273 .65911 m .523 .66235 L .52165 .66318 L F
.53273 .65911 m .53439 .65825 L .523 .66235 L F
.53106 .65991 m .52165 .66318 L .52028 .66395 L F
.53106 .65991 m .53273 .65911 L .52165 .66318 L F
.5446 .65389 m .53603 .65734 L .53439 .65825 L F
.54267 .6548 m .53439 .65825 L .53273 .65911 L F
.54267 .6548 m .5446 .65389 L .53439 .65825 L F
.54072 .65566 m .53273 .65911 L .53106 .65991 L F
.54072 .65566 m .54267 .6548 L .53273 .65911 L F
.53875 .65646 m .53106 .65991 L .52936 .66066 L .31 .188 0 r
F
.53875 .65646 m .54072 .65566 L .53106 .65991 L F
.53676 .6572 m .52936 .66066 L .52765 .66134 L .343 .195 0 r
F
.53676 .6572 m .53875 .65646 L .53874 .65646 L F
.53676 .6572 m .53874 .65646 L .52936 .66066 L F
.53474 .65787 m .53676 .6572 L .52765 .66134 L .377 .2 0 r
F
.53477 .65793 m .53676 .6572 L .53474 .65787 L .557 .368 0 r
F
.58885 .76781 m .59192 .76602 L .57719 .77909 L .619 .227 0 r
F
.65392 .86824 m .63634 .8713 L .63233 .87419 L .065 0 0 r
F
.58572 .76944 m .57464 .78122 L .57203 .7832 L .676 .419 0 r
F
.58572 .76944 m .58885 .76781 L .57464 .78122 L F
.64927 .87115 m .63233 .87419 L .62826 .87697 L .046 0 0 r
F
.64927 .87115 m .65392 .86824 L .63233 .87419 L F
.58252 .77089 m .58572 .76944 L .57203 .7832 L .729 .622 0 r
F
.64455 .87394 m .62826 .87697 L .62412 .87963 L .025 0 0 r
F
.64455 .87394 m .64927 .87115 L .62826 .87697 L F
.63976 .87661 m .62412 .87963 L .61993 .88218 L .004 0 0 r
F
.63976 .87661 m .64455 .87394 L .62412 .87963 L F
.59697 .75628 m .58885 .76781 L .58572 .76944 L .838 .867 0 r
F
.58947 .76217 m .58572 .76944 L .58252 .77089 L .914 .989 0 r
F
.59327 .75739 m .59059 .76166 L .58947 .76217 L F
.59059 .76166 m .58572 .76944 L .58947 .76217 L F
.58255 .7635 m .57926 .77216 L .57592 .77324 L 1 1 0 r
F
.58258 .76349 m .58234 .76293 L .58255 .7635 L .557 .368 0 r
F
.58234 .76293 m .53676 .6572 L .58231 .76294 L F
.58234 .76293 m .58231 .76294 L .58255 .7635 L F
.57353 .77385 m .53474 .65787 L .57004 .77813 L .653 .436 0 r
F
.58361 .76316 m .57926 .77216 L .58255 .7635 L 1 1 0 r
F
.58636 .76253 m .58252 .77089 L .57926 .77216 L .978 1 0 r
F
.58948 .7583 m .58742 .76203 L .58636 .76253 L F
.58742 .76203 m .58252 .77089 L .58636 .76253 L F
.58948 .7583 m .59327 .75739 L .58252 .77089 L F
.55025 .6508 m .54083 .65426 L .53925 .65534 L 0 0 0 r
F
.54839 .65189 m .53925 .65534 L .53765 .65637 L F
.54839 .65189 m .55025 .6508 L .53925 .65534 L F
.5465 .65291 m .53765 .65637 L .53603 .65734 L F
.5465 .65291 m .54839 .65189 L .53765 .65637 L F
.5446 .65389 m .5465 .65291 L .53603 .65734 L F
.55565 .64825 m .54839 .65189 L .5465 .65291 L F
.55351 .6493 m .5465 .65291 L .5446 .65389 L .334 .189 0 r
F
.55134 .65029 m .5446 .65389 L .54267 .6548 L .36 .195 0 r
F
.55776 .64714 m .55025 .6508 L .54839 .65189 L 0 0 0 r
F
.55134 .65029 m .55351 .6493 L .5446 .65389 L .36 .195 0 r
F
.54915 .65123 m .54267 .6548 L .54072 .65566 L .385 .2 0 r
F
.54915 .65123 m .55134 .65029 L .54267 .6548 L F
.54694 .65211 m .54072 .65566 L .53875 .65646 L .411 .205 0 r
F
.54694 .65211 m .54915 .65123 L .54915 .65123 L F
.54694 .65211 m .54915 .65123 L .54072 .65566 L F
.5447 .65292 m .54694 .65211 L .53875 .65646 L .436 .209 0 r
F
.54473 .65298 m .54694 .65211 L .5447 .65292 L .445 .287 0 r
F
.663 .86209 m .64417 .8652 L .64029 .8683 L .102 0 0 r
F
.663 .86209 m .66744 .85885 L .64417 .8652 L F
.6585 .86522 m .64029 .8683 L .63634 .8713 L .084 0 0 r
F
.6585 .86522 m .663 .86209 L .64029 .8683 L F
.62081 .74369 m .60882 .75235 L .60618 .75494 L 0 0 0 r
F
.62081 .74369 m .62392 .74132 L .6131 .74923 L F
.62081 .74369 m .6131 .74923 L .61276 .74951 L F
.61763 .74593 m .62081 .74369 L .60618 .75494 L .465 .202 0 r
F
.61763 .74593 m .60618 .75494 L .60346 .75742 L F
.60999 .7518 m .60346 .75742 L .60068 .75977 L .528 .214 0 r
F
.61438 .74804 m .61037 .75148 L .60999 .7518 L F
.61037 .75148 m .60346 .75742 L .60999 .7518 L F
.61276 .74951 m .6131 .74923 L .60882 .75235 L 0 0 0 r
F
.65392 .86824 m .6585 .86522 L .63634 .8713 L .065 0 0 r
F
.61105 .75001 m .60068 .75977 L .59783 .76199 L .586 .224 0 r
F
.61105 .75001 m .61438 .74804 L .60068 .75977 L F
.60765 .75183 m .59783 .76199 L .59491 .76408 L .639 .343 0 r
F
.60765 .75183 m .61105 .75001 L .59783 .76199 L F
.60417 .75348 m .59491 .76408 L .59192 .76602 L .683 .536 0 r
F
.60417 .75348 m .60765 .75183 L .59491 .76408 L F
.60061 .75497 m .59192 .76602 L .58885 .76781 L .75 .714 0 r
F
.60061 .75497 m .60417 .75348 L .59192 .76602 L F
.59697 .75628 m .60061 .75497 L .58885 .76781 L .838 .867 0 r
F
.67272 .86159 m .6585 .86522 L .65392 .86824 L 0 0 0 r
F
.55565 .64825 m .55776 .64714 L .54839 .65189 L F
.55351 .6493 m .55565 .64825 L .5465 .65291 L .334 .189 0 r
F
.66755 .86466 m .65392 .86824 L .64927 .87115 L 0 0 0 r
F
.66755 .86466 m .67272 .86159 L .65392 .86824 L F
.66231 .8676 m .64927 .87115 L .64455 .87394 L F
.66231 .8676 m .66755 .86466 L .64927 .87115 L F
.60262 .7487 m .60061 .75497 L .59697 .75628 L .907 1 0 r
F
.60602 .74413 m .60398 .7482 L .60262 .7487 L F
.60398 .7482 m .60061 .75497 L .60262 .7487 L F
.5948 .74996 m .59327 .75739 L .58948 .7583 L .987 1 0 r
F
.59483 .74996 m .59461 .74951 L .5948 .74996 L .445 .287 0 r
F
.59461 .74951 m .54694 .65211 L .59458 .74951 L F
.59461 .74951 m .59458 .74951 L .5948 .74996 L F
.5869 .75876 m .5447 .65292 L .58361 .76316 L .557 .368 0 r
F
.5961 .74964 m .59327 .75739 L .5948 .74996 L .987 1 0 r
F
.59327 .75739 m .59697 .75628 L .58572 .76944 L .914 .989 0 r
F
.59901 .74908 m .59697 .75628 L .59327 .75739 L .952 1 0 r
F
.60184 .74498 m .60028 .7486 L .59901 .74908 L F
.60028 .7486 m .59697 .75628 L .59901 .74908 L F
.60184 .74498 m .60602 .74413 L .59697 .75628 L F
.55569 .64723 m .54545 .65071 L .54393 .65194 L 0 0 0 r
F
.55569 .64723 m .55746 .64594 L .54545 .65071 L F
.5539 .64848 m .54393 .65194 L .54239 .65313 L F
.5539 .64848 m .55569 .64723 L .54393 .65194 L F
.55209 .64967 m .54239 .65313 L .54083 .65426 L F
.55209 .64967 m .5539 .64848 L .54239 .65313 L F
.55025 .6508 m .55209 .64967 L .54083 .65426 L F
.56394 .6435 m .55569 .64723 L .5539 .64848 L F
.56191 .64477 m .5539 .64848 L .55209 .64967 L F
.56191 .64477 m .56394 .6435 L .5539 .64848 L F
.55985 .64598 m .55209 .64967 L .55025 .6508 L F
.55985 .64598 m .56191 .64477 L .55209 .64967 L F
.55776 .64714 m .55985 .64598 L .55025 .6508 L F
.56595 .64218 m .55746 .64594 L .55569 .64723 L F
.56394 .6435 m .56595 .64218 L .55569 .64723 L F
.56101 .64455 m .55565 .64825 L .55351 .6493 L .448 .208 0 r
F
.55865 .64564 m .55351 .6493 L .55134 .65029 L .466 .211 0 r
F
.55865 .64564 m .56101 .64455 L .55351 .6493 L F
.55626 .64667 m .55134 .65029 L .54915 .65123 L .483 .214 0 r
F
.55626 .64667 m .55865 .64564 L .55134 .65029 L F
.55384 .64764 m .54915 .65123 L .54694 .65211 L .499 .217 0 r
F
.55384 .64764 m .55626 .64667 L .54915 .65123 L F
.5961 .74964 m .55384 .64764 L .54694 .65211 L .445 .287 0 r
F
.59807 .7472 m .60184 .74498 L .59876 .74944 L .987 1 0 r
F
.598 .74695 m .5983 .74679 L .59807 .7472 L F
.5983 .74679 m .60184 .74498 L .59807 .7472 L F
.61438 .74804 m .61763 .74593 L .60346 .75742 L .528 .214 0 r
F
.68775 .85173 m .6718 .8555 L .66744 .85885 L 0 0 0 r
F
.68282 .85513 m .66744 .85885 L .663 .86209 L F
.68282 .85513 m .68775 .85173 L .66744 .85885 L F
.67781 .85842 m .663 .86209 L .6585 .86522 L F
.67781 .85842 m .68282 .85513 L .663 .86209 L F
.67272 .86159 m .67781 .85842 L .6585 .86522 L F
.61806 .74036 m .61105 .75001 L .60765 .75183 L .714 .696 0 r
F
.61413 .74181 m .60765 .75183 L .60417 .75348 L .787 .834 0 r
F
.61413 .74181 m .61806 .74036 L .60765 .75183 L F
.61011 .74307 m .60417 .75348 L .60061 .75497 L .852 .947 0 r
F
.61011 .74307 m .61413 .74181 L .60417 .75348 L F
.60602 .74413 m .61011 .74307 L .60061 .75497 L .907 1 0 r
F
.61311 .73329 m .61011 .74307 L .60602 .74413 L .888 1 0 r
F
.68279 .8576 m .67272 .86159 L .66755 .86466 L 0 0 0 r
F
.60853 .73397 m .60602 .74413 L .60184 .74498 L .914 1 0 r
F
.60853 .73397 m .61311 .73329 L .60602 .74413 L F
.67709 .86072 m .66755 .86466 L .66231 .8676 L 0 0 0 r
F
.67709 .86072 m .68279 .8576 L .66755 .86466 L F
.60313 .73829 m .6031 .73825 L .60312 .73829 L .342 .178 0 r
F
.6031 .73825 m .55384 .64764 L .59909 .74538 L F
.60313 .73829 m .60184 .74498 L .59909 .74538 L .932 1 0 r
F
.59909 .74538 m .60184 .74498 L .598 .74695 L .987 1 0 r
F
.60256 .74122 m .60853 .73397 L .60184 .74498 L .932 1 0 r
F
.60313 .73829 m .60424 .7374 L .60256 .74122 L F
.60424 .7374 m .60853 .73397 L .60256 .74122 L F
.69738 .84461 m .6803 .8485 L .67609 .85205 L .013 0 0 r
F
.69261 .84822 m .67609 .85205 L .6718 .8555 L 0 0 0 r
F
.69261 .84822 m .69738 .84461 L .67609 .85205 L F
.68775 .85173 m .69261 .84822 L .6718 .8555 L F
.62938 .73503 m .62081 .74369 L .61763 .74593 L .592 .225 0 r
F
.62569 .73696 m .61763 .74593 L .61438 .74804 L .633 .372 0 r
F
.62569 .73696 m .62938 .73503 L .61763 .74593 L F
.62191 .73875 m .61438 .74804 L .61105 .75001 L .668 .539 0 r
F
.62191 .73875 m .62569 .73696 L .61438 .74804 L F
.61806 .74036 m .62191 .73875 L .61105 .75001 L .714 .696 0 r
F
.62202 .73125 m .61806 .74036 L .61413 .74181 L .816 .938 0 r
F
.61761 .73237 m .61413 .74181 L .61011 .74307 L .856 1 0 r
F
.61761 .73237 m .62202 .73125 L .61413 .74181 L F
.61311 .73329 m .61761 .73237 L .61011 .74307 L .888 1 0 r
F
.61167 .72818 m .61311 .73329 L .60853 .73397 L .832 1 0 r
F
.56092 .64321 m .56261 .64177 L .54988 .6467 L .037 0 0 r
F
.5718 .63792 m .56261 .64177 L .56092 .64321 L 0 0 0 r
F
.56988 .63939 m .56092 .64321 L .5592 .6446 L F
.56988 .63939 m .5718 .63792 L .56092 .64321 L F
.56793 .64081 m .5592 .6446 L .55746 .64594 L F
.56793 .64081 m .56988 .63939 L .5592 .6446 L F
.56595 .64218 m .56793 .64081 L .55746 .64594 L F
.57238 .63826 m .56595 .64218 L .56394 .6435 L F
.57017 .63962 m .57238 .63826 L .56394 .6435 L .375 .191 0 r
F
.57017 .63962 m .56394 .6435 L .56191 .64477 L F
.56792 .64094 m .56191 .64477 L .55985 .64598 L .394 .196 0 r
F
.56792 .64094 m .57017 .63962 L .56191 .64477 L F
.56565 .64219 m .55985 .64598 L .55776 .64714 L .412 .2 0 r
F
.56565 .64219 m .56792 .64094 L .55985 .64598 L F
.56334 .6434 m .55776 .64714 L .55565 .64825 L .43 .204 0 r
F
.56334 .6434 m .56565 .64219 L .55776 .64714 L F
.56101 .64455 m .56334 .6434 L .55565 .64825 L .448 .208 0 r
F
.5718 .63792 m .5737 .63641 L .56261 .64177 L 0 0 0 r
F
.56703 .63968 m .56334 .6434 L .56101 .64455 L .549 .222 0 r
F
.56451 .64089 m .56101 .64455 L .55865 .64564 L .558 .246 0 r
F
.56451 .64089 m .56703 .63968 L .56101 .64455 L F
.56196 .64203 m .56451 .64089 L .56451 .64089 L .567 .301 0 r
F
.56092 .64321 m .54988 .6467 L .54842 .64808 L .037 0 0 r
F
.5592 .6446 m .56092 .64321 L .54842 .64808 L .014 0 0 r
F
.56196 .64203 m .56451 .64089 L .55865 .64564 L .567 .301 0 r
F
.5592 .6446 m .54842 .64808 L .54695 .64942 L .014 0 0 r
F
.55746 .64594 m .54695 .64942 L .54545 .65071 L 0 0 0 r
F
.55746 .64594 m .5592 .6446 L .54695 .64942 L F
.55939 .64312 m .56196 .64203 L .55626 .64667 L .575 .359 0 r
F
.55942 .64317 m .56196 .64203 L .55939 .64312 L .248 .08 0 r
F
.56196 .64203 m .55865 .64564 L .55626 .64667 L .567 .301 0 r
F
.61167 .72818 m .56196 .64203 L .55942 .64317 L .248 .08 0 r
F
.61342 .7279 m .56196 .64203 L .61167 .72818 L F
.56261 .64177 m .55131 .64527 L .54988 .6467 L .058 0 0 r
F
.56261 .64177 m .56428 .64028 L .55131 .64527 L F
.70207 .8409 m .68444 .84485 L .6803 .8485 L .028 0 0 r
F
.5774 .63323 m .56754 .63716 L .56592 .63874 L 0 0 0 r
F
.69738 .84461 m .70207 .8409 L .6803 .8485 L .013 0 0 r
F
.57557 .63484 m .56592 .63874 L .56428 .64028 L 0 0 0 r
F
.57557 .63484 m .5774 .63323 L .56592 .63874 L F
.5737 .63641 m .56428 .64028 L .56261 .64177 L F
.5737 .63641 m .57557 .63484 L .56428 .64028 L F
.64663 .72336 m .63558 .73073 L .63278 .73354 L F
.64334 .72594 m .63278 .73354 L .6299 .73624 L F
.63997 .7284 m .64334 .72594 L .6299 .73624 L .448 .199 0 r
F
.63997 .7284 m .6299 .73624 L .62694 .73884 L F
.63155 .73492 m .62694 .73884 L .62392 .74132 L .498 .209 0 r
F
.63652 .73074 m .63242 .7342 L .63155 .73492 L F
.63242 .7342 m .62694 .73884 L .63155 .73492 L F
.64334 .72594 m .64663 .72336 L .63768 .72994 L 0 0 0 r
F
.63688 .73058 m .63768 .72994 L .63278 .73354 L F
.64334 .72594 m .63768 .72994 L .63688 .73058 L F
.63299 .73295 m .62392 .74132 L .62081 .74369 L .547 .218 0 r
F
.63299 .73295 m .63652 .73074 L .62392 .74132 L F
.62938 .73503 m .63299 .73295 L .62081 .74369 L .592 .225 0 r
F
.57672 .63538 m .56988 .63939 L .56793 .64081 L 0 0 0 r
F
.57457 .63685 m .56793 .64081 L .56595 .64218 L F
.57457 .63685 m .57672 .63538 L .56793 .64081 L F
.57238 .63826 m .57457 .63685 L .56595 .64218 L F
.63059 .72841 m .62569 .73696 L .62191 .73875 L .716 .74 0 r
F
.58094 .63231 m .5737 .63641 L .5718 .63792 L 0 0 0 r
F
.57885 .63387 m .5718 .63792 L .56988 .63939 L F
.57885 .63387 m .58094 .63231 L .5718 .63792 L F
.57672 .63538 m .57885 .63387 L .56988 .63939 L F
.57439 .63574 m .57017 .63962 L .56792 .64094 L .52 .216 0 r
F
.62635 .72992 m .62191 .73875 L .61806 .74036 L .769 .847 0 r
F
.62635 .72992 m .63059 .72841 L .62191 .73875 L F
.57196 .63711 m .56792 .64094 L .56565 .64219 L .53 .218 0 r
F
.57196 .63711 m .57439 .63574 L .56792 .64094 L F
.56951 .63842 m .56565 .64219 L .56334 .6434 L .54 .22 0 r
F
.56951 .63842 m .57196 .63711 L .56565 .64219 L F
.62202 .73125 m .62635 .72992 L .61806 .74036 L .816 .938 0 r
F
.56703 .63968 m .56951 .63842 L .56334 .6434 L .549 .222 0 r
F
.57921 .63158 m .56913 .63554 L .56754 .63716 L 0 0 0 r
F
.5774 .63323 m .57921 .63158 L .56754 .63716 L F
.57148 .63477 m .56951 .63842 L .56703 .63968 L .635 .429 0 r
F
.56886 .6361 m .56703 .63968 L .56451 .64089 L .636 .47 0 r
F
.56886 .6361 m .57148 .63477 L .56703 .63968 L F
.5662 .63738 m .56451 .64089 L .56196 .64203 L .637 .512 0 r
F
.5662 .63738 m .56886 .6361 L .56451 .64089 L F
.62332 .72308 m .62202 .73125 L .61761 .73237 L .804 .984 0 r
F
.61638 .72764 m .61761 .73237 L .61311 .73329 L .82 1 0 r
F
.61851 .72396 m .61816 .72726 L .61638 .72764 L F
.61816 .72726 m .61761 .73237 L .61638 .72764 L F
.61342 .7279 m .61311 .73329 L .61167 .72818 L .832 1 0 r
F
.61192 .72859 m .61342 .7279 L .61167 .72818 L .248 .08 0 r
F
.61342 .7279 m .5662 .63738 L .56196 .64203 L F
.61342 .7279 m .61357 .72778 L .61311 .73329 L .832 1 0 r
F
.63652 .73074 m .63997 .7284 L .62694 .73884 L .498 .209 0 r
F
.63474 .72673 m .62938 .73503 L .62569 .73696 L .671 .617 0 r
F
.63059 .72841 m .63474 .72673 L .62569 .73696 L .716 .74 0 r
F
.62805 .72198 m .62635 .72992 L .62202 .73125 L .783 .936 0 r
F
.62332 .72308 m .62805 .72198 L .62202 .73125 L .804 .984 0 r
F
.61851 .72396 m .62332 .72308 L .61761 .73237 L .82 1 0 r
F
.6224 .7163 m .62332 .72308 L .61851 .72396 L .718 .925 0 r
F
.61776 .71972 m .61738 .71912 L .61773 .71978 L .117 .063 0 r
F
.61738 .71912 m .5662 .63738 L .61549 .72435 L F
.61776 .71972 m .61851 .72396 L .61549 .72435 L .715 .939 0 r
F
.61429 .72768 m .61851 .72396 L .61653 .72737 L .832 1 0 r
F
.61452 .72704 m .61851 .72396 L .61429 .72768 L F
.61549 .72435 m .61851 .72396 L .61342 .7279 L F
.61814 .72189 m .6224 .7163 L .61851 .72396 L .715 .939 0 r
F
.61776 .71972 m .61879 .71896 L .61814 .72189 L F
.61879 .71896 m .6224 .7163 L .61814 .72189 L F
.65298 .71789 m .64098 .72485 L .63832 .72784 L 0 0 0 r
F
.65298 .71789 m .65604 .71501 L .64098 .72485 L F
.64984 .72068 m .63832 .72784 L .63558 .73073 L F
.64984 .72068 m .65298 .71789 L .63832 .72784 L F
.64663 .72336 m .64984 .72068 L .63558 .73073 L F
.6428 .72289 m .63652 .73074 L .63299 .73295 L .624 .347 0 r
F
.63881 .72488 m .63299 .73295 L .62938 .73503 L .649 .484 0 r
F
.63881 .72488 m .6428 .72289 L .63299 .73295 L F
.63474 .72673 m .63881 .72488 L .62938 .73503 L .671 .617 0 r
F
.63269 .72067 m .63059 .72841 L .62635 .72992 L .757 .876 0 r
F
.62805 .72198 m .63269 .72067 L .62635 .72992 L .783 .936 0 r
F
.62743 .71533 m .62805 .72198 L .62332 .72308 L .718 .901 0 r
F
.6224 .7163 m .62743 .71533 L .62332 .72308 L .718 .925 0 r
F
.62492 .71038 m .62743 .71533 L .6224 .7163 L .594 .762 0 r
F
.62075 .71327 m .62023 .71245 L .62073 .71333 L 0 .04 0 r
F
.58099 .62988 m .5707 .63387 L .56913 .63554 L 0 0 0 r
F
.57921 .63158 m .58099 .62988 L .56913 .63554 L F
.583 .6307 m .57557 .63484 L .5737 .63641 L F
.583 .6307 m .58502 .62904 L .57557 .63484 L F
.58094 .63231 m .583 .6307 L .5737 .63641 L F
.57913 .63284 m .57457 .63685 L .57238 .63826 L .499 .21 0 r
F
.57677 .63431 m .57238 .63826 L .57017 .63962 L .51 .213 0 r
F
.57677 .63431 m .57913 .63284 L .57238 .63826 L F
.57439 .63574 m .57677 .63431 L .57017 .63962 L .52 .216 0 r
F
.57408 .63339 m .57196 .63711 L .56951 .63842 L .633 .387 0 r
F
.57148 .63477 m .57408 .63339 L .56951 .63842 L .635 .429 0 r
F
.58274 .62814 m .57224 .63215 L .5707 .63387 L .001 0 0 r
F
.58099 .62988 m .58274 .62814 L .5707 .63387 L 0 0 0 r
F
.57164 .63135 m .57148 .63477 L .56886 .6361 L .713 .681 0 r
F
.56891 .63276 m .57164 .63135 L .56886 .6361 L .713 .704 0 r
F
.62023 .71245 m .56891 .63276 L .61928 .71673 L 0 .04 0 r
F
.62075 .71327 m .6224 .7163 L .61928 .71673 L .569 .76 0 r
F
.61928 .71673 m .56891 .63276 L .61776 .71972 L .117 .063 0 r
F
.61728 .71702 m .61928 .71673 L .61776 .71972 L .715 .939 0 r
F
.61928 .71673 m .61929 .71673 L .61776 .71972 L F
.56891 .63276 m .56886 .6361 L .5662 .63738 L .713 .704 0 r
F
.61776 .71972 m .56891 .63276 L .5662 .63738 L .117 .063 0 r
F
.61929 .71673 m .6224 .7163 L .61776 .71972 L .715 .939 0 r
F
.69671 .84583 m .61928 .71673 L .61776 .71972 L .117 .063 0 r
F
.62023 .71245 m .61928 .71673 L .61929 .71674 L 0 .04 0 r
F
.58274 .62814 m .58446 .62636 L .57224 .63215 L .001 0 0 r
F
.58502 .62904 m .5774 .63323 L .57557 .63484 L 0 0 0 r
F
.58502 .62904 m .58702 .62734 L .5774 .63323 L F
.58373 .62973 m .57885 .63387 L .57672 .63538 L .476 .204 0 r
F
.58145 .63131 m .57672 .63538 L .57457 .63685 L .488 .207 0 r
F
.58145 .63131 m .58373 .62973 L .57672 .63538 L F
.57913 .63284 m .58145 .63131 L .57457 .63685 L .499 .21 0 r
F
.58702 .62734 m .57921 .63158 L .5774 .63323 L 0 0 0 r
F
.57915 .63045 m .57677 .63431 L .57439 .63574 L .629 .304 0 r
F
.57663 .63194 m .57439 .63574 L .57196 .63711 L .631 .345 0 r
F
.57663 .63194 m .57915 .63045 L .57439 .63574 L F
.57408 .63339 m .57663 .63194 L .57196 .63711 L .633 .387 0 r
F
.57698 .62836 m .57663 .63194 L .57408 .63339 L .711 .633 0 r
F
.57433 .62988 m .57408 .63339 L .57148 .63477 L .712 .657 0 r
F
.57433 .62988 m .57698 .62836 L .57408 .63339 L F
.57164 .63135 m .57433 .62988 L .57148 .63477 L .713 .681 0 r
F
.57282 .62669 m .57433 .62988 L .57164 .63135 L .833 .858 0 r
F
.57007 .62825 m .57282 .62669 L .57164 .63135 L .825 .866 0 r
F
.56966 .6239 m .57282 .62669 L .57133 .62753 L .923 .995 0 r
F
.56966 .6239 m .57133 .62753 L .57007 .62825 L F
.6467 .72074 m .63997 .7284 L .63652 .73074 L .595 .226 0 r
F
.6428 .72289 m .6467 .72074 L .63652 .73074 L .624 .347 0 r
F
.59091 .62381 m .58274 .62814 L .58099 .62988 L 0 0 0 r
F
.58898 .6256 m .58099 .62988 L .57921 .63158 L F
.58898 .6256 m .59091 .62381 L .58099 .62988 L F
.58702 .62734 m .58898 .6256 L .57921 .63158 L F
.58164 .6289 m .57913 .63284 L .57677 .63431 L .626 .264 0 r
F
.57915 .63045 m .58164 .6289 L .57677 .63431 L .629 .304 0 r
F
.6417 .71749 m .63881 .72488 L .63474 .72673 L .694 .719 0 r
F
.63723 .71917 m .63474 .72673 L .63059 .72841 L .727 .803 0 r
F
.63723 .71917 m .6417 .71749 L .63474 .72673 L F
.63269 .72067 m .63723 .71917 L .63059 .72841 L .757 .876 0 r
F
.63237 .71414 m .63269 .72067 L .62805 .72198 L .715 .87 0 r
F
.62743 .71533 m .63237 .71414 L .62805 .72198 L .718 .901 0 r
F
.56966 .6239 m .57238 .62218 L .57282 .62669 L .923 .995 0 r
F
.63005 .7092 m .63237 .71414 L .62743 .71533 L .614 .759 0 r
F
.62492 .71038 m .63005 .7092 L .62743 .71533 L .594 .762 0 r
F
.56767 .61976 m .57238 .62218 L .56966 .6239 L 1 1 0 r
F
.62607 .70622 m .63005 .7092 L .62492 .71038 L .533 .533 0 r
F
.62374 .70955 m .62607 .70622 L .62492 .71038 L .496 .487 0 r
F
.62181 .70767 m .56966 .6239 L .57007 .62825 L 0 .009 0 r
F
.62244 .70863 m .62187 .7055 L .62181 .70767 L F
.62373 .70954 m .62285 .70703 L .62374 .70955 L .496 .487 0 r
F
.62244 .70863 m .62284 .70703 L .62373 .70954 L F
.62284 .70703 m .62285 .70703 L .62373 .70954 L F
.62285 .70703 m .62607 .70622 L .62374 .70955 L F
.62206 .70482 m .56966 .6239 L .62284 .70703 L 0 0 0 r
F
.62269 .70579 m .62607 .70622 L .62285 .70703 L .455 .22 0 r
F
.62269 .70579 m .62285 .70703 L .62284 .70703 L F
.62269 .70579 m .62158 .70344 L .62206 .70482 L 0 0 0 r
F
.62269 .70579 m .6257 .70371 L .62607 .70622 L .455 .22 0 r
F
.6225 .70488 m .62158 .70344 L .62269 .70579 L 0 0 0 r
F
.62206 .70482 m .62284 .70703 L .623 .70728 L F
.6227 .70582 m .623 .70728 L .70176 .83039 L F
.62206 .70482 m .623 .70728 L .6227 .70582 L F
.62269 .70579 m .62206 .70482 L .6227 .70582 L F
.62284 .70703 m .62187 .7055 L .62244 .70863 L 0 .009 0 r
F
.62187 .7055 m .56966 .6239 L .62181 .70767 L F
.62068 .70554 m .6225 .70488 L .62269 .70579 L .455 .22 0 r
F
.6225 .70488 m .6257 .70371 L .62269 .70579 L F
.6226 .70503 m .6225 .70488 L .62269 .70579 L 0 0 0 r
F
.69848 .82283 m .6226 .70503 L .62269 .70579 L F
.62181 .70767 m .57007 .62825 L .62172 .71095 L 0 .009 0 r
F
.62068 .70554 m .62269 .70579 L .62087 .70752 L .455 .22 0 r
F
.62269 .70579 m .62284 .70703 L .62087 .70752 L F
.69848 .82283 m .62269 .70579 L .70176 .83039 L 0 0 0 r
F
.62269 .70579 m .6227 .70582 L .70176 .83039 L F
.62284 .70703 m .62285 .70703 L .62244 .70863 L .496 .487 0 r
F
.62164 .71489 m .62492 .71038 L .6224 .7163 L .569 .76 0 r
F
.62164 .71483 m .62492 .71038 L .62164 .71489 L F
.62168 .71263 m .62492 .71038 L .62162 .71486 L F
.62173 .71095 m .62492 .71038 L .62075 .71327 L F
.62244 .70863 m .62492 .71038 L .62173 .71095 L .496 .487 0 r
F
.70176 .83039 m .62244 .70863 L .70113 .8381 L 0 .009 0 r
F
.62244 .70863 m .62181 .70767 L .62242 .70867 L F
.62244 .70863 m .62242 .70867 L .70113 .8381 L F
.62244 .70863 m .62173 .71095 L .62172 .71095 L .496 .487 0 r
F
.62172 .71095 m .57007 .62825 L .62075 .71327 L 0 .04 0 r
F
.61969 .71132 m .62172 .71095 L .62075 .71327 L .569 .76 0 r
F
.62172 .71095 m .62173 .71095 L .62075 .71327 L F
.57007 .62825 m .57164 .63135 L .56891 .63276 L .825 .866 0 r
F
.62075 .71327 m .57007 .62825 L .56891 .63276 L 0 .04 0 r
F
.62075 .71327 m .62168 .71263 L .62162 .71486 L .569 .76 0 r
F
.70113 .8381 m .62172 .71095 L .62075 .71327 L 0 .04 0 r
F
.62181 .70767 m .62172 .71095 L .70113 .8381 L 0 .009 0 r
F
.62244 .70863 m .62172 .71095 L .61969 .71132 L .496 .487 0 r
F
.62087 .70752 m .62244 .70863 L .61969 .71132 L F
.70176 .83039 m .6229 .70711 L .62244 .70863 L 0 .009 0 r
F
.6229 .70711 m .62284 .70703 L .62244 .70863 L F
.62087 .70752 m .62284 .70703 L .62244 .70863 L .496 .487 0 r
F
.62206 .70482 m .568 .62027 L .56966 .6239 L 0 0 0 r
F
.62158 .70344 m .568 .62027 L .62206 .70482 L F
.568 .62027 m .56767 .61976 L .56966 .6239 L F
.62162 .71486 m .62164 .71483 L .62164 .71489 L .569 .76 0 r
F
.62073 .71333 m .61929 .71674 L .69671 .84583 L 0 .04 0 r
F
.62023 .71245 m .61929 .71674 L .62073 .71333 L F
.61969 .71132 m .62075 .71327 L .61728 .71702 L .569 .76 0 r
F
.62075 .71327 m .61928 .71673 L .61728 .71702 L F
.70113 .8381 m .62075 .71327 L .69671 .84583 L 0 .04 0 r
F
.62075 .71327 m .62073 .71333 L .69671 .84583 L F
.61773 .71978 m .61549 .72435 L .68864 .85342 L .117 .063 0 r
F
.61738 .71912 m .61577 .72359 L .61773 .71978 L F
.61577 .72359 m .61549 .72435 L .61773 .71978 L F
.61549 .72435 m .5662 .63738 L .61342 .7279 L .248 .08 0 r
F
.61728 .71702 m .61776 .71972 L .61361 .7246 L .715 .939 0 r
F
.61776 .71972 m .61549 .72435 L .61361 .7246 L F
.69671 .84583 m .61776 .71972 L .68864 .85342 L .117 .063 0 r
F
.61776 .71972 m .61773 .71978 L .68864 .85342 L F
.61357 .72778 m .61452 .72704 L .61429 .72768 L .832 1 0 r
F
.61357 .72778 m .61653 .72737 L .61311 .73329 L F
.61166 .72818 m .61167 .72818 L .61159 .72805 L 1 .61 0 r
F
.6086 .72847 m .61159 .72805 L .61153 .72795 L F
.60858 .72844 m .61153 .72795 L .55939 .64312 L F
.6086 .72847 m .61153 .72795 L .60858 .72844 L F
.60835 .72804 m .55939 .64312 L .60562 .73425 L F
.60741 .73075 m .60853 .73397 L .60562 .73425 L .839 1 0 r
F
.60835 .72804 m .60562 .73425 L .60856 .72849 L 1 .61 0 r
F
.60858 .72844 m .60853 .73397 L .60741 .73075 L .839 1 0 r
F
.60858 .72844 m .60741 .73075 L .60672 .72876 L F
.60858 .72844 m .61167 .72818 L .60853 .73397 L F
.68249 .85663 m .60858 .72844 L .67132 .86372 L 1 .61 0 r
F
.60858 .72844 m .60835 .72804 L .60856 .72849 L F
.60858 .72844 m .60856 .72849 L .67132 .86372 L F
.60562 .73425 m .55939 .64312 L .60313 .73829 L .342 .178 0 r
F
.60387 .73441 m .60562 .73425 L .60313 .73829 L .932 1 0 r
F
.60562 .73425 m .60564 .73425 L .60313 .73829 L F
.55939 .64312 m .55626 .64667 L .55384 .64764 L .575 .359 0 r
F
.60313 .73829 m .55939 .64312 L .55384 .64764 L .342 .178 0 r
F
.60564 .73425 m .60853 .73397 L .60313 .73829 L .932 1 0 r
F
.67132 .86372 m .60562 .73425 L .60313 .73829 L .342 .178 0 r
F
.60856 .72849 m .60562 .73425 L .67132 .86372 L 1 .61 0 r
F
.60672 .72876 m .60741 .73075 L .60387 .73441 L .839 1 0 r
F
.60741 .73075 m .60562 .73425 L .60387 .73441 L F
.60862 .72498 m .60858 .72844 L .60672 .72876 L F
.68249 .85663 m .61159 .72805 L .6086 .72847 L 1 .61 0 r
F
.60862 .72498 m .61361 .7246 L .61167 .72818 L .839 1 0 r
F
.60862 .72498 m .61167 .72818 L .60858 .72844 L F
.68249 .85663 m .68864 .85342 L .61167 .72818 L 1 .61 0 r
F
.68249 .85663 m .61167 .72818 L .61166 .72818 L F
.68864 .85342 m .61549 .72435 L .61342 .7279 L .248 .08 0 r
F
.61361 .7246 m .61549 .72435 L .61342 .7279 L .832 1 0 r
F
.68864 .85342 m .61362 .72823 L .61192 .72859 L .248 .08 0 r
F
.61362 .72823 m .61342 .7279 L .61192 .72859 L F
.61361 .7246 m .61342 .7279 L .61167 .72818 L .832 1 0 r
F
.60312 .73829 m .59909 .74538 L .65699 .87043 L .342 .178 0 r
F
.6031 .73825 m .60266 .73904 L .60312 .73829 L F
.60266 .73904 m .59909 .74538 L .60312 .73829 L F
.59909 .74538 m .55384 .64764 L .5961 .74964 L .445 .287 0 r
F
.60387 .73441 m .60313 .73829 L .59759 .7456 L .932 1 0 r
F
.60313 .73829 m .59909 .74538 L .59759 .7456 L F
.67132 .86372 m .60313 .73829 L .65699 .87043 L .342 .178 0 r
F
.60313 .73829 m .60312 .73829 L .65699 .87043 L F
.5961 .74964 m .59876 .74944 L .59327 .75739 L .987 1 0 r
F
.59759 .7456 m .59876 .74944 L .5961 .74964 L F
.65699 .87043 m .59909 .74538 L .5961 .74964 L .445 .287 0 r
F
.59759 .7456 m .59909 .74538 L .598 .74695 L .987 1 0 r
F
.5967 .75083 m .5961 .74964 L .59547 .75127 L .445 .287 0 r
F
.5961 .74964 m .54694 .65211 L .59473 .74975 L F
.5961 .74964 m .59473 .74975 L .59483 .74996 L F
.59325 .74598 m .59759 .7456 L .5948 .74996 L 1 1 0 r
F
.59195 .75025 m .5948 .74996 L .58948 .7583 L F
.59256 .75151 m .5951 .75055 L .5948 .74996 L 1 .708 0 r
F
.59195 .75025 m .59457 .74952 L .5447 .65292 L F
.59195 .75025 m .5447 .65292 L .5869 .75876 L F
.59202 .75 m .59195 .75025 L .59075 .75024 L 1 1 0 r
F
.59195 .75025 m .58948 .7583 L .5907 .75059 L F
.59195 .75025 m .5907 .75059 L .59075 .75024 L F
.59195 .75025 m .5948 .74996 L .59457 .74952 L 1 .708 0 r
F
.59256 .75151 m .5948 .74996 L .59195 .75025 L F
.59202 .75 m .5948 .74996 L .59195 .75025 L 1 1 0 r
F
.5948 .74996 m .54694 .65211 L .54473 .65298 L .445 .287 0 r
F
.59325 .74598 m .5948 .74996 L .59202 .75 L 1 1 0 r
F
.59599 .74995 m .59483 .74996 L .59547 .75127 L .445 .287 0 r
F
.5961 .74964 m .59483 .74996 L .59599 .74995 L F
.6516 .87313 m .65699 .87043 L .5951 .75055 L 1 .708 0 r
F
.6516 .87313 m .5951 .75055 L .59256 .75151 L F
.6516 .87313 m .59195 .75025 L .6349 .87917 L F
.59032 .75299 m .58948 .7583 L .5869 .75876 L 1 1 0 r
F
.58576 .76028 m .58948 .7583 L .58605 .76295 L F
.5869 .75876 m .58948 .7583 L .58601 .76015 L F
.5869 .75876 m .58601 .76015 L .58576 .76028 L F
.59209 .75067 m .5869 .75876 L .6349 .87917 L 1 .708 0 r
F
.59195 .75025 m .5869 .75876 L .59209 .75067 L F
.59075 .75024 m .59032 .75299 L .58562 .75899 L 1 1 0 r
F
.59032 .75299 m .5869 .75876 L .58562 .75899 L F
.59325 .74598 m .59202 .75 L .59075 .75024 L F
.59759 .7456 m .5961 .74964 L .5948 .74996 L .987 1 0 r
F
.59547 .75127 m .59483 .74996 L .5948 .74996 L .445 .287 0 r
F
.65699 .87043 m .5967 .75083 L .59547 .75127 L F
.5447 .65292 m .53875 .65646 L .53676 .6572 L .436 .209 0 r
F
.58361 .76316 m .5447 .65292 L .53676 .6572 L .557 .368 0 r
F
.58361 .76316 m .58605 .76295 L .57926 .77216 L 1 1 0 r
F
.58562 .75899 m .58605 .76295 L .58361 .76316 L F
.6349 .87917 m .5869 .75876 L .58361 .76316 L .557 .368 0 r
F
.58562 .75899 m .5869 .75876 L .58576 .76028 L 1 1 0 r
F
.58421 .76453 m .58361 .76316 L .58322 .76498 L .557 .368 0 r
F
.58361 .76316 m .53676 .6572 L .58248 .76326 L F
.58169 .75944 m .58562 .75899 L .58255 .7635 L 1 1 0 r
F
.57985 .76384 m .58255 .7635 L .57592 .77324 L F
.58048 .76531 m .58286 .76418 L .58255 .7635 L 1 .752 0 r
F
.57985 .76384 m .5823 .76294 L .53474 .65787 L F
.57985 .76384 m .53474 .65787 L .57353 .77385 L F
.57997 .76354 m .57985 .76384 L .57896 .76381 L 1 1 0 r
F
.57985 .76384 m .57592 .77324 L .57883 .76422 L F
.57985 .76384 m .57883 .76422 L .57896 .76381 L F
.57985 .76384 m .58255 .7635 L .5823 .76294 L 1 .752 0 r
F
.58048 .76531 m .58255 .7635 L .57985 .76384 L F
.57997 .76354 m .58255 .7635 L .57985 .76384 L 1 1 0 r
F
.58255 .7635 m .53676 .6572 L .53477 .65793 L .557 .368 0 r
F
.58169 .75944 m .58255 .7635 L .57997 .76354 L 1 1 0 r
F
.58361 .76316 m .58248 .76326 L .58258 .7635 L .557 .368 0 r
F
.58354 .76348 m .58258 .7635 L .58322 .76498 L F
.58361 .76316 m .58258 .7635 L .58354 .76348 L F
.62998 .8816 m .6349 .87917 L .58286 .76418 L 1 .752 0 r
F
.62998 .8816 m .58286 .76418 L .58048 .76531 L F
.62998 .8816 m .57985 .76384 L .61135 .88692 L F
.57801 .76676 m .57592 .77324 L .57353 .77385 L 1 1 0 r
F
.57241 .77536 m .57592 .77324 L .57222 .77782 L F
.57243 .7752 m .57261 .7751 L .57241 .77536 L F
.57261 .7751 m .57592 .77324 L .57241 .77536 L F
.57353 .77385 m .57592 .77324 L .57243 .7752 L F
.58013 .76492 m .57353 .77385 L .61135 .88692 L 1 .752 0 r
F
.57985 .76384 m .57353 .77385 L .58013 .76492 L F
.57896 .76381 m .57801 .76676 L .57251 .77411 L 1 1 0 r
F
.57801 .76676 m .57353 .77385 L .57251 .77411 L F
.58169 .75944 m .57997 .76354 L .57896 .76381 L F
.58562 .75899 m .58361 .76316 L .58255 .7635 L F
.58322 .76498 m .58258 .76349 L .58255 .7635 L .557 .368 0 r
F
.6349 .87917 m .58421 .76453 L .58322 .76498 L F
.53474 .65787 m .52765 .66134 L .52592 .66196 L .377 .2 0 r
F
.57004 .77813 m .53474 .65787 L .52592 .66196 L .653 .436 0 r
F
.57004 .77813 m .57222 .77782 L .56383 .7882 L 1 1 0 r
F
.57251 .77411 m .57222 .77782 L .57004 .77813 L F
.61135 .88692 m .57353 .77385 L .57004 .77813 L .653 .436 0 r
F
.57251 .77411 m .57353 .77385 L .57243 .7752 L 1 1 0 r
F
.5703 .77883 m .57004 .77813 L .56952 .77924 L .653 .436 0 r
F
.57004 .77813 m .52592 .66196 L .56915 .77825 L F
.56904 .77475 m .57251 .77411 L .56923 .77849 L 1 1 0 r
F
.60697 .88911 m .61135 .88692 L .56923 .77849 L 1 .786 0 r
F
.56673 .77898 m .56898 .77785 L .56877 .7773 L F
.56649 .77833 m .56877 .7773 L .52418 .66252 L F
.56673 .77898 m .56877 .7773 L .56649 .77833 L F
.56673 .77898 m .52418 .66252 L .55883 .79035 L F
.56229 .78022 m .55806 .79065 L .55509 .79157 L 1 1 0 r
F
.56551 .77516 m .56329 .77977 L .56229 .78022 L F
.56329 .77977 m .55806 .79065 L .56229 .78022 L F
.56692 .77864 m .56673 .77898 L .56616 .77893 L F
.56673 .77898 m .56097 .78952 L .56593 .77938 L F
.56673 .77898 m .56593 .77938 L .56616 .77893 L F
.56673 .77898 m .56923 .77849 L .56898 .77785 L 1 .786 0 r
F
.56673 .77898 m .56923 .77849 L .56097 .78952 L 1 1 0 r
F
.60697 .88911 m .56923 .77849 L .56673 .77898 L 1 .786 0 r
F
.56692 .77864 m .56923 .77849 L .56673 .77898 L 1 1 0 r
F
.56923 .77849 m .52592 .66196 L .5242 .66258 L .653 .436 0 r
F
.56904 .77475 m .56923 .77849 L .56692 .77864 L 1 1 0 r
F
.57004 .77813 m .56915 .77825 L .56924 .77849 L .653 .436 0 r
F
.56988 .77845 m .56924 .77849 L .56952 .77924 L F
.57004 .77813 m .56924 .77849 L .56988 .77845 L F
.60697 .88911 m .56673 .77898 L .58684 .89369 L 1 .786 0 r
F
.5647 .7819 m .56097 .78952 L .55883 .79035 L 1 1 0 r
F
.55791 .7914 m .56097 .78952 L .55755 .79325 L .846 .764 0 r
F
.55793 .79132 m .55803 .79126 L .55791 .7914 L F
.55803 .79126 m .56097 .78952 L .55791 .7914 L F
.55883 .79035 m .56097 .78952 L .55793 .79132 L F
.56707 .78089 m .55883 .79035 L .58684 .89369 L 1 .786 0 r
F
.56673 .77898 m .55883 .79035 L .56707 .78089 L F
.56616 .77893 m .5647 .7819 L .55806 .79065 L 1 1 0 r
F
.5647 .7819 m .55883 .79035 L .55806 .79065 L F
.56904 .77475 m .56692 .77864 L .56616 .77893 L F
.57251 .77411 m .57004 .77813 L .56923 .77849 L F
.56952 .77924 m .56924 .77849 L .56923 .77849 L .653 .436 0 r
F
.61135 .88692 m .5703 .77883 L .56952 .77924 L F
.52418 .66252 m .51608 .6659 L .51465 .66644 L .321 .192 0 r
F
.55524 .79423 m .52418 .66252 L .51465 .66644 L .737 .497 0 r
F
.55534 .79411 m .55755 .79325 L .5571 .79374 L .846 .764 0 r
F
.55524 .79423 m .5571 .79374 L .54684 .80493 L F
.55534 .79411 m .5571 .79374 L .55524 .79423 L F
.55548 .79496 m .55524 .79423 L .55492 .79537 L .737 .497 0 r
F
.55524 .79423 m .5147 .6666 L .55461 .7944 L F
.55509 .79157 m .55806 .79065 L .55467 .79461 L .947 .917 0 r
F
.58308 .89566 m .58684 .89369 L .55467 .79461 L 1 .804 0 r
F
.55466 .79461 m .55467 .79461 L .5546 .7944 L F
.55243 .79532 m .55467 .79461 L .54449 .80651 L .947 .917 0 r
F
.58308 .89566 m .55467 .79461 L .55466 .79461 L 1 .804 0 r
F
.55245 .79539 m .5546 .7944 L .55445 .79393 L F
.55243 .79532 m .54449 .80651 L .55029 .79801 L .947 .917 0 r
F
.55243 .79532 m .51321 .66691 L .54264 .80761 L 1 .804 0 r
F
.55217 .79525 m .54449 .80651 L .5421 .80793 L .947 .917 0 r
F
.55315 .79767 m .55243 .79532 L .54264 .80761 L 1 .804 0 r
F
.55243 .79532 m .55029 .79801 L .55185 .79572 L .947 .917 0 r
F
.54872 .79683 m .5421 .80793 L .53966 .80916 L 1 1 0 r
F
.55222 .79462 m .55426 .79333 L .51321 .66691 L 1 .804 0 r
F
.55206 .79229 m .54947 .79636 L .54872 .79683 L 1 1 0 r
F
.54947 .79636 m .5421 .80793 L .54872 .79683 L F
.55243 .79532 m .55445 .79393 L .55426 .79333 L 1 .804 0 r
F
.55243 .79532 m .55426 .79333 L .55222 .79462 L F
.55245 .79539 m .55445 .79393 L .55243 .79532 L F
.5527 .79494 m .55243 .79532 L .55217 .79525 L .947 .917 0 r
F
.55243 .79532 m .55185 .79572 L .55217 .79525 L F
.58308 .89566 m .5546 .7944 L .55245 .79539 L 1 .804 0 r
F
.5527 .79494 m .55467 .79461 L .55243 .79532 L .947 .917 0 r
F
.55467 .79461 m .5147 .6666 L .51334 .66729 L .737 .497 0 r
F
.55509 .79157 m .55467 .79461 L .5527 .79494 L .947 .917 0 r
F
.55524 .79423 m .55461 .7944 L .55468 .79461 L .737 .497 0 r
F
.55516 .79453 m .55468 .79461 L .55492 .79537 L F
.55524 .79423 m .55468 .79461 L .55516 .79453 L F
.55806 .79065 m .55755 .79325 L .55534 .79411 L .846 .764 0 r
F
.58684 .89369 m .55883 .79035 L .55524 .79423 L .737 .497 0 r
F
.55806 .79065 m .55883 .79035 L .55793 .79132 L .846 .764 0 r
F
.58308 .89566 m .55315 .79767 L .56185 .89948 L 1 .804 0 r
F
.54264 .80761 m .54449 .80651 L .54188 .80831 L .638 .226 0 r
F
.55315 .79767 m .54264 .80761 L .56185 .89948 L 1 .804 0 r
F
.53922 .81077 m .54111 .80965 L .54057 .81015 L .638 .226 0 r
F
.53912 .81087 m .54057 .81015 L .52829 .82154 L F
.53922 .81077 m .54057 .81015 L .53912 .81087 L F
.53874 .81124 m .53912 .81087 L .5383 .81167 L F
.56185 .89948 m .53917 .81108 L .53874 .81124 L .81 .552 0 r
F
.53917 .81108 m .53912 .81087 L .53874 .81124 L F
.5421 .80793 m .54111 .80965 L .53922 .81077 L .638 .226 0 r
F
.56185 .89948 m .54264 .80761 L .53912 .81087 L .81 .552 0 r
F
.5421 .80793 m .53912 .81087 L .53874 .81124 L .638 .226 0 r
F
.53874 .81124 m .53912 .81087 L .53871 .81109 L .81 .552 0 r
F
.53912 .81087 m .53911 .81085 L .53892 .81096 L F
.53912 .81087 m .53892 .81096 L .53871 .81109 L F
.53912 .81087 m .51321 .66691 L .50314 .67067 L F
.53911 .81085 m .50314 .67067 L .53871 .81109 L F
.53966 .80916 m .5421 .80793 L .53874 .81124 L .703 .374 0 r
F
.53912 .81087 m .53798 .81198 L .53807 .81189 L .638 .226 0 r
F
.53912 .81087 m .53807 .81189 L .5383 .81167 L F
.55877 .90126 m .56185 .89948 L .53874 .81124 L 1 .785 0 r
F
.53874 .81124 m .53874 .81124 L .5387 .81107 L F
.5383 .81167 m .52829 .82154 L .52648 .82333 L .638 .226 0 r
F
.53798 .81198 m .52829 .82154 L .5383 .81167 L F
.53736 .81228 m .53722 .81237 L .53545 .81376 L 0 0 0 r
F
.53682 .81221 m .53874 .81124 L .52648 .82333 L .703 .374 0 r
F
.55877 .90126 m .53874 .81124 L .53874 .81124 L 1 .785 0 r
F
.55877 .90126 m .5387 .81107 L .53868 .81108 L F
.55877 .90126 m .53857 .81059 L .53682 .81221 L F
.53719 .81182 m .53874 .81124 L .53682 .81221 L .703 .374 0 r
F
.53868 .81108 m .5387 .81107 L .53857 .81059 L 1 .785 0 r
F
.53857 .81059 m .50314 .67067 L .50204 .67108 L .81 .552 0 r
F
.53871 .81109 m .53858 .81059 L .53857 .81059 L F
.53858 .81059 m .50314 .67067 L .53857 .81059 L F
.53966 .80916 m .53874 .81124 L .53719 .81182 L .703 .374 0 r
F
.55509 .79157 m .5527 .79494 L .55217 .79525 L .947 .917 0 r
F
.55806 .79065 m .55524 .79423 L .55467 .79461 L .846 .764 0 r
F
.55492 .79537 m .55468 .7946 L .55467 .79461 L .737 .497 0 r
F
.58684 .89369 m .55548 .79496 L .55492 .79537 L F
.5147 .6666 m .51465 .66644 L .51334 .66729 L F
.5421 .80793 m .54264 .80761 L .54188 .80831 L .638 .226 0 r
F
.5368 .81424 m .53685 .81418 L .53644 .81255 L 1 .786 0 r
F
.55565 .90291 m .53685 .81418 L .5368 .81424 L F
.53448 .81338 m .50092 .67143 L .5231 .82619 L F
.53397 .81381 m .53243 .81568 L .52274 .82647 L .76 .572 0 r
F
.53448 .81338 m .53626 .81184 L .5361 .8112 L 1 .786 0 r
F
.53431 .81264 m .5361 .8112 L .50092 .67143 L F
.53448 .81338 m .5361 .8112 L .53431 .81264 L F
.53146 .81492 m .52274 .82647 L .52083 .82781 L .871 .749 0 r
F
.53464 .81106 m .53199 .81449 L .53146 .81492 L F
.53199 .81449 m .52274 .82647 L .53146 .81492 L F
.5345 .81321 m .53408 .81372 L .53397 .81381 L .76 .572 0 r
F
.53408 .81372 m .53243 .81568 L .53397 .81381 L F
.53717 .81021 m .53966 .80916 L .53644 .81255 L F
.53448 .81338 m .53644 .81255 L .52463 .82498 L F
.53552 .81294 m .53644 .81255 L .53626 .81184 L 1 .786 0 r
F
.53467 .81418 m .53626 .81184 L .53448 .81338 L F
.53626 .81184 m .50204 .67108 L .50094 .67149 L 1 .785 0 r
F
.53644 .81255 m .53627 .81184 L .53626 .81184 L F
.53627 .81184 m .50204 .67108 L .53626 .81184 L F
.53717 .81021 m .53644 .81255 L .53448 .81338 L .76 .572 0 r
F
.53467 .81418 m .53644 .81255 L .53552 .81294 L 1 .786 0 r
F
.55565 .90291 m .53644 .81255 L .53467 .81418 L F
.53682 .81221 m .53642 .81258 L .53652 .81248 L .703 .374 0 r
F
.53683 .81219 m .53652 .81248 L .53685 .81211 L F
.53682 .81221 m .53652 .81248 L .53683 .81219 L F
.52948 .91471 m .53688 .90432 L .52835 .9148 L .838 .348 0 r
F
.5527 .91131 m .5392 .90258 L .53688 .90432 L .799 .046 0 r
F
.55273 .91129 m .5392 .90258 L .5527 .91131 L F
.55628 .90871 m .54149 .90073 L .55559 .90932 L .77 .307 0 r
F
.55367 .91076 m .5392 .90258 L .55298 .91144 L .799 .046 0 r
F
.55551 .90942 m .54149 .90073 L .5392 .90258 L .77 .307 0 r
F
.55554 .90939 m .54149 .90073 L .55551 .90942 L F
.55565 .90291 m .53448 .81338 L .53452 .90593 L 1 .786 0 r
F
.53243 .81568 m .52463 .82498 L .5231 .82619 L .76 .572 0 r
F
.53484 .81295 m .52463 .82498 L .5345 .81321 L F
.52238 .82677 m .52463 .82498 L .52095 .82795 L .449 .196 0 r
F
.52241 .82675 m .52245 .82672 L .52238 .82677 L F
.52245 .82672 m .52463 .82498 L .52238 .82677 L F
.5231 .82619 m .52463 .82498 L .52241 .82675 L F
.53448 .81702 m .5231 .82619 L .53452 .90593 L 1 .786 0 r
F
.53448 .81338 m .5231 .82619 L .53448 .81702 L F
.53243 .81568 m .5231 .82619 L .52274 .82647 L .76 .572 0 r
F
.53717 .81021 m .53484 .81295 L .5345 .81321 L F
.55877 .90126 m .53682 .81221 L .53644 .81255 L 1 .785 0 r
F
.53685 .81211 m .5365 .81249 L .53644 .81255 L .703 .374 0 r
F
.53966 .80916 m .53719 .81182 L .53685 .81211 L F
.51992 .82875 m .50092 .67143 L .49085 .67513 L .874 .594 0 r
F
.51992 .82875 m .52095 .82795 L .50718 .83903 L .449 .196 0 r
F
.52274 .82647 m .52095 .82795 L .51992 .82875 L F
.53452 .90593 m .5231 .82619 L .51992 .82875 L .874 .594 0 r
F
.52274 .82647 m .5231 .82619 L .52241 .82675 L .449 .196 0 r
F
.51992 .82875 m .50958 .83709 L .51971 .82906 L F
.51971 .82906 m .51992 .82875 L .51968 .82894 L .874 .594 0 r
F
.51995 .82891 m .51992 .82875 L .51971 .82906 L F
.52274 .82647 m .51992 .82875 L .51971 .82906 L .449 .196 0 r
F
.52083 .82781 m .52274 .82647 L .51971 .82906 L .529 .209 0 r
F
.51971 .82906 m .50958 .83709 L .50591 .84082 L .449 .196 0 r
F
.53214 .90742 m .53452 .90593 L .51971 .82906 L 1 .692 0 r
F
.51814 .83015 m .51971 .82906 L .51919 .8295 L .529 .209 0 r
F
.51814 .83015 m .51919 .8295 L .50591 .84082 L F
.51692 .83134 m .50591 .84082 L .50463 .84248 L F
.51641 .83166 m .50591 .84082 L .51692 .83134 L F
.5179 .8303 m .5178 .82977 L .5178 .82977 L 1 .692 0 r
F
.53214 .90742 m .51971 .82906 L .51814 .83015 L F
.51814 .83015 m .51971 .82906 L .51948 .8279 L F
.51861 .82975 m .51971 .82906 L .51814 .83015 L .529 .209 0 r
F
.51861 .82975 m .51824 .83006 L .51843 .82998 L F
.51824 .83006 m .51641 .83166 L .51803 .83031 L F
.51824 .83006 m .51803 .83031 L .51843 .82998 L F
.52973 .90878 m .53214 .90742 L .51792 .83044 L 1 .692 0 r
F
.51632 .8314 m .51792 .83044 L .5178 .82977 L F
.4901 .67546 m .48016 .67877 L .4798 .67918 L 0 0 0 r
F
.48934 .67572 m .4901 .67546 L .4798 .67918 L .244 .178 0 r
F
.51632 .8314 m .51661 .83123 L .50463 .84248 L .603 .22 0 r
F
.51843 .82998 m .51641 .83166 L .51692 .83134 L .529 .209 0 r
F
.517 .83086 m .51792 .83044 L .50463 .84248 L .603 .22 0 r
F
.50958 .83709 m .50718 .83903 L .50591 .84082 L .449 .196 0 r
F
.51632 .8314 m .48934 .67572 L .50346 .84302 L 1 .692 0 r
F
.51623 .83148 m .51622 .8315 L .5162 .83151 L .603 .22 0 r
F
.51693 .83487 m .51632 .8314 L .50352 .84377 L 1 .692 0 r
F
.51693 .83487 m .50352 .84377 L .5092 .91106 L F
.5092 .91106 m .50352 .84377 L .50088 .84633 L .934 .633 0 r
F
.51587 .83188 m .51208 .83546 L .50332 .844 L .603 .22 0 r
F
.51208 .83546 m .50463 .84248 L .50352 .84377 L F
.51208 .83546 m .50352 .84377 L .50332 .844 L F
.50088 .84633 m .50352 .84377 L .50079 .84561 L .934 .633 0 r
F
.51622 .8315 m .50463 .84248 L .51587 .83188 L .603 .22 0 r
F
.51632 .8314 m .50346 .84302 L .50352 .84377 L 1 .692 0 r
F
.51632 .8314 m .5178 .82977 L .51769 .82915 L F
.51632 .8314 m .51769 .82915 L .5162 .83069 L F
.51814 .83015 m .4901 .67546 L .5179 .8303 L F
.51814 .83015 m .51948 .8279 L .51802 .82951 L F
.51968 .82894 m .51959 .82845 L .51959 .82845 L .874 .594 0 r
F
.51992 .82875 m .49085 .67513 L .51968 .82894 L F
.51925 .82876 m .52083 .82781 L .51632 .8314 L .603 .22 0 r
F
.51679 .83095 m .51632 .8314 L .51661 .83117 L F
.51632 .8314 m .51622 .8315 L .51628 .83144 L F
.51632 .8314 m .517 .83086 L .51661 .83123 L F
.51632 .8314 m .51628 .83144 L .51661 .83117 L F
.51661 .83117 m .51623 .83148 L .51587 .83188 L F
.51623 .83148 m .5162 .83151 L .51587 .83188 L F
.51887 .82898 m .51925 .82876 L .51632 .8314 L F
.51887 .82898 m .51679 .83095 L .51661 .83117 L F
.5178 .82977 m .4901 .67546 L .48934 .67572 L 1 .692 0 r
F
.5178 .82977 m .4901 .67546 L .5178 .82977 L F
.51802 .82951 m .51948 .8279 L .4901 .67546 L F
.51689 .82998 m .51887 .82898 L .51599 .83177 L .671 .233 0 r
F
.51437 .83258 m .51599 .83177 L .50332 .844 L F
.51689 .82998 m .51599 .83177 L .51437 .83258 L F
.51635 .83158 m .51792 .83044 L .51632 .8314 L 1 .692 0 r
F
.51646 .83216 m .5174 .83105 L .51635 .83158 L F
.5174 .83105 m .51792 .83044 L .51635 .83158 L F
.51401 .83295 m .50332 .844 L .50199 .84538 L .671 .233 0 r
F
.51689 .82998 m .51437 .83258 L .51401 .83295 L F
.51437 .83258 m .50332 .844 L .51401 .83295 L F
.5162 .83069 m .51769 .82915 L .48934 .67572 L 1 .692 0 r
F
.52973 .90878 m .51792 .83044 L .51646 .83216 L F
.51792 .83044 m .51814 .83015 L .5179 .8303 L F
.53214 .90742 m .51817 .83033 L .51792 .83044 L F
.51817 .83033 m .51814 .83015 L .51792 .83044 L F
.52083 .82781 m .51971 .82906 L .51861 .82975 L .529 .209 0 r
F
.52083 .82781 m .51861 .82975 L .51843 .82998 L F
.517 .83086 m .52083 .82781 L .51792 .83044 L .603 .22 0 r
F
.53452 .90593 m .51995 .82891 L .51971 .82906 L .874 .594 0 r
F
.51959 .82845 m .49085 .67513 L .4901 .67546 L F
.51959 .82845 m .49085 .67513 L .51959 .82845 L F
.50079 .84561 m .50101 .84543 L .50082 .84556 L 0 0 0 r
F
.50079 .84561 m .50129 .84473 L .48647 .85474 L F
.50079 .84561 m .48647 .85474 L .50071 .84586 L F
.50079 .84561 m .47944 .67954 L .50069 .84577 L .934 .633 0 r
F
.50079 .84561 m .50069 .84577 L .50071 .84586 L F
.50079 .84561 m .48934 .67572 L .47944 .67954 L F
.50352 .84377 m .48934 .67572 L .50079 .84561 L F
.50332 .844 m .50352 .84377 L .50079 .84561 L 0 0 0 r
F
.50199 .84538 m .50332 .844 L .50071 .84586 L F
.50759 .91228 m .5092 .91106 L .50074 .84611 L 1 .458 0 r
F
.50759 .91228 m .50074 .84611 L .50073 .84611 L F
.50759 .91228 m .50071 .84586 L .49958 .84703 L F
.49958 .84703 m .50071 .84586 L .50011 .84629 L 0 0 0 r
F
.49958 .84703 m .50011 .84629 L .48584 .85646 L F
.4996 .84715 m .49958 .84703 L .4995 .84726 L 1 .458 0 r
F
.50759 .91228 m .4996 .84715 L .4995 .84726 L F
.4995 .84726 m .48584 .85646 L .48519 .85806 L 0 0 0 r
F
.50199 .84538 m .49968 .84696 L .4995 .84726 L F
.49968 .84696 m .48584 .85646 L .4995 .84726 L F
.49945 .84731 m .4995 .84726 L .49939 .84734 L F
.49826 .84838 m .49939 .84734 L .48519 .85806 L F
.49953 .84751 m .49953 .84751 L .4995 .84726 L 1 .456 0 r
F
.50596 .91337 m .4995 .84726 L .49844 .84899 L F
.49836 .84831 m .49939 .84734 L .49826 .84838 L 0 0 0 r
F
.50063 .84662 m .50044 .84673 L .49836 .84831 L F
.50044 .84673 m .49939 .84734 L .49836 .84831 L F
.49876 .85179 m .49836 .84831 L .48462 .85935 L 1 .456 0 r
F
.49844 .84899 m .4995 .84726 L .49836 .84831 L F
.49876 .85179 m .48462 .85935 L .48645 .91499 L F
.48645 .91499 m .48462 .85935 L .48241 .86116 L .99 .671 0 r
F
.50063 .84662 m .49551 .85042 L .48454 .85954 L 0 0 0 r
F
.49551 .85042 m .48519 .85806 L .48462 .85935 L F
.49551 .85042 m .48462 .85935 L .48454 .85954 L F
.48241 .86116 m .48462 .85935 L .48237 .8606 L .99 .671 0 r
F
.49836 .84831 m .47872 .68008 L .4846 .8587 L 1 .456 0 r
F
.49836 .84831 m .4846 .8587 L .48462 .85935 L F
.49836 .84831 m .4995 .84726 L .47872 .68008 L F
.49946 .8473 m .4995 .84726 L .49945 .84731 L 0 0 0 r
F
.49926 .84772 m .50063 .84662 L .49817 .8486 L .443 .195 0 r
F
.49701 .84953 m .49817 .8486 L .48571 .85859 L F
.48638 .85805 m .48571 .85859 L .48454 .85954 L F
.49701 .84953 m .48571 .85859 L .48638 .85805 L F
.49926 .84772 m .49817 .8486 L .49701 .84953 L F
.49926 .84772 m .48454 .85954 L .48387 .86089 L F
.49787 .84868 m .49926 .84772 L .48487 .86004 L .516 .206 0 r
F
.48545 .85952 m .48487 .86004 L .48387 .86089 L F
.49787 .84868 m .48487 .86004 L .48545 .85952 L F
.49649 .84994 m .48387 .86089 L .4832 .86213 L F
.49562 .85064 m .48387 .86089 L .49649 .84994 L F
.48387 .86089 m .48454 .85954 L .48239 .86079 L 0 0 0 r
F
.48248 .86197 m .48238 .86068 L .48239 .86079 L .99 .671 0 r
F
.48247 .86192 m .48237 .8606 L .48248 .86197 L F
.48645 .91499 m .48247 .86192 L .48248 .86197 L F
.48567 .91597 m .48645 .91499 L .4824 .86098 L .898 .166 0 r
F
.48567 .91597 m .4824 .86098 L .4824 .86099 L F
.48567 .91597 m .48239 .86079 L .48182 .86197 L F
.48182 .86197 m .48239 .86079 L .48172 .86118 L 0 0 0 r
F
.48182 .86197 m .48172 .86118 L .48105 .86157 L F
.48182 .86197 m .48105 .86157 L .48114 .86233 L F
.48454 .85954 m .48462 .85935 L .48246 .86054 L F
.48246 .86055 m .48246 .86054 L .48237 .8606 L F
.48454 .85954 m .48246 .86054 L .48246 .86055 L F
.48462 .85935 m .48462 .85929 L .48237 .8606 L .99 .671 0 r
F
.48237 .8606 m .47872 .68008 L .46914 .68424 L F
.48462 .85929 m .47872 .68008 L .48237 .8606 L F
.48454 .85954 m .48237 .8606 L .48239 .86079 L 0 0 0 r
F
.48238 .86073 m .47032 .69998 L .46967 .69111 L .99 .671 0 r
F
.47032 .69998 m .46914 .68424 L .46967 .69111 L F
.46967 .69111 m .46914 .68428 L .46918 .68459 L F
.48238 .86073 m .46914 .68424 L .48238 .86073 L F
.48237 .8606 m .48227 .85967 L .46704 .8681 L 0 0 0 r
F
.48239 .86079 m .48046 .86171 L .46712 .8697 L F
.48238 .86068 m .48237 .8606 L .48239 .86079 L .99 .671 0 r
F
.48237 .8606 m .46704 .8681 L .48239 .86079 L 0 0 0 r
F
.48237 .8606 m .46914 .68424 L .48239 .86079 L .99 .671 0 r
F
.48182 .86197 m .48183 .86196 L .46919 .68463 L .898 .166 0 r
F
.4824 .86099 m .4824 .86098 L .48239 .86079 L F
.48191 .86192 m .48239 .86079 L .48182 .86197 L 0 0 0 r
F
.48248 .86162 m .4824 .8609 L .48191 .86192 L F
.4824 .8609 m .48239 .86079 L .48191 .86192 L F
.48567 .91597 m .48183 .86205 L .48184 .86215 L .898 .166 0 r
F
.48184 .86215 m .46712 .8697 L .4672 .8712 L 0 0 0 r
F
.48387 .86089 m .48191 .86192 L .48184 .86215 L F
.48183 .86205 m .48182 .86197 L .48184 .86215 L .898 .166 0 r
F
.48182 .86197 m .46919 .68463 L .48184 .86215 L F
.46919 .68463 m .46919 .68463 L .48184 .86215 L F
.48182 .86197 m .46712 .8697 L .48184 .86215 L 0 0 0 r
F
.48183 .86209 m .46919 .68463 L .46923 .6849 L .898 .166 0 r
F
.48183 .86209 m .46918 .68459 L .48183 .86209 L F
.48117 .86328 m .48125 .86313 L .4672 .8712 L 0 0 0 r
F
.48125 .86313 m .48174 .86221 L .48117 .86256 L F
.48125 .86313 m .48117 .86256 L .4672 .8712 L F
.48488 .91682 m .48185 .86235 L .48127 .86332 L .897 .166 0 r
F
.48488 .91682 m .48567 .91597 L .48184 .86215 L F
.48488 .91682 m .48184 .86215 L .48184 .86215 L F
.48488 .91682 m .48127 .86332 L .48128 .86339 L F
.48128 .86339 m .4672 .8712 L .46728 .87258 L 0 0 0 r
F
.48127 .86328 m .48127 .86327 L .48127 .86322 L .897 .166 0 r
F
.48127 .86328 m .48127 .86322 L .48126 .86323 L F
.48126 .86323 m .48174 .86221 L .48125 .86313 L 0 0 0 r
F
.48181 .8622 m .48174 .86221 L .48126 .86323 L F
.48127 .86327 m .48183 .86209 L .46978 .69265 L .897 .166 0 r
F
.48408 .91755 m .48488 .91682 L .48129 .86359 L .896 .166 0 r
F
.48408 .91755 m .48129 .86359 L .48129 .86359 L F
.48128 .86339 m .48127 .86328 L .48128 .86339 L .897 .166 0 r
F
.48127 .86332 m .48127 .86328 L .48128 .86339 L F
.48127 .86332 m .48184 .86215 L .48127 .86328 L F
.48127 .86328 m .48126 .86323 L .48128 .86339 L F
.48126 .86323 m .4672 .8712 L .48128 .86339 L 0 0 0 r
F
.48185 .86235 m .48184 .86215 L .48127 .86332 L .897 .166 0 r
F
.48135 .86318 m .48126 .86323 L .48128 .86339 L 0 0 0 r
F
.48128 .86339 m .48128 .86339 L .48128 .86339 L .897 .166 0 r
F
.48125 .86345 m .48128 .86339 L .48119 .86345 L 0 0 0 r
F
.48184 .86215 m .48151 .86277 L .48127 .86328 L .897 .166 0 r
F
.48135 .86318 m .48181 .8622 L .48126 .86323 L 0 0 0 r
F
.4832 .86213 m .48187 .8622 L .48135 .86318 L F
.48187 .8622 m .48181 .8622 L .48135 .86318 L F
.48126 .86323 m .48127 .86322 L .46923 .6849 L .897 .166 0 r
F
.46977 .69296 m .46923 .6849 L .46977 .69288 L F
.46977 .69296 m .46977 .69288 L .48128 .86332 L F
.48126 .86323 m .46977 .69296 L .48128 .86332 L F
.47819 .86591 m .48119 .86345 L .46728 .87258 L 0 0 0 r
F
.4806 .86443 m .48074 .8642 L .47819 .86591 L F
.48074 .8642 m .48119 .86345 L .47819 .86591 L F
.48129 .86359 m .48129 .86359 L .48128 .86339 L .896 .166 0 r
F
.48408 .91755 m .48128 .86339 L .48073 .865 L F
.48069 .86437 m .48119 .86345 L .4806 .86443 L 0 0 0 r
F
.48251 .86326 m .48235 .86328 L .48069 .86437 L F
.48235 .86328 m .48119 .86345 L .48069 .86437 L F
.48408 .91755 m .48069 .86437 L .4669 .91861 L .896 .166 0 r
F
.48183 .86196 m .48209 .86141 L .46967 .69111 L .898 .166 0 r
F
.48209 .86141 m .48238 .86073 L .46967 .69111 L F
.48128 .86332 m .46923 .6849 L .46928 .68517 L .897 .166 0 r
F
.48128 .86332 m .46923 .6849 L .48128 .86332 L F
.48114 .86233 m .48105 .86157 L .46712 .8697 L 0 0 0 r
F
.48046 .86171 m .46704 .8681 L .46711 .86948 L F
.48046 .86171 m .46711 .86948 L .46712 .8697 L F
.47974 .86813 m .46735 .87374 L .4669 .91861 L .896 .166 0 r
F
.48069 .86437 m .46735 .87374 L .47974 .86813 L F
.46507 .87477 m .46549 .87436 L .46418 .87405 L .077 0 0 r
F
.4669 .91861 m .46735 .87374 L .46567 .87454 L 1 .699 0 r
F
.48328 .91815 m .4669 .91861 L .467 .91925 L .107 0 0 r
F
.48328 .91815 m .48408 .91755 L .4669 .91861 L F
.48246 .91862 m .467 .91925 L .4671 .91976 L .067 0 0 r
F
.48246 .91862 m .48328 .91815 L .467 .91925 L F
.46735 .87374 m .46728 .87258 L .46579 .87406 L .077 0 0 r
F
.46735 .87374 m .46579 .87406 L .46581 .87425 L F
.46735 .87374 m .46549 .87436 L .46565 .87451 L F
.46567 .87454 m .46736 .87315 L .46566 .87429 L 1 .699 0 r
F
.46567 .87454 m .46735 .87374 L .46507 .87477 L .077 0 0 r
F
.46735 .87374 m .46736 .87315 L .46567 .87454 L 1 .699 0 r
F
.46736 .87387 m .46735 .87374 L .46567 .87454 L .077 0 0 r
F
.46572 .87413 m .46728 .87258 L .46565 .87336 L F
.46581 .87425 m .46579 .87406 L .46549 .87436 L F
.46549 .87436 m .46572 .87413 L .46488 .87372 L F
.46572 .87413 m .46565 .87336 L .46488 .87372 L F
.46566 .87429 m .46928 .68517 L .46054 .69033 L 1 .699 0 r
F
.48069 .86437 m .46728 .87258 L .46735 .87374 L 0 0 0 r
F
.46736 .87315 m .46928 .68517 L .46566 .87429 L 1 .699 0 r
F
.46567 .8746 m .46567 .87454 L .46576 .87471 L F
.4669 .91861 m .46567 .8746 L .46576 .87471 L F
.46576 .87468 m .45065 .88047 L .45152 .88184 L .077 0 0 r
F
.46736 .87387 m .46567 .87454 L .46576 .87468 L F
.46567 .87454 m .46576 .87468 L .46576 .87471 L 1 .699 0 r
F
.46567 .87454 m .45065 .88047 L .46576 .87468 L .077 0 0 r
F
.46567 .87454 m .46576 .87463 L .46576 .87468 L 1 .699 0 r
F
.46596 .87596 m .46595 .87588 L .46595 .87586 L 0 0 0 r
F
.46602 .87582 m .46594 .8757 L .46595 .87586 L .034 0 0 r
F
.46745 .87505 m .46601 .87567 L .46602 .87582 L F
.46601 .87567 m .46594 .8757 L .46602 .87582 L F
.48164 .91896 m .4671 .91976 L .46721 .92015 L .026 0 0 r
F
.47882 .91912 m .48246 .91862 L .4671 .91976 L F
.48164 .91896 m .48184 .91888 L .47882 .91912 L F
.48184 .91888 m .48246 .91862 L .47882 .91912 L F
.467 .91925 m .4669 .91861 L .46577 .87483 L 0 0 0 r
F
.467 .91925 m .46577 .87483 L .46577 .87483 L F
.467 .91925 m .46576 .87468 L .46576 .87468 L F
.467 .91925 m .46576 .87468 L .46586 .87579 L F
.46589 .87522 m .46576 .87468 L .46581 .87523 L .034 0 0 r
F
.46576 .87468 m .46576 .87463 L .4658 .87514 L 0 0 0 r
F
.46576 .87468 m .4658 .87514 L .46586 .87579 L F
.46586 .87573 m .46436 .87538 L .46511 .87605 L .034 0 0 r
F
.46626 .87902 m .46615 .87749 L .46614 .87696 L 0 0 0 r
F
.46745 .87505 m .46597 .87521 L .46601 .87567 L .034 0 0 r
F
.46753 .87614 m .46745 .87505 L .46602 .87582 L 0 0 0 r
F
.46603 .87587 m .46602 .87582 L .46595 .87586 L F
.46753 .87614 m .46602 .87582 L .46603 .87587 L F
.4671 .91976 m .46605 .87689 L .46614 .87695 L F
.46624 .87784 m .46606 .87699 L .46615 .87788 L F
.46721 .92015 m .4671 .91976 L .46615 .87749 L F
.46721 .92015 m .46615 .87749 L .46626 .87902 L F
.4671 .91976 m .467 .91925 L .46595 .87601 L F
.4671 .91976 m .46595 .87601 L .46595 .87601 L F
.4671 .91976 m .46595 .87588 L .46605 .87705 L F
.467 .91925 m .46589 .8768 L .46598 .87694 L F
.46115 .92635 m .4668 .91785 L .46056 .92635 L 1 .41 0 r
F
.46721 .92004 m .46624 .87784 L .46386 .9203 L 0 0 0 r
F
.46747 .87713 m .46614 .877 L .46624 .87784 L F
.46624 .87804 m .46614 .87696 L .46614 .87695 L F
.46624 .87804 m .46614 .87695 L .46616 .87713 L F
.46605 .87705 m .46596 .87596 L .46595 .8759 L F
.46753 .87614 m .46595 .87586 L .46595 .87591 L F
.46597 .87603 m .46595 .8759 L .46595 .87581 L F
.46605 .87705 m .46595 .8759 L .46597 .87603 L F
.46601 .87567 m .46581 .87523 L .46586 .87573 L .034 0 0 r
F
.46597 .87521 m .46581 .87523 L .46601 .87567 L F
.46589 .87522 m .46584 .87464 L .46576 .87468 L F
.46589 .8768 m .46586 .87573 L .46598 .87694 L 0 0 0 r
F
.46594 .8757 m .46586 .87573 L .46595 .87586 L .034 0 0 r
F
.46745 .87505 m .46736 .87387 L .46584 .87464 L F
.46745 .87505 m .46584 .87464 L .46589 .87522 L F
.46586 .87573 m .46101 .69086 L .46595 .87586 L 0 0 0 r
F
.46753 .87614 m .46595 .87591 L .46605 .87683 L F
.46606 .87699 m .45242 .88312 L .45332 .88431 L F
.4661 .87692 m .4661 .8769 L .46614 .87695 L F
.46753 .87614 m .46605 .87683 L .46614 .87695 L F
.4661 .8769 m .46149 .69139 L .46614 .87695 L F
.46605 .87689 m .46605 .87688 L .4661 .87692 L F
.46614 .87695 m .46605 .87683 L .46606 .87699 L F
.46586 .87573 m .46595 .87586 L .46598 .87694 L F
.46605 .87683 m .45242 .88312 L .46606 .87699 L F
.46605 .87688 m .46595 .87581 L .46594 .87539 L F
.46605 .87683 m .46594 .87539 L .46149 .69139 L F
.46605 .87688 m .46594 .87539 L .46605 .87683 L F
.46605 .87688 m .46149 .69139 L .4661 .87692 L F
.46614 .87695 m .46149 .69139 L .46196 .69192 L F
.46567 .87454 m .46054 .69034 L .46576 .87463 L 1 .699 0 r
F
.46196 .69192 m .46149 .69139 L .46149 .69139 L 0 0 0 r
F
.46586 .87579 m .46576 .87463 L .46101 .69086 L F
.46595 .87588 m .46101 .69086 L .46149 .69139 L F
.46196 .69192 m .46149 .69139 L .46108 .69172 L F
.46576 .87463 m .46054 .69034 L .46101 .69086 L 1 .699 0 r
F
.46054 .69034 m .46054 .69033 L .46101 .69086 L F
.46576 .87463 m .46054 .69033 L .46576 .87463 L F
.46595 .87588 m .46101 .69086 L .46595 .87588 L 0 0 0 r
F
.46149 .69139 m .46101 .69086 L .45231 .69705 L .023 0 0 r
F
.46149 .69139 m .46101 .69086 L .46149 .69139 L F
.46113 .6925 m .46108 .69172 L .4532 .69806 L 0 0 0 r
F
.46196 .69192 m .46108 .69172 L .46113 .6925 L F
.46196 .69192 m .46149 .69139 L .46196 .69192 L F
.46196 .69192 m .46149 .69139 L .46196 .69192 L F
.46586 .87573 m .45152 .88184 L .46595 .87586 L .034 0 0 r
F
.46605 .87683 m .46587 .8759 L .46596 .87687 L 0 0 0 r
F
.46605 .87705 m .46595 .87581 L .46605 .87688 L F
.46595 .87601 m .46595 .87601 L .46595 .87588 L F
.46598 .87694 m .46595 .87588 L .46595 .87588 L F
.46595 .87591 m .46587 .8759 L .46605 .87683 L F
.46624 .87804 m .46614 .8769 L .46624 .87788 L F
.46614 .877 m .46606 .87699 L .46624 .87784 L F
.46614 .877 m .46614 .87695 L .46606 .87699 L F
.46624 .87701 m .46614 .87695 L .46614 .877 L F
.46762 .87715 m .46753 .87614 L .46614 .87695 L F
.46762 .87715 m .46614 .87695 L .46624 .87701 L F
.46624 .87784 m .46614 .8769 L .46196 .69192 L F
.46624 .87788 m .46619 .87745 L .46624 .87784 L F
.46619 .87745 m .46614 .8769 L .46624 .87784 L F
.46616 .87713 m .46614 .87695 L .46614 .8769 L F
.46581 .87523 m .46436 .87538 L .46586 .87573 L .034 0 0 r
F
.46596 .87687 m .46587 .8759 L .45242 .88312 L 0 0 0 r
F
.46595 .8759 m .46595 .87586 L .46595 .87581 L F
.46596 .87596 m .46595 .87586 L .46595 .8759 L F
.46595 .87591 m .46595 .87586 L .46587 .8759 L F
.46577 .87483 m .46577 .87483 L .46576 .87468 L F
.46576 .87468 m .46576 .87468 L .46576 .87463 L F
.46581 .87523 m .46576 .87468 L .46436 .87538 L .034 0 0 r
F
.46595 .87586 m .45152 .88184 L .45242 .88312 L F
.46511 .87605 m .46436 .87538 L .45152 .88184 L F
.46493 .87483 m .46418 .87405 L .45065 .88047 L .077 0 0 r
F
.45332 .88431 m .43717 .88899 L .43891 .89024 L .178 0 0 r
F
.45273 .92081 m .45416 .88532 L .45295 .88582 L 1 .724 0 r
F
.46433 .87879 m .46606 .87699 L .45332 .88431 L 0 0 0 r
F
.46386 .9203 m .46352 .87952 L .45273 .92081 L F
.46626 .87902 m .46614 .87696 L .46624 .87804 L F
.46624 .87784 m .45332 .88431 L .45416 .88532 L F
.46352 .87952 m .46196 .69192 L .45416 .88532 L F
.46352 .87952 m .45416 .88532 L .45273 .92081 L F
.46624 .87784 m .46352 .87941 L .46386 .9203 L F
.46762 .87715 m .46624 .87784 L .45424 .88541 L F
.46624 .87784 m .45416 .88532 L .45424 .88541 L F
.45315 .88589 m .45301 .88579 L .45309 .88592 L .148 0 0 r
F
.45424 .88541 m .45308 .88577 L .45315 .88589 L F
.45308 .88577 m .45301 .88579 L .45315 .88589 L F
.46731 .92041 m .46721 .92015 L .45273 .92081 L .044 0 0 r
F
.46731 .92041 m .45273 .92081 L .45378 .92114 L F
.46742 .92054 m .46731 .92041 L .45378 .92114 L .003 0 0 r
F
.46742 .92054 m .45378 .92114 L .45483 .92134 L F
.45483 .92134 m .45378 .92114 L .4541 .8874 L 0 0 0 r
F
.45424 .88541 m .45416 .88532 L .45307 .88577 L .148 0 0 r
F
.45308 .88577 m .45307 .88577 L .45295 .88582 L F
.45424 .88541 m .45307 .88577 L .45308 .88577 L F
.45499 .88881 m .4541 .8874 L .45411 .88696 L 0 0 0 r
F
.45416 .88532 m .45332 .88431 L .45295 .88582 L .148 0 0 r
F
.45295 .88582 m .45419 .88479 L .45295 .88553 L 1 .724 0 r
F
.45416 .88532 m .45419 .88479 L .45295 .88582 L F
.45297 .88574 m .45332 .88431 L .45215 .88479 L .148 0 0 r
F
.45295 .88553 m .46196 .69192 L .45409 .69912 L 1 .724 0 r
F
.45419 .88479 m .46196 .69192 L .45295 .88553 L F
.46771 .87807 m .46762 .87715 L .45424 .88541 L 0 0 0 r
F
.46547 .92068 m .46742 .92054 L .45483 .92134 L F
.46753 .92056 m .46751 .92055 L .46547 .92068 L F
.46751 .92055 m .46742 .92054 L .46547 .92068 L F
.45309 .88592 m .45409 .69912 L .45499 .70027 L 1 .724 0 r
F
.45309 .88595 m .45309 .88592 L .45309 .88592 L F
.45309 .88592 m .45409 .69912 L .45309 .88592 L F
.45396 .88705 m .45319 .88607 L .45313 .88596 L 0 0 0 r
F
.45396 .88705 m .45313 .88596 L .45321 .88605 L F
.45319 .88607 m .45309 .88595 L .45309 .88592 L F
.45319 .88607 m .45309 .88592 L .45313 .88596 L F
.45378 .92114 m .45273 .92081 L .45309 .88603 L F
.45309 .88603 m .45309 .88603 L .45309 .88595 L F
.45378 .92114 m .45309 .88603 L .45309 .88603 L F
.45499 .88798 m .45411 .88696 L .45411 .88694 L F
.45427 .88702 m .45416 .88691 L .45411 .88694 L .087 0 0 r
F
.45403 .88683 m .45323 .88597 L .45317 .886 L .117 0 0 r
F
.45403 .88683 m .45317 .886 L .45396 .88685 L F
.45517 .88644 m .45424 .88541 L .45321 .88586 L F
.45517 .88644 m .45321 .88586 L .45326 .88592 L F
.45517 .88644 m .45315 .88589 L .45403 .88683 L F
.45517 .88644 m .45396 .88685 L .45411 .88694 L F
.45411 .88694 m .45499 .70027 L .4559 .70154 L 0 0 0 r
F
.45378 .92114 m .45396 .88685 L .45411 .88694 L F
.45396 .88685 m .45499 .70027 L .45411 .88694 L F
.45396 .88705 m .45309 .88588 L .45396 .88689 L F
.45378 .92114 m .45309 .88595 L .45396 .88705 L F
.45273 .92081 m .45295 .88587 L .45309 .88595 L 1 .724 0 r
F
.45411 .88694 m .44067 .8914 L .44245 .89249 L .117 0 0 r
F
.45396 .88685 m .44067 .8914 L .45411 .88694 L F
.45416 .88699 m .45411 .88694 L .45404 .88697 L .087 0 0 r
F
.45427 .88702 m .45411 .88694 L .45416 .88699 L F
.45499 .88798 m .45426 .88709 L .45499 .88785 L 0 0 0 r
F
.45611 .8874 m .45416 .88699 L .45499 .88781 L .087 0 0 r
F
.45426 .88709 m .45411 .88691 L .45455 .88738 L 0 0 0 r
F
.45426 .88709 m .45455 .88738 L .45499 .88785 L F
.45426 .88709 m .45411 .88694 L .45411 .88691 L F
.45499 .88798 m .45411 .88694 L .45426 .88709 L F
.45499 .88781 m .45404 .88697 L .45492 .88784 L .087 0 0 r
F
.45416 .88699 m .45404 .88697 L .45499 .88781 L F
.45499 .88881 m .45411 .88696 L .45499 .88798 L 0 0 0 r
F
.45483 .92134 m .4541 .8874 L .45499 .88881 L F
.45611 .8874 m .45506 .88779 L .45513 .8879 L .087 0 0 r
F
.45611 .8874 m .45517 .88644 L .45416 .88691 L F
.45611 .8874 m .45416 .88691 L .45427 .88702 L F
.46771 .87807 m .45424 .88541 L .45517 .88644 L 0 0 0 r
F
.45513 .8879 m .4559 .70154 L .45681 .70298 L F
.45483 .92134 m .45499 .88786 L .45513 .8879 L F
.45603 .88886 m .45515 .88792 L .45514 .88791 L F
.4568 .88841 m .45513 .8879 L .45603 .88872 L .059 0 0 r
F
.45532 .88808 m .45514 .88791 L .45513 .88786 L 0 0 0 r
F
.45603 .88886 m .45514 .88791 L .45532 .88808 L F
.45515 .88792 m .45513 .88791 L .45513 .8879 L F
.45603 .88886 m .45513 .88786 L .45603 .88874 L F
.46753 .92056 m .45483 .92134 L .45589 .92142 L F
.45589 .92142 m .45483 .92134 L .45513 .88799 L F
.45513 .888 m .45513 .88799 L .45513 .88791 L F
.45589 .92142 m .45513 .88799 L .45513 .888 L F
.45803 .88917 m .45706 .8883 L .45611 .88884 L .032 0 0 r
F
.45589 .92142 m .45513 .88791 L .45603 .88886 L 0 0 0 r
F
.4517 .92036 m .45068 .91979 L .45151 .92036 L .164 0 0 r
F
.46056 .92635 m .44868 .91829 L .46089 .92661 L 1 .41 0 r
F
.46087 .9266 m .44868 .91829 L .46089 .92662 L F
.4517 .92036 m .43458 .91979 L .43651 .92044 L .164 0 0 r
F
.45589 .92129 m .45603 .88872 L .45118 .92159 L 0 0 0 r
F
.45603 .88872 m .45499 .88915 L .44596 .89442 L .059 0 0 r
F
.45499 .88915 m .44425 .89352 L .44596 .89442 L F
.45499 .88915 m .45513 .8879 L .44425 .89352 L F
.45603 .88872 m .45594 .88864 L .45499 .88915 L F
.45594 .88864 m .45513 .8879 L .45499 .88915 L F
.45506 .88779 m .45499 .88781 L .45513 .8879 L .087 0 0 r
F
.45499 .88781 m .4559 .70154 L .45513 .8879 L 0 0 0 r
F
.45499 .88786 m .45499 .88781 L .45513 .8879 L F
.45499 .88781 m .44245 .89249 L .45513 .8879 L .087 0 0 r
F
.45513 .8879 m .44245 .89249 L .44425 .89352 L F
.45492 .88784 m .45404 .88697 L .44245 .89249 L F
.45295 .88587 m .45295 .88582 L .45309 .88595 L 1 .724 0 r
F
.45301 .88579 m .45295 .88582 L .45309 .88592 L .148 0 0 r
F
.45295 .88582 m .45297 .88574 L .45286 .88577 L F
.45295 .88582 m .45286 .88577 L .43891 .89024 L F
.45297 .88574 m .45215 .88479 L .43891 .89024 L F
.45295 .88582 m .45409 .69912 L .45309 .88588 L 1 .724 0 r
F
.45295 .88582 m .45309 .88588 L .45309 .88592 L F
.45295 .88582 m .45309 .88592 L .45309 .88595 L F
.45295 .88582 m .43891 .89024 L .45309 .88592 L .148 0 0 r
F
.45317 .886 m .45309 .88592 L .44067 .8914 L .117 0 0 r
F
.45396 .88685 m .45317 .886 L .44067 .8914 L F
.45499 .88785 m .45411 .88691 L .4559 .70154 L 0 0 0 r
F
.45309 .88592 m .43891 .89024 L .44067 .8914 L .148 0 0 r
F
.45323 .88597 m .45309 .88592 L .45317 .886 L .117 0 0 r
F
.45323 .88597 m .45315 .88589 L .45309 .88592 L F
.45326 .88592 m .45321 .88586 L .45315 .88589 L F
.45396 .88689 m .45309 .88588 L .45499 .70027 L 0 0 0 r
F
.45119 .88492 m .44976 .88414 L .43717 .88899 L .178 0 0 r
F
.44509 .89473 m .44425 .89352 L .43255 .89784 L .201 0 0 r
F
.4444 .92183 m .44596 .89442 L .44509 .89493 L 1 .74 0 r
F
.44596 .89442 m .44425 .89352 L .44505 .89467 L .201 0 0 r
F
.44513 .89471 m .44505 .89467 L .44509 .89473 L F
.44596 .89442 m .44505 .89467 L .44513 .89471 L F
.45173 .88423 m .45121 .88358 L .44976 .88414 L .178 0 0 r
F
.45118 .92159 m .45194 .89219 L .4444 .92183 L 0 0 0 r
F
.45194 .89219 m .45681 .70298 L .44596 .89439 L F
.45194 .89219 m .44596 .89439 L .4444 .92183 L F
.45697 .92138 m .45589 .92142 L .4444 .92183 L F
.45697 .92138 m .4444 .92183 L .44643 .92188 L F
.44855 .84871 m .45681 .70298 L .44913 .82874 L 1 .74 0 r
F
.4451 .89472 m .4451 .89472 L .44509 .89493 L F
.44596 .89442 m .44596 .89439 L .44509 .89493 L F
.44596 .89439 m .44855 .84871 L .4451 .89472 L F
.44596 .89439 m .4451 .89472 L .44509 .89493 L F
.44514 .89471 m .44509 .89473 L .44527 .89481 L .201 0 0 r
F
.44509 .89473 m .44496 .89476 L .44499 .89477 L F
.44855 .84871 m .44913 .82874 L .4451 .89472 L 1 .74 0 r
F
.44855 .84871 m .4451 .89472 L .4451 .89472 L F
.44608 .89448 m .44514 .89471 L .44527 .89481 L .201 0 0 r
F
.44608 .89448 m .44596 .89442 L .44509 .89473 L F
.44509 .89473 m .44512 .89441 L .4451 .89442 L 1 .74 0 r
F
.44509 .89493 m .4451 .89472 L .44509 .89473 L F
.4451 .89472 m .44512 .89441 L .44509 .89473 L F
.4451 .89442 m .45681 .70298 L .44965 .71444 L F
.44512 .89441 m .45681 .70298 L .4451 .89442 L F
.44527 .89481 m .44965 .71444 L .45095 .71748 L F
.4444 .92183 m .44509 .89476 L .44527 .89481 L F
.44509 .89476 m .44965 .71444 L .44527 .89481 L F
.44961 .89626 m .44793 .8954 L .44719 .89573 L .168 0 0 r
F
.4498 .8963 m .44966 .89623 L .44961 .89626 L F
.44966 .89623 m .44793 .8954 L .44961 .89626 L F
.4498 .8963 m .44719 .89573 L .44767 .89586 L F
.45643 .92132 m .45697 .92138 L .44643 .92188 L .062 .15 0 r
F
.45805 .92123 m .45787 .92126 L .45643 .92132 L F
.46765 .92045 m .46753 .92056 L .45589 .92142 L .081 .154 0 r
F
.46765 .92045 m .45589 .92142 L .45697 .92138 L F
.45787 .92126 m .45697 .92138 L .45643 .92132 L .062 .15 0 r
F
.45805 .92123 m .44643 .92188 L .44847 .92183 L F
.44847 .92183 m .44643 .92188 L .44718 .89578 L 0 0 0 r
F
.44719 .89578 m .44718 .89578 L .44719 .89573 L F
.44847 .92183 m .44718 .89578 L .44719 .89578 L F
.45169 .89718 m .4498 .8963 L .44908 .89665 L .156 0 0 r
F
.44847 .92183 m .44719 .89573 L .44719 .89573 L 0 0 0 r
F
.44847 .92183 m .44719 .89573 L .44894 .89656 L F
.4498 .8963 m .44729 .89578 L .44894 .89655 L .168 0 0 r
F
.44643 .92188 m .44701 .89569 L .44719 .89573 L 0 0 0 r
F
.44643 .92188 m .4444 .92183 L .44527 .89488 L F
.44643 .92188 m .44527 .89488 L .44527 .89488 L F
.44643 .92188 m .44527 .89481 L .44527 .89481 L F
.4454 .89484 m .44531 .89479 L .44527 .89481 L .183 0 0 r
F
.44643 .92188 m .44527 .89481 L .44701 .89568 L 0 0 0 r
F
.44768 .89547 m .44527 .89481 L .44701 .89565 L .183 0 0 r
F
.44527 .89481 m .44527 .89478 L .44619 .89526 L 0 0 0 r
F
.44527 .89481 m .44619 .89526 L .44701 .89568 L F
.44527 .89488 m .44527 .89488 L .44527 .89481 L F
.44701 .89565 m .44527 .89481 L .43525 .89885 L .183 0 0 r
F
.44719 .89573 m .43525 .89885 L .43797 .89982 L F
.44793 .8954 m .44701 .89565 L .44719 .89573 L F
.44701 .89569 m .44701 .89565 L .44719 .89573 L 0 0 0 r
F
.44701 .89565 m .43525 .89885 L .44719 .89573 L .183 0 0 r
F
.44793 .8954 m .44608 .89448 L .44531 .89479 L F
.44793 .8954 m .44531 .89479 L .4454 .89484 L F
.44793 .8954 m .44527 .89481 L .44768 .89547 L F
.45603 .88872 m .45197 .89102 L .45118 .92159 L 0 0 0 r
F
.45706 .8883 m .45603 .88872 L .44608 .89448 L .059 0 0 r
F
.45603 .88872 m .44596 .89442 L .44608 .89448 L F
.45701 .88962 m .45611 .88884 L .44608 .89448 L .032 0 0 r
F
.45803 .88917 m .44608 .89448 L .44793 .8954 L F
.44701 .89565 m .45095 .71748 L .44719 .89573 L 0 0 0 r
F
.44719 .89573 m .44719 .8957 L .44862 .8964 L F
.44719 .89573 m .44862 .8964 L .44894 .89656 L F
.44729 .89578 m .44719 .89573 L .44714 .89575 L .168 0 0 r
F
.44767 .89586 m .44719 .89573 L .44729 .89578 L F
.44042 .92137 m .42459 .92064 L .42745 .92115 L .121 0 0 r
F
.4424 .92166 m .42745 .92115 L .43034 .92154 L .086 0 0 r
F
.44276 .92195 m .44894 .89655 L .43918 .92203 L 0 0 0 r
F
.44847 .92169 m .44894 .89655 L .44276 .92195 L F
.4482 .8985 m .44056 .90069 L .43918 .92203 L F
.44894 .89655 m .44056 .90069 L .4482 .8985 L F
.44812 .89692 m .43797 .89982 L .44056 .90069 L .168 0 0 r
F
.44894 .89655 m .43797 .89982 L .44908 .89665 L F
.43986 .9009 m .43988 .90089 L .43985 .9009 L .257 0 0 r
F
.43988 .90089 m .44056 .90069 L .43987 .90089 L F
.43988 .90089 m .43987 .90089 L .43985 .9009 L F
.43918 .92203 m .44056 .90069 L .43985 .90105 L 1 .753 0 r
F
.44056 .90069 m .44056 .90067 L .43985 .90105 L F
.44056 .90069 m .43797 .89982 L .43984 .9009 L .257 0 0 r
F
.44527 .89481 m .44499 .89477 L .43525 .89885 L .201 0 0 r
F
.44499 .89477 m .44441 .89499 L .43525 .89885 L F
.44719 .89573 m .45095 .71748 L .45225 .72113 L 0 0 0 r
F
.44875 .89661 m .44714 .89575 L .43797 .89982 L .168 0 0 r
F
.44889 .89657 m .44887 .89655 L .44875 .89661 L F
.44887 .89655 m .44714 .89575 L .44875 .89661 L F
.44056 .90067 m .44059 .90029 L .43986 .9009 L 1 .753 0 r
F
.44496 .89476 m .43255 .89784 L .43456 .89859 L .201 0 0 r
F
.44496 .89476 m .43456 .89859 L .43525 .89885 L F
.44701 .89568 m .44527 .89478 L .45095 .71748 L 0 0 0 r
F
.44067 .8914 m .43891 .89024 L .42465 .8944 L .264 0 0 r
F
.44067 .8914 m .42465 .8944 L .42725 .89562 L F
.44245 .89249 m .44067 .8914 L .42725 .89562 L .242 0 0 r
F
.44245 .89249 m .42725 .89562 L .42989 .89676 L F
.44425 .89352 m .44245 .89249 L .42989 .89676 L .221 0 0 r
F
.44425 .89352 m .42989 .89676 L .43255 .89784 L F
.44059 .90029 m .45225 .72113 L .43988 .90061 L 1 .753 0 r
F
.44059 .90029 m .43988 .90061 L .43986 .9009 L F
.44056 .90067 m .43986 .9009 L .43985 .90105 L F
.43986 .9009 m .42839 .90285 L .43912 .90113 L .257 0 0 r
F
.43985 .90105 m .43986 .9009 L .43986 .9009 L 1 .753 0 r
F
.43918 .92203 m .43986 .90092 L .44007 .90098 L F
.43986 .90092 m .43986 .9009 L .44007 .90098 L F
.44847 .92183 m .44847 .92169 L .44276 .92195 L 0 0 0 r
F
.45053 .92166 m .44847 .92183 L .43918 .92203 L .05 .148 0 r
F
.45053 .92166 m .43918 .92203 L .44217 .92197 L F
.44217 .92197 m .43918 .92203 L .44007 .90101 L .108 .011 0 r
F
.44008 .90101 m .44007 .90101 L .44007 .90098 L F
.44217 .92197 m .44007 .90101 L .44008 .90101 L F
.4526 .9214 m .45053 .92166 L .44217 .92197 L .08 .154 0 r
F
.4526 .9214 m .44217 .92197 L .44519 .92183 L F
.44519 .92183 m .44217 .92197 L .44291 .90191 L .109 .011 0 r
F
.44519 .92183 m .44291 .90191 L .44291 .90191 L F
.44519 .92183 m .44291 .90191 L .443 .90194 L F
.44554 .90279 m .443 .90194 L .44554 .90276 L F
.44519 .92183 m .443 .90194 L .44554 .90279 L F
.44352 .90167 m .4427 .90182 L .44291 .90191 L .25 0 0 r
F
.44352 .90167 m .44073 .90075 L .44008 .90098 L F
.44352 .90167 m .44008 .90098 L .44013 .90099 L F
.44217 .92197 m .44007 .90098 L .44008 .90098 L .108 .011 0 r
F
.44302 .90176 m .44007 .90098 L .44113 .90132 L .25 0 0 r
F
.44269 .90182 m .44259 .90179 L .44269 .90182 L .108 .011 0 r
F
.44302 .90176 m .44113 .90132 L .44269 .90182 L .25 0 0 r
F
.44217 .92197 m .44008 .90098 L .44269 .90182 L .108 .011 0 r
F
.44008 .90098 m .44259 .90179 L .44269 .90182 L F
.44113 .90132 m .43992 .90104 L .44269 .90182 L .25 0 0 r
F
.44013 .90099 m .44008 .90098 L .44007 .90098 L F
.44008 .90098 m .44008 .90096 L .44259 .90179 L .108 .011 0 r
F
.44352 .90167 m .44007 .90098 L .44302 .90176 L .25 0 0 r
F
.44073 .90075 m .43988 .90089 L .44007 .90098 L .257 0 0 r
F
.44073 .90075 m .44056 .90069 L .43986 .9009 L F
.43986 .9009 m .45225 .72113 L .44507 .73932 L 1 .753 0 r
F
.43986 .9009 m .45225 .72113 L .43986 .9009 L F
.44908 .89665 m .44812 .89692 L .44073 .90075 L .168 0 0 r
F
.44812 .89692 m .44056 .90069 L .44073 .90075 L F
.44894 .89655 m .44059 .90029 L .44056 .90069 L 0 0 0 r
F
.45085 .89746 m .44908 .89665 L .44073 .90075 L .156 0 0 r
F
.44894 .89656 m .44719 .8957 L .4472 .89532 L 0 0 0 r
F
.44509 .89473 m .44499 .89477 L .44527 .89481 L .201 0 0 r
F
.44499 .89477 m .44496 .89476 L .44441 .89499 L F
.44527 .89481 m .44527 .89481 L .44527 .89478 L 0 0 0 r
F
.44698 .89743 m .45225 .72113 L .44059 .90029 L F
.45664 .89116 m .45803 .88917 L .44793 .8954 L .008 0 0 r
F
.459 .89001 m .44793 .8954 L .4498 .8963 L F
.44894 .89655 m .4472 .89532 L .45225 .72113 L 0 0 0 r
F
.44894 .89656 m .4472 .89532 L .44894 .89655 L F
.44894 .89655 m .44714 .89575 L .44889 .89657 L .168 0 0 r
F
.44729 .89578 m .44714 .89575 L .44894 .89655 L F
.44894 .89655 m .44895 .89615 L .44698 .89743 L 0 0 0 r
F
.44719 .89573 m .44719 .89573 L .44719 .8957 L F
.44895 .89615 m .45225 .72113 L .44698 .89743 L F
.459 .89001 m .45875 .88979 L .45664 .89116 L .008 0 0 r
F
.45875 .88979 m .45803 .88917 L .45664 .89116 L F
.45169 .89718 m .44073 .90075 L .44352 .90167 L .156 0 0 r
F
.44269 .90182 m .44008 .90096 L .44667 .74654 L .108 .011 0 r
F
.44259 .90179 m .44008 .90096 L .44269 .90182 L F
.44113 .90132 m .44007 .90098 L .43992 .90104 L .25 0 0 r
F
.44269 .90182 m .43992 .90104 L .43232 .90372 L F
.44269 .90182 m .43232 .90372 L .43244 .90375 L F
.44269 .90185 m .44269 .90182 L .44291 .90191 L .108 .011 0 r
F
.4427 .90182 m .44269 .90182 L .44291 .90191 L .25 0 0 r
F
.44269 .90182 m .44667 .74654 L .44291 .90191 L .108 .011 0 r
F
.44217 .92197 m .44269 .90185 L .44291 .90191 L F
.44269 .90182 m .43201 .90383 L .44291 .90191 L .25 0 0 r
F
.44519 .92183 m .44554 .90279 L .44576 .90285 L .109 .011 0 r
F
.44634 .90259 m .44299 .90194 L .44521 .90256 L .248 0 0 r
F
.44892 .90351 m .44634 .90259 L .44576 .90285 L .251 0 0 r
F
.44919 .90357 m .44896 .90349 L .44892 .90351 L F
.44896 .90349 m .44634 .90259 L .44892 .90351 L F
.44919 .90357 m .44576 .90285 L .44579 .90286 L F
.45373 .92113 m .4526 .9214 L .44519 .92183 L .106 .159 0 r
F
.4547 .92105 m .45446 .92109 L .45373 .92113 L F
.45446 .92109 m .4526 .9214 L .45373 .92113 L F
.4547 .92105 m .44519 .92183 L .44824 .92159 L F
.44824 .92159 m .44519 .92183 L .44576 .90285 L .109 .011 0 r
F
.44824 .92159 m .44576 .90285 L .44577 .90286 L F
.44919 .90357 m .44579 .90286 L .44842 .90374 L .251 0 0 r
F
.44576 .90285 m .43567 .90479 L .43936 .90574 L .248 0 0 r
F
.44634 .90259 m .44554 .90276 L .44576 .90285 L F
.44554 .90279 m .44554 .90276 L .44576 .90285 L .109 .011 0 r
F
.44554 .90276 m .43567 .90479 L .44576 .90285 L .248 0 0 r
F
.44634 .90259 m .4449 .90255 L .44555 .90276 L F
.44634 .90259 m .44352 .90167 L .44291 .90191 L F
.44634 .90259 m .44291 .90191 L .44297 .90193 L F
.4536 .8981 m .45169 .89718 L .44352 .90167 L .149 0 0 r
F
.4536 .8981 m .44352 .90167 L .44634 .90259 L F
.44554 .90276 m .44826 .75556 L .44576 .90285 L .109 .011 0 r
F
.44842 .90374 m .44576 .90282 L .44842 .90368 L F
.45207 .90463 m .44919 .90357 L .44865 .90385 L .26 0 0 r
F
.44824 .92159 m .44577 .90286 L .44733 .90337 L .109 .011 0 r
F
.44824 .92159 m .44733 .90337 L .44842 .90376 L F
.44824 .92142 m .44842 .90374 L .44212 .92174 L F
.44791 .90519 m .44285 .90666 L .4421 .92182 L F
.44842 .90374 m .44285 .90666 L .44791 .90519 L F
.44842 .90376 m .44733 .90337 L .44842 .90374 L F
.44919 .90357 m .4396 .90569 L .44285 .90666 L .251 0 0 r
F
.4467 .90486 m .44285 .90666 L .4431 .90673 L F
.44919 .90357 m .44285 .90666 L .4467 .90486 L F
.4396 .90569 m .44085 .90614 L .44285 .90666 L F
.4423 .9068 m .43936 .90574 L .44219 .90683 L .306 0 0 r
F
.44285 .90666 m .43936 .90574 L .4423 .9068 L F
.44285 .90666 m .44219 .90683 L .44219 .90698 L 1 .709 0 r
F
.44285 .90666 m .4423 .9068 L .44234 .90681 L .306 0 0 r
F
.44841 .90374 m .44576 .90286 L .43952 .90567 L .251 0 0 r
F
.44841 .90374 m .43952 .90567 L .4396 .90569 L F
.44291 .90189 m .44667 .74654 L .44826 .75556 L .108 .011 0 r
F
.44291 .90191 m .44291 .90188 L .44291 .90189 L F
.44291 .90188 m .44667 .74654 L .44291 .90189 L F
.44521 .90256 m .44289 .90192 L .44485 .90255 L .248 0 0 r
F
.44299 .90194 m .44289 .90192 L .44521 .90256 L F
.44576 .90282 m .44826 .75556 L .44984 .76698 L .109 .011 0 r
F
.44576 .90282 m .44826 .75556 L .44576 .90282 L F
.44554 .90276 m .44291 .90189 L .44555 .90273 L F
.44291 .90191 m .44291 .90189 L .44554 .90276 L F
.44297 .90193 m .44291 .90191 L .44289 .90192 L .248 0 0 r
F
.44553 .90276 m .44289 .90192 L .43567 .90479 L F
.44291 .90191 m .43201 .90383 L .43567 .90479 L .25 0 0 r
F
.44291 .90191 m .44291 .90191 L .44291 .90189 L .109 .011 0 r
F
.44555 .90273 m .44291 .90189 L .44826 .75556 L F
.44287 .90628 m .44984 .76698 L .44221 .90656 L 1 .709 0 r
F
.44008 .90096 m .44507 .73932 L .44667 .74654 L 1 .753 0 r
F
.43986 .9009 m .44507 .73932 L .44008 .90096 L F
.44219 .90683 m .44984 .76698 L .44286 .79694 L 1 .709 0 r
F
.44219 .90683 m .44984 .76698 L .44219 .90683 L F
.44842 .90374 m .44287 .90628 L .44285 .90666 L .109 .011 0 r
F
.45133 .90481 m .44865 .90385 L .4431 .90673 L .26 0 0 r
F
.44579 .90286 m .44576 .90285 L .44579 .90286 L .251 0 0 r
F
.44577 .90286 m .44576 .90282 L .44842 .90374 L .109 .011 0 r
F
.44842 .90374 m .44576 .90286 L .44841 .90374 L .251 0 0 r
F
.44579 .90286 m .44576 .90286 L .44842 .90374 L F
.44579 .90286 m .44576 .90285 L .44576 .90286 L F
.44577 .90286 m .44576 .90285 L .44576 .90282 L .109 .011 0 r
F
.45383 .89972 m .4536 .8981 L .44634 .90259 L .146 0 0 r
F
.45553 .89907 m .44634 .90259 L .44919 .90357 L F
.44662 .9031 m .44576 .90282 L .44984 .76698 L .109 .011 0 r
F
.44842 .90368 m .44662 .9031 L .44984 .76698 L F
.44555 .90276 m .44485 .90255 L .44554 .90276 L .248 0 0 r
F
.4449 .90255 m .44485 .90255 L .44555 .90276 L F
.44554 .90276 m .44485 .90255 L .44553 .90276 L F
.44576 .90285 m .44576 .90282 L .44576 .90282 L .109 .011 0 r
F
.44658 .90458 m .44984 .76698 L .44287 .90628 L F
.44842 .90374 m .44843 .90334 L .44658 .90458 L F
.44843 .90334 m .44984 .76698 L .44658 .90458 L F
.45553 .89907 m .45512 .89886 L .45383 .89972 L .146 0 0 r
F
.45512 .89886 m .4536 .8981 L .45383 .89972 L F
.45207 .90463 m .4431 .90673 L .44688 .90779 L .26 0 0 r
F
.44629 .90723 m .44501 .81321 L .44742 .83119 L .257 .04 0 r
F
.44688 .90779 m .4431 .90673 L .44288 .90681 L .32 0 0 r
F
.4421 .92182 m .44285 .90666 L .44219 .90698 L 1 .709 0 r
F
.44287 .90628 m .44221 .90656 L .44219 .90683 L F
.44219 .90698 m .44219 .90683 L .44219 .90683 L F
.4421 .92182 m .44219 .90686 L .44249 .90696 L F
.44249 .90696 m .43283 .90788 L .4374 .9089 L .306 0 0 r
F
.4431 .90673 m .44219 .90683 L .44249 .90696 L F
.44219 .90686 m .44219 .90683 L .44249 .90696 L 1 .709 0 r
F
.44219 .90683 m .43283 .90788 L .44249 .90696 L .306 0 0 r
F
.44234 .90681 m .4423 .9068 L .44219 .90683 L F
.44219 .90683 m .44219 .90589 L .44249 .90696 L 1 .709 0 r
F
.44249 .90696 m .44219 .90589 L .44252 .90596 L F
.44594 .9079 m .44288 .90681 L .44249 .90696 L .32 0 0 r
F
.44688 .90779 m .44288 .90681 L .44594 .9079 L F
.44285 .90666 m .44287 .90628 L .44219 .90683 L 1 .709 0 r
F
.4431 .90673 m .44285 .90666 L .44234 .90681 L .306 0 0 r
F
.44824 .92159 m .44824 .92142 L .4421 .92182 L .109 .011 0 r
F
.44824 .92142 m .44212 .92174 L .4421 .92182 L F
.45169 .9212 m .4547 .92105 L .44824 .92159 L .128 .162 0 r
F
.45681 .92063 m .45519 .92095 L .45169 .9212 L F
.45519 .92095 m .4547 .92105 L .45169 .9212 L F
.45681 .92063 m .44824 .92159 L .45131 .92129 L F
.45131 .92129 m .44824 .92159 L .44256 .9218 L .078 .153 0 r
F
.45131 .92129 m .44729 .92152 L .44608 .92166 L F
.44285 .92178 m .44256 .9218 L .4421 .92182 L F
.45131 .92129 m .44256 .9218 L .44285 .92178 L F
.44729 .92152 m .4421 .92182 L .44463 .92172 L F
.44729 .92152 m .44463 .92172 L .44608 .92166 L F
.44608 .92149 m .44594 .90796 L .44628 .90808 L .257 .04 0 r
F
.44608 .92166 m .44608 .92149 L .44608 .92149 L F
.44608 .92149 m .44594 .90796 L .44608 .92149 L F
.4502 .90888 m .44688 .90779 L .44632 .90804 L .34 0 0 r
F
.45026 .90885 m .44688 .90779 L .4502 .90888 L F
.45481 .92078 m .45681 .92063 L .45131 .92129 L .142 .165 0 r
F
.45893 .92017 m .45765 .92044 L .45481 .92078 L F
.45765 .92044 m .45681 .92063 L .45481 .92078 L F
.45893 .92017 m .45131 .92129 L .4544 .92096 L F
.45378 .92101 m .45131 .92129 L .44608 .92166 L .082 .154 0 r
F
.4544 .92096 m .45415 .92099 L .45378 .92101 L F
.45415 .92099 m .45131 .92129 L .45378 .92101 L F
.4544 .92096 m .4503 .9213 L .45009 .92146 L F
.4503 .9213 m .44608 .92166 L .44813 .92156 L F
.4503 .9213 m .44813 .92156 L .45009 .92146 L F
.45009 .92146 m .44608 .92166 L .44628 .90806 L .258 .04 0 r
F
.45009 .92146 m .44628 .90806 L .44928 .90896 L F
.44973 .90912 m .44928 .90896 L .44973 .9091 L F
.45009 .92146 m .44928 .90896 L .44973 .90912 L F
.45456 .91043 m .4507 .90898 L .45016 .90928 L .368 0 0 r
F
.45009 .92126 m .44973 .9091 L .44614 .92152 L .258 .04 0 r
F
.44942 .91015 m .44624 .91107 L .44608 .92171 L F
.44973 .9091 m .44624 .91107 L .44942 .91015 L F
.44608 .92166 m .4421 .92182 L .4425 .90688 L .257 .04 0 r
F
.44608 .92166 m .4425 .90688 L .44257 .9069 L F
.44608 .92166 m .4425 .90662 L .44594 .9079 L F
.4507 .90898 m .44202 .90999 L .44624 .91107 L .34 0 0 r
F
.44936 .90972 m .44624 .91107 L .44669 .91118 L F
.4507 .90898 m .44624 .91107 L .44936 .90972 L F
.44548 .91122 m .44202 .90999 L .43759 .91146 L .369 0 0 r
F
.44566 .91118 m .44202 .90999 L .44548 .91122 L F
.44624 .91107 m .44202 .90999 L .44566 .91118 L F
.44979 .90909 m .44632 .90804 L .44628 .90806 L .34 0 0 r
F
.44979 .90909 m .44628 .90806 L .44973 .9091 L F
.4507 .90898 m .44632 .90804 L .44979 .90909 L F
.44632 .90804 m .43743 .9089 L .44202 .90999 L .32 0 0 r
F
.43743 .9089 m .4374 .9089 L .4376 .90895 L F
.43743 .9089 m .4376 .90895 L .44202 .90999 L F
.44688 .90779 m .44594 .9079 L .44632 .90804 L F
.44594 .90796 m .44594 .9079 L .44628 .90808 L .257 .04 0 r
F
.44594 .9079 m .44628 .90806 L .44628 .90808 L F
.44594 .9079 m .4374 .9089 L .44626 .90805 L .32 0 0 r
F
.44594 .9079 m .44626 .90805 L .44632 .90804 L F
.44594 .9079 m .44628 .90802 L .44628 .90806 L .257 .04 0 r
F
.44629 .90806 m .44628 .90806 L .44742 .83119 L .258 .04 0 r
F
.45207 .90463 m .44865 .90385 L .45133 .90481 L .26 0 0 r
F
.4498 .8963 m .44894 .89655 L .44908 .89665 L .168 0 0 r
F
.45169 .89718 m .44908 .89665 L .45085 .89746 L .156 0 0 r
F
.45749 .90016 m .45553 .89907 L .44919 .90357 L .15 0 0 r
F
.45749 .90016 m .44919 .90357 L .45207 .90463 L F
.45337 .90625 m .45207 .90463 L .44688 .90779 L .276 0 0 r
F
.45499 .90587 m .45433 .90559 L .45337 .90625 L F
.45433 .90559 m .45207 .90463 L .45337 .90625 L F
.45499 .90587 m .44688 .90779 L .4507 .90898 L F
.44973 .9091 m .44629 .90806 L .44742 .83119 L .258 .04 0 r
F
.44973 .9091 m .44628 .90806 L .44202 .90999 L .34 0 0 r
F
.44828 .90978 m .44742 .83119 L .44625 .91073 L .258 .04 0 r
F
.44973 .9091 m .44972 .90878 L .44828 .90978 L F
.44972 .90878 m .44742 .83119 L .44828 .90978 L F
.44594 .9079 m .4425 .90662 L .44501 .81321 L .257 .04 0 r
F
.44594 .9079 m .44249 .90696 L .44545 .90796 L .32 0 0 r
F
.44594 .9079 m .44501 .81321 L .44628 .90802 L .257 .04 0 r
F
.44628 .90808 m .44627 .90722 L .44629 .90723 L F
.44627 .90722 m .44501 .81321 L .44629 .90723 L F
.44624 .91107 m .44742 .83119 L .4455 .91122 L 1 .676 0 r
F
.44624 .91107 m .4455 .91122 L .44549 .91139 L F
.44624 .91107 m .44566 .91118 L .44574 .91121 L .369 0 0 r
F
.44545 .90796 m .44249 .90696 L .43741 .9089 L .32 0 0 r
F
.43743 .9089 m .43741 .9089 L .4374 .9089 L F
.44545 .90796 m .43741 .9089 L .43743 .9089 L F
.44548 .91122 m .44742 .83119 L .44544 .91057 L 1 .676 0 r
F
.44252 .90596 m .44285 .79927 L .44498 .8142 L 1 .709 0 r
F
.44219 .90589 m .44286 .79694 L .44252 .90596 L F
.44741 .83123 m .43878 .83824 L .44216 .85341 L .829 .304 0 r
F
.44742 .83119 m .44741 .8312 L .44741 .83123 L F
.44741 .8312 m .43878 .83824 L .44741 .83123 L F
.44498 .8142 m .44286 .79707 L .44501 .81321 L 1 .709 0 r
F
.44285 .79927 m .44286 .79707 L .44498 .8142 L F
.44286 .79707 m .44286 .79694 L .44501 .81321 L F
.44741 .8312 m .44501 .81321 L .43878 .83824 L .829 .304 0 r
F
.44742 .83119 m .44501 .81321 L .44741 .8312 L F
.44544 .91057 m .44742 .83119 L .44216 .85341 L 1 .676 0 r
F
.44574 .91121 m .44566 .91118 L .44548 .91122 L .369 0 0 r
F
.4455 .91122 m .44742 .83119 L .44548 .91122 L 1 .676 0 r
F
.44549 .91139 m .4455 .91122 L .44548 .91122 L F
.44608 .92171 m .44624 .91107 L .44549 .91139 L F
.44608 .92171 m .44548 .91125 L .44559 .91128 L F
.44669 .91118 m .44548 .91122 L .44606 .91144 L .369 0 0 r
F
.44606 .91144 m .44559 .91128 L .44606 .91141 L 1 .676 0 r
F
.44608 .92171 m .44559 .91128 L .44606 .91144 L F
.45141 .91258 m .44669 .91118 L .44634 .91132 L .402 0 0 r
F
.45141 .91258 m .44634 .91132 L .44778 .91181 L F
.45589 .92142 m .45589 .92129 L .45118 .92159 L 0 0 0 r
F
.45914 .92097 m .45805 .92123 L .44847 .92183 L .099 .157 0 r
F
.45914 .92097 m .44847 .92183 L .45053 .92166 L F
.46025 .92061 m .45914 .92097 L .45053 .92166 L .135 .164 0 r
F
.46025 .92061 m .45053 .92166 L .4526 .9214 L F
.46248 .91962 m .46136 .92015 L .4547 .92105 L .2 .175 0 r
F
.46248 .91962 m .4547 .92105 L .45681 .92063 L F
.45752 .92064 m .4544 .92096 L .45009 .92146 L 0 0 0 r
F
.46136 .92015 m .46025 .92061 L .4526 .9214 L .169 .17 0 r
F
.46136 .92015 m .4526 .9214 L .4547 .92105 L F
.45413 .92128 m .45009 .92146 L .44647 .92168 L 0 0 0 r
F
.44695 .92166 m .44647 .92168 L .44608 .92171 L F
.45413 .92128 m .44647 .92168 L .44695 .92166 L F
.45752 .92064 m .45009 .92146 L .45413 .92128 L F
.45413 .92128 m .44611 .92171 L .45099 .92168 L F
.44611 .92171 m .44608 .92171 L .45099 .92168 L F
.45141 .91258 m .44606 .91144 L .45014 .9126 L .402 0 0 r
F
.45363 .91051 m .45016 .90928 L .44669 .91118 L .368 0 0 r
F
.45456 .91043 m .45016 .90928 L .45363 .91051 L F
.45999 .89085 m .459 .89001 L .4498 .8963 L 0 0 0 r
F
.45999 .89085 m .4498 .8963 L .45169 .89718 L F
.46098 .89173 m .45999 .89085 L .45169 .89718 L F
.46098 .89173 m .45169 .89718 L .4536 .8981 L F
.45947 .90146 m .45749 .90016 L .45207 .90463 L .161 0 0 r
F
.45947 .90146 m .45207 .90463 L .45499 .90587 L F
.45794 .90739 m .45499 .90587 L .4507 .90898 L .299 0 0 r
F
.46108 .91972 m .45893 .92017 L .4544 .92096 L .142 .164 0 r
F
.45794 .90739 m .4507 .90898 L .45456 .91043 L .299 0 0 r
F
.46361 .91903 m .46248 .91962 L .45681 .92063 L .228 .18 0 r
F
.46361 .91903 m .45681 .92063 L .45893 .92017 L F
.46108 .91972 m .4544 .92096 L .45752 .92064 L .142 .164 0 r
F
.45456 .91043 m .44669 .91118 L .45141 .91258 L .368 0 0 r
F
.45014 .91261 m .45014 .9126 L .45083 .91289 L .365 .062 0 r
F
.45141 .91258 m .45002 .9126 L .45083 .91289 L .402 0 0 r
F
.45083 .91289 m .45014 .9126 L .45082 .91283 L .365 .062 0 r
F
.45099 .92148 m .45014 .91261 L .45083 .91289 L F
.45524 .9141 m .45141 .91258 L .45083 .91289 L .446 0 0 r
F
.45588 .91428 m .45531 .91406 L .45524 .9141 L F
.45531 .91406 m .45141 .91258 L .45524 .9141 L F
.46065 .92045 m .45752 .92064 L .45413 .92128 L 0 0 0 r
F
.45787 .92124 m .45413 .92128 L .45099 .92168 L .03 0 0 r
F
.45821 .92122 m .458 .92123 L .45787 .92124 L F
.458 .92123 m .45413 .92128 L .45787 .92124 L F
.46065 .92045 m .45413 .92128 L .45821 .92122 L 0 0 0 r
F
.45821 .92122 m .45099 .92168 L .45593 .92177 L .03 0 0 r
F
.45591 .92165 m .45099 .92168 L .45083 .91289 L .364 .062 0 r
F
.45591 .92165 m .45083 .91289 L .45487 .91436 L F
.45593 .92177 m .45589 .92151 L .45387 .92211 L F
.45592 .91426 m .45141 .91258 L .45588 .91428 L .446 0 0 r
F
.45619 .91436 m .45083 .91289 L .45487 .91432 L F
.45674 .91237 m .45456 .91043 L .45141 .91258 L .405 0 0 r
F
.45847 .9123 m .45741 .91179 L .45674 .91237 L F
.45741 .91179 m .45456 .91043 L .45674 .91237 L F
.45847 .9123 m .45141 .91258 L .45619 .91436 L F
.45487 .91432 m .45083 .91289 L .45025 .88197 L .364 .062 0 r
F
.45487 .91436 m .45083 .91289 L .45487 .91432 L F
.45487 .91432 m .45083 .91289 L .45419 .91429 L .446 0 0 r
F
.45097 .92148 m .45014 .9126 L .45099 .92148 L .365 .062 0 r
F
.45099 .92168 m .44606 .91144 L .45002 .91257 L F
.45014 .91261 m .45002 .91257 L .45014 .9126 L F
.45099 .92168 m .45002 .91257 L .45014 .91261 L F
.45419 .91429 m .45083 .91289 L .44855 .9141 L .446 0 0 r
F
.44778 .91181 m .44634 .91132 L .44606 .91144 L .402 0 0 r
F
.44973 .9091 m .44625 .91073 L .44624 .91107 L .258 .04 0 r
F
.44669 .91118 m .44624 .91107 L .44574 .91121 L .369 0 0 r
F
.45014 .9126 m .44606 .91144 L .44597 .86813 L .365 .062 0 r
F
.44606 .91141 m .44248 .85821 L .44598 .86926 L 1 .676 0 r
F
.4507 .90898 m .45026 .90885 L .4502 .90888 L .34 0 0 r
F
.45082 .91283 m .44597 .86813 L .45025 .88197 L .365 .062 0 r
F
.45014 .9126 m .44597 .86813 L .45082 .91283 L F
.44544 .91057 m .44216 .85341 L .44601 .91069 L 1 .676 0 r
F
.45012 .88236 m .44231 .87973 L .44747 .89052 L .913 .325 0 r
F
.45025 .88197 m .44998 .88189 L .45012 .88236 L F
.44998 .88189 m .44231 .87973 L .45012 .88236 L F
.44598 .86926 m .4423 .85548 L .44597 .86813 L 1 .676 0 r
F
.44248 .85821 m .4423 .85548 L .44598 .86926 L F
.4423 .85548 m .44216 .85341 L .44597 .86813 L F
.44998 .88189 m .44597 .86813 L .44231 .87973 L .913 .325 0 r
F
.45025 .88197 m .44597 .86813 L .44998 .88189 L F
.447 .8972 m .44747 .89052 L .44514 .89616 L .978 .306 0 r
F
.45593 .92177 m .45099 .92168 L .45591 .92165 L .364 .062 0 r
F
.45589 .92151 m .45487 .91432 L .45391 .92178 L F
.45477 .91506 m .45328 .91558 L .45387 .92211 L F
.45487 .91432 m .45328 .91558 L .45477 .91506 L F
.45328 .91558 m .44855 .9141 L .45284 .91573 L .461 0 0 r
F
.45257 .9157 m .45325 .91525 L .45253 .91552 L 1 .614 0 r
F
.45387 .92211 m .45328 .91558 L .45257 .9157 L F
.45328 .91558 m .45325 .91525 L .45257 .9157 L F
.45009 .92146 m .45009 .92126 L .44608 .92171 L .258 .04 0 r
F
.45009 .92126 m .44614 .92152 L .44608 .92171 L F
.45099 .92168 m .44608 .92171 L .44606 .91144 L .365 .062 0 r
F
.45257 .9157 m .44855 .9141 L .44603 .91514 L .461 0 0 r
F
.45284 .91573 m .45271 .91568 L .45257 .9157 L F
.45271 .91568 m .44855 .9141 L .45257 .9157 L F
.45412 .91584 m .45328 .91558 L .45284 .91573 L F
.45619 .91436 m .45487 .91432 L .45412 .91584 L .446 0 0 r
F
.45487 .91432 m .44855 .9141 L .45328 .91558 L F
.45487 .91432 m .45328 .91558 L .45412 .91584 L F
.45487 .91432 m .45325 .91525 L .45328 .91558 L .364 .062 0 r
F
.45386 .9149 m .45092 .8881 L .45325 .91525 L F
.45092 .8881 m .4508 .88697 L .4509 .88815 L F
.45092 .8881 m .4509 .88815 L .45325 .91525 L F
.4508 .88697 m .45072 .88718 L .45325 .91525 L F
.45483 .91405 m .45025 .88197 L .45386 .9149 L F
.45253 .91552 m .45025 .88197 L .44747 .89052 L 1 .614 0 r
F
.45325 .91525 m .45025 .88197 L .45253 .91552 L F
.45412 .91584 m .45257 .9157 L .45363 .91612 L .461 0 0 r
F
.45363 .91612 m .44747 .89052 L .45302 .90057 L 1 .614 0 r
F
.45387 .92211 m .45257 .9157 L .45363 .91612 L F
.45257 .9157 m .44747 .89052 L .45363 .91612 L F
.45363 .91612 m .44603 .91514 L .4523 .91688 L .461 0 0 r
F
.45257 .9157 m .44603 .91514 L .45363 .91612 L F
.45302 .90057 m .447 .8972 L .45138 .90447 L .978 .306 0 r
F
.447 .8972 m .44514 .89616 L .4466 .89811 L F
.447 .8972 m .4466 .89811 L .45138 .90447 L F
.45302 .90057 m .44867 .89269 L .447 .8972 L F
.44867 .89269 m .44747 .89052 L .447 .8972 L F
.4508 .88697 m .45025 .88197 L .45072 .88718 L .364 .062 0 r
F
.45487 .91432 m .45483 .91405 L .45386 .9149 L F
.45589 .92151 m .45391 .92178 L .45387 .92211 L F
.45619 .91436 m .45592 .91426 L .45588 .91428 L .446 0 0 r
F
.45083 .91289 m .44304 .91269 L .44855 .9141 L .402 0 0 r
F
.45002 .9126 m .44304 .91269 L .45083 .91289 L F
.45099 .92168 m .45097 .92148 L .45099 .92148 L .365 .062 0 r
F
.45014 .9126 m .44606 .91144 L .44943 .91261 L .402 0 0 r
F
.44943 .91261 m .44606 .91144 L .44304 .91269 L F
.44606 .91144 m .43759 .91146 L .44304 .91269 L .369 0 0 r
F
.44548 .91125 m .44548 .91122 L .44577 .91133 L 1 .676 0 r
F
.44548 .91122 m .43759 .91146 L .44606 .91144 L .369 0 0 r
F
.44577 .91133 m .44544 .91057 L .44606 .91141 L 1 .676 0 r
F
.44548 .91122 m .44544 .91057 L .44577 .91133 L F
.44544 .91057 m .44601 .91069 L .44606 .91141 L F
.44257 .9069 m .4425 .90688 L .4425 .90662 L .257 .04 0 r
F
.4396 .90569 m .43952 .90567 L .43936 .90574 L .251 0 0 r
F
.44219 .90683 m .43936 .90574 L .43283 .90788 L .306 0 0 r
F
.4396 .90569 m .43936 .90574 L .44085 .90614 L .251 0 0 r
F
.43244 .90375 m .43232 .90372 L .43201 .90383 L .25 0 0 r
F
.43986 .9009 m .43912 .90113 L .44007 .90098 L .257 0 0 r
F
.43988 .90089 m .43986 .9009 L .44007 .90098 L F
.44007 .90098 m .43986 .9009 L .44008 .90096 L 1 .753 0 r
F
.44007 .90098 m .42839 .90285 L .43201 .90383 L .257 0 0 r
F
.44008 .90098 m .44007 .90098 L .44008 .90096 L .108 .011 0 r
F
.43986 .9009 m .43985 .9009 L .43984 .9009 L .257 0 0 r
F
.43984 .9009 m .43797 .89982 L .42839 .90285 L F
.45603 .88872 m .45197 .89083 L .45197 .89102 L 0 0 0 r
F
.45803 .88917 m .45611 .88884 L .45701 .88962 L .032 0 0 r
F
.4569 .88827 m .45611 .8874 L .45513 .8879 L .059 0 0 r
F
.45706 .8883 m .45513 .8879 L .4568 .88841 L F
.45515 .88792 m .45513 .8879 L .45513 .88786 L 0 0 0 r
F
.46781 .87892 m .46771 .87807 L .45517 .88644 L F
.46781 .87892 m .45517 .88644 L .45611 .8874 L F
.45603 .88874 m .45513 .88786 L .45681 .70298 L F
.45313 .88596 m .45309 .88592 L .45309 .88588 L F
.45321 .88605 m .45313 .88596 L .45309 .88588 L F
.45603 .88872 m .45681 .70298 L .45197 .89083 L F
.45706 .8883 m .45698 .88823 L .4569 .88827 L .059 0 0 r
F
.45698 .88823 m .45611 .8874 L .4569 .88827 L F
.46615 .87788 m .46614 .87773 L .46433 .87879 L 0 0 0 r
F
.46614 .87773 m .46606 .87699 L .46433 .87879 L F
.46565 .87451 m .46549 .87436 L .46507 .87477 L .077 0 0 r
F
.46549 .87436 m .46488 .87372 L .46418 .87405 L F
.46576 .87471 m .46576 .87463 L .46576 .87463 L 1 .699 0 r
F
.46507 .87477 m .46418 .87405 L .46493 .87483 L .077 0 0 r
F
.46624 .87784 m .46196 .69192 L .46352 .87935 L 0 0 0 r
F
.46515 .87847 m .46352 .87935 L .46352 .87941 L F
.46624 .87784 m .46352 .87935 L .46515 .87847 L F
.46762 .87715 m .46747 .87713 L .46624 .87784 L F
.46721 .92015 m .46721 .92004 L .46386 .9203 L F
.48073 .865 m .48128 .86339 L .48069 .86437 L .896 .166 0 r
F
.48251 .86326 m .48069 .86437 L .46736 .87387 L 0 0 0 r
F
.48069 .86437 m .46735 .87374 L .46736 .87387 L F
.48069 .86437 m .46736 .87315 L .46735 .87374 L .896 .166 0 r
F
.48069 .86437 m .46928 .68517 L .46736 .87315 L F
.48069 .86437 m .48091 .86401 L .46928 .68517 L F
.48091 .86401 m .48128 .86339 L .48128 .86332 L F
.48126 .86323 m .48128 .86332 L .48128 .86339 L .897 .166 0 r
F
.48126 .86323 m .48125 .86313 L .48117 .86328 L 0 0 0 r
F
.48091 .86401 m .48128 .86332 L .46928 .68517 L .896 .166 0 r
F
.48129 .86344 m .48128 .86339 L .48125 .86345 L 0 0 0 r
F
.48182 .86427 m .48251 .86326 L .48062 .86459 L F
.48002 .86546 m .48062 .86459 L .46736 .87387 L F
.48182 .86427 m .48062 .86459 L .48002 .86546 L F
.4832 .86213 m .48135 .86318 L .48128 .86339 L F
.48251 .86326 m .4832 .86213 L .48128 .86339 L F
.48251 .86326 m .48128 .86339 L .48129 .86344 L F
.48181 .8622 m .48184 .86215 L .48174 .86221 L F
.48184 .86215 m .48183 .86209 L .48151 .86277 L .897 .166 0 r
F
.48185 .8622 m .48184 .86215 L .48181 .8622 L 0 0 0 r
F
.48128 .86339 m .48128 .86332 L .48128 .86332 L .897 .166 0 r
F
.46927 .68517 m .46882 .68512 L .46848 .68557 L 0 0 0 r
F
.46928 .68517 m .46927 .68517 L .46927 .68517 L F
.46927 .68517 m .46882 .68512 L .46927 .68517 L F
.46919 .68463 m .46918 .68459 L .46919 .68463 L .898 .166 0 r
F
.48191 .86192 m .48182 .86197 L .48184 .86215 L 0 0 0 r
F
.48184 .86215 m .48184 .86215 L .48183 .86209 L .897 .166 0 r
F
.48184 .86215 m .48183 .86209 L .48183 .86209 L .898 .166 0 r
F
.46919 .68463 m .46918 .68459 L .46923 .6849 L F
.46927 .68517 m .46923 .6849 L .46882 .68512 L 0 0 0 r
F
.46928 .68517 m .46923 .6849 L .46927 .68517 L F
.46848 .68557 m .46882 .68512 L .46007 .68978 L F
.46923 .6849 m .46918 .68459 L .45961 .68921 L F
.46923 .6849 m .46918 .68459 L .46923 .6849 L F
.46914 .68428 m .46914 .68424 L .46918 .68459 L .99 .671 0 r
F
.48209 .86141 m .48239 .86079 L .48238 .86073 L .898 .166 0 r
F
.4832 .86213 m .48387 .86089 L .48184 .86215 L 0 0 0 r
F
.4832 .86213 m .48184 .86215 L .48185 .8622 L F
.48387 .86089 m .48239 .86079 L .48248 .86162 L F
.49787 .84868 m .49562 .85064 L .49649 .84994 L .516 .206 0 r
F
.49646 .84949 m .49787 .84868 L .48403 .86137 L .585 .216 0 r
F
.48453 .86086 m .48403 .86137 L .4832 .86213 L F
.49646 .84949 m .48403 .86137 L .48453 .86086 L F
.49527 .85066 m .4832 .86213 L .48266 .86302 L F
.49527 .85066 m .48266 .86302 L .48267 .8631 L F
.49449 .85136 m .4832 .86213 L .49527 .85066 L F
.49646 .84949 m .49449 .85136 L .49527 .85066 L F
.49503 .85016 m .49646 .84949 L .4832 .86258 L .649 .224 0 r
F
.48362 .8621 m .4832 .86258 L .48251 .86326 L F
.49503 .85016 m .4832 .86258 L .48362 .8621 L F
.49401 .85125 m .48251 .86326 L .48182 .86427 L F
.49333 .85194 m .48251 .86326 L .49401 .85125 L F
.49503 .85016 m .49333 .85194 L .49401 .85125 L F
.49358 .8507 m .49503 .85016 L .48182 .86427 L .707 .243 0 r
F
.49272 .85169 m .48182 .86427 L .48112 .86517 L F
.49358 .8507 m .49213 .85236 L .49272 .85169 L F
.49213 .85236 m .48182 .86427 L .49272 .85169 L F
.48267 .8631 m .48266 .86302 L .48251 .86326 L .585 .216 0 r
F
.50596 .91337 m .50759 .91228 L .49953 .84751 L 1 .456 0 r
F
.50596 .91337 m .49953 .84751 L .49953 .84751 L F
.49958 .84703 m .47908 .67983 L .49949 .84716 L 1 .458 0 r
F
.49958 .84703 m .49949 .84716 L .4995 .84726 L F
.4995 .84726 m .47908 .67983 L .47872 .68008 L F
.50063 .84662 m .50199 .84538 L .4995 .84726 L 0 0 0 r
F
.50063 .84662 m .4995 .84726 L .49946 .8473 L F
.50073 .84611 m .50074 .84611 L .50071 .84586 L 1 .458 0 r
F
.49958 .84703 m .50071 .84586 L .47908 .67983 L F
.50015 .84664 m .50071 .84586 L .49958 .84703 L 0 0 0 r
F
.50199 .84538 m .50071 .84586 L .50015 .84664 L F
.50332 .844 m .50079 .84561 L .50071 .84586 L F
.50071 .84586 m .47944 .67954 L .47908 .67983 L .934 .633 0 r
F
.48239 .86079 m .48238 .86073 L .48238 .86073 L .99 .671 0 r
F
.44405 .92653 m .43638 .92176 L .44121 .92175 L .287 .235 0 r
F
.44579 .92665 m .44273 .92663 L .44405 .92653 L .14 .162 0 r
F
.44273 .92663 m .44243 .92663 L .44405 .92653 L F
.44579 .92665 m .43973 .9269 L .44243 .92663 L F
.44557 .92723 m .44296 .92728 L .44175 .92706 L .125 .16 0 r
F
.44794 .92733 m .44447 .92734 L .44557 .92723 L F
.44794 .92733 m .44686 .92748 L .44603 .92743 L F
.44812 .92858 m .44741 .92863 L .44623 .92858 L .039 .146 0 r
F
.44741 .92863 m .44604 .92873 L .44623 .92858 L F
.46188 .92845 m .46191 .92828 L .45241 .92836 L .071 0 0 r
F
.45894 .92824 m .45783 .92858 L .44812 .92858 L .097 .156 0 r
F
.45894 .92824 m .44812 .92858 L .45021 .9283 L F
.45106 .92679 m .44794 .92733 L .44175 .92706 L .152 .165 0 r
F
.45106 .92679 m .44175 .92706 L .44579 .92665 L F
.44975 .92859 m .44564 .92921 L .44405 .92653 L .296 .219 0 r
F
.44243 .92663 m .43638 .92176 L .44405 .92653 L .287 .235 0 r
F
.44121 .92175 m .43638 .92176 L .43118 .92145 L .035 .145 0 r
F
.44121 .92175 m .43118 .92145 L .4368 .92161 L F
.44258 .9259 m .44121 .92175 L .4368 .92161 L .975 .076 0 r
F
.44765 .92629 m .44579 .92665 L .44405 .92653 L .157 .165 0 r
F
.44677 .92621 m .44405 .92653 L .44401 .92646 L .296 .219 0 r
F
.44677 .92621 m .44401 .92646 L .44121 .92175 L F
.44259 .92591 m .4409 .92632 L .43647 .92581 L .15 .163 0 r
F
.44259 .92591 m .44418 .92602 L .44258 .9259 L .975 .076 0 r
F
.44357 .92601 m .44418 .92602 L .44259 .92591 L F
.44418 .92602 m .44121 .92175 L .44258 .9259 L F
.44828 .92634 m .44579 .92665 L .44765 .92629 L .157 .165 0 r
F
.44986 .92615 m .44405 .92653 L .44677 .92621 L F
.44691 .92632 m .44405 .92653 L .44677 .92621 L .296 .219 0 r
F
.45661 .92673 m .45446 .92737 L .44794 .92733 L .174 .169 0 r
F
.45661 .92673 m .44794 .92733 L .45106 .92679 L F
.4542 .92616 m .45106 .92679 L .44579 .92665 L F
.4542 .92616 m .45065 .92637 L .44986 .92615 L F
.45065 .92637 m .44579 .92665 L .44843 .92632 L F
.45065 .92637 m .44843 .92632 L .44986 .92615 L F
.44625 .92733 m .44405 .92653 L .44686 .92632 L .296 .219 0 r
F
.44975 .92859 m .44688 .92629 L .44571 .92822 L F
.44688 .92629 m .44677 .92621 L .44673 .92629 L F
.44688 .92629 m .44673 .92629 L .44571 .92822 L F
.44677 .92621 m .44121 .92175 L .4442 .92605 L F
.44451 .92584 m .4368 .92161 L .44245 .92173 L .975 .076 0 r
F
.44584 .92596 m .44292 .92591 L .44451 .92584 L .15 .163 0 r
F
.44292 .92591 m .44259 .92591 L .44451 .92584 L F
.44677 .92621 m .4442 .92605 L .44515 .92612 L .296 .219 0 r
F
.44575 .92615 m .44565 .92616 L .44566 .92615 L .157 .165 0 r
F
.44565 .92616 m .4409 .92632 L .44422 .92608 L F
.44677 .92621 m .4409 .92632 L .44823 .92607 L F
.44677 .92621 m .44405 .92653 L .4409 .92632 L F
.44677 .92621 m .44422 .92608 L .44571 .92822 L .296 .219 0 r
F
.44584 .92596 m .44422 .92608 L .44259 .92591 L .15 .163 0 r
F
.44515 .92612 m .4442 .92605 L .44422 .92608 L .296 .219 0 r
F
.44565 .92616 m .44422 .92608 L .44584 .92596 L .157 .165 0 r
F
.45071 .92766 m .44571 .92822 L .44451 .92584 L .388 .336 0 r
F
.45081 .92555 m .44584 .92596 L .44451 .92584 L .152 .164 0 r
F
.44781 .92557 m .44451 .92584 L .44447 .92576 L .388 .336 0 r
F
.44781 .92557 m .44447 .92576 L .44245 .92173 L F
.44259 .92591 m .4368 .92161 L .44451 .92584 L .975 .076 0 r
F
.44975 .92548 m .44245 .92173 L .44814 .92187 L .388 .336 0 r
F
.45081 .92555 m .44818 .92557 L .44975 .92548 L .152 .164 0 r
F
.44818 .92557 m .44781 .92557 L .44975 .92548 L F
.45081 .92555 m .44451 .92584 L .44781 .92557 L F
.45877 .926 m .45661 .92673 L .45106 .92679 L .201 .174 0 r
F
.45877 .926 m .45106 .92679 L .4542 .92616 L F
.45736 .92547 m .4542 .92616 L .44986 .92615 L .187 .171 0 r
F
.45396 .92558 m .44986 .92615 L .44584 .92596 L .164 .167 0 r
F
.45736 .92547 m .44986 .92615 L .45396 .92558 L .187 .171 0 r
F
.45396 .92558 m .44584 .92596 L .45081 .92555 L .164 .167 0 r
F
.45574 .92705 m .45071 .92766 L .44975 .92548 L .391 .301 0 r
F
.45306 .92522 m .44975 .92548 L .4497 .92538 L F
.45306 .92522 m .4497 .92538 L .44814 .92187 L F
.44781 .92557 m .44245 .92173 L .44975 .92548 L .388 .336 0 r
F
.45084 .92512 m .44796 .92538 L .44545 .92509 L .128 .161 0 r
F
.45139 .92518 m .45175 .92514 L .45084 .92512 L .805 .046 0 r
F
.45362 .92526 m .45081 .92555 L .44975 .92548 L .133 .162 0 r
F
.45399 .92529 m .45081 .92555 L .45362 .92526 L F
.45581 .92514 m .44975 .92548 L .45306 .92522 L F
.46095 .92519 m .45877 .926 L .4542 .92616 L .222 .177 0 r
F
.46095 .92519 m .4542 .92616 L .45736 .92547 L F
.45809 .92502 m .45396 .92558 L .45081 .92555 L .151 .166 0 r
F
.45809 .92502 m .45512 .92524 L .45581 .92514 L F
.45512 .92524 m .45081 .92555 L .45404 .92528 L F
.45512 .92524 m .45404 .92528 L .45581 .92514 L F
.45574 .92705 m .44975 .92548 L .45317 .9253 L .391 .301 0 r
F
.45574 .92705 m .45321 .92532 L .45368 .92689 L F
.45317 .9253 m .44975 .92548 L .45306 .92522 L F
.45321 .92532 m .45306 .92522 L .4531 .92533 L F
.45321 .92532 m .4531 .92533 L .45368 .92689 L F
.45306 .92522 m .44814 .92187 L .45178 .92517 L F
.45084 .92512 m .45175 .92514 L .45077 .92508 L .805 .046 0 r
F
.45077 .92508 m .44814 .92187 L .44564 .92188 L F
.45175 .92514 m .44814 .92187 L .45077 .92508 L F
.45305 .9251 m .44564 .92188 L .45206 .9223 L F
.45375 .92514 m .45132 .92513 L .45305 .9251 L .128 .161 0 r
F
.45132 .92513 m .45084 .92512 L .45305 .9251 L F
.45306 .92522 m .44796 .92538 L .45488 .92514 L .133 .162 0 r
F
.46065 .92641 m .46056 .92635 L .46072 .92646 L 1 .41 0 r
F
.4635 .92564 m .46234 .92645 L .45661 .92673 L .239 .18 0 r
F
.4635 .92564 m .45661 .92673 L .45877 .926 L F
.46055 .92477 m .45736 .92547 L .45396 .92558 L .182 .171 0 r
F
.46055 .92477 m .45396 .92558 L .45809 .92502 L F
.45954 .92652 m .45368 .92689 L .45305 .9251 L .514 .376 0 r
F
.46314 .92437 m .46095 .92519 L .45736 .92547 L .23 .179 0 r
F
.46314 .92437 m .45736 .92547 L .46055 .92477 L F
.45797 .92499 m .45581 .92514 L .45375 .92514 L .062 .15 0 r
F
.45917 .92486 m .45809 .92502 L .45581 .92514 L .087 .155 0 r
F
.46375 .92421 m .46055 .92477 L .45809 .92502 L .133 .163 0 r
F
.46412 .92395 m .46314 .92437 L .46055 .92477 L .203 .175 0 r
F
.46375 .92421 m .45965 .9248 L .46224 .92461 L .133 .163 0 r
F
.45965 .9248 m .45809 .92502 L .45889 .92494 L F
.45965 .9248 m .45889 .92494 L .46224 .92461 L F
.46535 .92367 m .46497 .92379 L .46412 .92395 L .203 .175 0 r
F
.46497 .92379 m .46314 .92437 L .46412 .92395 L F
.46224 .92461 m .46001 .92483 L .45917 .92486 L .087 .155 0 r
F
.46001 .92483 m .45809 .92502 L .45917 .92486 L F
.46224 .92461 m .45917 .92486 L .46084 .92489 L F
.45917 .92486 m .45581 .92514 L .45877 .92499 L F
.45917 .92486 m .45877 .92499 L .46084 .92489 L F
.45488 .92514 m .45252 .92522 L .45375 .92514 L .133 .162 0 r
F
.45581 .92514 m .45306 .92522 L .45488 .92514 L F
.45581 .92514 m .45399 .92529 L .45362 .92526 L F
.45734 .92508 m .45375 .92514 L .45305 .9251 L .054 .148 0 r
F
.46084 .92489 m .45865 .925 L .45797 .92499 L .062 .15 0 r
F
.46084 .92489 m .45808 .92499 L .45958 .92506 L F
.45865 .925 m .45581 .92514 L .45797 .92499 L F
.45808 .92499 m .45375 .92514 L .45758 .92509 L F
.45808 .92499 m .45758 .92509 L .45958 .92506 L F
.45758 .92509 m .45375 .92514 L .45734 .92508 L .054 .148 0 r
F
.45958 .92506 m .45728 .92508 L .45695 .92506 L F
.45728 .92508 m .45305 .9251 L .45691 .92506 L F
.45728 .92508 m .45691 .92506 L .45695 .92506 L F
.45694 .92505 m .45305 .9251 L .45206 .9223 L .514 .376 0 r
F
.45557 .92498 m .45614 .92497 L .45555 .92497 L .641 .019 0 r
F
.45954 .92652 m .45305 .9251 L .45695 .92506 L .514 .376 0 r
F
.45902 .92511 m .45663 .92508 L .45847 .92515 L .054 .148 0 r
F
.45695 .92506 m .45305 .9251 L .45678 .92505 L .514 .376 0 r
F
.45084 .92512 m .44564 .92188 L .45305 .9251 L .805 .046 0 r
F
.45695 .92506 m .45305 .9251 L .45194 .92504 L .054 .148 0 r
F
.45663 .92508 m .45194 .92504 L .45635 .92511 L F
.45663 .92508 m .45635 .92511 L .45847 .92515 L F
.45695 .92506 m .45194 .92504 L .45902 .92511 L F
.45592 .92516 m .4562 .92502 L .45557 .92498 L .641 .019 0 r
F
.45843 .92648 m .45635 .92511 L .45592 .92516 L F
.4557 .92505 m .45194 .92504 L .45042 .92485 L .061 .149 0 r
F
.45635 .92511 m .45624 .92504 L .45607 .92509 L .641 .019 0 r
F
.45624 .92504 m .4562 .92502 L .45615 .92504 L F
.45624 .92504 m .45615 .92504 L .45607 .92509 L F
.45677 .92495 m .45662 .92529 L .45704 .9252 L .514 .376 0 r
F
.45847 .92515 m .45635 .92511 L .4557 .92505 L .061 .149 0 r
F
.45958 .92506 m .45758 .92509 L .45734 .92508 L .054 .148 0 r
F
.45958 .92506 m .45695 .92506 L .45902 .92511 L F
.45677 .92495 m .45206 .9223 L .45614 .92498 L .514 .376 0 r
F
.45555 .92497 m .45206 .9223 L .45054 .92234 L .641 .019 0 r
F
.45614 .92497 m .45206 .9223 L .45555 .92497 L F
.45809 .92515 m .45054 .92234 L .45759 .92325 L F
.45635 .92511 m .45607 .92509 L .45592 .92516 L F
.45672 .92506 m .45628 .92506 L .45662 .92529 L .514 .376 0 r
F
.45704 .9252 m .45662 .92529 L .45843 .92648 L F
.45754 .92539 m .45695 .92506 L .45732 .92546 L F
.45695 .92506 m .45687 .92505 L .45732 .92546 L F
.45754 .92539 m .45732 .92546 L .45843 .92648 L F
.45843 .92648 m .4557 .92505 L .45809 .92515 L .641 .019 0 r
F
.45847 .92515 m .45646 .92508 L .45809 .92515 L .061 .149 0 r
F
.45646 .92508 m .4557 .92505 L .45809 .92515 L F
.45954 .92652 m .45754 .92539 L .45843 .92648 L .514 .376 0 r
F
.46074 .92647 m .46065 .92641 L .46113 .92678 L 1 .41 0 r
F
.46065 .92641 m .46072 .92646 L .46113 .92678 L F
.46056 .92635 m .46089 .92661 L .46113 .92678 L F
.46681 .92662 m .46056 .92635 L .46091 .92663 L .218 0 0 r
F
.46681 .92662 m .46454 .92635 L .46056 .92635 L F
.46112 .92679 m .46112 .92677 L .46091 .92663 L .52 0 0 r
F
.46113 .92678 m .46087 .9266 L .46089 .92662 L 1 .41 0 r
F
.46692 .92729 m .46091 .92663 L .46144 .92709 L .183 0 0 r
F
.4776 .92628 m .47397 .92612 L .46681 .92662 L F
.47397 .92612 m .47145 .9262 L .46681 .92662 L F
.46681 .92662 m .46678 .92636 L .46454 .92635 L .218 0 0 r
F
.46817 .92595 m .46805 .92672 L .4612 .92717 L .247 .181 0 r
F
.46144 .92709 m .46091 .92663 L .46099 .92707 L .183 0 0 r
F
.46234 .92645 m .4612 .92717 L .45446 .92737 L .206 .175 0 r
F
.46817 .92595 m .4612 .92717 L .46234 .92645 L .247 .181 0 r
F
.46234 .92645 m .45446 .92737 L .45661 .92673 L .206 .175 0 r
F
.4683 .92506 m .46817 .92595 L .46234 .92645 L .286 .187 0 r
F
.4683 .92506 m .46234 .92645 L .4635 .92564 L F
.46466 .92474 m .4635 .92564 L .45877 .926 L .269 .185 0 r
F
.46466 .92474 m .45877 .926 L .46095 .92519 L F
.46551 .9261 m .46579 .92669 L .46309 .92695 L .322 .192 0 r
F
.46843 .92409 m .4683 .92506 L .4635 .92564 L .328 .193 0 r
F
.46843 .92409 m .4635 .92564 L .46466 .92474 L F
.46855 .92305 m .46843 .92409 L .46466 .92474 L .372 .204 0 r
F
.46855 .92305 m .46827 .92317 L .46583 .9238 L F
.46827 .92317 m .46466 .92474 L .46583 .9238 L F
.46583 .9238 m .46095 .92519 L .46314 .92437 L .293 .189 0 r
F
.46327 .92446 m .46583 .9238 L .46314 .92437 L .476 0 0 r
F
.46583 .9238 m .46466 .92474 L .46095 .92519 L .293 .189 0 r
F
.46551 .9261 m .46583 .9238 L .46327 .92446 L .476 0 0 r
F
.46656 .92597 m .46653 .92587 L .46551 .9261 L F
.46653 .92587 m .46583 .9238 L .46551 .9261 L F
.46702 .92782 m .46692 .92729 L .46133 .92731 L .147 0 0 r
F
.46702 .92782 m .46133 .92731 L .46138 .92734 L F
.48268 .92726 m .46692 .92729 L .46702 .92782 L .112 0 0 r
F
.48268 .92726 m .48351 .92673 L .46692 .92729 L F
.46805 .92672 m .46793 .92736 L .46007 .92776 L .207 .175 0 r
F
.4749 .92601 m .46793 .92736 L .46805 .92672 L .252 .182 0 r
F
.46805 .92672 m .46007 .92776 L .4612 .92717 L .207 .175 0 r
F
.474 .9252 m .46805 .92672 L .46817 .92595 L .296 .188 0 r
F
.474 .9252 m .4749 .92601 L .46805 .92672 L F
.46713 .92823 m .46702 .92782 L .46176 .92786 L .11 0 0 r
F
.46713 .92823 m .46176 .92786 L .46181 .92788 L F
.48184 .92766 m .46702 .92782 L .46713 .92823 L .074 0 0 r
F
.48184 .92766 m .48268 .92726 L .46702 .92782 L F
.46793 .92736 m .46781 .92788 L .45894 .92824 L .168 .169 0 r
F
.47579 .92668 m .46781 .92788 L .46793 .92736 L .21 .176 0 r
F
.46793 .92736 m .45894 .92824 L .46007 .92776 L .168 .169 0 r
F
.4749 .92601 m .47579 .92668 L .46793 .92736 L .252 .182 0 r
F
.46853 .92632 m .4684 .9275 L .46461 .9278 L .344 .247 0 r
F
.46853 .92632 m .46461 .9278 L .46579 .92669 L F
.46758 .9257 m .46853 .92632 L .46579 .92669 L .386 .282 0 r
F
.46865 .92685 m .46758 .9257 L .46696 .92715 L .445 0 0 r
F
.46758 .9257 m .46583 .9238 L .46652 .92585 L F
.46758 .9257 m .46855 .92305 L .46583 .9238 L F
.4731 .92427 m .46817 .92595 L .4683 .92506 L .343 .209 0 r
F
.46862 .92552 m .46861 .92555 L .46758 .9257 L .386 .282 0 r
F
.46861 .92555 m .46853 .92632 L .46758 .9257 L F
.4731 .92427 m .474 .9252 L .46817 .92595 L .343 .209 0 r
F
.46865 .92685 m .46862 .92552 L .46758 .9257 L .445 0 0 r
F
.47219 .92322 m .4731 .92427 L .47306 .92428 L .396 .296 0 r
F
.47219 .92322 m .47306 .92428 L .4683 .92506 L F
.47127 .92208 m .47219 .92322 L .46843 .92409 L .46 .394 0 r
F
.47132 .92216 m .47219 .92322 L .47127 .92208 L .436 .008 0 r
F
.47579 .92668 m .47667 .92723 L .46781 .92788 L .21 .176 0 r
F
.47219 .92322 m .4683 .92506 L .46843 .92409 L .396 .296 0 r
F
.481 .92792 m .46713 .92823 L .46724 .92851 L .035 0 0 r
F
.481 .92792 m .48184 .92766 L .46713 .92823 L F
.48015 .92805 m .46724 .92851 L .46735 .92865 L 0 0 0 r
F
.48015 .92805 m .481 .92792 L .46724 .92851 L F
.47755 .92763 m .46758 .92853 L .46769 .92827 L .127 .162 0 r
F
.47755 .92763 m .47843 .92791 L .46758 .92853 L F
.47667 .92723 m .46769 .92827 L .46781 .92788 L .168 .169 0 r
F
.47667 .92723 m .47755 .92763 L .46769 .92827 L F
.47399 .92677 m .47311 .92817 L .4722 .92705 L .383 .347 0 r
F
.47593 .92646 m .47446 .92735 L .47399 .92677 L F
.47446 .92735 m .47311 .92817 L .47399 .92677 L F
.47297 .92541 m .4722 .92705 L .47127 .92581 L .442 .468 0 r
F
.47972 .9242 m .4749 .92601 L .474 .9252 L .352 .231 0 r
F
.47781 .92324 m .474 .9252 L .4731 .92427 L .405 .34 0 r
F
.47781 .92324 m .47972 .9242 L .474 .9252 L F
.47588 .92213 m .4731 .92427 L .47219 .92322 L .469 .471 0 r
F
.47588 .92213 m .47781 .92324 L .4731 .92427 L F
.47332 .92586 m .47588 .92213 L .47219 .92322 L .436 .008 0 r
F
.47332 .92586 m .47593 .92646 L .4722 .92705 L .442 .468 0 r
F
.48514 .92527 m .47883 .92514 L .47888 .92546 L .217 0 0 r
F
.48433 .92606 m .48514 .92527 L .47888 .92546 L .183 0 0 r
F
.47905 .92556 m .47888 .92544 L .47906 .92557 L .629 .015 0 r
F
.47888 .92544 m .47888 .92544 L .47906 .92557 L F
.47886 .92543 m .47886 .92543 L .47906 .92557 L F
.47906 .92557 m .47886 .92543 L .47886 .92545 L F
.47911 .9256 m .47905 .92556 L .47906 .92557 L F
.48433 .92606 m .47888 .92546 L .4788 .92599 L .183 0 0 r
F
.47888 .92544 m .47886 .92543 L .47888 .92544 L .629 .015 0 r
F
.47947 .92463 m .47949 .92462 L .47935 .92453 L F
.47959 .92468 m .47953 .92464 L .47953 .92464 L .634 .017 0 r
F
.48514 .92527 m .47934 .92457 L .47927 .92515 L .217 0 0 r
F
.48162 .92503 m .47579 .92668 L .4749 .92601 L .304 .19 0 r
F
.47927 .92515 m .47914 .92478 L .479 .92494 L .217 0 0 r
F
.47927 .92515 m .47879 .92478 L .47883 .92514 L F
.47934 .92457 m .47905 .92454 L .47927 .92515 L F
.48514 .92527 m .48594 .92435 L .47935 .92453 L F
.48514 .92527 m .47935 .92453 L .47934 .92457 L F
.48594 .92435 m .4793 .92417 L .47935 .92453 L .248 0 0 r
F
.47972 .9242 m .48162 .92503 L .4749 .92601 L .352 .231 0 r
F
.47463 .92561 m .47593 .92646 L .47332 .92586 L .442 .468 0 r
F
.47398 .92741 m .47463 .92561 L .47332 .92586 L .436 .008 0 r
F
.47463 .92561 m .47588 .92213 L .47332 .92586 L F
.47397 .92517 m .47463 .92561 L .47332 .92586 L .442 .468 0 r
F
.47397 .92517 m .47332 .92586 L .47297 .92541 L F
.47332 .92586 m .4722 .92705 L .47297 .92541 L F
.47297 .92541 m .47219 .92322 L .47132 .92216 L .436 .008 0 r
F
.47308 .92564 m .47303 .92549 L .47297 .92541 L F
.47303 .92549 m .47219 .92322 L .47297 .92541 L F
.47398 .92741 m .47338 .92601 L .47308 .92564 L F
.47336 .92596 m .47219 .92322 L .47303 .9255 L F
.472 .92599 m .47398 .92741 L .47297 .92541 L .831 .099 0 r
F
.47127 .92208 m .46843 .92409 L .46855 .92305 L .46 .394 0 r
F
.46967 .92518 m .47127 .92581 L .46853 .92632 L .456 .445 0 r
F
.47067 .92495 m .47127 .92581 L .46967 .92518 L F
.47067 .92495 m .4707 .92481 L .46974 .92532 L .402 0 0 r
F
.4707 .92481 m .47127 .92208 L .46984 .92511 L F
.4707 .92481 m .46984 .92511 L .46974 .92532 L F
.46967 .92518 m .47127 .92208 L .46855 .92305 L F
.46983 .92514 m .47127 .92208 L .46967 .92518 L F
.46967 .92518 m .46853 .92632 L .46861 .92556 L .456 .445 0 r
F
.47127 .92581 m .4684 .9275 L .46853 .92632 L .392 .348 0 r
F
.47034 .92647 m .46967 .92518 L .46865 .92685 L .402 0 0 r
F
.46967 .92518 m .46855 .92305 L .46862 .92552 L F
.46967 .92518 m .46861 .92556 L .46862 .92552 L .456 .445 0 r
F
.46967 .92518 m .46862 .92552 L .46865 .92685 L .402 0 0 r
F
.46967 .92518 m .46862 .92552 L .46866 .9251 L .456 .445 0 r
F
.47035 .92449 m .46967 .92518 L .46866 .9251 L F
.47035 .92449 m .47067 .92495 L .46967 .92518 L F
.46974 .92532 m .46983 .92514 L .46967 .92518 L .402 0 0 r
F
.47034 .92647 m .47067 .92495 L .46974 .92532 L F
.47173 .92452 m .47127 .92581 L .47108 .92416 L .526 .631 0 r
F
.47173 .92452 m .47297 .92541 L .47127 .92581 L F
.472 .92599 m .47173 .92452 L .47034 .92647 L .831 .099 0 r
F
.47173 .92452 m .47127 .92208 L .47067 .92495 L F
.47115 .92475 m .47127 .92581 L .47067 .92495 L .526 .631 0 r
F
.47173 .92452 m .47067 .92495 L .47034 .92647 L .831 .099 0 r
F
.47115 .92475 m .47115 .92475 L .47067 .92495 L .526 .631 0 r
F
.47108 .92416 m .47115 .92475 L .47035 .92449 L F
.47115 .92475 m .47067 .92495 L .47035 .92449 L F
.47173 .92452 m .47282 .92512 L .47127 .92208 L .831 .099 0 r
F
.472 .92374 m .47173 .92452 L .47108 .92416 L .526 .631 0 r
F
.47173 .92452 m .47297 .92541 L .47282 .92512 L .831 .099 0 r
F
.472 .92599 m .47297 .92541 L .47173 .92452 L F
.47193 .92396 m .47297 .92541 L .47173 .92452 L .526 .631 0 r
F
.472 .92374 m .47397 .92517 L .47297 .92541 L F
.472 .92374 m .47297 .92541 L .47193 .92396 L F
.47338 .92601 m .47336 .92596 L .47308 .92564 L .436 .008 0 r
F
.47336 .92596 m .47303 .9255 L .47308 .92564 L F
.46862 .92552 m .46855 .92305 L .46758 .9257 L .445 0 0 r
F
.46866 .9251 m .46862 .92552 L .46758 .9257 L .386 .282 0 r
F
.46866 .9251 m .46758 .9257 L .46698 .92558 L F
.46656 .92597 m .46579 .92669 L .46551 .9261 L .322 .192 0 r
F
.46566 .92621 m .46656 .92597 L .46551 .9261 L .476 0 0 r
F
.46696 .92715 m .46656 .92597 L .46566 .92621 L F
.46758 .9257 m .46757 .92571 L .46656 .92597 L .386 .282 0 r
F
.46757 .92571 m .46579 .92669 L .46656 .92597 L F
.46758 .9257 m .46652 .92585 L .46656 .92597 L .445 0 0 r
F
.46758 .9257 m .46656 .92597 L .46698 .92558 L .386 .282 0 r
F
.46758 .9257 m .46656 .92597 L .46696 .92715 L .445 0 0 r
F
.4663 .92573 m .46314 .92437 L .46535 .92367 L .476 0 0 r
F
.46698 .92558 m .46597 .92594 L .4663 .92573 L .322 .192 0 r
F
.46597 .92594 m .46551 .9261 L .4663 .92573 L F
.46772 .92649 m .46696 .92715 L .4663 .92573 L 0 .002 0 r
F
.46698 .92558 m .46656 .92597 L .46551 .9261 L .322 .192 0 r
F
.46696 .92715 m .46551 .9261 L .4663 .92573 L .476 0 0 r
F
.46798 .92632 m .46865 .92685 L .46696 .92715 L .399 .265 0 r
F
.46806 .92625 m .46866 .9251 L .46698 .92558 L .173 0 0 r
F
.46806 .92625 m .46872 .92618 L .46798 .92632 L .399 .265 0 r
F
.46873 .92611 m .46872 .92618 L .46806 .92625 L F
.46872 .92618 m .46865 .92685 L .46798 .92632 L F
.46877 .9267 m .46873 .92611 L .46806 .92625 L .173 0 0 r
F
.46873 .92611 m .46866 .9251 L .46806 .92625 L F
.46878 .92567 m .46873 .92611 L .46806 .92625 L .399 .265 0 r
F
.46815 .92701 m .46772 .92649 L .46741 .92642 L .233 0 0 r
F
.46685 .92652 m .46741 .92642 L .46532 .92595 L F
.46878 .92567 m .46798 .92632 L .46816 .92612 L .399 .265 0 r
F
.46798 .92632 m .46696 .92715 L .46772 .92649 L F
.46877 .9267 m .46806 .92625 L .46815 .92701 L .173 0 0 r
F
.46806 .92625 m .46698 .92558 L .46772 .92649 L F
.46798 .92632 m .46772 .92649 L .468 .92629 L .399 .265 0 r
F
.46806 .92625 m .46772 .92649 L .46815 .92701 L .173 0 0 r
F
.468 .92629 m .46772 .92649 L .46816 .92612 L .399 .265 0 r
F
.46739 .92673 m .46741 .92642 L .46685 .92652 L .233 0 0 r
F
.46815 .92701 m .4676 .92658 L .46739 .92673 L F
.4676 .92658 m .46741 .92642 L .46739 .92673 L F
.46772 .92649 m .46698 .92558 L .4663 .92573 L F
.46551 .9261 m .46314 .92437 L .4663 .92573 L .476 0 0 r
F
.4663 .92573 m .46551 .9261 L .46532 .92595 L .322 .192 0 r
F
.46772 .92649 m .4663 .92573 L .46532 .92595 L .233 0 0 r
F
.46816 .92612 m .46772 .92649 L .4663 .92573 L 0 .002 0 r
F
.46713 .92523 m .4663 .92573 L .46535 .92367 L F
.46816 .92612 m .4663 .92573 L .46713 .92523 L F
.46551 .9261 m .46309 .92695 L .46449 .92632 L .322 .192 0 r
F
.46551 .9261 m .46449 .92632 L .46532 .92595 L F
.46532 .92595 m .46309 .92695 L .46049 .92709 L .267 .184 0 r
F
.46372 .92622 m .46049 .92709 L .45803 .92712 L .224 .178 0 r
F
.46532 .92595 m .46462 .92611 L .46372 .92622 L .267 .184 0 r
F
.46462 .92611 m .46049 .92709 L .46372 .92622 L F
.46279 .92633 m .46372 .92622 L .46221 .9264 L .084 .154 0 r
F
.46503 .92589 m .46375 .92421 L .46224 .92461 L .457 0 0 r
F
.46815 .92701 m .46532 .92595 L .46683 .92557 L .233 0 0 r
F
.46816 .92612 m .46687 .92499 L .46683 .92557 L 0 .002 0 r
F
.46703 .92583 m .46683 .92557 L .46654 .92588 L .427 0 0 r
F
.46621 .92568 m .46616 .9257 L .46608 .92571 L .165 .168 0 r
F
.46756 .92539 m .46683 .92557 L .46621 .92568 L F
.46683 .92557 m .46532 .92595 L .46621 .92568 L F
.46654 .92588 m .46641 .92565 L .46621 .92568 L .427 0 0 r
F
.46755 .92649 m .46621 .92568 L .46696 .92678 L F
.46621 .92568 m .46594 .92574 L .46613 .92576 L .165 .168 0 r
F
.46584 .92576 m .46532 .92595 L .46372 .92622 L F
.46608 .92571 m .466 .92574 L .46584 .92576 L F
.466 .92574 m .46532 .92595 L .46584 .92576 L F
.46394 .92607 m .46224 .92461 L .46084 .92489 L .472 0 0 r
F
.46579 .92669 m .46461 .9278 L .46088 .92796 L .302 .188 0 r
F
.46579 .92669 m .46088 .92796 L .46309 .92695 L F
.46372 .92622 m .46297 .92634 L .46221 .9264 L .224 .178 0 r
F
.46297 .92634 m .45803 .92712 L .46221 .9264 L F
.46221 .9264 m .46141 .92648 L .4608 .92649 L .194 .172 0 r
F
.46141 .92648 m .45574 .92705 L .4608 .92649 L F
.4608 .92649 m .45368 .92689 L .45954 .92652 L .175 .169 0 r
F
.46018 .92651 m .4608 .92649 L .45954 .92652 L 0 0 0 r
F
.46494 .92645 m .46508 .92625 L .4645 .92629 L .472 0 0 r
F
.4664 .92701 m .46542 .92645 L .46494 .92645 L F
.46542 .92645 m .46508 .92625 L .46494 .92645 L F
.46221 .9264 m .45803 .92712 L .45574 .92705 L .194 .172 0 r
F
.46373 .92647 m .4608 .92649 L .46018 .92651 L 0 0 0 r
F
.46616 .9257 m .46532 .92595 L .46608 .92571 L .165 .168 0 r
F
.46594 .92574 m .46372 .92622 L .46563 .92599 L F
.46696 .92678 m .46576 .92623 L .4664 .92701 L .457 0 0 r
F
.4653 .92603 m .46372 .92622 L .46279 .92633 L .084 .154 0 r
F
.466 .92595 m .46372 .92622 L .4653 .92603 L F
.46621 .92568 m .46593 .92596 L .46696 .92678 L .427 0 0 r
F
.46594 .92574 m .46563 .92599 L .46697 .92583 L .165 .168 0 r
F
.46697 .92583 m .466 .92595 L .4653 .92603 L .084 .154 0 r
F
.46697 .92583 m .46532 .92603 L .46641 .92618 L F
.46532 .92603 m .46221 .9264 L .46508 .92625 L F
.46696 .92678 m .46571 .92578 L .46547 .92582 L .457 0 0 r
F
.46532 .92603 m .46547 .92582 L .46503 .92589 L F
.46696 .92678 m .46547 .92582 L .46532 .92603 L F
.46532 .92603 m .46508 .92625 L .46552 .92651 L F
.46532 .92603 m .46508 .92625 L .46517 .92624 L .084 .154 0 r
F
.46532 .92603 m .46517 .92624 L .46641 .92618 L F
.46576 .92623 m .46532 .92603 L .46552 .92651 L .457 0 0 r
F
.46532 .92603 m .46224 .92461 L .46508 .92625 L F
.46576 .92623 m .46552 .92651 L .4664 .92701 L F
.46641 .92618 m .46508 .92625 L .4645 .92629 L 0 0 0 r
F
.46508 .92625 m .46221 .9264 L .4645 .92629 L F
.4645 .92629 m .46459 .92597 L .46394 .92607 L .472 0 0 r
F
.46508 .92625 m .46459 .92597 L .4645 .92629 L F
.46459 .92597 m .46224 .92461 L .46394 .92607 L F
.46621 .92568 m .46375 .92421 L .46593 .92596 L .427 0 0 r
F
.46571 .92578 m .46375 .92421 L .46503 .92589 L .457 0 0 r
F
.46618 .9263 m .46084 .92489 L .4659 .92542 L .472 0 0 r
F
.4664 .92701 m .4645 .92629 L .46618 .9263 L F
.46641 .92618 m .4645 .92629 L .46618 .9263 L 0 0 0 r
F
.4645 .92629 m .46084 .92489 L .46618 .9263 L .472 0 0 r
F
.46618 .9263 m .4608 .92649 L .46589 .92645 L 0 0 0 r
F
.4645 .92629 m .4608 .92649 L .46618 .9263 L F
.4645 .92629 m .46221 .9264 L .46142 .92646 L F
.46535 .92367 m .46055 .92477 L .46375 .92421 L .203 .175 0 r
F
.46291 .92525 m .46084 .92489 L .45958 .92506 L .187 0 0 r
F
.4659 .92542 m .46323 .92514 L .46291 .92525 L F
.46323 .92514 m .46084 .92489 L .46291 .92525 L F
.46621 .92568 m .46535 .92367 L .46375 .92421 L .427 0 0 r
F
.4659 .92542 m .46364 .92529 L .46544 .92575 L .187 0 0 r
F
.46364 .92529 m .45958 .92506 L .46368 .92554 L F
.46364 .92529 m .46368 .92554 L .46544 .92575 L F
.4644 .92646 m .4608 .92649 L .46373 .92647 L 0 0 0 r
F
.46279 .92552 m .45958 .92506 L .45847 .92515 L .194 0 0 r
F
.46589 .92645 m .45954 .92652 L .46543 .92666 L 0 0 0 r
F
.46527 .92665 m .45954 .92652 L .45843 .92648 L 0 .137 0 r
F
.46543 .92666 m .4653 .92665 L .46527 .92665 L F
.4653 .92665 m .45954 .92652 L .46527 .92665 L F
.46142 .92646 m .46221 .9264 L .4608 .92649 L 0 0 0 r
F
.4608 .92649 m .45574 .92705 L .45368 .92689 L .175 .169 0 r
F
.46543 .92666 m .45843 .92648 L .46502 .92681 L 0 .137 0 r
F
.46502 .92681 m .45843 .92648 L .45809 .92515 L .598 .409 0 r
F
.46502 .92681 m .46465 .92663 L .46468 .92692 L F
.46502 .92681 m .46468 .92673 L .46275 .92575 L F
.46544 .92575 m .46328 .92557 L .46503 .926 L .194 0 0 r
F
.46328 .92557 m .45847 .92515 L .46328 .92578 L F
.46328 .92557 m .46328 .92578 L .46503 .926 L F
.46502 .92681 m .46275 .92575 L .46282 .92576 L .598 .409 0 r
F
.4631 .92577 m .45847 .92515 L .45809 .92515 L .179 0 0 r
F
.46503 .926 m .46328 .92578 L .4631 .92577 L F
.46328 .92578 m .45847 .92515 L .4631 .92577 L F
.46503 .926 m .46281 .92573 L .46282 .92576 L F
.46281 .92573 m .45809 .92515 L .46266 .92573 L F
.46281 .92573 m .46266 .92573 L .46282 .92576 L F
.46287 .92551 m .45958 .92506 L .46279 .92552 L .194 0 0 r
F
.46468 .92673 m .45809 .92515 L .45996 .92525 L .598 .409 0 r
F
.46263 .92572 m .45996 .92525 L .46185 .92534 L F
.46468 .92673 m .45996 .92525 L .46263 .92572 L F
.46269 .92583 m .45753 .92516 L .46273 .92591 L .179 0 0 r
F
.46283 .92608 m .46231 .92574 L .46208 .92574 L .578 .003 0 r
F
.46373 .92649 m .46277 .92598 L .46283 .92608 L F
.46282 .92576 m .45753 .92516 L .46277 .92584 L .179 0 0 r
F
.46273 .92575 m .4624 .92574 L .46273 .92591 L .598 .409 0 r
F
.4621 .92584 m .45753 .92516 L .45679 .92511 L .144 0 0 r
F
.46468 .92673 m .46185 .92534 L .46196 .92534 L .598 .409 0 r
F
.46327 .92597 m .46282 .92576 L .46327 .9261 L F
.46282 .92576 m .46275 .92575 L .46196 .92534 L F
.46282 .92576 m .46251 .9256 L .4628 .9258 L F
.46282 .92576 m .4628 .9258 L .46327 .9261 L F
.4628 .9258 m .46273 .92591 L .46302 .92594 L F
.46277 .92585 m .46273 .92591 L .46469 .92619 L .179 0 0 r
F
.46269 .92583 m .46273 .92591 L .46277 .92585 L F
.46218 .92562 m .46211 .92563 L .46262 .9259 L .578 .003 0 r
F
.46238 .92588 m .45679 .92511 L .4624 .92601 L .144 0 0 r
F
.46192 .92592 m .45679 .92511 L .45626 .925 L 0 .119 0 r
F
.46269 .92591 m .46262 .9259 L .46302 .92611 L .578 .003 0 r
F
.46269 .92591 m .46302 .92611 L .46308 .92612 L F
.46302 .92594 m .46273 .92591 L .46384 .92649 L .598 .409 0 r
F
.46277 .92598 m .46237 .92577 L .46283 .92608 L .578 .003 0 r
F
.46308 .92612 m .46302 .92611 L .46373 .92649 L F
.46218 .92562 m .46262 .9259 L .46269 .92591 L F
.46503 .926 m .46282 .92576 L .46483 .92611 L .179 0 0 r
F
.46368 .92554 m .45958 .92506 L .46328 .92557 L .194 0 0 r
F
.46185 .92534 m .45809 .92515 L .45759 .92325 L .598 .409 0 r
F
.46218 .92562 m .45759 .92325 L .46211 .92563 L .578 .003 0 r
F
.46328 .92557 m .46287 .92551 L .46279 .92552 L .194 0 0 r
F
.46544 .92575 m .46368 .92554 L .46328 .92557 L F
.46196 .92534 m .46185 .92534 L .45759 .92325 L .598 .409 0 r
F
.46251 .9256 m .45759 .92325 L .46218 .92562 L F
.46185 .92563 m .45759 .92325 L .45685 .92336 L .578 .003 0 r
F
.46201 .92558 m .45759 .92325 L .46185 .92563 L F
.46456 .92618 m .45685 .92336 L .46443 .92542 L F
.4638 .92622 m .46327 .92597 L .46384 .92649 L .598 .409 0 r
F
.46327 .92597 m .46327 .9261 L .46384 .92649 L F
.46465 .92663 m .4638 .92622 L .4643 .92662 L F
.46465 .92663 m .4643 .92662 L .46468 .92692 L F
.46384 .92648 m .46228 .92567 L .46373 .92649 L .578 .003 0 r
F
.46228 .92567 m .46218 .92562 L .46228 .92568 L F
.46228 .92567 m .46228 .92568 L .46373 .92649 L F
.4638 .92622 m .46384 .92649 L .46468 .92692 L .598 .409 0 r
F
.46468 .92692 m .46384 .92648 L .46373 .92649 L .578 .003 0 r
F
.46468 .92692 m .46238 .92588 L .46382 .92612 L F
.46457 .92628 m .46382 .92612 L .46457 .92625 L F
.46496 .92646 m .4644 .92646 L .46373 .92647 L 0 0 0 r
F
.46468 .92692 m .46382 .92612 L .46457 .92628 L .578 .003 0 r
F
.46238 .92588 m .4624 .926 L .46442 .92633 L .144 0 0 r
F
.46442 .92633 m .4624 .92601 L .46192 .92592 L 0 .119 0 r
F
.46442 .92633 m .46192 .92592 L .46422 .92642 L F
.4624 .92601 m .45679 .92511 L .46192 .92592 L F
.4562 .92502 m .45614 .92497 L .45557 .92498 L .641 .019 0 r
F
.45677 .92495 m .45628 .92506 L .45672 .92506 L .514 .376 0 r
F
.45677 .92495 m .45614 .92498 L .45628 .92506 L F
.45695 .92506 m .45678 .92505 L .45694 .92505 L F
.45695 .92506 m .45677 .92495 L .45687 .92505 L F
.4557 .92505 m .45054 .92234 L .45809 .92515 L .641 .019 0 r
F
.4557 .92505 m .45042 .92485 L .45506 .92505 L .061 .149 0 r
F
.4557 .92505 m .45506 .92505 L .45753 .92516 L F
.45753 .92516 m .45042 .92485 L .44921 .92459 L .079 .151 0 r
F
.45753 .92516 m .44921 .92459 L .45679 .92511 L F
.46192 .92592 m .45626 .925 L .46182 .92599 L 0 .119 0 r
F
.46192 .92592 m .46182 .92599 L .46422 .92642 L F
.46457 .92625 m .46238 .92588 L .46442 .92633 L .144 0 0 r
F
.46469 .92619 m .46238 .92588 L .46457 .92625 L F
.46457 .92625 m .46238 .92588 L .46456 .92618 L .578 .003 0 r
F
.46238 .92588 m .46273 .92591 L .46215 .92584 L .144 0 0 r
F
.46469 .92619 m .46273 .92591 L .46238 .92588 L F
.46273 .92575 m .46273 .92591 L .4628 .9258 L .598 .409 0 r
F
.46282 .92576 m .46277 .92584 L .46483 .92611 L .179 0 0 r
F
.46237 .92577 m .46231 .92574 L .46237 .92578 L .578 .003 0 r
F
.46237 .92577 m .46237 .92578 L .46283 .92608 L F
.46483 .92611 m .46269 .92583 L .46469 .92619 L .179 0 0 r
F
.46282 .92576 m .45809 .92515 L .45753 .92516 L F
.46208 .92574 m .46201 .92558 L .46185 .92563 L .578 .003 0 r
F
.46231 .92574 m .46201 .92558 L .46208 .92574 L F
.46251 .9256 m .4624 .92561 L .46248 .92565 L .598 .409 0 r
F
.4624 .92561 m .46218 .92562 L .46248 .92565 L F
.46248 .92565 m .46218 .92562 L .4624 .92574 L F
.46251 .9256 m .4624 .92574 L .46273 .92575 L F
.46238 .92588 m .45685 .92336 L .46456 .92618 L .578 .003 0 r
F
.46238 .92588 m .46215 .92584 L .4621 .92584 L .144 0 0 r
F
.46273 .92591 m .45753 .92516 L .4621 .92584 L F
.46589 .92645 m .46511 .92646 L .46496 .92646 L 0 0 0 r
F
.46511 .92646 m .4644 .92646 L .46496 .92646 L F
.46792 .92638 m .46683 .92557 L .46788 .92629 L .233 0 0 r
F
.46815 .92701 m .46683 .92557 L .46792 .92638 L F
.46788 .92629 m .46683 .92557 L .46755 .92649 L 0 .002 0 r
F
.46756 .92539 m .46621 .92568 L .46697 .92583 L .165 .168 0 r
F
.46621 .92568 m .46613 .92576 L .46697 .92583 L F
.46687 .92499 m .46535 .92367 L .46657 .92523 L 0 .002 0 r
F
.46687 .92499 m .46657 .92523 L .46683 .92557 L F
.46816 .92612 m .46683 .92557 L .46788 .92629 L F
.46788 .92629 m .46683 .92557 L .46756 .92539 L .233 0 0 r
F
.46683 .92557 m .46535 .92367 L .46607 .925 L .427 0 0 r
F
.46683 .92557 m .46607 .925 L .46654 .92588 L F
.46641 .92565 m .46535 .92367 L .46621 .92568 L F
.46755 .92649 m .46703 .92583 L .46654 .92588 L F
.45809 .92515 m .4557 .92505 L .45753 .92516 L .061 .149 0 r
F
.45635 .92511 m .45194 .92504 L .4557 .92505 L F
.45282 .92522 m .45178 .92517 L .45183 .92522 L .391 .301 0 r
F
.45306 .92522 m .45178 .92517 L .45282 .92522 L F
.45252 .92522 m .45249 .92522 L .45251 .92522 L .133 .162 0 r
F
.45306 .92522 m .44975 .92548 L .44796 .92538 L F
.45306 .92522 m .45183 .92522 L .45368 .92689 L .391 .301 0 r
F
.45252 .92522 m .45251 .92522 L .45375 .92514 L .133 .162 0 r
F
.45375 .92514 m .45183 .92522 L .45084 .92512 L .128 .161 0 r
F
.45183 .92522 m .44796 .92538 L .45084 .92512 L F
.45099 .92522 m .45139 .92518 L .45084 .92512 L .805 .046 0 r
F
.45249 .92522 m .44796 .92538 L .45183 .92522 L .133 .162 0 r
F
.45368 .92689 m .45183 .92522 L .45099 .92522 L .805 .046 0 r
F
.45183 .92522 m .45175 .92514 L .45099 .92522 L F
.45249 .92522 m .45183 .92522 L .45375 .92514 L .133 .162 0 r
F
.45368 .92689 m .45084 .92512 L .45305 .9251 L .805 .046 0 r
F
.45305 .9251 m .4508 .92512 L .45194 .92504 L .128 .161 0 r
F
.45084 .92512 m .4508 .92512 L .45305 .9251 L F
.4508 .92512 m .44545 .92509 L .44949 .92506 L F
.4508 .92512 m .44949 .92506 L .45194 .92504 L F
.44986 .92615 m .44677 .92621 L .44823 .92607 L .157 .165 0 r
F
.44986 .92615 m .44828 .92634 L .44765 .92629 L F
.45071 .92766 m .44781 .92557 L .44975 .92548 L .388 .336 0 r
F
.44975 .92548 m .44781 .92557 L .44959 .92548 L .152 .164 0 r
F
.44959 .92548 m .44219 .92562 L .44796 .92538 L F
.44781 .92557 m .44219 .92562 L .44959 .92548 L F
.44781 .92557 m .44451 .92584 L .44219 .92562 L F
.44794 .92567 m .44451 .92584 L .44781 .92557 L .388 .336 0 r
F
.44823 .92607 m .44575 .92615 L .44584 .92596 L .157 .165 0 r
F
.44575 .92615 m .44566 .92615 L .44584 .92596 L F
.45071 .92766 m .44451 .92584 L .44794 .92567 L .388 .336 0 r
F
.44422 .92608 m .4409 .92632 L .44259 .92591 L .15 .163 0 r
F
.44271 .92599 m .44357 .92601 L .44259 .92591 L .975 .076 0 r
F
.44564 .92921 m .44243 .92663 L .44405 .92653 L .287 .235 0 r
F
.44405 .92653 m .44243 .92663 L .44387 .92652 L .14 .162 0 r
F
.44387 .92652 m .43599 .92659 L .4409 .92632 L F
.44243 .92663 m .43599 .92659 L .44387 .92652 L F
.44571 .92822 m .44422 .92608 L .44271 .92599 L .975 .076 0 r
F
.44422 .92608 m .44418 .92602 L .44271 .92599 L F
.44571 .92822 m .44259 .92591 L .44451 .92584 L F
.44451 .92584 m .44244 .92591 L .44219 .92562 L .15 .163 0 r
F
.44259 .92591 m .44244 .92591 L .44451 .92584 L F
.44244 .92591 m .43647 .92581 L .43985 .9257 L F
.44244 .92591 m .43985 .9257 L .44219 .92562 L F
.44243 .92663 m .43973 .9269 L .43599 .92659 L .14 .162 0 r
F
.44258 .92675 m .43973 .9269 L .44243 .92663 L .287 .235 0 r
F
.44296 .92728 m .44045 .92716 L .44175 .92706 L .125 .16 0 r
F
.44564 .92921 m .43973 .9269 L .44258 .92675 L .287 .235 0 r
F
.43825 .92705 m .43825 .92697 L .43813 .92696 L 1 .177 0 r
F
.44157 .92971 m .43813 .92696 L .43973 .9269 L F
.43973 .9269 m .43813 .92696 L .43599 .92659 L .117 .158 0 r
F
.43813 .92696 m .43112 .92676 L .43421 .92665 L F
.43813 .92696 m .43421 .92665 L .43599 .92659 L F
.44157 .93105 m .43775 .92793 L .43903 .9279 L .129 .096 0 r
F
.43903 .9279 m .43775 .92793 L .43881 .92788 L .063 .15 0 r
F
.43881 .92788 m .42979 .92765 L .43375 .92757 L F
.43775 .92793 m .42979 .92765 L .43881 .92788 L F
.43775 .92793 m .43569 .92805 L .42979 .92765 L F
.4379 .92805 m .43569 .92805 L .43775 .92793 L .129 .096 0 r
F
.44157 .93105 m .43569 .92805 L .4379 .92805 L F
.43458 .92816 m .43461 .92805 L .43443 .92804 L 1 .31 0 r
F
.4385 .9313 m .43443 .92804 L .43569 .92805 L F
.43569 .92805 m .43443 .92804 L .42979 .92765 L .029 .143 0 r
F
.43443 .92804 m .42587 .9276 L .42838 .92763 L F
.43443 .92804 m .42838 .92763 L .42979 .92765 L F
.43443 .92804 m .43194 .92805 L .42587 .9276 L F
.46746 .92866 m .45455 .92884 L .45563 .92889 L 0 0 0 r
F
.45672 .9288 m .45563 .92889 L .45146 .92884 L .02 .142 0 r
F
.45672 .9288 m .45146 .92884 L .45208 .92878 L F
.4555 .93247 m .45547 .93244 L .45452 .93244 L 0 .048 0 r
F
.46724 .92851 m .46713 .92823 L .46191 .92828 L .071 0 0 r
F
.46724 .92851 m .46191 .92828 L .46188 .92845 L F
.47994 .92359 m .47996 .92357 L .47981 .92348 L .634 .017 0 r
F
.47978 .92366 m .47981 .92348 L .47968 .92365 L .248 0 0 r
F
.48006 .92362 m .48 .92359 L .48 .92359 L .955 .406 0 r
F
.48594 .92435 m .47981 .92348 L .47978 .92366 L .248 0 0 r
F
.48674 .92329 m .47975 .92307 L .47981 .92348 L .278 0 0 r
F
.50255 .92016 m .50259 .92013 L .50242 .92005 L .72 .033 0 r
F
.50178 .92092 m .50242 .92005 L .5018 .92055 L .262 0 0 r
F
.50666 .92217 m .50831 .92097 L .50112 .92136 L .233 0 0 r
F
.50132 .92147 m .50114 .92134 L .50132 .92147 L .72 .033 0 r
F
.50114 .92134 m .50113 .92135 L .50132 .92147 L F
.50132 .92147 m .50112 .92134 L .50111 .92136 L F
.50138 .9215 m .50132 .92147 L .50132 .92147 L F
.50666 .92217 m .50112 .92136 L .50048 .92215 L .233 0 0 r
F
.50831 .92097 m .50136 .92091 L .50112 .92136 L .262 0 0 r
F
.50263 .92015 m .50243 .92003 L .50242 .92005 L .899 .381 0 r
F
.50268 .92018 m .50263 .92015 L .50263 .92015 L F
.50831 .92097 m .50242 .92005 L .50178 .92092 L .262 0 0 r
F
.50283 .91965 m .50275 .9196 L .50268 .92018 L .899 .381 0 r
F
.50275 .9196 m .50265 .91955 L .50266 .91972 L F
.50275 .9196 m .50266 .91972 L .50268 .92018 L F
.50265 .91955 m .50242 .92001 L .50268 .92018 L F
.50995 .91964 m .51049 .91915 L .50734 .91931 L .289 0 0 r
F
.50995 .91964 m .50265 .91955 L .50242 .92005 L F
.52796 .91551 m .52801 .91548 L .52784 .9154 L .784 .043 0 r
F
.52668 .91644 m .52784 .9154 L .52693 .91601 L .259 0 0 r
F
.53097 .91785 m .53341 .91636 L .52576 .917 L .233 0 0 r
F
.52597 .9171 m .52578 .91698 L .52576 .917 L .784 .043 0 r
F
.52602 .91713 m .52597 .91709 L .52597 .9171 L F
.53097 .91785 m .52576 .917 L .52459 .91797 L .233 0 0 r
F
.53341 .91636 m .52628 .91645 L .52576 .917 L .259 0 0 r
F
.52576 .917 m .52577 .91697 L .52575 .91699 L .784 .043 0 r
F
.52578 .91698 m .52577 .91697 L .52576 .917 L F
.52805 .9155 m .52785 .91538 L .52784 .9154 L .838 .348 0 r
F
.52811 .91552 m .52806 .91549 L .52805 .9155 L F
.53341 .91636 m .52784 .9154 L .52668 .91644 L .259 0 0 r
F
.52852 .9149 m .52844 .91485 L .52811 .91552 L .838 .348 0 r
F
.52844 .91485 m .52835 .9148 L .52828 .915 L F
.52844 .91485 m .52828 .915 L .52811 .91552 L F
.52835 .9148 m .52785 .91536 L .52811 .91552 L F
.53583 .91474 m .53665 .91414 L .53328 .91441 L .283 0 0 r
F
.53583 .91474 m .52835 .9148 L .52784 .9154 L F
.55355 .91069 m .55551 .90942 L .5535 .91066 L .799 .046 0 r
F
.55563 .90953 m .55551 .90942 L .55355 .91069 L F
.55388 .91065 m .55551 .90942 L .55434 .91014 L .24 0 0 r
F
.55429 .9139 m .5575 .91221 L .55025 .91306 L .193 0 0 r
F
.54838 .91417 m .55025 .91306 L .53583 .91474 L F
.55429 .9139 m .55025 .91306 L .54838 .91417 L F
.5575 .91221 m .56067 .9104 L .55272 .91132 L .217 0 0 r
F
.55293 .91141 m .55275 .9113 L .55272 .91132 L .799 .046 0 r
F
.55298 .91144 m .55294 .91141 L .55293 .91141 L F
.5575 .91221 m .55272 .91132 L .55106 .91248 L .217 0 0 r
F
.56067 .9104 m .5535 .91066 L .55272 .91132 L .24 0 0 r
F
.55272 .91132 m .55273 .91129 L .5527 .91131 L .799 .046 0 r
F
.55275 .9113 m .55273 .91129 L .55272 .91132 L F
.55573 .90951 m .55554 .90939 L .55551 .90942 L .77 .307 0 r
F
.55578 .90953 m .55573 .9095 L .55573 .90951 L F
.55621 .90971 m .55583 .90948 L .55578 .90953 L F
.5563 .90975 m .55622 .9097 L .55621 .90971 L F
.56067 .9104 m .55551 .90942 L .55388 .91065 L .24 0 0 r
F
.55637 .90876 m .55628 .90871 L .55628 .90883 L .77 .307 0 r
F
.56379 .90847 m .56486 .90776 L .56137 .90815 L .262 0 0 r
F
.56379 .90847 m .55628 .90871 L .55551 .90942 L F
.52393 .33675 m .52124 .33667 L .52358 .3386 L .055 .101 0 r
F
.52393 .33675 m .52153 .33508 L .52124 .33667 L F
.72774 .63464 m .71626 .6412 L .71424 .64524 L 0 0 0 r
F
.72774 .63464 m .72994 .63051 L .71626 .6412 L F
.66503 .4793 m .66353 .48515 L .66273 .48838 L .691 .172 0 r
F
.66503 .4793 m .66592 .47609 L .66353 .48515 L F
.35185 .56998 m .33985 .56219 L .34069 .56449 L 1 .405 0 r
F
.35265 .5722 m .35185 .56998 L .34069 .56449 L 1 .377 0 r
F
.86659 .64642 m .85309 .65623 L .85089 .66252 L 0 0 0 r
F
.86659 .64642 m .86889 .63995 L .85309 .65623 L F
.68606 .41079 m .68395 .41679 L .68257 .42113 L .669 .178 0 r
F
.68445 .41517 m .68606 .41079 L .68589 .41126 L .685 .181 0 r
F
.68445 .41517 m .68589 .41126 L .68257 .42113 L F
.68285 .41945 m .68445 .41517 L .68122 .42535 L .702 .185 0 r
F
.68306 .41892 m .68445 .41517 L .68285 .41945 L .662 .185 0 r
F
.68606 .41079 m .68749 .40679 L .68395 .41679 L .669 .178 0 r
F
.68958 .40289 m .68606 .41079 L .68468 .41463 L 0 0 0 r
F
.68758 .4075 m .68958 .40289 L .68949 .40309 L .662 .185 0 r
F
.68758 .4075 m .68949 .40309 L .68445 .41517 L F
.68758 .4075 m .68445 .41517 L .68306 .41892 L F
.68468 .41463 m .68606 .41079 L .68445 .41517 L 0 0 0 r
F
.68554 .412 m .68758 .4075 L .68751 .40767 L .69 .191 0 r
F
.68554 .412 m .68751 .40767 L .68285 .41945 L F
.68347 .41641 m .68554 .412 L .68548 .41216 L .719 .198 0 r
F
.68347 .41641 m .68548 .41216 L .68127 .42362 L F
.68137 .42071 m .68347 .41641 L .68342 .41654 L .748 .205 0 r
F
.68137 .42071 m .68342 .41654 L .67971 .4277 L F
.67925 .42491 m .68137 .42071 L .68134 .42082 L .776 .211 0 r
F
.67925 .42491 m .68134 .42082 L .67817 .43168 L F
.67713 .42901 m .67925 .42491 L .67923 .42501 L .804 .216 0 r
F
.67713 .42901 m .67923 .42501 L .67666 .43557 L F
.67499 .43302 m .67713 .42901 L .67711 .4291 L .83 .239 0 r
F
.67499 .43302 m .67711 .4291 L .67518 .43937 L F
.67286 .43692 m .67499 .43302 L .67498 .43309 L .855 .343 0 r
F
.67286 .43692 m .67498 .43309 L .67372 .44309 L F
.67074 .44073 m .67286 .43692 L .67286 .43698 L .896 .452 0 r
F
.67074 .44073 m .67286 .43698 L .6723 .44673 L F
.66863 .44445 m .67074 .44073 L .67074 .44077 L .959 .559 0 r
F
.66863 .44445 m .67074 .44077 L .67092 .4503 L F
.66654 .44807 m .66863 .44445 L .66863 .44447 L 1 .66 0 r
F
.66654 .44807 m .66863 .44447 L .66958 .45379 L F
.6645 .45161 m .66654 .44807 L .66828 .45722 L 1 .751 0 r
F
.66451 .45158 m .66654 .44807 L .6645 .45161 L .648 .21 0 r
F
.67713 .42901 m .67666 .43557 L .67518 .43937 L .804 .216 0 r
F
.67499 .43302 m .67518 .43937 L .67372 .44309 L .83 .239 0 r
F
.67286 .43692 m .67372 .44309 L .6723 .44673 L .855 .343 0 r
F
.67074 .44073 m .6723 .44673 L .67092 .4503 L .896 .452 0 r
F
.67718 .43216 m .67074 .44073 L .66867 .44438 L 0 0 0 r
F
.66863 .44445 m .67092 .4503 L .66958 .45379 L .959 .559 0 r
F
.67414 .43633 m .67718 .43216 L .66872 .44432 L .597 .198 0 r
F
.66873 .4443 m .66872 .44432 L .66863 .44445 L F
.67414 .43633 m .66872 .44432 L .66873 .4443 L F
.67414 .43633 m .66873 .4443 L .66657 .44803 L F
.66873 .4443 m .66863 .44445 L .66692 .44741 L F
.66873 .4443 m .66692 .44741 L .66657 .44803 L F
.66654 .44807 m .66958 .45379 L .66828 .45722 L 1 .66 0 r
F
.671 .44039 m .67414 .43633 L .66654 .44807 L .648 .21 0 r
F
.67012 .44192 m .66654 .44807 L .66451 .45158 L F
.671 .44039 m .66995 .4422 L .67012 .44192 L F
.66995 .4422 m .66654 .44807 L .67012 .44192 L F
.66657 .44803 m .66863 .44445 L .66654 .44807 L .597 .198 0 r
F
.66867 .44438 m .67074 .44073 L .66863 .44445 L 0 0 0 r
F
.6708 .44065 m .67286 .43692 L .67074 .44073 L F
.67971 .4277 m .68127 .42362 L .67864 .4335 L .738 .192 0 r
F
.67817 .43168 m .67971 .4277 L .6774 .43743 L .757 .196 0 r
F
.68137 .42071 m .67971 .4277 L .67817 .43168 L .748 .205 0 r
F
.67925 .42491 m .67817 .43168 L .67666 .43557 L .776 .211 0 r
F
.68013 .4279 m .67286 .43692 L .6708 .44065 L 0 0 0 r
F
.67294 .43682 m .67499 .43302 L .67286 .43692 L F
.68127 .42362 m .68285 .41945 L .67991 .42947 L .72 .189 0 r
F
.68347 .41641 m .68127 .42362 L .67971 .4277 L .719 .198 0 r
F
.683 .42354 m .67499 .43302 L .67294 .43682 L 0 0 0 r
F
.67508 .4329 m .67713 .42901 L .67499 .43302 L F
.68578 .41907 m .67713 .42901 L .67508 .4329 L F
.67723 .42887 m .67925 .42491 L .67713 .42901 L F
.68554 .412 m .68285 .41945 L .68127 .42362 L .69 .191 0 r
F
.68848 .41451 m .67925 .42491 L .67723 .42887 L 0 0 0 r
F
.67938 .42475 m .68137 .42071 L .67925 .42491 L F
.69109 .40986 m .68137 .42071 L .67938 .42475 L F
.68152 .42052 m .68347 .41641 L .68137 .42071 L F
.69361 .40511 m .68347 .41641 L .68152 .42052 L F
.68363 .41619 m .68554 .412 L .68347 .41641 L F
.69602 .40027 m .68554 .412 L .68363 .41619 L F
.68573 .41175 m .68758 .4075 L .68554 .412 L F
.69833 .39535 m .68758 .4075 L .68573 .41175 L F
.68606 .41079 m .68767 .40629 L .68749 .40679 L .669 .178 0 r
F
.77116 .44995 m .76975 .45888 L .77009 .46382 L 0 0 0 r
F
.77116 .44995 m .77046 .4451 L .76975 .45888 L F
.57553 .35972 m .57256 .3623 L .57463 .3643 L .117 .097 0 r
F
.57553 .35972 m .57336 .35791 L .57256 .3623 L F
.43569 .67365 m .41841 .67253 L .41939 .67419 L .735 .04 0 r
F
.43638 .6751 m .43569 .67365 L .41939 .67419 L .712 .036 0 r
F
.4525 .67382 m .43569 .67365 L .43638 .6751 L .607 .021 0 r
F
.62449 .44028 m .61856 .44494 L .61939 .44753 L .061 .032 0 r
F
.62449 .44028 m .62364 .43772 L .61856 .44494 L F
.42399 .63136 m .40887 .62842 L .40985 .6299 L .896 .064 0 r
F
.42475 .63275 m .42399 .63136 L .40985 .6299 L .876 .06 0 r
F
.4545 .63666 m .43971 .635 L .44026 .63628 L .758 .044 0 r
F
.45479 .63786 m .4545 .63666 L .44026 .63628 L .735 .04 0 r
F
.4689 .63775 m .4545 .63666 L .45479 .63786 L .679 .033 0 r
F
.5211 .33632 m .51849 .33592 L .52082 .3379 L 0 .094 0 r
F
.5211 .33632 m .51869 .33466 L .51849 .33592 L F
.52436 .62487 m .51197 .62562 L .51125 .62685 L .405 0 0 r
F
.52436 .62487 m .52531 .6236 L .51197 .62562 L F
.44035 .62812 m .42588 .62534 L .42664 .62662 L .832 .053 0 r
F
.44088 .62932 m .44035 .62812 L .42664 .62662 L .809 .049 0 r
F
.40887 .61756 m .39459 .61314 L .39567 .61471 L .978 .076 0 r
F
.40977 .61904 m .40887 .61756 L .39567 .61471 L .958 .072 0 r
F
.35499 .64067 m .33897 .63342 L .34028 .63613 L 1 .259 0 r
F
.35625 .6432 m .35499 .64067 L .34028 .63613 L 1 .24 0 r
F
.42514 .62402 m .4107 .62048 L .41164 .62188 L .903 .064 0 r
F
.42588 .62534 m .42514 .62402 L .41164 .62188 L .881 .06 0 r
F
.52636 .33828 m .52358 .3386 L .52595 .34035 L .128 .127 0 r
F
.52636 .33828 m .52393 .33675 L .52358 .3386 L F
.58333 .36375 m .58041 .36656 L .5823 .36878 L .036 .07 0 r
F
.58333 .36375 m .58146 .36158 L .58041 .36656 L F
.39867 .6665 m .38119 .66281 L .38254 .66498 L .966 .075 0 r
F
.39984 .66845 m .39867 .6665 L .38254 .66498 L .951 .073 0 r
F
.32402 .47995 m .31731 .47017 L .31683 .47278 L 1 .902 0 r
F
.32361 .48257 m .32402 .47995 L .31683 .47278 L 1 .884 0 r
F
.90012 .50642 m .89092 .51908 L .89066 .52594 L 0 0 0 r
F
.90012 .50642 m .90055 .49948 L .89092 .51908 L F
.28479 .83672 m .25559 .82939 L .25954 .83324 L .896 .062 0 r
F
.28828 .84035 m .28479 .83672 L .25954 .83324 L .873 .058 0 r
F
.43971 .635 m .42475 .63275 L .42554 .63411 L .823 .053 0 r
F
.44026 .63628 m .43971 .635 L .42554 .63411 L .801 .049 0 r
F
.5288 .33969 m .52636 .33828 L .52595 .34035 L .182 .208 0 r
F
.55564 .6106 m .54433 .61238 L .54329 .61392 L .295 0 0 r
F
.55564 .6106 m .55686 .60902 L .54433 .61238 L F
.30853 .57475 m .29717 .5639 L .29773 .56701 L 1 .527 0 r
F
.30914 .57779 m .30853 .57475 L .29773 .56701 L 1 .506 0 r
F
.52355 .3378 m .52082 .3379 L .52319 .33966 L .099 .113 0 r
F
.52355 .3378 m .5211 .33632 L .52082 .3379 L F
.57767 .36154 m .57463 .3643 L .57668 .36632 L .125 .097 0 r
F
.57767 .36154 m .57553 .35972 L .57463 .3643 L F
.80986 .20116 m .80814 .21588 L .81296 .22104 L 0 .065 0 r
F
.80986 .20116 m .80499 .19623 L .80814 .21588 L F
.62981 .5111 m .62176 .51548 L .62158 .51811 L .053 0 0 r
F
.62981 .5111 m .63 .50845 L .62176 .51548 L F
.62847 .44489 m .62248 .44965 L .62329 .45229 L .052 .03 0 r
F
.62847 .44489 m .62762 .44229 L .62248 .44965 L F
.33329 .53572 m .32329 .52671 L .32367 .52924 L 1 .617 0 r
F
.33368 .53821 m .33329 .53572 L .32367 .52924 L 1 .592 0 r
F
.45288 .67507 m .4525 .67382 L .43638 .6751 L .578 .016 0 r
F
.46854 .67312 m .4525 .67382 L .45288 .67507 L .469 0 0 r
F
.57323 .5982 m .56255 .60055 L .56146 .60231 L .232 0 0 r
F
.57323 .5982 m .57446 .59639 L .56255 .60055 L F
.53126 .34103 m .52833 .34198 L .53073 .34353 L .223 .274 0 r
F
.8079 .20277 m .80759 .21631 L .81246 .22141 L 0 .068 0 r
F
.8079 .20277 m .80281 .19809 L .80759 .21631 L F
.29456 .51385 m .28723 .5022 L .28696 .50531 L 1 .724 0 r
F
.29437 .51697 m .29456 .51385 L .28696 .50531 L 1 .703 0 r
F
.34661 .58292 m .33277 .57566 L .33384 .57803 L 1 .349 0 r
F
.3476 .58519 m .34661 .58292 L .33384 .57803 L 1 .324 0 r
F
.52602 .33916 m .52319 .33966 L .52558 .3413 L .175 .202 0 r
F
.52602 .33916 m .52355 .3378 L .52319 .33966 L F
.1107 .71991 m .08614 .69984 L .08913 .70616 L 1 .14 0 r
F
.11359 .72597 m .1107 .71991 L .08913 .70616 L 1 .116 0 r
F
.3724 .59354 m .35924 .58704 L .36032 .58905 L 1 .225 0 r
F
.37339 .59546 m .3724 .59354 L .36032 .58905 L 1 .196 0 r
F
.5852 .3659 m .5823 .36878 L .58417 .37099 L .031 .069 0 r
F
.5852 .3659 m .58333 .36375 L .5823 .36878 L F
.12734 .70133 m .10262 .68284 L .1054 .68887 L 1 .2 0 r
F
.13002 .70709 m .12734 .70133 L .1054 .68887 L 1 .173 0 r
F
.39151 .60823 m .37765 .60285 L .37879 .60461 L 1 .103 0 r
F
.39251 .6099 m .39151 .60823 L .37879 .60461 L 1 .087 0 r
F
.53372 .34232 m .53073 .34353 L .53312 .34504 L .253 .324 0 r
F
.53372 .34232 m .53126 .34103 L .53073 .34353 L F
.88864 .33952 m .88163 .35463 L .88428 .36121 L 0 .002 0 r
F
.88864 .33952 m .8859 .33298 L .88163 .35463 L F
.30721 .50004 m .29773 .48937 L .29768 .49227 L 1 .776 0 r
F
.30721 .50289 m .30721 .50004 L .29768 .49227 L 1 .756 0 r
F
.6253 .44285 m .61939 .44753 L .62017 .45012 L .05 .029 0 r
F
.6253 .44285 m .62449 .44028 L .61939 .44753 L F
.62642 .50782 m .61879 .51217 L .61863 .51475 L .033 0 0 r
F
.62642 .50782 m .6266 .50522 L .61879 .51217 L F
.18615 .77027 m .15861 .75643 L .16228 .7616 L 1 .095 0 r
F
.18957 .77517 m .18615 .77027 L .16228 .7616 L 1 .091 0 r
F
.59208 .57983 m .58215 .58281 L .58115 .58484 L .162 0 0 r
F
.59208 .57983 m .59319 .57775 L .58215 .58281 L F
.5798 .36339 m .57668 .36632 L .57871 .36834 L .131 .097 0 r
F
.5798 .36339 m .57767 .36154 L .57668 .36632 L F
.32431 .55074 m .31203 .54177 L .31271 .54444 L 1 .532 0 r
F
.32497 .55332 m .32431 .55074 L .31271 .54444 L 1 .509 0 r
F
.52849 .34045 m .52602 .33916 L .52558 .3413 L .226 .282 0 r
F
.53618 .34359 m .53312 .34504 L .53551 .34652 L .275 .359 0 r
F
.53618 .34359 m .53372 .34232 L .53312 .34504 L F
.64824 .53917 m .64314 .54527 L .64214 .54806 L 0 0 0 r
F
.64824 .53917 m .64923 .53634 L .64314 .54527 L F
.54545 .65071 m .53327 .65379 L .53205 .65504 L .122 0 0 r
F
.54545 .65071 m .54695 .64942 L .53327 .65379 L F
.51359 .66334 m .49991 .66565 L .49926 .66671 L .24 0 0 r
F
.51359 .66334 m .51457 .66231 L .49991 .66565 L F
.36886 .60404 m .35425 .59824 L .35548 .60031 L 1 .205 0 r
F
.36996 .60602 m .36886 .60404 L .35548 .60031 L 1 .179 0 r
F
.53863 .34486 m .53551 .34652 L .53789 .34799 L .289 .38 0 r
F
.53863 .34486 m .53618 .34359 L .53551 .34652 L F
.46899 .63275 m .46896 .63167 L .45508 .63136 L .668 .03 0 r
F
.48261 .63248 m .46896 .63167 L .46899 .63275 L .6 .021 0 r
F
.48261 .63248 m .48285 .63141 L .46896 .63167 L F
.6137 .55603 m .6044 .55963 L .60364 .562 L .103 0 0 r
F
.6137 .55603 m .61453 .55361 L .6044 .55963 L F
.54963 .325 m .54712 .32321 L .54938 .32312 L .613 .012 0 r
F
.61115 .55189 m .6022 .55556 L .60147 .55788 L .089 0 0 r
F
.61115 .55189 m .61194 .54953 L .6022 .55556 L F
.52477 .62996 m .51233 .6308 L .51159 .63207 L .398 0 0 r
F
.52477 .62996 m .52575 .62867 L .51233 .6308 L F
.4986 .66772 m .48416 .6696 L .48385 .67066 L .309 0 0 r
F
.4986 .66772 m .49926 .66671 L .48416 .6696 L F
.59385 .58436 m .58368 .58725 L .58265 .58931 L .17 0 0 r
F
.59385 .58436 m .595 .58224 L .58368 .58725 L F
.57444 .60292 m .5636 .6052 L .56248 .60699 L .235 0 0 r
F
.57444 .60292 m .57571 .60107 L .5636 .6052 L F
.17199 .79354 m .14458 .7777 L .14856 .78309 L .957 .087 0 r
F
.17573 .79866 m .17199 .79354 L .14856 .78309 L .93 .082 0 r
F
.54106 .34614 m .53863 .34486 L .53789 .34799 L .298 .391 0 r
F
.55647 .61544 m .54506 .61719 L .54399 .61877 L .294 0 0 r
F
.55647 .61544 m .55772 .61382 L .54506 .61719 L F
.7604 .81036 m .74238 .81491 L .73834 .81955 L .006 0 0 r
F
.7604 .81036 m .76483 .80553 L .74238 .81491 L F
.32361 .48257 m .31683 .47278 L .3164 .47539 L 1 .884 0 r
F
.32324 .48519 m .32361 .48257 L .3164 .47539 L 1 .865 0 r
F
.50978 .6292 m .49702 .62945 L .49652 .63058 L .45 .002 0 r
F
.50978 .6292 m .51052 .62805 L .49702 .62945 L F
.76183 .56067 m .75284 .56885 L .75168 .57345 L 0 0 0 r
F
.76183 .56067 m .76297 .55597 L .75284 .56885 L F
.32449 .85227 m .29545 .84735 L .29914 .85072 L .833 .051 0 r
F
.32764 .85546 m .32449 .85227 L .29914 .85072 L .809 .047 0 r
F
.88624 .34033 m .87893 .35546 L .88135 .36206 L 0 0 0 r
F
.88624 .34033 m .88374 .33374 L .87893 .35546 L F
.58705 .36804 m .58417 .37099 L .58603 .3732 L .027 .069 0 r
F
.58705 .36804 m .5852 .3659 L .58417 .37099 L F
.71806 .34476 m .73737 .34186 L .73932 .34652 L 1 .088 0 r
F
.71806 .34476 m .71467 .34145 L .73737 .34186 L F
.58189 .36525 m .57871 .36834 L .58071 .37037 L .135 .096 0 r
F
.58189 .36525 m .5798 .36339 L .57871 .36834 L F
.62928 .44751 m .62329 .45229 L .62405 .45493 L .043 .027 0 r
F
.62928 .44751 m .62847 .44489 L .62329 .45229 L F
.27486 .8667 m .24551 .85659 L .24988 .86046 L .779 .045 0 r
F
.27877 .87031 m .27486 .8667 L .24988 .86046 L .747 .039 0 r
F
.51128 .32673 m .51062 .32 L .5124 .32522 L 1 .366 0 r
F
.51128 .32673 m .50912 .32344 L .51062 .32 L F
.54289 .32511 m .54234 .32317 L .54414 .32673 L .682 .042 0 r
F
.54289 .32511 m .54069 .32264 L .54234 .32317 L F
.53892 .6197 m .52716 .62095 L .52624 .6223 L .348 0 0 r
F
.53892 .6197 m .54004 .61831 L .52716 .62095 L F
.66416 .48247 m .66273 .48838 L .66193 .49156 L .696 .173 0 r
F
.66416 .48247 m .66503 .4793 L .66273 .48838 L F
.35265 .5722 m .34069 .56449 L .34156 .56676 L 1 .377 0 r
F
.35349 .5744 m .35265 .5722 L .34156 .56676 L 1 .349 0 r
F
.62607 .44544 m .62017 .45012 L .62092 .45273 L .04 .025 0 r
F
.62607 .44544 m .6253 .44285 L .62017 .45012 L F
.49602 .63166 m .48285 .63141 L .48261 .63248 L .518 .011 0 r
F
.49602 .63166 m .49652 .63058 L .48285 .63141 L F
.62958 .51375 m .62158 .51811 L .62136 .52073 L .044 0 0 r
F
.62958 .51375 m .62981 .5111 L .62158 .51811 L F
.33187 .61682 m .31766 .60774 L .31875 .61067 L 1 .367 0 r
F
.33296 .61962 m .33187 .61682 L .31875 .61067 L 1 .347 0 r
F
.8171 .75217 m .80005 .75849 L .79655 .76402 L 0 0 0 r
F
.8171 .75217 m .82087 .74644 L .80005 .75849 L F
.58396 .36714 m .58071 .37037 L .5827 .37242 L .136 .094 0 r
F
.58396 .36714 m .58189 .36525 L .58071 .37037 L F
.62634 .5822 m .61861 .58759 L .61725 .59 L 0 0 0 r
F
.62634 .5822 m .62776 .57972 L .61861 .58759 L F
.6871 .68634 m .67533 .69251 L .6728 .69595 L F
.6871 .68634 m .68995 .6829 L .67533 .69251 L F
.5889 .37016 m .58603 .3732 L .58788 .3754 L .025 .069 0 r
F
.5889 .37016 m .58705 .36804 L .58603 .3732 L F
.46893 .63889 m .4689 .63775 L .45479 .63786 L .655 .029 0 r
F
.4827 .63828 m .4689 .63775 L .46893 .63889 L .586 .02 0 r
F
.4827 .63828 m .48295 .63715 L .4689 .63775 L F
.29437 .51697 m .28696 .50531 L .28675 .50843 L 1 .703 0 r
F
.29422 .5201 m .29437 .51697 L .28675 .50843 L 1 .682 0 r
F
.33368 .53821 m .32367 .52924 L .32409 .53176 L 1 .592 0 r
F
.33412 .54068 m .33368 .53821 L .32409 .53176 L 1 .567 0 r
F
.91137 .51426 m .89891 .52683 L .8988 .53385 L 0 0 0 r
F
.91137 .51426 m .91149 .50711 L .89891 .52683 L F
.87495 .65758 m .85942 .66661 L .85716 .67305 L F
.87495 .65758 m .87735 .65094 L .85942 .66661 L F
.60349 .61016 m .59416 .61479 L .59262 .61682 L F
.60349 .61016 m .60515 .60806 L .59416 .61479 L F
.6262 .5104 m .61863 .51475 L .61842 .51732 L .023 0 0 r
F
.6262 .5104 m .62642 .50782 L .61863 .51475 L F
.77178 .45481 m .77009 .46382 L .77036 .46876 L 0 0 0 r
F
.77178 .45481 m .77116 .44995 L .77009 .46382 L F
.30721 .50289 m .29768 .49227 L .29768 .49517 L 1 .756 0 r
F
.30726 .50574 m .30721 .50289 L .29768 .49517 L 1 .735 0 r
F
.38957 .61821 m .37468 .6136 L .37593 .61542 L 1 .089 0 r
F
.39066 .61992 m .38957 .61821 L .37593 .61542 L 1 .083 0 r
F
.41841 .67253 m .40103 .67037 L .40224 .67226 L .844 .057 0 r
F
.41939 .67419 m .41841 .67253 L .40224 .67226 L .825 .053 0 r
F
.32324 .48519 m .3164 .47539 L .31601 .47801 L 1 .865 0 r
F
.32292 .48781 m .32324 .48519 L .31601 .47801 L 1 .846 0 r
F
.30914 .57779 m .29773 .56701 L .29834 .57012 L 1 .506 0 r
F
.3098 .58083 m .30914 .57779 L .29834 .57012 L 1 .485 0 r
F
.63005 .45013 m .62405 .45493 L .62478 .45758 L .034 .024 0 r
F
.63005 .45013 m .62928 .44751 L .62405 .45493 L F
.37857 .65838 m .36161 .65315 L .36303 .65559 L 1 .131 0 r
F
.37986 .66061 m .37857 .65838 L .36303 .65559 L 1 .114 0 r
F
.4079 .62691 m .39291 .62325 L .39407 .62486 L .954 .072 0 r
F
.40887 .62842 m .4079 .62691 L .39407 .62486 L .935 .069 0 r
F
.586 .36906 m .5827 .37242 L .58465 .37449 L .136 .093 0 r
F
.586 .36906 m .58396 .36714 L .5827 .37242 L F
.51007 .63449 m .49724 .63489 L .49674 .63606 L .441 0 0 r
F
.51007 .63449 m .51084 .6333 L .49724 .63489 L F
.11848 .71474 m .09492 .69484 L .09775 .70108 L 1 .146 0 r
F
.12124 .72072 m .11848 .71474 L .09775 .70108 L 1 .119 0 r
F
.53948 .62466 m .52765 .62595 L .52671 .62733 L .343 0 0 r
F
.53948 .62466 m .54064 .62325 L .52765 .62595 L F
.4168 .8641 m .38974 .86509 L .39181 .86772 L .622 .025 0 r
F
.41821 .86662 m .4168 .8641 L .39181 .86772 L .594 .02 0 r
F
.59074 .37228 m .58788 .3754 L .5897 .37761 L .024 .069 0 r
F
.59074 .37228 m .5889 .37016 L .58788 .3754 L F
.62679 .44803 m .62092 .45273 L .62162 .45534 L .03 .022 0 r
F
.62679 .44803 m .62607 .44544 L .62092 .45273 L F
.32497 .55332 m .31271 .54444 L .31344 .5471 L 1 .509 0 r
F
.32568 .55589 m .32497 .55332 L .31344 .5471 L 1 .485 0 r
F
.17763 .78765 m .151 .77186 L .15485 .77721 L .962 .088 0 r
F
.18125 .79271 m .17763 .78765 L .15485 .77721 L .936 .084 0 r
F
.27808 .86037 m .24929 .8503 L .25356 .85416 L .787 .046 0 r
F
.28191 .86396 m .27808 .86037 L .25356 .85416 L .755 .041 0 r
F
.24054 .81323 m .21189 .80313 L .21592 .80753 L .951 .074 0 r
F
.24419 .81739 m .24054 .81323 L .21592 .80753 L .929 .07 0 r
F
.45508 .63136 m .44088 .62932 L .44142 .63048 L .746 .04 0 r
F
.45537 .63245 m .45508 .63136 L .44142 .63048 L .722 .036 0 r
F
.46899 .63275 m .45508 .63136 L .45537 .63245 L .668 .03 0 r
F
.31618 .88533 m .2868 .87722 L .29092 .88052 L .704 .03 0 r
F
.31974 .88839 m .31618 .88533 L .29092 .88052 L .67 .024 0 r
F
.3476 .58519 m .33384 .57803 L .33494 .58037 L 1 .324 0 r
F
.34862 .58744 m .3476 .58519 L .33494 .58037 L 1 .298 0 r
F
.49622 .63719 m .48295 .63715 L .4827 .63828 L .503 .009 0 r
F
.49622 .63719 m .49674 .63606 L .48295 .63715 L F
.61032 .55424 m .60147 .55788 L .6007 .56018 L .08 0 0 r
F
.61032 .55424 m .61115 .55189 L .60147 .55788 L F
.61283 .55842 m .60364 .562 L .60283 .56434 L .094 0 0 r
F
.61283 .55842 m .6137 .55603 L .60364 .562 L F
.40977 .61904 m .39567 .61471 L .39677 .61624 L .958 .072 0 r
F
.4107 .62048 m .40977 .61904 L .39677 .61624 L .936 .069 0 r
F
.75355 .80253 m .73656 .80773 L .73255 .8122 L 0 0 0 r
F
.75355 .80253 m .75792 .79788 L .73656 .80773 L F
.58801 .371 m .58465 .37449 L .58658 .37658 L .134 .091 0 r
F
.58801 .371 m .586 .36906 L .58465 .37449 L F
.64723 .54197 m .64214 .54806 L .64111 .55083 L 0 0 0 r
F
.64723 .54197 m .64824 .53917 L .64214 .54806 L F
.59094 .58189 m .58115 .58484 L .58011 .58684 L .153 0 0 r
F
.59094 .58189 m .59208 .57983 L .58115 .58484 L F
.72545 .63872 m .71424 .64524 L .71214 .64924 L 0 0 0 r
F
.72545 .63872 m .72774 .63464 L .71424 .64524 L F
.35625 .6432 m .34028 .63613 L .34164 .63883 L 1 .24 0 r
F
.35754 .64572 m .35625 .6432 L .34164 .63883 L 1 .222 0 r
F
.37339 .59546 m .36032 .58905 L .36144 .59103 L 1 .196 0 r
F
.37441 .59736 m .37339 .59546 L .36144 .59103 L 1 .167 0 r
F
.57197 .59999 m .56146 .60231 L .56035 .60404 L .222 0 0 r
F
.57197 .59999 m .57323 .5982 L .56146 .60231 L F
.545 .32762 m .54414 .32673 L .54602 .32991 L 0 0 0 r
F
.545 .32762 m .54289 .32511 L .54414 .32673 L F
.5544 .61216 m .54329 .61392 L .54223 .61542 L .285 0 0 r
F
.5544 .61216 m .55564 .6106 L .54329 .61392 L F
.42588 .62534 m .41164 .62188 L .4126 .62324 L .881 .06 0 r
F
.42664 .62662 m .42588 .62534 L .4126 .62324 L .858 .056 0 r
F
.42475 .63275 m .40985 .6299 L .41086 .63134 L .876 .06 0 r
F
.42554 .63411 m .42475 .63275 L .41086 .63134 L .854 .056 0 r
F
.41228 .90965 m .38402 .90556 L .38644 .90785 L .542 .001 0 r
F
.41395 .91175 m .41228 .90965 L .38644 .90785 L .524 0 0 r
F
.52339 .62609 m .51125 .62685 L .51052 .62805 L .394 0 0 r
F
.52339 .62609 m .52436 .62487 L .51125 .62685 L F
.59257 .37439 m .5897 .37761 L .59151 .37983 L .024 .068 0 r
F
.59257 .37439 m .59074 .37228 L .5897 .37761 L F
.62931 .51639 m .62136 .52073 L .6211 .52334 L .035 0 0 r
F
.62931 .51639 m .62958 .51375 L .62136 .52073 L F
.44088 .62932 m .42664 .62662 L .42741 .62786 L .809 .049 0 r
F
.44142 .63048 m .44088 .62932 L .42741 .62786 L .786 .045 0 r
F
.63077 .45277 m .62478 .45758 L .62546 .46023 L .026 .021 0 r
F
.63077 .45277 m .63005 .45013 L .62478 .45758 L F
.59266 .58645 m .58265 .58931 L .58157 .59135 L .16 0 0 r
F
.59266 .58645 m .59385 .58436 L .58265 .58931 L F
.39251 .6099 m .37879 .60461 L .37996 .60634 L 1 .087 0 r
F
.39354 .61154 m .39251 .6099 L .37996 .60634 L 1 .083 0 r
F
.48448 .33241 m .48218 .32738 L .48305 .3191 L 1 .475 0 r
F
.4848 .32875 m .48223 .32673 L .48318 .31724 L .923 .387 0 r
F
.35932 .86136 m .33084 .85856 L .3341 .86157 L .766 .041 0 r
F
.36198 .86422 m .35932 .86136 L .3341 .86157 L .741 .037 0 r
F
.32292 .48781 m .31601 .47801 L .31566 .48063 L 1 .846 0 r
F
.32263 .49043 m .32292 .48781 L .31566 .48063 L 1 .826 0 r
F
.52827 .65849 m .51554 .66122 L .51457 .66231 L .162 0 0 r
F
.52827 .65849 m .52954 .65739 L .51554 .66122 L F
.45479 .63786 m .44026 .63628 L .44081 .63751 L .735 .04 0 r
F
.45509 .63902 m .45479 .63786 L .44081 .63751 L .711 .036 0 r
F
.46893 .63889 m .45479 .63786 L .45509 .63902 L .655 .029 0 r
F
.58998 .37297 m .58658 .37658 L .58847 .37868 L .131 .089 0 r
F
.58998 .37297 m .58801 .371 L .58658 .37658 L F
.29422 .5201 m .28675 .50843 L .28658 .51155 L 1 .682 0 r
F
.29413 .52323 m .29422 .5201 L .28658 .51155 L 1 .66 0 r
F
.36996 .60602 m .35548 .60031 L .35675 .60236 L 1 .179 0 r
F
.3711 .60796 m .36996 .60602 L .35675 .60236 L 1 .152 0 r
F
.62594 .51298 m .61842 .51732 L .61818 .51987 L .014 0 0 r
F
.62594 .51298 m .6262 .5104 L .61842 .51732 L F
.72137 .34817 m .73932 .34652 L .74128 .35114 L 1 .087 0 r
F
.72137 .34817 m .71806 .34476 L .73932 .34652 L F
.6633 .48561 m .66193 .49156 L .66114 .49472 L .701 .173 0 r
F
.6633 .48561 m .66416 .48247 L .66193 .49156 L F
.89959 .51335 m .89066 .52594 L .89029 .53279 L 0 0 0 r
F
.89959 .51335 m .90012 .50642 L .89066 .52594 L F
.80853 .74544 m .79289 .75244 L .7894 .75779 L F
.80853 .74544 m .81227 .73989 L .79289 .75244 L F
.62746 .45063 m .62162 .45534 L .62227 .45795 L .019 .018 0 r
F
.62746 .45063 m .62679 .44803 L .62162 .45534 L F
.33412 .54068 m .32409 .53176 L .32456 .53427 L 1 .567 0 r
F
.33459 .54314 m .33412 .54068 L .32456 .53427 L 1 .541 0 r
F
.30726 .50574 m .29768 .49517 L .29773 .49806 L 1 .735 0 r
F
.30735 .50858 m .30726 .50574 L .29773 .49806 L 1 .714 0 r
F
.35349 .5744 m .34156 .56676 L .34248 .56901 L 1 .349 0 r
F
.35436 .57657 m .35349 .5744 L .34248 .56901 L 1 .321 0 r
F
.81463 .20618 m .81296 .22104 L .81767 .22628 L 0 .061 0 r
F
.81463 .20618 m .80986 .20116 L .81296 .22104 L F
.52597 .32152 m .52159 .32581 L .53098 .30377 L .504 .047 0 r
F
.22884 .84014 m .2002 .82765 L .2046 .83218 L .85 .061 0 r
F
.23288 .8444 m .22884 .84014 L .2046 .83218 L .819 .056 0 r
F
.57313 .60473 m .56248 .60699 L .56133 .60875 L .224 0 0 r
F
.57313 .60473 m .57444 .60292 L .56248 .60699 L F
.44026 .63628 m .42554 .63411 L .42633 .63542 L .801 .049 0 r
F
.44081 .63751 m .44026 .63628 L .42633 .63542 L .778 .045 0 r
F
.81287 .20758 m .81246 .22141 L .81724 .2266 L 0 .063 0 r
F
.81287 .20758 m .8079 .20277 L .81246 .22141 L F
.55451 .32869 m .55342 .32908 L .5555 .33174 L 0 .055 0 r
F
.55451 .32869 m .5521 .32682 L .55342 .32908 L F
.86417 .65285 m .85089 .66252 L .84858 .66877 L 0 0 0 r
F
.86417 .65285 m .86659 .64642 L .85089 .66252 L F
.89126 .34612 m .88428 .36121 L .88682 .36784 L F
.89126 .34612 m .88864 .33952 L .88428 .36121 L F
.51371 .32862 m .5124 .32522 L .51453 .32859 L .901 .065 0 r
F
.51371 .32862 m .51128 .32673 L .5124 .32522 L F
.39984 .66845 m .38254 .66498 L .38392 .66714 L .951 .073 0 r
F
.40103 .67037 m .39984 .66845 L .38392 .66714 L .936 .07 0 r
F
.5944 .37651 m .59151 .37983 L .5933 .38205 L .024 .068 0 r
F
.5944 .37651 m .59257 .37439 L .59151 .37983 L F
.46857 .67421 m .46854 .67312 L .45288 .67507 L .45 0 0 r
F
.48353 .67166 m .46854 .67312 L .46857 .67421 L .371 0 0 r
F
.48353 .67166 m .48385 .67066 L .46854 .67312 L F
.31865 .87889 m .28977 .87084 L .29381 .87413 L .711 .031 0 r
F
.32215 .88192 m .31865 .87889 L .29381 .87413 L .678 .026 0 r
F
.7606 .56535 m .75168 .57345 L .75045 .57803 L 0 0 0 r
F
.7606 .56535 m .76183 .56067 L .75168 .57345 L F
.55518 .61702 m .54399 .61877 L .54289 .6203 L .283 0 0 r
F
.55518 .61702 m .55647 .61544 L .54399 .61877 L F
.59192 .37497 m .58847 .37868 L .59034 .38081 L .127 .087 0 r
F
.59192 .37497 m .58998 .37297 L .58847 .37868 L F
.43638 .6751 m .41939 .67419 L .42037 .67581 L .712 .036 0 r
F
.43708 .67651 m .43638 .6751 L .42037 .67581 L .687 .032 0 r
F
.45288 .67507 m .43638 .6751 L .43708 .67651 L .578 .016 0 r
F
.62489 .58464 m .61725 .59 L .61585 .59237 L 0 0 0 r
F
.62489 .58464 m .62634 .5822 L .61725 .59 L F
.63144 .45541 m .62546 .46023 L .62609 .4629 L .017 .017 0 r
F
.63144 .45541 m .63077 .45277 L .62546 .46023 L F
.3098 .58083 m .29834 .57012 L .29899 .57322 L 1 .485 0 r
F
.3105 .58386 m .3098 .58083 L .29899 .57322 L 1 .463 0 r
F
.33296 .61962 m .31875 .61067 L .31988 .6136 L 1 .347 0 r
F
.33408 .62241 m .33296 .61962 L .31988 .6136 L 1 .328 0 r
F
.88859 .34697 m .88135 .36206 L .88364 .3687 L 0 0 0 r
F
.88859 .34697 m .88624 .34033 L .88135 .36206 L F
.38974 .86509 m .36198 .86422 L .36469 .86698 L .696 .033 0 r
F
.39181 .86772 m .38974 .86509 L .36469 .86698 L .669 .028 0 r
F
.52377 .63122 m .51159 .63207 L .51084 .6333 L .386 0 0 r
F
.52377 .63122 m .52477 .62996 L .51159 .63207 L F
.41324 .9027 m .38541 .8988 L .38779 .90106 L .539 .001 0 r
F
.41488 .90476 m .41324 .9027 L .38779 .90106 L .521 0 0 r
F
.77231 .45967 m .77036 .46876 L .77057 .47369 L 0 0 0 r
F
.77231 .45967 m .77178 .45481 L .77036 .46876 L F
.32568 .55589 m .31344 .5471 L .31421 .54974 L 1 .485 0 r
F
.32643 .55844 m .32568 .55589 L .31421 .54974 L 1 .46 0 r
F
.46901 .63378 m .46899 .63275 L .45537 .63245 L .644 .025 0 r
F
.48236 .63352 m .46899 .63275 L .46901 .63378 L .576 .017 0 r
F
.48236 .63352 m .48261 .63248 L .46899 .63275 L F
.59621 .37862 m .5933 .38205 L .59506 .38427 L .024 .068 0 r
F
.59621 .37862 m .5944 .37651 L .5933 .38205 L F
.32263 .49043 m .31566 .48063 L .31537 .48325 L 1 .826 0 r
F
.32239 .49304 m .32263 .49043 L .31537 .48325 L 1 .805 0 r
F
.54703 .33017 m .54602 .32991 L .54796 .33283 L 0 0 0 r
F
.54703 .33017 m .545 .32762 L .54602 .32991 L F
.53777 .62105 m .52624 .6223 L .52531 .6236 L .336 0 0 r
F
.53777 .62105 m .53892 .6197 L .52624 .6223 L F
.62809 .45324 m .62227 .45795 L .62288 .46057 L .008 .015 0 r
F
.62809 .45324 m .62746 .45063 L .62227 .45795 L F
.50902 .6303 m .49652 .63058 L .49602 .63166 L .438 0 0 r
F
.50902 .6303 m .50978 .6292 L .49652 .63058 L F
.59383 .37699 m .59034 .38081 L .59217 .38296 L .122 .084 0 r
F
.59383 .37699 m .59192 .37497 L .59034 .38081 L F
.60945 .55656 m .6007 .56018 L .59989 .56246 L .071 0 0 r
F
.60945 .55656 m .61032 .55424 L .6007 .56018 L F
.62898 .51902 m .6211 .52334 L .62079 .52594 L .025 0 0 r
F
.62898 .51902 m .62931 .51639 L .6211 .52334 L F
.61192 .56079 m .60283 .56434 L .60199 .56666 L .085 0 0 r
F
.61192 .56079 m .61283 .55842 L .60283 .56434 L F
.54393 .65194 m .53205 .65504 L .5308 .65624 L .097 0 0 r
F
.54393 .65194 m .54545 .65071 L .53205 .65504 L F
.60179 .61223 m .59262 .61682 L .59105 .61881 L 0 0 0 r
F
.60179 .61223 m .60349 .61016 L .59262 .61682 L F
.45326 .67628 m .45288 .67507 L .43708 .67651 L .547 .011 0 r
F
.46857 .67421 m .45288 .67507 L .45326 .67628 L .45 0 0 r
F
.62563 .51555 m .61818 .51987 L .61789 .52242 L .004 0 0 r
F
.62563 .51555 m .62594 .51298 L .61818 .51987 L F
.64619 .54475 m .64111 .55083 L .64005 .55358 L 0 0 0 r
F
.64619 .54475 m .64723 .54197 L .64111 .55083 L F
.34862 .58744 m .33494 .58037 L .33608 .58269 L 1 .298 0 r
F
.34968 .58965 m .34862 .58744 L .33608 .58269 L 1 .272 0 r
F
.29413 .52323 m .28658 .51155 L .28646 .51468 L 1 .66 0 r
F
.29408 .52636 m .29413 .52323 L .28646 .51468 L 1 .638 0 r
F
.55687 .33061 m .5555 .33174 L .5576 .33427 L 0 .068 0 r
F
.55687 .33061 m .55451 .32869 L .5555 .33174 L F
.23302 .83395 m .20501 .82148 L .2093 .82599 L .857 .062 0 r
F
.23696 .83817 m .23302 .83395 L .2093 .82599 L .828 .057 0 r
F
.13002 .70709 m .1054 .68887 L .10829 .69486 L 1 .173 0 r
F
.1328 .7128 m .13002 .70709 L .10829 .69486 L 1 .146 0 r
F
.39066 .61992 m .37593 .61542 L .37721 .6172 L 1 .083 0 r
F
.39177 .62161 m .39066 .61992 L .37721 .6172 L .997 .079 0 r
F
.30735 .50858 m .29773 .49806 L .29783 .50095 L 1 .714 0 r
F
.30749 .51141 m .30735 .50858 L .29783 .50095 L 1 .692 0 r
F
.3524 .8978 m .32337 .89134 L .32706 .89418 L .634 .017 0 r
F
.35545 .90041 m .3524 .8978 L .32706 .89418 L .599 .011 0 r
F
.58976 .58391 m .58011 .58684 L .57905 .58881 L .143 0 0 r
F
.58976 .58391 m .59094 .58189 L .58011 .58684 L F
.49551 .63271 m .48261 .63248 L .48236 .63352 L .495 .006 0 r
F
.49551 .63271 m .49602 .63166 L .48261 .63248 L F
.33459 .54314 m .32456 .53427 L .32506 .53677 L 1 .541 0 r
F
.33511 .54558 m .33459 .54314 L .32506 .53677 L 1 .515 0 r
F
.598 .38075 m .59506 .38427 L .5968 .38651 L .024 .067 0 r
F
.598 .38075 m .59621 .37862 L .59506 .38427 L F
.5126 .66433 m .49926 .66671 L .4986 .66772 L .212 0 0 r
F
.5126 .66433 m .51359 .66334 L .49926 .66671 L F
.59569 .37904 m .59217 .38296 L .59397 .38513 L .116 .082 0 r
F
.59569 .37904 m .59383 .37699 L .59217 .38296 L F
.11359 .72597 m .08913 .70616 L .09224 .71244 L 1 .116 0 r
F
.11659 .73197 m .11359 .72597 L .09224 .71244 L 1 .113 0 r
F
.63207 .45806 m .62609 .4629 L .62668 .46557 L .007 .014 0 r
F
.63207 .45806 m .63144 .45541 L .62609 .4629 L F
.37441 .59736 m .36144 .59103 L .36258 .59298 L 1 .167 0 r
F
.37546 .59922 m .37441 .59736 L .36258 .59298 L 1 .138 0 r
F
.51618 .3302 m .51453 .32859 L .51681 .33113 L .521 0 0 r
F
.51618 .3302 m .51371 .32862 L .51453 .32859 L F
.66247 .48872 m .66114 .49472 L .66035 .49784 L .705 .174 0 r
F
.66247 .48872 m .6633 .48561 L .66114 .49472 L F
.40887 .62842 m .39407 .62486 L .39526 .62643 L .935 .069 0 r
F
.40985 .6299 m .40887 .62842 L .39526 .62643 L .914 .065 0 r
F
.91112 .52141 m .8988 .53385 L .89855 .54086 L 0 0 0 r
F
.91112 .52141 m .91137 .51426 L .8988 .53385 L F
.49793 .66867 m .48385 .67066 L .48353 .67166 L .282 0 0 r
F
.49793 .66867 m .4986 .66772 L .48385 .67066 L F
.57068 .60174 m .56035 .60404 L .55922 .60573 L .212 0 0 r
F
.57068 .60174 m .57197 .59999 L .56035 .60404 L F
.46896 .63998 m .46893 .63889 L .45509 .63902 L .629 .024 0 r
F
.48245 .63936 m .46893 .63889 L .46896 .63998 L .56 .015 0 r
F
.48245 .63936 m .4827 .63828 L .46893 .63889 L F
.62867 .45585 m .62288 .46057 L .62345 .4632 L 0 .011 0 r
F
.62867 .45585 m .62809 .45324 L .62288 .46057 L F
.59144 .58851 m .58157 .59135 L .58047 .59336 L .15 0 0 r
F
.59144 .58851 m .59266 .58645 L .58157 .59135 L F
.35436 .57657 m .34248 .56901 L .34344 .57123 L 1 .321 0 r
F
.35526 .57872 m .35436 .57657 L .34344 .57123 L 1 .291 0 r
F
.72457 .35166 m .74128 .35114 L .74322 .35575 L 1 .087 0 r
F
.72457 .35166 m .72137 .34817 L .74128 .35114 L F
.32239 .49304 m .31537 .48325 L .31511 .48587 L 1 .805 0 r
F
.3222 .49566 m .32239 .49304 L .31511 .48587 L 1 .784 0 r
F
.53829 .62604 m .52671 .62733 L .52575 .62867 L .33 0 0 r
F
.53829 .62604 m .53948 .62466 L .52671 .62733 L F
.37986 .66061 m .36303 .65559 L .36448 .65801 L 1 .114 0 r
F
.38119 .66281 m .37986 .66061 L .36448 .65801 L 1 .097 0 r
F
.68417 .6897 m .6728 .69595 L .67019 .69932 L 0 0 0 r
F
.68417 .6897 m .6871 .68634 L .6728 .69595 L F
.4107 .62048 m .39677 .61624 L .39789 .61773 L .936 .069 0 r
F
.41164 .62188 m .4107 .62048 L .39789 .61773 L .913 .065 0 r
F
.50929 .63563 m .49674 .63606 L .49622 .63719 L .428 0 0 r
F
.50929 .63563 m .51007 .63449 L .49674 .63606 L F
.59978 .38288 m .5968 .38651 L .59852 .38876 L .023 .066 0 r
F
.59978 .38288 m .598 .38075 L .5968 .38651 L F
.59752 .38112 m .59397 .38513 L .59573 .38732 L .109 .079 0 r
F
.59752 .38112 m .59569 .37904 L .59397 .38513 L F
.18957 .77517 m .16228 .7616 L .16605 .76671 L 1 .091 0 r
F
.19307 .78 m .18957 .77517 L .16605 .76671 L .99 .088 0 r
F
.54871 .33276 m .54067 .34282 L .54106 .34614 L 1 .825 0 r
F
.5521 .32682 m .54842 .33198 L .54871 .33276 L F
.54826 .32703 m .54703 .33017 L .54841 .33197 L .033 .068 0 r
F
.54878 .33109 m .54843 .33196 L .5521 .32682 L .24 .316 0 r
F
.54973 .32885 m .54939 .32965 L .5521 .32682 L .713 .217 0 r
F
.54826 .32703 m .54841 .33197 L .54878 .33109 L .033 .068 0 r
F
.5485 .33058 m .54844 .33153 L .54878 .33109 L .713 .217 0 r
F
.54937 .32967 m .54878 .33109 L .5521 .32682 L F
.54968 .32889 m .54826 .32703 L .54878 .33109 L 0 .048 0 r
F
.5485 .33058 m .54878 .33109 L .54937 .32967 L .713 .217 0 r
F
.55015 .32952 m .54969 .3289 L .549 .33273 L 0 .048 0 r
F
.54969 .3289 m .54968 .32889 L .54966 .32897 L F
.54969 .3289 m .54966 .32897 L .549 .33273 L F
.54968 .32889 m .54878 .33109 L .549 .33273 L F
.54878 .33109 m .54842 .33198 L .54843 .33196 L .24 .316 0 r
F
.54878 .33109 m .54841 .33197 L .54842 .33198 L .033 .068 0 r
F
.54844 .33153 m .54842 .33198 L .54878 .33109 L .24 .316 0 r
F
.54878 .33109 m .54842 .33198 L .549 .33273 L .033 .068 0 r
F
.55268 .32468 m .54973 .32885 L .5521 .32682 L .713 .217 0 r
F
.54973 .32885 m .5485 .33058 L .54939 .32965 L F
.54836 .33279 m .54703 .33017 L .54796 .33283 L 0 .004 0 r
F
.54836 .33276 m .54703 .33017 L .54836 .33279 L F
.5484 .33229 m .54703 .33017 L .54837 .33279 L F
.54842 .33198 m .54703 .33017 L .54871 .33276 L F
.5485 .33058 m .54162 .34032 L .54844 .33153 L .713 .217 0 r
F
.54837 .33279 m .54836 .33276 L .54836 .33279 L 0 .004 0 r
F
.54871 .33276 m .5484 .33229 L .54837 .33279 L F
.54162 .34032 m .54067 .34282 L .54842 .33198 L .24 .316 0 r
F
.54162 .34032 m .54842 .33198 L .54844 .33153 L F
.54842 .33198 m .54067 .34282 L .54871 .33276 L 1 .825 0 r
F
.549 .33273 m .54842 .33198 L .54871 .33276 L 0 .004 0 r
F
.38402 .90556 m .35545 .90041 L .35856 .90291 L .577 .008 0 r
F
.38644 .90785 m .38402 .90556 L .35856 .90291 L .554 .001 0 r
F
.55313 .61367 m .54223 .61542 L .54115 .61689 L .274 0 0 r
F
.55313 .61367 m .5544 .61216 L .54223 .61542 L F
.35754 .64572 m .34164 .63883 L .34303 .64152 L 1 .222 0 r
F
.35886 .64822 m .35754 .64572 L .34303 .64152 L 1 .204 0 r
F
.3711 .60796 m .35675 .60236 L .35804 .60437 L 1 .152 0 r
F
.37226 .60988 m .3711 .60796 L .35804 .60437 L 1 .126 0 r
F
.39354 .61154 m .37996 .60634 L .38116 .60804 L 1 .083 0 r
F
.39459 .61314 m .39354 .61154 L .38116 .60804 L .994 .079 0 r
F
.55916 .33258 m .5576 .33427 L .55969 .33671 L 0 .074 0 r
F
.55916 .33258 m .55687 .33061 L .5576 .33427 L F
.62861 .52164 m .62079 .52594 L .62044 .52853 L .016 0 0 r
F
.62861 .52164 m .62898 .51902 L .62079 .52594 L F
.45537 .63245 m .44142 .63048 L .44197 .6316 L .722 .036 0 r
F
.45566 .6335 m .45537 .63245 L .44197 .6316 L .696 .031 0 r
F
.46901 .63378 m .45537 .63245 L .45566 .6335 L .644 .025 0 r
F
.87242 .66418 m .85716 .67305 L .85478 .67945 L 0 0 0 r
F
.87242 .66418 m .87495 .65758 L .85716 .67305 L F
.72309 .64276 m .71214 .64924 L .70997 .6532 L F
.72309 .64276 m .72545 .63872 L .71214 .64924 L F
.35427 .89122 m .32571 .88485 L .32933 .88768 L .639 .018 0 r
F
.35728 .89381 m .35427 .89122 L .32933 .88768 L .605 .012 0 r
F
.41939 .67419 m .40224 .67226 L .40347 .67412 L .825 .053 0 r
F
.42037 .67581 m .41939 .67419 L .40347 .67412 L .806 .05 0 r
F
.5718 .60651 m .56133 .60875 L .56016 .61048 L .213 0 0 r
F
.5718 .60651 m .57313 .60473 L .56133 .60875 L F
.42664 .62662 m .4126 .62324 L .41358 .62457 L .858 .056 0 r
F
.42741 .62786 m .42664 .62662 L .41358 .62457 L .834 .051 0 r
F
.32643 .55844 m .31421 .54974 L .31502 .55235 L 1 .46 0 r
F
.32722 .56096 m .32643 .55844 L .31502 .55235 L 1 .435 0 r
F
.51572 .33175 m .51401 .33044 L .51632 .33274 L 0 .026 0 r
F
.62528 .51811 m .61789 .52242 L .61755 .52495 L 0 0 0 r
F
.62528 .51811 m .62563 .51555 L .61789 .52242 L F
.63265 .46072 m .62668 .46557 L .62723 .46824 L 0 .011 0 r
F
.63265 .46072 m .63207 .45806 L .62668 .46557 L F
.3105 .58386 m .29899 .57322 L .29969 .57632 L 1 .463 0 r
F
.31124 .58688 m .3105 .58386 L .29969 .57632 L 1 .442 0 r
F
.4957 .63828 m .4827 .63828 L .48245 .63936 L .477 .004 0 r
F
.4957 .63828 m .49622 .63719 L .4827 .63828 L F
.5224 .62728 m .51052 .62805 L .50978 .6292 L .382 0 0 r
F
.5224 .62728 m .52339 .62609 L .51052 .62805 L F
.42554 .63411 m .41086 .63134 L .41189 .63274 L .854 .056 0 r
F
.42633 .63542 m .42554 .63411 L .41189 .63274 L .831 .052 0 r
F
.60854 .55886 m .59989 .56246 L .59904 .56472 L .061 0 0 r
F
.60854 .55886 m .60945 .55656 L .59989 .56246 L F
.29408 .52636 m .28646 .51468 L .28639 .51782 L 1 .638 0 r
F
.29407 .52949 m .29408 .52636 L .28639 .51782 L 1 .616 0 r
F
.30749 .51141 m .29783 .50095 L .29798 .50383 L 1 .692 0 r
F
.30768 .51424 m .30749 .51141 L .29798 .50383 L 1 .67 0 r
F
.59932 .38323 m .59573 .38732 L .59746 .38953 L .102 .076 0 r
F
.59932 .38323 m .59752 .38112 L .59573 .38732 L F
.51862 .33178 m .51681 .33113 L .51915 .33323 L 0 .066 0 r
F
.51862 .33178 m .51618 .3302 L .51681 .33113 L F
.60153 .38503 m .59852 .38876 L .60021 .39102 L .022 .065 0 r
F
.60153 .38503 m .59978 .38288 L .59852 .38876 L F
.6292 .45847 m .62345 .4632 L .62398 .46583 L 0 .007 0 r
F
.6292 .45847 m .62867 .45585 L .62345 .4632 L F
.17573 .79866 m .14856 .78309 L .15266 .78842 L .93 .082 0 r
F
.17956 .8037 m .17573 .79866 L .15266 .78842 L .902 .078 0 r
F
.44142 .63048 m .42741 .62786 L .42819 .62905 L .786 .045 0 r
F
.44197 .6316 m .44142 .63048 L .42819 .62905 L .76 .04 0 r
F
.61096 .56314 m .60199 .56666 L .60111 .56896 L .075 0 0 r
F
.61096 .56314 m .61192 .56079 L .60199 .56666 L F
.62341 .58705 m .61585 .59237 L .61442 .59471 L 0 0 0 r
F
.62341 .58705 m .62489 .58464 L .61585 .59237 L F
.75929 .57001 m .75045 .57803 L .74915 .58258 L F
.75929 .57001 m .7606 .56535 L .75045 .57803 L F
.33511 .54558 m .32506 .53677 L .32562 .53925 L 1 .515 0 r
F
.33566 .54801 m .33511 .54558 L .32562 .53925 L 1 .487 0 r
F
.81321 .75783 m .79655 .76402 L .79294 .76947 L 0 0 0 r
F
.81321 .75783 m .8171 .75217 L .79655 .76402 L F
.77276 .46454 m .77057 .47369 L .77072 .47861 L F
.77276 .46454 m .77231 .45967 L .77057 .47369 L F
.50693 .32747 m .50754 .31713 L .50912 .32344 L 1 .323 0 r
F
.50693 .32747 m .50657 .31617 L .50754 .31713 L F
.28828 .84035 m .25954 .83324 L .26357 .837 L .873 .058 0 r
F
.29183 .84389 m .28828 .84035 L .26357 .837 L .849 .054 0 r
F
.3222 .49566 m .31511 .48587 L .31491 .4885 L 1 .784 0 r
F
.32205 .49828 m .3222 .49566 L .31491 .4885 L 1 .762 0 r
F
.12124 .72072 m .09775 .70108 L .10071 .70726 L 1 .119 0 r
F
.12411 .72665 m .12124 .72072 L .10071 .70726 L 1 .114 0 r
F
.8193 .21129 m .81767 .22628 L .82229 .23162 L 0 .056 0 r
F
.8193 .21129 m .81463 .20618 L .81767 .22628 L F
.33408 .62241 m .31988 .6136 L .32105 .61652 L 1 .328 0 r
F
.33524 .62519 m .33408 .62241 L .32105 .61652 L 1 .309 0 r
F
.55387 .61856 m .54289 .6203 L .54178 .62179 L .271 0 0 r
F
.55387 .61856 m .55518 .61702 L .54289 .6203 L F
.89377 .35277 m .88682 .36784 L .88923 .37451 L 0 0 0 r
F
.89377 .35277 m .89126 .34612 L .88682 .36784 L F
.64512 .54752 m .64005 .55358 L .63896 .5563 L F
.64512 .54752 m .64619 .54475 L .64005 .55358 L F
.81773 .21251 m .81724 .2266 L .82193 .23187 L 0 .058 0 r
F
.81773 .21251 m .81287 .20758 L .81724 .2266 L F
.89896 .52028 m .89029 .53279 L .88981 .53963 L 0 0 0 r
F
.89896 .52028 m .89959 .51335 L .89029 .53279 L F
.45509 .63902 m .44081 .63751 L .44138 .63869 L .711 .036 0 r
F
.45539 .64013 m .45509 .63902 L .44138 .63869 L .685 .031 0 r
F
.46896 .63998 m .45509 .63902 L .45539 .64013 L .629 .024 0 r
F
.75589 .8151 m .73834 .81955 L .73421 .8241 L 0 0 0 r
F
.75589 .8151 m .7604 .81036 L .73834 .81955 L F
.38541 .8988 m .35728 .89381 L .36033 .89629 L .578 .008 0 r
F
.38779 .90106 m .38541 .8988 L .36033 .89629 L .555 .002 0 r
F
.5509 .33529 m .54993 .33553 L .55193 .33806 L 0 .002 0 r
F
.5509 .33529 m .549 .33273 L .54993 .33553 L F
.44081 .63751 m .42633 .63542 L .42715 .63669 L .778 .045 0 r
F
.44138 .63869 m .44081 .63751 L .42715 .63669 L .754 .04 0 r
F
.34968 .58965 m .33608 .58269 L .33726 .58498 L 1 .272 0 r
F
.35077 .59184 m .34968 .58965 L .33726 .58498 L 1 .245 0 r
F
.60107 .38536 m .59746 .38953 L .59915 .39176 L .094 .074 0 r
F
.60107 .38536 m .59932 .38323 L .59746 .38953 L F
.5614 .3346 m .55969 .33671 L .56178 .3391 L 0 .076 0 r
F
.5614 .3346 m .55916 .33258 L .55969 .33671 L F
.60326 .38719 m .60021 .39102 L .60187 .3933 L .019 .063 0 r
F
.60326 .38719 m .60153 .38503 L .60021 .39102 L F
.66164 .4918 m .66035 .49784 L .65956 .50094 L .708 .174 0 r
F
.66164 .4918 m .66247 .48872 L .66035 .49784 L F
.51807 .33351 m .51632 .33274 L .51869 .33466 L 0 .052 0 r
F
.51807 .33351 m .51572 .33175 L .51632 .33274 L F
.58855 .58591 m .57905 .58881 L .57795 .59075 L .133 0 0 r
F
.58855 .58591 m .58976 .58391 L .57905 .58881 L F
.63318 .46339 m .62723 .46824 L .62774 .47092 L 0 .007 0 r
F
.63318 .46339 m .63265 .46072 L .62723 .46824 L F
.52101 .33341 m .51915 .33323 L .52153 .33508 L 0 .081 0 r
F
.52101 .33341 m .51862 .33178 L .51915 .33323 L F
.60373 .34421 m .68589 .26765 L .67964 .28061 L .531 .04 0 r
F
.60373 .34421 m .59541 .34866 L .68514 .26832 L F
.68515 .26833 m .68514 .26832 L .68589 .26765 L F
.60373 .34421 m .68514 .26832 L .68515 .26833 L F
.68806 .27095 m .68409 .26818 L .69108 .2726 L .435 0 0 r
F
.69195 .27322 m .69108 .2726 L .69359 .27418 L F
.68806 .27095 m .69108 .2726 L .69195 .27322 L F
.67979 .26579 m .68812 .26542 L .69097 .26973 L .461 0 0 r
F
.67979 .26579 m .67512 .26384 L .68812 .26542 L F
.8908 .35366 m .88364 .3687 L .8858 .37538 L 0 0 0 r
F
.8908 .35366 m .88859 .34697 L .88364 .3687 L F
.52698 .65954 m .51457 .66231 L .51359 .66334 L .133 0 0 r
F
.52698 .65954 m .52827 .65849 L .51457 .66231 L F
.5366 .62235 m .52531 .6236 L .52436 .62487 L .324 0 0 r
F
.5366 .62235 m .53777 .62105 L .52531 .6236 L F
.62819 .52425 m .62044 .52853 L .62004 .5311 L .006 0 0 r
F
.62819 .52425 m .62861 .52164 L .62044 .52853 L F
.62969 .46109 m .62398 .46583 L .62446 .46846 L 0 .004 0 r
F
.62969 .46109 m .6292 .45847 L .62398 .46583 L F
.35526 .57872 m .34344 .57123 L .34443 .57343 L 1 .291 0 r
F
.3562 .58084 m .35526 .57872 L .34443 .57343 L 1 .262 0 r
F
.60006 .61426 m .59105 .61881 L .58945 .62075 L 0 0 0 r
F
.60006 .61426 m .60179 .61223 L .59105 .61881 L F
.40103 .67037 m .38392 .66714 L .38532 .66927 L .936 .07 0 r
F
.40224 .67226 m .40103 .67037 L .38532 .66927 L .92 .068 0 r
F
.37546 .59922 m .36258 .59298 L .36377 .59491 L 1 .138 0 r
F
.37654 .60105 m .37546 .59922 L .36377 .59491 L 1 .109 0 r
F
.52276 .63243 m .51084 .6333 L .51007 .63449 L .373 0 0 r
F
.52276 .63243 m .52377 .63122 L .51084 .6333 L F
.62488 .52066 m .61755 .52495 L .61718 .52748 L 0 0 0 r
F
.62488 .52066 m .62528 .51811 L .61755 .52495 L F
.72768 .35525 m .74322 .35575 L .74515 .36036 L .988 .087 0 r
F
.72768 .35525 m .72457 .35166 L .74322 .35575 L F
.60279 .38752 m .59915 .39176 L .60081 .39401 L .086 .071 0 r
F
.60279 .38752 m .60107 .38536 L .59915 .39176 L F
.59018 .59054 m .58047 .59336 L .57933 .59533 L .14 0 0 r
F
.59018 .59054 m .59144 .58851 L .58047 .59336 L F
.39177 .62161 m .37721 .6172 L .37852 .61894 L .997 .079 0 r
F
.39291 .62325 m .39177 .62161 L .37852 .61894 L .977 .076 0 r
F
.86164 .65924 m .84858 .66877 L .84616 .67498 L 0 0 0 r
F
.86164 .65924 m .86417 .65285 L .84858 .66877 L F
.60495 .38937 m .60187 .3933 L .6035 .39559 L .016 .061 0 r
F
.60495 .38937 m .60326 .38719 L .60187 .3933 L F
.50825 .63137 m .49602 .63166 L .49551 .63271 L .426 0 0 r
F
.50825 .63137 m .50902 .6303 L .49602 .63166 L F
.30768 .51424 m .29798 .50383 L .29818 .5067 L 1 .67 0 r
F
.30791 .51705 m .30768 .51424 L .29818 .5067 L 1 .647 0 r
F
.18125 .79271 m .15485 .77721 L .1588 .78248 L .936 .084 0 r
F
.18497 .79771 m .18125 .79271 L .1588 .78248 L .909 .08 0 r
F
.29407 .52949 m .28639 .51782 L .28636 .52096 L 1 .616 0 r
F
.29412 .53263 m .29407 .52949 L .28636 .52096 L 1 .593 0 r
F
.46904 .63478 m .46901 .63378 L .45566 .6335 L .617 .02 0 r
F
.48212 .63451 m .46901 .63378 L .46904 .63478 L .55 .012 0 r
F
.48212 .63451 m .48236 .63352 L .46901 .63378 L F
.32205 .49828 m .31491 .4885 L .31475 .49112 L 1 .762 0 r
F
.32194 .50089 m .32205 .49828 L .31475 .49112 L 1 .739 0 r
F
.56936 .60345 m .55922 .60573 L .55805 .60739 L .201 0 0 r
F
.56936 .60345 m .57068 .60174 L .55922 .60573 L F
.52047 .33501 m .51869 .33466 L .5211 .33632 L 0 .078 0 r
F
.52047 .33501 m .51807 .33351 L .51869 .33466 L F
.32722 .56096 m .31502 .55235 L .31588 .55495 L 1 .435 0 r
F
.32804 .56347 m .32722 .56096 L .31588 .55495 L 1 .41 0 r
F
.52336 .33502 m .52153 .33508 L .52393 .33675 L 0 .085 0 r
F
.52336 .33502 m .52101 .33341 L .52153 .33508 L F
.55277 .3378 m .55193 .33806 L .55397 .34044 L 0 0 0 r
F
.55277 .3378 m .5509 .33529 L .55193 .33806 L F
.56357 .33666 m .56178 .3391 L .56385 .34144 L .01 .076 0 r
F
.56357 .33666 m .5614 .3346 L .56178 .3391 L F
.60759 .56115 m .59904 .56472 L .59816 .56695 L .051 0 0 r
F
.60759 .56115 m .60854 .55886 L .59904 .56472 L F
.46861 .67525 m .46857 .67421 L .45326 .67628 L .43 0 0 r
F
.48321 .67261 m .46857 .67421 L .46861 .67525 L .347 0 0 r
F
.48321 .67261 m .48353 .67166 L .46857 .67421 L F
.33566 .54801 m .32562 .53925 L .32621 .54172 L 1 .487 0 r
F
.33626 .55042 m .33566 .54801 L .32621 .54172 L 1 .46 0 r
F
.43708 .67651 m .42037 .67581 L .42138 .6774 L .687 .032 0 r
F
.43779 .67787 m .43708 .67651 L .42138 .6774 L .661 .028 0 r
F
.45326 .67628 m .43708 .67651 L .43779 .67787 L .547 .011 0 r
F
.31124 .58688 m .29969 .57632 L .30044 .57941 L 1 .442 0 r
F
.31203 .58989 m .31124 .58688 L .30044 .57941 L 1 .421 0 r
F
.80469 .75091 m .7894 .75779 L .78581 .76306 L 0 0 0 r
F
.80469 .75091 m .80853 .74544 L .7894 .75779 L F
.63367 .46606 m .62774 .47092 L .62819 .4736 L 0 .004 0 r
F
.63367 .46606 m .63318 .46339 L .62774 .47092 L F
.60997 .56547 m .60111 .56896 L .60019 .57124 L .065 0 0 r
F
.60997 .56547 m .61096 .56314 L .60111 .56896 L F
.32764 .85546 m .29914 .85072 L .30289 .85401 L .809 .047 0 r
F
.33084 .85856 m .32764 .85546 L .30289 .85401 L .784 .043 0 r
F
.60446 .38971 m .60081 .39401 L .60242 .39629 L .078 .068 0 r
F
.60446 .38971 m .60279 .38752 L .60081 .39401 L F
.40985 .6299 m .39526 .62643 L .39647 .62796 L .914 .065 0 r
F
.41086 .63134 m .40985 .6299 L .39647 .62796 L .892 .061 0 r
F
.27877 .87031 m .24988 .86046 L .25433 .86424 L .747 .039 0 r
F
.28275 .87382 m .27877 .87031 L .25433 .86424 L .713 .034 0 r
F
.37226 .60988 m .35804 .60437 L .35937 .60635 L 1 .126 0 r
F
.37346 .61176 m .37226 .60988 L .35937 .60635 L 1 .1 0 r
F
.24419 .81739 m .21592 .80753 L .22002 .81186 L .929 .07 0 r
F
.24792 .82147 m .24419 .81739 L .22002 .81186 L .905 .066 0 r
F
.54239 .65313 m .5308 .65624 L .52954 .65739 L .071 0 0 r
F
.54239 .65313 m .54393 .65194 L .5308 .65624 L F
.495 .63371 m .48236 .63352 L .48212 .63451 L .472 .001 0 r
F
.495 .63371 m .49551 .63271 L .48236 .63352 L F
.74908 .80709 m .73255 .8122 L .72846 .81658 L 0 0 0 r
F
.74908 .80709 m .75355 .80253 L .73255 .8122 L F
.60662 .39157 m .6035 .39559 L .60511 .3979 L .012 .059 0 r
F
.60662 .39157 m .60495 .38937 L .6035 .39559 L F
.63013 .46371 m .62446 .46846 L .6249 .47109 L 0 0 0 r
F
.63013 .46371 m .62969 .46109 L .62446 .46846 L F
.39459 .61314 m .38116 .60804 L .38238 .6097 L .994 .079 0 r
F
.39567 .61471 m .39459 .61314 L .38238 .6097 L .972 .076 0 r
F
.55183 .61515 m .54115 .61689 L .54004 .61831 L .262 0 0 r
F
.55183 .61515 m .55313 .61367 L .54115 .61689 L F
.41164 .62188 m .39789 .61773 L .39904 .61919 L .913 .065 0 r
F
.4126 .62324 m .41164 .62188 L .39904 .61919 L .889 .06 0 r
F
.52295 .33617 m .5211 .33632 L .52355 .3378 L 0 .109 0 r
F
.52295 .33617 m .52047 .33501 L .5211 .33632 L F
.53709 .62737 m .52575 .62867 L .52477 .62996 L .317 0 0 r
F
.53709 .62737 m .53829 .62604 L .52575 .62867 L F
.57043 .60825 m .56016 .61048 L .55896 .61217 L .202 0 0 r
F
.57043 .60825 m .5718 .60651 L .56016 .61048 L F
.52573 .33649 m .52393 .33675 L .52636 .33828 L 0 .095 0 r
F
.52573 .33649 m .52336 .33502 L .52393 .33675 L F
.91074 .52856 m .89855 .54086 L .89818 .54787 L 0 0 0 r
F
.91074 .52856 m .91112 .52141 L .89855 .54086 L F
.64402 .55027 m .63896 .5563 L .63785 .559 L F
.64402 .55027 m .64512 .54752 L .63896 .5563 L F
.62189 .58944 m .61442 .59471 L .61296 .59702 L F
.62189 .58944 m .62341 .58705 L .61442 .59471 L F
.35886 .64822 m .34303 .64152 L .34446 .64419 L 1 .204 0 r
F
.36022 .65069 m .35886 .64822 L .34446 .64419 L 1 .187 0 r
F
.66082 .49485 m .65956 .50094 L .65877 .50401 L .711 .174 0 r
F
.66082 .49485 m .66164 .4918 L .65956 .50094 L F
.62773 .52685 m .62004 .5311 L .6196 .53367 L 0 0 0 r
F
.62773 .52685 m .62819 .52425 L .62004 .5311 L F
.46898 .64103 m .46896 .63998 L .45539 .64013 L .602 .019 0 r
F
.4822 .6404 m .46896 .63998 L .46898 .64103 L .533 .01 0 r
F
.4822 .6404 m .48245 .63936 L .46896 .63998 L F
.77312 .46943 m .77072 .47861 L .77079 .48353 L 0 0 0 r
F
.77312 .46943 m .77276 .46454 L .77072 .47861 L F
.62444 .5232 m .61718 .52748 L .61676 .52999 L F
.62444 .5232 m .62488 .52066 L .61718 .52748 L F
.38119 .66281 m .36448 .65801 L .36597 .66042 L 1 .097 0 r
F
.38254 .66498 m .38119 .66281 L .36597 .66042 L 1 .084 0 r
F
.60609 .39192 m .60242 .39629 L .604 .39858 L .068 .065 0 r
F
.60609 .39192 m .60446 .38971 L .60242 .39629 L F
.32194 .50089 m .31475 .49112 L .31463 .49375 L 1 .739 0 r
F
.32188 .5035 m .32194 .50089 L .31463 .49375 L 1 .716 0 r
F
.45364 .67745 m .45326 .67628 L .43779 .67787 L .516 .006 0 r
F
.46861 .67525 m .45326 .67628 L .45364 .67745 L .43 0 0 r
F
.55465 .34019 m .55397 .34044 L .55603 .34268 L 0 0 0 r
F
.55465 .34019 m .55277 .3378 L .55397 .34044 L F
.56569 .33876 m .56385 .34144 L .56589 .34375 L .017 .074 0 r
F
.56569 .33876 m .56357 .33666 L .56385 .34144 L F
.1328 .7128 m .10829 .69486 L .11128 .7008 L 1 .146 0 r
F
.13568 .71845 m .1328 .7128 L .11128 .7008 L 1 .12 0 r
F
.5085 .63673 m .49622 .63719 L .4957 .63828 L .415 0 0 r
F
.5085 .63673 m .50929 .63563 L .49622 .63719 L F
.35077 .59184 m .33726 .58498 L .33848 .58725 L 1 .245 0 r
F
.3519 .594 m .35077 .59184 L .33848 .58725 L 1 .218 0 r
F
.60826 .39379 m .60511 .3979 L .60668 .40023 L .008 .057 0 r
F
.60826 .39379 m .60662 .39157 L .60511 .3979 L F
.52548 .33717 m .52355 .3378 L .52602 .33916 L .105 .13 0 r
F
.5223 .33225 m .52101 .33341 L .52336 .33502 L .03 .084 0 r
F
.52332 .33583 m .5223 .33225 L .52336 .33502 L .828 .133 0 r
F
.52332 .33586 m .52336 .33502 L .52513 .33671 L F
.52332 .33586 m .52275 .33469 L .52332 .33583 L F
.52284 .33516 m .52278 .33481 L .52332 .33586 L F
.52275 .33469 m .5223 .33225 L .52332 .33583 L F
.52402 .33526 m .52204 .33552 L .52332 .33586 L .2 .165 0 r
F
.52332 .33586 m .52295 .33617 L .52363 .33644 L F
.52326 .33737 m .52284 .33516 L .52332 .33586 L .828 .133 0 r
F
.52301 .3354 m .52134 .33503 L .52204 .33552 L .2 .165 0 r
F
.52402 .33526 m .52284 .33516 L .52301 .3354 L F
.52284 .33516 m .52134 .33503 L .52301 .3354 L F
.52332 .33586 m .52204 .33552 L .52295 .33617 L F
.52513 .33671 m .52457 .33618 L .52573 .33649 L .828 .133 0 r
F
.52457 .33618 m .52336 .33502 L .52568 .33646 L F
.52457 .33618 m .52568 .33646 L .52573 .33649 L F
.52513 .33671 m .52332 .33586 L .5248 .33676 L .2 .165 0 r
F
.52513 .33671 m .5248 .33676 L .52548 .33717 L F
.52332 .33586 m .52363 .33644 L .52548 .33717 L F
.5242 .33758 m .52295 .33617 L .52355 .3378 L .105 .13 0 r
F
.52548 .33717 m .52363 .33644 L .5242 .33758 L F
.52363 .33644 m .52295 .33617 L .5242 .33758 L F
.52817 .33772 m .52573 .33649 L .52636 .33828 L .037 .113 0 r
F
.52663 .33572 m .52402 .33526 L .52435 .33569 L .261 .326 0 r
F
.52597 .33655 m .52513 .33671 L .52573 .33649 L 0 0 0 r
F
.52597 .33655 m .52513 .33671 L .52548 .33717 L .261 .326 0 r
F
.52606 .33657 m .52513 .33671 L .52597 .33655 L 0 0 0 r
F
.52597 .33655 m .52435 .33569 L .52513 .33671 L .261 .326 0 r
F
.52663 .33572 m .52435 .33569 L .52597 .33655 L F
.52759 .33739 m .52705 .33713 L .52817 .33772 L 0 0 0 r
F
.52705 .33713 m .52573 .33649 L .52815 .33771 L F
.52705 .33713 m .52815 .33771 L .52817 .33772 L F
.52663 .33572 m .52597 .33655 L .52759 .33739 L .261 .326 0 r
F
.52628 .33663 m .52597 .33655 L .52759 .33739 L 0 0 0 r
F
.52597 .33655 m .52573 .33649 L .52759 .33739 L F
.52759 .33739 m .52548 .33717 L .52801 .33812 L .261 .326 0 r
F
.52597 .33655 m .52548 .33717 L .52759 .33739 L F
.52628 .33663 m .52326 .33737 L .52513 .33671 L 0 0 0 r
F
.52628 .33663 m .52513 .33671 L .52606 .33657 L F
.52326 .33737 m .52332 .33586 L .52513 .33671 L .828 .133 0 r
F
.52402 .33526 m .52332 .33586 L .52513 .33671 L .2 .165 0 r
F
.52278 .33481 m .52275 .33469 L .52332 .33586 L .828 .133 0 r
F
.51159 .66526 m .4986 .66772 L .49793 .66867 L .182 0 0 r
F
.51159 .66526 m .5126 .66433 L .4986 .66772 L F
.42741 .62786 m .41358 .62457 L .41458 .62585 L .834 .051 0 r
F
.42819 .62905 m .42741 .62786 L .41458 .62585 L .808 .047 0 r
F
.30791 .51705 m .29818 .5067 L .29843 .50957 L 1 .647 0 r
F
.30819 .51985 m .30791 .51705 L .29843 .50957 L 1 .623 0 r
F
.33524 .62519 m .32105 .61652 L .32227 .61943 L 1 .309 0 r
F
.33645 .62795 m .33524 .62519 L .32227 .61943 L 1 .29 0 r
F
.7579 .57464 m .74915 .58258 L .74778 .5871 L 0 0 0 r
F
.7579 .57464 m .75929 .57001 L .74915 .58258 L F
.5873 .58788 m .57795 .59075 L .57682 .59266 L .122 0 0 r
F
.5873 .58788 m .58855 .58591 L .57795 .59075 L F
.63411 .46874 m .62819 .4736 L .62861 .47628 L 0 0 0 r
F
.63411 .46874 m .63367 .46606 L .62819 .4736 L F
.29412 .53263 m .28636 .52096 L .28638 .5241 L 1 .593 0 r
F
.29421 .53576 m .29412 .53263 L .28638 .5241 L 1 .571 0 r
F
.72065 .64674 m .70997 .6532 L .70773 .6571 L 0 0 0 r
F
.72065 .64674 m .72309 .64276 L .70997 .6532 L F
.45566 .6335 m .44197 .6316 L .44252 .63268 L .696 .031 0 r
F
.45596 .63451 m .45566 .6335 L .44252 .63268 L .669 .026 0 r
F
.46904 .63478 m .45566 .6335 L .45596 .63451 L .617 .02 0 r
F
.3562 .58084 m .34443 .57343 L .34546 .57561 L 1 .262 0 r
F
.35718 .58293 m .3562 .58084 L .34546 .57561 L 1 .231 0 r
F
.5214 .62842 m .50978 .6292 L .50902 .6303 L .369 0 0 r
F
.5214 .62842 m .5224 .62728 L .50978 .6292 L F
.28191 .86396 m .25356 .85416 L .25791 .85792 L .755 .041 0 r
F
.2858 .86745 m .28191 .86396 L .25791 .85792 L .723 .035 0 r
F
.42633 .63542 m .41189 .63274 L .41293 .6341 L .831 .052 0 r
F
.42715 .63669 m .42633 .63542 L .41293 .6341 L .807 .048 0 r
F
.63053 .46634 m .6249 .47109 L .62529 .47373 L 0 0 0 r
F
.63053 .46634 m .63013 .46371 L .6249 .47109 L F
.68117 .69298 m .67019 .69932 L .66751 .70261 L F
.68117 .69298 m .68417 .6897 L .67019 .69932 L F
.11659 .73197 m .09224 .71244 L .09548 .71866 L 1 .113 0 r
F
.11971 .73792 m .11659 .73197 L .09548 .71866 L .997 .109 0 r
F
.55253 .62006 m .54178 .62179 L .54064 .62325 L .258 0 0 r
F
.55253 .62006 m .55387 .61856 L .54178 .62179 L F
.49726 .66957 m .48353 .67166 L .48321 .67261 L .253 0 0 r
F
.49726 .66957 m .49793 .66867 L .48353 .67166 L F
.49517 .63932 m .48245 .63936 L .4822 .6404 L .46 0 0 r
F
.49517 .63932 m .4957 .63828 L .48245 .63936 L F
.68409 .26818 m .69097 .26973 L .69359 .27418 L .454 0 0 r
F
.68409 .26818 m .67979 .26579 L .69097 .26973 L F
.44197 .6316 m .42819 .62905 L .42899 .63021 L .76 .04 0 r
F
.44252 .63268 m .44197 .6316 L .42899 .63021 L .733 .035 0 r
F
.73069 .35892 m .74515 .36036 L .74706 .36496 L .964 .087 0 r
F
.73069 .35892 m .72768 .35525 L .74515 .36036 L F
.52801 .33812 m .52602 .33916 L .52849 .34045 L .185 .224 0 r
F
.52801 .33812 m .52548 .33717 L .52602 .33916 L F
.60769 .39416 m .604 .39858 L .60554 .4009 L .059 .062 0 r
F
.60769 .39416 m .60609 .39192 L .604 .39858 L F
.23288 .8444 m .2046 .83218 L .20911 .83661 L .819 .056 0 r
F
.23701 .84856 m .23288 .8444 L .20911 .83661 L .788 .051 0 r
F
.32804 .56347 m .31588 .55495 L .31678 .55753 L 1 .41 0 r
F
.32891 .56595 m .32804 .56347 L .31678 .55753 L 1 .384 0 r
F
.33626 .55042 m .32621 .54172 L .32685 .54417 L 1 .46 0 r
F
.3369 .55281 m .33626 .55042 L .32685 .54417 L 1 .431 0 r
F
.89615 .35947 m .88923 .37451 L .89153 .38123 L 0 0 0 r
F
.89615 .35947 m .89377 .35277 L .88923 .37451 L F
.37654 .60105 m .36377 .59491 L .36498 .5968 L 1 .109 0 r
F
.37765 .60285 m .37654 .60105 L .36498 .5968 L 1 .092 0 r
F
.58888 .59254 m .57933 .59533 L .57815 .59728 L .129 0 0 r
F
.58888 .59254 m .59018 .59054 L .57933 .59533 L F
.82388 .2165 m .82229 .23162 L .8268 .23703 L 0 .052 0 r
F
.82388 .2165 m .8193 .21129 L .82229 .23162 L F
.60986 .39603 m .60668 .40023 L .60821 .40257 L .002 .055 0 r
F
.60986 .39603 m .60826 .39379 L .60668 .40023 L F
.6066 .56341 m .59816 .56695 L .59724 .56916 L .041 0 0 r
F
.6066 .56341 m .60759 .56115 L .59816 .56695 L F
.82247 .21756 m .82193 .23187 L .82653 .23722 L 0 .053 0 r
F
.82247 .21756 m .81773 .21251 L .82193 .23187 L F
.55661 .34237 m .55603 .34268 L .55813 .3448 L 0 .008 0 r
F
.55661 .34237 m .55465 .34019 L .55603 .34268 L F
.86977 .67074 m .85478 .67945 L .85228 .68581 L 0 0 0 r
F
.86977 .67074 m .87242 .66418 L .85478 .67945 L F
.56776 .3409 m .56589 .34375 L .56792 .34603 L .014 .071 0 r
F
.56776 .3409 m .56569 .33876 L .56589 .34375 L F
.42037 .67581 m .40347 .67412 L .40473 .67596 L .806 .05 0 r
F
.42138 .6774 m .42037 .67581 L .40473 .67596 L .786 .047 0 r
F
.89823 .52719 m .88981 .53963 L .88921 .54645 L 0 0 0 r
F
.89823 .52719 m .89896 .52028 L .88981 .53963 L F
.49295 .32878 m .48996 .33094 L .49068 .32947 L .112 0 0 r
F
.60893 .56778 m .60019 .57124 L .59923 .57349 L .055 0 0 r
F
.60893 .56778 m .60997 .56547 L .60019 .57124 L F
.5983 .61625 m .58945 .62075 L .58782 .62266 L 0 0 0 r
F
.5983 .61625 m .60006 .61426 L .58945 .62075 L F
.53053 .33909 m .52801 .33812 L .52849 .34045 L .227 .295 0 r
F
.31203 .58989 m .30044 .57941 L .30124 .5825 L 1 .421 0 r
F
.31286 .59289 m .31203 .58989 L .30124 .5825 L 1 .4 0 r
F
.32188 .5035 m .31463 .49375 L .31456 .49637 L 1 .716 0 r
F
.32186 .50611 m .32188 .5035 L .31456 .49637 L 1 .692 0 r
F
.45539 .64013 m .44138 .63869 L .44195 .63984 L .685 .031 0 r
F
.4557 .6412 m .45539 .64013 L .44195 .63984 L .658 .026 0 r
F
.46898 .64103 m .45539 .64013 L .4557 .6412 L .602 .019 0 r
F
.56801 .60513 m .55805 .60739 L .55686 .60902 L .189 0 0 r
F
.56801 .60513 m .56936 .60345 L .55805 .60739 L F
.62722 .52944 m .6196 .53367 L .61912 .53621 L 0 0 0 r
F
.62722 .52944 m .62773 .52685 L .6196 .53367 L F
.44138 .63869 m .42715 .63669 L .42798 .63792 L .754 .04 0 r
F
.44195 .63984 m .44138 .63869 L .42798 .63792 L .728 .036 0 r
F
.53318 .33977 m .53126 .34103 L .53372 .34232 L .183 .222 0 r
F
.89286 .36041 m .8858 .37538 L .88782 .3821 L 0 0 0 r
F
.89286 .36041 m .8908 .35366 L .8858 .37538 L F
.6345 .47142 m .62861 .47628 L .62898 .47897 L F
.6345 .47142 m .63411 .46874 L .62861 .47628 L F
.31974 .88839 m .29092 .88052 L .29511 .88372 L .67 .024 0 r
F
.32337 .89134 m .31974 .88839 L .29511 .88372 L .635 .018 0 r
F
.53541 .62362 m .52436 .62487 L .52339 .62609 L .312 0 0 r
F
.53541 .62362 m .5366 .62235 L .52436 .62487 L F
.62396 .52573 m .61676 .52999 L .61631 .53248 L 0 0 0 r
F
.62396 .52573 m .62444 .5232 L .61676 .52999 L F
.39291 .62325 m .37852 .61894 L .37986 .62065 L .977 .076 0 r
F
.39407 .62486 m .39291 .62325 L .37986 .62065 L .957 .072 0 r
F
.60924 .39642 m .60554 .4009 L .60704 .40324 L .049 .059 0 r
F
.60924 .39642 m .60769 .39416 L .60554 .4009 L F
.63088 .46898 m .62529 .47373 L .62564 .47636 L 0 0 0 r
F
.63088 .46898 m .63053 .46634 L .62529 .47373 L F
.66002 .49788 m .65877 .50401 L .65797 .50706 L .713 .175 0 r
F
.66002 .49788 m .66082 .49485 L .65877 .50401 L F
.61143 .3983 m .60821 .40257 L .60972 .40493 L 0 .052 0 r
F
.61143 .3983 m .60986 .39603 L .60821 .40257 L F
.19307 .78 m .16605 .76671 L .16991 .77176 L .99 .088 0 r
F
.19666 .78477 m .19307 .78 L .16991 .77176 L .967 .084 0 r
F
.64289 .55299 m .63785 .559 L .6367 .56168 L 0 0 0 r
F
.64289 .55299 m .64402 .55027 L .63785 .559 L F
.41821 .86662 m .39181 .86772 L .39392 .87025 L .594 .02 0 r
F
.41965 .86904 m .41821 .86662 L .39392 .87025 L .565 .014 0 r
F
.30819 .51985 m .29843 .50957 L .29872 .51242 L 1 .623 0 r
F
.30851 .52263 m .30819 .51985 L .29872 .51242 L 1 .599 0 r
F
.52173 .6336 m .51007 .63449 L .50929 .63563 L .359 0 0 r
F
.52173 .6336 m .52276 .63243 L .51007 .63449 L F
.29421 .53576 m .28638 .5241 L .28646 .52725 L 1 .571 0 r
F
.29435 .5389 m .29421 .53576 L .28646 .52725 L 1 .548 0 r
F
.37346 .61176 m .35937 .60635 L .36074 .6083 L 1 .1 0 r
F
.37468 .6136 m .37346 .61176 L .36074 .6083 L 1 .088 0 r
F
.5357 .34076 m .53372 .34232 L .53618 .34359 L .221 .285 0 r
F
.5357 .34076 m .53318 .33977 L .53372 .34232 L F
.36198 .86422 m .3341 .86157 L .33742 .8645 L .741 .037 0 r
F
.36469 .86698 m .36198 .86422 L .33742 .8645 L .715 .033 0 r
F
.55867 .34432 m .55813 .3448 L .56027 .34683 L 0 .027 0 r
F
.56084 .34606 m .55867 .34432 L .56027 .34683 L 0 .049 0 r
F
.56048 .34593 m .55867 .34432 L .56084 .34606 L .147 0 0 r
F
.55867 .34432 m .55676 .34262 L .55813 .3448 L 0 .027 0 r
F
.55701 .34472 m .55867 .34432 L .56048 .34593 L .147 0 0 r
F
.55867 .34432 m .55661 .34237 L .55676 .34262 L 0 .027 0 r
F
.23696 .83817 m .2093 .82599 L .21368 .8304 L .828 .057 0 r
F
.24099 .84231 m .23696 .83817 L .21368 .8304 L .797 .052 0 r
F
.12411 .72665 m .10071 .70726 L .10378 .7134 L 1 .114 0 r
F
.12709 .73251 m .12411 .72665 L .10378 .7134 L 1 .11 0 r
F
.56976 .34307 m .56792 .34603 L .56992 .34829 L .002 .067 0 r
F
.56976 .34307 m .56776 .3409 L .56792 .34603 L F
.50747 .63239 m .49551 .63271 L .495 .63371 L .413 0 0 r
F
.50747 .63239 m .50825 .63137 L .49551 .63271 L F
.39567 .61471 m .38238 .6097 L .38363 .61133 L .972 .076 0 r
F
.39677 .61624 m .39567 .61471 L .38363 .61133 L .948 .072 0 r
F
.62033 .5918 m .61296 .59702 L .61146 .59929 L 0 0 0 r
F
.62033 .5918 m .62189 .58944 L .61296 .59702 L F
.46906 .63572 m .46904 .63478 L .45596 .63451 L .59 .015 0 r
F
.48187 .63545 m .46904 .63478 L .46906 .63572 L .524 .006 0 r
F
.48187 .63545 m .48212 .63451 L .46904 .63478 L F
.40224 .67226 m .38532 .66927 L .38675 .67138 L .92 .068 0 r
F
.40347 .67412 m .40224 .67226 L .38675 .67138 L .905 .065 0 r
F
.56903 .60995 m .55896 .61217 L .55772 .61382 L .19 0 0 r
F
.56903 .60995 m .57043 .60825 L .55896 .61217 L F
.77339 .47431 m .77079 .48353 L .77079 .48844 L 0 0 0 r
F
.77339 .47431 m .77312 .46943 L .77079 .48353 L F
.61074 .3987 m .60704 .40324 L .6085 .40559 L .039 .055 0 r
F
.61074 .3987 m .60924 .39642 L .60704 .40324 L F
.52567 .66053 m .51359 .66334 L .5126 .66433 L .102 0 0 r
F
.52567 .66053 m .52698 .65954 L .51359 .66334 L F
.55051 .61658 m .54004 .61831 L .53892 .6197 L .25 0 0 r
F
.55051 .61658 m .55183 .61515 L .54004 .61831 L F
.3519 .594 m .33848 .58725 L .33973 .58948 L 1 .218 0 r
F
.35306 .59614 m .3519 .594 L .33973 .58948 L 1 .191 0 r
F
.5382 .34177 m .53618 .34359 L .53863 .34486 L .243 .319 0 r
F
.5382 .34177 m .5357 .34076 L .53618 .34359 L F
.41086 .63134 m .39647 .62796 L .39771 .62946 L .892 .061 0 r
F
.41189 .63274 m .41086 .63134 L .39771 .62946 L .869 .057 0 r
F
.3369 .55281 m .32685 .54417 L .32754 .54661 L 1 .431 0 r
F
.33758 .55519 m .3369 .55281 L .32754 .54661 L 1 .402 0 r
F
.61296 .40058 m .60972 .40493 L .61119 .4073 L 0 .05 0 r
F
.61296 .40058 m .61143 .3983 L .60972 .40493 L F
.35718 .58293 m .34546 .57561 L .34654 .57776 L 1 .231 0 r
F
.35819 .585 m .35718 .58293 L .34654 .57776 L 1 .201 0 r
F
.80922 .76341 m .79294 .76947 L .78924 .77485 L 0 0 0 r
F
.80922 .76341 m .81321 .75783 L .79294 .76947 L F
.32186 .50611 m .31456 .49637 L .31454 .49899 L 1 .692 0 r
F
.32188 .50871 m .32186 .50611 L .31454 .49899 L 1 .667 0 r
F
.58602 .58982 m .57682 .59266 L .57565 .59454 L .111 0 0 r
F
.58602 .58982 m .5873 .58788 L .57682 .59266 L F
.4126 .62324 m .39904 .61919 L .40021 .62061 L .889 .06 0 r
F
.41358 .62457 m .4126 .62324 L .40021 .62061 L .863 .056 0 r
F
.32215 .88192 m .29381 .87413 L .29791 .87732 L .678 .026 0 r
F
.32571 .88485 m .32215 .88192 L .29791 .87732 L .644 .02 0 r
F
.63484 .47411 m .62898 .47897 L .6293 .48165 L 0 0 0 r
F
.63484 .47411 m .6345 .47142 L .62898 .47897 L F
.85899 .66559 m .84616 .67498 L .84363 .68115 L F
.85899 .66559 m .86164 .65924 L .84616 .67498 L F
.32891 .56595 m .31678 .55753 L .31772 .56009 L 1 .384 0 r
F
.32982 .56841 m .32891 .56595 L .31772 .56009 L 1 .357 0 r
F
.63118 .47161 m .62564 .47636 L .62595 .479 L 0 0 0 r
F
.63118 .47161 m .63088 .46898 L .62564 .47636 L F
.53586 .62866 m .52477 .62996 L .52377 .63122 L .303 0 0 r
F
.53586 .62866 m .53709 .62737 L .52477 .62996 L F
.60557 .56565 m .59724 .56916 L .59628 .57135 L .031 0 0 r
F
.60557 .56565 m .6066 .56341 L .59724 .56916 L F
.17956 .8037 m .15266 .78842 L .15685 .79366 L .902 .078 0 r
F
.1835 .80866 m .17956 .8037 L .15685 .79366 L .874 .073 0 r
F
.56084 .34606 m .56027 .34683 L .56243 .34877 L 0 .049 0 r
F
.49447 .63467 m .48212 .63451 L .48187 .63545 L .458 0 0 r
F
.49447 .63467 m .495 .63371 L .48212 .63451 L F
.73359 .36268 m .74706 .36496 L .74892 .36956 L .936 .087 0 r
F
.73359 .36268 m .73069 .35892 L .74706 .36496 L F
.33645 .62795 m .32227 .61943 L .32353 .62233 L 1 .29 0 r
F
.33769 .63069 m .33645 .62795 L .32353 .62233 L 1 .272 0 r
F
.54067 .34282 m .53863 .34486 L .54106 .34614 L .253 .334 0 r
F
.54067 .34282 m .5382 .34177 L .53863 .34486 L F
.36022 .65069 m .34446 .64419 L .34592 .64686 L 1 .187 0 r
F
.36161 .65315 m .36022 .65069 L .34592 .64686 L 1 .17 0 r
F
.62666 .53201 m .61912 .53621 L .6186 .53875 L 0 0 0 r
F
.62666 .53201 m .62722 .52944 L .61912 .53621 L F
.62343 .52825 m .61631 .53248 L .61581 .53497 L F
.62343 .52825 m .62396 .52573 L .61631 .53248 L F
.70482 .35205 m .70105 .36081 L .69979 .3663 L F
.75643 .57924 m .74778 .5871 L .74633 .59159 L F
.75643 .57924 m .7579 .57464 L .74778 .5871 L F
.61221 .40101 m .6085 .40559 L .60992 .40797 L .028 .052 0 r
F
.61221 .40101 m .61074 .3987 L .6085 .40559 L F
.57171 .34527 m .56992 .34829 L .57189 .35054 L 0 .062 0 r
F
.57171 .34527 m .56976 .34307 L .56992 .34829 L F
.60784 .57006 m .59923 .57349 L .59823 .57572 L .044 0 0 r
F
.60784 .57006 m .60893 .56778 L .59923 .57349 L F
.54083 .65426 m .52954 .65739 L .52827 .65849 L .043 0 0 r
F
.54083 .65426 m .54239 .65313 L .52954 .65739 L F
.91022 .53571 m .89818 .54787 L .89768 .55487 L 0 0 0 r
F
.91022 .53571 m .91074 .52856 L .89818 .54787 L F
.58754 .59451 m .57815 .59728 L .57695 .59919 L .118 0 0 r
F
.58754 .59451 m .58888 .59254 L .57815 .59728 L F
.69039 .27326 m .69359 .27418 L .69597 .27878 L .435 0 0 r
F
.68961 .27248 m .68998 .27264 L .69039 .27326 L F
.68998 .27264 m .69359 .27418 L .69039 .27326 L F
.68806 .27095 m .6887 .27133 L .68961 .27248 L F
.6887 .27133 m .69359 .27418 L .68961 .27248 L F
.69171 .27406 m .68806 .27095 L .69597 .27878 L 0 .024 0 r
F
.69171 .27406 m .69597 .27878 L .69812 .28352 L F
.69505 .27746 m .69171 .27406 L .69731 .28232 L 0 .019 0 r
F
.69789 .28306 m .69731 .28232 L .69812 .28352 L F
.69505 .27746 m .69731 .28232 L .69789 .28306 L F
.69505 .27746 m .69812 .28352 L .70004 .28838 L F
.69809 .28112 m .69505 .27746 L .69906 .28623 L 0 .013 0 r
F
.69973 .28724 m .69906 .28623 L .70004 .28838 L F
.69809 .28112 m .69906 .28623 L .69973 .28724 L F
.61446 .40289 m .61119 .4073 L .61262 .4097 L 0 .047 0 r
F
.61446 .40289 m .61296 .40058 L .61119 .4073 L F
.37765 .60285 m .36498 .5968 L .36623 .59866 L 1 .092 0 r
F
.37879 .60461 m .37765 .60285 L .36623 .59866 L 1 .088 0 r
F
.30851 .52263 m .29872 .51242 L .29906 .51527 L 1 .599 0 r
F
.30888 .52541 m .30851 .52263 L .29906 .51527 L 1 .575 0 r
F
.39181 .86772 m .36469 .86698 L .36745 .86965 L .669 .028 0 r
F
.39392 .87025 m .39181 .86772 L .36745 .86965 L .642 .023 0 r
F
.31286 .59289 m .30124 .5825 L .30207 .58559 L 1 .4 0 r
F
.31373 .59588 m .31286 .59289 L .30207 .58559 L 1 .379 0 r
F
.42819 .62905 m .41458 .62585 L .4156 .62709 L .808 .047 0 r
F
.42899 .63021 m .42819 .62905 L .4156 .62709 L .78 .042 0 r
F
.43779 .67787 m .42138 .6774 L .4224 .67896 L .661 .028 0 r
F
.43852 .6792 m .43779 .67787 L .4224 .67896 L .635 .024 0 r
F
.45364 .67745 m .43779 .67787 L .43852 .6792 L .516 .006 0 r
F
.41395 .91175 m .38644 .90785 L .38889 .91003 L .524 0 0 r
F
.41565 .91374 m .41395 .91175 L .38889 .91003 L .504 0 0 r
F
.29435 .5389 m .28646 .52725 L .28658 .5304 L 1 .548 0 r
F
.29454 .54203 m .29435 .5389 L .28658 .5304 L 1 .525 0 r
F
.65921 .50089 m .65797 .50706 L .65716 .51008 L .714 .175 0 r
F
.65921 .50089 m .66002 .49788 L .65797 .50706 L F
.55116 .62152 m .54064 .62325 L .53948 .62466 L .245 0 0 r
F
.55116 .62152 m .55253 .62006 L .54064 .62325 L F
.38254 .66498 m .36597 .66042 L .36748 .66281 L 1 .084 0 r
F
.38392 .66714 m .38254 .66498 L .36748 .66281 L 1 .082 0 r
F
.46901 .64203 m .46898 .64103 L .4557 .6412 L .574 .014 0 r
F
.48194 .64139 m .46898 .64103 L .46901 .64203 L .505 .004 0 r
F
.48194 .64139 m .4822 .6404 L .46898 .64103 L F
.46864 .67624 m .46861 .67525 L .45364 .67745 L .407 0 0 r
F
.48288 .67351 m .46861 .67525 L .46864 .67624 L .32 0 0 r
F
.48288 .67351 m .48321 .67261 L .46861 .67525 L F
.5077 .63778 m .4957 .63828 L .49517 .63932 L .4 0 0 r
F
.5077 .63778 m .5085 .63673 L .4957 .63828 L F
.75127 .81975 m .73421 .8241 L .72999 .82856 L 0 0 0 r
F
.75127 .81975 m .75589 .8151 L .73421 .8241 L F
.54173 .32192 m .54069 .32264 L .54289 .32511 L .016 .111 0 r
F
.54133 .32152 m .54207 .31949 L .54173 .32192 L .316 0 0 r
F
.54149 .32124 m .54133 .32152 L .54173 .32192 L .016 .111 0 r
F
.54392 .32287 m .54281 .32212 L .54289 .32511 L .066 .098 0 r
F
.54227 .32209 m .54173 .32192 L .54458 .32142 L .185 0 0 r
F
.54173 .32192 m .54207 .31949 L .54458 .32142 L .316 0 0 r
F
.54281 .32212 m .54149 .32124 L .54173 .32192 L .066 .098 0 r
F
.54281 .32212 m .54173 .32192 L .54289 .32511 L F
.54423 .32221 m .54281 .32212 L .54458 .32142 L .185 0 0 r
F
.54281 .32212 m .54227 .32209 L .54242 .32205 L F
.54281 .32212 m .54242 .32205 L .54458 .32142 L F
.54227 .32209 m .54114 .32203 L .54173 .32192 L F
.54133 .32152 m .5412 .32175 L .54173 .32192 L .016 .111 0 r
F
.5412 .32175 m .54069 .32264 L .54173 .32192 L F
.54114 .32203 m .54133 .32152 L .54173 .32192 L .316 0 0 r
F
.71813 .65067 m .70773 .6571 L .70542 .66096 L 0 0 0 r
F
.71813 .65067 m .72065 .64674 L .70773 .6571 L F
.5631 .34766 m .56243 .34877 L .5646 .35065 L 0 .068 0 r
F
.5631 .34766 m .56084 .34606 L .56243 .34877 L F
.63514 .4768 m .6293 .48165 L .62958 .48434 L 0 0 0 r
F
.63514 .4768 m .63484 .47411 L .6293 .48165 L F
.52039 .62952 m .50902 .6303 L .50825 .63137 L .356 0 0 r
F
.52039 .62952 m .5214 .62842 L .50902 .6303 L F
.64172 .5557 m .6367 .56168 L .63552 .56433 L 0 0 0 r
F
.64172 .5557 m .64289 .55299 L .6367 .56168 L F
.45596 .63451 m .44252 .63268 L .44309 .63371 L .669 .026 0 r
F
.45626 .63547 m .45596 .63451 L .44309 .63371 L .64 .021 0 r
F
.46906 .63572 m .45596 .63451 L .45626 .63547 L .59 .015 0 r
F
.32188 .50871 m .31454 .49899 L .31457 .50161 L 1 .667 0 r
F
.32195 .5113 m .32188 .50871 L .31457 .50161 L 1 .642 0 r
F
.42715 .63669 m .41293 .6341 L .414 .63542 L .807 .048 0 r
F
.42798 .63792 m .42715 .63669 L .414 .63542 L .782 .043 0 r
F
.61363 .40334 m .60992 .40797 L .6113 .41036 L .017 .048 0 r
F
.61363 .40334 m .61221 .40101 L .60992 .40797 L F
.63144 .47425 m .62595 .479 L .62621 .48163 L 0 0 0 r
F
.63144 .47425 m .63118 .47161 L .62595 .479 L F
.56663 .60678 m .55686 .60902 L .55564 .6106 L .178 0 0 r
F
.56663 .60678 m .56801 .60513 L .55686 .60902 L F
.8984 .36622 m .89153 .38123 L .8937 .38798 L 0 0 0 r
F
.8984 .36622 m .89615 .35947 L .89153 .38123 L F
.51508 .32842 m .51371 .32862 L .51618 .3302 L .039 .143 0 r
F
.51508 .32842 m .51235 .32814 L .51371 .32862 L F
.5965 .6182 m .58782 .62266 L .58616 .62453 L 0 0 0 r
F
.5965 .6182 m .5983 .61625 L .58782 .62266 L F
.80075 .75632 m .78581 .76306 L .78213 .76827 L F
.80075 .75632 m .80469 .75091 L .78581 .76306 L F
.44252 .63268 m .42899 .63021 L .4298 .63132 L .733 .035 0 r
F
.44309 .63371 m .44252 .63268 L .4298 .63132 L .705 .03 0 r
F
.61591 .40522 m .61262 .4097 L .61401 .41211 L 0 .044 0 r
F
.61591 .40522 m .61446 .40289 L .61262 .4097 L F
.18497 .79771 m .1588 .78248 L .16286 .78769 L .909 .08 0 r
F
.18879 .80263 m .18497 .79771 L .16286 .78769 L .881 .075 0 r
F
.57359 .3475 m .57189 .35054 L .57385 .35278 L 0 .056 0 r
F
.57359 .3475 m .57171 .34527 L .57189 .35054 L F
.33758 .55519 m .32754 .54661 L .32826 .54903 L 1 .402 0 r
F
.33829 .55754 m .33758 .55519 L .32826 .54903 L 1 .373 0 r
F
.82835 .2218 m .8268 .23703 L .83122 .24253 L 0 .047 0 r
F
.82835 .2218 m .82388 .2165 L .8268 .23703 L F
.82709 .22271 m .82653 .23722 L .83104 .24265 L 0 .048 0 r
F
.82709 .22271 m .82247 .21756 L .82653 .23722 L F
.29183 .84389 m .26357 .837 L .26767 .84068 L .849 .054 0 r
F
.29545 .84735 m .29183 .84389 L .26767 .84068 L .824 .05 0 r
F
.49462 .64031 m .4822 .6404 L .48194 .64139 L .445 0 0 r
F
.49462 .64031 m .49517 .63932 L .4822 .6404 L F
.67666 .43557 m .67817 .43168 L .6762 .44128 L .776 .199 0 r
F
.39407 .62486 m .37986 .62065 L .38123 .62232 L .957 .072 0 r
F
.39526 .62643 m .39407 .62486 L .38123 .62232 L .935 .068 0 r
F
.61104 .34115 m .67964 .28061 L .67607 .29046 L .583 .045 0 r
F
.61104 .34115 m .60373 .34421 L .67964 .28061 L F
.13568 .71845 m .11128 .7008 L .11439 .70668 L 1 .12 0 r
F
.13866 .72405 m .13568 .71845 L .11439 .70668 L 1 .11 0 r
F
.35545 .90041 m .32706 .89418 L .33081 .89691 L .599 .011 0 r
F
.35856 .90291 m .35545 .90041 L .33081 .89691 L .576 .005 0 r
F
.45404 .67856 m .45364 .67745 L .43852 .6792 L .485 0 0 r
F
.46864 .67624 m .45364 .67745 L .45404 .67856 L .407 0 0 r
F
.62286 .53075 m .61581 .53497 L .61527 .53743 L 0 0 0 r
F
.62286 .53075 m .62343 .52825 L .61581 .53497 L F
.51058 .66613 m .49793 .66867 L .49726 .66957 L .149 0 0 r
F
.51058 .66613 m .51159 .66526 L .49793 .66867 L F
.62606 .53457 m .6186 .53875 L .61803 .54127 L 0 0 0 r
F
.62606 .53457 m .62666 .53201 L .6186 .53875 L F
.56539 .34918 m .5646 .35065 L .5668 .35249 L 0 .081 0 r
F
.56539 .34918 m .5631 .34766 L .5646 .35065 L F
.37468 .6136 m .36074 .6083 L .36213 .61022 L 1 .088 0 r
F
.37593 .61542 m .37468 .6136 L .36213 .61022 L 1 .084 0 r
F
.67809 .69619 m .66751 .70261 L .66476 .70584 L 0 0 0 r
F
.67809 .69619 m .68117 .69298 L .66751 .70261 L F
.5342 .62485 m .52339 .62609 L .5224 .62728 L .298 0 0 r
F
.5342 .62485 m .53541 .62362 L .52339 .62609 L F
.35819 .585 m .34654 .57776 L .34765 .57989 L 1 .201 0 r
F
.35924 .58704 m .35819 .585 L .34765 .57989 L 1 .171 0 r
F
.89476 .36719 m .88782 .3821 L .8897 .38886 L 0 0 0 r
F
.89476 .36719 m .89286 .36041 L .88782 .3821 L F
.41488 .90476 m .38779 .90106 L .3902 .90322 L .521 0 0 r
F
.41656 .90671 m .41488 .90476 L .3902 .90322 L .501 0 0 r
F
.32982 .56841 m .31772 .56009 L .31871 .56263 L 1 .357 0 r
F
.33076 .57085 m .32982 .56841 L .31871 .56263 L 1 .33 0 r
F
.89741 .5341 m .88921 .54645 L .88849 .55326 L 0 0 0 r
F
.89741 .5341 m .89823 .52719 L .88921 .54645 L F
.51483 .32927 m .51335 .32991 L .51572 .33175 L .089 .119 0 r
F
.51483 .32927 m .51236 .32811 L .51335 .32991 L F
.61873 .59412 m .61146 .59929 L .60994 .60154 L 0 0 0 r
F
.61873 .59412 m .62033 .5918 L .61146 .59929 L F
.77358 .4792 m .77079 .48844 L .77072 .49334 L F
.77358 .4792 m .77339 .47431 L .77079 .48844 L F
.35306 .59614 m .33973 .58948 L .34103 .59169 L 1 .191 0 r
F
.35425 .59824 m .35306 .59614 L .34103 .59169 L 1 .164 0 r
F
.6045 .56786 m .59628 .57135 L .59529 .57351 L .021 0 0 r
F
.6045 .56786 m .60557 .56565 L .59628 .57135 L F
.61501 .40569 m .6113 .41036 L .61264 .41277 L .006 .045 0 r
F
.61501 .40569 m .61363 .40334 L .6113 .41036 L F
.5847 .59173 m .57565 .59454 L .57446 .59639 L .1 0 0 r
F
.5847 .59173 m .58602 .58982 L .57565 .59454 L F
.30888 .52541 m .29906 .51527 L .29946 .5181 L 1 .575 0 r
F
.30929 .52817 m .30888 .52541 L .29946 .5181 L 1 .55 0 r
F
.44195 .63984 m .42798 .63792 L .42882 .6391 L .728 .036 0 r
F
.44254 .64094 m .44195 .63984 L .42882 .6391 L .7 .031 0 r
F
.4557 .6412 m .44195 .63984 L .44254 .64094 L .658 .026 0 r
F
.63539 .47949 m .62958 .48434 L .62981 .48703 L 0 0 0 r
F
.63539 .47949 m .63514 .4768 L .62958 .48434 L F
.45601 .64223 m .4557 .6412 L .44254 .64094 L .63 .021 0 r
F
.46901 .64203 m .4557 .6412 L .45601 .64223 L .574 .014 0 r
F
.5676 .61162 m .55772 .61382 L .55647 .61544 L .177 0 0 r
F
.5676 .61162 m .56903 .60995 L .55772 .61382 L F
.61733 .40756 m .61401 .41211 L .61537 .41454 L 0 .041 0 r
F
.61733 .40756 m .61591 .40522 L .61401 .41211 L F
.39677 .61624 m .38363 .61133 L .38491 .61292 L .948 .072 0 r
F
.39789 .61773 m .39677 .61624 L .38491 .61292 L .923 .067 0 r
F
.54423 .32221 m .54458 .32142 L .54712 .32321 L .185 0 0 r
F
.73639 .36652 m .74892 .36956 L .75075 .37417 L .907 .088 0 r
F
.73639 .36652 m .73359 .36268 L .74892 .36956 L F
.49657 .67041 m .48321 .67261 L .48288 .67351 L .221 0 0 r
F
.49657 .67041 m .49726 .66957 L .48321 .67261 L F
.63166 .47688 m .62621 .48163 L .62643 .48427 L 0 0 0 r
F
.63166 .47688 m .63144 .47425 L .62621 .48163 L F
.60672 .57231 m .59823 .57572 L .59719 .57792 L .033 0 0 r
F
.60672 .57231 m .60784 .57006 L .59823 .57572 L F
.57542 .34976 m .57385 .35278 L .57578 .355 L 0 .049 0 r
F
.57542 .34976 m .57359 .3475 L .57385 .35278 L F
.32195 .5113 m .31457 .50161 L .31464 .50422 L 1 .642 0 r
F
.32206 .51389 m .32195 .5113 L .31464 .50422 L 1 .616 0 r
F
.74452 .81157 m .72846 .81658 L .72427 .82086 L 0 0 0 r
F
.74452 .81157 m .74908 .80709 L .72846 .81658 L F
.29454 .54203 m .28658 .5304 L .28674 .53356 L 1 .525 0 r
F
.29477 .54516 m .29454 .54203 L .28674 .53356 L 1 .502 0 r
F
.51766 .32922 m .51618 .3302 L .51862 .33178 L .19 .229 0 r
F
.51766 .32922 m .51508 .32842 L .51618 .3302 L F
.11971 .73792 m .09548 .71866 L .09883 .72482 L .997 .109 0 r
F
.12293 .7438 m .11971 .73792 L .09883 .72482 L .972 .104 0 r
F
.54916 .61798 m .53892 .6197 L .53777 .62105 L .237 0 0 r
F
.54916 .61798 m .55051 .61658 L .53892 .6197 L F
.52068 .63472 m .50929 .63563 L .5085 .63673 L .343 0 0 r
F
.52068 .63472 m .52173 .6336 L .50929 .63563 L F
.86699 .67725 m .85228 .68581 L .84966 .69212 L 0 0 0 r
F
.86699 .67725 m .86977 .67074 L .85228 .68581 L F
.24792 .82147 m .22002 .81186 L .22421 .81611 L .905 .066 0 r
F
.25172 .82547 m .24792 .82147 L .22421 .81611 L .881 .062 0 r
F
.42138 .6774 m .40473 .67596 L .40601 .67777 L .786 .047 0 r
F
.4224 .67896 m .42138 .6774 L .40601 .67777 L .765 .044 0 r
F
.5677 .35068 m .5668 .35249 L .56899 .3543 L 0 .089 0 r
F
.5677 .35068 m .56539 .34918 L .5668 .35249 L F
.65841 .50387 m .65716 .51008 L .65634 .51308 L .715 .175 0 r
F
.65841 .50387 m .65921 .50089 L .65716 .51008 L F
.35728 .89381 m .32933 .88768 L .333 .8904 L .605 .012 0 r
F
.36033 .89629 m .35728 .89381 L .333 .8904 L .579 .006 0 r
F
.58617 .59645 m .57695 .59919 L .57571 .60107 L .106 0 0 r
F
.58617 .59645 m .58754 .59451 L .57695 .59919 L F
.31373 .59588 m .30207 .58559 L .30296 .58866 L 1 .379 0 r
F
.31465 .59886 m .31373 .59588 L .30296 .58866 L 1 .358 0 r
F
.33769 .63069 m .32353 .62233 L .32482 .62522 L 1 .272 0 r
F
.33897 .63342 m .33769 .63069 L .32482 .62522 L 1 .254 0 r
F
.41358 .62457 m .40021 .62061 L .40141 .62199 L .863 .056 0 r
F
.41458 .62585 m .41358 .62457 L .40141 .62199 L .836 .051 0 r
F
.61634 .40806 m .61264 .41277 L .61394 .4152 L 0 .041 0 r
F
.61634 .40806 m .61501 .40569 L .61264 .41277 L F
.50668 .63337 m .495 .63371 L .49447 .63467 L .398 0 0 r
F
.50668 .63337 m .50747 .63239 L .495 .63371 L F
.41189 .63274 m .39771 .62946 L .39896 .63092 L .869 .057 0 r
F
.41293 .6341 m .41189 .63274 L .39896 .63092 L .845 .053 0 r
F
.37879 .60461 m .36623 .59866 L .36751 .60049 L 1 .088 0 r
F
.37996 .60634 m .37879 .60461 L .36751 .60049 L 1 .085 0 r
F
.70387 .35743 m .69979 .3663 L .69844 .37169 L 0 0 0 r
F
.70387 .35743 m .70482 .35205 L .69979 .3663 L F
.6187 .40994 m .61537 .41454 L .61669 .41698 L 0 .038 0 r
F
.6187 .40994 m .61733 .40756 L .61537 .41454 L F
.46909 .63663 m .46906 .63572 L .45626 .63547 L .56 .01 0 r
F
.48161 .63636 m .46906 .63572 L .46909 .63663 L .496 .001 0 r
F
.48161 .63636 m .48187 .63545 L .46906 .63572 L F
.38644 .90785 m .35856 .90291 L .36171 .9053 L .554 .001 0 r
F
.38889 .91003 m .38644 .90785 L .36171 .9053 L .535 0 0 r
F
.64053 .55838 m .63552 .56433 L .63431 .56696 L 0 0 0 r
F
.64053 .55838 m .64172 .5557 L .63552 .56433 L F
.75487 .58381 m .74633 .59159 L .74481 .59605 L F
.75487 .58381 m .75643 .57924 L .74633 .59159 L F
.51701 .33135 m .51572 .33175 L .51807 .33351 L 0 .059 0 r
F
.51701 .33135 m .51483 .32927 L .51572 .33175 L F
.33829 .55754 m .32826 .54903 L .32903 .55143 L 1 .373 0 r
F
.33905 .55988 m .33829 .55754 L .32903 .55143 L 1 .342 0 r
F
.53461 .62991 m .52377 .63122 L .52276 .63243 L .289 0 0 r
F
.53461 .62991 m .53586 .62866 L .52377 .63122 L F
.62225 .53324 m .61527 .53743 L .61468 .53988 L 0 0 0 r
F
.62225 .53324 m .62286 .53075 L .61527 .53743 L F
.36161 .65315 m .34592 .64686 L .34742 .64951 L 1 .17 0 r
F
.36303 .65559 m .36161 .65315 L .34742 .64951 L 1 .155 0 r
F
.57 .35219 m .56899 .3543 L .57118 .3561 L 0 .093 0 r
F
.57 .35219 m .5677 .35068 L .56899 .3543 L F
.62541 .53712 m .61803 .54127 L .61741 .54377 L 0 0 0 r
F
.62541 .53712 m .62606 .53457 L .61803 .54127 L F
.5772 .35204 m .57578 .355 L .57769 .35721 L 0 .042 0 r
F
.5772 .35204 m .57542 .34976 L .57578 .355 L F
.63559 .48219 m .62981 .48703 L .62999 .48972 L 0 0 0 r
F
.63559 .48219 m .63539 .47949 L .62981 .48703 L F
.40347 .67412 m .38675 .67138 L .38821 .67347 L .905 .065 0 r
F
.40473 .67596 m .40347 .67412 L .38821 .67347 L .889 .063 0 r
F
.54717 .32276 m .54712 .32321 L .54963 .325 L 0 .126 0 r
F
.54717 .32276 m .54423 .32221 L .54712 .32321 L F
.63183 .47952 m .62643 .48427 L .6266 .4869 L 0 0 0 r
F
.63183 .47952 m .63166 .47688 L .62643 .48427 L F
.52009 .33045 m .51862 .33178 L .52101 .33341 L .179 .201 0 r
F
.52009 .33045 m .51766 .32922 L .51862 .33178 L F
.49394 .63558 m .48187 .63545 L .48161 .63636 L .444 0 0 r
F
.49394 .63558 m .49447 .63467 L .48187 .63545 L F
.67518 .43937 m .67666 .43557 L .67504 .44504 L .794 .202 0 r
F
.52434 .66147 m .5126 .66433 L .51159 .66526 L .07 0 0 r
F
.52434 .66147 m .52567 .66053 L .5126 .66433 L F
.30929 .52817 m .29946 .5181 L .2999 .52092 L 1 .55 0 r
F
.30975 .53092 m .30929 .52817 L .2999 .52092 L 1 .524 0 r
F
.61763 .41045 m .61394 .4152 L .61519 .41764 L 0 .038 0 r
F
.61763 .41045 m .61634 .40806 L .61394 .4152 L F
.32206 .51389 m .31464 .50422 L .31475 .50683 L 1 .616 0 r
F
.32222 .51647 m .32206 .51389 L .31475 .50683 L 1 .589 0 r
F
.54977 .62294 m .53948 .62466 L .53829 .62604 L .231 0 0 r
F
.54977 .62294 m .55116 .62152 L .53948 .62466 L F
.54392 .32287 m .54289 .32511 L .545 .32762 L .066 .098 0 r
F
.28275 .87382 m .25433 .86424 L .25887 .86791 L .713 .034 0 r
F
.2868 .87722 m .28275 .87382 L .25887 .86791 L .679 .028 0 r
F
.33076 .57085 m .31871 .56263 L .31974 .56515 L 1 .33 0 r
F
.33175 .57327 m .33076 .57085 L .31974 .56515 L 1 .303 0 r
F
.56522 .60839 m .55564 .6106 L .5544 .61216 L .165 0 0 r
F
.56522 .60839 m .56663 .60678 L .55564 .6106 L F
.33084 .85856 m .30289 .85401 L .30671 .85721 L .784 .043 0 r
F
.3341 .86157 m .33084 .85856 L .30671 .85721 L .758 .038 0 r
F
.12709 .73251 m .10378 .7134 L .10697 .71948 L 1 .11 0 r
F
.13018 .73832 m .12709 .73251 L .10697 .71948 L .975 .106 0 r
F
.60339 .57005 m .59529 .57351 L .59425 .57564 L .01 0 0 r
F
.60339 .57005 m .6045 .56786 L .59529 .57351 L F
.62004 .41233 m .61669 .41698 L .61797 .41945 L 0 .035 0 r
F
.62004 .41233 m .6187 .40994 L .61669 .41698 L F
.35924 .58704 m .34765 .57989 L .34879 .58199 L 1 .171 0 r
F
.36032 .58905 m .35924 .58704 L .34879 .58199 L 1 .14 0 r
F
.42899 .63021 m .4156 .62709 L .41664 .6283 L .78 .042 0 r
F
.4298 .63132 m .42899 .63021 L .41664 .6283 L .751 .037 0 r
F
.90957 .54285 m .89768 .55487 L .89706 .56186 L 0 0 0 r
F
.90957 .54285 m .91022 .53571 L .89768 .55487 L F
.85622 .6719 m .84363 .68115 L .84099 .68726 L F
.85622 .6719 m .85899 .66559 L .84363 .68115 L F
.29477 .54516 m .28674 .53356 L .28696 .53671 L 1 .502 0 r
F
.29505 .54829 m .29477 .54516 L .28696 .53671 L 1 .478 0 r
F
.57228 .35371 m .57118 .3561 L .57336 .35791 L 0 .095 0 r
F
.57228 .35371 m .57 .35219 L .57118 .3561 L F
.38779 .90106 m .36033 .89629 L .36343 .89866 L .555 .002 0 r
F
.3902 .90322 m .38779 .90106 L .36343 .89866 L .535 0 0 r
F
.19666 .78477 m .16991 .77176 L .17386 .77673 L .967 .084 0 r
F
.20034 .78947 m .19666 .78477 L .17386 .77673 L .944 .08 0 r
F
.59467 .62011 m .58616 .62453 L .58446 .62636 L 0 0 0 r
F
.59467 .62011 m .5965 .6182 L .58616 .62453 L F
.35425 .59824 m .34103 .59169 L .34236 .59387 L 1 .164 0 r
F
.35548 .60031 m .35425 .59824 L .34236 .59387 L 1 .137 0 r
F
.53925 .65534 m .52827 .65849 L .52698 .65954 L .013 0 0 r
F
.53925 .65534 m .54083 .65426 L .52827 .65849 L F
.71553 .65455 m .70542 .66096 L .70303 .66476 L 0 0 0 r
F
.71553 .65455 m .71813 .65067 L .70542 .66096 L F
.77367 .4841 m .77072 .49334 L .77058 .49823 L F
.77367 .4841 m .77358 .4792 L .77072 .49334 L F
.60556 .57455 m .59719 .57792 L .59612 .58009 L .022 0 0 r
F
.60556 .57455 m .60672 .57231 L .59719 .57792 L F
.5185 .33534 m .51807 .33351 L .52047 .33501 L .732 .093 0 r
F
.5185 .33534 m .51701 .33135 L .51807 .33351 L F
.51935 .63057 m .50825 .63137 L .50747 .63239 L .341 0 0 r
F
.51935 .63057 m .52039 .62952 L .50825 .63137 L F
.57893 .35434 m .57769 .35721 L .57958 .3594 L 0 .034 0 r
F
.57893 .35434 m .5772 .35204 L .57769 .35721 L F
.38392 .66714 m .36748 .66281 L .36903 .66519 L 1 .082 0 r
F
.38532 .66927 m .38392 .66714 L .36903 .66519 L .997 .08 0 r
F
.6171 .59641 m .60994 .60154 L .60837 .60375 L 0 0 0 r
F
.6171 .59641 m .61873 .59412 L .60994 .60154 L F
.58335 .5936 m .57446 .59639 L .57323 .5982 L .089 0 0 r
F
.58335 .5936 m .5847 .59173 L .57446 .59639 L F
.37593 .61542 m .36213 .61022 L .36356 .61211 L 1 .084 0 r
F
.37721 .6172 m .37593 .61542 L .36356 .61211 L .999 .081 0 r
F
.65761 .50684 m .65634 .51308 L .65551 .51606 L .715 .176 0 r
F
.65761 .50684 m .65841 .50387 L .65634 .51308 L F
.23701 .84856 m .20911 .83661 L .2137 .84096 L .788 .051 0 r
F
.24122 .85262 m .23701 .84856 L .2137 .84096 L .756 .046 0 r
F
.50688 .63879 m .49517 .63932 L .49462 .64031 L .384 0 0 r
F
.50688 .63879 m .5077 .63778 L .49517 .63932 L F
.90053 .37302 m .8937 .38798 L .89576 .39477 L 0 0 0 r
F
.90053 .37302 m .8984 .36622 L .8937 .38798 L F
.73908 .37043 m .75075 .37417 L .75253 .37879 L .876 .088 0 r
F
.73908 .37043 m .73639 .36652 L .75075 .37417 L F
.46904 .64299 m .46901 .64203 L .45601 .64223 L .544 .008 0 r
F
.48168 .64234 m .46901 .64203 L .46904 .64299 L .48 0 0 r
F
.48168 .64234 m .48194 .64139 L .46901 .64203 L F
.42798 .63792 m .414 .63542 L .41508 .6367 L .782 .043 0 r
F
.42882 .6391 m .42798 .63792 L .41508 .6367 L .755 .038 0 r
F
.39526 .62643 m .38123 .62232 L .38263 .62396 L .935 .068 0 r
F
.39647 .62796 m .39526 .62643 L .38263 .62396 L .912 .064 0 r
F
.45626 .63547 m .44309 .63371 L .44366 .6347 L .64 .021 0 r
F
.45657 .63639 m .45626 .63547 L .44366 .6347 L .61 .016 0 r
F
.46909 .63663 m .45626 .63547 L .45657 .63639 L .56 .01 0 r
F
.63574 .48488 m .62999 .48972 L .63013 .4924 L 0 0 0 r
F
.63574 .48488 m .63559 .48219 L .62999 .48972 L F
.61887 .41286 m .61519 .41764 L .6164 .4201 L 0 .034 0 r
F
.61887 .41286 m .61763 .41045 L .61519 .41764 L F
.54998 .3236 m .54717 .32276 L .54963 .325 L .049 .131 0 r
F
.5223 .33225 m .52009 .33045 L .52101 .33341 L .03 .084 0 r
F
.63195 .48215 m .6266 .4869 L .62673 .48953 L 0 0 0 r
F
.63195 .48215 m .63183 .47952 L .6266 .4869 L F
.44309 .63371 m .4298 .63132 L .43062 .6324 L .705 .03 0 r
F
.44366 .6347 m .44309 .63371 L .43062 .6324 L .674 .025 0 r
F
.83272 .22719 m .82835 .2218 L .83122 .24253 L 0 .042 0 r
F
.83161 .22797 m .83104 .24265 L .83545 .24816 L 0 .044 0 r
F
.83161 .22797 m .82709 .22271 L .83104 .24265 L F
.80511 .76893 m .78924 .77485 L .78542 .78016 L 0 0 0 r
F
.80511 .76893 m .80922 .76341 L .78924 .77485 L F
.62133 .41474 m .61797 .41945 L .61921 .42192 L 0 .031 0 r
F
.62133 .41474 m .62004 .41233 L .61797 .41945 L F
.62159 .53572 m .61468 .53988 L .61406 .54232 L 0 0 0 r
F
.62159 .53572 m .62225 .53324 L .61468 .53988 L F
.2858 .86745 m .25791 .85792 L .26234 .86158 L .723 .035 0 r
F
.28977 .87084 m .2858 .86745 L .26234 .86158 L .689 .03 0 r
F
.56614 .61326 m .55647 .61544 L .55518 .61702 L .164 0 0 r
F
.56614 .61326 m .5676 .61162 L .55647 .61544 L F
.33905 .55988 m .32903 .55143 L .32985 .55382 L 1 .342 0 r
F
.33985 .56219 m .33905 .55988 L .32985 .55382 L 1 .312 0 r
F
.57455 .35526 m .57336 .35791 L .57553 .35972 L .015 .095 0 r
F
.57455 .35526 m .57228 .35371 L .57336 .35791 L F
.62471 .53965 m .61741 .54377 L .61676 .54626 L 0 0 0 r
F
.62471 .53965 m .62541 .53712 L .61741 .54377 L F
.53297 .62603 m .5224 .62728 L .5214 .62842 L .284 0 0 r
F
.53297 .62603 m .5342 .62485 L .5224 .62728 L F
.39789 .61773 m .38491 .61292 L .38622 .61448 L .923 .067 0 r
F
.39904 .61919 m .39789 .61773 L .38622 .61448 L .896 .063 0 r
F
.31465 .59886 m .30296 .58866 L .30389 .59174 L 1 .358 0 r
F
.31561 .60183 m .31465 .59886 L .30389 .59174 L 1 .338 0 r
F
.89651 .37403 m .8897 .38886 L .89145 .39564 L 0 0 0 r
F
.89651 .37403 m .89476 .36719 L .8897 .38886 L F
.32222 .51647 m .31475 .50683 L .31492 .50943 L 1 .589 0 r
F
.32242 .51904 m .32222 .51647 L .31492 .50943 L 1 .562 0 r
F
.43852 .6792 m .4224 .67896 L .42344 .68049 L .635 .024 0 r
F
.43925 .68048 m .43852 .6792 L .42344 .68049 L .608 .02 0 r
F
.45404 .67856 m .43852 .6792 L .43925 .68048 L .485 0 0 r
F
.58476 .59836 m .57571 .60107 L .57444 .60292 L .094 0 0 r
F
.58476 .59836 m .58617 .59645 L .57571 .60107 L F
.63929 .56105 m .63431 .56696 L .63307 .56957 L 0 0 0 r
F
.63929 .56105 m .64053 .55838 L .63431 .56696 L F
.49407 .64126 m .48194 .64139 L .48168 .64234 L .429 0 0 r
F
.49407 .64126 m .49462 .64031 L .48194 .64139 L F
.46868 .67718 m .46864 .67624 L .45404 .67856 L .383 0 0 r
F
.48255 .67436 m .46864 .67624 L .46868 .67718 L .29 0 0 r
F
.48255 .67436 m .48288 .67351 L .46864 .67624 L F
.54618 .32481 m .545 .32762 L .54703 .33017 L .066 .084 0 r
F
.54618 .32481 m .54392 .32287 L .545 .32762 L F
.30975 .53092 m .2999 .52092 L .30038 .52374 L 1 .524 0 r
F
.31025 .53366 m .30975 .53092 L .30038 .52374 L 1 .498 0 r
F
.58062 .35663 m .57958 .3594 L .58146 .36158 L 0 .027 0 r
F
.58062 .35663 m .57893 .35434 L .57958 .3594 L F
.89649 .54099 m .88849 .55326 L .88766 .56006 L 0 0 0 r
F
.89649 .54099 m .89741 .5341 L .88849 .55326 L F
.54779 .61934 m .53777 .62105 L .5366 .62235 L .223 0 0 r
F
.54779 .61934 m .54916 .61798 L .53777 .62105 L F
.52134 .33503 m .52047 .33501 L .52295 .33617 L 0 0 0 r
F
.52134 .33503 m .5185 .33534 L .52047 .33501 L F
.37996 .60634 m .36751 .60049 L .36883 .60228 L 1 .085 0 r
F
.38116 .60804 m .37996 .60634 L .36883 .60228 L .979 .08 0 r
F
.33897 .63342 m .32482 .62522 L .32616 .6281 L 1 .254 0 r
F
.34028 .63613 m .33897 .63342 L .32616 .6281 L 1 .237 0 r
F
.62007 .41529 m .6164 .4201 L .61757 .42258 L 0 .03 0 r
F
.62007 .41529 m .61887 .41286 L .6164 .4201 L F
.24099 .84231 m .21368 .8304 L .21815 .83473 L .797 .052 0 r
F
.2451 .84635 m .24099 .84231 L .21815 .83473 L .765 .047 0 r
F
.1835 .80866 m .15685 .79366 L .16115 .79883 L .874 .073 0 r
F
.18753 .81353 m .1835 .80866 L .16115 .79883 L .845 .069 0 r
F
.57678 .35685 m .57553 .35972 L .57767 .36154 L .026 .094 0 r
F
.57678 .35685 m .57455 .35526 L .57553 .35972 L F
.44254 .64094 m .42882 .6391 L .42968 .64024 L .7 .031 0 r
F
.44314 .642 m .44254 .64094 L .42968 .64024 L .671 .026 0 r
F
.45601 .64223 m .44254 .64094 L .44314 .642 L .63 .021 0 r
F
.70276 .36277 m .69844 .37169 L .69702 .37697 L 0 0 0 r
F
.70276 .36277 m .70387 .35743 L .69844 .37169 L F
.67372 .44309 m .67518 .43937 L .67391 .44873 L .812 .205 0 r
F
.62258 .41717 m .61921 .42192 L .62041 .42442 L 0 .028 0 r
F
.62258 .41717 m .62133 .41474 L .61921 .42192 L F
.29505 .54829 m .28696 .53671 L .28722 .53987 L 1 .478 0 r
F
.29538 .55142 m .29505 .54829 L .28722 .53987 L 1 .455 0 r
F
.33175 .57327 m .31974 .56515 L .32081 .56764 L 1 .303 0 r
F
.33277 .57566 m .33175 .57327 L .32081 .56764 L 1 .275 0 r
F
.67493 .69932 m .66476 .70584 L .66193 .70898 L 0 0 0 r
F
.67493 .69932 m .67809 .69619 L .66476 .70584 L F
.45633 .64321 m .45601 .64223 L .44314 .642 L .599 .015 0 r
F
.46904 .64299 m .45601 .64223 L .45633 .64321 L .544 .008 0 r
F
.63584 .48758 m .63013 .4924 L .63023 .49509 L 0 0 0 r
F
.63584 .48758 m .63574 .48488 L .63013 .4924 L F
.60224 .57222 m .59425 .57564 L .59319 .57775 L F
.60224 .57222 m .60339 .57005 L .59425 .57564 L F
.41458 .62585 m .40141 .62199 L .40262 .62333 L .836 .051 0 r
F
.4156 .62709 m .41458 .62585 L .40262 .62333 L .807 .047 0 r
F
.51961 .6358 m .5085 .63673 L .5077 .63778 L .327 0 0 r
F
.51961 .6358 m .52068 .63472 L .5085 .63673 L F
.63203 .48479 m .62673 .48953 L .62682 .49216 L 0 0 0 r
F
.63203 .48479 m .63195 .48215 L .62673 .48953 L F
.55268 .32468 m .5521 .32682 L .55451 .32869 L .713 .217 0 r
F
.61792 .33883 m .67607 .29046 L .67485 .29777 L .591 .044 0 r
F
.61792 .33883 m .61104 .34115 L .67607 .29046 L F
.75323 .58836 m .74481 .59605 L .74322 .60048 L 0 0 0 r
F
.75323 .58836 m .75487 .58381 L .74481 .59605 L F
.41293 .6341 m .39896 .63092 L .40025 .63233 L .845 .053 0 r
F
.414 .63542 m .41293 .6341 L .40025 .63233 L .819 .048 0 r
F
.50955 .66695 m .49726 .66957 L .49657 .67041 L .113 0 0 r
F
.50955 .66695 m .51058 .66613 L .49726 .66957 L F
.36032 .58905 m .34879 .58199 L .34998 .58407 L 1 .14 0 r
F
.36144 .59103 m .36032 .58905 L .34998 .58407 L 1 .111 0 r
F
.13866 .72405 m .11439 .70668 L .11761 .71251 L 1 .11 0 r
F
.14174 .7296 m .13866 .72405 L .11761 .71251 L 1 .107 0 r
F
.45443 .67964 m .45404 .67856 L .43925 .68048 L .466 0 0 r
F
.46868 .67718 m .45404 .67856 L .45443 .67964 L .383 0 0 r
F
.6568 .5098 m .65551 .51606 L .65467 .51901 L .715 .176 0 r
F
.6568 .5098 m .65761 .50684 L .65551 .51606 L F
.79669 .76165 m .78213 .76827 L .77834 .7734 L 0 0 0 r
F
.79669 .76165 m .80075 .75632 L .78213 .76827 L F
.58228 .35891 m .58146 .36158 L .58333 .36375 L 0 .021 0 r
F
.58228 .35891 m .58062 .35663 L .58146 .36158 L F
.50588 .63431 m .49447 .63467 L .49394 .63558 L .383 0 0 r
F
.50588 .63431 m .50668 .63337 L .49447 .63467 L F
.60435 .57675 m .59612 .58009 L .595 .58224 L .011 0 0 r
F
.60435 .57675 m .60556 .57455 L .59612 .58009 L F
.62089 .53818 m .61406 .54232 L .6134 .54474 L 0 0 0 r
F
.62089 .53818 m .62159 .53572 L .61406 .54232 L F
.62122 .41774 m .61757 .42258 L .61869 .42507 L 0 .026 0 r
F
.62122 .41774 m .62007 .41529 L .61757 .42258 L F
.32242 .51904 m .31492 .50943 L .31513 .51203 L 1 .562 0 r
F
.32267 .52161 m .32242 .51904 L .31513 .51203 L 1 .534 0 r
F
.56379 .60996 m .5544 .61216 L .55313 .61367 L .152 0 0 r
F
.56379 .60996 m .56522 .60839 L .5544 .61216 L F
.57899 .35848 m .57767 .36154 L .5798 .36339 L .032 .093 0 r
F
.57899 .35848 m .57678 .35685 L .57767 .36154 L F
.53334 .63111 m .52276 .63243 L .52173 .6336 L .273 0 0 r
F
.53334 .63111 m .53461 .62991 L .52276 .63243 L F
.36303 .65559 m .34742 .64951 L .34896 .65215 L 1 .155 0 r
F
.36448 .65801 m .36303 .65559 L .34896 .65215 L 1 .14 0 r
F
.35548 .60031 m .34236 .59387 L .34373 .59603 L 1 .137 0 r
F
.35675 .60236 m .35548 .60031 L .34373 .59603 L 1 .11 0 r
F
.62397 .54217 m .61676 .54626 L .61606 .54873 L 0 0 0 r
F
.62397 .54217 m .62471 .53965 L .61676 .54626 L F
.74167 .37442 m .75253 .37879 L .75425 .38342 L .846 .089 0 r
F
.74167 .37442 m .73908 .37043 L .75253 .37879 L F
.46912 .63749 m .46909 .63663 L .45657 .63639 L .53 .004 0 r
F
.48135 .63722 m .46909 .63663 L .46912 .63749 L .479 0 0 r
F
.48135 .63722 m .48161 .63636 L .46909 .63663 L F
.33985 .56219 m .32985 .55382 L .3307 .55618 L 1 .312 0 r
F
.34069 .56449 m .33985 .56219 L .3307 .55618 L 1 .281 0 r
F
.62379 .41962 m .62041 .42442 L .62157 .42693 L 0 .024 0 r
F
.62379 .41962 m .62258 .41717 L .62041 .42442 L F
.58197 .59545 m .57323 .5982 L .57197 .59999 L .077 0 0 r
F
.58197 .59545 m .58335 .5936 L .57323 .5982 L F
.86408 .68372 m .84966 .69212 L .84693 .69837 L 0 0 0 r
F
.86408 .68372 m .86699 .67725 L .84966 .69212 L F
.32337 .89134 m .29511 .88372 L .29937 .88681 L .635 .018 0 r
F
.32706 .89418 m .32337 .89134 L .29937 .88681 L .608 .012 0 r
F
.49588 .6712 m .48288 .67351 L .48255 .67436 L .187 0 0 r
F
.49588 .6712 m .49657 .67041 L .48288 .67351 L F
.77368 .48899 m .77058 .49823 L .77037 .50311 L 0 0 0 r
F
.77368 .48899 m .77367 .4841 L .77058 .49823 L F
.54835 .62432 m .53829 .62604 L .53709 .62737 L .216 0 0 r
F
.54835 .62432 m .54977 .62294 L .53829 .62604 L F
.4224 .67896 m .40601 .67777 L .4073 .67955 L .765 .044 0 r
F
.42344 .68049 m .4224 .67896 L .4073 .67955 L .745 .04 0 r
F
.18879 .80263 m .16286 .78769 L .16702 .79281 L .881 .075 0 r
F
.19271 .80746 m .18879 .80263 L .16702 .79281 L .852 .07 0 r
F
.74655 .82431 m .72999 .82856 L .72568 .83293 L 0 0 0 r
F
.74655 .82431 m .75127 .81975 L .72999 .82856 L F
.61543 .59867 m .60837 .60375 L .60678 .60592 L F
.61543 .59867 m .6171 .59641 L .60837 .60375 L F
.54826 .32703 m .54618 .32481 L .54703 .33017 L .033 .068 0 r
F
.31025 .53366 m .30038 .52374 L .30092 .52654 L 1 .498 0 r
F
.3108 .53638 m .31025 .53366 L .30092 .52654 L 1 .472 0 r
F
.59281 .62198 m .58446 .62636 L .58274 .62814 L 0 0 0 r
F
.59281 .62198 m .59467 .62011 L .58446 .62636 L F
.37721 .6172 m .36356 .61211 L .36502 .61396 L .999 .081 0 r
F
.37852 .61894 m .37721 .6172 L .36502 .61396 L .977 .077 0 r
F
.6359 .49027 m .63023 .49509 L .63027 .49777 L 0 0 0 r
F
.6359 .49027 m .63584 .48758 L .63023 .49509 L F
.36469 .86698 m .33742 .8645 L .3408 .86733 L .715 .033 0 r
F
.36745 .86965 m .36469 .86698 L .3408 .86733 L .688 .028 0 r
F
.12293 .7438 m .09883 .72482 L .1023 .73092 L .972 .104 0 r
F
.12627 .74962 m .12293 .7438 L .1023 .73092 L .947 .1 0 r
F
.63207 .48742 m .62682 .49216 L .62686 .49478 L 0 0 0 r
F
.63207 .48742 m .63203 .48479 L .62682 .49216 L F
.31561 .60183 m .30389 .59174 L .30486 .59481 L 1 .338 0 r
F
.31661 .60479 m .31561 .60183 L .30486 .59481 L 1 .318 0 r
F
.55527 .32596 m .55451 .32869 L .55687 .33061 L .127 .132 0 r
F
.55527 .32596 m .55268 .32468 L .55451 .32869 L F
.4934 .63645 m .48161 .63636 L .48135 .63722 L .428 0 0 r
F
.4934 .63645 m .49394 .63558 L .48161 .63636 L F
.4298 .63132 m .41664 .6283 L .41769 .62946 L .751 .037 0 r
F
.43062 .6324 m .4298 .63132 L .41769 .62946 L .721 .032 0 r
F
.63802 .56369 m .63307 .56957 L .63179 .57214 L 0 0 0 r
F
.63802 .56369 m .63929 .56105 L .63307 .56957 L F
.58116 .36014 m .5798 .36339 L .58189 .36525 L .033 .091 0 r
F
.58116 .36014 m .57899 .35848 L .5798 .36339 L F
.58396 .36115 m .58333 .36375 L .5852 .3659 L 0 .018 0 r
F
.58566 .36332 m .58396 .36115 L .58398 .36123 L 0 .019 0 r
F
.58566 .36332 m .58398 .36123 L .5852 .3659 L F
.58735 .36586 m .58566 .36332 L .58705 .36804 L 0 .024 0 r
F
.58701 .36494 m .58566 .36332 L .58739 .36556 L F
.58747 .36537 m .58709 .36504 L .58739 .36556 L .023 .083 0 r
F
.58741 .36543 m .58709 .36504 L .58739 .36556 L 0 .024 0 r
F
.58709 .36504 m .58701 .36494 L .58739 .36556 L F
.58739 .36556 m .58716 .36527 L .58735 .36586 L F
.58716 .36527 m .58566 .36332 L .58735 .36586 L F
.58566 .36332 m .5852 .3659 L .58705 .36804 L 0 .019 0 r
F
.58739 .36556 m .5854 .36359 L .586 .36906 L .023 .083 0 r
F
.58709 .36504 m .5854 .36359 L .58739 .36556 L F
.58732 .36539 m .58682 .36477 L .58741 .36543 L 1 .23 0 r
F
.58682 .36477 m .58566 .36332 L .58709 .36504 L F
.58682 .36477 m .58709 .36504 L .58741 .36543 L F
.58559 .36328 m .58396 .36115 L .58566 .36332 L 1 .486 0 r
F
.58516 .36301 m .58396 .36115 L .58559 .36328 L F
.58396 .36115 m .5823 .35899 L .58333 .36375 L 0 .018 0 r
F
.5833 .36185 m .58116 .36014 L .58189 .36525 L .032 .088 0 r
F
.58259 .36029 m .58116 .36014 L .5833 .36185 L 0 .085 0 r
F
.58085 .35649 m .58103 .35866 L .58259 .36029 L F
.58103 .35866 m .58116 .36014 L .58259 .36029 L F
.58396 .36115 m .58228 .35891 L .5823 .35899 L 0 .018 0 r
F
.58078 .35251 m .58062 .35663 L .58228 .35891 L 0 0 0 r
F
.58164 .35559 m .58228 .35891 L .58396 .36115 L F
.58164 .35559 m .58078 .35251 L .58228 .35891 L F
.58322 .36095 m .58085 .35649 L .5833 .36185 L 0 .08 0 r
F
.58322 .36095 m .58164 .35559 L .58396 .36115 L 1 .486 0 r
F
.58144 .35692 m .58164 .35559 L .58322 .36095 L F
.58298 .35805 m .58144 .35692 L .58322 .36095 L 0 .08 0 r
F
.58144 .35692 m .58085 .35649 L .58322 .36095 L F
.57868 .35498 m .57899 .35848 L .58116 .36014 L 0 .089 0 r
F
.57953 .34981 m .57893 .35434 L .58062 .35663 L 0 .01 0 r
F
.58078 .35251 m .57953 .34981 L .58062 .35663 L 0 0 0 r
F
.58085 .35649 m .57868 .35498 L .58116 .36014 L 0 .085 0 r
F
.58091 .36033 m .58144 .35692 L .58322 .36095 L 1 .486 0 r
F
.58091 .36033 m .58322 .36095 L .58516 .36301 L F
.58521 .36315 m .5833 .36185 L .5854 .36359 L 0 .08 0 r
F
.58538 .36331 m .5854 .36359 L .58709 .36504 L 0 .076 0 r
F
.5833 .36185 m .58189 .36525 L .58396 .36714 L .032 .088 0 r
F
.5854 .36359 m .58396 .36714 L .586 .36906 L .029 .086 0 r
F
.5854 .36359 m .5833 .36185 L .58396 .36714 L F
.58506 .35967 m .58298 .35805 L .58515 .363 L 0 .076 0 r
F
.58538 .36331 m .58515 .363 L .5854 .36359 L F
.58506 .35967 m .58515 .363 L .58538 .36331 L F
.58515 .363 m .58491 .36285 L .58521 .36315 L 0 .08 0 r
F
.58491 .36285 m .5833 .36185 L .58521 .36315 L F
.58176 .36319 m .58091 .36033 L .58515 .363 L 1 .23 0 r
F
.58538 .36331 m .58515 .363 L .58566 .36332 L F
.58176 .36319 m .58515 .363 L .58538 .36331 L F
.58176 .36319 m .58538 .36331 L .58732 .36539 L F
.58538 .36331 m .58566 .36332 L .58672 .36464 L F
.58538 .36331 m .58672 .36464 L .58732 .36539 L F
.58365 .3614 m .58327 .36096 L .58456 .36236 L 1 .486 0 r
F
.58322 .36095 m .58327 .36096 L .58365 .3614 L F
.58322 .36095 m .58456 .36236 L .58516 .36301 L F
.58327 .36096 m .58396 .36115 L .58516 .36301 L F
.58298 .35805 m .58322 .36095 L .58515 .363 L 0 .08 0 r
F
.58322 .36095 m .5833 .36185 L .58515 .363 L F
.58322 .36095 m .58322 .36095 L .58365 .3614 L 1 .486 0 r
F
.58506 .35967 m .58537 .36324 L .58709 .36504 L 0 .076 0 r
F
.58537 .36324 m .58538 .36331 L .5863 .36424 L F
.58537 .36324 m .5863 .36424 L .58709 .36504 L F
.58634 .3627 m .58709 .36504 L .58747 .36537 L F
.58506 .35967 m .58709 .36504 L .58634 .3627 L F
.58759 .36598 m .58705 .36804 L .5889 .37016 L 0 .024 0 r
F
.58741 .36543 m .58737 .36569 L .58759 .36598 L F
.58737 .36569 m .58705 .36804 L .58759 .36598 L F
.6044 .38606 m .60326 .38719 L .60495 .38937 L 0 .042 0 r
F
.60604 .38778 m .60495 .38937 L .60662 .39157 L 0 .04 0 r
F
.60765 .38941 m .60662 .39157 L .60826 .39379 L 0 .037 0 r
F
.60922 .39096 m .60826 .39379 L .60986 .39603 L 0 .034 0 r
F
.61073 .39227 m .60986 .39603 L .61143 .3983 L 0 .03 0 r
F
.61073 .39164 m .61058 .3921 L .61073 .39227 L 0 .034 0 r
F
.61066 .39168 m .61058 .3921 L .61073 .39227 L 0 .03 0 r
F
.61058 .3921 m .60986 .39603 L .61073 .39227 L F
.61073 .39227 m .61053 .39228 L .61073 .39249 L 0 .034 0 r
F
.61058 .3921 m .61053 .39228 L .61073 .39227 L F
.61073 .39164 m .60919 .38943 L .6092 .39083 L F
.6093 .39092 m .6092 .39083 L .6092 .39087 L 0 .03 0 r
F
.61054 .39235 m .6092 .39087 L .60986 .39603 L F
.61058 .3921 m .6092 .39083 L .60924 .39642 L 0 .034 0 r
F
.61073 .39164 m .6092 .39083 L .61058 .3921 L F
.61066 .39168 m .60903 .38954 L .6092 .39083 L 0 .03 0 r
F
.61066 .39168 m .6092 .39083 L .6093 .39092 L F
.61066 .39168 m .6092 .39087 L .61054 .39235 L F
.60919 .38943 m .60761 .38725 L .60763 .38911 L 0 .038 0 r
F
.60761 .38725 m .60599 .3851 L .60603 .38767 L 0 .042 0 r
F
.60714 .3887 m .60603 .38767 L .60662 .39157 L 0 .037 0 r
F
.60714 .3887 m .60603 .38767 L .60609 .39192 L 0 .042 0 r
F
.60761 .38725 m .60603 .38767 L .60714 .3887 L F
.60599 .3851 m .60539 .3869 L .60603 .38767 L 0 .046 0 r
F
.60599 .3851 m .60432 .38298 L .60438 .38596 L F
.60539 .3869 m .60438 .38596 L .60495 .38937 L 0 .04 0 r
F
.60539 .3869 m .60438 .38596 L .60446 .38971 L 0 .046 0 r
F
.60599 .3851 m .60438 .38596 L .60539 .3869 L F
.60432 .38298 m .60363 .38504 L .60438 .38596 L 0 .051 0 r
F
.60271 .38425 m .60153 .38503 L .60326 .38719 L 0 .044 0 r
F
.60432 .38298 m .60261 .38089 L .6027 .38416 L 0 .051 0 r
F
.60363 .38504 m .6027 .38416 L .60326 .38719 L 0 .042 0 r
F
.60363 .38504 m .6027 .38416 L .60279 .38752 L 0 .051 0 r
F
.60432 .38298 m .6027 .38416 L .60363 .38504 L F
.60261 .38089 m .60185 .38311 L .6027 .38416 L 0 .055 0 r
F
.60099 .38236 m .59978 .38288 L .60153 .38503 L 0 .046 0 r
F
.60261 .38089 m .60086 .37883 L .60097 .38228 L 0 .055 0 r
F
.60185 .38311 m .60097 .38228 L .60153 .38503 L 0 .044 0 r
F
.60185 .38311 m .60097 .38228 L .60107 .38536 L 0 .055 0 r
F
.60261 .38089 m .60097 .38228 L .60185 .38311 L F
.60086 .37883 m .60005 .38113 L .60097 .38228 L 0 .058 0 r
F
.59922 .38039 m .598 .38075 L .59978 .38288 L 0 .047 0 r
F
.60086 .37883 m .59907 .37681 L .5992 .38031 L 0 .058 0 r
F
.60005 .38113 m .5992 .38031 L .59978 .38288 L 0 .046 0 r
F
.60005 .38113 m .5992 .38031 L .59932 .38323 L 0 .058 0 r
F
.60086 .37883 m .5992 .38031 L .60005 .38113 L F
.59907 .37681 m .59825 .3791 L .5992 .38031 L 0 .062 0 r
F
.59741 .37834 m .59621 .37862 L .598 .38075 L 0 .047 0 r
F
.59907 .37681 m .59723 .37481 L .59739 .37825 L 0 .062 0 r
F
.59825 .3791 m .59739 .37825 L .598 .38075 L 0 .047 0 r
F
.59825 .3791 m .59739 .37825 L .59752 .38112 L 0 .062 0 r
F
.59907 .37681 m .59739 .37825 L .59825 .3791 L F
.59723 .37481 m .59643 .37703 L .59739 .37825 L 0 .066 0 r
F
.59556 .37619 m .5944 .37651 L .59621 .37862 L 0 .045 0 r
F
.59723 .37481 m .59536 .37285 L .59553 .3761 L 0 .066 0 r
F
.59643 .37703 m .59553 .3761 L .59621 .37862 L 0 .047 0 r
F
.59643 .37703 m .59553 .3761 L .59569 .37904 L 0 .066 0 r
F
.59723 .37481 m .59553 .3761 L .59643 .37703 L F
.59536 .37285 m .5946 .3749 L .59553 .3761 L 0 .07 0 r
F
.59366 .37395 m .59257 .37439 L .5944 .37651 L 0 .042 0 r
F
.59536 .37285 m .59344 .37093 L .59363 .37384 L 0 .07 0 r
F
.5946 .3749 m .59363 .37384 L .5944 .37651 L 0 .045 0 r
F
.5946 .3749 m .59363 .37384 L .59383 .37699 L 0 .07 0 r
F
.59536 .37285 m .59363 .37384 L .5946 .3749 L F
.59344 .37093 m .59277 .37272 L .59363 .37384 L 0 .073 0 r
F
.5917 .37156 m .59074 .37228 L .59257 .37439 L 0 .037 0 r
F
.59344 .37093 m .59149 .36904 L .59167 .37143 L 0 .073 0 r
F
.59277 .37272 m .59167 .37143 L .59257 .37439 L 0 .042 0 r
F
.59277 .37272 m .59167 .37143 L .59192 .37497 L 0 .073 0 r
F
.59344 .37093 m .59167 .37143 L .59277 .37272 L F
.59149 .36904 m .59094 .37047 L .59167 .37143 L .008 .076 0 r
F
.58969 .36896 m .5889 .37016 L .59074 .37228 L 0 .031 0 r
F
.58963 .36879 m .5896 .36885 L .58969 .36896 L F
.59149 .36904 m .5895 .36718 L .58963 .36879 L .008 .076 0 r
F
.59094 .37047 m .58963 .36879 L .59074 .37228 L 0 .037 0 r
F
.59094 .37047 m .58963 .36879 L .58998 .37297 L .008 .076 0 r
F
.59149 .36904 m .58963 .36879 L .59094 .37047 L F
.58963 .36877 m .58963 .36878 L .58963 .36879 L .016 .08 0 r
F
.5895 .36718 m .58914 .3681 L .58963 .36877 L F
.5895 .36718 m .58747 .36537 L .5875 .36572 L F
.58914 .36811 m .5875 .36572 L .58759 .36598 L 0 .031 0 r
F
.58914 .36811 m .58759 .36598 L .5889 .37016 L F
.5896 .36885 m .5889 .37016 L .58969 .36896 L F
.58963 .3688 m .58801 .371 L .58998 .37297 L .016 .08 0 r
F
.58963 .36879 m .58963 .36879 L .58963 .3688 L F
.58914 .36811 m .5889 .37016 L .58963 .36879 L 0 .031 0 r
F
.58963 .36879 m .58801 .371 L .58963 .3688 L .016 .08 0 r
F
.58914 .36811 m .5875 .36572 L .58801 .371 L F
.5895 .36718 m .5875 .36572 L .58914 .36811 L F
.58747 .36537 m .58739 .36556 L .58751 .36575 L .023 .083 0 r
F
.58921 .36746 m .58741 .36543 L .5875 .36572 L 0 .031 0 r
F
.58921 .36746 m .5875 .36572 L .58914 .36811 L F
.59105 .36944 m .58921 .36746 L .58963 .36879 L 0 .037 0 r
F
.59105 .36944 m .58963 .36879 L .59094 .37047 L F
.59292 .3714 m .59105 .36944 L .59167 .37143 L 0 .042 0 r
F
.59292 .3714 m .59167 .37143 L .59277 .37272 L F
.5948 .37334 m .59292 .3714 L .59363 .37384 L 0 .045 0 r
F
.5948 .37334 m .59363 .37384 L .5946 .3749 L F
.59667 .37529 m .5948 .37334 L .59553 .3761 L 0 .047 0 r
F
.59667 .37529 m .59553 .3761 L .59643 .37703 L F
.59852 .37725 m .59667 .37529 L .59739 .37825 L F
.59852 .37725 m .59739 .37825 L .59825 .3791 L F
.60035 .37923 m .59852 .37725 L .5992 .38031 L 0 .046 0 r
F
.60035 .37923 m .5992 .38031 L .60005 .38113 L F
.60216 .38124 m .60035 .37923 L .60097 .38228 L 0 .044 0 r
F
.60216 .38124 m .60097 .38228 L .60185 .38311 L F
.60393 .38327 m .60216 .38124 L .6027 .38416 L 0 .042 0 r
F
.60393 .38327 m .6027 .38416 L .60363 .38504 L F
.60567 .38533 m .60393 .38327 L .60438 .38596 L 0 .04 0 r
F
.60567 .38533 m .60438 .38596 L .60539 .3869 L F
.60737 .38742 m .60567 .38533 L .60603 .38767 L 0 .037 0 r
F
.60737 .38742 m .60603 .38767 L .60714 .3887 L F
.60903 .38954 m .60737 .38742 L .60763 .3893 L 0 .034 0 r
F
.60887 .39044 m .60763 .3893 L .60826 .39379 L F
.60856 .39015 m .60763 .38911 L .60763 .3893 L 0 .038 0 r
F
.60919 .38943 m .60763 .38911 L .60886 .39048 L F
.60903 .38954 m .60763 .3893 L .60887 .39044 L 0 .034 0 r
F
.60886 .39048 m .60856 .39015 L .60769 .39416 L 0 .038 0 r
F
.60856 .39015 m .60763 .3893 L .60769 .39416 L F
.61073 .39249 m .60924 .39642 L .61074 .3987 L 0 .034 0 r
F
.61053 .39228 m .60924 .39642 L .61073 .39249 L F
.6092 .39083 m .60917 .39091 L .60922 .39096 L F
.60917 .39091 m .60826 .39379 L .60922 .39096 L F
.60919 .38943 m .60887 .39044 L .6092 .39083 L 0 .038 0 r
F
.60903 .38954 m .60887 .39044 L .6092 .39083 L 0 .034 0 r
F
.60887 .39044 m .60826 .39379 L .6092 .39083 L F
.6092 .39083 m .60881 .39062 L .6092 .39103 L 0 .038 0 r
F
.60887 .39044 m .60881 .39062 L .6092 .39083 L F
.6092 .39103 m .60769 .39416 L .60924 .39642 L F
.60881 .39062 m .60769 .39416 L .6092 .39103 L F
.60763 .3893 m .6076 .38936 L .60765 .38941 L 0 .037 0 r
F
.6076 .38936 m .60662 .39157 L .60765 .38941 L F
.60761 .38725 m .60714 .3887 L .60763 .3893 L 0 .042 0 r
F
.60737 .38742 m .60714 .3887 L .60763 .3893 L 0 .037 0 r
F
.60714 .3887 m .60662 .39157 L .60763 .3893 L F
.60763 .3893 m .60708 .38889 L .60763 .38948 L 0 .042 0 r
F
.60714 .3887 m .60708 .38889 L .60763 .3893 L F
.60763 .38948 m .60609 .39192 L .60769 .39416 L F
.60708 .38889 m .60609 .39192 L .60763 .38948 L F
.60603 .38767 m .60599 .38772 L .60604 .38778 L 0 .04 0 r
F
.60599 .38772 m .60495 .38937 L .60604 .38778 L F
.60567 .38533 m .60539 .3869 L .60603 .38767 L F
.60539 .3869 m .60495 .38937 L .60603 .38767 L F
.60603 .38767 m .60533 .38708 L .60603 .38785 L 0 .046 0 r
F
.60539 .3869 m .60533 .38708 L .60603 .38767 L F
.60603 .38785 m .60446 .38971 L .60609 .39192 L F
.60533 .38708 m .60446 .38971 L .60603 .38785 L F
.60438 .38596 m .60435 .386 L .6044 .38606 L 0 .042 0 r
F
.60435 .386 m .60326 .38719 L .6044 .38606 L F
.60393 .38327 m .60363 .38504 L .60438 .38596 L F
.60363 .38504 m .60326 .38719 L .60438 .38596 L F
.60438 .38596 m .60357 .38521 L .60438 .38613 L 0 .051 0 r
F
.60363 .38504 m .60357 .38521 L .60438 .38596 L F
.60438 .38613 m .60279 .38752 L .60446 .38971 L F
.60357 .38521 m .60279 .38752 L .60438 .38613 L F
.6027 .38416 m .60266 .38419 L .60271 .38425 L 0 .044 0 r
F
.60266 .38419 m .60153 .38503 L .60271 .38425 L F
.60216 .38124 m .60185 .38311 L .6027 .38416 L F
.60185 .38311 m .60153 .38503 L .6027 .38416 L F
.6027 .38416 m .60179 .38328 L .6027 .38433 L 0 .055 0 r
F
.60185 .38311 m .60179 .38328 L .6027 .38416 L F
.6027 .38433 m .60107 .38536 L .60279 .38752 L F
.60179 .38328 m .60107 .38536 L .6027 .38433 L F
.60097 .38228 m .60093 .3823 L .60099 .38236 L 0 .046 0 r
F
.60093 .3823 m .59978 .38288 L .60099 .38236 L F
.60035 .37923 m .60005 .38113 L .60097 .38228 L F
.60005 .38113 m .59978 .38288 L .60097 .38228 L F
.60097 .38228 m .59999 .3813 L .60098 .38245 L 0 .058 0 r
F
.60005 .38113 m .59999 .3813 L .60097 .38228 L F
.60098 .38245 m .59932 .38323 L .60107 .38536 L F
.59999 .3813 m .59932 .38323 L .60098 .38245 L F
.5992 .38031 m .59916 .38032 L .59922 .38039 L 0 .047 0 r
F
.59916 .38032 m .598 .38075 L .59922 .38039 L F
.59852 .37725 m .59825 .3791 L .5992 .38031 L F
.59825 .3791 m .598 .38075 L .5992 .38031 L F
.5992 .38031 m .59819 .37927 L .59921 .38049 L 0 .062 0 r
F
.59825 .3791 m .59819 .37927 L .5992 .38031 L F
.59921 .38049 m .59752 .38112 L .59932 .38323 L F
.59819 .37927 m .59752 .38112 L .59921 .38049 L F
.59739 .37825 m .59735 .37826 L .59741 .37834 L 0 .047 0 r
F
.59735 .37826 m .59621 .37862 L .59741 .37834 L F
.59667 .37529 m .59643 .37703 L .59739 .37825 L F
.59643 .37703 m .59621 .37862 L .59739 .37825 L F
.59739 .37825 m .59637 .37718 L .5974 .37844 L 0 .066 0 r
F
.59643 .37703 m .59637 .37718 L .59739 .37825 L F
.5974 .37844 m .59569 .37904 L .59752 .38112 L F
.59637 .37718 m .59569 .37904 L .5974 .37844 L F
.59553 .3761 m .5955 .37612 L .59556 .37619 L 0 .045 0 r
F
.5955 .37612 m .5944 .37651 L .59556 .37619 L F
.5948 .37334 m .5946 .3749 L .59553 .3761 L F
.5946 .3749 m .5944 .37651 L .59553 .3761 L F
.59553 .3761 m .59454 .37505 L .59554 .3763 L 0 .07 0 r
F
.5946 .3749 m .59454 .37505 L .59553 .3761 L F
.59554 .3763 m .59383 .37699 L .59569 .37904 L F
.59454 .37505 m .59383 .37699 L .59554 .3763 L F
.59363 .37384 m .59359 .37386 L .59366 .37395 L 0 .042 0 r
F
.59359 .37386 m .59257 .37439 L .59366 .37395 L F
.59292 .3714 m .59277 .37272 L .59363 .37384 L F
.59277 .37272 m .59257 .37439 L .59363 .37384 L F
.59363 .37384 m .59272 .37285 L .59364 .37402 L 0 .073 0 r
F
.59277 .37272 m .59272 .37285 L .59363 .37384 L F
.59364 .37402 m .59192 .37497 L .59383 .37699 L F
.59272 .37285 m .59192 .37497 L .59364 .37402 L F
.59167 .37143 m .59163 .37147 L .5917 .37156 L 0 .037 0 r
F
.59163 .37147 m .59074 .37228 L .5917 .37156 L F
.59105 .36944 m .59094 .37047 L .59167 .37143 L F
.59094 .37047 m .59074 .37228 L .59167 .37143 L F
.59167 .37143 m .59091 .37056 L .59167 .37156 L .008 .076 0 r
F
.59094 .37047 m .59091 .37056 L .59167 .37143 L F
.59167 .37156 m .58998 .37297 L .59192 .37497 L F
.59091 .37056 m .58998 .37297 L .59167 .37156 L F
.58921 .36746 m .58914 .36811 L .58963 .36879 L 0 .031 0 r
F
.58963 .36878 m .58801 .371 L .58963 .36879 L .016 .08 0 r
F
.58914 .3681 m .58801 .371 L .58963 .36877 L F
.58751 .36575 m .586 .36906 L .58801 .371 L .023 .083 0 r
F
.58739 .36556 m .586 .36906 L .58751 .36575 L F
.40473 .67596 m .38821 .67347 L .3897 .67555 L .889 .063 0 r
F
.40601 .67777 m .40473 .67596 L .3897 .67555 L .874 .06 0 r
F
.62233 .42021 m .61869 .42507 L .61977 .42757 L 0 .022 0 r
F
.62233 .42021 m .62122 .41774 L .61869 .42507 L F
.29538 .55142 m .28722 .53987 L .28753 .54303 L 1 .455 0 r
F
.29576 .55454 m .29538 .55142 L .28753 .54303 L 1 .432 0 r
F
.39647 .62796 m .38263 .62396 L .38405 .62556 L .912 .064 0 r
F
.39771 .62946 m .39647 .62796 L .38405 .62556 L .888 .06 0 r
F
.90879 .54999 m .89706 .56186 L .8963 .56883 L 0 0 0 r
F
.90879 .54999 m .90957 .54285 L .89706 .56186 L F
.58332 .60023 m .57444 .60292 L .57313 .60473 L .081 0 0 r
F
.58332 .60023 m .58476 .59836 L .57444 .60292 L F
.41965 .86904 m .39392 .87025 L .39607 .87269 L .565 .014 0 r
F
.42111 .87135 m .41965 .86904 L .39607 .87269 L .534 .009 0 r
F
.56465 .61485 m .55518 .61702 L .55387 .61856 L .15 0 0 r
F
.56465 .61485 m .56614 .61326 L .55518 .61702 L F
.62495 .42209 m .62157 .42693 L .62268 .42945 L 0 .021 0 r
F
.62495 .42209 m .62379 .41962 L .62157 .42693 L F
.90253 .37986 m .89576 .39477 L .89769 .4016 L 0 0 0 r
F
.90253 .37986 m .90053 .37302 L .89576 .39477 L F
.51831 .63158 m .50747 .63239 L .50668 .63337 L .326 0 0 r
F
.51831 .63158 m .51935 .63057 L .50747 .63239 L F
.32571 .88485 m .29791 .87732 L .30209 .8804 L .644 .02 0 r
F
.32933 .88768 m .32571 .88485 L .30209 .8804 L .613 .014 0 r
F
.71284 .65837 m .70303 .66476 L .70056 .66851 L 0 0 0 r
F
.71284 .65837 m .71553 .65455 L .70303 .66476 L F
.6723 .44673 m .67372 .44309 L .67281 .45236 L .829 .207 0 r
F
.33277 .57566 m .32081 .56764 L .32193 .57011 L 1 .275 0 r
F
.33384 .57803 m .33277 .57566 L .32193 .57011 L 1 .247 0 r
F
.39904 .61919 m .38622 .61448 L .38755 .616 L .896 .063 0 r
F
.40021 .62061 m .39904 .61919 L .38755 .616 L .868 .058 0 r
F
.60105 .57436 m .59319 .57775 L .59208 .57983 L 0 0 0 r
F
.60105 .57436 m .60224 .57222 L .59319 .57775 L F
.52919 .33632 m .52663 .33572 L .52759 .33739 L .278 .38 0 r
F
.52851 .33736 m .52759 .33739 L .52817 .33772 L .163 .161 0 r
F
.52851 .33736 m .52759 .33739 L .52801 .33812 L .278 .38 0 r
F
.52919 .33632 m .52759 .33739 L .52851 .33736 L F
.52897 .33686 m .52628 .33663 L .52759 .33739 L .163 .161 0 r
F
.52897 .33686 m .52759 .33739 L .52851 .33736 L F
.523 .66235 m .51159 .66526 L .51058 .66613 L .035 0 0 r
F
.523 .66235 m .52434 .66147 L .51159 .66526 L F
.32267 .52161 m .31513 .51203 L .31539 .51462 L 1 .534 0 r
F
.32296 .52416 m .32267 .52161 L .31539 .51462 L 1 .505 0 r
F
.42882 .6391 m .41508 .6367 L .41619 .63793 L .755 .038 0 r
F
.42968 .64024 m .42882 .6391 L .41619 .63793 L .726 .034 0 r
F
.38532 .66927 m .36903 .66519 L .37061 .66755 L .997 .08 0 r
F
.38675 .67138 m .38532 .66927 L .37061 .66755 L .985 .078 0 r
F
.38116 .60804 m .36883 .60228 L .37017 .60405 L .979 .08 0 r
F
.38238 .6097 m .38116 .60804 L .37017 .60405 L .954 .076 0 r
F
.50605 .63975 m .49462 .64031 L .49407 .64126 L .367 0 0 r
F
.50605 .63975 m .50688 .63879 L .49462 .64031 L F
.65598 .51273 m .65467 .51901 L .65381 .52195 L .715 .176 0 r
F
.65598 .51273 m .6568 .5098 L .65467 .51901 L F
.62014 .54062 m .6134 .54474 L .61269 .54714 L 0 0 0 r
F
.62014 .54062 m .62089 .53818 L .6134 .54474 L F
.45657 .63639 m .44366 .6347 L .44425 .63565 L .61 .016 0 r
F
.45689 .63727 m .45657 .63639 L .44425 .63565 L .579 .01 0 r
F
.46912 .63749 m .45657 .63639 L .45689 .63727 L .53 .004 0 r
F
.83602 .23333 m .83161 .22797 L .83545 .24816 L 0 .039 0 r
F
.53172 .62718 m .5214 .62842 L .52039 .62952 L .269 0 0 r
F
.53172 .62718 m .53297 .62603 L .5214 .62842 L F
.85335 .67817 m .84099 .68726 L .83823 .69333 L 0 0 0 r
F
.85335 .67817 m .85622 .6719 L .84099 .68726 L F
.46907 .6439 m .46904 .64299 L .45633 .64321 L .513 .002 0 r
F
.48141 .64324 m .46904 .64299 L .46907 .6439 L .464 0 0 r
F
.48141 .64324 m .48168 .64234 L .46904 .64299 L F
.44366 .6347 m .43062 .6324 L .43146 .63343 L .674 .025 0 r
F
.44425 .63565 m .44366 .6347 L .43146 .63343 L .643 .019 0 r
F
.53765 .65637 m .52698 .65954 L .52567 .66053 L 0 0 0 r
F
.53765 .65637 m .53925 .65534 L .52698 .65954 L F
.73987 .81595 m .72427 .82086 L .72 .82506 L F
.73987 .81595 m .74452 .81157 L .72427 .82086 L F
.29545 .84735 m .26767 .84068 L .27184 .84427 L .824 .05 0 r
F
.29914 .85072 m .29545 .84735 L .27184 .84427 L .798 .045 0 r
F
.36144 .59103 m .34998 .58407 L .3512 .58611 L 1 .111 0 r
F
.36258 .59298 m .36144 .59103 L .3512 .58611 L 1 .099 0 r
F
.34028 .63613 m .32616 .6281 L .32754 .63097 L 1 .237 0 r
F
.34164 .63883 m .34028 .63613 L .32754 .63097 L 1 .22 0 r
F
.62318 .54467 m .61606 .54873 L .61532 .55118 L 0 0 0 r
F
.62318 .54467 m .62397 .54217 L .61606 .54873 L F
.89809 .3809 m .89145 .39564 L .89305 .40246 L F
.89809 .3809 m .89651 .37403 L .89145 .39564 L F
.5464 .62066 m .5366 .62235 L .53541 .62362 L .209 0 0 r
F
.5464 .62066 m .54779 .61934 L .5366 .62235 L F
.62338 .42269 m .61977 .42757 L .6208 .43009 L 0 .018 0 r
F
.62338 .42269 m .62233 .42021 L .61977 .42757 L F
.70149 .36806 m .69702 .37697 L .69554 .38214 L 0 0 0 r
F
.70149 .36806 m .70276 .36277 L .69702 .37697 L F
.60311 .57893 m .595 .58224 L .59385 .58436 L F
.60311 .57893 m .60435 .57675 L .595 .58224 L F
.6359 .49297 m .63027 .49777 L .63028 .50044 L F
.6359 .49297 m .6359 .49027 L .63027 .49777 L F
.55015 .32952 m .549 .33273 L .5509 .33529 L 0 .048 0 r
F
.63205 .49005 m .62686 .49478 L .62686 .4974 L 0 0 0 r
F
.63205 .49005 m .63207 .48742 L .62686 .49478 L F
.13018 .73832 m .10697 .71948 L .11028 .7255 L .975 .106 0 r
F
.13338 .74407 m .13018 .73832 L .11028 .7255 L .95 .102 0 r
F
.34069 .56449 m .3307 .55618 L .3316 .55853 L 1 .281 0 r
F
.34156 .56676 m .34069 .56449 L .3316 .55853 L 1 .25 0 r
F
.55776 .3274 m .55687 .33061 L .55916 .33258 L .136 .13 0 r
F
.55776 .3274 m .55527 .32596 L .55687 .33061 L F
.25172 .82547 m .22421 .81611 L .22848 .82029 L .881 .062 0 r
F
.25559 .82939 m .25172 .82547 L .22848 .82029 L .856 .058 0 r
F
.62607 .42458 m .62268 .42945 L .62376 .43199 L 0 .017 0 r
F
.62607 .42458 m .62495 .42209 L .62268 .42945 L F
.3108 .53638 m .30092 .52654 L .3015 .52932 L 1 .472 0 r
F
.31139 .53908 m .3108 .53638 L .3015 .52932 L 1 .444 0 r
F
.74415 .37848 m .75425 .38342 L .75592 .38807 L .824 .09 0 r
F
.74415 .37848 m .74167 .37442 L .75425 .38342 L F
.75151 .59287 m .74322 .60048 L .74155 .60488 L 0 0 0 r
F
.75151 .59287 m .75323 .58836 L .74322 .60048 L F
.49352 .64217 m .48168 .64234 L .48141 .64324 L .412 0 0 r
F
.49352 .64217 m .49407 .64126 L .48168 .64234 L F
.89548 .54788 m .88766 .56006 L .88672 .56684 L 0 0 0 r
F
.89548 .54788 m .89649 .54099 L .88766 .56006 L F
.35675 .60236 m .34373 .59603 L .34513 .59815 L 1 .11 0 r
F
.35804 .60437 m .35675 .60236 L .34513 .59815 L 1 .095 0 r
F
.39392 .87025 m .36745 .86965 L .37026 .87223 L .642 .023 0 r
F
.39607 .87269 m .39392 .87025 L .37026 .87223 L .613 .018 0 r
F
.4156 .62709 m .40262 .62333 L .40386 .62463 L .807 .047 0 r
F
.41664 .6283 m .4156 .62709 L .40386 .62463 L .777 .041 0 r
F
.58055 .59726 m .57197 .59999 L .57068 .60174 L .064 0 0 r
F
.58055 .59726 m .58197 .59545 L .57197 .59999 L F
.56232 .6115 m .55313 .61367 L .55183 .61515 L .139 0 0 r
F
.56232 .6115 m .56379 .60996 L .55313 .61367 L F
.77361 .49389 m .77037 .50311 L .77008 .50799 L 0 0 0 r
F
.77361 .49389 m .77368 .48899 L .77037 .50311 L F
.29576 .55454 m .28753 .54303 L .28789 .5462 L 1 .432 0 r
F
.29618 .55767 m .29576 .55454 L .28789 .5462 L 1 .409 0 r
F
.32296 .52416 m .31539 .51462 L .31569 .51721 L 1 .505 0 r
F
.32329 .52671 m .32296 .52416 L .31569 .51721 L 1 .476 0 r
F
.414 .63542 m .40025 .63233 L .40155 .63371 L .819 .048 0 r
F
.41508 .6367 m .414 .63542 L .40155 .63371 L .792 .044 0 r
F
.44314 .642 m .42968 .64024 L .43055 .64134 L .671 .026 0 r
F
.44374 .64301 m .44314 .642 L .43055 .64134 L .64 .02 0 r
F
.45633 .64321 m .44314 .642 L .44374 .64301 L .599 .015 0 r
F
.61373 .6009 m .60678 .60592 L .60515 .60806 L 0 0 0 r
F
.61373 .6009 m .61543 .59867 L .60678 .60592 L F
.63672 .56631 m .63179 .57214 L .63048 .5747 L F
.63672 .56631 m .63802 .56369 L .63179 .57214 L F
.62439 .42519 m .6208 .43009 L .62179 .43262 L 0 .013 0 r
F
.62439 .42519 m .62338 .42269 L .6208 .43009 L F
.20034 .78947 m .17386 .77673 L .17791 .78164 L .944 .08 0 r
F
.20411 .79409 m .20034 .78947 L .17791 .78164 L .92 .076 0 r
F
.62455 .33703 m .67485 .29777 L .67535 .30332 L .586 .039 0 r
F
.62455 .33703 m .61792 .33883 L .67485 .29777 L F
.51853 .63684 m .5077 .63778 L .50688 .63879 L .31 0 0 r
F
.51853 .63684 m .51961 .6358 L .5077 .63778 L F
.31661 .60479 m .30486 .59481 L .30588 .59787 L 1 .318 0 r
F
.31766 .60774 m .31661 .60479 L .30588 .59787 L 1 .298 0 r
F
.43925 .68048 m .42344 .68049 L .42449 .68198 L .608 .02 0 r
F
.44 .68173 m .43925 .68048 L .42449 .68198 L .58 .015 0 r
F
.45443 .67964 m .43925 .68048 L .44 .68173 L .466 0 0 r
F
.45666 .64414 m .45633 .64321 L .44374 .64301 L .568 .01 0 r
F
.46907 .6439 m .45633 .64321 L .45666 .64414 L .513 .002 0 r
F
.62714 .42708 m .62376 .43199 L .62479 .43455 L 0 .014 0 r
F
.62714 .42708 m .62607 .42458 L .62376 .43199 L F
.53415 .33794 m .53318 .33977 L .5357 .34076 L .246 .318 0 r
F
.53415 .33794 m .53159 .33733 L .53318 .33977 L F
.61936 .54305 m .61269 .54714 L .61194 .54953 L 0 0 0 r
F
.61936 .54305 m .62014 .54062 L .61269 .54714 L F
.63586 .49566 m .63028 .50044 L .63023 .50312 L F
.63586 .49566 m .6359 .49297 L .63028 .50044 L F
.632 .49267 m .62686 .4974 L .62682 .50001 L F
.632 .49267 m .63205 .49005 L .62686 .4974 L F
.36448 .65801 m .34896 .65215 L .35053 .65478 L 1 .14 0 r
F
.36597 .66042 m .36448 .65801 L .35053 .65478 L 1 .126 0 r
F
.37852 .61894 m .36502 .61396 L .36651 .61577 L .977 .077 0 r
F
.37986 .62065 m .37852 .61894 L .36651 .61577 L .954 .073 0 r
F
.53205 .63228 m .52173 .6336 L .52068 .63472 L .256 0 0 r
F
.53205 .63228 m .53334 .63111 L .52173 .6336 L F
.67092 .4503 m .6723 .44673 L .67174 .45591 L .845 .209 0 r
F
.33384 .57803 m .32193 .57011 L .32308 .57256 L 1 .247 0 r
F
.33494 .58037 m .33384 .57803 L .32308 .57256 L 1 .219 0 r
F
.54691 .62566 m .53709 .62737 L .53586 .62866 L .2 0 0 r
F
.54691 .62566 m .54835 .62432 L .53709 .62737 L F
.56017 .32897 m .55916 .33258 L .5614 .3346 L .135 .112 0 r
F
.56017 .32897 m .55776 .3274 L .55916 .33258 L F
.46872 .67807 m .46868 .67718 L .45443 .67964 L .358 0 0 r
F
.48222 .67515 m .46868 .67718 L .46872 .67807 L .259 0 0 r
F
.48222 .67515 m .48255 .67436 L .46868 .67718 L F
.59982 .57647 m .59208 .57983 L .59094 .58189 L 0 0 0 r
F
.59982 .57647 m .60105 .57436 L .59208 .57983 L F
.65516 .51565 m .65381 .52195 L .65294 .52487 L .714 .177 0 r
F
.65516 .51565 m .65598 .51273 L .65381 .52195 L F
.67168 .70235 m .66193 .70898 L .65902 .71204 L 0 0 0 r
F
.67168 .70235 m .67493 .69932 L .66193 .70898 L F
.50506 .6352 m .49394 .63558 L .4934 .63645 L .367 0 0 r
F
.50506 .6352 m .50588 .63431 L .49394 .63558 L F
.80089 .77437 m .78542 .78016 L .78151 .78539 L 0 0 0 r
F
.80089 .77437 m .80511 .76893 L .78542 .78016 L F
.59091 .62381 m .59281 .62198 L .58274 .62814 L F
.55181 .33234 m .5509 .33529 L .55277 .3378 L 0 .015 0 r
F
.55181 .33234 m .55015 .32952 L .5509 .33529 L F
.62235 .54715 m .61532 .55118 L .61453 .55361 L 0 0 0 r
F
.62235 .54715 m .62318 .54467 L .61532 .55118 L F
.58184 .60207 m .57313 .60473 L .5718 .60651 L .068 0 0 r
F
.58184 .60207 m .58332 .60023 L .57313 .60473 L F
.46915 .63831 m .46912 .63749 L .45689 .63727 L .506 0 0 r
F
.48109 .63803 m .46912 .63749 L .46915 .63831 L .463 0 0 r
F
.48109 .63803 m .48135 .63722 L .46912 .63749 L F
.31139 .53908 m .3015 .52932 L .30213 .53209 L 1 .444 0 r
F
.31203 .54177 m .31139 .53908 L .30213 .53209 L 1 .417 0 r
F
.34156 .56676 m .3316 .55853 L .33254 .56086 L 1 .25 0 r
F
.34248 .56901 m .34156 .56676 L .33254 .56086 L 1 .218 0 r
F
.62536 .4277 m .62179 .43262 L .62274 .43516 L 0 .009 0 r
F
.62536 .4277 m .62439 .42519 L .62179 .43262 L F
.56313 .61641 m .55387 .61856 L .55253 .62006 L .136 0 0 r
F
.56313 .61641 m .56465 .61485 L .55387 .61856 L F
.50851 .66772 m .49657 .67041 L .49588 .6712 L .076 0 0 r
F
.50851 .66772 m .50955 .66695 L .49657 .67041 L F
.36258 .59298 m .3512 .58611 L .35246 .58813 L 1 .099 0 r
F
.36377 .59491 m .36258 .59298 L .35246 .58813 L 1 .095 0 r
F
.41565 .91374 m .38889 .91003 L .39137 .91209 L .504 0 0 r
F
.41738 .91561 m .41565 .91374 L .39137 .91209 L .483 0 0 r
F
.53667 .33865 m .5357 .34076 L .5382 .34177 L .251 .335 0 r
F
.53667 .33865 m .53415 .33794 L .5357 .34076 L F
.60182 .58108 m .59385 .58436 L .59266 .58645 L 0 0 0 r
F
.60182 .58108 m .60311 .57893 L .59385 .58436 L F
.35856 .90291 m .33081 .89691 L .33461 .89952 L .576 .005 0 r
F
.36171 .9053 m .35856 .90291 L .33461 .89952 L .557 0 0 r
F
.38238 .6097 m .37017 .60405 L .37155 .60578 L .954 .076 0 r
F
.38363 .61133 m .38238 .6097 L .37155 .60578 L .927 .072 0 r
F
.39771 .62946 m .38405 .62556 L .3855 .62712 L .888 .06 0 r
F
.39896 .63092 m .39771 .62946 L .3855 .62712 L .863 .056 0 r
F
.14174 .7296 m .11761 .71251 L .12093 .71828 L 1 .107 0 r
F
.14491 .73508 m .14174 .7296 L .12093 .71828 L .995 .103 0 r
F
.43062 .6324 m .41769 .62946 L .41877 .63058 L .721 .032 0 r
F
.43146 .63343 m .43062 .6324 L .41877 .63058 L .688 .026 0 r
F
.62817 .42961 m .62479 .43455 L .62578 .43712 L 0 .01 0 r
F
.62817 .42961 m .62714 .42708 L .62479 .43455 L F
.40021 .62061 m .38755 .616 L .38892 .61748 L .868 .058 0 r
F
.40141 .62199 m .40021 .62061 L .38892 .61748 L .839 .053 0 r
F
.45484 .68067 m .45443 .67964 L .44 .68173 L .446 0 0 r
F
.46872 .67807 m .45443 .67964 L .45484 .68067 L .358 0 0 r
F
.32329 .52671 m .31569 .51721 L .31604 .51979 L 1 .476 0 r
F
.32367 .52924 m .32329 .52671 L .31604 .51979 L 1 .446 0 r
F
.49285 .63727 m .48135 .63722 L .48109 .63803 L .412 0 0 r
F
.49285 .63727 m .4934 .63645 L .48135 .63722 L F
.24122 .85262 m .2137 .84096 L .21838 .84521 L .756 .046 0 r
F
.24551 .85659 m .24122 .85262 L .21838 .84521 L .723 .04 0 r
F
.90441 .38675 m .89769 .4016 L .8995 .40847 L 0 0 0 r
F
.90441 .38675 m .90253 .37986 L .89769 .4016 L F
.86105 .69014 m .84693 .69837 L .84408 .70458 L F
.86105 .69014 m .86408 .68372 L .84693 .69837 L F
.7001 .37328 m .69554 .38214 L .69402 .3872 L F
.7001 .37328 m .70149 .36806 L .69554 .38214 L F
.42344 .68049 m .4073 .67955 L .40862 .68132 L .745 .04 0 r
F
.42449 .68198 m .42344 .68049 L .40862 .68132 L .724 .037 0 r
F
.74652 .38261 m .75592 .38807 L .75753 .39273 L .819 .091 0 r
F
.74652 .38261 m .74415 .37848 L .75592 .38807 L F
.6319 .4953 m .62682 .50001 L .62673 .50262 L 0 0 0 r
F
.6319 .4953 m .632 .49267 L .62682 .50001 L F
.34164 .63883 m .32754 .63097 L .32896 .63384 L 1 .22 0 r
F
.34303 .64152 m .34164 .63883 L .32896 .63384 L 1 .205 0 r
F
.63577 .49835 m .63023 .50312 L .63014 .50578 L 0 0 0 r
F
.63577 .49835 m .63586 .49566 L .63023 .50312 L F
.29618 .55767 m .28789 .5462 L .28829 .54936 L 1 .409 0 r
F
.29665 .56078 m .29618 .55767 L .28829 .54936 L 1 .386 0 r
F
.70084 .28502 m .69809 .28112 L .70171 .29335 L 0 .008 0 r
F
.51724 .63255 m .50668 .63337 L .50588 .63431 L .309 0 0 r
F
.51724 .63255 m .51831 .63158 L .50668 .63337 L F
.56249 .33067 m .5614 .3346 L .56357 .33666 L .129 .099 0 r
F
.56249 .33067 m .56017 .32897 L .5614 .3346 L F
.90787 .55712 m .8963 .56883 L .89542 .5758 L 0 0 0 r
F
.90787 .55712 m .90879 .54999 L .8963 .56883 L F
.2868 .87722 m .25887 .86791 L .26348 .87148 L .679 .028 0 r
F
.29092 .88052 m .2868 .87722 L .26348 .87148 L .646 .022 0 r
F
.71008 .66214 m .70056 .66851 L .69802 .6722 L 0 0 0 r
F
.71008 .66214 m .71284 .65837 L .70056 .66851 L F
.18753 .81353 m .16115 .79883 L .16556 .80391 L .845 .069 0 r
F
.19166 .81832 m .18753 .81353 L .16556 .80391 L .815 .064 0 r
F
.49519 .67193 m .48255 .67436 L .48222 .67515 L .15 0 0 r
F
.49519 .67193 m .49588 .6712 L .48255 .67436 L F
.79253 .76691 m .77834 .7734 L .77445 .77845 L 0 0 0 r
F
.79253 .76691 m .79669 .76165 L .77834 .7734 L F
.35804 .60437 m .34513 .59815 L .34657 .60024 L 1 .095 0 r
F
.35937 .60635 m .35804 .60437 L .34657 .60024 L 1 .091 0 r
F
.53916 .33945 m .5382 .34177 L .54067 .34282 L .248 .33 0 r
F
.53916 .33945 m .53667 .33865 L .5382 .34177 L F
.3341 .86157 m .30671 .85721 L .31059 .86033 L .758 .038 0 r
F
.33742 .8645 m .3341 .86157 L .31059 .86033 L .731 .034 0 r
F
.54498 .62194 m .53541 .62362 L .5342 .62485 L .194 0 0 r
F
.54498 .62194 m .5464 .62066 L .53541 .62362 L F
.61853 .54546 m .61194 .54953 L .61115 .55189 L 0 0 0 r
F
.61853 .54546 m .61936 .54305 L .61194 .54953 L F
.53045 .62828 m .52039 .62952 L .51935 .63057 L .253 0 0 r
F
.53045 .62828 m .53172 .62718 L .52039 .62952 L F
.62627 .43022 m .62274 .43516 L .62364 .43772 L 0 .005 0 r
F
.62627 .43022 m .62536 .4277 L .62274 .43516 L F
.40601 .67777 m .3897 .67555 L .39121 .67761 L .874 .06 0 r
F
.4073 .67955 m .40601 .67777 L .39121 .67761 L .858 .058 0 r
F
.36033 .89629 m .333 .8904 L .33674 .89301 L .579 .006 0 r
F
.36343 .89866 m .36033 .89629 L .33674 .89301 L .56 0 0 r
F
.42968 .64024 m .41619 .63793 L .41731 .63913 L .726 .034 0 r
F
.43055 .64134 m .42968 .64024 L .41731 .63913 L .697 .028 0 r
F
.41656 .90671 m .3902 .90322 L .39264 .90525 L .501 0 0 r
F
.41825 .90855 m .41656 .90671 L .39264 .90525 L .48 0 0 r
F
.57909 .59904 m .57068 .60174 L .56936 .60345 L .052 0 0 r
F
.57909 .59904 m .58055 .59726 L .57068 .60174 L F
.55306 .33574 m .55277 .3378 L .55465 .34019 L 0 0 0 r
F
.55306 .33574 m .55181 .33234 L .55277 .3378 L F
.63537 .56891 m .63048 .5747 L .62914 .57722 L F
.63537 .56891 m .63672 .56631 L .63048 .5747 L F
.89949 .38781 m .89305 .40246 L .89451 .40931 L F
.89949 .38781 m .89809 .3809 L .89305 .40246 L F
.62916 .43215 m .62578 .43712 L .62672 .4397 L 0 .006 0 r
F
.62916 .43215 m .62817 .42961 L .62578 .43712 L F
.38675 .67138 m .37061 .66755 L .37222 .66991 L .985 .078 0 r
F
.38821 .67347 m .38675 .67138 L .37222 .66991 L .973 .076 0 r
F
.77344 .49878 m .77008 .50799 L .76972 .51285 L 0 0 0 r
F
.77344 .49878 m .77361 .49389 L .77008 .50799 L F
.62147 .54961 m .61453 .55361 L .6137 .55603 L F
.62147 .54961 m .62235 .54715 L .61453 .55361 L F
.65432 .51856 m .65294 .52487 L .65204 .52776 L .713 .177 0 r
F
.65432 .51856 m .65516 .51565 L .65294 .52487 L F
.50521 .64067 m .49407 .64126 L .49352 .64217 L .348 0 0 r
F
.50521 .64067 m .50605 .63975 L .49407 .64126 L F
.44425 .63565 m .43146 .63343 L .43232 .63441 L .643 .019 0 r
F
.44484 .63656 m .44425 .63565 L .43232 .63441 L .61 .014 0 r
F
.45689 .63727 m .44425 .63565 L .44484 .63656 L .579 .01 0 r
F
.74971 .59736 m .74155 .60488 L .73981 .60925 L 0 0 0 r
F
.74971 .59736 m .75151 .59287 L .74155 .60488 L F
.4572 .6381 m .45689 .63727 L .44484 .63656 L .546 .004 0 r
F
.46915 .63831 m .45689 .63727 L .4572 .6381 L .506 0 0 r
F
.66958 .45379 m .67092 .4503 L .6707 .45941 L .86 .211 0 r
F
.31766 .60774 m .30588 .59787 L .30694 .60093 L 1 .298 0 r
F
.31875 .61067 m .31766 .60774 L .30694 .60093 L 1 .279 0 r
F
.33494 .58037 m .32308 .57256 L .32428 .57498 L 1 .219 0 r
F
.33608 .58269 m .33494 .58037 L .32428 .57498 L 1 .191 0 r
F
.61199 .60309 m .60515 .60806 L .60349 .61016 L 0 0 0 r
F
.61199 .60309 m .61373 .6009 L .60515 .60806 L F
.56082 .613 m .55183 .61515 L .55051 .61658 L .125 0 0 r
F
.56082 .613 m .56232 .6115 L .55183 .61515 L F
.59855 .57856 m .59094 .58189 L .58976 .58391 L 0 0 0 r
F
.59855 .57856 m .59982 .57647 L .59094 .58189 L F
.12627 .74962 m .1023 .73092 L .10589 .73696 L .947 .1 0 r
F
.12971 .75537 m .12627 .74962 L .10589 .73696 L .921 .096 0 r
F
.2451 .84635 m .21815 .83473 L .22272 .83896 L .765 .047 0 r
F
.24929 .8503 m .2451 .84635 L .22272 .83896 L .733 .042 0 r
F
.4691 .64477 m .46907 .6439 L .45666 .64414 L .491 0 0 r
F
.48114 .6441 m .46907 .6439 L .4691 .64477 L .447 0 0 r
F
.48114 .6441 m .48141 .64324 L .46907 .6439 L F
.31203 .54177 m .30213 .53209 L .30281 .53485 L 1 .417 0 r
F
.31271 .54444 m .31203 .54177 L .30281 .53485 L 1 .389 0 r
F
.52165 .66318 m .51058 .66613 L .50955 .66695 L 0 0 0 r
F
.52165 .66318 m .523 .66235 L .51058 .66613 L F
.28977 .87084 m .26234 .86158 L .26685 .86514 L .689 .03 0 r
F
.29381 .87413 m .28977 .87084 L .26685 .86514 L .656 .024 0 r
F
.41664 .6283 m .40386 .62463 L .40512 .62589 L .777 .041 0 r
F
.41769 .62946 m .41664 .6283 L .40512 .62589 L .745 .036 0 r
F
.34248 .56901 m .33254 .56086 L .33353 .56316 L 1 .218 0 r
F
.34344 .57123 m .34248 .56901 L .33353 .56316 L 1 .187 0 r
F
.53603 .65734 m .52567 .66053 L .52434 .66147 L 0 0 0 r
F
.53603 .65734 m .53765 .65637 L .52567 .66053 L F
.54162 .34032 m .53916 .33945 L .54067 .34282 L .24 .316 0 r
F
.63099 .33565 m .67535 .30332 L .67704 .30771 L .578 .035 0 r
F
.63099 .33565 m .62455 .33703 L .67535 .30332 L F
.32367 .52924 m .31604 .51979 L .31643 .52235 L 1 .446 0 r
F
.32409 .53176 m .32367 .52924 L .31643 .52235 L 1 .416 0 r
F
.19271 .80746 m .16702 .79281 L .17128 .79786 L .852 .07 0 r
F
.19671 .81222 m .19271 .80746 L .17128 .79786 L .823 .066 0 r
F
.63176 .49791 m .62673 .50262 L .6266 .50522 L 0 0 0 r
F
.63176 .49791 m .6319 .4953 L .62673 .50262 L F
.85035 .68438 m .83823 .69333 L .83537 .69935 L F
.85035 .68438 m .85335 .67817 L .83823 .69333 L F
.63563 .50103 m .63014 .50578 L .63 .50845 L F
.63563 .50103 m .63577 .49835 L .63014 .50578 L F
.38889 .91003 m .36171 .9053 L .36491 .90757 L .535 0 0 r
F
.39137 .91209 m .38889 .91003 L .36491 .90757 L .514 0 0 r
F
.58033 .60387 m .5718 .60651 L .57043 .60825 L .055 0 0 r
F
.58033 .60387 m .58184 .60207 L .5718 .60651 L F
.62714 .43277 m .62364 .43772 L .62449 .44028 L 0 0 0 r
F
.62714 .43277 m .62627 .43022 L .62364 .43772 L F
.56473 .33246 m .56357 .33666 L .56569 .33876 L .118 .092 0 r
F
.56473 .33246 m .56249 .33067 L .56357 .33666 L F
.89437 .55475 m .88672 .56684 L .88566 .57361 L 0 0 0 r
F
.89437 .55475 m .89548 .54788 L .88672 .56684 L F
.37986 .62065 m .36651 .61577 L .36804 .61756 L .954 .073 0 r
F
.38123 .62232 m .37986 .62065 L .36804 .61756 L .931 .069 0 r
F
.6005 .5832 m .59266 .58645 L .59144 .58851 L 0 0 0 r
F
.6005 .5832 m .60182 .58108 L .59266 .58645 L F
.41508 .6367 m .40155 .63371 L .40288 .63505 L .792 .044 0 r
F
.41619 .63793 m .41508 .6367 L .40288 .63505 L .764 .039 0 r
F
.49295 .64302 m .48141 .64324 L .48114 .6441 L .393 0 0 r
F
.49295 .64302 m .49352 .64217 L .48141 .64324 L F
.63009 .4347 m .62672 .4397 L .62762 .44229 L 0 .002 0 r
F
.63009 .4347 m .62916 .43215 L .62672 .4397 L F
.36377 .59491 m .35246 .58813 L .35376 .59012 L 1 .095 0 r
F
.36498 .5968 m .36377 .59491 L .35376 .59012 L .998 .091 0 r
F
.74174 .82878 m .72568 .83293 L .72129 .83721 L 0 0 0 r
F
.74174 .82878 m .74655 .82431 L .72568 .83293 L F
.29665 .56078 m .28829 .54936 L .28875 .55252 L 1 .386 0 r
F
.29717 .5639 m .29665 .56078 L .28875 .55252 L 1 .363 0 r
F
.54544 .62695 m .53586 .62866 L .53461 .62991 L .184 0 0 r
F
.54544 .62695 m .54691 .62566 L .53586 .62866 L F
.55287 .34144 m .55465 .34019 L .55661 .34237 L .967 .226 0 r
F
.55287 .34144 m .55306 .33574 L .55465 .34019 L F
.51743 .63782 m .50688 .63879 L .50605 .63975 L .291 0 0 r
F
.51743 .63782 m .51853 .63684 L .50688 .63879 L F
.44374 .64301 m .43055 .64134 L .43144 .6424 L .64 .02 0 r
F
.44436 .64398 m .44374 .64301 L .43144 .6424 L .609 .015 0 r
F
.45666 .64414 m .44374 .64301 L .44436 .64398 L .568 .01 0 r
F
.36597 .66042 m .35053 .65478 L .35214 .65741 L 1 .126 0 r
F
.36748 .66281 m .36597 .66042 L .35214 .65741 L 1 .113 0 r
F
.61765 .54785 m .61115 .55189 L .61032 .55424 L 0 0 0 r
F
.61765 .54785 m .61853 .54546 L .61115 .55189 L F
.13338 .74407 m .11028 .7255 L .11371 .73147 L .95 .102 0 r
F
.13669 .74976 m .13338 .74407 L .11371 .73147 L .925 .098 0 r
F
.38363 .61133 m .37155 .60578 L .37296 .60747 L .927 .072 0 r
F
.38491 .61292 m .38363 .61133 L .37296 .60747 L .898 .067 0 r
F
.53074 .63339 m .52068 .63472 L .51961 .6358 L .238 0 0 r
F
.53074 .63339 m .53205 .63228 L .52068 .63472 L F
.56158 .61793 m .55253 .62006 L .55116 .62152 L .121 0 0 r
F
.56158 .61793 m .56313 .61641 L .55253 .62006 L F
.74878 .3868 m .75753 .39273 L .75907 .39741 L .813 .093 0 r
F
.74878 .3868 m .74652 .38261 L .75753 .39273 L F
.45699 .64503 m .45666 .64414 L .44436 .64398 L .535 .004 0 r
F
.4691 .64477 m .45666 .64414 L .45699 .64503 L .491 0 0 r
F
.3902 .90322 m .36343 .89866 L .36657 .90092 L .535 0 0 r
F
.39264 .90525 m .3902 .90322 L .36657 .90092 L .515 0 0 r
F
.62055 .55206 m .6137 .55603 L .61283 .55842 L 0 0 0 r
F
.62055 .55206 m .62147 .54961 L .6137 .55603 L F
.50423 .63604 m .4934 .63645 L .49285 .63727 L .349 0 0 r
F
.50423 .63604 m .50506 .6352 L .4934 .63645 L F
.62796 .43532 m .62449 .44028 L .6253 .44285 L 0 0 0 r
F
.62796 .43532 m .62714 .43277 L .62449 .44028 L F
.65347 .52145 m .65204 .52776 L .65113 .53064 L .713 .178 0 r
F
.65347 .52145 m .65432 .51856 L .65204 .52776 L F
.40141 .62199 m .38892 .61748 L .3903 .61893 L .839 .053 0 r
F
.40262 .62333 m .40141 .62199 L .3903 .61893 L .808 .048 0 r
F
.69857 .37843 m .69402 .3872 L .69246 .39215 L 0 0 0 r
F
.69857 .37843 m .7001 .37328 L .69402 .3872 L F
.39896 .63092 m .3855 .62712 L .38698 .62865 L .863 .056 0 r
F
.40025 .63233 m .39896 .63092 L .38698 .62865 L .837 .052 0 r
F
.63399 .57148 m .62914 .57722 L .62776 .57972 L 0 0 0 r
F
.63399 .57148 m .63537 .56891 L .62914 .57722 L F
.31271 .54444 m .30281 .53485 L .30354 .5376 L 1 .389 0 r
F
.31344 .5471 m .31271 .54444 L .30354 .5376 L 1 .361 0 r
F
.66828 .45722 m .66958 .45379 L .66969 .46284 L .873 .236 0 r
F
.63157 .50053 m .6266 .50522 L .62642 .50782 L 0 0 0 r
F
.63157 .50053 m .63176 .49791 L .6266 .50522 L F
.32409 .53176 m .31643 .52235 L .31688 .52491 L 1 .416 0 r
F
.32456 .53427 m .32409 .53176 L .31688 .52491 L 1 .385 0 r
F
.35937 .60635 m .34657 .60024 L .34805 .6023 L 1 .091 0 r
F
.36074 .6083 m .35937 .60635 L .34805 .6023 L 1 .087 0 r
F
.63098 .43727 m .62762 .44229 L .62847 .44489 L 0 0 0 r
F
.63098 .43727 m .63009 .4347 L .62762 .44229 L F
.63544 .50371 m .63 .50845 L .62981 .5111 L F
.63544 .50371 m .63563 .50103 L .63 .50845 L F
.7033 .28914 m .70084 .28502 L .70315 .29842 L 0 .002 0 r
F
.56689 .33434 m .56569 .33876 L .56776 .3409 L .102 .086 0 r
F
.56689 .33434 m .56473 .33246 L .56569 .33876 L F
.5776 .60078 m .56936 .60345 L .56801 .60513 L .038 0 0 r
F
.5776 .60078 m .57909 .59904 L .56936 .60345 L F
.34303 .64152 m .32896 .63384 L .33041 .6367 L 1 .205 0 r
F
.34446 .64419 m .34303 .64152 L .33041 .6367 L 1 .19 0 r
F
.33608 .58269 m .32428 .57498 L .32553 .57738 L 1 .191 0 r
F
.33726 .58498 m .33608 .58269 L .32553 .57738 L 1 .163 0 r
F
.43146 .63343 m .41877 .63058 L .41986 .63166 L .688 .026 0 r
F
.43232 .63441 m .43146 .63343 L .41986 .63166 L .655 .021 0 r
F
.46918 .63908 m .46915 .63831 L .4572 .6381 L .489 0 0 r
F
.48083 .6388 m .46915 .63831 L .46918 .63908 L .446 0 0 r
F
.48083 .6388 m .48109 .63803 L .46915 .63831 L F
.59725 .58062 m .58976 .58391 L .58855 .58591 L 0 0 0 r
F
.59725 .58062 m .59855 .57856 L .58976 .58391 L F
.66836 .7053 m .65902 .71204 L .65604 .71501 L F
.66836 .7053 m .67168 .70235 L .65902 .71204 L F
.44 .68173 m .42449 .68198 L .42556 .68344 L .58 .015 0 r
F
.44075 .68294 m .44 .68173 L .42556 .68344 L .552 .011 0 r
F
.45484 .68067 m .44 .68173 L .44075 .68294 L .446 0 0 r
F
.34344 .57123 m .33353 .56316 L .33455 .56545 L 1 .187 0 r
F
.34443 .57343 m .34344 .57123 L .33455 .56545 L 1 .156 0 r
F
.31875 .61067 m .30694 .60093 L .30805 .60398 L 1 .279 0 r
F
.31988 .6136 m .31875 .61067 L .30805 .60398 L 1 .261 0 r
F
.73512 .82025 m .72 .82506 L .71565 .82916 L 0 0 0 r
F
.73512 .82025 m .73987 .81595 L .72 .82506 L F
.77318 .50367 m .76972 .51285 L .76928 .5177 L F
.77318 .50367 m .77344 .49878 L .76972 .51285 L F
.90616 .39368 m .8995 .40847 L .90118 .41536 L F
.90616 .39368 m .90441 .38675 L .8995 .40847 L F
.55412 .34445 m .55661 .34237 L .55867 .34432 L 1 .199 0 r
F
.55412 .34445 m .55287 .34144 L .55661 .34237 L F
.54354 .62318 m .5342 .62485 L .53297 .62603 L .178 0 0 r
F
.54354 .62318 m .54498 .62194 L .5342 .62485 L F
.61021 .60525 m .60349 .61016 L .60179 .61223 L 0 0 0 r
F
.61021 .60525 m .61199 .60309 L .60349 .61016 L F
.46876 .67891 m .46872 .67807 L .45484 .68067 L .33 0 0 r
F
.48189 .67589 m .46872 .67807 L .46876 .67891 L .224 0 0 r
F
.48189 .67589 m .48222 .67515 L .46872 .67807 L F
.49229 .63805 m .48109 .63803 L .48083 .6388 L .394 0 0 r
F
.49229 .63805 m .49285 .63727 L .48109 .63803 L F
.51616 .63348 m .50588 .63431 L .50506 .6352 L .291 0 0 r
F
.51616 .63348 m .51724 .63255 L .50588 .63431 L F
.62872 .43788 m .6253 .44285 L .62607 .44544 L 0 0 0 r
F
.62872 .43788 m .62796 .43532 L .6253 .44285 L F
.5593 .61446 m .55051 .61658 L .54916 .61798 L .11 0 0 r
F
.5593 .61446 m .56082 .613 L .55051 .61658 L F
.63727 .33464 m .67704 .30771 L .67952 .31139 L .57 .03 0 r
F
.63727 .33464 m .63099 .33565 L .67704 .30771 L F
.25559 .82939 m .22848 .82029 L .23284 .82438 L .856 .058 0 r
F
.25954 .83324 m .25559 .82939 L .23284 .82438 L .829 .054 0 r
F
.52916 .62934 m .51935 .63057 L .51831 .63158 L .236 0 0 r
F
.52916 .62934 m .53045 .62828 L .51935 .63057 L F
.74782 .6018 m .73981 .60925 L .73799 .61358 L 0 0 0 r
F
.74782 .6018 m .74971 .59736 L .73981 .60925 L F
.20411 .79409 m .17791 .78164 L .18205 .78647 L .92 .076 0 r
F
.20796 .79865 m .20411 .79409 L .18205 .78647 L .895 .072 0 r
F
.59913 .5853 m .59144 .58851 L .59018 .59054 L 0 0 0 r
F
.59913 .5853 m .6005 .5832 L .59144 .58851 L F
.70723 .66584 m .69802 .6722 L .69541 .67583 L F
.70723 .66584 m .71008 .66214 L .69802 .6722 L F
.29717 .5639 m .28875 .55252 L .28925 .55569 L 1 .363 0 r
F
.29773 .56701 m .29717 .5639 L .28925 .55569 L 1 .34 0 r
F
.61674 .55023 m .61032 .55424 L .60945 .55656 L 0 0 0 r
F
.61674 .55023 m .61765 .54785 L .61032 .55424 L F
.90682 .56424 m .89542 .5758 L .89442 .58275 L F
.90682 .56424 m .90787 .55712 L .89542 .5758 L F
.63183 .43985 m .62847 .44489 L .62928 .44751 L F
.63183 .43985 m .63098 .43727 L .62847 .44489 L F
.50746 .66843 m .49588 .6712 L .49519 .67193 L .035 0 0 r
F
.50746 .66843 m .50851 .66772 L .49588 .6712 L F
.90072 .39476 m .89451 .40931 L .89582 .41617 L 0 0 0 r
F
.90072 .39476 m .89949 .38781 L .89451 .40931 L F
.57878 .60564 m .57043 .60825 L .56903 .60995 L .041 0 0 r
F
.57878 .60564 m .58033 .60387 L .57043 .60825 L F
.32706 .89418 m .29937 .88681 L .3037 .88979 L .608 .012 0 r
F
.33081 .89691 m .32706 .89418 L .3037 .88979 L .589 .006 0 r
F
.36498 .5968 m .35376 .59012 L .35509 .59208 L .998 .091 0 r
F
.36623 .59866 m .36498 .5968 L .35509 .59208 L .972 .087 0 r
F
.43055 .64134 m .41731 .63913 L .41845 .64028 L .697 .028 0 r
F
.43144 .6424 m .43055 .64134 L .41845 .64028 L .666 .023 0 r
F
.14491 .73508 m .12093 .71828 L .12436 .724 L .995 .103 0 r
F
.14819 .74051 m .14491 .73508 L .12436 .724 L .973 .099 0 r
F
.79657 .77973 m .78151 .78539 L .77749 .79055 L 0 0 0 r
F
.79657 .77973 m .80089 .77437 L .78151 .78539 L F
.63134 .50313 m .62642 .50782 L .6262 .5104 L F
.63134 .50313 m .63157 .50053 L .62642 .50782 L F
.29914 .85072 m .27184 .84427 L .27609 .84778 L .798 .045 0 r
F
.30289 .85401 m .29914 .85072 L .27609 .84778 L .771 .041 0 r
F
.61958 .55449 m .61283 .55842 L .61192 .56079 L 0 0 0 r
F
.61958 .55449 m .62055 .55206 L .61283 .55842 L F
.6352 .50639 m .62981 .5111 L .62958 .51375 L F
.6352 .50639 m .63544 .50371 L .62981 .5111 L F
.56897 .33631 m .56776 .3409 L .56976 .34307 L .083 .08 0 r
F
.56897 .33631 m .56689 .33434 L .56776 .3409 L F
.36745 .86965 m .3408 .86733 L .34423 .87007 L .688 .028 0 r
F
.37026 .87223 m .36745 .86965 L .34423 .87007 L .66 .023 0 r
F
.32456 .53427 m .31688 .52491 L .31737 .52746 L 1 .385 0 r
F
.32506 .53677 m .32456 .53427 L .31737 .52746 L 1 .354 0 r
F
.44484 .63656 m .43232 .63441 L .43318 .63536 L .61 .014 0 r
F
.44545 .63742 m .44484 .63656 L .43318 .63536 L .575 .008 0 r
F
.4572 .6381 m .44484 .63656 L .44545 .63742 L .546 .004 0 r
F
.38123 .62232 m .36804 .61756 L .36959 .61931 L .931 .069 0 r
F
.38263 .62396 m .38123 .62232 L .36959 .61931 L .906 .065 0 r
F
.41769 .62946 m .40512 .62589 L .4064 .62712 L .745 .036 0 r
F
.41877 .63058 m .41769 .62946 L .4064 .62712 L .712 .031 0 r
F
.8579 .69651 m .84408 .70458 L .84111 .71074 L 0 0 0 r
F
.8579 .69651 m .86105 .69014 L .84408 .70458 L F
.45525 .68165 m .45484 .68067 L .44075 .68294 L .424 0 0 r
F
.46876 .67891 m .45484 .68067 L .45525 .68165 L .33 0 0 r
F
.6526 .52433 m .65113 .53064 L .65019 .5335 L .712 .179 0 r
F
.6526 .52433 m .65347 .52145 L .65113 .53064 L F
.42449 .68198 m .40862 .68132 L .40996 .68306 L .724 .037 0 r
F
.42556 .68344 m .42449 .68198 L .40996 .68306 L .703 .034 0 r
F
.50436 .64154 m .49352 .64217 L .49295 .64302 L .328 0 0 r
F
.50436 .64154 m .50521 .64067 L .49352 .64217 L F
.45753 .63889 m .4572 .6381 L .44545 .63742 L .523 0 0 r
F
.46918 .63908 m .4572 .6381 L .45753 .63889 L .489 0 0 r
F
.38821 .67347 m .37222 .66991 L .37386 .67226 L .973 .076 0 r
F
.3897 .67555 m .38821 .67347 L .37386 .67226 L .962 .074 0 r
F
.31344 .5471 m .30354 .5376 L .30431 .54032 L 1 .361 0 r
F
.31421 .54974 m .31344 .5471 L .30431 .54032 L 1 .332 0 r
F
.4073 .67955 m .39121 .67761 L .39274 .67966 L .858 .058 0 r
F
.40862 .68132 m .4073 .67955 L .39274 .67966 L .843 .055 0 r
F
.75094 .39106 m .75907 .39741 L .76054 .40211 L .807 .094 0 r
F
.75094 .39106 m .74878 .3868 L .75907 .39741 L F
.55701 .34472 m .55412 .34445 L .55867 .34432 L .147 0 0 r
F
.66702 .46059 m .66828 .45722 L .66871 .46623 L .886 .275 0 r
F
.62944 .44046 m .62607 .44544 L .62679 .44803 L 0 0 0 r
F
.62944 .44046 m .62872 .43788 L .62607 .44544 L F
.38491 .61292 m .37296 .60747 L .3744 .60913 L .898 .067 0 r
F
.38622 .61448 m .38491 .61292 L .3744 .60913 L .869 .063 0 r
F
.46913 .64558 m .4691 .64477 L .45699 .64503 L .473 0 0 r
F
.48087 .6449 m .4691 .64477 L .46913 .64558 L .428 0 0 r
F
.48087 .6449 m .48114 .6441 L .4691 .64477 L F
.63258 .57403 m .62776 .57972 L .62634 .5822 L 0 0 0 r
F
.63258 .57403 m .63399 .57148 L .62776 .57972 L F
.32933 .88768 m .30209 .8804 L .30633 .88338 L .613 .014 0 r
F
.333 .8904 m .32933 .88768 L .30633 .88338 L .594 .008 0 r
F
.49448 .67261 m .48222 .67515 L .48189 .67589 L .11 0 0 r
F
.49448 .67261 m .49519 .67193 L .48222 .67515 L F
.63262 .44245 m .62928 .44751 L .63005 .45013 L 0 0 0 r
F
.63262 .44245 m .63183 .43985 L .62928 .44751 L F
.34443 .57343 m .33455 .56545 L .33562 .56771 L 1 .156 0 r
F
.34546 .57561 m .34443 .57343 L .33562 .56771 L 1 .126 0 r
F
.41619 .63793 m .40288 .63505 L .40423 .63635 L .764 .039 0 r
F
.41731 .63913 m .41619 .63793 L .40423 .63635 L .735 .034 0 r
F
.33726 .58498 m .32553 .57738 L .32681 .57976 L 1 .163 0 r
F
.33848 .58725 m .33726 .58498 L .32681 .57976 L 1 .135 0 r
F
.56 .6194 m .55116 .62152 L .54977 .62294 L .105 0 0 r
F
.56 .6194 m .56158 .61793 L .55116 .62152 L F
.54395 .6282 m .53461 .62991 L .53334 .63111 L .166 0 0 r
F
.54395 .6282 m .54544 .62695 L .53461 .62991 L F
.5959 .58265 m .58855 .58591 L .5873 .58788 L 0 0 0 r
F
.5959 .58265 m .59725 .58062 L .58855 .58591 L F
.89316 .56161 m .88566 .57361 L .88449 .58035 L F
.89316 .56161 m .89437 .55475 L .88566 .57361 L F
.69694 .3835 m .69246 .39215 L .69088 .39698 L F
.69694 .3835 m .69857 .37843 L .69246 .39215 L F
.36074 .6083 m .34805 .6023 L .34956 .60433 L 1 .087 0 r
F
.36213 .61022 m .36074 .6083 L .34956 .60433 L .987 .084 0 r
F
.57609 .6025 m .56801 .60513 L .56663 .60678 L .025 0 0 r
F
.57609 .6025 m .5776 .60078 L .56801 .60513 L F
.52028 .66395 m .50955 .66695 L .50851 .66772 L 0 0 0 r
F
.52028 .66395 m .52165 .66318 L .50955 .66695 L F
.78827 .7721 m .77445 .77845 L .77046 .78343 L F
.78827 .7721 m .79253 .76691 L .77445 .77845 L F
.42111 .87135 m .39607 .87269 L .39825 .87503 L .534 .009 0 r
F
.4226 .87356 m .42111 .87135 L .39825 .87503 L .503 .003 0 r
F
.36748 .66281 m .35214 .65741 L .35378 .66003 L 1 .113 0 r
F
.36903 .66519 m .36748 .66281 L .35378 .66003 L 1 .102 0 r
F
.63106 .50574 m .6262 .5104 L .62594 .51298 L 0 0 0 r
F
.63106 .50574 m .63134 .50313 L .6262 .5104 L F
.49238 .64383 m .48114 .6441 L .48087 .6449 L .373 0 0 r
F
.49238 .64383 m .49295 .64302 L .48114 .6441 L F
.40262 .62333 m .3903 .61893 L .39172 .62033 L .808 .048 0 r
F
.40386 .62463 m .40262 .62333 L .39172 .62033 L .776 .043 0 r
F
.5294 .63446 m .51961 .6358 L .51853 .63684 L .219 0 0 r
F
.5294 .63446 m .53074 .63339 L .51961 .6358 L F
.31988 .6136 m .30805 .60398 L .3092 .60703 L 1 .261 0 r
F
.32105 .61652 m .31988 .6136 L .3092 .60703 L 1 .243 0 r
F
.61578 .55259 m .60945 .55656 L .60854 .55886 L 0 0 0 r
F
.61578 .55259 m .61674 .55023 L .60945 .55656 L F
.51632 .63877 m .50605 .63975 L .50521 .64067 L .271 0 0 r
F
.51632 .63877 m .51743 .63782 L .50605 .63975 L F
.70549 .29344 m .7033 .28914 L .70434 .30358 L 0 0 0 r
F
.57097 .33835 m .56976 .34307 L .57171 .34527 L .06 .073 0 r
F
.57097 .33835 m .56897 .33631 L .56976 .34307 L F
.29773 .56701 m .28925 .55569 L .2898 .55885 L 1 .34 0 r
F
.29834 .57012 m .29773 .56701 L .2898 .55885 L 1 .318 0 r
F
.63492 .50906 m .62958 .51375 L .62931 .51639 L 0 0 0 r
F
.63492 .50906 m .6352 .50639 L .62958 .51375 L F
.84724 .69055 m .83537 .69935 L .8324 .70531 L F
.84724 .69055 m .85035 .68438 L .83537 .69935 L F
.40025 .63233 m .38698 .62865 L .38848 .63013 L .837 .052 0 r
F
.40155 .63371 m .40025 .63233 L .38848 .63013 L .809 .047 0 r
F
.44436 .64398 m .43144 .6424 L .43234 .64341 L .609 .015 0 r
F
.44498 .6449 m .44436 .64398 L .43234 .64341 L .575 .009 0 r
F
.45699 .64503 m .44436 .64398 L .44498 .6449 L .535 .004 0 r
F
.77284 .50856 m .76928 .5177 L .76876 .52254 L 0 0 0 r
F
.77284 .50856 m .77318 .50367 L .76928 .5177 L F
.12971 .75537 m .10589 .73696 L .10959 .74293 L .921 .096 0 r
F
.13327 .76106 m .12971 .75537 L .10959 .74293 L .894 .091 0 r
F
.55969 .34538 m .56084 .34606 L .5631 .34766 L 0 .112 0 r
F
.55969 .34538 m .55701 .34472 L .56084 .34606 L F
.34446 .64419 m .33041 .6367 L .33191 .63956 L 1 .19 0 r
F
.34592 .64686 m .34446 .64419 L .33191 .63956 L 1 .176 0 r
F
.32506 .53677 m .31737 .52746 L .3179 .53 L 1 .354 0 r
F
.32562 .53925 m .32506 .53677 L .3179 .53 L 1 .322 0 r
F
.63012 .44304 m .62679 .44803 L .62746 .45063 L 0 0 0 r
F
.63012 .44304 m .62944 .44046 L .62679 .44803 L F
.6434 .33399 m .67952 .31139 L .68252 .31464 L .564 .025 0 r
F
.6434 .33399 m .63727 .33464 L .67952 .31139 L F
.59773 .58736 m .59018 .59054 L .58888 .59254 L 0 0 0 r
F
.59773 .58736 m .59913 .5853 L .59018 .59054 L F
.19166 .81832 m .16556 .80391 L .17006 .80891 L .815 .064 0 r
F
.19588 .82303 m .19166 .81832 L .17006 .80891 L .784 .059 0 r
F
.61857 .55689 m .61192 .56079 L .61096 .56314 L 0 0 0 r
F
.61857 .55689 m .61958 .55449 L .61192 .56079 L F
.60839 .60737 m .60179 .61223 L .60006 .61426 L F
.60839 .60737 m .61021 .60525 L .60179 .61223 L F
.63337 .44506 m .63005 .45013 L .63077 .45277 L F
.63337 .44506 m .63262 .44245 L .63005 .45013 L F
.5034 .63684 m .49285 .63727 L .49229 .63805 L .33 0 0 r
F
.5034 .63684 m .50423 .63604 L .49285 .63727 L F
.45732 .64587 m .45699 .64503 L .44498 .6449 L .51 0 0 r
F
.46913 .64558 m .45699 .64503 L .45732 .64587 L .473 0 0 r
F
.65171 .52719 m .65019 .5335 L .64923 .53634 L .711 .18 0 r
F
.65171 .52719 m .6526 .52433 L .65019 .5335 L F
.31421 .54974 m .30431 .54032 L .30513 .54303 L 1 .332 0 r
F
.31502 .55235 m .31421 .54974 L .30513 .54303 L 1 .304 0 r
F
.36623 .59866 m .35509 .59208 L .35646 .59401 L .972 .087 0 r
F
.36751 .60049 m .36623 .59866 L .35646 .59401 L .944 .083 0 r
F
.43232 .63441 m .41986 .63166 L .42096 .6327 L .655 .021 0 r
F
.43318 .63536 m .43232 .63441 L .42096 .6327 L .62 .015 0 r
F
.55775 .61588 m .54916 .61798 L .54779 .61934 L .095 0 0 r
F
.55775 .61588 m .5593 .61446 L .54916 .61798 L F
.5772 .60737 m .56903 .60995 L .5676 .61162 L .027 0 0 r
F
.5772 .60737 m .57878 .60564 L .56903 .60995 L F
.54207 .62438 m .53297 .62603 L .53172 .62718 L .161 0 0 r
F
.54207 .62438 m .54354 .62318 L .53297 .62603 L F
.39607 .87269 m .37026 .87223 L .37311 .87471 L .613 .018 0 r
F
.39825 .87503 m .39607 .87269 L .37311 .87471 L .584 .013 0 r
F
.66581 .46389 m .66702 .46059 L .66776 .46956 L .897 .31 0 r
F
.24551 .85659 m .21838 .84521 L .22315 .84937 L .723 .04 0 r
F
.24988 .86046 m .24551 .85659 L .22315 .84937 L .69 .035 0 r
F
.90778 .40064 m .90118 .41536 L .90274 .42229 L 0 0 0 r
F
.90778 .40064 m .90616 .39368 L .90118 .41536 L F
.74584 .60621 m .73799 .61358 L .73609 .61787 L F
.74584 .60621 m .74782 .6018 L .73799 .61358 L F
.46921 .63981 m .46918 .63908 L .45753 .63889 L .47 0 0 r
F
.48056 .63952 m .46918 .63908 L .46921 .63981 L .427 0 0 r
F
.48056 .63952 m .48083 .6388 L .46918 .63908 L F
.75299 .39537 m .76054 .40211 L .76195 .40682 L .802 .096 0 r
F
.75299 .39537 m .75094 .39106 L .76054 .40211 L F
.13669 .74976 m .11371 .73147 L .11726 .73738 L .925 .098 0 r
F
.1401 .75539 m .13669 .74976 L .11726 .73738 L .898 .093 0 r
F
.63074 .50833 m .62594 .51298 L .62563 .51555 L 0 0 0 r
F
.63074 .50833 m .63106 .50574 L .62594 .51298 L F
.34546 .57561 m .33562 .56771 L .33673 .56995 L 1 .126 0 r
F
.34654 .57776 m .34546 .57561 L .33673 .56995 L 1 .111 0 r
F
.56226 .34624 m .5631 .34766 L .56539 .34918 L 0 .114 0 r
F
.56226 .34624 m .55969 .34538 L .5631 .34766 L F
.19671 .81222 m .17128 .79786 L .17565 .80283 L .823 .066 0 r
F
.20082 .81689 m .19671 .81222 L .17565 .80283 L .793 .061 0 r
F
.63074 .44564 m .62746 .45063 L .62809 .45324 L 0 0 0 r
F
.63074 .44564 m .63012 .44304 L .62746 .45063 L F
.63112 .57655 m .62634 .5822 L .62489 .58464 L F
.63112 .57655 m .63258 .57403 L .62634 .5822 L F
.57289 .34047 m .57171 .34527 L .57359 .3475 L .031 .066 0 r
F
.57289 .34047 m .57097 .33835 L .57171 .34527 L F
.52785 .63035 m .51831 .63158 L .51724 .63255 L .218 0 0 r
F
.52785 .63035 m .52916 .62934 L .51831 .63158 L F
.63458 .51172 m .62931 .51639 L .62898 .51902 L 0 0 0 r
F
.63458 .51172 m .63492 .50906 L .62931 .51639 L F
.51507 .63436 m .50506 .6352 L .50423 .63604 L .272 0 0 r
F
.51507 .63436 m .51616 .63348 L .50506 .6352 L F
.38263 .62396 m .36959 .61931 L .37118 .62102 L .906 .065 0 r
F
.38405 .62556 m .38263 .62396 L .37118 .62102 L .881 .061 0 r
F
.33848 .58725 m .32681 .57976 L .32813 .5821 L 1 .135 0 r
F
.33973 .58948 m .33848 .58725 L .32813 .5821 L 1 .109 0 r
F
.59452 .58466 m .5873 .58788 L .58602 .58982 L 0 0 0 r
F
.59452 .58466 m .5959 .58265 L .5873 .58788 L F
.63408 .44768 m .63077 .45277 L .63144 .45541 L F
.63408 .44768 m .63337 .44506 L .63077 .45277 L F
.66496 .70815 m .65604 .71501 L .65298 .71789 L F
.65185 .71881 m .64984 .72068 L .64663 .72336 L .493 .206 0 r
F
.6579 .71354 m .65365 .7173 L .65185 .71881 L F
.65365 .7173 m .64984 .72068 L .65185 .71881 L F
.66496 .70815 m .66836 .7053 L .66205 .71027 L 0 0 0 r
F
.66039 .71166 m .66205 .71027 L .65604 .71501 L F
.66496 .70815 m .66205 .71027 L .66039 .71166 L F
.49173 .63878 m .48083 .6388 L .48056 .63952 L .374 0 0 r
F
.49173 .63878 m .49229 .63805 L .48083 .6388 L F
.70431 .66947 m .69541 .67583 L .69272 .6794 L 0 0 0 r
F
.70431 .66947 m .70723 .66584 L .69541 .67583 L F
.61477 .55492 m .60854 .55886 L .60759 .56115 L F
.61477 .55492 m .61578 .55259 L .60854 .55886 L F
.90175 .40175 m .89582 .41617 L .89699 .42307 L F
.90175 .40175 m .90072 .39476 L .89582 .41617 L F
.32562 .53925 m .3179 .53 L .31848 .53252 L 1 .322 0 r
F
.32621 .54172 m .32562 .53925 L .31848 .53252 L 1 .291 0 r
F
.38622 .61448 m .3744 .60913 L .37587 .61076 L .869 .063 0 r
F
.38755 .616 m .38622 .61448 L .37587 .61076 L .838 .058 0 r
F
.24929 .8503 m .22272 .83896 L .22737 .84311 L .733 .042 0 r
F
.25356 .85416 m .24929 .8503 L .22737 .84311 L .701 .037 0 r
F
.29834 .57012 m .2898 .55885 L .29039 .56202 L 1 .318 0 r
F
.29899 .57322 m .29834 .57012 L .29039 .56202 L 1 .296 0 r
F
.41877 .63058 m .4064 .62712 L .40771 .6283 L .712 .031 0 r
F
.41986 .63166 m .41877 .63058 L .40771 .6283 L .678 .025 0 r
F
.90563 .57134 m .89442 .58275 L .89328 .58968 L 0 0 0 r
F
.90563 .57134 m .90682 .56424 L .89442 .58275 L F
.43144 .6424 m .41845 .64028 L .41961 .64139 L .666 .023 0 r
F
.43234 .64341 m .43144 .6424 L .41961 .64139 L .634 .018 0 r
F
.44075 .68294 m .42556 .68344 L .42664 .68488 L .552 .011 0 r
F
.44152 .68411 m .44075 .68294 L .42664 .68488 L .524 .007 0 r
F
.45525 .68165 m .44075 .68294 L .44152 .68411 L .424 0 0 r
F
.69522 .38848 m .69088 .39698 L .68928 .40169 L 0 0 0 r
F
.69522 .38848 m .69694 .3835 L .69088 .39698 L F
.29092 .88052 m .26348 .87148 L .26817 .87494 L .646 .022 0 r
F
.29511 .88372 m .29092 .88052 L .26817 .87494 L .628 .016 0 r
F
.36213 .61022 m .34956 .60433 L .35111 .60633 L .987 .084 0 r
F
.36356 .61211 m .36213 .61022 L .35111 .60633 L .964 .08 0 r
F
.57453 .60417 m .56663 .60678 L .56522 .60839 L .011 0 0 r
F
.57453 .60417 m .57609 .6025 L .56663 .60678 L F
.61751 .55928.502 0 0 r
F
.45801 .64741 m .44626 .6466 L .44692 .64739 L .471 0 0 r
F
.61156 .57086 m .60556 .57455 L .60435 .57675 L 0 0 0 r
F
.61156 .57086 m .61283 .56859 L .60556 .57455 L F
.52382 .63313 m .51507 .63436 L .51396 .6352 L .158 0 0 r
F
.52382 .63313 m .52518 .63225 L .51507 .63436 L F
.41132 .68478 m .39588 .68373 L .39749 .68575 L .814 .051 0 r
F
.4127 .68649 m .41132 .68478 L .39749 .68575 L .8 .049 0 r
F
.32985 .55382 m .32208 .54494 L .32293 .54738 L 1 .135 0 r
F
.3307 .55618 m .32985 .55382 L .32293 .54738 L 1 .128 0 r
F
.31974 .56515 m .30994 .55632 L .31104 .55892 L 1 .159 0 r
F
.32081 .56764 m .31974 .56515 L .31104 .55892 L 1 .132 0 r
F
.49061 .64597 m .48031 .64638 L .48003 .64704 L .302 0 0 r
F
.49061 .64597 m .49121 .6453 L .48031 .64638 L F
.62725 .52625 m .62286 .53075 L .62225 .53324 L 0 0 0 r
F
.62725 .52625 m .62788 .52372 L .62286 .53075 L F
.50082 .63898 m .49116 .63947 L .49058 .64011 L .265 0 0 r
F
.50082 .63898 m .50169 .63831 L .49116 .63947 L F
.42209 .6337 m .41038 .63054 L .41174 .63159 L .608 .013 0 r
F
.42323 .63465 m .42209 .6337 L .41174 .63159 L .589 .007 0 r
F
.64579 .54407 m .64402 .55027 L .64289 .55299 L .709 .187 0 r
F
.64579 .54407 m .64685 .5413 L .64402 .55027 L F
.65958 .48276 m .66247 .48872 L .66164 .4918 L .989 .412 0 r
F
.65958 .48276 m .6605 .47971 L .66247 .48872 L F
.50424 .6702 m .49377 .67323 L .49305 .67379 L 0 0 0 r
F
.50424 .6702 m .50532 .66967 L .49377 .67323 L F
.30207 .58559 m .29324 .57468 L .29406 .57785 L 1 .214 0 r
F
.30296 .58866 m .30207 .58559 L .29406 .57785 L 1 .195 0 r
F
.40771 .6283 m .39611 .62432 L .39763 .62557 L .672 .026 0 r
F
.40903 .62944 m .40771 .6283 L .39763 .62557 L .639 .02 0 r
F
.36491 .90757 m .33847 .90203 L .34239 .90442 L .536 0 0 r
F
.36816 .90973 m .36491 .90757 L .34239 .90442 L .513 0 0 r
F
.2002 .82765 m .17467 .81382 L .17938 .81865 L .753 .053 0 r
F
.2046 .83218 m .2002 .82765 L .17938 .81865 L .728 .048 0 r
F
.90356 .42287 m .89889 .4369 L .89962 .44384 L 0 0 0 r
F
.90356 .42287 m .90318 .41581 L .89889 .4369 L F
.63087 .5301 m .62606 .53457 L .62541 .53712 L F
.63087 .5301 m .63155 .52751 L .62606 .53457 L F
.46888 .68113 m .46884 .68044 L .45608 .68348 L .234 0 0 r
F
.48086 .67778 m .46884 .68044 L .46888 .68113 L .105 0 0 r
F
.48086 .67778 m .4812 .67721 L .46884 .68044 L F
.61954 .40515 m .6187 .40994 L .62004 .41233 L 0 .006 0 r
F
.61954 .40515 m .61817 .40284 L .6187 .40994 L F
.84771 .71529 m .83482 .72288 L .83151 .72886 L 0 0 0 r
F
.84771 .71529 m .85123 .70908 L .83482 .72288 L F
.45836 .64812 m .45801 .64741 L .44692 .64739 L .45 0 0 r
F
.46922 .64775 m .45801 .64741 L .45836 .64812 L .41 0 0 r
F
.35053 .65478 m .33662 .64812 L .33827 .65098 L 1 .141 0 r
F
.35214 .65741 m .35053 .65478 L .33827 .65098 L 1 .132 0 r
F
.42774 .68628 m .4127 .68649 L .41409 .68818 L .661 .028 0 r
F
.42885 .68767 m .42774 .68628 L .41409 .68818 L .641 .026 0 r
F
.55127 .62118 m .54354 .62318 L .54207 .62438 L .029 0 0 r
F
.55127 .62118 m .55293 .61991 L .54354 .62318 L F
.5117 .63673 m .50255 .6376 L .50169 .63831 L .208 0 0 r
F
.5117 .63673 m .51284 .63599 L .50255 .6376 L F
.63415 .46926 m .63144 .47425 L .63166 .47688 L 0 0 0 r
F
.63415 .46926 m .63396 .46663 L .63144 .47425 L F
.36804 .61756 m .35598 .61214 L .35767 .61401 L .888 .067 0 r
F
.36959 .61931 m .36804 .61756 L .35767 .61401 L .862 .063 0 r
F
.67691 .33647 m .70035 .32911 L .70402 .33207 L .58 .011 0 r
F
.67691 .33647 m .67173 .33536 L .70035 .32911 L F
.53774 .63278 m .5294 .63446 L .52805 .63549 L .086 0 0 r
F
.53774 .63278 m .53933 .6317 L .5294 .63446 L F
.56801 .61052 m .56082 .613 L .5593 .61446 L 0 0 0 r
F
.56801 .61052 m .56969 .60899 L .56082 .613 L F
.32616 .6281 m .31423 .6192 L .3156 .62224 L 1 .179 0 r
F
.32754 .63097 m .32616 .6281 L .3156 .62224 L 1 .166 0 r
F
.15504 .75118 m .13154 .73526 L .13529 .7408 L .926 .091 0 r
F
.15861 .75643 m .15504 .75118 L .13529 .7408 L .901 .087 0 r
F
.61899 .40543 m .61763 .41045 L .61887 .41286 L 0 .005 0 r
F
.61899 .40543 m .61773 .40307 L .61763 .41045 L F
.62324 .58876 m .61873 .59412 L .6171 .59641 L 0 0 0 r
F
.62324 .58876 m .62489 .58638 L .61873 .59412 L F
.37296 .60747 m .36229 .60141 L .36384 .60318 L .824 .063 0 r
F
.3744 .60913 m .37296 .60747 L .36384 .60318 L .792 .058 0 r
F
.34513 .59815 m .33384 .59123 L .33536 .59344 L .974 .091 0 r
F
.34657 .60024 m .34513 .59815 L .33536 .59344 L .949 .087 0 r
F
.58706 .59422 m .58055 .59726 L .57909 .59904 L 0 0 0 r
F
.58706 .59422 m .58863 .59237 L .58055 .59726 L F
.4693 .64171 m .46927 .64113 L .45852 .64098 L .406 0 0 r
F
.47974 .64142 m .46927 .64113 L .4693 .64171 L .362 0 0 r
F
.47974 .64142 m .48001 .64083 L .46927 .64113 L F
.69503 .67996 m .6871 .68634 L .68417 .6897 L 0 0 0 r
F
.69503 .67996 m .69821 .67654 L .6871 .68634 L F
.58308 .91225 m .56484 .91333 L .56168 .91528 L .177 0 0 r
F
.58308 .91225 m .58699 .9102 L .56484 .91333 L F
.60788 .56849 m .60224 .57222 L .60105 .57436 L 0 0 0 r
F
.60788 .56849 m .60913 .56629 L .60224 .57222 L F
.63821 .4717 m .63514 .4768 L .63539 .47949 L F
.63821 .4717 m .63795 .469 L .63514 .4768 L F
.39172 .62033 m .38047 .61542 L .38206 .6169 L .738 .042 0 r
F
.39316 .6217 m .39172 .62033 L .38206 .6169 L .704 .036 0 r
F
.36657 .90092 m .34053 .89552 L .34437 .89791 L .54 0 0 r
F
.36976 .90307 m .36657 .90092 L .34437 .89791 L .518 0 0 r
F
.30671 .85721 m .2804 .8512 L .28479 .85454 L .743 .036 0 r
F
.31059 .86033 m .30671 .85721 L .28479 .85454 L .715 .031 0 r
F
.20501 .82148 m .18011 .80771 L .18468 .81251 L .763 .055 0 r
F
.2093 .82599 m .20501 .82148 L .18468 .81251 L .734 .05 0 r
F
.40561 .63761 m .39315 .63437 L .39476 .6357 L .721 .032 0 r
F
.407 .63883 m .40561 .63761 L .39476 .6357 L .689 .027 0 r
F
.76163 .41769 m .76683 .42584 L .76786 .43064 L .777 .106 0 r
F
.76163 .41769 m .76011 .41313 L .76683 .42584 L F
.43419 .6453 m .42198 .64348 L .42319 .64447 L .567 .006 0 r
F
.43513 .64618 m .43419 .6453 L .42319 .64447 L .545 0 0 r
F
.4565 .68434 m .45608 .68348 L .44308 .68634 L .353 0 0 r
F
.46888 .68113 m .45608 .68348 L .4565 .68434 L .234 0 0 r
F
.76975 .53289 m .76593 .54175 L .76502 .54651 L 0 0 0 r
F
.76975 .53289 m .77055 .52804 L .76593 .54175 L F
.49 .64071 m .48001 .64083 L .47974 .64142 L .307 0 0 r
F
.49 .64071 m .49058 .64011 L .48001 .64083 L F
.38848 .63013 m .37613 .62595 L .37783 .62752 L .798 .047 0 r
F
.39001 .63158 m .38848 .63013 L .37783 .62752 L .769 .043 0 r
F
.42078 .64246 m .40842 .64 L .40986 .64114 L .64 .018 0 r
F
.42198 .64348 m .42078 .64246 L .40986 .64114 L .607 .013 0 r
F
.62657 .52876 m .62225 .53324 L .62159 .53572 L 0 0 0 r
F
.62657 .52876 m .62725 .52625 L .62225 .53324 L F
.83722 .70874 m .82612 .71708 L .82282 .72287 L F
.83722 .70874 m .84068 .70273 L .82612 .71708 L F
.73711 .62346 m .72994 .63051 L .72774 .63464 L F
.73711 .62346 m .73942 .61921 L .72994 .63051 L F
.62087 .40749 m .62004 .41233 L .62133 .41474 L 0 .002 0 r
F
.62087 .40749 m .61954 .40515 L .62004 .41233 L F
.49232 .6743 m .4812 .67721 L .48086 .67778 L 0 0 0 r
F
.49232 .6743 m .49305 .67379 L .4812 .67721 L F
.3307 .55618 m .32293 .54738 L .32383 .5498 L 1 .128 0 r
F
.3316 .55853 m .3307 .55618 L .32383 .5498 L .979 .124 0 r
F
.44731 .63973 m .43585 .63793 L .43677 .6387 L .508 0 0 r
F
.44794 .64041 m .44731 .63973 L .43677 .6387 L .486 0 0 r
F
.45852 .64098 m .44731 .63973 L .44794 .64041 L .463 0 0 r
F
.90128 .59257 m .89063 .60348 L .88912 .61035 L 0 0 0 r
F
.90128 .59257 m .90286 .58551 L .89063 .60348 L F
.35246 .58813 m .34288 .58078 L .34423 .58287 L .906 .09 0 r
F
.35376 .59012 m .35246 .58813 L .34423 .58287 L .876 .085 0 r
F
.53599 .62876 m .52785 .63035 L .52653 .63132 L .087 0 0 r
F
.53599 .62876 m .53754 .62773 L .52785 .63035 L F
.32081 .56764 m .31104 .55892 L .31218 .56149 L 1 .132 0 r
F
.32193 .57011 m .32081 .56764 L .31218 .56149 L 1 .119 0 r
F
.61023 .57311 m .60435 .57675 L .60311 .57893 L 0 0 0 r
F
.61023 .57311 m .61156 .57086 L .60435 .57675 L F
.6343 .47191 m .63166 .47688 L .63183 .47952 L F
.6343 .47191 m .63415 .46926 L .63166 .47688 L F
.59875 .61742 m .59281 .62198 L .59091 .62381 L F
.59875 .61742 m .60075 .61549 L .59281 .62198 L F
.62021 .40781 m .61887 .41286 L .62007 .41529 L F
.62021 .40781 m .61899 .40543 L .61887 .41286 L F
.65871 .48578 m .66164 .4918 L .66082 .49485 L .993 .41 0 r
F
.65871 .48578 m .65958 .48276 L .66164 .4918 L F
.63015 .53268 m .62541 .53712 L .62471 .53965 L 0 0 0 r
F
.63015 .53268 m .63087 .5301 L .62541 .53712 L F
.64469 .54683 m .64289 .55299 L .64172 .5557 L .709 .189 0 r
F
.64469 .54683 m .64579 .54407 L .64289 .55299 L F
.58848 .5991 m .58184 .60207 L .58033 .60387 L 0 0 0 r
F
.58848 .5991 m .59012 .59722 L .58184 .60207 L F
.37386 .67226 m .3589 .66789 L .36067 .67052 L 1 .085 0 r
F
.37553 .6746 m .37386 .67226 L .36067 .67052 L 1 .084 0 r
F
.52387 .63829 m .51519 .63966 L .51404 .64051 L .129 0 0 r
F
.52387 .63829 m .52528 .63741 L .51519 .63966 L F
.45887 .64159 m .45852 .64098 L .44794 .64041 L .44 0 0 r
F
.4693 .64171 m .45852 .64098 L .45887 .64159 L .406 0 0 r
F
.7124 .31716 m .71154 .31218 L .70677 .33032 L 0 0 0 r
F
.5688 .61548 m .56158 .61793 L .56 .6194 L F
.5688 .61548 m .57054 .61394 L .56158 .61793 L F
.58711 .36133 m .58747 .36537 L .5895 .36718 L 0 .071 0 r
F
.58711 .36133 m .58506 .35967 L .58747 .36537 L F
.58434 .3642 m .58176 .36319 L .58741 .36543 L 0 .079 0 r
F
.58434 .3642 m .58741 .36543 L .58921 .36746 L F
.63842 .4744 m .63539 .47949 L .63559 .48219 L 0 0 0 r
F
.63842 .4744 m .63821 .4717 L .63539 .47949 L F
.41913 .91736 m .3939 .91403 L .39646 .91585 L .46 0 0 r
F
.4209 .91899 m .41913 .91736 L .39646 .91585 L .436 0 0 r
F
.57927 .8975 m .56185 .89948 L .55877 .90126 L .102 0 0 r
F
.57927 .8975 m .58308 .89566 L .56185 .89948 L F
.30296 .58866 m .29406 .57785 L .29494 .58102 L 1 .195 0 r
F
.30389 .59174 m .30296 .58866 L .29494 .58102 L 1 .176 0 r
F
.55167 .62617 m .54395 .6282 L .54243 .62941 L .015 0 0 r
F
.55167 .62617 m .55339 .6249 L .54395 .6282 L F
.50082 .64454 m .49121 .6453 L .49061 .64597 L .232 0 0 r
F
.50082 .64454 m .50172 .64386 L .49121 .6453 L F
.8873 .58892 m .88031 .60046 L .87869 .60711 L 0 0 0 r
F
.8873 .58892 m .88892 .58212 L .88031 .60046 L F
.68193 .33783 m .67691 .33647 L .70402 .33207 L .59 .011 0 r
F
.62215 .40985 m .62133 .41474 L .62258 .41717 L 0 0 0 r
F
.62215 .40985 m .62087 .40749 L .62133 .41474 L F
.3943 .68169 m .37895 .67929 L .3807 .68164 L .931 .069 0 r
F
.39588 .68373 m .3943 .68169 L .3807 .68164 L .921 .068 0 r
F
.78295 .79535 m .76915 .80062 L .76483 .80553 L 0 0 0 r
F
.78295 .79535 m .7876 .79023 L .76915 .80062 L F
.25433 .86424 m .22801 .85343 L .23296 .85739 L .671 .029 0 r
F
.25887 .86791 m .25433 .86424 L .23296 .85739 L .653 .023 0 r
F
.65425 .71606 m .64663 .72336 L .64334 .72594 L .529 .214 0 r
F
.65425 .71606 m .6579 .71354 L .64663 .72336 L F
.21592 .80753 m .19061 .79592 L .19503 .80053 L .844 .063 0 r
F
.22002 .81186 m .21592 .80753 L .19503 .80053 L .817 .059 0 r
F
.60658 .57067 m .60105 .57436 L .59982 .57647 L 0 0 0 r
F
.60658 .57067 m .60788 .56849 L .60105 .57436 L F
.41998 .91027 m .39512 .90718 L .39764 .90899 L .458 0 0 r
F
.42172 .91188 m .41998 .91027 L .39764 .90899 L .434 0 0 r
F
.62585 .53127 m .62159 .53572 L .62089 .53818 L 0 0 0 r
F
.62585 .53127 m .62657 .52876 L .62159 .53572 L F
.5117 .64206 m .50261 .64314 L .50172 .64386 L .175 0 0 r
F
.5117 .64206 m .51288 .64131 L .50261 .64314 L F
.62154 .59112 m .6171 .59641 L .61543 .59867 L 0 0 0 r
F
.62154 .59112 m .62324 .58876 L .6171 .59641 L F
.34657 .60024 m .33536 .59344 L .33693 .59562 L .949 .087 0 r
F
.34805 .6023 m .34657 .60024 L .33693 .59562 L .924 .083 0 r
F
.58546 .59604 m .57909 .59904 L .5776 .60078 L 0 0 0 r
F
.58546 .59604 m .58706 .59422 L .57909 .59904 L F
.62138 .41021 m .62007 .41529 L .62122 .41774 L F
.62138 .41021 m .62021 .40781 L .62007 .41529 L F
.63439 .47455 m .63183 .47952 L .63195 .48215 L F
.63439 .47455 m .6343 .47191 L .63183 .47952 L F
.43585 .63793 m .42439 .63556 L .42556 .63642 L .544 0 0 r
F
.43677 .6387 m .43585 .63793 L .42556 .63642 L .522 0 0 r
F
.91295 .42887 m .90667 .44324 L .90772 .45027 L 0 0 0 r
F
.91295 .42887 m .91185 .42176 L .90667 .44324 L F
.36959 .61931 m .35767 .61401 L .35939 .61585 L .862 .063 0 r
F
.37118 .62102 m .36959 .61931 L .35939 .61585 L .834 .058 0 r
F
.3744 .60913 m .36384 .60318 L .36541 .60492 L .792 .058 0 r
F
.37587 .61076 m .3744 .60913 L .36541 .60492 L .759 .053 0 r
F
.5663 .61202 m .5593 .61446 L .55775 .61588 L 0 0 0 r
F
.5663 .61202 m .56801 .61052 L .5593 .61446 L F
.1407 .77222 m .11736 .75468 L .12141 .76045 L .839 .082 0 r
F
.14458 .7777 m .1407 .77222 L .12141 .76045 L .811 .077 0 r
F
.46926 .64838 m .46922 .64775 L .45836 .64812 L .385 0 0 r
F
.47974 .64765 m .46922 .64775 L .46926 .64838 L .336 0 0 r
F
.47974 .64765 m .48003 .64704 L .46922 .64775 L F
.32754 .63097 m .3156 .62224 L .317 .62528 L 1 .166 0 r
F
.32896 .63384 m .32754 .63097 L .317 .62528 L 1 .154 0 r
F
.3316 .55853 m .32383 .5498 L .32478 .55221 L .979 .124 0 r
F
.33254 .56086 m .3316 .55853 L .32478 .55221 L .954 .12 0 r
F
.52244 .63397 m .51396 .6352 L .51284 .63599 L .136 0 0 r
F
.52244 .63397 m .52382 .63313 L .51396 .6352 L F
.40903 .62944 m .39763 .62557 L .39917 .62678 L .639 .02 0 r
F
.41038 .63054 m .40903 .62944 L .39917 .62678 L .62 .014 0 r
F
.58912 .36304 m .5895 .36718 L .59149 .36904 L 0 .066 0 r
F
.58912 .36304 m .58711 .36133 L .5895 .36718 L F
.54959 .6224 m .54207 .62438 L .54058 .62554 L .01 0 0 r
F
.54959 .6224 m .55127 .62118 L .54207 .62438 L F
.42323 .63465 m .41174 .63159 L .41313 .63261 L .589 .007 0 r
F
.42439 .63556 m .42323 .63465 L .41313 .63261 L .568 0 0 r
F
.25791 .85792 m .2321 .84716 L .23693 .85111 L .678 .031 0 r
F
.26234 .86158 m .25791 .85792 L .23693 .85111 L .66 .025 0 r
F
.3939 .91403 m .36816 .90973 L .37145 .91177 L .492 0 0 r
F
.39646 .91585 m .3939 .91403 L .37145 .91177 L .468 0 0 r
F
.33461 .89952 m .30809 .89267 L .31255 .89543 L .568 0 0 r
F
.33847 .90203 m .33461 .89952 L .31255 .89543 L .546 0 0 r
F
.58666 .3655 m .58434 .3642 L .58921 .36746 L 0 .063 0 r
F
.58666 .3655 m .58921 .36746 L .59105 .36944 L F
.62938 .53525 m .62471 .53965 L .62397 .54217 L 0 0 0 r
F
.62938 .53525 m .63015 .53268 L .62471 .53965 L F
.63858 .4771 m .63559 .48219 L .63574 .48488 L F
.63858 .4771 m .63842 .4744 L .63559 .48219 L F
.76304 .42228 m .76786 .43064 L .76881 .43545 L .774 .109 0 r
F
.76304 .42228 m .76163 .41769 L .76786 .43064 L F
.37311 .87471 m .34772 .87272 L .35126 .87528 L .631 .018 0 r
F
.37601 .8771 m .37311 .87471 L .35126 .87528 L .601 .013 0 r
F
.35214 .65741 m .33827 .65098 L .33995 .65384 L 1 .132 0 r
F
.35378 .66003 m .35214 .65741 L .33995 .65384 L 1 .124 0 r
F
.32193 .57011 m .31218 .56149 L .31337 .56405 L 1 .119 0 r
F
.32308 .57256 m .32193 .57011 L .31337 .56405 L 1 .115 0 r
F
.44692 .64739 m .43513 .64618 L .43608 .64701 L .502 0 0 r
F
.44758 .64813 m .44692 .64739 L .43608 .64701 L .481 0 0 r
F
.45836 .64812 m .44692 .64739 L .44758 .64813 L .45 0 0 r
F
.65788 .48878 m .66082 .49485 L .66002 .49788 L .994 .404 0 r
F
.65788 .48878 m .65871 .48578 L .66082 .49485 L F
.77487 .78718 m .7622 .79315 L .75792 .79788 L 0 0 0 r
F
.77487 .78718 m .77944 .78223 L .7622 .79315 L F
.49994 .63959 m .49058 .64011 L .49 .64071 L .24 0 0 r
F
.49994 .63959 m .50082 .63898 L .49058 .64011 L F
.35376 .59012 m .34423 .58287 L .34562 .58493 L .876 .085 0 r
F
.35509 .59208 m .35376 .59012 L .34562 .58493 L .847 .08 0 r
F
.60887 .57533 m .60311 .57893 L .60182 .58108 L 0 0 0 r
F
.60887 .57533 m .61023 .57311 L .60311 .57893 L F
.39316 .6217 m .38206 .6169 L .38368 .61835 L .704 .036 0 r
F
.39462 .62303 m .39316 .6217 L .38368 .61835 L .675 .03 0 r
F
.9037 .42995 m .89962 .44384 L .90021 .45079 L 0 0 0 r
F
.9037 .42995 m .90356 .42287 L .89962 .44384 L F
.49001 .64658 m .48003 .64704 L .47974 .64765 L .275 0 0 r
F
.49001 .64658 m .49061 .64597 L .48003 .64704 L F
.62339 .41224 m .62258 .41717 L .62379 .41962 L 0 0 0 r
F
.62339 .41224 m .62215 .40985 L .62258 .41717 L F
.64355 .54958 m .64172 .5557 L .64053 .55838 L .71 .191 0 r
F
.64355 .54958 m .64469 .54683 L .64172 .5557 L F
.53613 .63381 m .52805 .63549 L .52668 .63647 L .063 0 0 r
F
.53613 .63381 m .53774 .63278 L .52805 .63549 L F
.76886 .53772 m .76502 .54651 L .76404 .55125 L 0 0 0 r
F
.76886 .53772 m .76975 .53289 L .76502 .54651 L F
.14726 .76643 m .12469 .749 L .12858 .75471 L .844 .084 0 r
F
.151 .77186 m .14726 .76643 L .12858 .75471 L .817 .079 0 r
F
.39512 .90718 m .36976 .90307 L .373 .90511 L .493 0 0 r
F
.39764 .90899 m .39512 .90718 L .373 .90511 L .47 0 0 r
F
.33674 .89301 m .31063 .88626 L .315 .88902 L .574 .001 0 r
F
.34053 .89552 m .33674 .89301 L .315 .88902 L .553 0 0 r
F
.51055 .63743 m .50169 .63831 L .50082 .63898 L .184 0 0 r
F
.51055 .63743 m .5117 .63673 L .50169 .63831 L F
.4127 .68649 m .39749 .68575 L .39912 .68778 L .8 .049 0 r
F
.41409 .68818 m .4127 .68649 L .39912 .68778 L .786 .048 0 r
F
.6225 .41264 m .62122 .41774 L .62233 .42021 L 0 0 0 r
F
.6225 .41264 m .62138 .41021 L .62122 .41774 L F
.39001 .63158 m .37783 .62752 L .37957 .62905 L .769 .043 0 r
F
.39157 .63299 m .39001 .63158 L .37957 .62905 L .739 .038 0 r
F
.58681 .60094 m .58033 .60387 L .57878 .60564 L 0 0 0 r
F
.58681 .60094 m .58848 .5991 L .58033 .60387 L F
.44308 .68634 m .42885 .68767 L .42998 .68903 L .474 0 0 r
F
.44387 .68741 m .44308 .68634 L .42998 .68903 L .457 0 0 r
F
.4565 .68434 m .44308 .68634 L .44387 .68741 L .353 0 0 r
F
.407 .63883 m .39476 .6357 L .39639 .63699 L .689 .027 0 r
F
.40842 .64 m .407 .63883 L .39639 .63699 L .658 .022 0 r
F
.30389 .59174 m .29494 .58102 L .29585 .58418 L 1 .176 0 r
F
.30486 .59481 m .30389 .59174 L .29585 .58418 L 1 .159 0 r
F
.63445 .47719 m .63195 .48215 L .63203 .48479 L 0 0 0 r
F
.63445 .47719 m .63439 .47455 L .63195 .48215 L F
.86376 .27339 m .86339 .28887 L .86695 .29498 L 0 .003 0 r
F
.45871 .64877 m .45836 .64812 L .44758 .64813 L .426 0 0 r
F
.46926 .64838 m .45836 .64812 L .45871 .64877 L .385 0 0 r
F
.69178 .6833 m .68417 .6897 L .68117 .69298 L 0 0 0 r
F
.69178 .6833 m .69503 .67996 L .68417 .6897 L F
.59671 .61931 m .59091 .62381 L .58898 .6256 L F
.59671 .61931 m .59875 .61742 L .59091 .62381 L F
.62508 .53376 m .62089 .53818 L .62014 .54062 L F
.62508 .53376 m .62585 .53127 L .62089 .53818 L F
.86373 .2734 m .86258 .28927 L .86598 .29544 L 0 .002 0 r
F
.73471 .62767 m .72774 .63464 L .72545 .63872 L 0 0 0 r
F
.73471 .62767 m .73711 .62346 L .72774 .63464 L F
.59109 .3648 m .59149 .36904 L .59344 .37093 L 0 .061 0 r
F
.59109 .3648 m .58912 .36304 L .59149 .36904 L F
.60525 .57283 m .59982 .57647 L .59855 .57856 L 0 0 0 r
F
.60525 .57283 m .60658 .57067 L .59982 .57647 L F
.46934 .64226 m .4693 .64171 L .45887 .64159 L .381 0 0 r
F
.47946 .64196 m .4693 .64171 L .46934 .64226 L .337 0 0 r
F
.47946 .64196 m .47974 .64142 L .4693 .64171 L F
.50314 .67067 m .49305 .67379 L .49232 .6743 L 0 0 0 r
F
.50314 .67067 m .50424 .6702 L .49305 .67379 L F
.58886 .36695 m .59105 .36944 L .59292 .3714 L 0 .057 0 r
F
.58886 .36695 m .58666 .3655 L .59105 .36944 L F
.56702 .61699 m .56 .6194 L .55839 .62084 L 0 0 0 r
F
.56702 .61699 m .5688 .61548 L .56 .6194 L F
.6387 .47981 m .63574 .48488 L .63584 .48758 L F
.6387 .47981 m .63858 .4771 L .63574 .48488 L F
.42198 .64348 m .40986 .64114 L .41132 .64223 L .607 .013 0 r
F
.42319 .64447 m .42198 .64348 L .41132 .64223 L .578 .007 0 r
F
.84407 .72143 m .83151 .72886 L .82807 .73478 L 0 0 0 r
F
.84407 .72143 m .84771 .71529 L .83151 .72886 L F
.53441 .62974 m .52653 .63132 L .52518 .63225 L .066 0 0 r
F
.53441 .62974 m .53599 .62876 L .52653 .63132 L F
.43513 .64618 m .42319 .64447 L .42442 .64541 L .545 0 0 r
F
.43608 .64701 m .43513 .64618 L .42442 .64541 L .525 0 0 r
F
.33254 .56086 m .32478 .55221 L .32577 .55459 L .954 .12 0 r
F
.33353 .56316 m .33254 .56086 L .32577 .55459 L .929 .116 0 r
F
.62459 .41464 m .62379 .41962 L .62495 .42209 L 0 0 0 r
F
.62459 .41464 m .62339 .41224 L .62379 .41962 L F
.42885 .68767 m .41409 .68818 L .41551 .68987 L .641 .026 0 r
F
.42998 .68903 m .42885 .68767 L .41551 .68987 L .621 .023 0 r
F
.62856 .5378 m .62397 .54217 L .62318 .54467 L 0 0 0 r
F
.62856 .5378 m .62938 .53525 L .62397 .54217 L F
.46892 .68177 m .46888 .68113 L .4565 .68434 L .197 0 0 r
F
.48051 .67831 m .46888 .68113 L .46892 .68177 L .059 0 0 r
F
.48051 .67831 m .48086 .67778 L .46888 .68113 L F
.48941 .64126 m .47974 .64142 L .47946 .64196 L .282 0 0 r
F
.48941 .64126 m .49 .64071 L .47974 .64142 L F
.26767 .84068 m .24179 .83233 L .24638 .83618 L .775 .045 0 r
F
.27184 .84427 m .26767 .84068 L .24638 .83618 L .747 .04 0 r
F
.6198 .59344 m .61543 .59867 L .61373 .6009 L 0 0 0 r
F
.6198 .59344 m .62154 .59112 L .61543 .59867 L F
.34805 .6023 m .33693 .59562 L .33853 .59777 L .924 .083 0 r
F
.34956 .60433 m .34805 .6023 L .33853 .59777 L .899 .079 0 r
F
.58383 .59782 m .5776 .60078 L .57609 .6025 L 0 0 0 r
F
.58383 .59782 m .58546 .59604 L .5776 .60078 L F
.44794 .64041 m .43677 .6387 L .4377 .63942 L .486 0 0 r
F
.44859 .64105 m .44794 .64041 L .4377 .63942 L .463 0 0 r
F
.45887 .64159 m .44794 .64041 L .44859 .64105 L .44 0 0 r
F
.54992 .6274 m .54243 .62941 L .54089 .63058 L 0 0 0 r
F
.54992 .6274 m .55167 .62617 L .54243 .62941 L F
.65709 .49176 m .66002 .49788 L .65921 .50089 L .992 .394 0 r
F
.65709 .49176 m .65788 .48878 L .66002 .49788 L F
.15861 .75643 m .13529 .7408 L .13914 .74627 L .901 .087 0 r
F
.16228 .7616 m .15861 .75643 L .13914 .74627 L .876 .083 0 r
F
.62357 .41508 m .62233 .42021 L .62338 .42269 L 0 0 0 r
F
.62357 .41508 m .6225 .41264 L .62233 .42021 L F
.89956 .5996 m .88912 .61035 L .88747 .61719 L F
.89956 .5996 m .90128 .59257 L .88912 .61035 L F
.32308 .57256 m .31337 .56405 L .3146 .56658 L 1 .115 0 r
F
.32428 .57498 m .32308 .57256 L .3146 .56658 L .986 .111 0 r
F
.37587 .61076 m .36541 .60492 L .36703 .60663 L .759 .053 0 r
F
.37737 .61235 m .37587 .61076 L .36703 .60663 L .727 .047 0 r
F
.60747 .57752 m .60182 .58108 L .6005 .5832 L 0 0 0 r
F
.60747 .57752 m .60887 .57533 L .60182 .58108 L F
.37553 .6746 m .36067 .67052 L .36247 .67316 L 1 .084 0 r
F
.37722 .67694 m .37553 .6746 L .36247 .67316 L 1 .083 0 r
F
.52244 .63913 m .51404 .64051 L .51288 .64131 L .104 0 0 r
F
.52244 .63913 m .52387 .63829 L .51404 .64051 L F
.29937 .88681 m .27293 .87831 L .27777 .88156 L .609 .01 0 r
F
.3037 .88979 m .29937 .88681 L .27777 .88156 L .588 .004 0 r
F
.63446 .47983 m .63203 .48479 L .63207 .48742 L 0 0 0 r
F
.63446 .47983 m .63445 .47719 L .63203 .48479 L F
.37118 .62102 m .35939 .61585 L .36115 .61765 L .834 .058 0 r
F
.3728 .6227 m .37118 .62102 L .36115 .61765 L .806 .054 0 r
F
.35509 .59208 m .34562 .58493 L .34705 .58696 L .847 .08 0 r
F
.35646 .59401 m .35509 .59208 L .34705 .58696 L .816 .075 0 r
F
.64238 .55231 m .64053 .55838 L .63929 .56105 L .711 .192 0 r
F
.64238 .55231 m .64355 .54958 L .64053 .55838 L F
.56456 .61347 m .55775 .61588 L .55617 .61726 L 0 0 0 r
F
.56456 .61347 m .5663 .61202 L .55775 .61588 L F
.83365 .71469 m .82282 .72287 L .81941 .72861 L F
.83365 .71469 m .83722 .70874 L .82282 .72287 L F
.32896 .63384 m .317 .62528 L .31844 .62832 L 1 .154 0 r
F
.33041 .6367 m .32896 .63384 L .31844 .62832 L 1 .142 0 r
F
.59301 .36659 m .59344 .37093 L .59536 .37285 L 0 .056 0 r
F
.59301 .36659 m .59109 .3648 L .59344 .37093 L F
.76434 .42692 m .76881 .43545 L .76968 .44027 L .772 .112 0 r
F
.76434 .42692 m .76304 .42228 L .76881 .43545 L F
.45921 .64215 m .45887 .64159 L .44859 .64105 L .415 0 0 r
F
.46934 .64226 m .45887 .64159 L .45921 .64215 L .381 0 0 r
F
.59098 .3685 m .59292 .3714 L .5948 .37334 L 0 .053 0 r
F
.59098 .3685 m .58886 .36695 L .59292 .3714 L F
.45693 .68515 m .4565 .68434 L .44387 .68741 L .326 0 0 r
F
.46892 .68177 m .4565 .68434 L .45693 .68515 L .197 0 0 r
F
.62427 .53623 m .62014 .54062 L .61936 .54305 L 0 0 0 r
F
.62427 .53623 m .62508 .53376 L .62014 .54062 L F
.42412 .87568 m .40047 .87727 L .40273 .87942 L .479 0 0 r
F
.42566 .87768 m .42412 .87568 L .40273 .87942 L .461 0 0 r
F
.63876 .48252 m .63584 .48758 L .6359 .49027 L 0 0 0 r
F
.63876 .48252 m .6387 .47981 L .63584 .48758 L F
.2046 .83218 m .17938 .81865 L .18419 .82338 L .728 .048 0 r
F
.20911 .83661 m .2046 .83218 L .18419 .82338 L .711 .042 0 r
F
.62574 .41708 m .62495 .42209 L .62607 .42458 L 0 0 0 r
F
.62574 .41708 m .62459 .41464 L .62495 .42209 L F
.30209 .8804 m .2761 .87197 L .28083 .87523 L .616 .012 0 r
F
.30633 .88338 m .30209 .8804 L .28083 .87523 L .596 .006 0 r
F
.49991 .64517 m .49061 .64597 L .49001 .64658 L .203 0 0 r
F
.49991 .64517 m .50082 .64454 L .49061 .64597 L F
.34423 .87007 m .31855 .86629 L .32262 .86913 L .675 .024 0 r
F
.34772 .87272 m .34423 .87007 L .32262 .86913 L .645 .019 0 r
F
.49159 .67474 m .48086 .67778 L .48051 .67831 L 0 0 0 r
F
.49159 .67474 m .49232 .6743 L .48086 .67778 L F
.54788 .62358 m .54058 .62554 L .53907 .62665 L F
.54788 .62358 m .54959 .6224 L .54058 .62554 L F
.88556 .59571 m .87869 .60711 L .87696 .61374 L F
.88556 .59571 m .8873 .58892 L .87869 .60711 L F
.41038 .63054 m .39917 .62678 L .40073 .62795 L .62 .014 0 r
F
.41174 .63159 m .41038 .63054 L .40073 .62795 L .6 .008 0 r
F
.39462 .62303 m .38368 .61835 L .38532 .61975 L .675 .03 0 r
F
.39611 .62432 m .39462 .62303 L .38532 .61975 L .656 .024 0 r
F
.30486 .59481 m .29585 .58418 L .29682 .58735 L 1 .159 0 r
F
.30588 .59787 m .30486 .59481 L .29682 .58735 L 1 .143 0 r
F
.76788 .54254 m .76404 .55125 L .76297 .55597 L 0 0 0 r
F
.76788 .54254 m .76886 .53772 L .76404 .55125 L F
.60387 .57496 m .59855 .57856 L .59725 .58062 L F
.60387 .57496 m .60525 .57283 L .59855 .57856 L F
.62459 .41755 m .62338 .42269 L .62439 .42519 L F
.62459 .41755 m .62357 .41508 L .62338 .42269 L F
.5851 .60274 m .57878 .60564 L .5772 .60737 L F
.5851 .60274 m .58681 .60094 L .57878 .60564 L F
.91391 .436 m .90772 .45027 L .90865 .45732 L F
.91391 .436 m .91295 .42887 L .90772 .45027 L F
.43677 .6387 m .42556 .63642 L .42675 .63725 L .522 0 0 r
F
.4377 .63942 m .43677 .6387 L .42675 .63725 L .499 0 0 r
F
.51051 .64277 m .50172 .64386 L .50082 .64454 L .147 0 0 r
F
.51051 .64277 m .5117 .64206 L .50172 .64386 L F
.52104 .63477 m .51284 .63599 L .5117 .63673 L .113 0 0 r
F
.52104 .63477 m .52244 .63397 L .51284 .63599 L F
.33353 .56316 m .32577 .55459 L .3268 .55696 L .929 .116 0 r
F
.33455 .56545 m .33353 .56316 L .3268 .55696 L .902 .111 0 r
F
.39588 .68373 m .3807 .68164 L .38247 .684 L .921 .068 0 r
F
.39749 .68575 m .39588 .68373 L .38247 .684 L .913 .066 0 r
F
.62769 .54033 m .62318 .54467 L .62235 .54715 L 0 0 0 r
F
.62769 .54033 m .62856 .5378 L .62318 .54467 L F
.35378 .66003 m .33995 .65384 L .34167 .6567 L 1 .124 0 r
F
.35545 .66265 m .35378 .66003 L .34167 .6567 L 1 .118 0 r
F
.42439 .63556 m .41313 .63261 L .41453 .63358 L .568 0 0 r
F
.42556 .63642 m .42439 .63556 L .41453 .63358 L .546 0 0 r
F
.40047 .87727 m .37601 .8771 L .37896 .87939 L .554 .008 0 r
F
.40273 .87942 m .40047 .87727 L .37896 .87939 L .524 .003 0 r
F
.2093 .82599 m .18468 .81251 L .18935 .81723 L .734 .05 0 r
F
.21368 .8304 m .2093 .82599 L .18935 .81723 L .718 .045 0 r
F
.63443 .48247 m .63207 .48742 L .63205 .49005 L 0 0 0 r
F
.63443 .48247 m .63446 .47983 L .63207 .48742 L F
.55523 .91882 m .53652 .91942 L .53408 .92105 L .207 0 0 r
F
.55523 .91882 m .55848 .91711 L .53652 .91942 L F
.65052 .71847 m .64334 .72594 L .63997 .7284 L .563 .22 0 r
F
.65052 .71847 m .65425 .71606 L .64334 .72594 L F
.65633 .49472 m .65921 .50089 L .65841 .50387 L .988 .382 0 r
F
.65633 .49472 m .65709 .49176 L .65921 .50089 L F
.5949 .36843 m .59536 .37285 L .59723 .37481 L 0 .051 0 r
F
.5949 .36843 m .59301 .36659 L .59536 .37285 L F
.59464 .62116 m .58898 .6256 L .58702 .62734 L 0 0 0 r
F
.59464 .62116 m .59671 .61931 L .58898 .6256 L F
.53449 .6348 m .52668 .63647 L .52528 .63741 L .04 0 0 r
F
.53449 .6348 m .53613 .63381 L .52668 .63647 L F
.39157 .63299 m .37957 .62905 L .38134 .63054 L .739 .038 0 r
F
.39315 .63437 m .39157 .63299 L .38134 .63054 L .708 .033 0 r
F
.46929 .64896 m .46926 .64838 L .45871 .64877 L .359 0 0 r
F
.47945 .64822 m .46926 .64838 L .46929 .64896 L .308 0 0 r
F
.47945 .64822 m .47974 .64765 L .46926 .64838 L F
.90359 .43704 m .90021 .45079 L .90065 .45775 L 0 0 0 r
F
.90359 .43704 m .9037 .42995 L .90021 .45079 L F
.59303 .37013 m .5948 .37334 L .59667 .37529 L 0 .048 0 r
F
.59303 .37013 m .59098 .3685 L .5948 .37334 L F
.62684 .41953 m .62607 .42458 L .62714 .42708 L 0 0 0 r
F
.62684 .41953 m .62574 .41708 L .62607 .42458 L F
.49905 .64016 m .49 .64071 L .48941 .64126 L .214 0 0 r
F
.49905 .64016 m .49994 .63959 L .49 .64071 L F
.32428 .57498 m .3146 .56658 L .31588 .5691 L .986 .111 0 r
F
.32553 .57738 m .32428 .57498 L .31588 .5691 L .963 .107 0 r
F
.56521 .61845 m .55839 .62084 L .55675 .62224 L 0 0 0 r
F
.56521 .61845 m .56702 .61699 L .55839 .62084 L F
.63877 .48523 m .6359 .49027 L .6359 .49297 L F
.63877 .48523 m .63876 .48252 L .6359 .49027 L F
.61802 .59573 m .61373 .6009 L .61199 .60309 L F
.61802 .59573 m .6198 .59344 L .61373 .6009 L F
.34956 .60433 m .33853 .59777 L .34018 .5999 L .899 .079 0 r
F
.35111 .60633 m .34956 .60433 L .34018 .5999 L .872 .075 0 r
F
.44758 .64813 m .43608 .64701 L .43705 .6478 L .481 0 0 r
F
.44825 .64882 m .44758 .64813 L .43705 .6478 L .459 0 0 r
F
.45871 .64877 m .44758 .64813 L .44825 .64882 L .426 0 0 r
F
.58216 .59958 m .57609 .6025 L .57453 .60417 L 0 0 0 r
F
.58216 .59958 m .58383 .59782 L .57609 .6025 L F
.60602 .57968 m .6005 .5832 L .59913 .5853 L F
.60602 .57968 m .60747 .57752 L .6005 .5832 L F
.40842 .64 m .39639 .63699 L .39805 .63825 L .658 .022 0 r
F
.40986 .64114 m .40842 .64 L .39805 .63825 L .626 .016 0 r
F
.62342 .5387 m .61936 .54305 L .61853 .54546 L 0 0 0 r
F
.62342 .5387 m .62427 .53623 L .61936 .54305 L F
.73223 .63182 m .72545 .63872 L .72309 .64276 L F
.73223 .63182 m .73471 .62767 L .72545 .63872 L F
.64117 .55502 m .63929 .56105 L .63802 .56369 L .711 .194 0 r
F
.64117 .55502 m .64238 .55231 L .63929 .56105 L F
.50938 .63809 m .50082 .63898 L .49994 .63959 L .159 0 0 r
F
.50938 .63809 m .51055 .63743 L .50082 .63898 L F
.62556 .42003 m .62439 .42519 L .62536 .4277 L 0 0 0 r
F
.62556 .42003 m .62459 .41755 L .62439 .42519 L F
.4894 .64715 m .47974 .64765 L .47945 .64822 L .246 0 0 r
F
.4894 .64715 m .49001 .64658 L .47974 .64765 L F
.35646 .59401 m .34705 .58696 L .34852 .58897 L .816 .075 0 r
F
.35786 .59591 m .35646 .59401 L .34852 .58897 L .786 .07 0 r
F
.86726 .27945 m .86695 .29498 L .8704 .30115 L 0 0 0 r
F
.86726 .27945 m .86376 .27339 L .86695 .29498 L F
.37737 .61235 m .36703 .60663 L .36867 .6083 L .727 .047 0 r
F
.3789 .6139 m .37737 .61235 L .36867 .6083 L .71 .042 0 r
F
.7782 .80039 m .76483 .80553 L .7604 .81036 L 0 0 0 r
F
.7782 .80039 m .78295 .79535 L .76483 .80553 L F
.31059 .86033 m .28479 .85454 L .28926 .85779 L .715 .031 0 r
F
.31454 .86335 m .31059 .86033 L .28926 .85779 L .686 .027 0 r
F
.86708 .27954 m .86598 .29544 L .86926 .30167 L 0 0 0 r
F
.86708 .27954 m .86373 .2734 L .86598 .29544 L F
.53281 .63068 m .52518 .63225 L .52382 .63313 L .045 0 0 r
F
.53281 .63068 m .53441 .62974 L .52518 .63225 L F
.68844 .68657 m .68117 .69298 L .67809 .69619 L 0 0 0 r
F
.68844 .68657 m .69178 .6833 L .68117 .69298 L F
.55248 .90444 m .53452 .90593 L .53214 .90742 L .135 0 0 r
F
.55248 .90444 m .55565 .90291 L .53452 .90593 L F
.14458 .7777 m .12141 .76045 L .12558 .76615 L .811 .077 0 r
F
.14856 .78309 m .14458 .7777 L .12558 .76615 L .788 .072 0 r
F
.22002 .81186 m .19503 .80053 L .19954 .80506 L .817 .059 0 r
F
.22421 .81611 m .22002 .81186 L .19954 .80506 L .79 .054 0 r
F
.76554 .43159 m .76968 .44027 L .77046 .4451 L .77 .115 0 r
F
.76554 .43159 m .76434 .42692 L .76968 .44027 L F
.62678 .54285 m .62235 .54715 L .62147 .54961 L 0 0 0 r
F
.62678 .54285 m .62769 .54033 L .62235 .54715 L F
.63436 .48511 m .63205 .49005 L .632 .49267 L F
.63436 .48511 m .63443 .48247 L .63205 .49005 L F
.54814 .62858 m .54089 .63058 L .53933 .6317 L F
.54814 .62858 m .54992 .6274 L .54089 .63058 L F
.3728 .6227 m .36115 .61765 L .36294 .61942 L .806 .054 0 r
F
.37445 .62434 m .3728 .6227 L .36294 .61942 L .777 .049 0 r
F
.56279 .61489 m .55617 .61726 L .55456 .61861 L 0 0 0 r
F
.56279 .61489 m .56456 .61347 L .55617 .61726 L F
.59674 .37031 m .59723 .37481 L .59907 .37681 L 0 .046 0 r
F
.59674 .37031 m .5949 .36843 L .59723 .37481 L F
.42319 .64447 m .41132 .64223 L .4128 .64329 L .578 .007 0 r
F
.42442 .64541 m .42319 .64447 L .4128 .64329 L .56 .001 0 r
F
.45907 .64937 m .45871 .64877 L .44825 .64882 L .401 0 0 r
F
.46929 .64896 m .45871 .64877 L .45907 .64937 L .359 0 0 r
F
.33455 .56545 m .3268 .55696 L .32788 .5593 L .902 .111 0 r
F
.33562 .56771 m .33455 .56545 L .32788 .5593 L .876 .107 0 r
F
.60245 .57706 m .59725 .58062 L .5959 .58265 L 0 0 0 r
F
.60245 .57706 m .60387 .57496 L .59725 .58062 L F
.33041 .6367 m .31844 .62832 L .31993 .63136 L 1 .142 0 r
F
.33191 .63956 m .33041 .6367 L .31993 .63136 L 1 .133 0 r
F
.41409 .68818 m .39912 .68778 L .40077 .68982 L .786 .048 0 r
F
.41551 .68987 m .41409 .68818 L .40077 .68982 L .774 .046 0 r
F
.46937 .64275 m .46934 .64226 L .45921 .64215 L .355 0 0 r
F
.47917 .64245 m .46934 .64226 L .46937 .64275 L .31 0 0 r
F
.47917 .64245 m .47946 .64196 L .46934 .64226 L F
.59502 .37182 m .59667 .37529 L .59852 .37725 L 0 .044 0 r
F
.59502 .37182 m .59303 .37013 L .59667 .37529 L F
.30588 .59787 m .29682 .58735 L .29783 .59052 L 1 .143 0 r
F
.30694 .60093 m .30588 .59787 L .29783 .59052 L 1 .131 0 r
F
.62789 .422 m .62714 .42708 L .62817 .42961 L 0 0 0 r
F
.62789 .422 m .62684 .41953 L .62714 .42708 L F
.43608 .64701 m .42442 .64541 L .42566 .6463 L .525 0 0 r
F
.43705 .6478 m .43608 .64701 L .42566 .6463 L .505 0 0 r
F
.65559 .49767 m .65841 .50387 L .65761 .50684 L .982 .369 0 r
F
.65559 .49767 m .65633 .49472 L .65841 .50387 L F
.63873 .48794 m .6359 .49297 L .63586 .49566 L 0 0 0 r
F
.63873 .48794 m .63877 .48523 L .6359 .49297 L F
.151 .77186 m .12858 .75471 L .13259 .76036 L .817 .079 0 r
F
.15485 .77721 m .151 .77186 L .13259 .76036 L .793 .074 0 r
F
.77019 .79204 m .75792 .79788 L .75355 .80253 L 0 0 0 r
F
.77019 .79204 m .77487 .78718 L .75792 .79788 L F
.58336 .60451 m .5772 .60737 L .57559 .60907 L F
.58336 .60451 m .5851 .60274 L .5772 .60737 L F
.48882 .64176 m .47946 .64196 L .47917 .64245 L .255 0 0 r
F
.48882 .64176 m .48941 .64126 L .47946 .64196 L F
.62648 .42253 m .62536 .4277 L .62627 .43022 L 0 0 0 r
F
.62648 .42253 m .62556 .42003 L .62536 .4277 L F
.44859 .64105 m .4377 .63942 L .43864 .6401 L .463 0 0 r
F
.44924 .64164 m .44859 .64105 L .43864 .6401 L .438 0 0 r
F
.45921 .64215 m .44859 .64105 L .44924 .64164 L .415 0 0 r
F
.44387 .68741 m .42998 .68903 L .43112 .69037 L .457 0 0 r
F
.44468 .68845 m .44387 .68741 L .43112 .69037 L .439 0 0 r
F
.45693 .68515 m .44387 .68741 L .44468 .68845 L .326 0 0 r
F
.521 .63993 m .51288 .64131 L .5117 .64206 L .077 0 0 r
F
.521 .63993 m .52244 .63913 L .51288 .64131 L F
.76681 .54734 m .76297 .55597 L .76183 .56067 L 0 0 0 r
F
.76681 .54734 m .76788 .54254 L .76297 .55597 L F
.62252 .54114 m .61853 .54546 L .61765 .54785 L F
.62252 .54114 m .62342 .5387 L .61853 .54546 L F
.54614 .62472 m .53907 .62665 L .53754 .62773 L F
.54614 .62472 m .54788 .62358 L .53907 .62665 L F
.37722 .67694 m .36247 .67316 L .3643 .67581 L 1 .083 0 r
F
.37895 .67929 m .37722 .67694 L .3643 .67581 L 1 .082 0 r
F
.39611 .62432 m .38532 .61975 L .387 .62112 L .656 .024 0 r
F
.39763 .62557 m .39611 .62432 L .387 .62112 L .637 .018 0 r
F
.89771 .60661 m .88747 .61719 L .8857 .624 L 0 0 0 r
F
.89771 .60661 m .89956 .5996 L .88747 .61719 L F
.32553 .57738 m .31588 .5691 L .3172 .57158 L .963 .107 0 r
F
.32681 .57976 m .32553 .57738 L .3172 .57158 L .939 .103 0 r
F
.84031 .72751 m .82807 .73478 L .82453 .74064 L 0 0 0 r
F
.84031 .72751 m .84407 .72143 L .82807 .73478 L F
.36816 .90973 m .34239 .90442 L .34636 .9067 L .513 0 0 r
F
.37145 .91177 m .36816 .90973 L .34636 .9067 L .489 0 0 r
F
.41174 .63159 m .40073 .62795 L .40232 .62908 L .6 .008 0 r
F
.41313 .63261 m .41174 .63159 L .40232 .62908 L .579 .001 0 r
F
.60453 .58182 m .59913 .5853 L .59773 .58736 L 0 0 0 r
F
.60453 .58182 m .60602 .57968 L .59913 .5853 L F
.63992 .55771 m .63802 .56369 L .63672 .56631 L .712 .196 0 r
F
.63992 .55771 m .64117 .55502 L .63802 .56369 L F
.25887 .86791 m .23296 .85739 L .23799 .86125 L .653 .023 0 r
F
.26348 .87148 m .25887 .86791 L .23799 .86125 L .633 .017 0 r
F
.42998 .68903 m .41551 .68987 L .41694 .69155 L .621 .023 0 r
F
.43112 .69037 m .42998 .68903 L .41694 .69155 L .601 .021 0 r
F
.63424 .48774 m .632 .49267 L .6319 .4953 L 0 0 0 r
F
.63424 .48774 m .63436 .48511 L .632 .49267 L F
.59854 .37222 m .59907 .37681 L .60086 .37883 L 0 .041 0 r
F
.59854 .37222 m .59674 .37031 L .59907 .37681 L F
.6162 .59799 m .61199 .60309 L .61021 .60525 L 0 0 0 r
F
.6162 .59799 m .61802 .59573 L .61199 .60309 L F
.58045 .60129 m .57453 .60417 L .57295 .60581 L F
.58045 .60129 m .58216 .59958 L .57453 .60417 L F
.45956 .64266 m .45921 .64215 L .44924 .64164 L .389 0 0 r
F
.46937 .64275 m .45921 .64215 L .45956 .64266 L .355 0 0 r
F
.35111 .60633 m .34018 .5999 L .34186 .60199 L .872 .075 0 r
F
.3527 .6083 m .35111 .60633 L .34186 .60199 L .845 .07 0 r
F
.60741 .90643 m .59084 .90802 L .58699 .9102 L .109 0 0 r
F
.60741 .90643 m .61195 .90412 L .59084 .90802 L F
.51321 .66691 m .50424 .6702 L .50314 .67067 L .265 .182 0 r
F
.59696 .37357 m .59852 .37725 L .60035 .37923 L 0 .04 0 r
F
.59696 .37357 m .59502 .37182 L .59852 .37725 L F
.59253 .62296 m .58702 .62734 L .58502 .62904 L 0 0 0 r
F
.59253 .62296 m .59464 .62116 L .58702 .62734 L F
.6289 .4245 m .62817 .42961 L .62916 .43215 L F
.6289 .4245 m .62789 .422 L .62817 .42961 L F
.35545 .66265 m .34167 .6567 L .34342 .65958 L 1 .118 0 r
F
.35716 .66527 m .35545 .66265 L .34342 .65958 L 1 .113 0 r
F
.35786 .59591 m .34852 .58897 L .35003 .59094 L .786 .07 0 r
F
.35931 .59777 m .35786 .59591 L .35003 .59094 L .769 .065 0 r
F
.46896 .68236 m .46892 .68177 L .45693 .68515 L .159 0 0 r
F
.48016 .67877 m .46892 .68177 L .46896 .68236 L .011 0 0 r
F
.48016 .67877 m .48051 .67831 L .46892 .68177 L F
.62582 .54535 m .62147 .54961 L .62055 .55206 L 0 0 0 r
F
.62582 .54535 m .62678 .54285 L .62147 .54961 L F
.36976 .90307 m .34437 .89791 L .34827 .90019 L .518 0 0 r
F
.373 .90511 m .36976 .90307 L .34827 .90019 L .495 0 0 r
F
.16228 .7616 m .13914 .74627 L .1431 .75168 L .876 .083 0 r
F
.16605 .76671 m .16228 .7616 L .1431 .75168 L .851 .078 0 r
F
.26234 .86158 m .23693 .85111 L .24184 .85497 L .66 .025 0 r
F
.26685 .86514 m .26234 .86158 L .24184 .85497 L .641 .019 0 r
F
.91474 .44316 m .90865 .45732 L .90944 .46439 L 0 0 0 r
F
.91474 .44316 m .91391 .436 L .90865 .45732 L F
.42556 .63642 m .41453 .63358 L .41596 .63451 L .546 0 0 r
F
.42675 .63725 m .42556 .63642 L .41596 .63451 L .524 0 0 r
F
.88372 .60247 m .87696 .61374 L .87511 .62034 L 0 0 0 r
F
.88372 .60247 m .88556 .59571 L .87696 .61374 L F
.49899 .64575 m .49001 .64658 L .4894 .64715 L .173 0 0 r
F
.49899 .64575 m .49991 .64517 L .49001 .64658 L F
.51962 .63551 m .5117 .63673 L .51055 .63743 L .088 0 0 r
F
.51962 .63551 m .52104 .63477 L .5117 .63673 L F
.56337 .61988 m .55675 .62224 L .55508 .62359 L 0 0 0 r
F
.56337 .61988 m .56521 .61845 L .55675 .62224 L F
.39315 .63437 m .38134 .63054 L .38313 .632 L .708 .033 0 r
F
.39476 .6357 m .39315 .63437 L .38313 .632 L .678 .028 0 r
F
.60574 .9012 m .58944 .903 L .58563 .90515 L .093 0 0 r
F
.33562 .56771 m .32788 .5593 L .329 .56163 L .876 .107 0 r
F
.33673 .56995 m .33562 .56771 L .329 .56163 L .85 .102 0 r
F
.63865 .49065 m .63586 .49566 L .63577 .49835 L 0 0 0 r
F
.63865 .49065 m .63873 .48794 L .63586 .49566 L F
.4377 .63942 m .42675 .63725 L .42795 .63803 L .499 0 0 r
F
.43864 .6401 m .4377 .63942 L .42795 .63803 L .475 0 0 r
F
.82997 .72058 m .81941 .72861 L .81589 .73428 L 0 0 0 r
F
.82997 .72058 m .83365 .71469 L .81941 .72861 L F
.62734 .42505 m .62627 .43022 L .62714 .43277 L F
.62734 .42505 m .62648 .42253 L .62627 .43022 L F
.601 .57913 m .5959 .58265 L .59452 .58466 L F
.601 .57913 m .60245 .57706 L .5959 .58265 L F
.57912 .91419 m .56168 .91528 L .55848 .91711 L .155 0 0 r
F
.57912 .91419 m .58308 .91225 L .56168 .91528 L F
.5008 .6454 m .49991 .64517 L .49899 .64575 L .086 0 0 r
F
.50808 .64403 m .50152 .64494 L .5008 .6454 L F
.50152 .64494 m .49991 .64517 L .5008 .6454 L F
.49983 .64593 m .49899 .64575 L .49806 .64627 L .053 0 0 r
F
.49806 .64627 m .49899 .64575 L .4894 .64715 L .14 0 0 r
F
.49889 .6464 m .49806 .64627 L .49711 .64675 L .019 0 0 r
F
.51029 .66766 m .49966 .64609 L .49892 .64646 L 1 .517 0 r
F
.49963 .64603 m .49806 .64627 L .49889 .6464 L .019 0 0 r
F
.50061 .64551 m .49899 .64575 L .49988 .64592 L .053 0 0 r
F
.49964 .64604 m .49963 .64601 L .49892 .64646 L 1 .517 0 r
F
.50055 .64551 m .50073 .64542 L .49899 .64575 L .053 0 0 r
F
.49993 .64596 m .49991 .64591 L .49991 .64598 L .807 .51 0 r
F
.49991 .64591 m .49815 .64069 L .49989 .64592 L F
.49991 .64591 m .49989 .64592 L .49991 .64598 L F
.51176 .66731 m .50065 .64559 L .49996 .64608 L F
.50065 .64559 m .50064 .64557 L .49996 .64608 L F
.50061 .64551 m .50073 .64542 L .50055 .64551 L .053 0 0 r
F
.50169 .64484 m .50082 .64454 L .49991 .64517 L .118 0 0 r
F
.5024 .64433 m .50082 .64454 L .50169 .64484 L F
.5093 .64342 m .51051 .64277 L .50082 .64454 L F
.50808 .64403 m .5093 .64342 L .50169 .64484 L .086 0 0 r
F
.50152 .64494 m .50169 .64484 L .49991 .64517 L F
.50808 .64403 m .50169 .64484 L .50152 .64494 L F
.50041 .64561 m .49815 .64069 L .4999 .64588 L .807 .51 0 r
F
.50061 .64551 m .5006 .64549 L .50041 .64561 L F
.5006 .64549 m .49815 .64069 L .50041 .64561 L F
.50061 .64551 m .50702 .63925 L .49815 .64069 L F
.51176 .66731 m .50784 .64414 L .50082 .64592 L F
.51105 .64301 m .51051 .64277 L .5093 .64342 L .018 0 0 r
F
.51805 .64136 m .51199 .64249 L .51105 .64301 L F
.51199 .64249 m .51051 .64277 L .51105 .64301 L F
.50984 .64361 m .5093 .64342 L .50808 .64403 L 0 0 0 r
F
.51059 .64327 m .51057 .64324 L .50997 .64354 L .731 .449 0 r
F
.51082 .64316 m .51081 .64315 L .51059 .64327 L F
.50984 .64361 m .51082 .64316 L .50983 .6436 L F
.50731 .64466 m .50685 .64458 L .5056 .64508 L 0 0 0 r
F
.50988 .64368 m .51086 .64324 L .50986 .64364 L .731 .449 0 r
F
.52242 .66302 m .51089 .6433 L .50988 .64368 L F
.51089 .6433 m .51086 .64324 L .50988 .64368 L F
.51953 .64067 m .5117 .64206 L .51051 .64277 L .048 0 0 r
F
.51953 .64067 m .521 .63993 L .5117 .64206 L F
.51805 .64136 m .51953 .64067 L .51223 .64237 L .018 0 0 r
F
.51199 .64249 m .51223 .64237 L .51051 .64277 L F
.51805 .64136 m .51223 .64237 L .51199 .64249 L F
.51081 .64315 m .51079 .64312 L .51059 .64327 L .731 .449 0 r
F
.5108 .64313 m .51675 .63687 L .50821 .63869 L F
.52242 .66302 m .51775 .64149 L .51105 .64356 L F
.52118 .64019 m .521 .63993 L .51953 .64067 L 0 0 0 r
F
.52774 .63826 m .52233 .6396 L .52118 .64019 L F
.52233 .6396 m .521 .63993 L .52118 .64019 L F
.5197 .64087 m .51953 .64067 L .51805 .64136 L F
.52059 .64049 m .52058 .64046 L .51984 .64081 L .643 .379 0 r
F
.52089 .64036 m .52088 .64034 L .52059 .64049 L F
.5197 .64087 m .52089 .64036 L .5197 .64087 L F
.51664 .64211 m .51655 .64201 L .51503 .6426 L 0 0 0 r
F
.51975 .64094 m .52094 .64044 L .51973 .64091 L .643 .379 0 r
F
.51505 .64267 m .51503 .6426 L .5135 .64314 L 0 0 0 r
F
.51983 .64105 m .52103 .64056 L .51979 .64099 L .643 .379 0 r
F
.53271 .65849 m .52107 .64063 L .51983 .64105 L F
.52107 .64063 m .52103 .64056 L .51983 .64105 L F
.53284 .63573 m .52528 .63741 L .52387 .63829 L .015 0 0 r
F
.53284 .63573 m .53449 .6348 L .52528 .63741 L F
.53116 .63663 m .52387 .63829 L .52244 .63913 L 0 0 0 r
F
.53116 .63663 m .53284 .63573 L .52387 .63829 L F
.52946 .63747 m .52244 .63913 L .521 .63993 L F
.52946 .63747 m .53116 .63663 L .52244 .63913 L F
.52774 .63826 m .52946 .63747 L .521 .63993 L F
.52087 .64032 m .52774 .63826 L .52118 .64019 L F
.52087 .64032 m .52118 .64019 L .51953 .64067 L F
.52087 .64032 m .51953 .64067 L .5197 .64087 L F
.51984 .64081 m .51984 .64079 L .5197 .64087 L .643 .379 0 r
F
.51984 .64079 m .51819 .63622 L .51969 .64086 L F
.51984 .64079 m .51969 .64086 L .5197 .64087 L F
.52087 .64032 m .52622 .634 L .51819 .63622 L F
.53271 .65849 m .52739 .63841 L .52116 .64076 L F
.52927 .6377 m .52946 .63747 L .52774 .63826 L 0 0 0 r
F
.52942 .63764 m .53065 .63711 L .52941 .63763 L .541 .3 0 r
F
.52572 .63915 m .526 .63901 L .52425 .6397 L 0 0 0 r
F
.52947 .6377 m .5307 .63718 L .52945 .63768 L .541 .3 0 r
F
.52955 .63781 m .53073 .63722 L .52947 .6377 L F
.54244 .65367 m .52941 .63763 L .52927 .6377 L F
.54452 .63082 m .53774 .63278 L .53613 .63381 L 0 0 0 r
F
.54267 .63186 m .53613 .63381 L .53449 .6348 L F
.54267 .63186 m .54452 .63082 L .53613 .63381 L F
.54079 .63286 m .53449 .6348 L .53284 .63573 L F
.54079 .63286 m .54267 .63186 L .53449 .6348 L F
.53889 .63382 m .53284 .63573 L .53116 .63663 L F
.53889 .63382 m .54079 .63286 L .53284 .63573 L F
.53099 .63691 m .53116 .63663 L .52946 .63747 L F
.53697 .63472 m .53233 .63624 L .53099 .63691 L F
.53233 .63624 m .53116 .63663 L .53099 .63691 L F
.53063 .63707 m .52946 .63747 L .52927 .6377 48846 .64868 L 0 0 0 r
F
.48851 .64867 m .48851 .64867 L .48846 .64868 L F
.49423 .64787 m .48864 .64862 L .48851 .64867 L F
.49423 .64787 m .4952 .64755 L .48866 .64861 L F
.49423 .64787 m .48866 .64861 L .48864 .64862 L F
.49423 .64787 m .48846 .64868 L .48752 .649 L F
.48846 .64868 m .48824 .64872 L .48752 .649 L F
.48676 .64897 m .48042 .64976 L .48007 .65015 L .936 .603 0 r
F
.48624 .64921 m .48002 .64976 L .47996 .64982 L .069 0 0 r
F
.48676 .64897 m .48637 .64329 L .48042 .64976 L .936 .603 0 r
F
.48624 .64921 m .48676 .64897 L .48133 .64965 L .069 0 0 r
F
.47996 .64982 m .48002 .64976 L .47826 .64998 L F
.47996 .64982 m .47801 .64394 L .47972 .65003 L .936 .603 0 r
F
.47996 .64982 m .47972 .65003 L .47973 .65006 L F
.47996 .64982 m .47973 .65006 L .47975 .65012 L F
.48624 .64921 m .47996 .64982 L .47973 .65006 L .069 0 0 r
F
.47996 .64982 m .48637 .64329 L .47801 .64394 L .936 .603 0 r
F
.48043 .64976 m .48637 .64329 L .47996 .64982 L F
.48559 .64947 m .48624 .64921 L .47973 .65006 L .028 0 0 r
F
.47916 .64873 m .46929 .64896 L .46933 .64949 L .278 0 0 r
F
.47886 .6492 m .46933 .64949 L .46936 .64997 L .246 0 0 r
F
.47886 .6492 m .47916 .64873 L .46933 .64949 L F
.47856 .64962 m .46936 .64997 L .4694 .6504 L .212 0 0 r
F
.47856 .64962 m .47886 .6492 L .46936 .64997 L F
.47826 .64998 m .4694 .6504 L .46944 .65079 L .177 0 0 r
F
.47826 .64998 m .47856 .64962 L .4694 .6504 L F
.47795 .6503 m .46944 .65079 L .46947 .65112 L .139 0 0 r
F
.47795 .6503 m .47826 .64998 L .46944 .65079 L F
.47119 .65123 m .46947 .65112 L .46951 .6514 L .099 0 0 r
F
.47764 .65056 m .47114 .65101 L .47119 .65123 L F
.47114 .65101 m .46947 .65112 L .47119 .65123 L F
.47764 .65056 m .47795 .6503 L .47113 .65096 L F
.47114 .65101 m .47113 .65096 L .46947 .65112 L F
.47764 .65056 m .47113 .65096 L .47114 .65101 L F
.47124 .65145 m .46951 .6514 L .46955 .65164 L .057 0 0 r
F
.4798 .67918 m .46896 .68236 L .469 .6829 L 0 0 0 r
F
.4798 .67918 m .48016 .67877 L .46896 .68236 L F
.47944 .67954 m .469 .6829 L .46905 .68339 L F
.47944 .67954 m .4798 .67918 L .469 .6829 L F
.47908 .67983 m .46905 .68339 L .46909 .68384 L F
.47908 .67983 m .47944 .67954 L .46905 .68339 L F
.47872 .68008 m .46909 .68384 L .46914 .68424 L F
.47872 .68008 m .47908 .67983 L .46909 .68384 L F
.47835 .68026 m .47122 .65135 L .47126 .65151 L .994 .647 0 r
F
.48934 .67572 m .4798 .67918 L .47944 .67954 L .244 .178 0 r
F
.48705 .67615 m .47925 .65045 L .47835 .68026 L 1 .274 0 r
F
.47523 .65083 m .47764 .65056 L .47367 .65097 L .057 0 0 r
F
.47758 .6506 m .47764 .65056 L .4712 .65127 L F
.47781 .65057 m .47764 .65056 L .47758 .6506 L 0 0 0 r
F
.47925 .65045 m .47758 .6506 L .47835 .68026 L 1 .274 0 r
F
.48782 .67607 m .48858 .67593 L .47976 .65015 L 1 .278 0 r
F
.47976 .65015 m .47976 .65015 L .47974 .65009 L F
.48782 .67607 m .47976 .65015 L .47976 .65015 L F
.48782 .67607 m .47974 .65009 L .47974 .65009 L F
.48782 .67607 m .47973 .65006 L .4796 .65012 L F
.48782 .67607 m .47962 .6502 L .47936 .65033 L F
.48045 .6502 m .48559 .64947 L .47936 .65033 L 0 0 0 r
F
.47835 .68026 m .47758 .6506 L .47127 .65156 L .994 .647 0 r
F
.47813 .65077 m .47733 .65077 L .47702 .65094 L 0 0 0 r
F
.48705 .67615 m .48782 .67607 L .47939 .65042 L 1 .274 0 r
F
.47939 .65042 m .47939 .65042 L .47937 .65035 L F
.48705 .67615 m .47939 .65042 L .47939 .65042 L F
.48705 .67615 m .47937 .65035 L .47937 .65035 L F
.48705 .67615 m .47936 .65033 L .47923 .65037 L F
.48428 .64984 m .48494 .64968 L .47875 .65057 L 0 0 0 r
F
.47863 .6506 m .47875 .65057 L .47733 .65077 L F
.48428 .64984 m .47875 .65057 L .47863 .6506 L F
.48428 .64984 m .47863 .6506 L .47813 .65077 L F
.47863 .6506 m .47733 .65077 L .47813 .65077 L F
.47937 .65035 m .47937 .65035 L .47936 .65033 L 1 .274 0 r
F
.47934 .65033 m .47936 .65033 L .47912 .65036 L 0 0 0 r
F
.48494 .64968 m .47912 .65036 L .479 .6504 L F
.4796 .65012 m .47973 .65006 L .47966 .65007 L .028 0 0 r
F
.4796 .65012 m .47966 .65007 L .47795 .6503 L F
.47962 .6502 m .4796 .65012 L .47936 .65033 L 1 .278 0 r
F
.47966 .65011 m .4796 .65012 L .47942 .65032 L .028 0 0 r
F
.4796 .65012 m .47795 .6503 L .47937 .65032 L F
.4796 .65012 m .47937 .65032 L .47942 .65032 L F
.4796 .65012 m .47772 .64419 L .47936 .65033 L 1 .278 0 r
F
.47935 .65029 m .47772 .64419 L .47742 .6444 L F
.47936 .65033 m .47935 .65029 L .47935 .65029 L F
.47935 .65029 m .47772 .64419 L .47935 .65029 L F
.47923 .65037 m .47936 .65033 L .47742 .6444 L 1 .274 0 r
F
.47935 .65033 m .47936 .65033 L .47934 .65033 L 0 0 0 r
F
.48045 .6502 m .47936 .65033 L .47935 .65033 L F
.479 .6504 m .47912 .65036 L .47764 .65056 L F
.47923 .65037 m .479 .6504 L .47899 .6504 L F
.47942 .65032 m .47795 .6503 L .47764 .65056 L .028 0 0 r
F
.47923 .65037 m .47742 .6444 L .47758 .65059 L 1 .274 0 r
F
.47925 .65045 m .47923 .65037 L .47758 .6506 L F
.479 .6504 m .47764 .65056 L .4785 .65061 L 0 0 0 r
F
.47923 .65037 m .47758 .65059 L .47758 .6506 L 1 .274 0 r
F
.48494 .64968 m .48542 .64953 L .48045 .6502 L 0 0 0 r
F
.48542 .64953 m .48559 .64947 L .48045 .6502 L F
.48494 .64968 m .47923 .65037 L .4785 .65061 L F
.47923 .65037 m .47899 .6504 L .4785 .65061 L F
.4712 .65127 m .47523 .65083 L .47119 .65123 L .057 0 0 r
F
.47523 .65083 m .47367 .65097 L .47119 .65123 L F
.4712 .65127 m .47119 .65123 L .46951 .6514 L F
.46965 .64501 m .46963 .6449 L .46213 .64495 L .084 0 0 r
F
.4712 .65127 m .47742 .6444 L .46959 .64473 L .994 .647 0 r
F
.47065 .65183 m .46959 .65182 L .46963 .65196 L 0 0 0 r
F
.47798 .68039 m .47835 .68026 L .47127 .65155 L .88 .141 0 r
F
.47127 .65155 m .47127 .65155 L .47125 .65147 L F
.47798 .68039 m .47127 .65155 L .47127 .65155 L F
.47798 .68039 m .47125 .65147 L .47125 .65147 L F
.47798 .68039 m .47124 .65145 L .47118 .65149 L F
.47121 .65147 m .47124 .65145 L .47117 .65146 L .014 0 0 r
F
.47124 .65145 m .47124 .65144 L .47118 .65149 L .88 .141 0 r
F
.47125 .65148 m .47124 .65145 L .47121 .65147 L .014 0 0 r
F
.47798 .68039 m .4712 .65157 L .47122 .65163 L .88 .141 0 r
F
.4712 .65157 m .47118 .65149 L .47122 .65163 L F
.4767 .65105 m .47702 .65094 L .47122 .65163 L 0 0 0 r
F
.47115 .65165 m .47095 .65166 L .47089 .65168 L F
.47761 .68047 m .47798 .68039 L .47124 .65173 L .877 .142 0 r
F
.47761 .68047 m .47124 .65173 L .47124 .65173 L F
.47761 .68047 m .47122 .65164 L .47122 .65164 L F
.47761 .68047 m .47122 .65163 L .47115 .65165 L F
.47761 .68047 m .47117 .65175 L .4712 .65176 L F
.47117 .65175 m .47115 .65165 L .4712 .65176 L F
.47124 .65173 m .47124 .65173 L .47122 .65164 L F
.4712 .65176 m .47089 .65168 L .47065 .65183 L 0 0 0 r
F
.4767 .65105 m .47141 .65163 L .4712 .65176 L F
.47141 .65163 m .47089 .65168 L .4712 .65176 L F
.4712 .65176 m .4712 .65176 L .47093 .65179 L F
.47069 .65183 m .47093 .65179 L .46963 .65196 L F
.47087 .6518 m .47088 .6518 L .47069 .65183 L F
.47088 .6518 m .47093 .65179 L .47069 .65183 L F
.47122 .65163 m .47122 .65163 L .47114 .65164 L F
.47122 .65163 m .47114 .65164 L .47115 .65164 L F
.47118 .65149 m .46955 .65164 L .471 .65162 L .014 0 0 r
F
.47118 .65149 m .47122 .65162 L .47128 .65162 L F
.47122 .65163 m .47118 .65149 L .47121 .65158 L .88 .141 0 r
F
.4712 .65127 m .46951 .6514 L .47124 .65145 L .057 0 0 r
F
.47118 .65149 m .47124 .65144 L .46963 .6449 L .88 .141 0 r
F
.47121 .65158 m .46964 .64495 L .46967 .64501 L F
.46964 .64495 m .46963 .6449 L .46967 .64501 L F
.47118 .65149 m .46963 .6449 L .47121 .65158 L F
.47118 .65149 m .47117 .65146 L .46955 .65164 L .014 0 0 r
F
.47115 .65165 m .47122 .65163 L .46967 .64501 L .877 .142 0 r
F
.47123 .65141 m .4696 .64478 L .46963 .6449 L .994 .647 0 r
F
.47123 .65141 m .46959 .64473 L .47123 .65141 L F
.47123 .65142 m .46959 .64473 L .47124 .65142 L F
.4712 .65129 m .46959 .64473 L .47126 .65151 L F
.46937 .64508 m .46967 .64501 L .46251 .64508 L .045 0 0 r
F
.46969 .64508 m .46967 .64501 L .46937 .64508 L F
.47122 .65164 m .47122 .65164 L .47122 .65163 L .877 .142 0 r
F
.47141 .65163 m .47121 .65163 L .47115 .65165 L 0 0 0 r
F
.4767 .65105 m .47146 .65161 L .47141 .65163 L F
.47146 .65161 m .47121 .65163 L .47141 .65163 L F
.47113 .6518 m .4712 .65176 L .47119 .65171 L .875 .142 0 r
F
.47007 .64679 m .46967 .64501 L .46971 .64508 L .877 .142 0 r
F
.4712 .65176 m .47115 .65165 L .47119 .65171 L F
.47121 .65163 m .47095 .65166 L .47115 .65165 L 0 0 0 r
F
.47128 .65162 m .46955 .65164 L .46959 .65182 L .014 0 0 r
F
.47115 .65165 m .46967 .64501 L .47119 .65171 L .877 .142 0 r
F
.47118 .65149 m .471 .65162 L .47122 .65162 L .014 0 0 r
F
.47112 .65173 m .47119 .65171 L .46971 .64508 L .875 .142 0 r
F
.47113 .6518 m .47119 .65171 L .47112 .65173 L F
.46971 .64508 m .46967 .64501 L .46969 .64508 L .045 0 0 r
F
.46933 .64949 m .46929 .64896 L .45907 .64937 L .331 0 0 r
F
.46933 .64949 m .45907 .64937 L .45943 .64993 L F
.46936 .64997 m .46933 .64949 L .45943 .64993 L .301 0 0 r
F
.46936 .64997 m .45943 .64993 L .4598 .65044 L F
.4694 .6504 m .46936 .64997 L .4598 .65044 L .269 0 0 r
F
.4694 .6504 m .4598 .65044 L .46017 .65091 L F
.46944 .65079 m .4694 .6504 L .46017 .65091 L .235 0 0 r
F
.46944 .65079 m .46017 .65091 L .46055 .65132 L F
.46947 .65112 m .46944 .65079 L .46055 .65132 L .199 0 0 r
F
.46947 .65112 m .46055 .65132 L .46093 .65169 L F
.46951 .6514 m .46947 .65112 L .46093 .65169 L .162 0 0 r
F
.46951 .6514 m .46093 .65169 L .46132 .65201 L F
.46955 .65164 m .46951 .6514 L .46132 .65201 L .123 0 0 r
F
.46955 .65164 m .46132 .65201 L .46171 .65228 L F
.46959 .65182 m .46955 .65164 L .46171 .65228 L .082 0 0 r
F
.46959 .65182 m .46171 .65228 L .4621 .6525 L F
.46963 .65196 m .46959 .65182 L .4621 .6525 L .04 0 0 r
F
.46398 .65253 m .4621 .6525 L .4625 .65268 L F
.46963 .65196 m .46364 .65239 L .46398 .65253 L F
.46364 .65239 m .4621 .6525 L .46398 .65253 L F
.46407 .65254 m .46963 .65196 L .46398 .65253 L 0 0 0 r
F
.46407 .65254 m .46398 .65253 L .4625 .65268 L F
.46407 .65254 m .46971 .64508 L .46289 .64517 L 1 .681 0 r
F
.46421 .65253 m .46971 .64508 L .46407 .65254 L F
.46896 .68236 m .45693 .68515 L .45737 .68591 L .159 0 0 r
F
.469 .6829 m .46896 .68236 L .45737 .68591 L .118 0 0 r
F
.469 .6829 m .45737 .68591 L .45781 .68664 L F
.46905 .68339 m .469 .6829 L .45781 .68664 L .074 0 0 r
F
.46905 .68339 m .45781 .68664 L .45825 .68734 L F
.46909 .68384 m .46905 .68339 L .45825 .68734 L .029 0 0 r
F
.46909 .68384 m .45825 .68734 L .4587 .68799 L F
.46914 .68424 m .46909 .68384 L .4587 .68799 L 0 0 0 r
F
.46933 .68539 m .46964 .65196 L .46409 .65268 L 1 .681 0 r
F
.46964 .65198 m .46963 .65196 L .46407 .65254 L 0 0 0 r
F
.47089 .65168 m .47095 .65166 L .46959 .65182 L F
.47089 .65168 m .46959 .65182 L .47065 .65183 L F
.46964 .65196 m .46964 .65191 L .46409 .65268 L 1 .681 0 r
F
.46964 .65191 m .46971 .64508 L .46421 .65252 L F
.46964 .65191 m .46421 .65252 L .46409 .65268 L F
.47113 .65177 m .47093 .65179 L .47087 .6518 L 0 0 0 r
F
.47115 .65187 m .4712 .65176 L .47113 .6518 L .875 .142 0 r
F
.47723 .68049 m .47122 .65186 L .47115 .65187 L F
.47122 .65186 m .4712 .65176 L .47115 .65187 L F
.47723 .68049 m .47113 .65177 L .46933 .68539 L F
.47113 .65177 m .47112 .65177 L .46933 .68539 L F
.47113 .65177 m .47087 .6518 L .47086 .65181 L 0 0 0 r
F
.46984 .65195 m .46963 .65196 L .46964 .65198 L F
.47112 .65176 m .46964 .65191 L .46964 .65198 L .875 .142 0 r
F
.47112 .65177 m .46964 .65198 L .46933 .68539 L F
.47087 .6518 m .46963 .65196 L .47062 .65191 L 0 0 0 r
F
.47112 .65176 m .46964 .65198 L .47112 .65177 L .875 .142 0 r
F
.47062 .65191 m .46984 .65195 L .46967 .65205 L 0 0 0 r
F
.46984 .65195 m .46964 .65198 L .46967 .65205 L F
.47723 .68049 m .47761 .68047 L .4712 .65177 L .875 .142 0 r
F
.4712 .65177 m .4712 .65177 L .4712 .65176 L F
.47723 .68049 m .4712 .65177 L .4712 .65177 L F
.47638 .65111 m .47113 .65177 L .47062 .65191 L 0 0 0 r
F
.47113 .65177 m .47086 .65181 L .47062 .65191 L F
.47606 .65112 m .47638 .65111 L .4709 .65187 L .123 .161 0 r
F
.47084 .65188 m .4709 .65187 L .46967 .65205 L F
.47606 .65112 m .4709 .65187 L .47084 .65188 L F
.47638 .65111 m .4722 .65163 L .47113 .65177 L 0 0 0 r
F
.4722 .65163 m .47093 .65179 L .47113 .65177 L F
.47113 .65177 m .47112 .65176 L .47112 .65177 L .875 .142 0 r
F
.47115 .65164 m .47114 .65164 L .47095 .65166 L 0 0 0 r
F
.47112 .65176 m .46971 .64508 L .46964 .65191 L .875 .142 0 r
F
.47686 .68045 m .47723 .68049 L .46933 .68539 L .504 .214 0 r
F
.47686 .68045 m .46933 .68539 L .46937 .68559 L F
.46967 .65205 m .46437 .65251 L .4644 .65264 L 0 0 0 r
F
.46967 .65205 m .46964 .65198 L .46407 .65254 L F
.46437 .65251 m .46407 .65254 L .4644 .65264 L F
.46409 .65268 m .46421 .65253 L .46407 .65254 L 1 .681 0 r
F
.46407 .65257 m .4629 .64522 L .46441 .6527 L F
.4629 .64522 m .46289 .64517 L .4629 .64522 L F
.4629 .64522 m .4629 .64522 L .46441 .6527 L F
.46439 .65258 m .46289 .64517 L .46328 .64522 L F
.46438 .65258 m .46289 .64517 L .46439 .65258 L F
.46328 .64522 m .45618 .64501 L .45691 .64509 L .044 0 0 r
F
.46366 .64521 m .46328 .64522 L .45691 .64509 L 0 .138 0 r
F
.46367 .64521 m .46328 .64522 L .46366 .64521 L F
.46971 .65208 m .46431 .65265 L .4644 .65265 L 0 0 0 r
F
.4644 .65265 m .4644 .65264 L .46328 .64522 L F
.46441 .65268 m .4644 .65264 L .4644 .65265 L F
.46971 .65208 m .46967 .65205 L .4644 .65264 L F
.4644 .65264 m .4644 .65264 L .46431 .65265 L F
.46971 .65208 m .4644 .65264 L .4644 .65264 L F
.46933 .68539 m .46407 .65257 L .46441 .6527 L 1 .681 0 r
F
.4644 .65265 m .46431 .65265 L .4629 .65281 L 0 0 0 r
F
.46442 .65276 m .4644 .65265 L .46473 .65271 L F
.46441 .65276 m .46441 .65276 L .4644 .65264 L F
.46937 .68559 m .4644 .65264 L .46441 .65268 L F
.46441 .6527 m .46439 .65264 L .4644 .65264 L 1 .681 0 r
F
.46464 .65272 m .4629 .65281 L .46331 .65289 L 0 0 0 r
F
.47648 .68037 m .47686 .68045 L .46937 .68559 L .561 .221 0 r
F
.47648 .68037 m .46937 .68559 L .46942 .68575 L F
.46971 .65208 m .4647 .65262 L .46473 .65271 L 0 0 0 r
F
.46976 .65207 m .46971 .65208 L .46473 .65271 L .092 .155 0 r
F
.46976 .65207 m .46473 .65271 L .46475 .65271 L F
.46473 .65271 m .46443 .65275 L .46443 .65275 L F
.46473 .65271 m .46473 .65271 L .46367 .64521 L 0 0 0 r
F
.46474 .65274 m .46473 .65271 L .46473 .65271 L F
.46976 .65207 m .46473 .65271 L .46473 .65271 L .092 .155 0 r
F
.46473 .65271 m .4643 .65266 L .46464 .65272 L 0 0 0 r
F
.46473 .65271 m .46466 .65272 L .46473 .65271 L .092 .155 0 r
F
.46466 .65272 m .46443 .65275 L .46473 .65271 L F
.46506 .65267 m .46367 .64521 L .46406 .64516 L 0 0 0 r
F
.46942 .68575 m .46473 .65271 L .46474 .65274 L F
.46942 .68575 m .46474 .65274 L .46507 .65281 L F
.46937 .68559 m .46442 .65276 L .46473 .65271 L F
.46937 .68559 m .46933 .68539 L .46441 .65276 L F
.46937 .68559 m .46441 .65276 L .46441 .65276 L F
.46507 .65274 m .46331 .65289 L .46372 .65293 L .092 .155 0 r
F
.47487 .68124 m .47648 .68037 L .46942 .68575 L .614 .226 0 r
F
.4761 .68023 m .47618 .68026 L .47487 .68124 L F
.47618 .68026 m .47648 .68037 L .47487 .68124 L F
.4761 .68023 m .46942 .68575 L .46947 .68588 L F
.46947 .68588 m .46942 .68575 L .46508 .65287 L 0 0 0 r
F
.46508 .65287 m .46508 .65287 L .46507 .65274 L F
.46947 .68588 m .46508 .65287 L .46508 .65287 L F
.46976 .65207 m .46504 .65267 L .46507 .65274 L .092 .155 0 r
F
.46595 .6526 m .46507 .65274 L .46509 .65273 L .137 .164 0 r
F
.4698 .65202 m .4662 .65257 L .46595 .6526 L F
.4662 .65257 m .46507 .65274 L .46595 .6526 L F
.46511 .65303 m .46507 .65274 L .46507 .65276 L 0 0 0 r
F
.46947 .68588 m .46511 .65306 L .46511 .65303 L F
.46511 .65306 m .46507 .65274 L .46511 .65303 L F
.46504 .65267 m .46473 .65271 L .46507 .65274 L .092 .155 0 r
F
.46474 .65274 m .46367 .64521 L .46507 .65281 L 0 0 0 r
F
.46507 .65273 m .46476 .65279 L .46476 .65278 L .137 .164 0 r
F
.4698 .65202 m .46507 .65274 L .46507 .65273 L F
.46507 .65274 m .46476 .65279 L .46507 .65273 L F
.46507 .65276 m .46507 .65274 L .46507 .65273 L 0 0 0 r
F
.4698 .65202 m .46976 .65207 L .46507 .65274 L .137 .164 0 r
F
.46942 .68575 m .46937 .68559 L .46475 .65284 L 0 0 0 r
F
.46942 .68575 m .46475 .65284 L .46475 .65284 L F
.46914 .68424 m .4587 .68799 L .45915 .68862 L F
.46918 .68459 m .46914 .68424 L .45915 .68862 L F
.46918 .68459 m .45915 .68862 L .45961 .68921 L F
.46923 .6849 m .45961 .68921 L .46007 .68978 L F
.46928 .68517 m .46007 .68978 L .46054 .69033 L F
.4694 .68533 m .46507 .65273 L .46251 .69048 L F
.464 .6529 m .46398 .6529 L .4638 .65293 L .137 .164 0 r
F
.46398 .6529 m .46372 .65293 L .4638 .65293 L F
.46506 .65274 m .46367 .64521 L .46507 .65274 L 0 0 0 r
F
.46505 .65267 m .46367 .64521 L .46506 .65267 L F
.4644 .65265 m .46328 .64522 L .46472 .65265 L F
.46472 .65264 m .46328 .64522 L .46367 .64521 L F
.46472 .65264 m .46328 .64522 L .46472 .65264 L F
.45907 .64937 m .44825 .64882 L .44893 .64947 L .401 0 0 r
F
.45943 .64993 m .45907 .64937 L .44893 .64947 L .375 0 0 r
F
.45943 .64993 m .44893 .64947 L .44962 .65007 L F
.4598 .65044 m .45943 .64993 L .44962 .65007 L .346 0 0 r
F
.4598 .65044 m .44962 .65007 L .45032 .65062 L F
.46017 .65091 m .4598 .65044 L .45032 .65062 L .316 0 0 r
F
.46017 .65091 m .45032 .65062 L .45102 .65113 L F
.46055 .65132 m .46017 .65091 L .45102 .65113 L .285 0 0 r
F
.46055 .65132 m .45102 .65113 L .45174 .65159 L F
.46093 .65169 m .46055 .65132 L .45174 .65159 L .252 0 0 r
F
.46093 .65169 m .45174 .65159 L .45246 .652 L F
.46132 .65201 m .46093 .65169 L .45246 .652 L .217 0 0 r
F
.46132 .65201 m .45246 .652 L .45319 .65237 L F
.46171 .65228 m .46132 .65201 L .45319 .65237 L .181 0 0 r
F
.46171 .65228 m .45319 .65237 L .45392 .6527 L F
.4621 .6525 m .46171 .65228 L .45392 .6527 L .144 0 0 r
F
.4621 .6525 m .45392 .6527 L .45466 .65298 L F
.4625 .65268 m .4621 .6525 L .45466 .65298 L .106 0 0 r
F
.4625 .65268 m .45466 .65298 L .45541 .65321 L F
.4629 .65281 m .4625 .65268 L .45541 .65321 L .068 0 0 r
F
.4629 .65281 m .45541 .65321 L .45617 .65341 L F
.46331 .65289 m .4629 .65281 L .45617 .65341 L .029 0 0 r
F
.46367 .64521 m .45691 .64509 L .45764 .64513 L 0 .138 0 r
F
.46331 .65289 m .45617 .65341 L .45693 .65356 L .029 0 0 r
F
.46328 .64522 m .46289 .64517 L .45618 .64501 L .044 0 0 r
F
.46406 .64516 m .46367 .64521 L .45764 .64513 L .035 .145 0 r
F
.46372 .65293 m .46331 .65289 L .45693 .65356 L 0 0 0 r
F
.46406 .64516 m .45764 .64513 L .45838 .64512 L .035 .145 0 r
F
.45893 .65352 m .45693 .65356 L .4577 .65367 L 0 0 0 r
F
.46372 .65293 m .4583 .65343 L .45893 .65352 L F
.4583 .65343 m .45693 .65356 L .45893 .65352 L F
.4591 .65351 m .46372 .65293 L .45893 .65352 L F
.4591 .65351 m .45893 .65352 L .4577 .65367 L F
.4591 .65351 m .46406 .64516 L .45838 .64512 L 1 .715 0 r
F
.45924 .65349 m .46406 .64516 L .4591 .65351 L F
.46245 .69247 m .4638 .65293 L .45912 .6537 L F
.4638 .65293 m .46372 .65293 L .4591 .65351 L 0 0 0 r
F
.46506 .65274 m .46506 .65274 L .46507 .65274 L F
.46475 .65271 m .46473 .65271 L .46443 .65275 L .092 .155 0 r
F
.46443 .65275 m .46443 .65275 L .46331 .65289 L F
.46473 .65271 m .46331 .65289 L .46507 .65274 L F
.4643 .65266 m .4629 .65281 L .46464 .65272 L 0 0 0 r
F
.4644 .65264 m .46407 .65254 L .4629 .65281 L F
.46407 .65254 m .4625 .65268 L .46259 .65271 L F
.46407 .65254 m .46259 .65271 L .4629 .65281 L F
.4638 .65293 m .4638 .65283 L .45912 .6537 L 1 .715 0 r
F
.4638 .65283 m .46406 .64516 L .45924 .65349 L F
.4638 .65283 m .45924 .65349 L .45912 .6537 L F
.46507 .65281 m .46506 .65274 L .46507 .65274 L 0 0 0 r
F
.46509 .65273 m .46507 .65274 L .46476 .65279 L .137 .164 0 r
F
.46475 .65284 m .46475 .65284 L .46473 .65271 L 0 0 0 r
F
.46507 .65273 m .4638 .65293 L .46251 .69048 L F
.46413 .65293 m .45945 .65347 L .45972 .65357 L F
.45945 .65347 m .4591 .65351 L .45972 .65357 L F
.46947 .68588 m .4694 .68533 L .46245 .69247 L F
.4694 .68533 m .46251 .69048 L .46245 .69247 L F
.46952 .686 m .46245 .69247 L .46293 .69305 L F
.46245 .69247 m .46245 .69247 L .46293 .69305 L F
.46957 .68612 m .46952 .686 L .46293 .69305 L F
.46957 .68612 m .46294 .69305 L .46342 .6937 L F
.46294 .69305 m .46293 .69305 L .46342 .6937 L F
.46871 .68734 m .46957 .68612 L .46342 .6937 L F
.46962 .68624 m .46961 .68622 L .46871 .68734 L F
.46961 .68622 m .46957 .68612 L .46871 .68734 L F
.46962 .68624 m .46871 .68734 L .46391 .69443 L F
.46871 .68734 m .46342 .6937 L .46391 .69443 L F
.46388 .69433 m .46356 .69389 L .46371 .69361 L F
.46356 .69389 m .46342 .6937 L .46371 .69361 L F
.46371 .69361 m .46342 .6937 L .46332 .692 L F
.46391 .69443 m .46342 .6937 L .46388 .69433 L F
.46391 .69443 m .46332 .692 L .46373 .69178 L F
.46391 .69443 m .46384 .69337 L .46067 .69921 L F
.46391 .69443 m .46067 .69921 L .45772 .70464 L F
.46339 .69362 m .46293 .69305 L .46288 .69224 L F
.46342 .6937 m .46293 .69305 L .46339 .69362 L F
.46952 .686 m .46947 .68588 L .46247 .69245 L F
.46952 .686 m .46247 .69245 L .46247 .69245 L F
.46952 .686 m .46245 .69247 L .46245 .69247 L F
.46413 .65293 m .4638 .65293 L .46012 .65338 L F
.46018 .65338 m .46012 .65338 L .4591 .65351 L F
.46413 .65293 m .46012 .65338 L .46018 .65338 L F
.46247 .69245 m .46247 .69245 L .46245 .69247 L F
.46245 .69247 m .46245 .69247 L .46245 .69247 L F
.46293 .69305 m .46245 .69247 L .45973 .65371 L F
.45974 .65371 m .45973 .65371 L .45972 .65357 L F
.46293 .69305 m .45973 .65371 L .45974 .65371 L F
.46454 .65289 m .46016 .65351 L .46043 .65359 L F
.46251 .64508 m .45474 .64471 L .45545 .64488 L .121 0 0 r
F
.46289 .64517 m .46251 .64508 L .45545 .64488 L .083 0 0 r
F
.46289 .64517 m .45545 .64488 L .45618 .64501 L F
.46454 .65289 m .46413 .65293 L .45972 .65357 L 0 0 0 r
F
.45912 .6537 m .45924 .65349 L .4591 .65351 L 1 .715 0 r
F
.46245 .69247 m .45911 .65354 L .45973 .65363 L F
.4598 .65356 m .45972 .65357 L .45848 .65374 L 0 0 0 r
F
.46454 .65289 m .45972 .65357 L .4598 .65356 L F
.4598 .65356 m .45972 .65357 L .45913 .64507 L F
.4598 .65359 m .45972 .65357 L .4598 .65356 L F
.46051 .65357 m .46043 .65359 L .45988 .64497 L F
.46051 .65361 m .46043 .65359 L .46051 .65357 L F
.46496 .65281 m .46454 .65289 L .46043 .65359 L .125 .161 0 r
F
.4598 .6536 m .45972 .65357 L .4598 .65359 L 0 0 0 r
F
.46293 .69305 m .45973 .65358 L .4598 .6536 L F
.45973 .65358 m .45972 .65357 L .4598 .6536 L F
.4633 .69201 m .46288 .69224 L .46044 .65375 L F
.46044 .65375 m .46044 .65375 L .46043 .65359 L F
.4633 .69201 m .46044 .65375 L .46044 .65375 L F
.4651 .65278 m .464 .6529 L .46413 .65293 L .137 .164 0 r
F
.4651 .65276 m .4651 .65278 L .46413 .65293 L .182 .172 0 r
F
.46115 .65375 m .46114 .65375 L .46113 .65358 L 0 0 0 r
F
.46373 .69178 m .46113 .65358 L .46114 .65358 L F
.46016 .65351 m .4598 .65356 L .46043 .65359 L F
.45981 .6537 m .4598 .65356 L .46043 .65359 L F
.45973 .65363 m .45972 .65356 L .45972 .65357 L 1 .715 0 r
F
.4598 .65356 m .45848 .65374 L .46043 .65359 L 0 0 0 r
F
.4598 .65356 m .4598 .65354 L .46043 .65359 L F
.46043 .65359 m .4598 .65354 L .46042 .65355 L F
.46293 .69305 m .45981 .6537 L .46043 .65359 L F
.46043 .65359 m .45848 .65374 L .46009 .65364 L F
.46213 .64495 m .46175 .64476 L .45402 .64449 L .159 0 0 r
F
.46213 .64495 m .45402 .64449 L .45474 .64471 L F
.46251 .64508 m .46213 .64495 L .45474 .64471 L .121 0 0 r
F
.46113 .65346 m .45988 .64497 L .46064 .64483 L 0 0 0 r
F
.46061 .65355 m .46047 .65358 L .46051 .65357 L .125 .161 0 r
F
.46496 .65281 m .46049 .65358 L .46061 .65355 L F
.46496 .65281 m .46043 .65359 L .46045 .65358 L F
.46342 .6937 m .46051 .65357 L .46113 .65358 L 0 0 0 r
F
.4633 .69201 m .46043 .65359 L .46051 .65361 L F
.46113 .65358 m .45926 .65379 L .46005 .6538 L .125 .161 0 r
F
.46496 .65281 m .46061 .65355 L .46123 .65356 L F
.46122 .6536 m .46112 .6534 L .4612 .6534 L 0 0 0 r
F
.46373 .69178 m .46114 .65358 L .46122 .6536 L F
.46123 .65356 m .46111 .65357 L .46113 .65358 L .125 .161 0 r
F
.46114 .65358 m .46112 .6534 L .46122 .6536 L 0 0 0 r
F
.46111 .65357 m .46107 .65358 L .46113 .65358 L .125 .161 0 r
F
.46107 .65358 m .45926 .65379 L .46113 .65358 L F
.46113 .65358 m .46051 .65357 L .46113 .65346 L 0 0 0 r
F
.46051 .65357 m .45988 .64497 L .46113 .65346 L F
.46051 .65357 m .46009 .65364 L .46015 .65363 L .125 .161 0 r
F
.46047 .65358 m .46009 .65364 L .46051 .65357 L F
.46049 .65358 m .46009 .65364 L .46061 .65355 L F
.46045 .65358 m .46043 .65359 L .46009 .65364 L F
.46009 .65364 m .45848 .65374 L .45926 .65379 L 0 0 0 r
F
.46015 .65363 m .46009 .65364 L .45926 .65379 L .125 .161 0 r
F
.46061 .65355 m .45926 .65379 L .46123 .65356 L F
.46042 .65355 m .45913 .64507 L .45988 .64497 L 0 0 0 r
F
.4598 .65354 m .45913 .64507 L .46042 .65355 L F
.46216 .65337 m .46496 .65281 L .46113 .65358 L .161 .167 0 r
F
.46538 .6527 m .46509 .65277 L .46216 .65337 L F
.4698 .65202 m .46507 .65273 L .4651 .65278 L .137 .164 0 r
F
.46984 .65191 m .4651 .65278 L .4651 .65276 L .182 .172 0 r
F
.46984 .65191 m .46413 .65293 L .46454 .65289 L F
.46512 .65277 m .46512 .65278 L .46454 .65289 L .227 .179 0 r
F
.46509 .65277 m .46496 .65281 L .46216 .65337 L .161 .167 0 r
F
.46373 .69178 m .46332 .692 L .46114 .65375 L 0 0 0 r
F
.46373 .69178 m .46114 .65375 L .46115 .65375 L F
.46538 .6527 m .46113 .65358 L .46116 .65357 L .161 .167 0 r
F
.46538 .6527 m .46079 .65365 L .46085 .65363 L F
.46342 .6937 m .46288 .69224 L .4633 .69201 L 0 0 0 r
F
.45915 .68862 m .4587 .68799 L .44799 .69235 L .177 0 0 r
F
.45915 .68862 m .44799 .69235 L .44883 .69328 L F
.45961 .68921 m .45915 .68862 L .44883 .69328 L .146 0 0 r
F
.45961 .68921 m .44883 .69328 L .44969 .69421 L F
.46007 .68978 m .45961 .68921 L .44969 .69421 L .114 0 0 r
F
.46007 .68978 m .44969 .69421 L .45056 .69514 L F
.46054 .69033 m .46007 .68978 L .45056 .69514 L .082 0 0 r
F
.46054 .69033 m .45056 .69514 L .45143 .69608 L F
.46101 .69086 m .46054 .69033 L .45143 .69608 L .052 0 0 r
F
.46101 .69086 m .45143 .69608 L .45231 .69705 L F
.46149 .69139 m .45231 .69705 L .4532 .69806 L .023 0 0 r
F
.46196 .69192 m .4532 .69806 L .45409 .69912 L 0 0 0 r
F
.46384 .69337 m .46121 .65356 L .45791 .7007 L F
.46114 .65358 m .46113 .65358 L .46112 .6534 L F
.4612 .6534 m .46112 .6534 L .46064 .64483 L F
.46121 .65356 m .46064 .64483 L .4602 .65376 L F
.4587 .68799 m .45825 .68734 L .44714 .69141 L .209 0 0 r
F
.4587 .68799 m .44714 .69141 L .44799 .69235 L F
.46121 .65361 m .4602 .65379 L .45791 .7007 L 0 0 0 r
F
.46121 .65356 m .4602 .65379 L .46121 .65361 L F
.45641 .65455 m .4602 .6538 L .4562 .65456 L F
.45641 .65455 m .4562 .65456 L .45522 .65475 L F
.4602 .6538 m .45721 .65436 L .45522 .65475 L F
.45972 .65347 m .45838 .64512 L .45913 .64507 L 1 .715 0 r
F
.4597 .65347 m .45838 .64512 L .45972 .65347 L F
.45911 .65354 m .45838 .64512 L .45973 .65363 L F
.45618 .64501 m .45545 .64488 L .44862 .64441 L .111 0 0 r
F
.45618 .64501 m .44862 .64441 L .44967 .64459 L F
.45691 .64509 m .45618 .64501 L .44967 .64459 L .073 0 0 r
F
.45691 .64509 m .44967 .64459 L .45073 .64472 L F
.45764 .64513 m .45691 .64509 L .45073 .64472 L 0 .131 0 r
F
.45693 .65356 m .45617 .65341 L .44958 .65385 L .104 0 0 r
F
.45764 .64513 m .45073 .64472 L .4518 .64481 L 0 .131 0 r
F
.45693 .65356 m .44958 .65385 L .45069 .65409 L .104 0 0 r
F
.45838 .64512 m .45764 .64513 L .4518 .64481 L .001 .138 0 r
F
.4577 .65367 m .45693 .65356 L .45069 .65409 L .073 0 0 r
F
.45838 .64512 m .4518 .64481 L .45288 .64486 L .001 .138 0 r
F
.45913 .64507 m .45838 .64512 L .45288 .64486 L .037 .145 0 r
F
.4577 .65367 m .45069 .65409 L .45181 .65429 L .073 0 0 r
F
.45848 .65374 m .4577 .65367 L .45181 .65429 L .043 0 0 r
F
.45913 .64507 m .45288 .64486 L .45396 .64487 L .037 .145 0 r
F
.45988 .64497 m .45913 .64507 L .45396 .64487 L .072 .152 0 r
F
.45848 .65374 m .45181 .65429 L .45294 .65447 L .043 0 0 r
F
.45926 .65379 m .45848 .65374 L .45294 .65447 L .015 0 0 r
F
.45988 .64497 m .45396 .64487 L .45505 .64484 L .072 .152 0 r
F
.46064 .64483 m .45988 .64497 L .45505 .64484 L .106 .158 0 r
F
.45926 .65379 m .45294 .65447 L .45407 .65462 L .015 0 0 r
F
.46005 .6538 m .45926 .65379 L .45407 .65462 L 0 0 0 r
F
.46064 .64483 m .45505 .64484 L .45615 .64476 L .106 .158 0 r
F
.46005 .6538 m .45407 .65462 L .45522 .65475 L 0 0 0 r
F
.45641 .65455 m .46064 .64483 L .45615 .64476 L 1 .749 0 r
F
.45737 .68591 m .45693 .68515 L .44468 .68845 L .298 0 0 r
F
.45737 .68591 m .44468 .68845 L .44549 .68946 L F
.45781 .68664 m .45737 .68591 L .44549 .68946 L .269 0 0 r
F
.45781 .68664 m .44549 .68946 L .44631 .69044 L F
.45825 .68734 m .45781 .68664 L .44631 .69044 L .239 0 0 r
F
.45825 .68734 m .44631 .69044 L .44714 .69141 L F
.45772 .70464 m .4602 .65379 L .45641 .65455 L 1 .749 0 r
F
.4602 .6538 m .4602 .6538 L .45641 .65455 L 0 0 0 r
F
.4602 .6538 m .46005 .6538 L .45721 .65436 L F
.45972 .65357 m .4597 .65347 L .45972 .65347 L 1 .715 0 r
F
.45972 .65356 m .4597 .65347 L .45972 .65357 L F
.45972 .65357 m .4591 .65351 L .45848 .65374 L 0 0 0 r
F
.4591 .65351 m .4577 .65367 L .45787 .65369 L F
.4591 .65351 m .45787 .65369 L .45848 .65374 L F
.4602 .65379 m .46064 .64483 L .45641 .65455 L 1 .749 0 r
F
.46083 .65379 m .4602 .6538 L .45641 .65455 L 0 0 0 r
F
.45772 .70464 m .45641 .65473 L .45733 .65464 L 1 .749 0 r
F
.45641 .65473 m .45641 .65455 L .45733 .65464 L F
.46084 .65379 m .45684 .65447 L .45733 .65464 L 0 0 0 r
F
.45684 .65447 m .45641 .65455 L .45733 .65464 L F
.46384 .69337 m .45791 .7007 L .45772 .70464 L F
.4644 .6953 m .46391 .69443 L .45774 .7046 L F
.45775 .7046 m .45774 .7046 L .45772 .70464 L F
.4644 .6953 m .45774 .7046 L .45775 .7046 L F
.4644 .6953 m .45775 .7046 L .45864 .70663 L F
.45775 .7046 m .45772 .70464 L .45864 .70663 L F
.46412 .69763 m .4644 .6953 L .45864 .70663 L F
.46489 .69637 m .46482 .69621 L .46412 .69763 L F
.46482 .69621 m .4644 .6953 L .46412 .69763 L F
.46489 .69637 m .46412 .69763 L .45955 .70907 L F
.46412 .69763 m .45864 .70663 L .45955 .70907 L F
.4594 .70836 m .45921 .70795 L .45927 .70778 L F
.45921 .70795 m .45864 .70663 L .45927 .70778 L F
.45927 .70778 m .45864 .70663 L .45863 .70491 L F
.45955 .70907 m .45864 .70663 L .4594 .70836 L F
.45955 .70907 m .45863 .70491 L .45948 .70521 L F
.45955 .70907 m .45952 .70701 L .45599 .718 L F
.45955 .70907 m .45599 .718 L .45354 .72563 L F
.45864 .70663 m .45772 .70464 L .45733 .65464 L F
.45864 .70663 m .45733 .65464 L .45748 .65469 L F
.46164 .65376 m .45792 .65454 L .45841 .65473 L F
.46158 .65377 m .46084 .65379 L .45772 .65454 L F
.46158 .65377 m .45772 .65454 L .45779 .65454 L F
.46164 .65376 m .45733 .65464 L .45761 .65461 L F
.46175 .64476 m .46137 .64453 L .45332 .64422 L .196 0 0 r
F
.46175 .64476 m .45332 .64422 L .45402 .64449 L F
.45841 .65473 m .45725 .64465 L .45836 .64451 L 0 0 0 r
F
.45864 .70663 m .45748 .65484 L .45841 .65473 L F
.45948 .70521 m .45863 .70491 L .45841 .65473 L F
.45948 .70521 m .45841 .65473 L .45841 .65473 L F
.45935 .65449 m .46164 .65376 L .45841 .65473 L F
.45869 .6547 m .45841 .65473 L .45855 .65473 L F
.45855 .65473 m .45841 .65454 L .45855 .65454 L F
.45948 .70521 m .45841 .65473 L .45855 .65473 L F
.45841 .65473 m .45841 .65454 L .45855 .65473 L F
.45855 .65473 m .45841 .65473 L .45753 .655 L F
.4559 .70154 m .45499 .70027 L .44706 .70961 L .241 0 0 r
F
.4559 .70154 m .44706 .70961 L .44836 .71186 L F
.45681 .70298 m .4559 .70154 L .44836 .71186 L .236 0 0 r
F
.44986 .7141 m .44836 .71186 L .44965 .71444 L F
.45681 .70298 m .44873 .71146 L .44986 .7141 L F
.44873 .71146 m .44836 .71186 L .44986 .7141 L F
.45952 .70701 m .45397 .71828 L .45354 .72563 L 0 0 0 r
F
.45748 .65484 m .45748 .65464 L .45841 .65473 L F
.45748 .65464 m .45637 .65487 L .45841 .65473 L F
.45841 .65473 m .45637 .65487 L .45753 .655 L F
.45409 .69912 m .4532 .69806 L .4445 .7058 L .257 0 0 r
F
.45409 .69912 m .4445 .7058 L .44578 .70761 L F
.45499 .70027 m .45409 .69912 L .44578 .70761 L .248 0 0 r
F
.45499 .70027 m .44578 .70761 L .44706 .70961 L F
.45426 .65606 m .45203 .65598 L .45354 .6563 L .114 0 0 r
F
.45753 .655 m .45301 .65581 L .45426 .65606 L F
.45301 .65581 m .45203 .65598 L .45426 .65606 L F
.45457 .65613 m .45774 .65502 L .45457 .65607 L 1 .789 0 r
F
.45354 .72563 m .45774 .65508 L .45457 .65613 L F
.45774 .65508 m .45774 .65502 L .45457 .65613 L F
.45002 .65765 m .45354 .6563 L .44971 .65771 L .298 0 0 r
F
.45354 .72563 m .45457 .65633 L .4558 .65637 L 1 .789 0 r
F
.45457 .65633 m .45457 .65612 L .45569 .65635 L F
.45457 .65633 m .45569 .65635 L .4558 .65637 L F
.45952 .70701 m .45855 .65473 L .45397 .71828 L 0 0 0 r
F
.45855 .65473 m .45753 .655 L .45774 .65502 L F
.45855 .65473 m .45774 .65497 L .45774 .65502 L F
.45855 .65473 m .45774 .65502 L .45397 .71828 L F
.46244 .65372 m .45855 .65473 L .45869 .65514 L F
.45855 .65473 m .45774 .65502 L .45869 .65514 L F
.45638 .65621 m .45624 .65617 L .4558 .65635 L .155 0 0 r
F
.46138 .71626 m .4549 .73116 L .45609 .73881 L .249 .018 0 r
F
.4549 .73116 m .45482 .73134 L .45609 .73881 L F
.46164 .72362 m .46138 .71626 L .45609 .73881 L .259 .024 0 r
F
.46228 .72186 m .46217 .72117 L .46164 .72362 L F
.46217 .72117 m .46138 .71626 L .46164 .72362 L F
.46228 .72186 m .45609 .73881 L .45733 .7489 L F
.45717 .74577 m .45609 .73881 L .45637 .73007 L .011 0 0 r
F
.45733 .7489 m .45609 .73881 L .45717 .74577 L F
.45733 .7489 m .45637 .73007 L .45761 .73237 L F
.45733 .7489 m .45743 .74306 L .45143 .78152 L F
.46047 .71217 m .45955 .70907 L .4537 .72517 L .242 .011 0 r
F
.46047 .71217 m .4537 .72517 L .45373 .72522 L F
.46047 .71217 m .45359 .72548 L .4536 .72551 L F
.45986 .65533 m .45655 .65625 L .45724 .65676 L .155 0 0 r
F
.45986 .65533 m .45869 .65514 L .45624 .65617 L F
.45986 .65533 m .45624 .65617 L .45638 .65621 L F
.45986 .65533 m .4558 .65635 L .45615 .65636 L F
.46244 .65372 m .45841 .65473 L .45869 .6547 L 0 0 0 r
F
.46137 .64453 m .461 .64425 L .45262 .64391 L .232 0 0 r
F
.46137 .64453 m .45262 .64391 L .45332 .64422 L F
.46324 .6537 m .46244 .65372 L .45869 .65514 L 0 0 0 r
F
.46324 .6537 m .45869 .65514 L .45986 .65533 L F
.46047 .71217 m .4536 .72551 L .45482 .73134 L .242 .011 0 r
F
.4536 .72551 m .45354 .72563 L .45482 .73134 L F
.46138 .71626 m .46047 .71217 L .45482 .73134 L .249 .018 0 r
F
.45579 .73599 m .45482 .73134 L .45493 .72782 L .016 0 0 r
F
.45609 .73881 m .45482 .73134 L .45579 .73599 L F
.45621 .73004 m .45493 .72782 L .45724 .65676 L F
.45609 .73881 m .45724 .65676 L .45725 .65676 L F
.45802 .65663 m .45769 .65651 L .45724 .65676 L .194 0 0 r
F
.45609 .73881 m .45725 .65676 L .45744 .65683 L .016 0 0 r
F
.45457 .65607 m .45753 .655 L .45426 .65606 L .129 0 0 r
F
.45869 .65514 m .45774 .65502 L .45499 .65593 L F
.4551 .65595 m .45499 .65593 L .45457 .65607 L F
.45869 .65514 m .45499 .65593 L .4551 .65595 L F
.4558 .65635 m .45354 .6563 L .45505 .65667 L F
.45869 .65514 m .4551 .65595 L .4558 .65635 L F
.45457 .65612 m .45457 .65607 L .4558 .65637 L 1 .789 0 r
F
.4551 .65595 m .45457 .65607 L .4558 .65635 L .129 0 0 r
F
.45457 .65607 m .45577 .65608 L .4558 .65635 L 1 .789 0 r
F
.45457 .65607 m .4558 .65635 L .4558 .65637 L F
.45457 .65607 m .45354 .6563 L .4558 .65635 L .129 0 0 r
F
.45615 .65636 m .4558 .65635 L .456 .6564 L .155 0 0 r
F
.456 .65647 m .4558 .65626 L .456 .6564 L .021 0 0 r
F
.45491 .72586 m .4558 .65635 L .456 .65647 L F
.4558 .65635 m .4558 .65626 L .456 .65647 L F
.456 .6564 m .4558 .65626 L .45581 .65608 L F
.45774 .65502 m .45753 .655 L .45457 .65607 L .129 0 0 r
F
.45753 .655 m .45637 .65487 L .45203 .65598 L .114 0 0 r
F
.45457 .65607 m .45776 .65473 L .45458 .65553 L 1 .789 0 r
F
.45774 .65502 m .45776 .65473 L .45457 .65607 L F
.45617 .64495 m .45615 .64476 L .45618 .64476 L 1 .749 0 r
F
.45617 .64495 m .45618 .64476 L .45725 .64465 L F
.45733 .65448 m .45617 .64495 L .45725 .64465 L F
.45792 .65454 m .45748 .65464 L .45841 .65473 L 0 0 0 r
F
.45779 .65454 m .45772 .65454 L .45733 .65464 L F
.45748 .65464 m .45725 .64465 L .45841 .65473 L F
.45748 .65469 m .45733 .65464 L .45725 .64465 L F
.45641 .65455 m .45615 .64476 L .45733 .65448 L 1 .749 0 r
F
.45545 .64488 m .45474 .64471 L .44758 .64418 L .148 0 0 r
F
.45466 .65298 m .45392 .6527 L .4463 .65291 L .201 0 0 r
F
.45545 .64488 m .44758 .64418 L .44862 .64441 L .148 0 0 r
F
.45466 .65298 m .4463 .65291 L .44738 .65326 L .201 0 0 r
F
.45541 .65321 m .45466 .65298 L .44738 .65326 L .169 0 0 r
F
.45541 .65321 m .44738 .65326 L .44848 .65358 L F
.45617 .65341 m .45541 .65321 L .44848 .65358 L .136 0 0 r
F
.45617 .65341 m .44848 .65358 L .44958 .65385 L F
.45505 .64484 m .45396 .64487 L .44904 .64449 L .038 .145 0 r
F
.45505 .64484 m .44904 .64449 L .45045 .64453 L F
.45615 .64476 m .45505 .64484 L .45045 .64453 L .067 .15 0 r
F
.45522 .65475 m .45407 .65462 L .44906 .65541 L .112 0 0 r
F
.45615 .64476 m .45045 .64453 L .45187 .64454 L .067 .15 0 r
F
.45474 .64471 m .45402 .64449 L .44654 .64391 L .184 0 0 r
F
.45474 .64471 m .44654 .64391 L .44758 .64418 L F
.45725 .64465 m .45615 .64476 L .45187 .64454 L .093 .155 0 r
F
.45522 .65475 m .44906 .65541 L .45054 .65569 L .112 0 0 r
F
.45637 .65487 m .45522 .65475 L .45054 .65569 L .109 0 0 r
F
.45725 .64465 m .45187 .64454 L .4533 .64451 L .093 .155 0 r
F
.45836 .64451 m .45725 .64465 L .4533 .64451 L .115 .159 0 r
F
.45637 .65487 m .45054 .65569 L .45203 .65598 L .109 0 0 r
F
.45836 .64451 m .4533 .64451 L .45474 .64446 L .115 .159 0 r
F
.45458 .65553 m .45836 .64451 L .45474 .64446 L 1 .789 0 r
F
.45761 .65461 m .45733 .65464 L .45637 .65487 L 0 0 0 r
F
.45733 .65464 m .45522 .65475 L .45637 .65487 L F
.45641 .65455 m .45522 .65475 L .45733 .65464 L F
.45733 .65464 m .45641 .65455 L .45733 .65448 L 1 .749 0 r
F
.45776 .65473 m .45836 .64451 L .45458 .65553 L 1 .789 0 r
F
.456 .65612 m .45581 .65608 L .45619 .64439 L .021 0 0 r
F
.456 .6564 m .45581 .65608 L .456 .65612 L F
.45724 .65664 m .45619 .64439 L .45764 .6443 L F
.45655 .65625 m .456 .6564 L .45724 .65676 L .155 0 0 r
F
.45482 .73134 m .456 .6564 L .45724 .65676 L .021 0 0 r
F
.45491 .72586 m .45363 .72288 L .4558 .65635 L F
.45491 .72586 m .4558 .65635 L .4558 .65635 L F
.456 .6564 m .45505 .65667 L .45645 .65673 L .155 0 0 r
F
.456 .6564 m .45645 .65673 L .45724 .65676 L F
.45724 .65676 m .456 .65617 L .45724 .65664 L .021 0 0 r
F
.456 .6564 m .456 .65617 L .45724 .65676 L F
.456 .65617 m .45619 .64439 L .45724 .65664 L F
.46104 .6556 m .45802 .65663 L .45869 .65731 L .194 0 0 r
F
.46104 .6556 m .45986 .65533 L .45769 .65651 L F
.46104 .6556 m .45769 .65651 L .45802 .65663 L F
.45841 .65473 m .45841 .65473 L .45841 .65454 L 0 0 0 r
F
.45855 .65454 m .45841 .65454 L .45836 .64451 L F
.45855 .65473 m .45836 .64451 L .45774 .65497 L F
.45869 .65731 m .45764 .6443 L .4591 .64422 L .016 0 0 r
F
.45609 .73881 m .45743 .65719 L .45869 .65731 L F
.45761 .73237 m .45637 .73007 L .45869 .65731 L .011 0 0 r
F
.45761 .73237 m .45869 .65731 L .45869 .65732 L F
.45946 .65703 m .46104 .6556 L .45869 .65731 L .241 0 0 r
F
.45905 .65734 m .45869 .65731 L .45888 .65741 L F
.45888 .65741 m .4587 .65689 L .45889 .65696 L .011 0 0 r
F
.45761 .73237 m .45869 .65731 L .45888 .65741 L F
.45869 .65731 m .4587 .65689 L .45888 .65741 L F
.45849 .65711 m .45818 .65712 L .45869 .65731 L .194 0 0 r
F
.45802 .65663 m .4576 .65678 L .45849 .65711 L F
.45802 .65663 m .45724 .65676 L .45744 .65683 L F
.45744 .65683 m .45764 .6443 L .45869 .65731 L .016 0 0 r
F
.45682 .65699 m .45505 .65667 L .45656 .65713 L .155 0 0 r
F
.45724 .65676 m .45645 .65673 L .45682 .65699 L F
.45645 .65673 m .45505 .65667 L .45682 .65699 L F
.45744 .65648 m .45725 .65643 L .45764 .6443 L .016 0 0 r
F
.45656 .65713 m .45505 .65667 L .45154 .65836 L .336 0 0 r
F
.45382 .65889 m .45154 .65836 L .45338 .65917 L F
.45656 .65713 m .45222 .6582 L .45382 .65889 L F
.45222 .6582 m .45154 .65836 L .45382 .65889 L F
.45808 .65775 m .45656 .65713 L .45382 .65889 L .377 0 0 r
F
.45412 .65895 m .45382 .65889 L .45338 .65917 L F
.45808 .65775 m .45382 .65889 L .45412 .65895 L F
.4556 .6599 m .45338 .65917 L .45521 .66024 L F
.45373 .72522 m .4537 .72517 L .45359 .72548 L .242 .011 0 r
F
.4536 .72551 m .45359 .72548 L .45354 .72563 L F
.45482 .73134 m .45354 .72563 L .45363 .72288 L .021 0 0 r
F
.45482 .73134 m .45363 .72288 L .45491 .72586 L F
.45605 .65993 m .45643 .65952 L .45584 .65987 L .418 .008 0 r
F
.45643 .65952 m .45808 .65775 L .45622 .65937 L F
.45643 .65952 m .45622 .65937 L .45521 .66024 L F
.45834 .65789 m .45808 .65775 L .45605 .65993 L F
.45605 .65993 m .45835 .65777 L .45607 .65959 L 1 .818 0 r
F
.45143 .78152 m .45834 .65789 L .4582 .65802 L F
.45605 .66007 m .4582 .65802 L .45605 .65993 L F
.45143 .78152 m .4582 .65802 L .45605 .66007 L F
.45294 .66303 m .45521 .66024 L .45246 .66319 L .64 .047 0 r
F
.45609 .73881 m .45493 .72782 L .45621 .73004 L .016 0 0 r
F
.45743 .74306 m .45888 .65741 L .45224 .76704 L .011 0 0 r
F
.45888 .65741 m .45808 .65775 L .45834 .65789 L .241 0 0 r
F
.45888 .65741 m .45835 .65777 L .45834 .65789 L .011 0 0 r
F
.45888 .65741 m .45834 .65789 L .45224 .76704 L F
.46222 .65603 m .45888 .65741 L .45961 .65862 L .241 0 0 r
F
.45888 .65741 m .45834 .65789 L .45961 .65862 L F
.45743 .74306 m .45224 .76704 L .45143 .78152 L .011 0 0 r
F
.45855 .76295 m .45733 .7489 L .45145 .78142 L .486 .065 0 r
F
.45145 .78146 m .45145 .78142 L .45143 .78152 L F
.45855 .76295 m .45145 .78142 L .45145 .78146 L F
.45855 .76295 m .45145 .78146 L .45309 .7998 L F
.45145 .78146 m .45143 .78152 L .45309 .7998 L F
.45902 .78469 m .45855 .76295 L .45309 .7998 L .505 .069 0 r
F
.45975 .78282 m .45958 .78001 L .45902 .78469 L F
.45958 .78001 m .45855 .76295 L .45902 .78469 L F
.45975 .78282 m .45309 .7998 L .45492 .82179 L F
.4547 .81778 m .45309 .7998 L .45335 .79405 L .204 .027 0 r
F
.45492 .82179 m .45309 .7998 L .4547 .81778 L F
.45533 .80716 m .45335 .79405 L .45936 .66311 L F
.45492 .82179 m .45335 .79405 L .45533 .80716 L F
.45309 .7998 m .45143 .78152 L .45758 .66109 L .194 .025 0 r
F
.45309 .7998 m .45758 .66109 L .45758 .6611 L F
.45799 .66059 m .45668 .6597 L .45758 .66109 L .418 .008 0 r
F
.46114 .65995 m .45847 .66111 L .45936 .66311 L .487 .031 0 r
F
.45492 .82179 m .45936 .66311 L .45937 .66312 L .204 .027 0 r
F
.45964 .66359 m .46114 .65995 L .45936 .66311 L .558 .051 0 r
F
.45964 .66359 m .45938 .66269 L .45965 .6631 L .204 .027 0 r
F
.45492 .82179 m .45937 .66312 L .45964 .66359 L F
.45937 .66312 m .45938 .66269 L .45964 .66359 L F
.46114 .65995 m .45758 .66109 L .45784 .66138 L .487 .031 0 r
F
.45847 .66111 m .45784 .66138 L .45936 .66311 L F
.45936 .66311 m .45785 .66117 L .45941 .66205 L .194 .025 0 r
F
.45309 .7998 m .45784 .66138 L .45936 .66311 L F
.45784 .66138 m .45785 .66117 L .45936 .66311 L F
.45309 .7998 m .45758 .66109 L .45765 .66117 L F
.45825 .66087 m .45799 .66059 L .45758 .66109 L .487 .031 0 r
F
.45309 .7998 m .45766 .66096 L .45784 .66138 L .194 .025 0 r
F
.45143 .78152 m .45605 .65993 L .45758 .66109 L 1 .818 0 r
F
.45784 .66138 m .45705 .66172 L .45936 .66311 L .487 .031 0 r
F
.46114 .65995 m .45961 .65862 L .45799 .66059 L F
.46114 .65995 m .45799 .66059 L .45825 .66087 L F
.45892 .66388 m .45705 .66172 L .45889 .66395 L F
.45832 .66248 m .45705 .66172 L .45892 .66388 L F
.45961 .65862 m .45725 .65949 L .45799 .66059 L .418 .008 0 r
F
.45725 .65949 m .45668 .6597 L .45799 .66059 L F
.45834 .65789 m .45835 .65777 L .45605 .65993 L 1 .818 0 r
F
.45961 .65862 m .45834 .65789 L .45605 .65993 L .418 .008 0 r
F
.45808 .65775 m .45547 .65854 L .45622 .65937 L .377 0 0 r
F
.45622 .65937 m .45398 .65899 L .4556 .6599 L F
.45547 .65854 m .45398 .65899 L .45622 .65937 L F
.45607 .65959 m .4591 .64422 L .45664 .64445 L 1 .818 0 r
F
.45743 .65719 m .45744 .65683 L .45869 .65731 L .016 0 0 r
F
.45818 .65712 m .45656 .65713 L .45869 .65731 L .194 0 0 r
F
.4576 .65678 m .45656 .65713 L .45849 .65711 L F
.45744 .65683 m .45724 .65676 L .45656 .65713 L F
.45725 .65676 m .45725 .65664 L .45744 .65683 L .016 0 0 r
F
.45744 .65683 m .45725 .65643 L .45744 .65648 L F
.45725 .65664 m .45725 .65643 L .45744 .65683 L F
.45825 .65763 m .45656 .65713 L .45808 .65775 L .194 0 0 r
F
.45869 .65731 m .45785 .65724 L .45825 .65763 L F
.45785 .65724 m .45656 .65713 L .45825 .65763 L F
.45725 .65676 m .45724 .65676 L .45725 .65643 L .016 0 0 r
F
.45835 .65777 m .4591 .64422 L .45607 .65959 L 1 .818 0 r
F
.4587 .65749 m .45869 .65731 L .45808 .65775 L .241 0 0 r
F
.45888 .65741 m .45883 .65739 L .4587 .65749 L F
.45883 .65739 m .45869 .65731 L .4587 .65749 L F
.46222 .65603 m .45869 .65731 L .45905 .65734 L F
.45869 .65732 m .45869 .65731 L .4587 .65689 L .011 0 0 r
F
.45889 .65696 m .4587 .65689 L .4591 .64422 L F
.45888 .65741 m .4591 .64422 L .45835 .65777 L F
.46222 .65603 m .4614 .65573 L .45946 .65703 L .241 0 0 r
F
.4614 .65573 m .46104 .6556 L .45946 .65703 L F
.46244 .65372 m .46189 .65375 L .45935 .65449 L 0 0 0 r
F
.46189 .65375 m .46164 .65376 L .45935 .65449 L F
.45941 .66205 m .45842 .64457 L .4602 .64479 L .194 .025 0 r
F
.45785 .66117 m .45842 .64457 L .45941 .66205 L F
.45889 .66395 m .45705 .66172 L .45492 .66496 L .701 .064 0 r
F
.45529 .66524 m .45492 .66496 L .45456 .6655 L F
.45889 .66395 m .45492 .66496 L .45529 .66524 L F
.45889 .66395 m .45456 .6655 L .45665 .669 L F
.45786 .66797 m .45889 .66395 L .45706 .66806 L .751 .12 0 r
F
.45923 .66465 m .45889 .66395 L .45786 .66797 L F
.45754 .66923 m .45923 .66465 L .45756 .66869 L 1 .844 0 r
F
.45021 .84999 m .45923 .6647 L .45754 .66923 L F
.45923 .6647 m .45923 .66465 L .45754 .66923 L F
.45523 .67539 m .45665 .669 L .45441 .67551 L .895 .302 0 r
F
.45829 .69783 m .4595 .66415 L .45912 .66701 L .204 .027 0 r
F
.45829 .69783 m .45912 .66701 L .45021 .84999 L F
.45955 .66363 m .45936 .66311 L .45889 .66395 L .558 .051 0 r
F
.45964 .66359 m .4596 .66352 L .45955 .66363 L F
.4596 .66352 m .45936 .66311 L .45955 .66363 L F
.45965 .6631 m .45938 .66269 L .45941 .6621 L .204 .027 0 r
F
.46405 .65372 m .46324 .6537 L .45986 .65533 L 0 0 0 r
F
.46405 .65372 m .45986 .65533 L .46104 .6556 L F
.4634 .65672 m .46222 .65603 L .45961 .65862 L .292 0 0 r
F
.4634 .65672 m .45961 .65862 L .46114 .65995 L F
.45968 .66238 m .45941 .6621 L .4602 .64479 L .204 .027 0 r
F
.45965 .6631 m .45941 .6621 L .45968 .66238 L F
.45505 .81749 m .45964 .66359 L .45351 .83026 L F
.45964 .66359 m .45889 .66395 L .45923 .66465 L .558 .051 0 r
F
.45964 .66359 m .4602 .64479 L .45951 .66393 L .204 .027 0 r
F
.45964 .66359 m .45951 .66393 L .45351 .83026 L F
.46266 .66215 m .45964 .66359 L .4607 .66762 L .558 .051 0 r
F
.4595 .66415 m .45951 .6638 L .45946 .66423 L .204 .027 0 r
F
.4595 .66415 m .45946 .66423 L .45912 .66701 L F
.45951 .6638 m .45925 .66424 L .45912 .66701 L F
.45964 .66359 m .45923 .66465 L .4607 .66762 L .558 .051 0 r
F
.45351 .83026 m .45829 .69783 L .45021 .84999 L .204 .027 0 r
F
.45492 .82179 m .45505 .81749 L .45351 .83026 L F
.4607 .66762 m .45817 .66848 L .4592 .67302 L .751 .12 0 r
F
.45021 .84999 m .45755 .66902 L .4592 .67302 L 1 .844 0 r
F
.45755 .66902 m .45756 .66869 L .4592 .67302 L F
.46539 .69775 m .46489 .69637 L .45955 .70907 L 0 0 0 r
F
.46539 .69775 m .45955 .70907 L .46047 .71217 L F
.46588 .69958 m .46539 .69775 L .46047 .71217 L F
.46588 .69958 m .46047 .71217 L .46138 .71626 L F
.46316 .72996 m .46228 .72186 L .45733 .7489 L .272 .03 0 r
F
.45709 .8462 m .45492 .82179 L .45021 .84999 L .693 .191 0 r
F
.45709 .8462 m .45021 .84999 L .45346 .86845 L F
.45346 .86845 m .45021 .84999 L .4592 .67302 L .346 .053 0 r
F
.45346 .86845 m .4592 .67302 L .45924 .6732 L F
.46245 .67464 m .4607 .66762 L .45954 .67182 L .795 .233 0 r
F
.45992 .67338 m .45954 .67182 L .4592 .67302 L F
.46245 .67464 m .45954 .67182 L .45992 .67338 L F
.46245 .67464 m .4592 .67302 L .45995 .67483 L F
.45965 .67485 m .45931 .67091 L .45975 .67183 L .346 .053 0 r
F
.46102 .81014 m .45975 .78282 L .45492 .82179 L .522 .071 0 r
F
.46102 .81014 m .45492 .82179 L .45709 .8462 L F
.45346 .86845 m .45924 .67319 L .45965 .67485 L .346 .053 0 r
F
.45965 .67485 m .4592 .67302 L .45868 .67492 L .795 .233 0 r
F
.45995 .67483 m .4592 .67302 L .45965 .67485 L F
.45924 .67319 m .45929 .67154 L .45965 .67485 L .346 .053 0 r
F
.45929 .67154 m .45931 .67091 L .45965 .67485 L F
.46245 .67464 m .46028 .6748 L .46116 .68298 L .795 .233 0 r
F
.46266 .66215 m .46149 .66046 L .45964 .66359 L .558 .051 0 r
F
.46149 .66046 m .46114 .65995 L .45964 .66359 L F
.46164 .65376 m .46162 .65376 L .46158 .65377 L 0 0 0 r
F
.46162 .65376 m .46084 .65379 L .46158 .65377 L F
.46538 .6527 m .46121 .65356 L .46084 .65379 L .161 .167 0 r
F
.46116 .65357 m .46113 .65358 L .46079 .65365 L F
.46085 .65363 m .46079 .65365 L .46005 .6538 L F
.46121 .65356 m .46005 .6538 L .4602 .65379 L F
.46121 .65356 m .4602 .65379 L .46084 .65379 L F
.46121 .65356 m .4602 .65376 L .4602 .65379 L 0 0 0 r
F
.4658 .65255 m .46538 .6527 L .4615 .65363 L .195 .173 0 r
F
.46155 .65361 m .4615 .65363 L .46084 .65379 L F
.4658 .65255 m .4615 .65363 L .46155 .65361 L F
.46084 .65379 m .46083 .65379 L .46083 .65379 L 0 0 0 r
F
.46083 .65379 m .46005 .6538 L .46083 .65379 L F
.4658 .65255 m .46084 .65379 L .46164 .65376 L .195 .173 0 r
F
.46623 .65239 m .4658 .65255 L .46164 .65376 L .227 .177 0 r
F
.46623 .65239 m .46164 .65376 L .46244 .65372 L F
.46487 .65381 m .46405 .65372 L .46104 .6556 L 0 0 0 r
F
.46487 .65381 m .46104 .6556 L .46222 .65603 L F
.46568 .65406 m .46487 .65381 L .46222 .65603 L .045 0 0 r
F
.46568 .65406 m .46222 .65603 L .4634 .65672 L F
.46459 .65792 m .4634 .65672 L .46114 .65995 L .342 .009 0 r
F
.46459 .65792 m .46114 .65995 L .46266 .66215 L F
.46416 .66622 m .46266 .66215 L .4607 .66762 L .621 .068 0 r
F
.46416 .66622 m .4607 .66762 L .46245 .67464 L F
.46116 .68298 m .46057 .64621 L .46263 .64766 L .346 .053 0 r
F
.46316 .72996 m .45733 .7489 L .45855 .76295 L .272 .03 0 r
F
.45346 .86845 m .45965 .67485 L .46116 .68298 L .346 .053 0 r
F
.46028 .6748 m .45965 .67485 L .46116 .68298 L .795 .233 0 r
F
.4607 .66762 m .45792 .66796 L .45817 .66848 L .751 .12 0 r
F
.4607 .66762 m .45923 .66465 L .45786 .66797 L F
.45965 .67485 m .46057 .64621 L .46116 .68298 L .346 .053 0 r
F
.45965 .67485 m .45868 .67492 L .46116 .68298 L .795 .233 0 r
F
.46079 .68537 m .45868 .67492 L .46056 .68689 L F
.46116 .68298 m .46019 .67982 L .46079 .68537 L F
.46019 .67982 m .45868 .67492 L .46079 .68537 L F
.464 .74238 m .46316 .72996 L .45855 .76295 L .288 .036 0 r
F
.464 .74238 m .45855 .76295 L .45975 .78282 L F
.46254 .84376 m .46102 .81014 L .45709 .8462 L .524 .071 0 r
F
.45973 .87059 m .45709 .8462 L .45346 .86845 L .682 .174 0 r
F
.46254 .84376 m .45709 .8462 L .45973 .87059 L .524 .071 0 r
F
.45973 .87059 m .45346 .86845 L .4572 .88567 L .682 .174 0 r
F
.4572 .88567 m .45346 .86845 L .46116 .68298 L .352 .054 0 r
F
.4572 .88567 m .46116 .68298 L .46123 .68373 L F
.46197 .68564 m .46245 .67464 L .46116 .68298 L .845 .336 0 r
F
.464 .69239 m .46205 .68591 L .46169 .68871 L F
.46205 .68591 m .46116 .68298 L .46169 .68871 L F
.4572 .88567 m .46133 .67904 L .46138 .67926 L .352 .054 0 r
F
.4572 .88567 m .46138 .67926 L .46169 .68871 L F
.4679 .87971 m .46781 .87892 L .45611 .8874 L 0 0 0 r
F
.4679 .87971 m .45611 .8874 L .45706 .8883 L F
.4572 .88567 m .46158 .69371 L .45496 .89474 L .352 .054 0 r
F
.46158 .69371 m .46169 .68871 L .46151 .69441 L F
.46158 .69371 m .46151 .69441 L .45496 .89474 L F
.45975 .71135 m .46056 .68689 L .45831 .70526 L .967 .474 0 r
F
.46123 .69591 m .46122 .69579 L .46104 .69892 L .845 .336 0 r
F
.46122 .69579 m .46056 .68689 L .46104 .69892 L F
.45956 .7241 m .46068 .70304 L .45989 .71196 L 1 .85 0 r
F
.45496 .89474 m .46079 .70686 L .45956 .7241 L F
.46079 .70686 m .46104 .69892 L .45987 .71888 L F
.46079 .70686 m .45987 .71888 L .45956 .7241 L F
.45747 .75009 m .45831 .70526 L .4555 .73251 L 1 .571 0 r
F
.45989 .71196 m .46104 .69892 L .45981 .71078 L .967 .474 0 r
F
.46104 .69892 m .46056 .68689 L .45975 .71135 L F
.46169 .68871 m .46104 .69892 L .45496 .89474 L .352 .054 0 r
F
.46637 .70212 m .46588 .69958 L .46138 .71626 L 0 0 0 r
F
.46169 .68871 m .46056 .68689 L .46248 .71269 L .845 .336 0 r
F
.46104 .69892 m .46125 .69226 L .45956 .7241 L 1 .85 0 r
F
.4619 .72048 m .46042 .71419 L .46075 .73785 L .967 .474 0 r
F
.46042 .71419 m .45989 .71196 L .46075 .73785 L F
.46799 .88046 m .4679 .87971 L .45723 .88817 L 0 0 0 r
F
.45725 .88817 m .45723 .88817 L .45706 .8883 L F
.46799 .88046 m .45723 .88817 L .45725 .88817 L F
.48182 .86427 m .46736 .87387 L .46745 .87505 L F
.46967 .6864 m .46962 .68624 L .46391 .69443 L F
.46967 .6864 m .46391 .69443 L .4644 .6953 L F
.46973 .68661 m .46967 .6864 L .4644 .6953 L F
.46973 .68661 m .4644 .6953 L .46489 .69637 L F
.46978 .68693 m .46973 .68661 L .46489 .69637 L F
.46978 .68693 m .46489 .69637 L .46539 .69775 L F
.46983 .68741 m .46978 .68693 L .46539 .69775 L F
.46983 .68741 m .46539 .69775 L .46588 .69958 L F
.46987 .68817 m .46983 .68741 L .46588 .69958 L F
.46987 .68817 m .46588 .69958 L .46637 .70212 L F
.46992 .68939 m .46987 .68817 L .46637 .70212 L F
.46992 .68939 m .46637 .70212 L .46685 .70584 L F
.46996 .69138 m .46992 .68939 L .46685 .70584 L F
.46996 .69138 m .46685 .70584 L .46732 .71163 L F
.46999 .69488 m .46996 .69138 L .46732 .71163 L F
.46799 .88046 m .45706 .8883 L .45803 .88917 L F
.46999 .69488 m .46732 .71163 L .46777 .72152 L F
.47001 .70181 m .46999 .69488 L .46777 .72152 L F
.46809 .88118 m .46799 .88046 L .45818 .88903 L F
.45819 .88903 m .45818 .88903 L .45803 .88917 L F
.46809 .88118 m .45818 .88903 L .45819 .88903 L F
.46809 .88118 m .45803 .88917 L .459 .89001 L F
.47001 .70181 m .46777 .72152 L .46815 .74108 L F
.46912 .7296 m .47001 .70181 L .46815 .74108 L F
.46913 .72947 m .46998 .70895 L .46912 .7296 L F
.46998 .70895 m .47001 .70181 L .46912 .7296 L F
.46989 .65177 m .46984 .65191 L .46512 .65278 L .227 .179 0 r
F
.46989 .65177 m .46512 .65278 L .46512 .65277 L F
.46984 .65191 m .4698 .65202 L .4651 .65278 L .182 .172 0 r
F
.47059 .65195 m .46967 .65205 L .46971 .65208 L .123 .161 0 r
F
.47084 .65188 m .46967 .65205 L .47059 .65195 L F
.47574 .65108 m .46971 .65208 L .46976 .65207 L .17 .17 0 r
F
.47606 .65112 m .47084 .65188 L .47059 .65195 L .123 .161 0 r
F
.47638 .65111 m .4767 .65105 L .4712 .65176 L 0 0 0 r
F
.47574 .65108 m .47606 .65112 L .46971 .65208 L .17 .17 0 r
F
.4767 .65105 m .47122 .65163 L .47122 .65163 L 0 0 0 r
F
.47758 .6506 m .47742 .6444 L .47127 .65156 L .994 .647 0 r
F
.47702 .65094 m .47733 .65077 L .47124 .65145 L .014 0 0 r
F
.47126 .65151 m .47124 .65145 L .47124 .65145 L .994 .647 0 r
F
.47702 .65094 m .47124 .65145 L .47125 .65148 L .014 0 0 r
F
.47702 .65094 m .47125 .65148 L .47128 .65162 L F
.47542 .65099 m .46976 .65207 L .4698 .65202 L .218 .178 0 r
F
.47638 .65111 m .4712 .65176 L .4712 .65176 L 0 0 0 r
F
.47542 .65099 m .47574 .65108 L .46976 .65207 L .218 .178 0 r
F
.47733 .65077 m .47758 .6506 L .4712 .65127 L .057 0 0 r
F
.47127 .65156 m .47155 .65123 L .4712 .65127 L .994 .647 0 r
F
.47122 .65135 m .47121 .65129 L .47123 .6514 L F
.47122 .65135 m .47123 .6514 L .47126 .65151 L F
.47121 .65129 m .4712 .65129 L .47121 .6513 L F
.47121 .65129 m .47121 .6513 L .47126 .65151 L F
.47733 .65077 m .4712 .65127 L .47124 .65145 L .057 0 0 r
F
.47509 .65084 m .4698 .65202 L .46984 .65191 L .265 .186 0 r
F
.47509 .65084 m .47542 .65099 L .4698 .65202 L F
.47571 .68005 m .4761 .68023 L .46947 .68588 L .665 .262 0 r
F
.47125 .65147 m .47125 .65147 L .47124 .65144 L .88 .141 0 r
F
.47125 .65148 m .47118 .65149 L .47128 .65162 L .014 0 0 r
F
.47125 .65148 m .47117 .65146 L .47118 .65149 L F
.47476 .65065 m .46984 .65191 L .46989 .65177 L .313 .193 0 r
F
.47476 .65065 m .47509 .65084 L .46984 .65191 L F
.47571 .68005 m .46947 .68588 L .46952 .686 L .665 .262 0 r
F
.46989 .65177 m .46454 .65289 L .46496 .65281 L .227 .179 0 r
F
.46993 .65158 m .46989 .65177 L .46496 .65281 L .272 .187 0 r
F
.47155 .65123 m .47742 .6444 L .4712 .65127 L .994 .647 0 r
F
.47443 .65042 m .46989 .65177 L .46993 .65158 L .362 .2 0 r
F
.47124 .65142 m .47123 .65141 L .47123 .65141 L .994 .647 0 r
F
.47124 .65145 m .47123 .65142 L .47124 .65142 L F
.47124 .65145 m .47123 .65142 L .47124 .65145 L F
.47443 .65042 m .47476 .65065 L .46989 .65177 L .362 .2 0 r
F
.47533 .67982 m .47571 .68005 L .46952 .686 L .711 .321 0 r
F
.46993 .65158 m .46496 .65281 L .46538 .6527 L .272 .187 0 r
F
.47533 .67982 m .46952 .686 L .46957 .68612 L .711 .321 0 r
F
.4741 .65013 m .47443 .65042 L .46993 .65158 L .41 .218 0 r
F
.46998 .65135 m .46993 .65158 L .46538 .6527 L .318 .194 0 r
F
.4741 .65013 m .46993 .65158 L .46998 .65135 L .41 .218 0 r
F
.46998 .65135 m .46538 .6527 L .4658 .65255 L .318 .194 0 r
F
.47494 .67956 m .47533 .67982 L .46957 .68612 L .754 .366 0 r
F
.47494 .67956 m .46957 .68612 L .46962 .68624 L F
.47377 .6498 m .4741 .65013 L .46998 .65135 L .46 .304 0 r
F
.47002 .65109 m .46998 .65135 L .4658 .65255 L .363 .2 0 r
F
.47377 .6498 m .46998 .65135 L .47002 .65109 L .46 .304 0 r
F
.47002 .65109 m .4658 .65255 L .46623 .65239 L .363 .2 0 r
F
.47455 .67927 m .47494 .67956 L .46962 .68624 L .79 .39 0 r
F
.47455 .67927 m .46962 .68624 L .46967 .6864 L F
.47343 .64944 m .47377 .6498 L .47002 .65109 L .511 .393 0 r
F
.47007 .6508 m .47002 .65109 L .46623 .65239 L .409 .206 0 r
F
.47343 .64944 m .47002 .65109 L .47007 .6508 L .511 .393 0 r
F
.47007 .6508 m .46623 .65239 L .46666 .65221 L .409 .206 0 r
F
.47416 .67897 m .47455 .67927 L .46967 .6864 L .822 .393 0 r
F
.47416 .67897 m .46967 .6864 L .46973 .68661 L F
.47309 .64903 m .47343 .64944 L .47007 .6508 L .565 .479 0 r
F
.47012 .65048 m .47007 .6508 L .46666 .65221 L .455 .212 0 r
F
.47309 .64903 m .47007 .6508 L .47012 .65048 L .565 .479 0 r
F
.47377 .67866 m .47416 .67897 L .46973 .68661 L .846 .372 0 r
F
.47276 .64859 m .47309 .64903 L .47012 .65048 L .621 .556 0 r
F
.47276 .64859 m .47012 .65048 L .47016 .65016 L F
.47377 .67866 m .46973 .68661 L .46978 .68693 L .846 .372 0 r
F
.47338 .67838 m .47377 .67866 L .46978 .68693 L .863 .329 0 r
F
.47242 .64813 m .47276 .64859 L .47016 .65016 L .682 .617 0 r
F
.47242 .64813 m .47016 .65016 L .47021 .64985 L F
.47338 .67838 m .46978 .68693 L .46983 .68741 L .863 .329 0 r
F
.47208 .64766 m .47242 .64813 L .47021 .64985 L .765 .644 0 r
F
.47208 .64766 m .47021 .64985 L .47026 .6496 L F
.46913 .72947 m .47035 .64964 L .46926 .65328 L .993 .526 0 r
F
.48112 .86517 m .48182 .86427 L .46745 .87505 L 0 0 0 r
F
.48112 .86517 m .46745 .87505 L .46753 .87614 L F
.48041 .86597 m .48112 .86517 L .46753 .87614 L F
.48041 .86597 m .46753 .87614 L .46762 .87715 L F
.47969 .86667 m .48041 .86597 L .46762 .87715 L F
.47969 .86667 m .46762 .87715 L .46771 .87807 L F
.47897 .86729 m .47969 .86667 L .46771 .87807 L .504 .199 0 r
F
.47897 .86729 m .46771 .87807 L .46781 .87892 L F
.47824 .86783 m .47897 .86729 L .46781 .87892 L .557 .205 0 r
F
.47824 .86783 m .46781 .87892 L .4679 .87971 L F
.4775 .86832 m .47824 .86783 L .4679 .87971 L .606 .209 0 r
F
.4775 .86832 m .4679 .87971 L .46799 .88046 L F
.47675 .86877 m .4775 .86832 L .47061 .87711 L .649 .211 0 r
F
.47065 .87691 m .47061 .87711 L .46799 .88046 L F
.47675 .86877 m .47061 .87711 L .47065 .87691 L F
.47831 .64364 m .46944 .6436 L .46948 .64396 L .22 0 0 r
F
.47801 .64394 m .46948 .64396 L .46951 .64426 L .186 0 0 r
F
.47801 .64394 m .47831 .64364 L .46948 .64396 L F
.47772 .64419 m .46951 .64426 L .46955 .64452 L .151 0 0 r
F
.47772 .64419 m .47801 .64394 L .46951 .64426 L F
.47742 .6444 m .46955 .64452 L .46959 .64473 L .114 0 0 r
F
.47742 .6444 m .47772 .64419 L .46955 .64452 L F
.47881 .6492 m .47476 .65065 L .47443 .65042 L .43 .307 0 r
F
.47811 .64888 m .47443 .65042 L .4741 .65013 L .477 .413 0 r
F
.47811 .64888 m .47881 .6492 L .47443 .65042 L F
.4774 .64852 m .4741 .65013 L .47377 .6498 L .524 .521 0 r
F
.4774 .64852 m .47811 .64888 L .4741 .65013 L F
.47908 .67343 m .47494 .67956 L .47455 .67927 L 1 .976 0 r
F
.47669 .6481 m .47377 .6498 L .47343 .64944 L .572 .629 0 r
F
.47669 .6481 m .4774 .64852 L .47377 .6498 L F
.47826 .67282 m .47908 .67343 L .47455 .67927 L 1 .998 0 r
F
.47826 .67282 m .47455 .67927 L .47416 .67897 L F
.47598 .64764 m .47343 .64944 L .47309 .64903 L .631 .734 0 r
F
.47598 .64764 m .47669 .6481 L .47343 .64944 L F
.47745 .67216 m .47826 .67282 L .47416 .67897 L 1 1 0 r
F
.47745 .67216 m .47416 .67897 L .47377 .67866 L F
.47527 .64713 m .47309 .64903 L .47276 .64859 L .729 .836 0 r
F
.47527 .64713 m .47598 .64764 L .47309 .64903 L F
.47663 .67146 m .47745 .67216 L .47377 .67866 L 1 .988 0 r
F
.47663 .67146 m .47377 .67866 L .47338 .67838 L F
.47455 .64657 m .47276 .64859 L .47242 .64813 L .838 .932 0 r
F
.47455 .64657 m .47527 .64713 L .47276 .64859 L F
.47581 .67071 m .47663 .67146 L .47338 .67838 L 1 .956 0 r
F
.47383 .64597 m .47455 .64657 L .47242 .64813 L .957 1 0 r
F
.4755 .64445 m .47455 .64657 L .47383 .64597 L 1 1 0 r
F
.47383 .64597 m .47242 .64813 L .47208 .64766 L .957 1 0 r
F
.47581 .67071 m .47338 .67838 L .47298 .67816 L 1 .956 0 r
F
.47499 .66992 m .47581 .67071 L .47298 .67816 L 1 .908 0 r
F
.47311 .64531 m .47383 .64597 L .47208 .64766 L 1 1 0 r
F
.47442 .64367 m .47383 .64597 L .47311 .64531 L F
.47442 .64367 m .4755 .64445 L .47383 .64597 L F
.47499 .66992 m .47298 .67816 L .47259 .67805 L 1 .908 0 r
F
.47416 .66909 m .47499 .66992 L .47259 .67805 L 1 .847 0 r
F
.47595 .66259 m .47499 .66992 L .47416 .66909 L 1 1 0 r
F
.47416 .66909 m .47259 .67805 L .47219 .67814 L 1 .847 0 r
F
.47436 .66627 m .47595 .66259 L .47416 .66909 L 1 1 0 r
F
.47473 .66109 m .475 .66142 L .47436 .66627 L F
.475 .66142 m .47595 .66259 L .47436 .66627 L F
.48231 .67528 m .47648 .68037 L .4761 .68023 L .753 .713 0 r
F
.48151 .67491 m .4761 .68023 L .47571 .68005 L .837 .803 0 r
F
.48151 .67491 m .48231 .67528 L .4761 .68023 L F
.4807 .67448 m .47571 .68005 L .47533 .67982 L .916 .878 0 r
F
.4807 .67448 m .48151 .67491 L .47571 .68005 L F
.47989 .67398 m .47533 .67982 L .47494 .67956 L .989 .936 0 r
F
.47989 .67398 m .4807 .67448 L .47533 .67982 L F
.47908 .67343 m .47989 .67398 L .47494 .67956 L 1 .976 0 r
F
.47839 .66497 m .47663 .67146 L .47581 .67071 L 1 1 0 r
F
.47717 .66385 m .47839 .66497 L .47581 .67071 L F
.47717 .66385 m .47581 .67071 L .47499 .66992 L F
.47595 .66259 m .47717 .66385 L .47499 .66992 L F
.476 .65595 m .47595 .66259 L .47473 .66109 L F
.47336 .66431 m .47442 .64367 L .47311 .64531 L .824 .369 0 r
F
.47334 .66821 m .47416 .66909 L .47219 .67814 L 1 .775 0 r
F
.47473 .66109 m .47416 .66909 L .47344 .66832 L 1 1 0 r
F
.47386 .66552 m .47344 .66832 L .47334 .66821 L F
.47473 .66109 m .47344 .66832 L .47386 .66552 L F
.47449 .66037 m .47442 .64367 L .47336 .66431 L .824 .369 0 r
F
.47173 .64721 m .47208 .64766 L .47026 .6496 L .841 .608 0 r
F
.47311 .64531 m .47208 .64766 L .47173 .64721 L 1 1 0 r
F
.47338 .66606 m .4745 .66073 L .47334 .66821 L 1 .989 0 r
F
.4745 .66073 m .47386 .66552 L .47334 .66821 L F
.47515 .80107 m .47338 .66633 L .47354 .84844 L .824 .369 0 r
F
.47338 .66606 m .47338 .66635 L .47325 .66721 L 1 .989 0 r
F
.47338 .66606 m .47311 .64531 L .47316 .668 L .824 .369 0 r
F
.47338 .66606 m .47325 .66721 L .47314 .66797 L 1 .989 0 r
F
.47338 .66635 m .47316 .668 L .47314 .66797 L F
.47338 .66633 m .47338 .66606 L .47316 .668 L .824 .369 0 r
F
.47185 .67754 m .47207 .67618 L .47179 .67862 L 1 .696 0 r
F
.47207 .67618 m .47334 .66821 L .47211 .67648 L F
.47207 .67618 m .47211 .67648 L .47179 .67862 L F
.47173 .64721 m .47026 .6496 L .4703 .64946 L .841 .608 0 r
F
.47139 .64683 m .47173 .64721 L .4703 .64946 L .872 .467 0 r
F
.47167 .67275 m .47173 .64721 L .47139 .64683 L .896 .44 0 r
F
.47199 .67547 m .47255 .67245 L .47185 .67754 L 1 .696 0 r
F
.47255 .67245 m .47334 .66821 L .47185 .67754 L F
.47328 .82424 m .47279 .76536 L .47273 .77309 L .896 .44 0 r
F
.47354 .84844 m .47332 .82397 L .47328 .82424 L F
.47332 .82397 m .47279 .76536 L .47328 .82424 L F
.47316 .668 m .47334 .66821 L .47199 .67547 L 1 .696 0 r
F
.47338 .66635 m .47334 .66821 L .47316 .668 L 1 .989 0 r
F
.47298 .67816 m .47338 .67838 L .46983 .68741 L .873 .267 0 r
F
.47334 .66821 m .47219 .67814 L .47179 .67862 L 1 .775 0 r
F
.47338 .66633 m .47316 .668 L .47354 .84844 L .824 .369 0 r
F
.47298 .67816 m .46983 .68741 L .46987 .68817 L .873 .267 0 r
F
.47259 .67805 m .47298 .67816 L .46987 .68817 L .874 .207 0 r
F
.47259 .67805 m .46987 .68817 L .46992 .68939 L F
.47219 .67814 m .47259 .67805 L .46992 .68939 L .868 .197 0 r
F
.47219 .67814 m .46992 .68939 L .46996 .69138 L F
.47179 .67862 m .47219 .67814 L .46996 .69138 L .856 .187 0 r
F
.47354 .84844 m .47316 .668 L .472 .67674 L .896 .44 0 r
F
.47146 .68153 m .46996 .69138 L .46999 .69488 L .856 .187 0 r
F
.47179 .67862 m .47158 .68008 L .47146 .68153 L F
.47158 .68008 m .46996 .69138 L .47146 .68153 L F
.47138 .67994 m .47179 .67862 L .46999 .69488 L .835 .176 0 r
F
.47138 .67994 m .46999 .69488 L .47001 .70181 L F
.47037 .6948 m .47139 .64683 L .47035 .64964 L .941 .475 0 r
F
.47061 .69123 m .47138 .67994 L .47046 .69451 L .803 .164 0 r
F
.47064 .69064 m .47076 .68891 L .47061 .69123 L F
.47076 .68891 m .47138 .67994 L .47061 .69123 L F
.4717 .67629 m .47179 .67862 L .47138 .67994 L 1 .696 0 r
F
.47191 .84758 m .47354 .84844 L .4717 .67629 L 1 .465 0 r
F
.4717 .67629 m .47199 .67547 L .47167 .67275 L .896 .44 0 r
F
.47199 .67547 m .47179 .67862 L .4717 .67629 L 1 .696 0 r
F
.47273 .77309 m .47199 .67547 L .4717 .67629 L .896 .44 0 r
F
.47199 .67547 m .47173 .64721 L .47167 .67275 L F
.47199 .67547 m .47311 .64531 L .47173 .64721 L F
.47206 .67501 m .47311 .64531 L .47199 .67547 L F
.47316 .668 m .47311 .64531 L .472 .67674 L F
.47213 .67327 m .47199 .67547 L .4717 .67629 L 1 .696 0 r
F
.47169 .66716 m .47251 .66726 L .4717 .67629 L 1 .615 0 r
F
.47175 .66632 m .47251 .66726 L .47169 .66716 L F
.47146 .676 m .4717 .67629 L .47138 .67994 L F
.47191 .84758 m .4717 .67629 L .47147 .67794 L 1 .465 0 r
F
.47251 .66726 m .47213 .67327 L .4717 .67629 L 1 .696 0 r
F
.47675 .86877 m .46799 .88046 L .46809 .88118 L .649 .211 0 r
F
.476 .86922 m .47675 .86877 L .46809 .88118 L .686 .212 0 r
F
.476 .86922 m .46809 .88118 L .46819 .88192 L F
.47524 .8697 m .476 .86922 L .46819 .88192 L .717 .211 0 r
F
.47524 .8697 m .46819 .88192 L .46828 .8827 L F
.47447 .87025 m .47524 .8697 L .46828 .8827 L .742 .208 0 r
F
.47447 .87025 m .46828 .8827 L .46838 .88357 L F
.47369 .87094 m .47447 .87025 L .46838 .88357 L .761 .204 0 r
F
.47369 .87094 m .46838 .88357 L .46848 .88461 L F
.4729 .87186 m .47369 .87094 L .46848 .88461 L .774 .199 0 r
F
.4729 .87186 m .46848 .88461 L .46858 .88592 L F
.47191 .84758 m .47147 .67757 L .47046 .87901 L 1 .465 0 r
F
.47279 .76536 m .47199 .67547 L .47273 .77309 L .896 .44 0 r
F
.47251 .66726 m .47316 .668 L .47199 .67547 L 1 .696 0 r
F
.47231 .65663 m .47251 .66726 L .47169 .66624 L 1 .928 0 r
F
.47125 .68101 m .47138 .67994 L .47064 .69064 L .803 .164 0 r
F
.47147 .67757 m .47125 .68101 L .47046 .87901 L 1 .465 0 r
F
.47022 .69759 m .47046 .69451 L .47001 .70181 L .803 .164 0 r
F
.47125 .68101 m .47135 .65775 L .47037 .6948 L .941 .475 0 r
F
.47135 .65775 m .47139 .64683 L .47037 .6948 L F
.47053 .69235 m .47046 .69451 L .47035 .69596 L .803 .164 0 r
F
.47095 .68366 m .47035 .69596 L .47022 .69759 L F
.47211 .87317 m .4729 .87186 L .46858 .88592 L .779 .191 0 r
F
.47211 .87317 m .46858 .88592 L .46867 .88768 L F
.47129 .87522 m .47211 .87317 L .46867 .88768 L .775 .182 0 r
F
.47129 .87522 m .46867 .88768 L .46877 .89025 L F
.48081 .91917 m .46721 .92015 L .46731 .92041 L 0 0 0 r
F
.48081 .91917 m .48164 .91896 L .46721 .92015 L F
.47998 .91926 m .46731 .92041 L .46742 .92054 L F
.47998 .91926 m .48081 .91917 L .47243 .91994 L F
.47272 .91992 m .47243 .91994 L .46731 .92041 L F
.47998 .91926 m .47243 .91994 L .47272 .91992 L F
.47914 .91921 m .47998 .91926 L .46742 .92054 L .108 .159 0 r
F
.47379 .91983 m .46742 .92054 L .46753 .92056 L F
.47914 .91921 m .47346 .91986 L .47379 .91983 L F
.47346 .91986 m .46742 .92054 L .47379 .91983 L F
.47829 .91904 m .46753 .92056 L .46765 .92045 L .155 .167 0 r
F
.47829 .91904 m .47914 .91921 L .46753 .92056 L F
.47743 .91874 m .46765 .92045 L .46776 .92022 L .202 .175 0 r
F
.47743 .91874 m .47829 .91904 L .46765 .92045 L F
.47657 .91832 m .46776 .92022 L .46788 .91987 L .252 .183 0 r
F
.47657 .91832 m .47743 .91874 L .46776 .92022 L F
.4757 .91778 m .47657 .91832 L .46788 .91987 L .303 .191 0 r
F
.4757 .91778 m .46788 .91987 L .46799 .91941 L F
.47483 .91713 m .4757 .91778 L .46799 .91941 L .356 .199 0 r
F
.47483 .91713 m .46799 .91941 L .46811 .91886 L F
.47395 .91637 m .47483 .91713 L .46811 .91886 L .414 .224 0 r
F
.47395 .91637 m .46811 .91886 L .46823 .91821 L F
.47307 .91551 m .47395 .91637 L .46823 .91821 L .478 .313 0 r
F
.47307 .91551 m .46823 .91821 L .46835 .91751 L F
.47217 .9146 m .47307 .91551 L .46835 .91751 L .552 .4 0 r
F
.47217 .9146 m .46835 .91751 L .46848 .91678 L F
.47128 .91369 m .4718 .91422 L .46848 .91678 L .639 .461 0 r
F
.4718 .91422 m .47217 .9146 L .4717 .91488 L F
.4718 .91422 m .4717 .91488 L .46848 .91678 L F
.47969 .85127 m .47524 .8697 L .47447 .87025 L 1 .71 0 r
F
.47992 .85045 m .4797 .85136 L .47969 .85127 L F
.4797 .85136 m .47524 .8697 L .47969 .85127 L F
.49063 .85136 m .48041 .86597 L .47969 .86667 L .803 .472 0 r
F
.48914 .8515 m .47969 .86667 L .47897 .86729 L .875 .563 0 r
F
.48914 .8515 m .49063 .85136 L .47969 .86667 L F
.48763 .85152 m .48914 .8515 L .47897 .86729 L .946 .634 0 r
F
.48763 .85152 m .47897 .86729 L .47824 .86783 L F
.48611 .85145 m .48763 .85152 L .47824 .86783 L 1 .683 0 r
F
.48611 .85145 m .47824 .86783 L .4775 .86832 L F
.48458 .85128 m .48611 .85145 L .4775 .86832 L 1 .713 0 r
F
.48458 .85128 m .4775 .86832 L .47675 .86877 L F
.47213 .68425 m .4723 .65928 L .47212 .68448 L .535 .09 0 r
F
.47128 .91369 m .46848 .91678 L .4686 .91612 L .639 .461 0 r
F
.46998 .91365 m .47128 .91369 L .4686 .91612 L .731 .419 0 r
F
.47052 .91306 m .47052 .91271 L .46998 .91365 L .37 .051 0 r
F
.47052 .91271 m .47129 .87522 L .46998 .91365 L F
.46998 .91365 m .47129 .87522 L .46877 .89025 L F
.46998 .91365 m .4686 .91612 L .46867 .9159 L .731 .419 0 r
F
.47036 .92092 m .46998 .91365 L .46868 .92206 L .37 .051 0 r
F
.46819 .88192 m .46809 .88118 L .459 .89001 L 0 0 0 r
F
.46819 .88192 m .459 .89001 L .45999 .89085 L F
.46912 .7296 m .46815 .74108 L .46829 .77126 L F
.46763 .79005 m .46815 .74108 L .46681 .76978 L .14 .012 0 r
F
.46776 .7975 m .46803 .77868 L .46784 .78418 L 1 .569 0 r
F
.46828 .8827 m .46819 .88192 L .46524 .88513 L 0 0 0 r
F
.4652 .88573 m .46524 .88513 L .45999 .89085 L F
.46828 .8827 m .46524 .88513 L .4652 .88573 L F
.46513 .91833 m .46516 .91853 L .46361 .91903 L .389 .204 0 r
F
.46479 .76277 m .464 .74238 L .45975 .78282 L .31 .042 0 r
F
.46517 .88655 m .45999 .89085 L .46098 .89173 L 0 0 0 r
F
.46828 .8827 m .4652 .88573 L .46517 .88655 L F
.4652 .88573 m .45999 .89085 L .46517 .88655 L F
.46637 .70212 m .46138 .71626 L .46228 .72186 L F
.46685 .70584 m .46637 .70212 L .46228 .72186 L F
.46685 .70584 m .46228 .72186 L .46316 .72996 L F
.46732 .71163 m .46685 .70584 L .46316 .72996 L .007 0 0 r
F
.46663 .71314 m .46559 .67563 L .464 .69239 L .782 .297 0 r
F
.46732 .71163 m .46316 .72996 L .464 .74238 L .007 0 0 r
F
.46777 .72152 m .46732 .71163 L .464 .74238 L .037 0 0 r
F
.46777 .72152 m .464 .74238 L .46479 .76277 L F
.46815 .74108 m .46777 .72152 L .46582 .74845 L .081 0 0 r
F
.46628 .75314 m .46582 .74845 L .46479 .76277 L F
.46815 .74108 m .46582 .74845 L .46628 .75314 L F
.46829 .77126 m .46815 .74108 L .46777 .77666 L .14 .012 0 r
F
.46784 .78418 m .46777 .77666 L .46763 .79005 L F
.46829 .77126 m .46777 .77666 L .46784 .78418 L F
.46838 .88357 m .46828 .8827 L .46517 .88655 L 0 0 0 r
F
.46513 .88716 m .46517 .88655 L .46098 .89173 L F
.46838 .88357 m .46517 .88655 L .46513 .88716 L F
.46199 .8927 m .46098 .89173 L .4536 .8981 L F
.46199 .8927 m .4536 .8981 L .45553 .89907 L F
.46301 .89381 m .46199 .8927 L .45553 .89907 L F
.46301 .89381 m .45553 .89907 L .45749 .90016 L F
.46404 .89516 m .46301 .89381 L .45749 .90016 L F
.46404 .89516 m .45749 .90016 L .45947 .90146 L F
.46508 .89692 m .46404 .89516 L .45947 .90146 L F
.46456 .87796 m .46254 .84376 L .45973 .87059 L .507 .069 0 r
F
.46147 .9031 m .45947 .90146 L .45499 .90587 L .181 0 0 r
F
.46508 .89692 m .45947 .90146 L .46147 .9031 L 0 0 0 r
F
.46147 .9031 m .45499 .90587 L .45794 .90739 L .181 0 0 r
F
.46838 .88357 m .46098 .89173 L .46199 .8927 L 0 0 0 r
F
.46848 .88461 m .46838 .88357 L .46199 .8927 L F
.46848 .88461 m .46199 .8927 L .46301 .89381 L F
.4629 .89291 m .45973 .87059 L .4572 .88567 L .666 .147 0 r
F
.46456 .87796 m .45973 .87059 L .4629 .89291 L .507 .069 0 r
F
.4635 .90535 m .46147 .9031 L .45794 .90739 L .21 0 0 r
F
.4635 .90535 m .45794 .90739 L .46093 .90943 L F
.4614 .90137 m .4572 .88567 L .45496 .89474 L .791 .223 0 r
F
.4629 .89291 m .4572 .88567 L .4614 .90137 L .666 .147 0 r
F
.4614 .90137 m .45496 .89474 L .46007 .90663 L .791 .223 0 r
F
.46007 .90663 m .45906 .9043 L .46025 .86054 L .486 .071 0 r
F
.45906 .9043 m .45496 .89474 L .46025 .86054 L F
.46479 .76277 m .45975 .78282 L .46102 .81014 L .31 .042 0 r
F
.46025 .86054 m .45496 .89474 L .46046 .74571 L .486 .071 0 r
F
.46025 .86054 m .46046 .74571 L .46065 .76107 L F
.46552 .79728 m .46479 .76277 L .46102 .81014 L .332 .048 0 r
F
.46168 .80713 m .4619 .72048 L .46075 .73785 L .937 .462 0 r
F
.46552 .79728 m .46102 .81014 L .46254 .84376 L .332 .048 0 r
F
.46203 .83315 m .46199 .79682 L .46168 .80713 L .937 .462 0 r
F
.46199 .79682 m .4619 .72048 L .46168 .80713 L F
.46203 .83315 m .4617 .80814 L .46139 .81829 L F
.4617 .80814 m .46075 .73785 L .46139 .81829 L F
.46119 .83142 m .46075 .73785 L .46139 .81829 L .486 .071 0 r
F
.46007 .90663 m .4603 .85014 L .46082 .85609 L F
.46082 .85609 m .46043 .81768 L .46119 .83142 L F
.4603 .85014 m .46043 .81768 L .46082 .85609 L F
.46043 .81768 m .46075 .73785 L .46119 .83142 L F
.46093 .90943 m .45794 .90739 L .45456 .91043 L .331 0 0 r
F
.46093 .90943 m .45456 .91043 L .45847 .9123 L F
.46007 .90663 m .46098 .84565 L .45891 .91013 L .486 .071 0 r
F
.46098 .84565 m .46139 .81829 L .46048 .85183 L F
.46098 .84565 m .46048 .85183 L .45891 .91013 L F
.46118 .79209 m .46075 .73785 L .46137 .78222 L F
.46065 .76107 m .46046 .74571 L .46075 .73785 L F
.45496 .89474 m .45989 .71196 L .46075 .73785 L 1 .85 0 r
F
.46139 .81829 m .46075 .73785 L .45902 .7639 L .937 .462 0 r
F
.46139 .81829 m .46 .85339 L .45946 .88125 L .486 .071 0 r
F
.46139 .81829 m .45946 .88125 L .45891 .91013 L F
.46166 .83992 m .46113 .8247 L .46015 .86747 L .937 .462 0 r
F
.46112 .82422 m .45902 .7639 L .46 .85339 L F
.46139 .81829 m .46136 .81777 L .46166 .83992 L F
.46136 .81777 m .45902 .7639 L .46112 .82422 L F
.46136 .81777 m .46112 .82422 L .46166 .83992 L F
.45946 .88125 m .45989 .85921 L .45928 .88735 L 1 .846 0 r
F
.45989 .85921 m .45987 .85941 L .45928 .88735 L F
.46 .85339 m .45902 .7639 L .4597 .86166 L .974 .494 0 r
F
.46 .85339 m .45988 .85636 L .45988 .85677 L 1 .846 0 r
F
.46 .85339 m .45988 .85677 L .45928 .88735 L F
.4597 .86166 m .45902 .7639 L .45579 .81145 L .974 .494 0 r
F
.45989 .85921 m .46 .85339 L .45987 .85941 L 1 .846 0 r
F
.45928 .88735 m .45988 .85636 L .45971 .8608 L F
.46848 .91678 m .46835 .91751 L .46648 .91811 L .389 .204 0 r
F
.46666 .91774 m .46648 .91811 L .46516 .91853 L F
.46848 .91678 m .46648 .91811 L .46666 .91774 L F
.46848 .91678 m .46516 .91853 L .46513 .91833 L F
.46848 .91678 m .46466 .91855 L .46475 .91845 L F
.46466 .91855 m .46361 .91903 L .46475 .91845 L F
.46475 .91845 m .46361 .91903 L .45893 .92017 L .249 .182 0 r
F
.46475 .91845 m .45893 .92017 L .46108 .91972 L F
.46484 .91836 m .46475 .91845 L .46108 .91972 L .252 .18 0 r
F
.46806 .91645 m .46848 .91678 L .46475 .91845 L .435 .208 0 r
F
.4686 .91612 m .46851 .91661 L .46806 .91645 L F
.46851 .91661 m .46848 .91678 L .46806 .91645 L F
.46599 .9179 m .4659 .91797 L .46601 .91796 L .459 .203 0 r
F
.46599 .9179 m .46601 .91796 L .46682 .91789 L F
.46803 .91631 m .46877 .89025 L .46614 .89939 L .57 .07 0 r
F
.46835 .91751 m .46823 .91821 L .46248 .91962 L .342 .197 0 r
F
.46835 .91751 m .46248 .91962 L .46361 .91903 L F
.4686 .91612 m .46475 .91845 L .4659 .91797 L .435 .208 0 r
F
.46803 .91631 m .4686 .91612 L .4659 .91797 L .459 .203 0 r
F
.4687 .91584 m .4687 .91554 L .46803 .91631 L .57 .07 0 r
F
.46872 .91577 m .4687 .91584 L .46803 .91631 L .459 .203 0 r
F
.4687 .91584 m .4686 .91612 L .46803 .91631 L F
.46868 .92206 m .4687 .91584 L .46803 .91631 L .57 .07 0 r
F
.4687 .91554 m .46877 .89025 L .46803 .91631 L F
.46803 .91631 m .46599 .9179 L .46666 .91789 L .459 .203 0 r
F
.46803 .91631 m .46666 .91789 L .46682 .91789 L F
.46776 .92022 m .46765 .92045 L .45697 .92138 L .124 .162 0 r
F
.46776 .92022 m .45697 .92138 L .45805 .92123 L F
.46788 .91987 m .46776 .92022 L .45805 .92123 L .166 .169 0 r
F
.46788 .91987 m .45805 .92123 L .45914 .92097 L F
.46799 .91941 m .46788 .91987 L .45914 .92097 L .209 .176 0 r
F
.46799 .91941 m .45914 .92097 L .46025 .92061 L F
.46811 .91886 m .46799 .91941 L .46025 .92061 L .253 .184 0 r
F
.46811 .91886 m .46025 .92061 L .46136 .92015 L F
.46823 .91821 m .46811 .91886 L .46136 .92015 L .297 .19 0 r
F
.46823 .91821 m .46136 .92015 L .46248 .91962 L F
.46868 .92206 m .46813 .9172 L .467 .92296 L .57 .07 0 r
F
.46813 .9172 m .46614 .89939 L .46682 .91789 L F
.46813 .9172 m .46682 .91789 L .467 .92296 L F
.46622 .91818 m .4659 .91797 L .46607 .91826 L 0 0 0 r
F
.467 .92296 m .46682 .91789 L .46615 .91869 L .719 .15 0 r
F
.46819 .9221 m .46868 .92206 L .467 .92296 L .412 .202 0 r
F
.46822 .92208 m .46872 .91577 L .46705 .91787 L .372 .02 0 r
F
.46822 .92208 m .46877 .92179 L .46819 .9221 L .412 .202 0 r
F
.46877 .92177 m .46877 .92179 L .46822 .92208 L F
.46877 .92179 m .46868 .92206 L .46819 .9221 L F
.46879 .92415 m .46877 .92177 L .46822 .92208 L .372 .02 0 r
F
.46998 .91365 m .46867 .9159 L .4687 .91584 L .731 .419 0 r
F
.46998 .91365 m .4687 .91584 L .46868 .92206 L .37 .051 0 r
F
.46877 .92177 m .46876 .92094 L .46822 .92208 L .372 .02 0 r
F
.4688 .92166 m .46877 .92177 L .46822 .92208 L .412 .202 0 r
F
.47052 .91306 m .47128 .91369 L .46998 .91365 L .731 .419 0 r
F
.47834 .85009 m .47992 .85045 L .47447 .87025 L 1 .689 0 r
F
.47834 .85009 m .47447 .87025 L .47369 .87094 L F
.47675 .84967 m .47834 .85009 L .47369 .87094 L 1 .665 0 r
F
.47675 .84967 m .47369 .87094 L .4729 .87186 L F
.47515 .84913 m .47675 .84967 L .4729 .87186 L 1 .637 0 r
F
.47515 .84913 m .4729 .87186 L .47211 .87317 L F
.47357 .91122 m .47515 .84913 L .47211 .87317 L .382 .057 0 r
F
.47412 .91043 m .47515 .84913 L .47357 .91122 L F
.47284 .90184 m .47211 .87317 L .47129 .87522 L F
.47181 .9075 m .47129 .87522 L .47056 .91107 L 1 .403 0 r
F
.47181 .9075 m .47056 .91107 L .47052 .91306 L F
.47185 .90992 m .47128 .91369 L .47052 .91306 L 1 1 0 r
F
.47144 .91088 m .47052 .91306 L .47036 .92092 L 1 .403 0 r
F
.47181 .9075 m .47052 .91306 L .47144 .91088 L F
.47338 .91109 m .47357 .91122 L .47128 .91369 L .943 .955 0 r
F
.47357 .91122 m .47217 .9146 L .47163 .91405 L F
.47357 .91122 m .47163 .91405 L .47128 .91369 L F
.47338 .91109 m .47304 .90093 L .47284 .90184 L .382 .057 0 r
F
.47357 .91122 m .47211 .87317 L .47338 .91109 L F
.47766 .91296 m .47395 .91637 L .47307 .91551 L .616 .673 0 r
F
.47578 .91178 m .47307 .91551 L .47217 .9146 L .76 .825 0 r
F
.47578 .91178 m .47766 .91296 L .47307 .91551 L F
.47357 .91122 m .47578 .91178 L .47217 .9146 L .943 .955 0 r
F
.47412 .91063 m .47412 .91043 L .47357 .91122 L .382 .057 0 r
F
.47389 .91047 m .47412 .91063 L .47357 .91122 L .943 .955 0 r
F
.47412 .91063 m .47578 .91178 L .47357 .91122 L F
.47953 .91399 m .47483 .91713 L .47395 .91637 L .539 .525 0 r
F
.47766 .91296 m .47953 .91399 L .47395 .91637 L .616 .673 0 r
F
.47395 .92087 m .47412 .91063 L .47357 .91122 L .382 .057 0 r
F
.472 .91947 m .47395 .92087 L .47338 .91109 L 1 .403 0 r
F
.47185 .90992 m .47228 .91026 L .47128 .91369 L 1 1 0 r
F
.47185 .90992 m .47338 .91109 L .47325 .90884 L 1 .403 0 r
F
.47234 .91006 m .47199 .91281 L .47128 .91369 L 1 1 0 r
F
.47185 .90992 m .4715 .91034 L .47036 .92092 L 1 .403 0 r
F
.4715 .91019 m .47185 .90992 L .47038 .91294 L 1 1 0 r
F
.47185 .90992 m .47325 .90884 L .47129 .87522 L 1 .403 0 r
F
.47185 .90992 m .47181 .9075 L .4715 .91034 L F
.47198 .909 m .47185 .90992 L .4715 .91019 L 1 1 0 r
F
.47917 .85779 m .476 .86922 L .47524 .8697 L 1 .723 0 r
F
.48148 .85077 m .47906 .85894 L .47917 .85779 L F
.47906 .85894 m .476 .86922 L .47917 .85779 L F
.49211 .85109 m .48112 .86517 L .48041 .86597 L .759 .362 0 r
F
.49063 .85136 m .49211 .85109 L .48041 .86597 L .803 .472 0 r
F
.48304 .85105 m .48458 .85128 L .47675 .86877 L 1 .725 0 r
F
.48304 .85105 m .47675 .86877 L .476 .86922 L F
.49211 .85109 m .49358 .8507 L .48112 .86517 L .759 .362 0 r
F
.47974 .65009 m .47974 .65009 L .47973 .65006 L 1 .278 0 r
F
.47975 .65012 m .47973 .65005 L .47972 .65005 L .936 .603 0 r
F
.48559 .64947 m .47973 .65006 L .47966 .65011 L .028 0 0 r
F
.48559 .64947 m .47966 .65011 L .47942 .65032 L F
.48821 .64221 m .47917 .64245 L .47889 .64289 L .226 0 0 r
F
.48821 .64221 m .48882 .64176 L .47917 .64245 L F
.48761 .64262 m .47889 .64289 L .4786 .64329 L .195 0 0 r
F
.48761 .64262 m .48821 .64221 L .47889 .64289 L F
.48699 .64298 m .4786 .64329 L .47831 .64364 L .163 0 0 r
F
.48699 .64298 m .48761 .64262 L .4786 .64329 L F
.48637 .64329 m .47831 .64364 L .47801 .64394 L .129 0 0 r
F
.48637 .64329 m .48699 .64298 L .47831 .64364 L F
.48627 .67617 m .47835 .68026 L .47798 .68039 L .475 .214 0 r
F
.48627 .67617 m .48705 .67615 L .47835 .68026 L F
.48361 .64994 m .47702 .65094 L .4767 .65105 L 0 0 0 r
F
.48361 .64994 m .48428 .64984 L .47702 .65094 L F
.48549 .67612 m .47798 .68039 L .47761 .68047 L .53 .252 0 r
F
.48549 .67612 m .48627 .67617 L .47798 .68039 L F
.48294 .64999 m .48361 .64994 L .4767 .65105 L .15 .166 0 r
F
.48294 .64999 m .4767 .65105 L .47638 .65111 L F
.4847 .67601 m .47761 .68047 L .47723 .68049 L .583 .373 0 r
F
.4847 .67601 m .48549 .67612 L .47761 .68047 L F
.48226 .64999 m .47638 .65111 L .47606 .65112 L .197 .174 0 r
F
.48226 .64999 m .48294 .64999 L .47638 .65111 L F
.48391 .67583 m .47723 .68049 L .47686 .68045 L .633 .494 0 r
F
.48391 .67583 m .4847 .67601 L .47723 .68049 L F
.48158 .64994 m .47606 .65112 L .47574 .65108 L .243 .182 0 r
F
.48158 .64994 m .48226 .64999 L .47606 .65112 L F
.48311 .67559 m .47686 .68045 L .47648 .68037 L .68 .609 0 r
F
.48311 .67559 m .48391 .67583 L .47686 .68045 L F
.4796 .65012 m .47973 .65006 L .47772 .64419 L 1 .278 0 r
F
.47966 .65011 m .47973 .65006 L .4796 .65012 L .028 0 0 r
F
.48089 .64983 m .47574 .65108 L .47542 .65099 L .29 .189 0 r
F
.4785 .65061 m .47781 .65057 L .47733 .65077 L 0 0 0 r
F
.47781 .65057 m .47758 .6506 L .47733 .65077 L F
.48089 .64983 m .48158 .64994 L .47574 .65108 L .29 .189 0 r
F
.48231 .67528 m .48311 .67559 L .47648 .68037 L .753 .713 0 r
F
.47972 .65005 m .47801 .64394 L .47772 .64419 L .936 .603 0 r
F
.47973 .65005 m .47801 .64394 L .47972 .65005 L F
.4802 .64967 m .47542 .65099 L .47509 .65084 L .337 .196 0 r
F
.4802 .64967 m .48089 .64983 L .47542 .65099 L F
.47951 .64946 m .4802 .64967 L .47509 .65084 L .384 .209 0 r
F
.48406 .64817 m .4802 .64967 L .47951 .64946 L .44 .355 0 r
F
.48301 .64791 m .47951 .64946 L .47881 .6492 L .482 .464 0 r
F
.48301 .64791 m .48406 .64817 L .47951 .64946 L F
.48195 .64758 m .47881 .6492 L .47811 .64888 L .523 .572 0 r
F
.48195 .64758 m .48301 .64791 L .47881 .6492 L F
.48448 .66921 m .4807 .67448 L .47989 .67398 L 1 1 0 r
F
.48089 .64721 m .47811 .64888 L .4774 .64852 L .565 .678 0 r
F
.48089 .64721 m .48195 .64758 L .47811 .64888 L F
.48326 .66851 m .47989 .67398 L .47908 .67343 L 1 1 0 r
F
.48326 .66851 m .48448 .66921 L .47989 .67398 L F
.47982 .64678 m .4774 .64852 L .47669 .6481 L .626 .781 0 r
F
.47982 .64678 m .48089 .64721 L .4774 .64852 L F
.48275 .64544 m .48089 .64721 L .47982 .64678 L .681 .873 0 r
F
.48205 .66774 m .47908 .67343 L .47826 .67282 L 1 1 0 r
F
.48205 .66774 m .48326 .66851 L .47908 .67343 L F
.47874 .64629 m .47982 .64678 L .47669 .6481 L .713 .881 0 r
F
.48134 .64496 m .47982 .64678 L .47874 .64629 L .759 .958 0 r
F
.48134 .64496 m .48275 .64544 L .47982 .64678 L F
.48083 .6669 m .47826 .67282 L .47745 .67216 L 1 1 0 r
F
.48083 .6669 m .48205 .66774 L .47826 .67282 L F
.47992 .64442 m .47874 .64629 L .47767 .64575 L .843 1 0 r
F
.47992 .64442 m .48134 .64496 L .47874 .64629 L F
.47961 .66598 m .48083 .6669 L .47745 .67216 L 1 1 0 r
F
.48233 .66149 m .48083 .6669 L .47961 .66598 L F
.4785 .64379 m .47992 .64442 L .47767 .64575 L .933 1 0 r
F
.48026 .64252 m .47992 .64442 L .4785 .64379 L .928 1 0 r
F
.48075 .66038 m .47961 .66598 L .47839 .66497 L 1 1 0 r
F
.48075 .66038 m .48233 .66149 L .47961 .66598 L F
.47889 .64289 m .46937 .64275 L .46941 .6432 L .282 0 0 r
F
.47889 .64289 m .47917 .64245 L .46937 .64275 L F
.4786 .64329 m .46941 .6432 L .46944 .6436 L .252 0 0 r
F
.4786 .64329 m .47889 .64289 L .46941 .6432 L F
.47831 .64364 m .4786 .64329 L .46944 .6436 L .22 0 0 r
F
.47851 .64181 m .48026 .64252 L .4785 .64379 L 1 1 0 r
F
.47981 .64062 m .48026 .64252 L .47851 .64181 L .975 1 0 r
F
.47916 .65913 m .48075 .66038 L .47839 .66497 L 1 1 0 r
F
.48095 .65532 m .48075 .66038 L .47916 .65913 L F
.47906 .65471 m .47979 .65495 L .47916 .65913 L F
.47979 .65495 m .48095 .65532 L .47922 .65899 L F
.47979 .65495 m .47922 .65899 L .47916 .65913 L F
.4792 .65397 m .48095 .65532 L .47906 .65471 L F
.48615 .64855 m .48158 .64994 L .48089 .64983 L .355 .198 0 r
F
.48511 .64839 m .48089 .64983 L .4802 .64967 L .398 .251 0 r
F
.48511 .64839 m .48615 .64855 L .48089 .64983 L F
.48406 .64817 m .48511 .64839 L .4802 .64967 L .44 .355 0 r
F
.48416 .64587 m .48195 .64758 L .48089 .64721 L .607 .784 0 r
F
.48275 .64544 m .48416 .64587 L .48089 .64721 L .681 .873 0 r
F
.48392 .6625 m .48205 .66774 L .48083 .6669 L 1 1 0 r
F
.48233 .66149 m .48392 .6625 L .48083 .6669 L F
.48287 .65659 m .48233 .66149 L .48075 .66038 L F
.48095 .65532 m .48287 .65659 L .48075 .66038 L F
.48034 .65074 m .48095 .65532 L .47904 .65385 L F
.48078 .65401 m .48254 .65216 L .48095 .65532 L F
.48034 .65074 m .48106 .6512 L .48078 .65401 L F
.48106 .6512 m .48254 .65216 L .48078 .65401 L F
.48373 .64364 m .48275 .64544 L .48134 .64496 L .782 .995 0 r
F
.48254 .65216 m .48287 .65659 L .48095 .65532 L 1 1 0 r
F
.48719 .64865 m .48226 .64999 L .48158 .64994 L .311 .192 0 r
F
.48615 .64855 m .48717 L F
.4644 .65265 m .46328 .64522 L .46472 .65265 L F
.46472 .65264 m .46328 .64522 L .46367 .64521 L F
.46472 .65264 m .46328 .64522 L .46472 .65264 L F
.45907 .64937 m .44825 .64882 L .44893 .64947 L .401 0 0 r
F
.45943 .64993 m .45907 .64937 L .44893 .64947 L .375 0 0 r
F
.45943 .64993 m .44893 .64947 L .44962 .65007 L F
.4598 .65044 m .45943 .64993 L .44962 .65007 L .346 0 0 r
F
.4598 .65044 m .44962 .65007 L .45032 .65062 L F
.46017 .65091 m .4598 .65044 L .45032 .65062 L .316 0 0 r
F
.46017 .65091 m .45032 .65062 L .45102 .65113 L F
.46055 .65132 m .46017 .65091 L .45102 .65113 L .285 0 0 r
F
.46055 .65132 m .45102 .65113 L .45174 .65159 L F
.46093 .65169 m .46055 .65132 L .45174 .65159 L .252 0 0 r
F
.46093 .65169 m .45174 .65159 L .45246 .652 L F
.46132 .65201 m .46093 .65169 L .45246 .652 L .217 0 0 r
F
.46132 .65201 m .45246 .652 L .45319 .65237 L F
.46171 .65228 m .46132 .65201 L .45319 .65237 L .181 0 0 r
F
.46171 .65228 m .45319 .65237 L .45392 .6527 L F
.4621 .6525 m .46171 .65228 L .45392 .6527 L .144 0 0 r
F
.4621 .6525 m .45392 .6527 L .45466 .65298 L F
.4625 .65268 m .4621 .6525 L .45466 .65298 L .106 0 0 r
F
.4625 .65268 m .45466 .65298 L .45541 .65321 L F
.4629 .65281 m .4625 .65268 L .45541 .65321 L .068 0 0 r
F
.4629 .65281 m .45541 .65321 L .45617 .65341 L F
.46331 .65289 m .4629 .65281 L .45617 .65341 L .029 0 0 r
F
.46367 .64521 m .45691 .64509 L .45764 .64513 L 0 .138 0 r
F
.46331 .65289 m .45617 .65341 L .45693 .65356 L .029 0 0 r
F
.46328 .64522 m .46289 .64517 L .45618 .64501 L .044 0 0 r
F
.46406 .64516 m .46367 .64521 L .45764 .64513 L .035 .145 0 r
F
.46372 .65293 m .46331 .65289 L .45693 .65356 L 0 0 0 r
F
.46406 .64516 m .45764 .64513 L .45838 .64512 L .035 .145 0 r
F
.45893 .65352 m .45693 .65356 L .4577 .65367 L 0 0 0 r
F
.46372 .65293 m .4583 .65343 L .45893 .65352 L F
.4583 .65343 m .45693 .65356 L .45893 .65352 L F
.4591 .65351 m .46372 .65293 L .45893 .65352 L F
.4591 .65351 m .45893 .65352 L .4577 .65367 L F
.4591 .65351 m .46406 .64516 L .45838 .64512 L 1 .715 0 r
F
.45924 .65349 m .46406 .64516 L .4591 .65351 L F
.46245 .69247 m .4638 .65293 L .45912 .6537 L F
.4638 .65293 m .46372 .65293 L .4591 .65351 L 0 0 0 r
F
.46506 .65274 m .46506 .65274 L .46507 .65274 L F
.46475 .65271 m .46473 .65271 L .46443 .65275 L .092 .155 0 r
F
.46443 .65275 m .46443 .65275 L .46331 .65289 L F
.46473 .65271 m .46331 .65289 L .46507 .65274 L F
.4643 .65266 m .4629 .65281 L .46464 .65272 L 0 0 0 r
F
.4644 .65264 m .46407 .65254 L .4629 .65281 L F
.46407 .65254 m .4625 .65268 L .46259 .65271 L F
.46407 .65254 m .46259 .65271 L .4629 .65281 L F
.4638 .65293 m .4638 .65283 L .45912 .6537 L 1 .715 0 r
F
.4638 .65283 m .46406 .64516 L .45924 .65349 L F
.4638 .65283 m .45924 .65349 L .45912 .6537 L F
.46507 .65281 m .46506 .65274 L .46507 .65274 L 0 0 0 r
F
.46509 .65273 m .46507 .65274 L .46476 .65279 L .137 .164 0 r
F
.46475 .65284 m .46475 .65284 L .46473 .65271 L 0 0 0 r
F
.46507 .65273 m .4638 .65293 L .46251 .69048 L F
.46413 .65293 m .45945 .65347 L .45972 .65357 L F
.45945 .65347 m .4591 .65351 L .45972 .65357 L F
.46947 .68588 m .4694 .68533 L .46245 .69247 L F
.4694 .68533 m .46251 .69048 L .46245 .69247 L F
.46952 .686 m .46245 .69247 L .46293 .69305 L F
.46245 .69247 m .46245 .69247 L .46293 .69305 L F
.46957 .68612 m .46952 .686 L .46293 .69305 L F
.46957 .68612 m .46294 .69305 L .46342 .6937 L F
.46294 .69305 m .46293 .69305 L .46342 .6937 L F
.46871 .68734 m .46957 .68612 L .46342 .6937 L F
.46962 .68624 m .46961 .68622 L .46871 .68734 L F
.46961 .68622 m .46957 .68612 L .46871 .68734 L F
.46962 .68624 m .46871 .68734 L .46391 .69443 L F
.46871 .68734 m .46342 .6937 L .46391 .69443 L F
.46388 .69433 m .46356 .69389 L .46371 .69361 L F
.46356 .69389 m .46342 .6937 L .46371 .69361 L F
.46371 .69361 m .46342 .6937 L .46332 .692 L F
.46391 .69443 m .46342 .6937 L .46388 .69433 L F
.46391 .69443 m .46332 .692 L .46373 .69178 L F
.46391 .69443 m .46384 .69337 L .46067 .69921 L F
.46391 .69443 m .46067 .69921 L .45772 .70464 L F
.46339 .69362 m .46293 .69305 L .46288 .69224 L F
.46342 .6937 m .46293 .69305 L .46339 .69362 L F
.46952 .686 m .46947 .68588 L .46247 .69245 L F
.46952 .686 m .46247 .69245 L .46247 .69245 L F
.46952 .686 m .46245 .69247 L .46245 .69247 L F
.46413 .65293 m .4638 .65293 L .46012 .65338 L F
.46018 .65338 m .46012 .65338 L .4591 .65351 L F
.46413 .65293 m .46012 .65338 L .46018 .65338 L F
.46247 .69245 m .46247 .69245 L .46245 .69247 L F
.46245 .69247 m .46245 .69247 L .46245 .69247 L F
.46293 .69305 m .46245 .69247 L .45973 .65371 L F
.45974 .65371 m .45973 .65371 L .45972 .65357 L F
.46293 .69305 m .45973 .65371 L .45974 .65371 L F
.46454 .65289 m .46016 .65351 L .46043 .65359 L F
.46251 .64508 m .45474 .64471 L .45545 .64488 L .121 0 0 r
F
.46289 .64517 m .46251 .64508 L .45545 .64488 L .083 0 0 r
F
.46289 .64517 m .45545 .64488 L .45618 .64501 L F
.46454 .65289 m .46413 .65293 L .45972 .65357 L 0 0 0 r
F
.45912 .6537 m .45924 .65349 L .4591 .65351 L 1 .715 0 r
F
.46245 .69247 m .45911 .65354 L .45973 .65363 L F
.4598 .65356 m .45972 .65357 L .45848 .65374 L 0 0 0 r
F
.46454 .65289 m .45972 .65357 L .4598 .65356 L F
.4598 .65356 m .45972 .65357 L .45913 .64507 L F
.4598 .65359 m .45972 .65357 L .4598 .65356 L F
.46051 .65357 m .46043 .65359 L .45988 .64497 L F
.46051 .65361 m .46043 .65359 L .46051 .65357 L F
.46496 .65281 m .46454 .65289 L .46043 .65359 L .125 .161 0 r
F
.4598 .6536 m .45972 .65357 L .4598 .65359 L 0 0 0 r
F
.46293 .69305 m .45973 .65358 L .4598 .6536 L F
.45973 .65358 m .45972 .65357 L .4598 .6536 L F
.4633 .69201 m .46288 .69224 L .46044 .65375 L F
.46044 .65375 m .46044 .65375 L .46043 .65359 L F
.4633 .69201 m .46044 .65375 L .46044 .65375 L F
.4651 .65278 m .464 .6529 L .46413 .65293 L .137 .164 0 r
F
.4651 .65276 m .4651 .65278 L .46413 .65293 L .182 .172 0 r
F
.46115 .65375 m .46114 .65375 L .46113 .65358 L 0 0 0 r
F
.46373 .69178 m .46113 .65358 L .46114 .65358 L F
.46016 .65351 m .4598 .65356 L .46043 .65359 L F
.45981 .6537 m .4598 .65356 L .46043 .65359 L F
.45973 .65363 m .45972 .65356 L .45972 .65357 L 1 .715 0 r
F
.4598 .65356 m .45848 .65374 L .46043 .65359 L 0 0 0 r
F
.4598 .65356 m .4598 .65354 L .46043 .65359 L F
.46043 .65359 m .4598 .65354 L .46042 .65355 L F
.46293 .69305 m .45981 .6537 L .46043 .65359 L F
.46043 .65359 m .45848 .65374 L .46009 .65364 L F
.46213 .64495 m .46175 .64476 L .45402 .64449 L .159 0 0 r
F
.46213 .64495 m .45402 .64449 L .45474 .64471 L F
.46251 .64508 m .46213 .64495 L .45474 .64471 L .121 0 0 r
F
.46113 .65346 m .45988 .64497 L .46064 .64483 L 0 0 0 r
F
.46061 .65355 m .46047 .65358 L .46051 .65357 L .125 .161 0 r
F
.46496 .65281 m .46049 .65358 L .46061 .65355 L F
.46496 .65281 m .46043 .65359 L .46045 .65358 L F
.46342 .6937 m .46051 .65357 L .46113 .65358 L 0 0 0 r
F
.4633 .69201 m .46043 .65359 L .46051 .65361 L F
.46113 .65358 m .45926 .65379 L .46005 .6538 L .125 .161 0 r
F
.46496 .65281 m .46061 .65355 L .46123 .65356 L F
.46122 .6536 m .46112 .6534 L .4612 .6534 L 0 0 0 r
F
.46373 .69178 m .46114 .65358 L .46122 .6536 L F
.46123 .65356 m .46111 .65357 L .46113 .65358 L .125 .161 0 r
F
.46114 .65358 m .46112 .6534 L .46122 .6536 L 0 0 0 r
F
.46111 .65357 m .46107 .65358 L .46113 .65358 L .125 .161 0 r
F
.46107 .65358 m .45926 .65379 L .46113 .65358 L F
.46113 .65358 m .46051 .65357 L .46113 .65346 L 0 0 0 r
F
.46051 .65357 m .45988 .64497 L .46113 .65346 L F
.46051 .65357 m .46009 .65364 L .46015 .65363 L .125 .161 0 r
F
.46047 .65358 m .46009 .65364 L .46051 .65357 L F
.46049 .65358 m .46009 .65364 L .46061 .65355 L F
.46045 .65358 m .46043 .65359 L .46009 .65364 L F
.46009 .65364 m .45848 .65374 L .45926 .65379 L 0 0 0 r
F
.46015 .65363 m .46009 .65364 L .45926 .65379 L .125 .161 0 r
F
.46061 .65355 m .45926 .65379 L .46123 .65356 L F
.46042 .65355 m .45913 .64507 L .45988 .64497 L 0 0 0 r
F
.4598 .65354 m .45913 .64507 L .46042 .65355 L F
.46216 .65337 m .46496 .65281 L .46113 .65358 L .161 .167 0 r
F
.46538 .6527 m .46509 .65277 L .46216 .65337 L F
.4698 .65202 m .46507 .65273 L .4651 .65278 L .137 .164 0 r
F
.46984 .65191 m .4651 .65278 L .4651 .65276 L .182 .172 0 r
F
.46984 .65191 m .46413 .65293 L .46454 .65289 L F
.46512 .65277 m .46512 .65278 L .46454 .65289 L .227 .179 0 r
F
.46509 .65277 m .46496 .65281 L .46216 .65337 L .161 .167 0 r
F
.46373 .69178 m .46332 .692 L .46114 .65375 L 0 0 0 r
F
.46373 .69178 m .46114 .65375 L .46115 .65375 L F
.46538 .6527 m .46113 .65358 L .46116 .65357 L .161 .167 0 r
F
.46538 .6527 m .46079 .65365 L .46085 .65363 L F
.46342 .6937 m .46288 .69224 L .4633 .69201 L 0 0 0 r
F
.45915 .68862 m .4587 .68799 L .44799 .69235 L .177 0 0 r
F
.45915 .68862 m .44799 .69235 L .44883 .69328 L F
.45961 .68921 m .45915 .68862 L .44883 .69328 L .146 0 0 r
F
.45961 .68921 m .44883 .69328 L .44969 .69421 L F
.46007 .68978 m .45961 .68921 L .44969 .69421 L .114 0 0 r
F
.46007 .68978 m .44969 .69421 L .45056 .69514 L F
.46054 .69033 m .46007 .68978 L .45056 .69514 L .082 0 0 r
F
.46054 .69033 m .45056 .69514 L .45143 .69608 L F
.46101 .69086 m .46054 .69033 L .45143 .69608 L .052 0 0 r
F
.46101 .69086 m .45143 .69608 L .45231 .69705 L F
.46149 .69139 m .45231 .69705 L .4532 .69806 L .023 0 0 r
F
.46196 .69192 m .4532 .69806 L .45409 .69912 L 0 0 0 r
F
.46384 .69337 m .46121 .65356 L .45791 .7007 L F
.46114 .65358 m .46113 .65358 L .46112 .6534 L F
.4612 .6534 m .46112 .6534 L .46064 .64483 L F
.46121 .65356 m .46064 .64483 L .4602 .65376 L F
.4587 .68799 m .45825 .68734 L .44714 .69141 L .209 0 0 r
F
.4587 .68799 m .44714 .69141 L .44799 .69235 L F
.46121 .65361 m .4602 .65379 L .45791 .7007 L 0 0 0 r
F
.46121 .65356 m .4602 .65379 L .46121 .65361 L F
.45641 .65455 m .4602 .6538 L .4562 .65456 L F
.45641 .65455 m .4562 .65456 L .45522 .65475 L F
.4602 .6538 m .45721 .65436 L .45522 .65475 L F
.45972 .65347 m .45838 .64512 L .45913 .64507 L 1 .715 0 r
F
.4597 .65347 m .45838 .64512 L .45972 .65347 L F
.45911 .65354 m .45838 .64512 L .45973 .65363 L F
.45618 .64501 m .45545 .64488 L .44862 .64441 L .111 0 0 r
F
.45618 .64501 m .44862 .64441 L .44967 .64459 L F
.45691 .64509 m .45618 .64501 L .44967 .64459 L .073 0 0 r
F
.45691 .64509 m .44967 .64459 L .45073 .64472 L F
.45764 .64513 m .45691 .64509 L .45073 .64472 L 0 .131 0 r
F
.45693 .65356 m .45617 .65341 L .44958 .65385 L .104 0 0 r
F
.45764 .64513 m .45073 .64472 L .4518 .64481 L 0 .131 0 r
F
.45693 .65356 m .44958 .65385 L .45069 .65409 L .104 0 0 r
F
.45838 .64512 m .45764 .64513 L .4518 .64481 L .001 .138 0 r
F
.4577 .65367 m .45693 .65356 L .45069 .65409 L .073 0 0 r
F
.45838 .64512 m .4518 .64481 L .45288 .64486 L .001 .138 0 r
F
.45913 .64507 m .45838 .64512 L .45288 .64486 L .037 .145 0 r
F
.4577 .65367 m .45069 .65409 L .45181 .65429 L .073 0 0 r
F
.45848 .65374 m .4577 .65367 L .45181 .65429 L .043 0 0 r
F
.45913 .64507 m .45288 .64486 L .45396 .64487 L .037 .145 0 r
F
.45988 .64497 m .45913 .64507 L .45396 .64487 L .072 .152 0 r
F
.45848 .65374 m .45181 .65429 L .45294 .65447 L .043 0 0 r
F
.45926 .65379 m .45848 .65374 L .45294 .65447 L .015 0 0 r
F
.45988 .64497 m .45396 .64487 L .45505 .64484 L .072 .152 0 r
F
.46064 .64483 m .45988 .64497 L .45505 .64484 L .106 .158 0 r
F
.45926 .65379 m .45294 .65447 L .45407 .65462 L .015 0 0 r
F
.46005 .6538 m .45926 .65379 L .45407 .65462 L 0 0 0 r
F
.46064 .64483 m .45505 .64484 L .45615 .64476 L .106 .158 0 r
F
.46005 .6538 m .45407 .65462 L .45522 .65475 L 0 0 0 r
F
.45641 .65455 m .46064 .64483 L .45615 .64476 L 1 .749 0 r
F
.45737 .68591 m .45693 .68515 L .44468 .68845 L .298 0 0 r
F
.45737 .68591 m .44468 .68845 L .44549 .68946 L F
.45781 .68664 m .45737 .68591 L .44549 .68946 L .269 0 0 r
F
.45781 .68664 m .44549 .68946 L .44631 .69044 L F
.45825 .68734 m .45781 .68664 L .44631 .69044 L .239 0 0 r
F
.45825 .68734 m .44631 .69044 L .44714 .69141 L F
.45772 .70464 m .4602 .65379 L .45641 .65455 L 1 .749 0 r
F
.4602 .6538 m .4602 .6538 L .45641 .65455 L 0 0 0 r
F
.4602 .6538 m .46005 .6538 L .45721 .65436 L F
.45972 .65357 m .4597 .65347 L .45972 .65347 L 1 .715 0 r
F
.45972 .65356 m .4597 .65347 L .45972 .65357 L F
.45972 .65357 m .4591 .65351 L .45848 .65374 L 0 0 0 r
F
.4591 .65351 m .4577 .65367 L .45787 .65369 L F
.4591 .65351 m .45787 .65369 L .45848 .65374 L F
.4602 .65379 m .46064 .64483 L .45641 .65455 L 1 .749 0 r
F
.46083 .65379 m .4602 .6538 L .45641 .65455 L 0 0 0 r
F
.45772 .70464 m .45641 .65473 L .45733 .65464 L 1 .749 0 r
F
.45641 .65473 m .45641 .65455 L .45733 .65464 L F
.46084 .65379 m .45684 .65447 L .45733 .65464 L 0 0 0 r
F
.45684 .65447 m .45641 .65455 L .45733 .65464 L F
.46384 .69337 m .45791 .7007 L .45772 .70464 L F
.4644 .6953 m .46391 .69443 L .45774 .7046 L F
.45775 .7046 m .45774 .7046 L .45772 .70464 L F
.4644 .6953 m .45774 .7046 L .45775 .7046 L F
.4644 .6953 m .45775 .7046 L .45864 .70663 L F
.45775 .7046 m .45772 .70464 L .45864 .70663 L F
.46412 .69763 m .4644 .6953 L .45864 .70663 L F
.46489 .69637 m .46482 .69621 L .46412 .69763 L F
.46482 .69621 m .4644 .6953 L .46412 .69763 L F
.46489 .69637 m .46412 .69763 L .45955 .70907 L F
.46412 .69763 m .45864 .70663 L .45955 .70907 L F
.4594 .70836 m .45921 .70795 L .45927 .70778 L F
.45921 .70795 m .45864 .70663 L .45927 .70778 L F
.45927 .70778 m .45864 .70663 L .45863 .70491 L F
.45955 .70907 m .45864 .70663 L .4594 .70836 L F
.45955 .70907 m .45863 .70491 L .45948 .70521 L F
.45955 .70907 m .45952 .70701 L .45599 .718 L F
.45955 .70907 m .45599 .718 L .45354 .72563 L F
.45864 .70663 m .45772 .70464 L .45733 .65464 L F
.45864 .70663 m .45733 .65464 L .45748 .65469 L F
.46164 .65376 m .45792 .65454 L .45841 .65473 L F
.46158 .65377 m .46084 .65379 L .45772 .65454 L F
.46158 .65377 m .45772 .65454 L .45779 .65454 L F
.46164 .65376 m .45733 .65464 L .45761 .65461 L F
.46175 .64476 m .46137 .64453 L .45332 .64422 L .196 0 0 r
F
.46175 .64476 m .45332 .64422 L .45402 .64449 L F
.45841 .65473 m .45725 .64465 L .45836 .64451 L 0 0 0 r
F
.45864 .70663 m .45748 .65484 L .45841 .65473 L F
.45948 .70521 m .45863 .70491 L .45841 .65473 L F
.45948 .70521 m .45841 .65473 L .45841 .65473 L F
.45935 .65449 m .46164 .65376 L .45841 .65473 L F
.45869 .6547 m .45841 .65473 L .45855 .65473 L F
.45855 .65473 m .45841 .65454 L .45855 .65454 L F
.45948 .70521 m .45841 .65473 L .45855 .65473 L F
.45841 .65473 m .45841 .65454 L .45855 .65473 L F
.45855 .65473 m .45841 .65473 L .45753 .655 L F
.4559 .70154 m .45499 .70027 L .44706 .70961 L .241 0 0 r
F
.4559 .70154 m .44706 .70961 L .44836 .71186 L F
.45681 .70298 m .4559 .70154 L .44836 .71186 L .236 0 0 r
F
.44986 .7141 m .44836 .71186 L .44965 .71444 L F
.45681 .70298 m .44873 .71146 L .44986 .7141 L F
.44873 .71146 m .44836 .71186 L .44986 .7141 L F
.45952 .70701 m .45397 .71828 L .45354 .72563 L 0 0 0 r
F
.45748 .65484 m .45748 .65464 L .45841 .65473 L F
.45748 .65464 m .45637 .65487 L .45841 .65473 L F
.45841 .65473 m .45637 .65487 L .45753 .655 L F
.45409 .69912 m .4532 .69806 L .4445 .7058 L .257 0 0 r
F
.45409 .69912 m .4445 .7058 L .44578 .70761 L F
.45499 .70027 m .45409 .69912 L .44578 .70761 L .248 0 0 r
F
.45499 .70027 m .44578 .70761 L .44706 .70961 L F
.45426 .65606 m .45203 .65598 L .45354 .6563 L .114 0 0 r
F
.45753 .655 m .45301 .65581 L .45426 .65606 L F
.45301 .65581 m .45203 .65598 L .45426 .65606 L F
.45457 .65613 m .45774 .65502 L .45457 .65607 L 1 .789 0 r
F
.45354 .72563 m .45774 .65508 L .45457 .65613 L F
.45774 .65508 m .45774 .65502 L .45457 .65613 L F
.45002 .65765 m .45354 .6563 L .44971 .65771 L .298 0 0 r
F
.45354 .72563 m .45457 .65633 L .4558 .65637 L 1 .789 0 r
F
.45457 .65633 m .45457 .65612 L .45569 .65635 L F
.45457 .65633 m .45569 .65635 L .4558 .65637 L F
.45952 .70701 m .45855 .65473 L .45397 .71828 L 0 0 0 r
F
.45855 .65473 m .45753 .655 L .45774 .65502 L F
.45855 .65473 m .45774 .65497 L .45774 .65502 L F
.45855 .65473 m .45774 .65502 L .45397 .71828 L F
.46244 .65372 m .45855 .65473 L .45869 .65514 L F
.45855 .65473 m .45774 .65502 L .45869 .65514 L F
.45638 .65621 m .45624 .65617 L .4558 .65635 L .155 0 0 r
F
.46138 .71626 m .4549 .73116 L .45609 .73881 L .249 .018 0 r
F
.4549 .73116 m .45482 .73134 L .45609 .73881 L F
.46164 .72362 m .46138 .71626 L .45609 .73881 L .259 .024 0 r
F
.46228 .72186 m .46217 .72117 L .46164 .72362 L F
.46217 .72117 m .46138 .71626 L .46164 .72362 L F
.46228 .72186 m .45609 .73881 L .45733 .7489 L F
.45717 .74577 m .45609 .73881 L .45637 .73007 L .011 0 0 r
F
.45733 .7489 m .45609 .73881 L .45717 .74577 L F
.45733 .7489 m .45637 .73007 L .45761 .73237 L F
.45733 .7489 m .45743 .74306 L .45143 .78152 L F
.46047 .71217 m .45955 .70907 L .4537 .72517 L .242 .011 0 r
F
.46047 .71217 m .4537 .72517 L .45373 .72522 L F
.46047 .71217 m .45359 .72548 L .4536 .72551 L F
.45986 .65533 m .45655 .65625 L .45724 .65676 L .155 0 0 r
F
.45986 .65533 m .45869 .65514 L .45624 .65617 L F
.45986 .65533 m .45624 .65617 L .45638 .65621 L F
.45986 .65533 m .4558 .65635 L .45615 .65636 L F
.46244 .65372 m .45841 .65473 L .45869 .6547 L 0 0 0 r
F
.46137 .64453 m .461 .64425 L .45262 .64391 L .232 0 0 r
F
.46137 .64453 m .45262 .64391 L .45332 .64422 L F
.46324 .6537 m .46244 .65372 L .45869 .65514 L 0 0 0 r
F
.46324 .6537 m .45869 .65514 L .45986 .65533 L F
.46047 .71217 m .4536 .72551 L .45482 .73134 L .242 .011 0 r
F
.4536 .72551 m .45354 .72563 L .45482 .73134 L F
.46138 .71626 m .46047 .71217 L .45482 .73134 L .249 .018 0 r
F
.45579 .73599 m .45482 .73134 L .45493 .72782 L .016 0 0 r
F
.45609 .73881 m .45482 .73134 L .45579 .73599 L F
.45621 .73004 m .45493 .72782 L .45724 .65676 L F
.45609 .73881 m .45724 .65676 L .45725 .65676 L F
.45802 .65663 m .45769 .65651 L .45724 .65676 L .194 0 0 r
F
.45609 .73881 m .45725 .65676 L .45744 .65683 L .016 0 0 r
F
.45457 .65607 m .45753 .655 L .45426 .65606 L .129 0 0 r
F
.45869 .65514 m .45774 .65502 L .45499 .65593 L F
.4551 .65595 m .45499 .65593 L .45457 .65607 L F
.45869 .65514 m .45499 .65593 L .4551 .65595 L F
.4558 .65635 m .45354 .6563 L .45505 .65667 L F
.45869 .65514 m .4551 .65595 L .4558 .65635 L F
.45457 .65612 m .45457 .65607 L .4558 .65637 L 1 .789 0 r
F
.4551 .65595 m .45457 .65607 L .4558 .65635 L .129 0 0 r
F
.45457 .65607 m .45577 .65608 L .4558 .65635 L 1 .789 0 r
F
.45457 .65607 m .4558 .65635 L .4558 .65637 L F
.45457 .65607 m .45354 .6563 L .4558 .65635 L .129 0 0 r
F
.45615 .65636 m .4558 .65635 L .456 .6564 L .155 0 0 r
F
.456 .65647 m .4558 .65626 L .456 .6564 L .021 0 0 r
F
.45491 .72586 m .4558 .65635 L .456 .65647 L F
.4558 .65635 m .4558 .65626 L .456 .65647 L F
.456 .6564 m .4558 .65626 L .45581 .65608 L F
.45774 .65502 m .45753 .655 L .45457 .65607 L .129 0 0 r
F
.45753 .655 m .45637 .65487 L .45203 .65598 L .114 0 0 r
F
.45457 .65607 m .45776 .65473 L .45458 .65553 L 1 .789 0 r
F
.45774 .65502 m .45776 .65473 L .45457 .65607 L F
.45617 .64495 m .45615 .64476 L .45618 .64476 L 1 .749 0 r
F
.45617 .64495 m .45618 .64476 L .45725 .64465 L F
.45733 .65448 m .45617 .64495 L .45725 .64465 L F
.45792 .65454 m .45748 .65464 L .45841 .65473 L 0 0 0 r
F
.45779 .65454 m .45772 .65454 L .45733 .65464 L F
.45748 .65464 m .45725 .64465 L .45841 .65473 L F
.45748 .65469 m .45733 .65464 L .45725 .64465 L F
.45641 .65455 m .45615 .64476 L .45733 .65448 L 1 .749 0 r
F
.45545 .64488 m .45474 .64471 L .44758 .64418 L .148 0 0 r
F
.45466 .65298 m .45392 .6527 L .4463 .65291 L .201 0 0 r
F
.45545 .64488 m .44758 .64418 L .44862 .64441 L .148 0 0 r
F
.45466 .65298 m .4463 .65291 L .44738 .65326 L .201 0 0 r
F
.45541 .65321 m .45466 .65298 L .44738 .65326 L .169 0 0 r
F
.45541 .65321 m .44738 .65326 L .44848 .65358 L F
.45617 .65341 m .45541 .65321 L .44848 .65358 L .136 0 0 r
F
.45617 .65341 m .44848 .65358 L .44958 .65385 L F
.45505 .64484 m .45396 .64487 L .44904 .64449 L .038 .145 0 r
F
.45505 .64484 m .44904 .64449 L .45045 .64453 L F
.45615 .64476 m .45505 .64484 L .45045 .64453 L .067 .15 0 r
F
.45522 .65475 m .45407 .65462 L .44906 .65541 L .112 0 0 r
F
.45615 .64476 m .45045 .64453 L .45187 .64454 L .067 .15 0 r
F
.45474 .64471 m .45402 .64449 L .44654 .64391 L .184 0 0 r
F
.45474 .64471 m .44654 .64391 L .44758 .64418 L F
.45725 .64465 m .45615 .64476 L .45187 .64454 L .093 .155 0 r
F
.45522 .65475 m .44906 .65541 L .45054 .65569 L .112 0 0 r
F
.45637 .65487 m .45522 .65475 L .45054 .65569 L .109 0 0 r
F
.45725 .64465 m .45187 .64454 L .4533 .64451 L .093 .155 0 r
F
.45836 .64451 m .45725 .64465 L .4533 .64451 L .115 .159 0 r
F
.45637 .65487 m .45054 .65569 L .45203 .65598 L .109 0 0 r
F
.45836 .64451 m .4533 .64451 L .45474 .64446 L .115 .159 0 r
F
.45458 .65553 m .45836 .64451 L .45474 .64446 L 1 .789 0 r
F
.45761 .65461 m .45733 .65464 L .45637 .65487 L 0 0 0 r
F
.45733 .65464 m .45522 .65475 L .45637 .65487 L F
.45641 .65455 m .45522 .65475 L .45733 .65464 L F
.45733 .65464 m .45641 .65455 L .45733 .65448 L 1 .749 0 r
F
.45776 .65473 m .45836 .64451 L .45458 .65553 L 1 .789 0 r
F
.456 .65612 m .45581 .65608 L .45619 .64439 L .021 0 0 r
F
.456 .6564 m .45581 .65608 L .456 .65612 L F
.45724 .65664 m .45619 .64439 L .45764 .6443 L F
.45655 .65625 m .456 .6564 L .45724 .65676 L .155 0 0 r
F
.45482 .73134 m .456 .6564 L .45724 .65676 L .021 0 0 r
F
.45491 .72586 m .45363 .72288 L .4558 .65635 L F
.45491 .72586 m .4558 .65635 L .4558 .65635 L F
.456 .6564 m .45505 .65667 L .45645 .65673 L .155 0 0 r
F
.456 .6564 m .45645 .65673 L .45724 .65676 L F
.45724 .65676 m .456 .65617 L .45724 .65664 L .021 0 0 r
F
.456 .6564 m .456 .65617 L .45724 .65676 L F
.456 .65617 m .45619 .64439 L .45724 .65664 L F
.46104 .6556 m .45802 .65663 L .45869 .65731 L .194 0 0 r
F
.46104 .6556 m .45986 .65533 L .45769 .65651 L F
.46104 .6556 m .45769 .65651 L .45802 .65663 L F
.45841 .65473 m .45841 .65473 L .45841 .65454 L 0 0 0 r
F
.45855 .65454 m .45841 .65454 L .45836 .64451 L F
.45855 .65473 m .45836 .64451 L .45774 .65497 L F
.45869 .65731 m .45764 .6443 L .4591 .64422 L .016 0 0 r
F
.45609 .73881 m .45743 .65719 L .45869 .65731 L F
.45761 .73237 m .45637 .73007 L .45869 .65731 L .011 0 0 r
F
.45761 .73237 m .45869 .65731 L .45869 .65732 L F
.45946 .65703 m .46104 .6556 L .45869 .65731 L .241 0 0 r
F
.45905 .65734 m .45869 .65731 L .45888 .65741 L F
.45888 .65741 m .4587 .65689 L .45889 .65696 L .011 0 0 r
F
.45761 .73237 m .45869 .65731 L .45888 .65741 L F
.45869 .65731 m .4587 .65689 L .45888 .65741 L F
.45849 .65711 m .45818 .65712 L .45869 .65731 L .194 0 0 r
F
.45802 .65663 m .4576 .65678 L .45849 .65711 L F
.45802 .65663 m .45724 .65676 L .45744 .65683 L F
.45744 .65683 m .45764 .6443 L .45869 .65731 L .016 0 0 r
F
.45682 .65699 m .45505 .65667 L .45656 .65713 L .155 0 0 r
F
.45724 .65676 m .45645 .65673 L .45682 .65699 L F
.45645 .65673 m .45505 .65667 L .45682 .65699 L F
.45744 .65648 m .45725 .65643 L .45764 .6443 L .016 0 0 r
F
.45656 .65713 m .45505 .65667 L .45154 .65836 L .336 0 0 r
F
.45382 .65889 m .45154 .65836 L .45338 .65917 L F
.45656 .65713 m .45222 .6582 L .45382 .65889 L F
.45222 .6582 m .45154 .65836 L .45382 .65889 L F
.45808 .65775 m .45656 .65713 L .45382 .65889 L .377 0 0 r
F
.45412 .65895 m .45382 .65889 L .45338 .65917 L F
.45808 .65775 m .45382 .65889 L .45412 .65895 L F
.4556 .6599 m .45338 .65917 L .45521 .66024 L F
.45373 .72522 m .4537 .72517 L .45359 .72548 L .242 .011 0 r
F
.4536 .72551 m .45359 .72548 L .45354 .72563 L F
.45482 .73134 m .45354 .72563 L .45363 .72288 L .021 0 0 r
F
.45482 .73134 m .45363 .72288 L .45491 .72586 L F
.45605 .65993 m .45643 .65952 L .45584 .65987 L .418 .008 0 r
F
.45643 .65952 m .45808 .65775 L .45622 .65937 L F
.45643 .65952 m .45622 .65937 L .45521 .66024 L F
.45834 .65789 m .45808 .65775 L .45605 .65993 L F
.45605 .65993 m .45835 .65777 L .45607 .65959 L 1 .818 0 r
F
.45143 .78152 m .45834 .65789 L .4582 .65802 L F
.45605 .66007 m .4582 .65802 L .45605 .65993 L F
.45143 .78152 m .4582 .65802 L .45605 .66007 L F
.45294 .66303 m .45521 .66024 L .45246 .66319 L .64 .047 0 r
F
.45609 .73881 m .45493 .72782 L .45621 .73004 L .016 0 0 r
F
.45743 .74306 m .45888 .65741 L .45224 .76704 L .011 0 0 r
F
.45888 .65741 m .45808 .65775 L .45834 .65789 L .241 0 0 r
F
.45888 .65741 m .45835 .65777 L .45834 .65789 L .011 0 0 r
F
.45888 .65741 m .45834 .65789 L .45224 .76704 L F
.46222 .65603 m .45888 .65741 L .45961 .65862 L .241 0 0 r
F
.45888 .65741 m .45834 .65789 L .45961 .65862 L F
.45743 .74306 m .45224 .76704 L .45143 .78152 L .011 0 0 r
F
.45855 .76295 m .45733 .7489 L .45145 .78142 L .486 .065 0 r
F
.45145 .78146 m .45145 .78142 L .45143 .78152 L F
.45855 .76295 m .45145 .78142 L .45145 .78146 L F
.45855 .76295 m .45145 .78146 L .45309 .7998 L F
.45145 .78146 m .45143 .78152 L .45309 .7998 L F
.45902 .78469 m .45855 .76295 L .45309 .7998 L .505 .069 0 r
F
.45975 .78282 m .45958 .78001 L .45902 .78469 L F
.45958 .78001 m .45855 .76295 L .45902 .78469 L F
.45975 .78282 m .45309 .7998 L .45492 .82179 L F
.4547 .81778 m .45309 .7998 L .45335 .79405 L .204 .027 0 r
F
.45492 .82179 m .45309 .7998 L .4547 .81778 L F
.45533 .80716 m .45335 .79405 L .45936 .66311 L F
.45492 .82179 m .45335 .79405 L .45533 .80716 L F
.45309 .7998 m .45143 .78152 L .45758 .66109 L .194 .025 0 r
F
.45309 .7998 m .45758 .66109 L .45758 .6611 L F
.45799 .66059 m .45668 .6597 L .45758 .66109 L .418 .008 0 r
F
.46114 .65995 m .45847 .66111 L .45936 .66311 L .487 .031 0 r
F
.45492 .82179 m .45936 .66311 L .45937 .66312 L .204 .027 0 r
F
.45964 .66359 m .46114 .65995 L .45936 .66311 L .558 .051 0 r
F
.45964 .66359 m .45938 .66269 L .45965 .6631 L .204 .027 0 r
F
.45492 .82179 m .45937 .66312 L .45964 .66359 L F
.45937 .66312 m .45938 .66269 L .45964 .66359 L F
.46114 .65995 m .45758 .66109 L .45784 .66138 L .487 .031 0 r
F
.45847 .66111 m .45784 .66138 L .45936 .66311 L F
.45936 .66311 m .45785 .66117 L .45941 .66205 L .194 .025 0 r
F
.45309 .7998 m .45784 .66138 L .45936 .66311 L F
.45784 .66138 m .45785 .66117 L .45936 .66311 L F
.45309 .7998 m .45758 .66109 L .45765 .66117 L F
.45825 .66087 m .45799 .66059 L .45758 .66109 L .487 .031 0 r
F
.45309 .7998 m .45766 .66096 L .45784 .66138 L .194 .025 0 r
F
.45143 .78152 m .45605 .65993 L .45758 .66109 L 1 .818 0 r
F
.45784 .66138 m .45705 .66172 L .45936 .66311 L .487 .031 0 r
F
.46114 .65995 m .45961 .65862 L .45799 .66059 L F
.46114 .65995 m .45799 .66059 L .45825 .66087 L F
.45892 .66388 m .45705 .66172 L .45889 .66395 L F
.45832 .66248 m .45705 .66172 L .45892 .66388 L F
.45961 .65862 m .45725 .65949 L .45799 .66059 L .418 .008 0 r
F
.45725 .65949 m .45668 .6597 L .45799 .66059 L F
.45834 .65789 m .45835 .65777 L .45605 .65993 L 1 .818 0 r
F
.45961 .65862 m .45834 .65789 L .45605 .65993 L .418 .008 0 r
F
.45808 .65775 m .45547 .65854 L .45622 .65937 L .377 0 0 r
F
.45622 .65937 m .45398 .65899 L .4556 .6599 L F
.45547 .65854 m .45398 .65899 L .45622 .65937 L F
.45607 .65959 m .4591 .64422 L .45664 .64445 L 1 .818 0 r
F
.45743 .65719 m .45744 .65683 L .45869 .65731 L .016 0 0 r
F
.45818 .65712 m .45656 .65713 L .45869 .65731 L .194 0 0 r
F
.4576 .65678 m .45656 .65713 L .45849 .65711 L F
.45744 .65683 m .45724 .65676 L .45656 .65713 L F
.45725 .65676 m .45725 .65664 L .45744 .65683 L .016 0 0 r
F
.45744 .65683 m .45725 .65643 L .45744 .65648 L F
.45725 .65664 m .45725 .65643 L .45744 .65683 L F
.45825 .65763 m .45656 .65713 L .45808 .65775 L .194 0 0 r
F
.45869 .65731 m .45785 .65724 L .45825 .65763 L F
.45785 .65724 m .45656 .65713 L .45825 .65763 L F
.45725 .65676 m .45724 .65676 L .45725 .65643 L .016 0 0 r
F
.45835 .65777 m .4591 .64422 L .45607 .65959 L 1 .818 0 r
F
.4587 .65749 m .45869 .65731 L .45808 .65775 L .241 0 0 r
F
.45888 .65741 m .45883 .65739 L .4587 .65749 L F
.45883 .65739 m .45869 .65731 L .4587 .65749 L F
.46222 .65603 m .45869 .65731 L .45905 .65734 L F
.45869 .65732 m .45869 .65731 L .4587 .65689 L .011 0 0 r
F
.45889 .65696 m .4587 .65689 L .4591 .64422 L F
.45888 .65741 m .4591 .64422 L .45835 .65777 L F
.46222 .65603 m .4614 .65573 L .45946 .65703 L .241 0 0 r
F
.4614 .65573 m .46104 .6556 L .45946 .65703 L F
.46244 .65372 m .46189 .65375 L .45935 .65449 L 0 0 0 r
F
.46189 .65375 m .46164 .65376 L .45935 .65449 L F
.45941 .66205 m .45842 .64457 L .4602 .64479 L .194 .025 0 r
F
.45785 .66117 m .45842 .64457 L .45941 .66205 L F
.45889 .66395 m .45705 .66172 L .45492 .66496 L .701 .064 0 r
F
.45529 .66524 m .45492 .66496 L .45456 .6655 L F
.45889 .66395 m .45492 .66496 L .45529 .66524 L F
.45889 .66395 m .45456 .6655 L .45665 .669 L F
.45786 .66797 m .45889 .66395 L .45706 .66806 L .751 .12 0 r
F
.45923 .66465 m .45889 .66395 L .45786 .66797 L F
.45754 .66923 m .45923 .66465 L .45756 .66869 L 1 .844 0 r
F
.45021 .84999 m .45923 .6647 L .45754 .66923 L F
.45923 .6647 m .45923 .66465 L .45754 .66923 L F
.45523 .67539 m .45665 .669 L .45441 .67551 L .895 .302 0 r
F
.45829 .69783 m .4595 .66415 L .45912 .66701 L .204 .027 0 r
F
.45829 .69783 m .45912 .66701 L .45021 .84999 L F
.45955 .66363 m .45936 .66311 L .45889 .66395 L .558 .051 0 r
F
.45964 .66359 m .4596 .66352 L .45955 .66363 L F
.4596 .66352 m .45936 .66311 L .45955 .66363 L F
.45965 .6631 m .45938 .66269 L .45941 .6621 L .204 .027 0 r
F
.46405 .65372 m .46324 .6537 L .45986 .65533 L 0 0 0 r
F
.46405 .65372 m .45986 .65533 L .46104 .6556 L F
.4634 .65672 m .46222 .65603 L .45961 .65862 L .292 0 0 r
F
.4634 .65672 m .45961 .65862 L .46114 .65995 L F
.45968 .66238 m .45941 .6621 L .4602 .64479 L .204 .027 0 r
F
.45965 .6631 m .45941 .6621 L .45968 .66238 L F
.45505 .81749 m .45964 .66359 L .45351 .83026 L F
.45964 .66359 m .45889 .66395 L .45923 .66465 L .558 .051 0 r
F
.45964 .66359 m .4602 .64479 L .45951 .66393 L .204 .027 0 r
F
.45964 .66359 m .45951 .66393 L .45351 .83026 L F
.46266 .66215 m .45964 .66359 L .4607 .66762 L .558 .051 0 r
F
.4595 .66415 m .45951 .6638 L .45946 .66423 L .204 .027 0 r
F
.4595 .66415 m .45946 .66423 L .45912 .66701 L F
.45951 .6638 m .45925 .66424 L .45912 .66701 L F
.45964 .66359 m .45923 .66465 L .4607 .66762 L .558 .051 0 r
F
.45351 .83026 m .45829 .69783 L .45021 .84999 L .204 .027 0 r
F
.45492 .82179 m .45505 .81749 L .45351 .83026 L F
.4607 .66762 m .45817 .66848 L .4592 .67302 L .751 .12 0 r
F
.45021 .84999 m .45755 .66902 L .4592 .67302 L 1 .844 0 r
F
.45755 .66902 m .45756 .66869 L .4592 .67302 L F
.46539 .69775 m .46489 .69637 L .45955 .70907 L 0 0 0 r
F
.46539 .69775 m .45955 .70907 L .46047 .71217 L F
.46588 .69958 m .46539 .69775 L .46047 .71217 L F
.46588 .69958 m .46047 .71217 L .46138 .71626 L F
.46316 .72996 m .46228 .72186 L .45733 .7489 L .272 .03 0 r
F
.45709 .8462 m .45492 .82179 L .45021 .84999 L .693 .191 0 r
F
.45709 .8462 m .45021 .84999 L .45346 .86845 L F
.45346 .86845 m .45021 .84999 L .4592 .67302 L .346 .053 0 r
F
.45346 .86845 m .4592 .67302 L .45924 .6732 L F
.46245 .67464 m .4607 .66762 L .45954 .67182 L .795 .233 0 r
F
.45992 .67338 m .45954 .67182 L .4592 .67302 L F
.46245 .67464 m .45954 .67182 L .45992 .67338 L F
.46245 .67464 m .4592 .67302 L .45995 .67483 L F
.45965 .67485 m .45931 .67091 L .45975 .67183 L .346 .053 0 r
F
.46102 .81014 m .45975 .78282 L .45492 .82179 L .522 .071 0 r
F
.46102 .81014 m .45492 .82179 L .45709 .8462 L F
.45346 .86845 m .45924 .67319 L .45965 .67485 L .346 .053 0 r
F
.45965 .67485 m .4592 .67302 L .45868 .67492 L .795 .233 0 r
F
.45995 .67483 m .4592 .67302 L .45965 .67485 L F
.45924 .67319 m .45929 .67154 L .45965 .67485 L .346 .053 0 r
F
.45929 .67154 m .45931 .67091 L .45965 .67485 L F
.46245 .67464 m .46028 .6748 L .46116 .68298 L .795 .233 0 r
F
.46266 .66215 m .46149 .66046 L .45964 .66359 L .558 .051 0 r
F
.46149 .66046 m .46114 .65995 L .45964 .66359 L F
.46164 .65376 m .46162 .65376 L .46158 .65377 L 0 0 0 r
F
.46162 .65376 m .46084 .65379 L .46158 .65377 L F
.46538 .6527 m .46121 .65356 L .46084 .65379 L .161 .167 0 r
F
.46116 .65357 m .46113 .65358 L .46079 .65365 L F
.46085 .65363 m .46079 .65365 L .46005 .6538 L F
.46121 .65356 m .46005 .6538 L .4602 .65379 L F
.46121 .65356 m .4602 .65379 L .46084 .65379 L F
.46121 .65356 m .4602 .65376 L .4602 .65379 L 0 0 0 r
F
.4658 .65255 m .46538 .6527 L .4615 .65363 L .195 .173 0 r
F
.46155 .65361 m .4615 .65363 L .46084 .65379 L F
.4658 .65255 m .4615 .65363 L .46155 .65361 L F
.46084 .65379 m .46083 .65379 L .46083 .65379 L 0 0 0 r
F
.46083 .65379 m .46005 .6538 L .46083 .65379 L F
.4658 .65255 m .46084 .65379 L .46164 .65376 L .195 .173 0 r
F
.46623 .65239 m .4658 .65255 L .46164 .65376 L .227 .177 0 r
F
.46623 .65239 m .46164 .65376 L .46244 .65372 L F
.46487 .65381 m .46405 .65372 L .46104 .6556 L 0 0 0 r
F
.46487 .65381 m .46104 .6556 L .46222 .65603 L F
.46568 .65406 m .46487 .65381 L .46222 .65603 L .045 0 0 r
F
.46568 .65406 m .46222 .65603 L .4634 .65672 L F
.46459 .65792 m .4634 .65672 L .46114 .65995 L .342 .009 0 r
F
.46459 .65792 m .46114 .65995 L .46266 .66215 L F
.46416 .66622 m .46266 .66215 L .4607 .66762 L .621 .068 0 r
F
.46416 .66622 m .4607 .66762 L .46245 .67464 L F
.46116 .68298 m .46057 .64621 L .46263 .64766 L .346 .053 0 r
F
.46316 .72996 m .45733 .7489 L .45855 .76295 L .272 .03 0 r
F
.45346 .86845 m .45965 .67485 L .46116 .68298 L .346 .053 0 r
F
.46028 .6748 m .45965 .67485 L .46116 .68298 L .795 .233 0 r
F
.4607 .66762 m .45792 .66796 L .45817 .66848 L .751 .12 0 r
F
.4607 .66762 m .45923 .66465 L .45786 .66797 L F
.45965 .67485 m .46057 .64621 L .46116 .68298 L .346 .053 0 r
F
.45965 .67485 m .45868 .67492 L .46116 .68298 L .795 .233 0 r
F
.46079 .68537 m .45868 .67492 L .46056 .68689 L F
.46116 .68298 m .46019 .67982 L .46079 .68537 L F
.46019 .67982 m .45868 .67492 L .46079 .68537 L F
.464 .74238 m .46316 .72996 L .45855 .76295 L .288 .036 0 r
F
.464 .74238 m .45855 .76295 L .45975 .78282 L F
.46254 .84376 m .46102 .81014 L .45709 .8462 L .524 .071 0 r
F
.45973 .87059 m .45709 .8462 L .45346 .86845 L .682 .174 0 r
F
.46254 .84376 m .45709 .8462 L .45973 .87059 L .524 .071 0 r
F
.45973 .87059 m .45346 .86845 L .4572 .88567 L .682 .174 0 r
F
.4572 .88567 m .45346 .86845 L .46116 .68298 L .352 .054 0 r
F
.4572 .88567 m .46116 .68298 L .46123 .68373 L F
.46197 .68564 m .46245 .67464 L .46116 .68298 L .845 .336 0 r
F
.464 .69239 m .46205 .68591 L .46169 .68871 L F
.46205 .68591 m .46116 .68298 L .46169 .68871 L F
.4572 .88567 m .46133 .67904 L .46138 .67926 L .352 .054 0 r
F
.4572 .88567 m .46138 .67926 L .46169 .68871 L F
.4679 .87971 m .46781 .87892 L .45611 .8874 L 0 0 0 r
F
.4679 .87971 m .45611 .8874 L .45706 .8883 L F
.4572 .88567 m .46158 .69371 L .45496 .89474 L .352 .054 0 r
F
.46158 .69371 m .46169 .68871 L .46151 .69441 L F
.46158 .69371 m .46151 .69441 L .45496 .89474 L F
.45975 .71135 m .46056 .68689 L .45831 .70526 L .967 .474 0 r
F
.46123 .69591 m .46122 .69579 L .46104 .69892 L .845 .336 0 r
F
.46122 .69579 m .46056 .68689 L .46104 .69892 L F
.45956 .7241 m .46068 .70304 L .45989 .71196 L 1 .85 0 r
F
.45496 .89474 m .46079 .70686 L .45956 .7241 L F
.46079 .70686 m .46104 .69892 L .45987 .71888 L F
.46079 .70686 m .45987 .71888 L .45956 .7241 L F
.45747 .75009 m .45831 .70526 L .4555 .73251 L 1 .571 0 r
F
.45989 .71196 m .46104 .69892 L .45981 .71078 L .967 .474 0 r
F
.46104 .69892 m .46056 .68689 L .45975 .71135 L F
.46169 .68871 m .46104 .69892 L .45496 .89474 L .352 .054 0 r
F
.46637 .70212 m .46588 .69958 L .46138 .71626 L 0 0 0 r
F
.46169 .68871 m .46056 .68689 L .46248 .71269 L .845 .336 0 r
F
.46104 .69892 m .46125 .69226 L .45956 .7241 L 1 .85 0 r
F
.4619 .72048 m .46042 .71419 L .46075 .73785 L .967 .474 0 r
F
.46042 .71419 m .45989 .71196 L .46075 .73785 L F
.46799 .88046 m .4679 .87971 L .45723 .88817 L 0 0 0 r
F
.45725 .88817 m .45723 .88817 L .45706 .8883 L F
.46799 .88046 m .45723 .88817 L .45725 .88817 L F
.48182 .86427 m .46736 .87387 L .46745 .87505 L F
.46967 .6864 m .46962 .68624 L .46391 .69443 L F
.46967 .6864 m .46391 .69443 L .4644 .6953 L F
.46973 .68661 m .46967 .6864 L .4644 .6953 L F
.46973 .68661 m .4644 .6953 L .46489 .69637 L F
.46978 .68693 m .46973 .68661 L .46489 .69637 L F
.46978 .68693 m .46489 .69637 L .46539 .69775 L F
.46983 .68741 m .46978 .68693 L .46539 .69775 L F
.46983 .68741 m .46539 .69775 L .46588 .69958 L F
.46987 .68817 m .46983 .68741 L .46588 .69958 L F
.46987 .68817 m .46588 .69958 L .46637 .70212 L F
.46992 .68939 m .46987 .68817 L .46637 .70212 L F
.46992 .68939 m .46637 .70212 L .46685 .70584 L F
.46996 .69138 m .46992 .68939 L .46685 .70584 L F
.46996 .69138 m .46685 .70584 L .46732 .71163 L F
.46999 .69488 m .46996 .69138 L .46732 .71163 L F
.46799 .88046 m .45706 .8883 L .45803 .88917 L F
.46999 .69488 m .46732 .71163 L .46777 .72152 L F
.47001 .70181 m .46999 .69488 L .46777 .72152 L F
.46809 .88118 m .46799 .88046 L .45818 .88903 L F
.45819 .88903 m .45818 .88903 L .45803 .88917 L F
.46809 .88118 m .45818 .88903 L .45819 .88903 L F
.46809 .88118 m .45803 .88917 L .459 .89001 L F
.47001 .70181 m .46777 .72152 L .46815 .74108 L F
.46912 .7296 m .47001 .70181 L .46815 .74108 L F
.46913 .72947 m .46998 .70895 L .46912 .7296 L F
.46998 .70895 m .47001 .70181 L .46912 .7296 L F
.46989 .65177 m .46984 .65191 L .46512 .65278 L .227 .179 0 r
F
.46989 .65177 m .46512 .65278 L .46512 .65277 L F
.46984 .65191 m .4698 .65202 L .4651 .65278 L .182 .172 0 r
F
.47059 .65195 m .46967 .65205 L .46971 .65208 L .123 .161 0 r
F
.47084 .65188 m .46967 .65205 L .47059 .65195 L F
.47574 .65108 m .46971 .65208 L .46976 .65207 L .17 .17 0 r
F
.47606 .65112 m .47084 .65188 L .47059 .65195 L .123 .161 0 r
F
.47638 .65111 m .4767 .65105 L .4712 .65176 L 0 0 0 r
F
.47574 .65108 m .47606 .65112 L .46971 .65208 L .17 .17 0 r
F
.4767 .65105 m .47122 .65163 L .47122 .65163 L 0 0 0 r
F
.47758 .6506 m .47742 .6444 L .47127 .65156 L .994 .647 0 r
F
.47702 .65094 m .47733 .65077 L .47124 .65145 L .014 0 0 r
F
.47126 .65151 m .47124 .65145 L .47124 .65145 L .994 .647 0 r
F
.47702 .65094 m .47124 .65145 L .47125 .65148 L .014 0 0 r
F
.47702 .65094 m .47125 .65148 L .47128 .65162 L F
.47542 .65099 m .46976 .65207 L .4698 .65202 L .218 .178 0 r
F
.47638 .65111 m .4712 .65176 L .4712 .65176 L 0 0 0 r
F
.47542 .65099 m .47574 .65108 L .46976 .65207 L .218 .178 0 r
F
.47733 .65077 m .47758 .6506 L .4712 .65127 L .057 0 0 r
F
.47127 .65156 m .47155 .65123 L .4712 .65127 L .994 .647 0 r
F
.47122 .65135 m .47121 .65129 L .47123 .6514 L F
.47122 .65135 m .47123 .6514 L .47126 .65151 L F
.47121 .65129 m .4712 .65129 L .47121 .6513 L F
.47121 .65129 m .47121 .6513 L .47126 .65151 L F
.47733 .65077 m .4712 .65127 L .47124 .65145 L .057 0 0 r
F
.47509 .65084 m .4698 .65202 L .46984 .65191 L .265 .186 0 r
F
.47509 .65084 m .47542 .65099 L .4698 .65202 L F
.47571 .68005 m .4761 .68023 L .46947 .68588 L .665 .262 0 r
F
.47125 .65147 m .47125 .65147 L .47124 .65144 L .88 .141 0 r
F
.47125 .65148 m .47118 .65149 L .47128 .65162 L .014 0 0 r
F
.47125 .65148 m .47117 .65146 L .47118 .65149 L F
.47476 .65065 m .46984 .65191 L .46989 .65177 L .313 .193 0 r
F
.47476 .65065 m .47509 .65084 L .46984 .65191 L F
.47571 .68005 m .46947 .68588 L .46952 .686 L .665 .262 0 r
F
.46989 .65177 m .46454 .65289 L .46496 .65281 L .227 .179 0 r
F
.46993 .65158 m .46989 .65177 L .46496 .65281 L .272 .187 0 r
F
.47155 .65123 m .47742 .6444 L .4712 .65127 L .994 .647 0 r
F
.47443 .65042 m .46989 .65177 L .46993 .65158 L .362 .2 0 r
F
.47124 .65142 m .47123 .65141 L .47123 .65141 L .994 .647 0 r
F
.47124 .65145 m .47123 .65142 L .47124 .65142 L F
.47124 .65145 m .47123 .65142 L .47124 .65145 L F
.47443 .65042 m .47476 .65065 L .46989 .65177 L .362 .2 0 r
F
.47533 .67982 m .47571 .68005 L .46952 .686 L .711 .321 0 r
F
.46993 .65158 m .46496 .65281 L .46538 .6527 L .272 .187 0 r
F
.47533 .67982 m .46952 .686 L .46957 .68612 L .711 .321 0 r
F
.4741 .65013 m .47443 .65042 L .46993 .65158 L .41 .218 0 r
F
.46998 .65135 m .46993 .65158 L .46538 .6527 L .318 .194 0 r
F
.4741 .65013 m .46993 .65158 L .46998 .65135 L .41 .218 0 r
F
.46998 .65135 m .46538 .6527 L .4658 .65255 L .318 .194 0 r
F
.47494 .67956 m .47533 .67982 L .46957 .68612 L .754 .366 0 r
F
.47494 .67956 m .46957 .68612 L .46962 .68624 L F
.47377 .6498 m .4741 .65013 L .46998 .65135 L .46 .304 0 r
F
.47002 .65109 m .46998 .65135 L .4658 .65255 L .363 .2 0 r
F
.47377 .6498 m .46998 .65135 L .47002 .65109 L .46 .304 0 r
F
.47002 .65109 m .4658 .65255 L .46623 .65239 L .363 .2 0 r
F
.47455 .67927 m .47494 .67956 L .46962 .68624 L .79 .39 0 r
F
.47455 .67927 m .46962 .68624 L .46967 .6864 L F
.47343 .64944 m .47377 .6498 L .47002 .65109 L .511 .393 0 r
F
.47007 .6508 m .47002 .65109 L .46623 .65239 L .409 .206 0 r
F
.47343 .64944 m .47002 .65109 L .47007 .6508 L .511 .393 0 r
F
.47007 .6508 m .46623 .65239 L .46666 .65221 L .409 .206 0 r
F
.47416 .67897 m .47455 .67927 L .46967 .6864 L .822 .393 0 r
F
.47416 .67897 m .46967 .6864 L .46973 .68661 L F
.47309 .64903 m .47343 .64944 L .47007 .6508 L .565 .479 0 r
F
.47012 .65048 m .47007 .6508 L .46666 .65221 L .455 .212 0 r
F
.47309 .64903 m .47007 .6508 L .47012 .65048 L .565 .479 0 r
F
.47377 .67866 m .47416 .67897 L .46973 .68661 L .846 .372 0 r
F
.47276 .64859 m .47309 .64903 L .47012 .65048 L .621 .556 0 r
F
.47276 .64859 m .47012 .65048 L .47016 .65016 L F
.47377 .67866 m .46973 .68661 L .46978 .68693 L .846 .372 0 r
F
.47338 .67838 m .47377 .67866 L .46978 .68693 L .863 .329 0 r
F
.47242 .64813 m .47276 .64859 L .47016 .65016 L .682 .617 0 r
F
.47242 .64813 m .47016 .65016 L .47021 .64985 L F
.47338 .67838 m .46978 .68693 L .46983 .68741 L .863 .329 0 r
F
.47208 .64766 m .47242 .64813 L .47021 .64985 L .765 .644 0 r
F
.47208 .64766 m .47021 .64985 L .47026 .6496 L F
.46913 .72947 m .47035 .64964 L .46926 .65328 L .993 .526 0 r
F
.48112 .86517 m .48182 .86427 L .46745 .87505 L 0 0 0 r
F
.48112 .86517 m .46745 .87505 L .46753 .87614 L F
.48041 .86597 m .48112 .86517 L .46753 .87614 L F
.48041 .86597 m .46753 .87614 L .46762 .87715 L F
.47969 .86667 m .48041 .86597 L .46762 .87715 L F
.47969 .86667 m .46762 .87715 L .46771 .87807 L F
.47897 .86729 m .47969 .86667 L .46771 .87807 L .504 .199 0 r
F
.47897 .86729 m .46771 .87807 L .46781 .87892 L F
.47824 .86783 m .47897 .86729 L .46781 .87892 L .557 .205 0 r
F
.47824 .86783 m .46781 .87892 L .4679 .87971 L F
.4775 .86832 m .47824 .86783 L .4679 .87971 L .606 .209 0 r
F
.4775 .86832 m .4679 .87971 L .46799 .88046 L F
.47675 .86877 m .4775 .86832 L .47061 .87711 L .649 .211 0 r
F
.47065 .87691 m .47061 .87711 L .46799 .88046 L F
.47675 .86877 m .47061 .87711 L .47065 .87691 L F
.47831 .64364 m .46944 .6436 L .46948 .64396 L .22 0 0 r
F
.47801 .64394 m .46948 .64396 L .46951 .64426 L .186 0 0 r
F
.47801 .64394 m .47831 .64364 L .46948 .64396 L F
.47772 .64419 m .46951 .64426 L .46955 .64452 L .151 0 0 r
F
.47772 .64419 m .47801 .64394 L .46951 .64426 L F
.47742 .6444 m .46955 .64452 L .46959 .64473 L .114 0 0 r
F
.47742 .6444 m .47772 .64419 L .46955 .64452 L F
.47881 .6492 m .47476 .65065 L .47443 .65042 L .43 .307 0 r
F
.47811 .64888 m .47443 .65042 L .4741 .65013 L .477 .413 0 r
F
.47811 .64888 m .47881 .6492 L .47443 .65042 L F
.4774 .64852 m .4741 .65013 L .47377 .6498 L .524 .521 0 r
F
.4774 .64852 m .47811 .64888 L .4741 .65013 L F
.47908 .67343 m .47494 .67956 L .47455 .67927 L 1 .976 0 r
F
.47669 .6481 m .47377 .6498 L .47343 .64944 L .572 .629 0 r
F
.47669 .6481 m .4774 .64852 L .47377 .6498 L F
.47826 .67282 m .47908 .67343 L .47455 .67927 L 1 .998 0 r
F
.47826 .67282 m .47455 .67927 L .47416 .67897 L F
.47598 .64764 m .47343 .64944 L .47309 .64903 L .631 .734 0 r
F
.47598 .64764 m .47669 .6481 L .47343 .64944 L F
.47745 .67216 m .47826 .67282 L .47416 .67897 L 1 1 0 r
F
.47745 .67216 m .47416 .67897 L .47377 .67866 L F
.47527 .64713 m .47309 .64903 L .47276 .64859 L .729 .836 0 r
F
.47527 .64713 m .47598 .64764 L .47309 .64903 L F
.47663 .67146 m .47745 .67216 L .47377 .67866 L 1 .988 0 r
F
.47663 .67146 m .47377 .67866 L .47338 .67838 L F
.47455 .64657 m .47276 .64859 L .47242 .64813 L .838 .932 0 r
F
.47455 .64657 m .47527 .64713 L .47276 .64859 L F
.47581 .67071 m .47663 .67146 L .47338 .67838 L 1 .956 0 r
F
.47383 .64597 m .47455 .64657 L .47242 .64813 L .957 1 0 r
F
.4755 .64445 m .47455 .64657 L .47383 .64597 L 1 1 0 r
F
.47383 .64597 m .47242 .64813 L .47208 .64766 L .957 1 0 r
F
.47581 .67071 m .47338 .67838 L .47298 .67816 L 1 .956 0 r
F
.47499 .66992 m .47581 .67071 L .47298 .67816 L 1 .908 0 r
F
.47311 .64531 m .47383 .64597 L .47208 .64766 L 1 1 0 r
F
.47442 .64367 m .47383 .64597 L .47311 .64531 L F
.47442 .64367 m .4755 .64445 L .47383 .64597 L F
.47499 .66992 m .47298 .67816 L .47259 .67805 L 1 .908 0 r
F
.47416 .66909 m .47499 .66992 L .47259 .67805 L 1 .847 0 r
F
.47595 .66259 m .47499 .66992 L .47416 .66909 L 1 1 0 r
F
.47416 .66909 m .47259 .67805 L .47219 .67814 L 1 .847 0 r
F
.47436 .66627 m .47595 .66259 L .47416 .66909 L 1 1 0 r
F
.47473 .66109 m .475 .66142 L .47436 .66627 L F
.475 .66142 m .47595 .66259 L .47436 .66627 L F
.48231 .67528 m .47648 .68037 L .4761 .68023 L .753 .713 0 r
F
.48151 .67491 m .4761 .68023 L .47571 .68005 L .837 .803 0 r
F
.48151 .67491 m .48231 .67528 L .4761 .68023 L F
.4807 .67448 m .47571 .68005 L .47533 .67982 L .916 .878 0 r
F
.4807 .67448 m .48151 .67491 L .47571 .68005 L F
.47989 .67398 m .47533 .67982 L .47494 .67956 L .989 .936 0 r
F
.47989 .67398 m .4807 .67448 L .47533 .67982 L F
.47908 .67343 m .47989 .67398 L .47494 .67956 L 1 .976 0 r
F
.47839 .66497 m .47663 .67146 L .47581 .67071 L 1 1 0 r
F
.47717 .66385 m .47839 .66497 L .47581 .67071 L F
.47717 .66385 m .47581 .67071 L .47499 .66992 L F
.47595 .66259 m .47717 .66385 L .47499 .66992 L F
.476 .65595 m .47595 .66259 L .47473 .66109 L F
.47336 .66431 m .47442 .64367 L .47311 .64531 L .824 .369 0 r
F
.47334 .66821 m .47416 .66909 L .47219 .67814 L 1 .775 0 r
F
.47473 .66109 m .47416 .66909 L .47344 .66832 L 1 1 0 r
F
.47386 .66552 m .47344 .66832 L .47334 .66821 L F
.47473 .66109 m .47344 .66832 L .47386 .66552 L F
.47449 .66037 m .47442 .64367 L .47336 .66431 L .824 .369 0 r
F
.47173 .64721 m .47208 .64766 L .47026 .6496 L .841 .608 0 r
F
.47311 .64531 m .47208 .64766 L .47173 .64721 L 1 1 0 r
F
.47338 .66606 m .4745 .66073 L .47334 .66821 L 1 .989 0 r
F
.4745 .66073 m .47386 .66552 L .47334 .66821 L F
.47515 .80107 m .47338 .66633 L .47354 .84844 L .824 .369 0 r
F
.47338 .66606 m .47338 .66635 L .47325 .66721 L 1 .989 0 r
F
.47338 .66606 m .47311 .64531 L .47316 .668 L .824 .369 0 r
F
.47338 .66606 m .47325 .66721 L .47314 .66797 L 1 .989 0 r
F
.47338 .66635 m .47316 .668 L .47314 .66797 L F
.47338 .66633 m .47338 .66606 L .47316 .668 L .824 .369 0 r
F
.47185 .67754 m .47207 .67618 L .47179 .67862 L 1 .696 0 r
F
.47207 .67618 m .47334 .66821 L .47211 .67648 L F
.47207 .67618 m .47211 .67648 L .47179 .67862 L F
.47173 .64721 m .47026 .6496 L .4703 .64946 L .841 .608 0 r
F
.47139 .64683 m .47173 .64721 L .4703 .64946 L .872 .467 0 r
F
.47167 .67275 m .47173 .64721 L .47139 .64683 L .896 .44 0 r
F
.47199 .67547 m .47255 .67245 L .47185 .67754 L 1 .696 0 r
F
.47255 .67245 m .47334 .66821 L .47185 .67754 L F
.47328 .82424 m .47279 .76536 L .47273 .77309 L .896 .44 0 r
F
.47354 .84844 m .47332 .82397 L .47328 .82424 L F
.47332 .82397 m .47279 .76536 L .47328 .82424 L F
.47316 .668 m .47334 .66821 L .47199 .67547 L 1 .696 0 r
F
.47338 .66635 m .47334 .66821 L .47316 .668 L 1 .989 0 r
F
.47298 .67816 m .47338 .67838 L .46983 .68741 L .873 .267 0 r
F
.47334 .66821 m .47219 .67814 L .47179 .67862 L 1 .775 0 r
F
.47338 .66633 m .47316 .668 L .47354 .84844 L .824 .369 0 r
F
.47298 .67816 m .46983 .68741 L .46987 .68817 L .873 .267 0 r
F
.47259 .67805 m .47298 .67816 L .46987 .68817 L .874 .207 0 r
F
.47259 .67805 m .46987 .68817 L .46992 .68939 L F
.47219 .67814 m .47259 .67805 L .46992 .68939 L .868 .197 0 r
F
.47219 .67814 m .46992 .68939 L .46996 .69138 L F
.47179 .67862 m .47219 .67814 L .46996 .69138 L .856 .187 0 r
F
.47354 .84844 m .47316 .668 L .472 .67674 L .896 .44 0 r
F
.47146 .68153 m .46996 .69138 L .46999 .69488 L .856 .187 0 r
F
.47179 .67862 m .47158 .68008 L .47146 .68153 L F
.47158 .68008 m .46996 .69138 L .47146 .68153 L F
.47138 .67994 m .47179 .67862 L .46999 .69488 L .835 .176 0 r
F
.47138 .67994 m .46999 .69488 L .47001 .70181 L F
.47037 .6948 m .47139 .64683 L .47035 .64964 L .941 .475 0 r
F
.47061 .69123 m .47138 .67994 L .47046 .69451 L .803 .164 0 r
F
.47064 .69064 m .47076 .68891 L .47061 .69123 L F
.47076 .68891 m .47138 .67994 L .47061 .69123 L F
.4717 .67629 m .47179 .67862 L .47138 .67994 L 1 .696 0 r
F
.47191 .84758 m .47354 .84844 L .4717 .67629 L 1 .465 0 r
F
.4717 .67629 m .47199 .67547 L .47167 .67275 L .896 .44 0 r
F
.47199 .67547 m .47179 .67862 L .4717 .67629 L 1 .696 0 r
F
.47273 .77309 m .47199 .67547 L .4717 .67629 L .896 .44 0 r
F
.47199 .67547 m .47173 .64721 L .47167 .67275 L F
.47199 .67547 m .47311 .64531 L .47173 .64721 L F
.47206 .67501 m .47311 .64531 L .47199 .67547 L F
.47316 .668 m .47311 .64531 L .472 .67674 L F
.47213 .67327 m .47199 .67547 L .4717 .67629 L 1 .696 0 r
F
.47169 .66716 m .47251 .66726 L .4717 .67629 L 1 .615 0 r
F
.47175 .66632 m .47251 .66726 L .47169 .66716 L F
.47146 .676 m .4717 .67629 L .47138 .67994 L F
.47191 .84758 m .4717 .67629 L .47147 .67794 L 1 .465 0 r
F
.47251 .66726 m .47213 .67327 L .4717 .67629 L 1 .696 0 r
F
.47675 .86877 m .46799 .88046 L .46809 .88118 L .649 .211 0 r
F
.476 .86922 m .47675 .86877 L .46809 .88118 L .686 .212 0 r
F
.476 .86922 m .46809 .88118 L .46819 .88192 L F
.47524 .8697 m .476 .86922 L .46819 .88192 L .717 .211 0 r
F
.47524 .8697 m .46819 .88192 L .46828 .8827 L F
.47447 .87025 m .47524 .8697 L .46828 .8827 L .742 .208 0 r
F
.47447 .87025 m .46828 .8827 L .46838 .88357 L F
.47369 .87094 m .47447 .87025 L .46838 .88357 L .761 .204 0 r
F
.47369 .87094 m .46838 .88357 L .46848 .88461 L F
.4729 .87186 m .47369 .87094 L .46848 .88461 L .774 .199 0 r
F
.4729 .87186 m .46848 .88461 L .46858 .88592 L F
.47191 .84758 m .47147 .67757 L .47046 .87901 L 1 .465 0 r
F
.47279 .76536 m .47199 .67547 L .47273 .77309 L .896 .44 0 r
F
.47251 .66726 m .47316 .668 L .47199 .67547 L 1 .696 0 r
F
.47231 .65663 m .47251 .66726 L .47169 .66624 L 1 .928 0 r
F
.47125 .68101 m .47138 .67994 L .47064 .69064 L .803 .164 0 r
F
.47147 .67757 m .47125 .68101 L .47046 .87901 L 1 .465 0 r
F
.47022 .69759 m .47046 .69451 L .47001 .70181 L .803 .164 0 r
F
.47125 .68101 m .47135 .65775 L .47037 .6948 L .941 .475 0 r
F
.47135 .65775 m .47139 .64683 L .47037 .6948 L F
.47053 .69235 m .47046 .69451 L .47035 .69596 L .803 .164 0 r
F
.47095 .68366 m .47035 .69596 L .47022 .69759 L F
.47211 .87317 m .4729 .87186 L .46858 .88592 L .779 .191 0 r
F
.47211 .87317 m .46858 .88592 L .46867 .88768 L F
.47129 .87522 m .47211 .87317 L .46867 .88768 L .775 .182 0 r
F
.47129 .87522 m .46867 .88768 L .46877 .89025 L F
.48081 .91917 m .46721 .92015 L .46731 .92041 L 0 0 0 r
F
.48081 .91917 m .48164 .91896 L .46721 .92015 L F
.47998 .91926 m .46731 .92041 L .46742 .92054 L F
.47998 .91926 m .48081 .91917 L .47243 .91994 L F
.47272 .91992 m .47243 .91994 L .46731 .92041 L F
.47998 .91926 m .47243 .91994 L .47272 .91992 L F
.47914 .91921 m .47998 .91926 L .46742 .92054 L .108 .159 0 r
F
.47379 .91983 m .46742 .92054 L .46753 .92056 L F
.47914 .91921 m .47346 .91986 L .47379 .91983 L F
.47346 .91986 m .46742 .92054 L .47379 .91983 L F
.47829 .91904 m .46753 .92056 L .46765 .92045 L .155 .167 0 r
F
.47829 .91904 m .47914 .91921 L .46753 .92056 L F
.47743 .91874 m .46765 .92045 L .46776 .92022 L .202 .175 0 r
F
.47743 .91874 m .47829 .91904 L .46765 .92045 L F
.47657 .91832 m .46776 .92022 L .46788 .91987 L .252 .183 0 r
F
.47657 .91832 m .47743 .91874 L .46776 .92022 L F
.4757 .91778 m .47657 .91832 L .46788 .91987 L .303 .191 0 r
F
.4757 .91778 m .46788 .91987 L .46799 .91941 L F
.47483 .91713 m .4757 .91778 L .46799 .91941 L .356 .199 0 r
F
.47483 .91713 m .46799 .91941 L .46811 .91886 L F
.47395 .91637 m .47483 .91713 L .46811 .91886 L .414 .224 0 r
F
.47395 .91637 m .46811 .91886 L .46823 .91821 L F
.47307 .91551 m .47395 .91637 L .46823 .91821 L .478 .313 0 r
F
.47307 .91551 m .46823 .91821 L .46835 .91751 L F
.47217 .9146 m .47307 .91551 L .46835 .91751 L .552 .4 0 r
F
.47217 .9146 m .46835 .91751 L .46848 .91678 L F
.47128 .91369 m .4718 .91422 L .46848 .91678 L .639 .461 0 r
F
.4718 .91422 m .47217 .9146 L .4717 .91488 L F
.4718 .91422 m .4717 .91488 L .46848 .91678 L F
.47969 .85127 m .47524 .8697 L .47447 .87025 L 1 .71 0 r
F
.47992 .85045 m .4797 .85136 L .47969 .85127 L F
.4797 .85136 m .47524 .8697 L .47969 .85127 L F
.49063 .85136 m .48041 .86597 L .47969 .86667 L .803 .472 0 r
F
.48914 .8515 m .47969 .86667 L .47897 .86729 L .875 .563 0 r
F
.48914 .8515 m .49063 .85136 L .47969 .86667 L F
.48763 .85152 m .48914 .8515 L .47897 .86729 L .946 .634 0 r
F
.48763 .85152 m .47897 .86729 L .47824 .86783 L F
.48611 .85145 m .48763 .85152 L .47824 .86783 L 1 .683 0 r
F
.48611 .85145 m .47824 .86783 L .4775 .86832 L F
.48458 .85128 m .48611 .85145 L .4775 .86832 L 1 .713 0 r
F
.48458 .85128 m .4775 .86832 L .47675 .86877 L F
.47213 .68425 m .4723 .65928 L .47212 .68448 L .535 .09 0 r
F
.47128 .91369 m .46848 .91678 L .4686 .91612 L .639 .461 0 r
F
.46998 .91365 m .47128 .91369 L .4686 .91612 L .731 .419 0 r
F
.47052 .91306 m .47052 .91271 L .46998 .91365 L .37 .051 0 r
F
.47052 .91271 m .47129 .87522 L .46998 .91365 L F
.46998 .91365 m .47129 .87522 L .46877 .89025 L F
.46998 .91365 m .4686 .91612 L .46867 .9159 L .731 .419 0 r
F
.47036 .92092 m .46998 .91365 L .46868 .92206 L .37 .051 0 r
F
.46819 .88192 m .46809 .88118 L .459 .89001 L 0 0 0 r
F
.46819 .88192 m .459 .89001 L .45999 .89085 L F
.46912 .7296 m .46815 .74108 L .46829 .77126 L F
.46763 .79005 m .46815 .74108 L .46681 .76978 L .14 .012 0 r
F
.46776 .7975 m .46803 .77868 L .46784 .78418 L 1 .569 0 r
F
.46828 .8827 m .46819 .88192 L .46524 .88513 L 0 0 0 r
F
.4652 .88573 m .46524 .88513 L .45999 .89085 L F
.46828 .8827 m .46524 .88513 L .4652 .88573 L F
.46513 .91833 m .46516 .91853 L .46361 .91903 L .389 .204 0 r
F
.46479 .76277 m .464 .74238 L .45975 .78282 L .31 .042 0 r
F
.46517 .88655 m .45999 .89085 L .46098 .89173 L 0 0 0 r
F
.46828 .8827 m .4652 .88573 L .46517 .88655 L F
.4652 .88573 m .45999 .89085 L .46517 .88655 L F
.46637 .70212 m .46138 .71626 L .46228 .72186 L F
.46685 .70584 m .46637 .70212 L .46228 .72186 L F
.46685 .70584 m .46228 .72186 L .46316 .72996 L F
.46732 .71163 m .46685 .70584 L .46316 .72996 L .007 0 0 r
F
.46663 .71314 m .46559 .67563 L .464 .69239 L .782 .297 0 r
F
.46732 .71163 m .46316 .72996 L .464 .74238 L .007 0 0 r
F
.46777 .72152 m .46732 .71163 L .464 .74238 L .037 0 0 r
F
.46777 .72152 m .464 .74238 L .46479 .76277 L F
.46815 .74108 m .46777 .72152 L .46582 .74845 L .081 0 0 r
F
.46628 .75314 m .46582 .74845 L .46479 .76277 L F
.46815 .74108 m .46582 .74845 L .46628 .75314 L F
.46829 .77126 m .46815 .74108 L .46777 .77666 L .14 .012 0 r
F
.46784 .78418 m .46777 .77666 L .46763 .79005 L F
.46829 .77126 m .46777 .77666 L .46784 .78418 L F
.46838 .88357 m .46828 .8827 L .46517 .88655 L 0 0 0 r
F
.46513 .88716 m .46517 .88655 L .46098 .89173 L F
.46838 .88357 m .46517 .88655 L .46513 .88716 L F
.46199 .8927 m .46098 .89173 L .4536 .8981 L F
.46199 .8927 m .4536 .8981 L .45553 .89907 L F
.46301 .89381 m .46199 .8927 L .45553 .89907 L F
.46301 .89381 m .45553 .89907 L .45749 .90016 L F
.46404 .89516 m .46301 .89381 L .45749 .90016 L F
.46404 .89516 m .45749 .90016 L .45947 .90146 L F
.46508 .89692 m .46404 .89516 L .45947 .90146 L F
.46456 .87796 m .46254 .84376 L .45973 .87059 L .507 .069 0 r
F
.46147 .9031 m .45947 .90146 L .45499 .90587 L .181 0 0 r
F
.46508 .89692 m .45947 .90146 L .46147 .9031 L 0 0 0 r
F
.46147 .9031 m .45499 .90587 L .45794 .90739 L .181 0 0 r
F
.46838 .88357 m .46098 .89173 L .46199 .8927 L 0 0 0 r
F
.46848 .88461 m .46838 .88357 L .46199 .8927 L F
.46848 .88461 m .46199 .8927 L .46301 .89381 L F
.4629 .89291 m .45973 .87059 L .4572 .88567 L .666 .147 0 r
F
.46456 .87796 m .45973 .87059 L .4629 .89291 L .507 .069 0 r
F
.4635 .90535 m .46147 .9031 L .45794 .90739 L .21 0 0 r
F
.4635 .90535 m .45794 .90739 L .46093 .90943 L F
.4614 .90137 m .4572 .88567 L .45496 .89474 L .791 .223 0 r
F
.4629 .89291 m .4572 .88567 L .4614 .90137 L .666 .147 0 r
F
.4614 .90137 m .45496 .89474 L .46007 .90663 L .791 .223 0 r
F
.46007 .90663 m .45906 .9043 L .46025 .86054 L .486 .071 0 r
F
.45906 .9043 m .45496 .89474 L .46025 .86054 L F
.46479 .76277 m .45975 .78282 L .46102 .81014 L .31 .042 0 r
F
.46025 .86054 m .45496 .89474 L .46046 .74571 L .486 .071 0 r
F
.46025 .86054 m .46046 .74571 L .46065 .76107 L F
.46552 .79728 m .46479 .76277 L .46102 .81014 L .332 .048 0 r
F
.46168 .80713 m .4619 .72048 L .46075 .73785 L .937 .462 0 r
F
.46552 .79728 m .46102 .81014 L .46254 .84376 L .332 .048 0 r
F
.46203 .83315 m .46199 .79682 L .46168 .80713 L .937 .462 0 r
F
.46199 .79682 m .4619 .72048 L .46168 .80713 L F
.46203 .83315 m .4617 .80814 L .46139 .81829 L F
.4617 .80814 m .46075 .73785 L .46139 .81829 L F
.46119 .83142 m .46075 .73785 L .46139 .81829 L .486 .071 0 r
F
.46007 .90663 m .4603 .85014 L .46082 .85609 L F
.46082 .85609 m .46043 .81768 L .46119 .83142 L F
.4603 .85014 m .46043 .81768 L .46082 .85609 L F
.46043 .81768 m .46075 .73785 L .46119 .83142 L F
.46093 .90943 m .45794 .90739 L .45456 .91043 L .331 0 0 r
F
.46093 .90943 m .45456 .91043 L .45847 .9123 L F
.46007 .90663 m .46098 .84565 L .45891 .91013 L .486 .071 0 r
F
.46098 .84565 m .46139 .81829 L .46048 .85183 L F
.46098 .84565 m .46048 .85183 L .45891 .91013 L F
.46118 .79209 m .46075 .73785 L .46137 .78222 L F
.46065 .76107 m .46046 .74571 L .46075 .73785 L F
.45496 .89474 m .45989 .71196 L .46075 .73785 L 1 .85 0 r
F
.46139 .81829 m .46075 .73785 L .45902 .7639 L .937 .462 0 r
F
.46139 .81829 m .46 .85339 L .45946 .88125 L .486 .071 0 r
F
.46139 .81829 m .45946 .88125 L .45891 .91013 L F
.46166 .83992 m .46113 .8247 L .46015 .86747 L .937 .462 0 r
F
.46112 .82422 m .45902 .7639 L .46 .85339 L F
.46139 .81829 m .46136 .81777 L .46166 .83992 L F
.46136 .81777 m .45902 .7639 L .46112 .82422 L F
.46136 .81777 m .46112 .82422 L .46166 .83992 L F
.45946 .88125 m .45989 .85921 L .45928 .88735 L 1 .846 0 r
F
.45989 .85921 m .45987 .85941 L .45928 .88735 L F
.46 .85339 m .45902 .7639 L .4597 .86166 L .974 .494 0 r
F
.46 .85339 m .45988 .85636 L .45988 .85677 L 1 .846 0 r
F
.46 .85339 m .45988 .85677 L .45928 .88735 L F
.4597 .86166 m .45902 .7639 L .45579 .81145 L .974 .494 0 r
F
.45989 .85921 m .46 .85339 L .45987 .85941 L 1 .846 0 r
F
.45928 .88735 m .45988 .85636 L .45971 .8608 L F
.46848 .91678 m .46835 .91751 L .46648 .91811 L .389 .204 0 r
F
.46666 .91774 m .46648 .91811 L .46516 .91853 L F
.46848 .91678 m .46648 .91811 L .46666 .91774 L F
.46848 .91678 m .46516 .91853 L .46513 .91833 L F
.46848 .91678 m .46466 .91855 L .46475 .91845 L F
.46466 .91855 m .46361 .91903 L .46475 .91845 L F
.46475 .91845 m .46361 .91903 L .45893 .92017 L .249 .182 0 r
F
.46475 .91845 m .45893 .92017 L .46108 .91972 L F
.46484 .91836 m .46475 .91845 L .46108 .91972 L .252 .18 0 r
F
.46806 .91645 m .46848 .91678 L .46475 .91845 L .435 .208 0 r
F
.4686 .91612 m .46851 .91661 L .46806 .91645 L F
.46851 .91661 m .46848 .91678 L .46806 .91645 L F
.46599 .9179 m .4659 .91797 L .46601 .91796 L .459 .203 0 r
F
.46599 .9179 m .46601 .91796 L .46682 .91789 L F
.46803 .91631 m .46877 .89025 L .46614 .89939 L .57 .07 0 r
F
.46835 .91751 m .46823 .91821 L .46248 .91962 L .342 .197 0 r
F
.46835 .91751 m .46248 .91962 L .46361 .91903 L F
.4686 .91612 m .46475 .91845 L .4659 .91797 L .435 .208 0 r
F
.46803 .91631 m .4686 .91612 L .4659 .91797 L .459 .203 0 r
F
.4687 .91584 m .4687 .91554 L .46803 .91631 L .57 .07 0 r
F
.46872 .91577 m .4687 .91584 L .46803 .91631 L .459 .203 0 r
F
.4687 .91584 m .4686 .91612 L .46803 .91631 L F
.46868 .92206 m .4687 .91584 L .46803 .91631 L .57 .07 0 r
F
.4687 .91554 m .46877 .89025 L .46803 .91631 L F
.46803 .91631 m .46599 .9179 L .46666 .91789 L .459 .203 0 r
F
.46803 .91631 m .46666 .91789 L .46682 .91789 L F
.46776 .92022 m .46765 .92045 L .45697 .92138 L .124 .162 0 r
F
.46776 .92022 m .45697 .92138 L .45805 .92123 L F
.46788 .91987 m .46776 .92022 L .45805 .92123 L .166 .169 0 r
F
.46788 .91987 m .45805 .92123 L .45914 .92097 L F
.46799 .91941 m .46788 .91987 L .45914 .92097 L .209 .176 0 r
F
.46799 .91941 m .45914 .92097 L .46025 .92061 L F
.46811 .91886 m .46799 .91941 L .46025 .92061 L .253 .184 0 r
F
.46811 .91886 m .46025 .92061 L .46136 .92015 L F
.46823 .91821 m .46811 .91886 L .46136 .92015 L .297 .19 0 r
F
.46823 .91821 m .46136 .92015 L .46248 .91962 L F
.46868 .92206 m .46813 .9172 L .467 .92296 L .57 .07 0 r
F
.46813 .9172 m .46614 .89939 L .46682 .91789 L F
.46813 .9172 m .46682 .91789 L .467 .92296 L F
.46622 .91818 m .4659 .91797 L .46607 .91826 L 0 0 0 r
F
.467 .92296 m .46682 .91789 L .46615 .91869 L .719 .15 0 r
F
.46819 .9221 m .46868 .92206 L .467 .92296 L .412 .202 0 r
F
.46822 .92208 m .46872 .91577 L .46705 .91787 L .372 .02 0 r
F
.46822 .92208 m .46877 .92179 L .46819 .9221 L .412 .202 0 r
F
.46877 .92177 m .46877 .92179 L .46822 .92208 L F
.46877 .92179 m .46868 .92206 L .46819 .9221 L F
.46879 .92415 m .46877 .92177 L .46822 .92208 L .372 .02 0 r
F
.46998 .91365 m .46867 .9159 L .4687 .91584 L .731 .419 0 r
F
.46998 .91365 m .4687 .91584 L .46868 .92206 L .37 .051 0 r
F
.46877 .92177 m .46876 .92094 L .46822 .92208 L .372 .02 0 r
F
.4688 .92166 m .46877 .92177 L .46822 .92208 L .412 .202 0 r
F
.47052 .91306 m .47128 .91369 L .46998 .91365 L .731 .419 0 r
F
.47834 .85009 m .47992 .85045 L .47447 .87025 L 1 .689 0 r
F
.47834 .85009 m .47447 .87025 L .47369 .87094 L F
.47675 .84967 m .47834 .85009 L .47369 .87094 L 1 .665 0 r
F
.47675 .84967 m .47369 .87094 L .4729 .87186 L F
.47515 .84913 m .47675 .84967 L .4729 .87186 L 1 .637 0 r
F
.47515 .84913 m .4729 .87186 L .47211 .87317 L F
.47357 .91122 m .47515 .84913 L .47211 .87317 L .382 .057 0 r
F
.47412 .91043 m .47515 .84913 L .47357 .91122 L F
.47284 .90184 m .47211 .87317 L .47129 .87522 L F
.47181 .9075 m .47129 .87522 L .47056 .91107 L 1 .403 0 r
F
.47181 .9075 m .47056 .91107 L .47052 .91306 L F
.47185 .90992 m .47128 .91369 L .47052 .91306 L 1 1 0 r
F
.47144 .91088 m .47052 .91306 L .47036 .92092 L 1 .403 0 r
F
.47181 .9075 m .47052 .91306 L .47144 .91088 L F
.47338 .91109 m .47357 .91122 L .47128 .91369 L .943 .955 0 r
F
.47357 .91122 m .47217 .9146 L .47163 .91405 L F
.47357 .91122 m .47163 .91405 L .47128 .91369 L F
.47338 .91109 m .47304 .90093 L .47284 .90184 L .382 .057 0 r
F
.47357 .91122 m .47211 .87317 L .47338 .91109 L F
.47766 .91296 m .47395 .91637 L .47307 .91551 L .616 .673 0 r
F
.47578 .91178 m .47307 .91551 L .47217 .9146 L .76 .825 0 r
F
.47578 .91178 m .47766 .91296 L .47307 .91551 L F
.47357 .91122 m .47578 .91178 L .47217 .9146 L .943 .955 0 r
F
.47412 .91063 m .47412 .91043 L .47357 .91122 L .382 .057 0 r
F
.47389 .91047 m .47412 .91063 L .47357 .91122 L .943 .955 0 r
F
.47412 .91063 m .47578 .91178 L .47357 .91122 L F
.47953 .91399 m .47483 .91713 L .47395 .91637 L .539 .525 0 r
F
.47766 .91296 m .47953 .91399 L .47395 .91637 L .616 .673 0 r
F
.47395 .92087 m .47412 .91063 L .47357 .91122 L .382 .057 0 r
F
.472 .91947 m .47395 .92087 L .47338 .91109 L 1 .403 0 r
F
.47185 .90992 m .47228 .91026 L .47128 .91369 L 1 1 0 r
F
.47185 .90992 m .47338 .91109 L .47325 .90884 L 1 .403 0 r
F
.47234 .91006 m .47199 .91281 L .47128 .91369 L 1 1 0 r
F
.47185 .90992 m .4715 .91034 L .47036 .92092 L 1 .403 0 r
F
.4715 .91019 m .47185 .90992 L .47038 .91294 L 1 1 0 r
F
.47185 .90992 m .47325 .90884 L .47129 .87522 L 1 .403 0 r
F
.47185 .90992 m .47181 .9075 L .4715 .91034 L F
.47198 .909 m .47185 .90992 L .4715 .91019 L 1 1 0 r
F
.47917 .85779 m .476 .86922 L .47524 .8697 L 1 .723 0 r
F
.48148 .85077 m .47906 .85894 L .47917 .85779 L F
.47906 .85894 m .476 .86922 L .47917 .85779 L F
.49211 .85109 m .48112 .86517 L .48041 .86597 L .759 .362 0 r
F
.49063 .85136 m .49211 .85109 L .48041 .86597 L .803 .472 0 r
F
.48304 .85105 m .48458 .85128 L .47675 .86877 L 1 .725 0 r
F
.48304 .85105 m .47675 .86877 L .476 .86922 L F
.49211 .85109 m .49358 .8507 L .48112 .86517 L .759 .362 0 r
F
.47974 .65009 m .47974 .65009 L .47973 .65006 L 1 .278 0 r
F
.47975 .65012 m .47973 .65005 L .47972 .65005 L .936 .603 0 r
F
.48559 .64947 m .47973 .65006 L .47966 .65011 L .028 0 0 r
F
.48559 .64947 m .47966 .65011 L .47942 .65032 L F
.48821 .64221 m .47917 .64245 L .47889 .64289 L .226 0 0 r
F
.48821 .64221 m .48882 .64176 L .47917 .64245 L F
.48761 .64262 m .47889 .64289 L .4786 .64329 L .195 0 0 r
F
.48761 .64262 m .48821 .64221 L .47889 .64289 L F
.48699 .64298 m .4786 .64329 L .47831 .64364 L .163 0 0 r
F
.48699 .64298 m .48761 .64262 L .4786 .64329 L F
.48637 .64329 m .47831 .64364 L .47801 .64394 L .129 0 0 r
F
.48637 .64329 m .48699 .64298 L .47831 .64364 L F
.48627 .67617 m .47835 .68026 L .47798 .68039 L .475 .214 0 r
F
.48627 .67617 m .48705 .67615 L .47835 .68026 L F
.48361 .64994 m .47702 .65094 L .4767 .65105 L 0 0 0 r
F
.48361 .64994 m .48428 .64984 L .47702 .65094 L F
.48549 .67612 m .47798 .68039 L .47761 .68047 L .53 .252 0 r
F
.48549 .67612 m .48627 .67617 L .47798 .68039 L F
.48294 .64999 m .48361 .64994 L .4767 .65105 L .15 .166 0 r
F
.48294 .64999 m .4767 .65105 L .47638 .65111 L F
.4847 .67601 m .47761 .68047 L .47723 .68049 L .583 .373 0 r
F
.4847 .67601 m .48549 .67612 L .47761 .68047 L F
.48226 .64999 m .47638 .65111 L .47606 .65112 L .197 .174 0 r
F
.48226 .64999 m .48294 .64999 L .47638 .65111 L F
.48391 .67583 m .47723 .68049 L .47686 .68045 L .633 .494 0 r
F
.48391 .67583 m .4847 .67601 L .47723 .68049 L F
.48158 .64994 m .47606 .65112 L .47574 .65108 L .243 .182 0 r
F
.48158 .64994 m .48226 .64999 L .47606 .65112 L F
.48311 .67559 m .47686 .68045 L .47648 .68037 L .68 .609 0 r
F
.48311 .67559 m .48391 .67583 L .47686 .68045 L F
.4796 .65012 m .47973 .65006 L .47772 .64419 L 1 .278 0 r
F
.47966 .65011 m .47973 .65006 L .4796 .65012 L .028 0 0 r
F
.48089 .64983 m .47574 .65108 L .47542 .65099 L .29 .189 0 r
F
.4785 .65061 m .47781 .65057 L .47733 .65077 L 0 0 0 r
F
.47781 .65057 m .47758 .6506 L .47733 .65077 L F
.48089 .64983 m .48158 .64994 L .47574 .65108 L .29 .189 0 r
F
.48231 .67528 m .48311 .67559 L .47648 .68037 L .753 .713 0 r
F
.47972 .65005 m .47801 .64394 L .47772 .64419 L .936 .603 0 r
F
.47973 .65005 m .47801 .64394 L .47972 .65005 L F
.4802 .64967 m .47542 .65099 L .47509 .65084 L .337 .196 0 r
F
.4802 .64967 m .48089 .64983 L .47542 .65099 L F
.47951 .64946 m .4802 .64967 L .47509 .65084 L .384 .209 0 r
F
.48406 .64817 m .4802 .64967 L .47951 .64946 L .44 .355 0 r
F
.48301 .64791 m .47951 .64946 L .47881 .6492 L .482 .464 0 r
F
.48301 .64791 m .48406 .64817 L .47951 .64946 L F
.48195 .64758 m .47881 .6492 L .47811 .64888 L .523 .572 0 r
F
.48195 .64758 m .48301 .64791 L .47881 .6492 L F
.48448 .66921 m .4807 .67448 L .47989 .67398 L 1 1 0 r
F
.48089 .64721 m .47811 .64888 L .4774 .64852 L .565 .678 0 r
F
.48089 .64721 m .48195 .64758 L .47811 .64888 L F
.48326 .66851 m .47989 .67398 L .47908 .67343 L 1 1 0 r
F
.48326 .66851 m .48448 .66921 L .47989 .67398 L F
.47982 .64678 m .4774 .64852 L .47669 .6481 L .626 .781 0 r
F
.47982 .64678 m .48089 .64721 L .4774 .64852 L F
.48275 .64544 m .48089 .64721 L .47982 .64678 L .681 .873 0 r
F
.48205 .66774 m .47908 .67343 L .47826 .67282 L 1 1 0 r
F
.48205 .66774 m .48326 .66851 L .47908 .67343 L F
.47874 .64629 m .47982 .64678 L .47669 .6481 L .713 .881 0 r
F
.48134 .64496 m .47982 .64678 L .47874 .64629 L .759 .958 0 r
F
.48134 .64496 m .48275 .64544 L .47982 .64678 L F
.48083 .6669 m .47826 .67282 L .47745 .67216 L 1 1 0 r
F
.48083 .6669 m .48205 .66774 L .47826 .67282 L F
.47992 .64442 m .47874 .64629 L .47767 .64575 L .843 1 0 r
F
.47992 .64442 m .48134 .64496 L .47874 .64629 L F
.47961 .66598 m .48083 .6669 L .47745 .67216 L 1 1 0 r
F
.48233 .66149 m .48083 .6669 L .47961 .66598 L F
.4785 .64379 m .47992 .64442 L .47767 .64575 L .933 1 0 r
F
.48026 .64252 m .47992 .64442 L .4785 .64379 L .928 1 0 r
F
.48075 .66038 m .47961 .66598 L .47839 .66497 L 1 1 0 r
F
.48075 .66038 m .48233 .66149 L .47961 .66598 L F
.47889 .64289 m .46937 .64275 L .46941 .6432 L .282 0 0 r
F
.47889 .64289 m .47917 .64245 L .46937 .64275 L F
.4786 .64329 m .46941 .6432 L .46944 .6436 L .252 0 0 r
F
.4786 .64329 m .47889 .64289 L .46941 .6432 L F
.47831 .64364 m .4786 .64329 L .46944 .6436 L .22 0 0 r
F
.47851 .64181 m .48026 .64252 L .4785 .64379 L 1 1 0 r
F
.47981 .64062 m .48026 .64252 L .47851 .64181 L .975 1 0 r
F
.47916 .65913 m .48075 .66038 L .47839 .66497 L 1 1 0 r
F
.48095 .65532 m .48075 .66038 L .47916 .65913 L F
.47906 .65471 m .47979 .65495 L .47916 .65913 L F
.47979 .65495 m .48095 .65532 L .47922 .65899 L F
.47979 .65495 m .47922 .65899 L .47916 .65913 L F
.4792 .65397 m .48095 .65532 L .47906 .65471 L F
.48615 .64855 m .48158 .64994 L .48089 .64983 L .355 .198 0 r
F
.48511 .64839 m .48089 .64983 L .4802 .64967 L .398 .251 0 r
F
.48511 .64839 m .48615 .64855 L .48089 .64983 L F
.48406 .64817 m .48511 .64839 L .4802 .64967 L .44 .355 0 r
F
.48416 .64587 m .48195 .64758 L .48089 .64721 L .607 .784 0 r
F
.48275 .64544 m .48416 .64587 L .48089 .64721 L .681 .873 0 r
F
.48392 .6625 m .48205 .66774 L .48083 .6669 L 1 1 0 r
F
.48233 .66149 m .48392 .6625 L .48083 .6669 L F
.48287 .65659 m .48233 .66149 L .48075 .66038 L F
.48095 .65532 m .48287 .65659 L .48075 .66038 L F
.48034 .65074 m .48095 .65532 L .47904 .65385 L F
.48078 .65401 m .48254 .65216 L .48095 .65532 L F
.48034 .65074 m .48106 .6512 L .48078 .65401 L F
.48106 .6512 m .48254 .65216 L .48078 .65401 L F
.48373 .64364 m .48275 .64544 L .48134 .64496 L .782 .995 0 r
F
.48254 .65216 m .48287 .65659 L .48095 .65532 L 1 1 0 r
F
.48719 .64865 m .48226 .64999 L .48158 .64994 L .311 .192 0 r
F
.48615 .64855 m .48719 .64865 L .48158 .64994 L .355 .198 0 r
F
.48146 .64814 m .48254 .65216 L .48034 .65074 L 1 1 0 r
F
.49226 .64836 m .48559 .64947 L .48494 .64968 L 0 0 0 r
F
.49025 .64864 m .48428 .64984 L .48361 .64994 L .179 .171 0 r
F
.48924 .6487 m .48361 .64994 L .48294 .64999 L .223 .179 0 r
F
.48924 .6487 m .49025 .64864 L .48361 .64994 L F
.48822 .6487 m .48294 .64999 L .48226 .64999 L .267 .186 0 r
F
.48752 .649 m .48701 .64892 L .48624 .64921 L 0 0 0 r
F
.48822 .6487 m .48924 .6487 L .48294 .64999 L .267 .186 0 r
F
.48701 .64892 m .48676 .64897 L .48624 .64921 L 0 0 0 r
F
.48719 .64865 m .48822 .6487 L .48226 .64999 L .311 .192 0 r
F
.48146 .64814 m .48391 .64947 L .48254 .65216 L 1 1 0 r
F
.48696 .64654 m .48406 .64817 L .48301 .64791 L .521 .591 0 r
F
.48557 .64623 m .48301 .64791 L .48195 .64758 L .555 .689 0 r
F
.48557 .64623 m .48696 .64654 L .48301 .64791 L F
.48416 .64587 m .48557 .64623 L .48195 .64758 L .607 .784 0 r
F
.48239 .64594 m .48391 .64947 L .48146 .64814 L 1 .991 0 r
F
.48139 .64798 m .48239 .64594 L .48146 .64814 L 1 .932 0 r
F
.47995 .64949 m .47981 .64062 L .47982 .6502 L .381 .059 0 r
F
.47951 .64946 m .47509 .65084 L .47476 .65065 L .384 .209 0 r
F
.47881 .6492 m .47951 .64946 L .47476 .65065 L .43 .307 0 r
F
.47874 .64629 m .47669 .6481 L .47598 .64764 L .713 .881 0 r
F
.47767 .64575 m .47598 .64764 L .47527 .64713 L .808 .976 0 r
F
.47767 .64575 m .47874 .64629 L .47598 .64764 L F
.47961 .66598 m .47745 .67216 L .47663 .67146 L 1 1 0 r
F
.47659 .64514 m .47767 .64575 L .47527 .64713 L .911 1 0 r
F
.4785 .64379 m .47767 .64575 L .47659 .64514 L .933 1 0 r
F
.47839 .66497 m .47961 .66598 L .47663 .67146 L 1 1 0 r
F
.47707 .64308 m .4785 .64379 L .4785 .6438 L F
.47707 .64308 m .4785 .6438 L .47659 .64514 L F
.47564 .64224 m .47707 .64308 L .4755 .64445 L F
.47565 .64236 m .47707 .64308 L .47564 .64224 L .65 .206 0 r
F
.47659 .64514 m .47527 .64713 L .47455 .64657 L .911 1 0 r
F
.4755 .64445 m .47659 .64514 L .47455 .64657 L 1 1 0 r
F
.47707 .64308 m .47659 .64514 L .4755 .64445 L F
.47916 .65913 m .47839 .66497 L .47717 .66385 L F
.47746 .6595 m .47916 .65913 L .47717 .66385 L F
.47758 .65769 m .47779 .65788 L .47746 .6595 L F
.47779 .65788 m .47916 .65913 L .47746 .6595 L F
.47904 .65385 m .47916 .65913 L .47758 .65769 L F
.47623 .65434 m .47707 .64308 L .47565 .64236 L .65 .206 0 r
F
.47758 .65769 m .47717 .66385 L .47595 .66259 L 1 1 0 r
F
.47766 .65584 m .47863 .65347 L .47779 .65682 L F
.47851 .64181 m .4785 .64379 L .47707 .64308 L F
.47747 .65631 m .47851 .64181 L .47707 .64308 L .65 .206 0 r
F
.47747 .65629 m .47851 .64181 L .47747 .65631 L F
.47596 .66101 m .47758 .65769 L .47595 .66259 L 1 1 0 r
F
.47718 .65725 m .47758 .65769 L .47596 .66101 L F
.47747 .65631 m .47779 .65682 L .47758 .65769 L F
.47766 .65584 m .47779 .65682 L .47747 .65631 L F
.47863 .65347 m .47904 .65385 L .47812 .65625 L F
.47863 .65347 m .47812 .65625 L .47758 .65769 L F
.47626 .65504 m .47758 .65769 L .476 .65595 L F
.47626 .65504 m .47747 .65631 L .47623 .65434 L .65 .206 0 r
F
.47747 .65631 m .47707 .64308 L .47623 .65434 L F
.47713 .65205 m .47747 .65631 L .47626 .65504 L 1 1 0 r
F
.47747 .65631 m .47758 .65769 L .47626 .65504 L F
.476 .65595 m .47718 .65725 L .47596 .66101 L F
.47931 .71775 m .47747 .65631 L .47626 .65504 L .65 .206 0 r
F
.47931 .71775 m .47863 .65347 L .47747 .65635 L F
.47863 .65347 m .47863 .65277 L .47754 .65613 L F
.47863 .65347 m .47754 .65613 L .47747 .65635 L F
.47863 .65277 m .47851 .64181 L .47754 .65541 L F
.47815 .65423 m .47754 .65541 L .47747 .65635 L F
.47863 .65277 m .47754 .65541 L .47815 .65423 L F
.47886 .65289 m .48034 .65074 L .47904 .65385 L 1 1 0 r
F
.4788 .65254 m .47851 .64181 L .47863 .65332 L .528 .09 0 r
F
.4788 .65254 m .47863 .65332 L .47863 .65347 L F
.47814 .64897 m .4788 .65254 L .47713 .65205 L 1 1 0 r
F
.4788 .65254 m .47904 .65385 L .47851 .65335 L F
.4788 .65254 m .47851 .65335 L .47713 .65205 L F
.4788 .65254 m .47981 .64062 L .47851 .64181 L .528 .09 0 r
F
.4788 .65254 m .4801 .65054 L .47886 .65289 L 1 1 0 r
F
.47982 .65032 m .47982 .64967 L .4788 .65254 L .528 .09 0 r
F
.47982 .64967 m .47981 .64062 L .4788 .65254 L F
.47935 .64994 m .47982 .65032 L .4788 .65254 L 1 1 0 r
F
.47982 .65032 m .4801 .65054 L .4788 .65254 L F
.4801 .65054 m .48034 .65074 L .47886 .65289 L F
.47904 .65385 m .4792 .65397 L .47906 .65471 L F
.47985 .69209 m .47982 .65032 L .4788 .65254 L .528 .09 0 r
F
.4788 .65257 m .4788 .65254 L .47863 .65347 L F
.47814 .64897 m .47935 .64994 L .4788 .65254 L 1 1 0 r
F
.47713 .65205 m .47766 .65584 L .47747 .65631 L F
.47713 .65205 m .47863 .65347 L .47766 .65584 L F
.47747 .65635 m .47747 .65629 L .47747 .65631 L .65 .206 0 r
F
.47881 .65295 m .4788 .65257 L .47864 .65378 L .528 .09 0 r
F
.4788 .65257 m .47863 .65347 L .47864 .65378 L F
.47981 .69047 m .47975 .6884 L .47921 .70517 L F
.4905 .67159 m .4847 .67601 L .48391 .67583 L .731 .799 0 r
F
.4893 .67126 m .48391 .67583 L .48311 .67559 L .81 .896 0 r
F
.4893 .67126 m .4905 .67159 L .48391 .67583 L F
.48811 .67086 m .48311 .67559 L .48231 .67528 L .885 .978 0 r
F
.48811 .67086 m .4893 .67126 L .48311 .67559 L F
.4869 .67038 m .48811 .67086 L .48231 .67528 L .957 1 0 r
F
.49999 .83129 m .49211 .85109 L .49063 .85136 L 1 1 0 r
F
.49778 .83056 m .49063 .85136 L .48914 .8515 L F
.49778 .83056 m .49999 .83129 L .49063 .85136 L F
.49555 .82963 m .48914 .8515 L .48763 .85152 L F
.49555 .82963 m .49778 .83056 L .48914 .8515 L F
.49331 .82849 m .49555 .82963 L .48763 .85152 L F
.49331 .82849 m .48763 .85152 L .48611 .85145 L F
.48421 .67349 m .48701 .69143 L .48365 .68482 L 1 .751 0 r
F
.49107 .82715 m .49331 .82849 L .48611 .85145 L 1 1 0 r
F
.48365 .68482 m .48701 .69143 L .48631 .71046 L 1 .794 0 r
F
.49107 .82715 m .48611 .85145 L .48458 .85128 L 1 1 0 r
F
.48365 .68482 m .48631 .71046 L .48303 .70226 L 1 .794 0 r
F
.48631 .71046 m .48871 .74662 L .48551 .73923 L 1 .857 0 r
F
.48303 .70226 m .48631 .71046 L .48551 .73923 L 1 .838 0 r
F
.48881 .82558 m .49107 .82715 L .48458 .85128 L 1 1 0 r
F
.49286 .79293 m .49107 .82715 L .48881 .82558 L F
.49 .78896 m .49286 .79293 L .48881 .82558 L F
.48871 .74662 m .49 .78896 L .48714 .78424 L 1 .922 0 r
F
.48551 .73923 m .48871 .74662 L .48714 .78424 L 1 .904 0 r
F
.49 .78896 m .48881 .82558 L .48655 .82376 L 1 1 0 r
F
.48714 .78424 m .49 .78896 L .48655 .82376 L 1 .977 0 r
F
.48684 .76043 m .48421 .67349 L .48365 .68482 L .174 .025 0 r
F
.49356 .90856 m .49047 .91297 L .48768 .91207 L .776 .961 0 r
F
.48986 .90721 m .49356 .90856 L .48768 .91207 L .912 1 0 r
F
.49438 .90246 m .49356 .90856 L .48986 .90721 L 1 1 0 r
F
.48982 .90015 m .49438 .90246 L .48986 .90721 L F
.49098 .85842 m .48752 .7609 L .48684 .76043 L .174 .025 0 r
F
.49098 .85842 m .49551 .88366 L .4903 .87607 L .974 .642 0 r
F
.49326 .8711 m .49726 .87074 L .49551 .88366 L F
.49203 .8605 m .49726 .87074 L .49326 .8711 L F
.49114 .85687 m .49726 .87074 L .49098 .85842 L F
.49099 .85816 m .48752 .7609 L .49098 .85842 L .174 .025 0 r
F
.49098 .85842 m .49203 .8605 L .49326 .8711 L .974 .642 0 r
F
.49114 .85687 m .48752 .7609 L .49111 .86146 L .174 .025 0 r
F
.50436 .83214 m .49503 .85016 L .49358 .8507 L 1 1 0 r
F
.50219 .83182 m .49358 .8507 L .49211 .85109 L F
.50219 .83182 m .50436 .83214 L .49358 .8507 L F
.49999 .83129 m .50219 .83182 L .49211 .85109 L F
.49139 .83263 m .49726 .87074 L .49114 .85687 L .829 .463 0 r
F
.49438 .90246 m .49892 .9042 L .49356 .90856 L 1 1 0 r
F
.49832 .89642 m .49892 .9042 L .49438 .90246 L F
.49298 .8931 m .49438 .90246 L .48982 .90015 L F
.49298 .8931 m .49832 .89642 L .49438 .90246 L F
.49551 .88366 m .49832 .89642 L .49588 .8949 L 1 .938 0 r
F
.49494 .88578 m .49588 .8949 L .49298 .8931 L F
.49551 .88366 m .49588 .8949 L .49494 .88578 L F
.49142 .86888 m .49114 .85687 L .49111 .86146 L .174 .025 0 r
F
.49001 .87788 m .49551 .88366 L .49298 .8931 L 1 .815 0 r
F
.49004 .87773 m .49551 .88366 L .49001 .87788 L F
.49024 .87599 m .49551 .88366 L .48997 .87766 L F
.48832 .89177 m .49298 .8931 L .48982 .90015 L 1 .983 0 r
F
.48895 .88912 m .48905 .88922 L .48832 .89177 L F
.48905 .88922 m .49298 .8931 L .48846 .89181 L F
.48905 .88922 m .48846 .89181 L .48832 .89177 L F
.49177 .87723 m .49156 .86796 L .49142 .86888 L .174 .025 0 r
F
.4878 .88884 m .48895 .88912 L .48832 .89177 L 1 .983 0 r
F
.48303 .70226 m .48551 .73923 L .48237 .7299 L 1 .838 0 r
F
.48881 .82558 m .48458 .85128 L .48304 .85105 L 1 1 0 r
F
.48551 .73923 m .48714 .78424 L .4843 .77834 L 1 .904 0 r
F
.48243 .7314 m .48551 .73923 L .4843 .77834 L 1 .884 0 r
F
.48237 .7299 m .48246 .73018 L .48243 .7314 L F
.48246 .73018 m .48551 .73923 L .48243 .7314 L F
.48314 .70512 m .48365 .68482 L .48303 .70226 L .229 .035 0 r
F
.48655 .82376 m .48881 .82558 L .48304 .85105 L 1 1 0 r
F
.48714 .78424 m .48655 .82376 L .48428 .82158 L 1 .977 0 r
F
.4843 .77834 m .48714 .78424 L .48428 .82158 L 1 .953 0 r
F
.48973 .87645 m .48367 .68543 L .48314 .70512 L .229 .035 0 r
F
.48367 .68543 m .48365 .68482 L .48314 .70512 L F
.48237 .7299 m .4843 .77834 L .48147 .77047 L 1 .884 0 r
F
.48655 .82376 m .48304 .85105 L .48148 .85077 L 1 1 0 r
F
.48428 .82158 m .48655 .82376 L .48148 .85077 L 1 .983 0 r
F
.48426 .77903 m .48428 .82158 L .482 .81886 L 1 .953 0 r
F
.4843 .77834 m .4843 .779 L .48426 .77903 L F
.4843 .779 m .48428 .82158 L .48426 .77903 L F
.47867 .75926 m .48147 .77047 L .47972 .8152 L 1 .906 0 r
F
.47971 .78194 m .48147 .77047 L .47867 .75926 L .22 .032 0 r
F
.50431 .91434 m .48645 .91499 L .48567 .91597 L .156 0 0 r
F
.50264 .91518 m .48567 .91597 L .48488 .91682 L .12 0 0 r
F
.50264 .91518 m .50431 .91434 L .48567 .91597 L F
.50096 .91589 m .48488 .91682 L .48408 .91755 L .081 0 0 r
F
.50096 .91589 m .50264 .91518 L .48488 .91682 L F
.4869 .91678 m .47829 .91904 L .47743 .91874 L .296 .19 0 r
F
.49925 .91647 m .48408 .91755 L .48328 .91815 L .04 0 0 r
F
.49925 .91647 m .50096 .91589 L .48408 .91755 L F
.4869 .91678 m .48871 .91714 L .47829 .91904 L .296 .19 0 r
F
.48148 .85077 m .48304 .85105 L .476 .86922 L 1 .723 0 r
F
.48279 .74224 m .48303 .70226 L .48237 .7299 L .236 .036 0 r
F
.4815 .77335 m .4843 .77834 L .482 .81886 L 1 .93 0 r
F
.48161 .77084 m .4843 .77834 L .4815 .77335 L F
.4878 .88884 m .48357 .72341 L .48279 .74224 L .236 .036 0 r
F
.48357 .72341 m .48303 .70226 L .48279 .74224 L F
.48147 .77047 m .48161 .77084 L .4815 .77335 L 1 .93 0 r
F
.48508 .91629 m .4869 .91678 L .47743 .91874 L .351 .198 0 r
F
.50431 .91434 m .50596 .91337 L .48645 .91499 L .156 0 0 r
F
.49324 .91371 m .4869 .91678 L .48508 .91629 L .457 .39 0 r
F
.48365 .82576 m .48148 .85077 L .47992 .85045 L 1 .983 0 r
F
.48428 .82158 m .48376 .82697 L .48365 .82576 L F
.48376 .82697 m .48148 .85077 L .48365 .82576 L F
.48147 .77047 m .482 .81886 L .47972 .8152 L 1 .93 0 r
F
.482 .81886 m .48428 .82158 L .47992 .85045 L 1 .956 0 r
F
.482 .81886 m .47992 .85045 L .47948 .85035 L F
.47964 .83901 m .47948 .85035 L .47834 .85009 L F
.482 .81886 m .47948 .85035 L .47964 .83901 L F
.47972 .8152 m .482 .81886 L .47931 .84186 L 1 .93 0 r
F
.47899 .83374 m .47931 .84186 L .47834 .85009 L F
.47972 .8152 m .47931 .84186 L .47899 .83374 L F
.49047 .91297 m .48508 .91629 L .48324 .91565 L .519 .537 0 r
F
.49047 .91297 m .49324 .91371 L .48508 .91629 L F
.48768 .91207 m .48324 .91565 L .48139 .91489 L .583 .692 0 r
F
.48768 .91207 m .49047 .91297 L .48324 .91565 L F
.48487 .91099 m .48768 .91207 L .48139 .91489 L .704 .849 0 r
F
.48986 .90721 m .48768 .91207 L .48487 .91099 L .912 1 0 r
F
.48613 .90553 m .48487 .91099 L .48205 .90969 L 1 1 0 r
F
.48613 .90553 m .48986 .90721 L .48487 .91099 L F
.48221 .90674 m .48613 .90553 L .48205 .90969 L F
.48239 .9033 m .48358 .90401 L .48221 .90674 L F
.48358 .90401 m .48613 .90553 L .48221 .90674 L F
.48503 .89739 m .48178 .78062 L .47995 .78178 L .22 .032 0 r
F
.485 .89736 m .48531 .89761 L .48239 .9033 L 1 1 0 r
F
.48531 .89761 m .48613 .90553 L .48358 .90401 L F
.48531 .89761 m .48358 .90401 L .48239 .9033 L F
.48591 .91723 m .48531 .89761 L .48503 .89739 L .22 .032 0 r
F
.48531 .89761 m .48178 .78062 L .48503 .89723 L F
.48531 .89761 m .48237 .7299 L .48147 .77047 L F
.48535 .89749 m .48237 .7299 L .48531 .89761 L F
.48608 .89815 m .48982 .90015 L .48854 .90201 L 1 1 0 r
F
.48547 .89719 m .48624 .89771 L .48608 .89815 L F
.48624 .89771 m .48982 .90015 L .48608 .89815 L F
.48798 .88817 m .48895 .88912 L .4878 .88884 L 1 .983 0 r
F
.48552 .89703 m .48237 .7299 L .48535 .89752 L .22 .032 0 r
F
.4878 .88884 m .48982 .90015 L .48628 .89759 L 1 .983 0 r
F
.48552 .89703 m .48575 .8972 L .48547 .89719 L 1 1 0 r
F
.48575 .8972 m .48982 .90015 L .48568 .89734 L F
.48575 .8972 m .48568 .89734 L .48547 .89719 L F
.48973 .87645 m .49298 .8931 L .48853 .88871 L 1 .815 0 r
F
.49356 .90856 m .49725 .90965 L .49047 .91297 L .776 .961 0 r
F
.48982 .90015 m .48986 .90721 L .48613 .90553 L 1 1 0 r
F
.49111 .91225 m .4902 .88859 L .48869 .91494 L .229 .035 0 r
F
.48973 .87645 m .48853 .88871 L .48798 .88817 L 1 .815 0 r
F
.48973 .87645 m .48303 .70226 L .48784 .88276 L .229 .035 0 r
F
.48973 .87645 m .48784 .88276 L .48798 .88817 L F
.48973 .87645 m .49024 .87599 L .48997 .87766 L 1 .815 0 r
F
.48991 .8755 m .48999 .87562 L .48973 .87645 L F
.48999 .87562 m .49024 .87599 L .48973 .87645 L F
.49111 .91225 m .48991 .8755 L .48973 .87645 L .229 .035 0 r
F
.48991 .8755 m .48989 .87489 L .48973 .87645 L F
.48989 .87489 m .48365 .68482 L .48973 .87645 L F
.48941 .87477 m .48991 .8755 L .48973 .87645 L 1 .815 0 r
F
.4878 .88884 m .48237 .7299 L .48552 .89703 L .236 .036 0 r
F
.48797 .88786 m .48303 .70226 L .48781 .88881 L F
.48781 .88882 m .48303 .70226 L .4878 .88884 L F
.48973 .87645 m .48798 .88817 L .48762 .88781 L 1 .815 0 r
F
.4902 .88859 m .48973 .87645 L .4881 .89266 L .229 .035 0 r
F
.48973 .87645 m .48798 .88817 L .4881 .89266 L F
.48531 .89761 m .48854 .90201 L .48613 .90553 L 1 1 0 r
F
.48529 .89741 m .48854 .90201 L .48531 .89761 L F
.48523 .89682 m .48545 .89716 L .48529 .89741 L F
.48545 .89716 m .48854 .90201 L .48529 .89741 L F
.48869 .91494 m .48795 .89307 L .48591 .91723 L .236 .036 0 r
F
.48795 .89307 m .4878 .88884 L .48747 .89386 L F
.48795 .89307 m .48747 .89386 L .48591 .91723 L F
.4902 .88859 m .4881 .89266 L .48869 .91494 L .229 .035 0 r
F
.4878 .88884 m .48628 .89759 L .48552 .89703 L 1 .983 0 r
F
.4878 .88884 m .48552 .89703 L .48591 .91723 L .236 .036 0 r
F
.4878 .88884 m .48552 .89703 L .48523 .89682 L 1 .983 0 r
F
.48762 .88781 m .4878 .88884 L .48523 .89682 L F
.48798 .88817 m .48797 .88786 L .48783 .88964 L .236 .036 0 r
F
.48797 .88786 m .48781 .88881 L .48783 .88964 L F
.48795 .89307 m .48798 .88817 L .48783 .88964 L F
.48869 .91494 m .4881 .89266 L .48795 .89307 L F
.4881 .89266 m .48798 .88817 L .48795 .89307 L F
.48558 .90004 m .48552 .89703 L .4854 .90041 L .22 .032 0 r
F
.48552 .89703 m .48535 .89752 L .4854 .90041 L F
.48523 .89682 m .48552 .89703 L .48547 .89719 L 1 1 0 r
F
.48531 .89761 m .48503 .89723 L .48503 .89739 L .22 .032 0 r
F
.485 .89736 m .47995 .78178 L .48 .78834 L F
.48591 .91723 m .48504 .89745 L .485 .89736 L F
.48504 .89745 m .47995 .78178 L .485 .89736 L F
.48508 .91629 m .47743 .91874 L .47657 .91832 L .351 .198 0 r
F
.48324 .91565 m .47657 .91832 L .4757 .91778 L .409 .261 0 r
F
.48324 .91565 m .48508 .91629 L .47657 .91832 L F
.48139 .91489 m .4757 .91778 L .47483 .91713 L .471 .386 0 r
F
.48139 .91489 m .48324 .91565 L .4757 .91778 L F
.47953 .91399 m .48139 .91489 L .47483 .91713 L .539 .525 0 r
F
.48487 .91099 m .48139 .91489 L .47953 .91399 L .704 .849 0 r
F
.48205 .90969 m .48487 .91099 L .47953 .91399 L .859 1 0 r
F
.48117 .91534 m .48591 .91723 L .485 .89736 L 1 .827 0 r
F
.47992 .85045 m .48148 .85077 L .47524 .8697 L 1 .71 0 r
F
.47867 .75926 m .47972 .8152 L .47743 .80982 L 1 .906 0 r
F
.47972 .8152 m .47834 .85009 L .47675 .84967 L 1 .93 0 r
F
.47743 .80982 m .47972 .8152 L .47675 .84967 L 1 .906 0 r
F
.4808 .89249 m .485 .89736 L .47867 .75926 L 1 .827 0 r
F
.4808 .89249 m .48111 .89285 L .48121 .89525 L 1 1 0 r
F
.48121 .89525 m .48265 .89374 L .48239 .9033 L F
.48107 .89192 m .48265 .89374 L .48121 .89525 L F
.48265 .89374 m .48411 .89549 L .48304 .90035 L F
.48265 .89374 m .48304 .90035 L .48239 .9033 L F
.48411 .89549 m .485 .89736 L .48239 .9033 L F
.48205 .90969 m .47953 .91399 L .47766 .91296 L .859 1 0 r
F
.47921 .90812 m .48205 .90969 L .47766 .91296 L 1 1 0 r
F
.48239 .9033 m .48205 .90969 L .47921 .90812 L F
.48051 .90198 m .48239 .9033 L .48037 .90637 L F
.47891 .90033 m .48239 .9033 L .47883 .90081 L F
.48318 .81648 m .48941 .87477 L .48318 .85517 L .891 .493 0 r
F
.48318 .85517 m .48941 .87477 L .48762 .88781 L 1 .674 0 r
F
.48474 .8425 m .48728 .85725 L .48798 .87962 L .283 .048 0 r
F
.47848 .88511 m .47867 .75926 L .47743 .80982 L .061 0 0 r
F
.4787 .88363 m .47867 .75926 L .47848 .88511 L F
.47891 .90033 m .47867 .75926 L .47871 .90105 L F
.47871 .90105 m .4787 .88363 L .47848 .88511 L F
.4808 .89249 m .47867 .75926 L .4789 .89654 L 1 .827 0 r
F
.4808 .89249 m .4789 .89654 L .47891 .90033 L F
.4808 .89249 m .48239 .9033 L .47891 .90033 L 1 1 0 r
F
.47871 .90105 m .48051 .90198 L .47921 .90812 L F
.47868 .9007 m .47886 .90083 L .47871 .90105 L F
.47886 .90083 m .48051 .90198 L .47871 .90105 L F
.47921 .90812 m .47766 .91296 L .47578 .91178 L F
.4808 .89249 m .47891 .90033 L .47891 .9035 L 1 .827 0 r
F
.47588 .91077 m .47921 .90812 L .47578 .91178 L 1 1 0 r
F
.47627 .90698 m .47735 .90726 L .47588 .91077 L F
.47735 .90726 m .47921 .90812 L .47588 .91077 L F
.47627 .90698 m .47515 .84913 L .47414 .90917 L .217 .028 0 r
F
.47627 .90698 m .47414 .90917 L .47412 .91063 L F
.47743 .80982 m .47675 .84967 L .47515 .84913 L 1 .906 0 r
F
.47627 .90698 m .47743 .80982 L .47515 .84913 L .217 .028 0 r
F
.47637 .90681 m .47642 .90683 L .47627 .90698 L 1 1 0 r
F
.47642 .90683 m .47735 .90726 L .47627 .90698 L F
.47636 .9067 m .47921 .90812 L .4763 .90678 L F
.47662 .90631 m .47921 .90812 L .47631 .90667 L F
.47652 .91939 m .47662 .90631 L .47627 .90698 L .217 .028 0 r
F
.47662 .90631 m .47743 .80982 L .47627 .90698 L F
.4763 .90678 m .47637 .90681 L .47627 .90698 L 1 1 0 r
F
.47636 .90613 m .47627 .90698 L .47389 .91047 L F
.47627 .90698 m .47578 .91178 L .47412 .91063 L F
.47627 .90698 m .47412 .91063 L .47389 .91047 L F
.47627 .90698 m .47412 .91063 L .47395 .92087 L .217 .028 0 r
F
.47652 .91939 m .47627 .90698 L .47395 .92087 L F
.47886 .90052 m .47883 .90081 L .47878 .90077 L 1 1 0 r
F
.47891 .90033 m .47883 .90081 L .47887 .9004 L F
.47871 .90105 m .47743 .80982 L .47664 .90403 L .061 0 0 r
F
.47871 .90105 m .47664 .90403 L .47662 .90631 L F
.47864 .9001 m .47871 .90105 L .47636 .90613 L 1 1 0 r
F
.47871 .90105 m .47921 .90812 L .47662 .90631 L F
.47871 .90105 m .47662 .90631 L .47636 .90613 L F
.47871 .90105 m .47662 .90631 L .47652 .91939 L .061 0 0 r
F
.47875 .9039 m .47891 .90033 L .47871 .90105 L F
.47894 .91756 m .47891 .9035 L .47875 .9039 L F
.47891 .9035 m .47891 .90033 L .47875 .9039 L F
.48051 .90198 m .48037 .90637 L .47921 .90812 L 1 1 0 r
F
.48009 .90203 m .47891 .9035 L .47894 .91756 L 1 .827 0 r
F
.4808 .89249 m .47891 .9035 L .48009 .90203 L F
.47631 .90667 m .47636 .9067 L .4763 .90678 L 1 1 0 r
F
.47636 .90613 m .47662 .90631 L .47631 .90667 L F
.47894 .91756 m .47875 .9039 L .47652 .91939 L .061 0 0 r
F
.47875 .9039 m .47871 .90105 L .47831 .9044 L F
.47875 .9039 m .47831 .9044 L .47652 .91939 L F
.48063 .89133 m .4808 .89249 L .47867 .90013 L 1 1 0 r
F
.4808 .89249 m .47891 .90033 L .47867 .90013 L F
.47869 .89989 m .47867 .90013 L .47864 .9001 L F
.48063 .89133 m .47867 .90013 L .47869 .89989 L F
.48097 .90323 m .48097 .89268 L .4808 .89249 L 1 .827 0 r
F
.48117 .91534 m .48097 .89268 L .48097 .90323 L F
.48117 .91534 m .485 .89736 L .48097 .89268 L F
.48178 .78062 m .48147 .77047 L .47971 .78194 L .22 .032 0 r
F
.48117 .91534 m .48088 .8971 L .47894 .91756 L 1 .827 0 r
F
.48088 .8971 m .4808 .89249 L .4804 .89788 L F
.48088 .8971 m .4804 .89788 L .47894 .91756 L F
.4808 .89249 m .48107 .89192 L .48111 .89285 L 1 1 0 r
F
.48065 .89143 m .48107 .89192 L .4808 .89249 L F
.48107 .89192 m .48107 .89192 L .4808 .89249 L F
.48065 .89135 m .48265 .89374 L .48065 .89143 L F
.47673 .79132 m .48222 .87777 L .47836 .85768 L .927 .502 0 r
F
.4745 .66073 m .47473 .66109 L .47386 .66552 L 1 .989 0 r
F
.47515 .80107 m .4745 .66073 L .47338 .66606 L .824 .369 0 r
F
.47338 .66606 m .47449 .66037 L .47381 .66276 L F
.4745 .66073 m .47449 .66037 L .47338 .66606 L F
.47466 .65933 m .47442 .64367 L .47449 .66037 L .737 .281 0 r
F
.47466 .65933 m .47449 .66037 L .4745 .66073 L F
.47564 .64224 m .4755 .64445 L .47442 .64367 L 1 1 0 r
F
.47466 .65933 m .47564 .64224 L .47442 .64367 L .737 .281 0 r
F
.47528 .657 m .47568 .65551 L .47537 .65734 L 1 1 0 r
F
.47466 .65933 m .47473 .66109 L .4745 .66073 L F
.47468 .65975 m .47537 .65734 L .47473 .66109 L F
.47568 .65551 m .47568 .65526 L .47466 .65933 L .737 .281 0 r
F
.47568 .65526 m .47564 .64224 L .47474 .65788 L F
.47568 .65526 m .47474 .65788 L .47466 .65933 L F
.4764 .70205 m .47931 .71775 L .47626 .65504 L 1 .815 0 r
F
.47579 .65431 m .47626 .65504 L .47564 .64224 L F
.47585 .65478 m .47596 .65456 L .476 .65595 L 1 1 0 r
F
.47596 .65456 m .47626 .65504 L .476 .65595 L F
.47568 .65551 m .476 .65595 L .47536 .65854 L F
.47579 .65431 m .47564 .64224 L .47568 .65526 L 1 .815 0 r
F
.47579 .65431 m .47568 .65526 L .47568 .65551 L F
.47579 .65431 m .47692 .65179 L .47585 .65478 L 1 1 0 r
F
.47524 .64975 m .4762 .65092 L .47579 .65431 L F
.4762 .65092 m .47692 .65179 L .47579 .65431 L F
.47524 .64975 m .47579 .65431 L .47442 .65374 L F
.47579 .65431 m .476 .65595 L .47568 .65551 L F
.47579 .65431 m .47568 .65551 L .47442 .65374 L F
.4758 .65442 m .47579 .65431 L .47568 .65551 L 1 .815 0 r
F
.4764 .70205 m .47626 .65504 L .47579 .65431 L F
.47596 .65456 m .47713 .65205 L .47626 .65504 L 1 1 0 r
F
.47692 .65179 m .47713 .65205 L .47585 .65478 L F
.47442 .65374 m .47537 .65734 L .47468 .65975 L F
.47568 .65551 m .47536 .65854 L .47473 .66109 L F
.47594 .74257 m .47568 .65551 L .47466 .65933 L .737 .281 0 r
F
.47512 .65639 m .47568 .65551 L .47528 .657 L 1 1 0 r
F
.47442 .65374 m .47534 .65502 L .47512 .65639 L F
.47534 .65502 m .47568 .65551 L .47512 .65639 L F
.47442 .65374 m .47466 .65933 L .47352 .65923 L F
.47466 .65933 m .4745 .66073 L .47352 .65923 L F
.47466 .65949 m .47466 .65933 L .4745 .66073 L .737 .281 0 r
F
.47594 .74257 m .47467 .66016 L .47515 .80107 L F
.47467 .66016 m .4745 .66131 L .47515 .80107 L F
.47377 .68218 m .47594 .74257 L .47341 .71687 L 1 .836 0 r
F
.47477 .78255 m .47594 .74257 L .47515 .80107 L 1 .866 0 r
F
.47341 .71687 m .47437 .72662 L .47477 .78255 L F
.47437 .72662 m .47594 .74257 L .47477 .78255 L F
.47341 .71687 m .47515 .80107 L .47293 .78432 L F
.47337 .73144 m .47382 .69828 L .47367 .69426 L 0 0 0 r
F
.47323 .74803 m .47343 .73067 L .47337 .73144 L F
.47343 .73067 m .47382 .69828 L .47337 .73144 L F
.4764 .70205 m .4763 .6939 L .47611 .71937 L 1 .815 0 r
F
.4763 .6939 m .47624 .68898 L .47589 .70766 L F
.47624 .68898 m .47581 .6553 L .47587 .69828 L F
.47624 .68898 m .47587 .69828 L .47589 .70766 L F
.47713 .66606 m .47768 .65902 L .4773 .6671 L 1 .683 0 r
F
.47581 .6553 m .4758 .65442 L .47568 .65624 L 1 .815 0 r
F
.4758 .65442 m .47568 .65551 L .47568 .65624 L F
.47679 .67921 m .4773 .6671 L .47686 .67986 L 1 .739 0 r
F
.47581 .6553 m .47568 .65624 L .47586 .71485 L 1 .815 0 r
F
.47581 .6553 m .47586 .71485 L .47588 .71412 L F
.47581 .6553 m .47589 .72591 L .47592 .72474 L F
.47596 .6467 m .47713 .65205 L .47524 .64975 L 1 .964 0 r
F
.47596 .6467 m .47814 .64897 L .47713 .65205 L F
.47658 .64428 m .47814 .64897 L .47596 .6467 L 1 .917 0 r
F
.47658 .64428 m .47901 .64646 L .47814 .64897 L F
.4771 .6423 m .47901 .64646 L .47658 .64428 L 1 .87 0 r
F
.47652 .6556 m .4771 .6423 L .47658 .64428 L .229 .03 0 r
F
.47651 .65666 m .47657 .6554 L .47652 .6556 L F
.47657 .6554 m .4771 .6423 L .47652 .6556 L F
.47667 .65586 m .4771 .6423 L .47651 .65666 L F
.47753 .65188 m .47821 .64933 L .47799 .65345 L .936 .578 0 r
F
.47696 .65421 m .4771 .6423 L .47663 .65719 L .229 .03 0 r
F
.47419 .64137 m .47658 .64428 L .47596 .6467 L 1 .856 0 r
F
.47591 .67066 m .47712 .66644 L .47679 .67921 L 1 .739 0 r
F
.47538 .66544 m .47637 .66357 L .47591 .67066 L F
.47444 .65626 m .47575 .66125 L .47538 .66544 L F
.47575 .66125 m .47637 .66357 L .47538 .66544 L F
.47338 .66606 m .47381 .66276 L .47336 .66431 L .824 .369 0 r
F
.47352 .65923 m .4745 .66073 L .47338 .66606 L 1 .989 0 r
F
.47467 .66016 m .47466 .65949 L .4745 .66131 L .737 .281 0 r
F
.47466 .65949 m .4745 .66073 L .4745 .66131 L F
.47444 .65626 m .47565 .66811 L .47412 .66552 L 1 .739 0 r
F
.47565 .66811 m .47679 .67921 L .4754 .6721 L F
.47565 .66811 m .4754 .6721 L .47412 .66552 L F
.47637 .66357 m .47712 .66644 L .47591 .67066 L F
.47679 .67921 m .47678 .67948 L .47412 .66552 L F
.4763 .6939 m .47589 .70766 L .47594 .74257 L 1 .815 0 r
F
.47412 .66552 m .47678 .67948 L .4764 .70205 L 1 .792 0 r
F
.4764 .70205 m .47611 .71937 L .47594 .74257 L 1 .815 0 r
F
.47649 .66188 m .47656 .64904 L .4759 .65956 L .229 .03 0 r
F
.4771 .6423 m .47974 .64436 L .47901 .64646 L 1 .87 0 r
F
.47751 .64063 m .47974 .64436 L .4771 .6423 L .975 .822 0 r
F
.47705 .64981 m .47751 .64063 L .47733 .64137 L .029 0 0 r
F
.47612 .66176 m .47641 .66298 L .47608 .66223 L 1 .683 0 r
F
.47641 .66298 m .47713 .66606 L .47638 .66333 L F
.47641 .66298 m .47638 .66333 L .47608 .66223 L F
.47657 .66056 m .47668 .65869 L .47654 .66084 L .229 .03 0 r
F
.47668 .65869 m .47696 .65421 L .47667 .6588 L F
.47668 .65869 m .47667 .6588 L .47654 .66084 L F
.47702 .65599 m .47799 .65345 L .47768 .65902 L 1 .629 0 r
F
.47649 .66188 m .47713 .66606 L .47612 .66176 L 1 .683 0 r
F
.47619 .66084 m .47612 .66176 L .4745 .65491 L F
.47649 .66188 m .47612 .66176 L .47619 .66084 L F
.47778 .64695 m .47831 .64605 L .47825 .64795 L .867 .538 0 r
F
.47656 .66105 m .47713 .65926 L .47719 .66467 L 1 .683 0 r
F
.47675 .65891 m .47695 .6553 L .47676 .65803 L .229 .03 0 r
F
.47693 .65685 m .47695 .6553 L .47675 .65891 L F
.47695 .6553 m .47696 .65421 L .47649 .66188 L F
.47675 .65756 m .47658 .65881 L .47649 .66168 L F
.47649 .66168 m .47667 .65586 L .47651 .65666 L F
.4763 .65956 m .47693 .65685 L .47656 .66105 L 1 .683 0 r
F
.4745 .65491 m .47612 .66176 L .47444 .65626 L F
.47612 .66176 m .47608 .66223 L .47444 .65626 L F
.47713 .66606 m .47712 .66644 L .47575 .66125 L F
.47577 .66109 m .47575 .66125 L .47444 .65626 L F
.47713 .66606 m .47575 .66125 L .47577 .66109 L F
.47605 .65811 m .47662 .65597 L .4763 .65956 L F
.4738 .64361 m .47596 .6467 L .47524 .64975 L 1 .905 0 r
F
.47419 .64137 m .47596 .6467 L .4738 .64361 L 1 .856 0 r
F
.47336 .64657 m .47524 .64975 L .47442 .65374 L 1 .951 0 r
F
.4738 .64361 m .47524 .64975 L .47336 .64657 L 1 .905 0 r
F
.47412 .66552 m .47416 .66609 L .47398 .67211 L 1 .792 0 r
F
.47416 .66609 m .4764 .70205 L .47398 .67211 L F
.47398 .67211 m .4764 .70205 L .47377 .68218 L F
.47335 .74738 m .47382 .69828 L .47323 .74803 L 0 0 0 r
F
.47293 .78432 m .4748 .79842 L .47354 .84844 L 1 .867 0 r
F
.4748 .79842 m .47515 .80107 L .47497 .8063 L F
.4748 .79842 m .47497 .8063 L .47354 .84844 L F
.47293 .78432 m .47354 .84844 L .47286 .84808 L F
.47295 .76346 m .47302 .75601 L .47293 .78432 L .877 .169 0 r
F
.47302 .75601 m .47341 .71687 L .47307 .76518 L F
.47302 .75601 m .47307 .76518 L .47293 .78432 L F
.4734 .71884 m .47366 .69379 L .47341 .71687 L 0 0 0 r
F
.4732 .73996 m .47342 .71721 L .4734 .71884 L F
.47342 .71721 m .47366 .69379 L .4734 .71884 L F
.47337 .74729 m .47382 .69828 L .47335 .74738 L F
.4737 .70617 m .47379 .69759 L .47372 .7065 L F
.4737 .70617 m .47372 .7065 L .47364 .7168 L F
.47361 .71532 m .4737 .70617 L .47364 .7168 L F
.47379 .69759 m .47381 .69803 L .47364 .7168 L F
.47588 .71412 m .47586 .71485 L .47589 .72591 L 1 .815 0 r
F
.47592 .72474 m .47589 .72591 L .47594 .74257 L F
.47377 .68218 m .4764 .70205 L .47594 .74257 L 1 .836 0 r
F
.47382 .69828 m .47399 .6798 L .47367 .69426 L 0 0 0 r
F
.47399 .6798 m .47412 .66552 L .47394 .67691 L F
.47399 .6798 m .47394 .67691 L .47367 .69426 L F
.47381 .69807 m .47381 .69812 L .47364 .7168 L F
.47397 .67978 m .47381 .69812 L .47381 .69807 L F
.47397 .67978 m .47398 .67979 L .47381 .69812 L F
.47366 .69379 m .47365 .69368 L .47341 .71687 L F
.47322 .73789 m .47343 .7168 L .4732 .73996 L F
.47343 .7168 m .47377 .68218 L .47342 .71721 L F
.47343 .7168 m .47342 .71721 L .4732 .73996 L F
.47329 .73215 m .47377 .68218 L .4731 .75028 L F
.47366 .69379 m .47377 .68218 L .47365 .69368 L F
.4731 .75028 m .47322 .73789 L .4732 .73996 L F
.47293 .78432 m .47286 .84808 L .47206 .84766 L 1 .867 0 r
F
.47293 .78432 m .47206 .84766 L .47236 .8194 L F
.47275 .78274 m .47293 .78432 L .47236 .8194 L 1 .86 0 r
F
.47165 .75293 m .4724 .77145 L .47125 .76988 L F
.4724 .77145 m .47243 .77802 L .47125 .76988 L F
.47277 .78041 m .47275 .78274 L .47196 .77601 L F
.47199 .77503 m .47196 .77601 L .47125 .76988 L F
.47277 .78041 m .47196 .77601 L .47199 .77503 L F
.4724 .77145 m .47277 .78041 L .47243 .77802 L F
.47277 .78041 m .47293 .78432 L .47275 .78274 L F
.47125 .76988 m .47275 .78274 L .47191 .84758 L F
.47275 .78274 m .47236 .8194 L .47191 .84758 L F
.47064 .69061 m .47046 .69451 L .47053 .69235 L .803 .164 0 r
F
.47046 .87901 m .47125 .68101 L .47037 .6948 L .941 .475 0 r
F
.47146 .676 m .4717 .67629 L .47167 .67284 L 1 .465 0 r
F
.47146 .676 m .47167 .67284 L .47139 .64683 L F
.47146 .676 m .47138 .67994 L .47125 .68101 L 1 .615 0 r
F
.47147 .67757 m .47146 .676 L .47125 .68101 L 1 .465 0 r
F
.47146 .676 m .47139 .64683 L .47125 .68101 L F
.47146 .676 m .47125 .68101 L .47101 .68311 L 1 .615 0 r
F
.47169 .66624 m .47146 .676 L .47095 .68366 L F
.47146 .676 m .47101 .68311 L .47095 .68366 L F
.47169 .66624 m .4717 .67629 L .47146 .676 L F
.47147 .67794 m .4717 .67629 L .47146 .676 L 1 .465 0 r
F
.47095 .68366 m .47125 .68101 L .47064 .69064 L .803 .164 0 r
F
.47052 .7932 m .47169 .66624 L .47095 .68366 L .423 .064 0 r
F
.46998 .91365 m .46877 .89025 L .4687 .91554 L .37 .051 0 r
F
.47046 .87901 m .47037 .6948 L .46885 .89453 L .941 .475 0 r
F
.47029 .85079 m .47094 .77716 L .47052 .7932 L .423 .064 0 r
F
.47033 .85712 m .47191 .84758 L .47046 .87901 L 1 .525 0 r
F
.47029 .85079 m .47067 .85005 L .47033 .85712 L F
.47067 .85005 m .47191 .84758 L .47033 .85712 L F
.47048 .84674 m .47056 .84678 L .47029 .85079 L F
.47056 .84678 m .47191 .84758 L .4704 .85058 L F
.47056 .84678 m .4704 .85058 L .47029 .85079 L F
.47123 .76774 m .47191 .84758 L .4705 .84675 L 1 .86 0 r
F
.47123 .76774 m .4705 .84675 L .47048 .84674 L F
.47037 .6948 m .47001 .70181 L .46998 .70943 L .803 .164 0 r
F
.47037 .6948 m .47004 .69996 L .46998 .70943 L .941 .475 0 r
F
.47037 .6948 m .46998 .70943 L .46885 .89453 L F
.47037 .6948 m .46998 .70943 L .46998 .70951 L .803 .164 0 r
F
.47066 .89642 m .47075 .87739 L .47007 .9074 L .534 .089 0 r
F
.46948 .88946 m .47046 .87901 L .46885 .89453 L 0 0 0 r
F
.46952 .8892 m .46956 .88877 L .46948 .88946 L F
.46956 .88877 m .47046 .87901 L .46948 .88946 L F
.46952 .88914 m .47046 .87901 L .46952 .8892 L F
.46962 .88822 m .46964 .88806 L .46952 .88918 L F
.46964 .88806 m .47046 .87901 L .46952 .88914 L F
.46964 .88806 m .46952 .88914 L .46952 .88918 L F
.47029 .85079 m .47046 .87901 L .46967 .88774 L 1 .525 0 r
F
.47007 .9074 m .47029 .85079 L .46946 .91326 L .423 .064 0 r
F
.47029 .85079 m .47095 .68366 L .46962 .88822 L F
.47005 .86459 m .47029 .85079 L .46964 .88806 L 1 .525 0 r
F
.47029 .85079 m .46967 .88774 L .46964 .88806 L F
.47029 .85079 m .46962 .88822 L .46946 .91326 L .423 .064 0 r
F
.47029 .8505 m .47029 .85079 L .47005 .86459 L 1 .525 0 r
F
.47048 .84674 m .47055 .8356 L .47019 .87799 L .423 .064 0 r
F
.47055 .8356 m .47094 .77716 L .47047 .84056 L F
.47055 .8356 m .47047 .84056 L .47019 .87799 L F
.47106 .80649 m .47078 .82284 L .47028 .88182 L .534 .089 0 r
F
.47033 .88141 m .47028 .88182 L .47007 .9074 L F
.47106 .80649 m .47028 .88182 L .47033 .88141 L F
.47017 .88294 m .47048 .84674 L .47019 .87799 L .423 .064 0 r
F
.47007 .9074 m .47024 .88224 L .47017 .88294 L F
.47024 .88224 m .47048 .84674 L .47017 .88294 L F
.47075 .87739 m .47106 .80649 L .47033 .88141 L .534 .089 0 r
F
.47075 .87739 m .47033 .88141 L .47007 .9074 L F
.46952 .88918 m .46952 .88914 L .46952 .8892 L 0 0 0 r
F
.46962 .88822 m .46963 .88683 L .4695 .89521 L .252 .035 0 r
F
.46963 .88683 m .47095 .68366 L .46955 .88853 L F
.46963 .88683 m .46955 .88853 L .4695 .89521 L F
.46952 .88918 m .46885 .89453 L .4689 .90235 L 0 0 0 r
F
.46935 .91472 m .4687 .91554 L .4687 .91584 L .37 .051 0 r
F
.46998 .91365 m .4687 .91554 L .46935 .91472 L F
.46998 .91365 m .4687 .91584 L .46872 .91577 L .731 .419 0 r
F
.47038 .91294 m .46998 .91365 L .46872 .91577 L F
.46909 .92096 m .47036 .92092 L .46868 .92206 L .665 .424 0 r
F
.46913 .92092 m .47036 .92092 L .46909 .92096 L F
.46918 .92074 m .46928 .92076 L .46911 .92092 L F
.46928 .92076 m .47036 .92092 L .46911 .92092 L F
.47038 .91294 m .47052 .91306 L .46998 .91365 L .731 .419 0 r
F
.47036 .92092 m .47052 .91306 L .46998 .91365 L .37 .051 0 r
F
.46918 .92074 m .47038 .91294 L .46872 .91577 L .248 0 0 r
F
.46969 .92032 m .4697 .92033 L .46918 .92074 L .665 .424 0 r
F
.4697 .92033 m .47036 .92092 L .4692 .92075 L F
.4694 .92057 m .4692 .92075 L .46918 .92074 L F
.4697 .92033 m .4692 .92075 L .4694 .92057 L F
.47015 .91895 m .47038 .91294 L .46978 .91937 L .051 0 0 r
F
.47015 .91895 m .46978 .91937 L .46969 .92032 L F
.472 .91947 m .47185 .90992 L .47036 .92092 L 1 .403 0 r
F
.47019 .91932 m .472 .91947 L .47036 .92092 L 1 1 0 r
F
.47015 .91896 m .47035 .91902 L .47019 .91932 L F
.47035 .91902 m .472 .91947 L .47019 .91932 L F
.47205 .91233 m .47319 .91028 L .47199 .91281 L F
.47234 .91006 m .47243 .91008 L .47205 .91233 L F
.47243 .91008 m .47319 .91028 L .47205 .91233 L F
.47319 .91028 m .47326 .91124 L .47199 .91281 L F
.472 .91947 m .47338 .91109 L .47185 .90992 L 1 .403 0 r
F
.47185 .90992 m .47234 .91006 L .47228 .91026 L 1 1 0 r
F
.47198 .909 m .47237 .9093 L .47185 .90992 L F
.47237 .9093 m .47389 .91047 L .47185 .90992 L F
.4735 .90328 m .47389 .91047 L .47254 .90943 L F
.4735 .90328 m .47254 .90943 L .47198 .909 L F
.47298 .9068 m .47394 .90051 L .4735 .90328 L 0 0 0 r
F
.47488 .89436 m .47636 .90613 L .47471 .90448 L 1 1 0 r
F
.47488 .89436 m .47471 .90448 L .4735 .90328 L F
.47394 .90051 m .47488 .89436 L .4735 .90328 L 0 0 0 r
F
.47136 .91732 m .47357 .91765 L .472 .91947 L 1 1 0 r
F
.47111 .91647 m .47147 .91664 L .47136 .91732 L F
.47147 .91664 m .47357 .91765 L .47136 .91732 L F
.47175 .91497 m .47319 .90553 L .47298 .9068 L 0 0 0 r
F
.47184 .91441 m .47319 .90553 L .47175 .91497 L F
.47197 .91171 m .4735 .90328 L .47267 .90641 L F
.47126 .91612 m .4735 .90328 L .47111 .91647 L F
.47146 .91562 m .47149 .91564 L .47111 .91647 L 1 1 0 r
F
.47149 .91564 m .4717 .91585 L .47131 .91626 L F
.47149 .91564 m .47131 .91626 L .47111 .91647 L F
.4717 .91585 m .47161 .91657 L .47111 .91647 L F
.4727 .91681 m .4728 .91728 L .47111 .91647 L F
.4717 .91585 m .4727 .91681 L .47161 .91657 L F
.4727 .91681 m .47357 .91765 L .4728 .91728 L F
.47016 .91895 m .4703 .91899 L .47015 .91896 L F
.4703 .91899 m .472 .91947 L .47029 .919 L F
.4703 .91899 m .47029 .919 L .47015 .91896 L F
.47064 .9184 m .472 .91947 L .47015 .91895 L F
.47098 .91703 m .472 .91947 L .47066 .91842 L F
.47111 .91647 m .472 .91947 L .47097 .91699 L F
.47115 .91749 m .47185 .91323 L .47095 .91788 L 0 0 0 r
F
.47185 .91323 m .4735 .90328 L .47146 .91496 L F
.47185 .91323 m .47146 .91496 L .47095 .91788 L F
.47097 .91699 m .47098 .91703 L .47064 .9184 L 1 1 0 r
F
.47098 .91703 m .47066 .91842 L .47064 .9184 L F
.47095 .91788 m .47111 .91647 L .47059 .91836 L 0 0 0 r
F
.47111 .91647 m .47198 .909 L .47059 .91836 L F
.4711 .91643 m .47111 .91647 L .47097 .91699 L 1 1 0 r
F
.47015 .91895 m .47016 .91895 L .47015 .91896 L F
.47185 .90992 m .47052 .91306 L .47038 .91294 L F
.47015 .91895 m .47198 .909 L .47038 .91294 L .051 0 0 r
F
.47011 .91996 m .47032 .91872 L .47015 .91895 L F
.47032 .91872 m .47198 .909 L .47015 .91895 L F
.47059 .91836 m .47064 .9184 L .47015 .91895 L 1 1 0 r
F
.47015 .91895 m .47036 .92092 L .46971 .92034 L F
.47015 .91895 m .46971 .92034 L .46969 .92032 L F
.47016 .9199 m .47052 .91774 L .47011 .91996 L .051 0 0 r
F
.47052 .91774 m .47198 .909 L .47044 .918 L F
.47052 .91774 m .47044 .918 L .47011 .91996 L F
.47039 .91968 m .47059 .91836 L .47016 .9199 L F
.47059 .91836 m .47198 .909 L .47016 .9199 L F
.4711 .91643 m .47094 .91709 L .47004 .91793 L 1 1 0 r
F
.47094 .91709 m .47064 .9184 L .47059 .91836 L F
.47094 .91709 m .47059 .91836 L .47004 .91793 L F
.47004 .91793 m .47059 .91836 L .47015 .91895 L F
.47063 .91481 m .4711 .91643 L .47004 .91793 L F
.47357 .91765 m .47371 .91882 L .47248 .91929 L .934 1 0 r
F
.47371 .91882 m .47318 .92032 L .472 .91947 L F
.47395 .92087 m .47357 .91122 L .47338 .91109 L .382 .057 0 r
F
.47386 .92017 m .47652 .91939 L .47395 .92087 L .934 1 0 r
F
.47357 .91765 m .47419 .91801 L .47386 .92017 L F
.47419 .91801 m .47652 .91939 L .47386 .92017 L F
.47506 .91532 m .47652 .91939 L .47357 .91765 L 1 1 0 r
F
.47184 .92117 m .47474 .9159 L .47357 .91765 L 0 0 0 r
F
.47117 .92254 m .47207 .92085 L .47184 .92117 L F
.47207 .92085 m .47474 .9159 L .47184 .92117 L F
.48235 .92196 m .47972 .9242 L .47781 .92324 L .469 .5 0 r
F
.47944 .92079 m .47781 .92324 L .47588 .92213 L .54 .664 0 r
F
.47944 .92079 m .48235 .92196 L .47781 .92324 L F
.48351 .92571 m .47667 .92723 L .47579 .92668 L .259 .183 0 r
F
.48162 .92503 m .48351 .92571 L .47579 .92668 L .304 .19 0 r
F
.49984 .92568 m .48433 .92606 L .48351 .92673 L .103 0 0 r
F
.48539 .92626 m .47755 .92763 L .47667 .92723 L .215 .177 0 r
F
.50157 .925 m .48514 .92527 L .48433 .92606 L .138 0 0 r
F
.49984 .92568 m .50157 .925 L .48433 .92606 L .103 0 0 r
F
.48351 .92571 m .48539 .92626 L .47667 .92723 L .259 .183 0 r
F
.47953 .9257 m .47787 .92759 L .47593 .92646 L .424 .446 0 r
F
.47634 .92514 m .47944 .92079 L .47588 .92213 L .381 0 0 r
F
.4828 .91916 m .48235 .92196 L .47944 .92079 L .643 .844 0 r
F
.50329 .92418 m .48594 .92435 L .48514 .92527 L .171 0 0 r
F
.50329 .92418 m .50498 .92324 L .48594 .92435 L F
.48812 .92378 m .48351 .92571 L .48162 .92503 L .359 .246 0 r
F
.48524 .92295 m .48162 .92503 L .47972 .9242 L .41 .363 0 r
F
.48524 .92295 m .48812 .92378 L .48162 .92503 L F
.47922 .92426 m .48295 .9248 L .47953 .9257 L .535 .725 0 r
F
.47922 .92426 m .4828 .91916 L .47944 .92079 L .309 0 0 r
F
.47934 .92422 m .4828 .91916 L .47922 .92426 L F
.48235 .92196 m .48524 .92295 L .47972 .9242 L .469 .5 0 r
F
.48032 .92389 m .48295 .9248 L .47922 .92426 L .535 .725 0 r
F
.4802 .92411 m .48032 .92389 L .4792 .92442 L .309 0 0 r
F
.48032 .92389 m .4828 .91916 L .47924 .92437 L F
.48032 .92389 m .47924 .92437 L .4792 .92442 L F
.47628 .92533 m .47953 .9257 L .47593 .92646 L .49 .599 0 r
F
.47669 .9252 m .47953 .9257 L .47628 .92533 L F
.47756 .92483 m .47764 .92486 L .47634 .92514 L F
.47764 .92486 m .47953 .9257 L .47656 .92518 L F
.47764 .92486 m .47656 .92518 L .47634 .92514 L F
.48185 .92321 m .48295 .9248 L .48032 .92389 L .605 .834 0 r
F
.48181 .92364 m .4819 .92322 L .4802 .92411 L 1 .376 0 r
F
.4819 .92322 m .4828 .91916 L .48041 .92371 L F
.4819 .92322 m .48041 .92371 L .4802 .92411 L F
.50157 .925 m .50329 .92418 L .48514 .92527 L .138 0 0 r
F
.49809 .92622 m .48351 .92673 L .48268 .92726 L .066 0 0 r
F
.49809 .92622 m .49984 .92568 L .48351 .92673 L F
.48539 .92626 m .48725 .92667 L .47755 .92763 L .215 .177 0 r
F
.49381 .92498 m .48725 .92667 L .48539 .92626 L .269 .185 0 r
F
.49097 .92445 m .48539 .92626 L .48351 .92571 L .313 .191 0 r
F
.49097 .92445 m .49381 .92498 L .48539 .92626 L F
.48812 .92378 m .49097 .92445 L .48351 .92571 L .359 .246 0 r
F
.49633 .92664 m .48268 .92726 L .48184 .92766 L .028 0 0 r
F
.49633 .92664 m .49809 .92622 L .48268 .92726 L F
.49454 .92692 m .48184 .92766 L .481 .92792 L 0 0 0 r
F
.49454 .92692 m .49633 .92664 L .48184 .92766 L F
.50532 .92771 m .48688 .92751 L .48608 .92856 L .215 0 0 r
F
.50532 .92771 m .50701 .92664 L .48688 .92751 L F
.49274 .92706 m .481 .92792 L .48015 .92805 L 0 0 0 r
F
.49274 .92706 m .49454 .92692 L .481 .92792 L F
.49093 .92707 m .48015 .92805 L .47929 .92805 L .09 .156 0 r
F
.49093 .92707 m .49274 .92706 L .48015 .92805 L F
.4891 .92693 m .47929 .92805 L .47843 .92791 L .131 .163 0 r
F
.4891 .92693 m .49093 .92707 L .47929 .92805 L F
.48725 .92667 m .47843 .92791 L .47755 .92763 L .173 .17 0 r
F
.48725 .92667 m .4891 .92693 L .47843 .92791 L F
.48684 .92592 m .4854 .92781 L .48247 .92684 L .409 .416 0 r
F
.48295 .9248 m .48247 .92684 L .47953 .9257 L .463 .551 0 r
F
.48273 .92572 m .48684 .92592 L .48247 .92684 L F
.48295 .9248 m .48441 .92522 L .48273 .92572 L F
.48441 .92522 m .48684 .92592 L .48273 .92572 L F
.49047 .92143 m .48812 .92378 L .48524 .92295 L .469 .513 0 r
F
.48665 .92042 m .49047 .92143 L .49038 .92146 L .529 .667 0 r
F
.48665 .92042 m .49038 .92146 L .48524 .92295 L F
.4828 .91916 m .48665 .92042 L .48235 .92196 L .643 .844 0 r
F
.4829 .91937 m .48665 .92042 L .4828 .91916 L .301 0 0 r
F
.4819 .92322 m .48505 .9241 L .48295 .9248 L .605 .834 0 r
F
.4819 .92322 m .48295 .9248 L .48185 .92321 L F
.48139 .92549 m .48493 .92384 L .4819 .92322 L 1 .376 0 r
F
.4819 .92322 m .48328 .92339 L .48505 .9241 L .605 .834 0 r
F
.48665 .92042 m .48524 .92295 L .48235 .92196 L .529 .667 0 r
F
.48505 .9241 m .48665 .92042 L .4829 .91937 L .301 0 0 r
F
.48637 .92449 m .48507 .92405 L .48505 .9241 L F
.48612 .92374 m .48637 .92449 L .48295 .9248 L .498 .652 0 r
F
.48637 .92449 m .48684 .92592 L .48441 .92522 L F
.48637 .92449 m .48441 .92522 L .48295 .9248 L F
.49062 .91859 m .49047 .92143 L .48706 .92053 L .608 .818 0 r
F
.49062 .91859 m .48706 .92053 L .48665 .92042 L F
.48726 .9244 m .4909 .92483 L .48893 .92536 L .498 .652 0 r
F
.48637 .92449 m .49062 .91859 L .48665 .92042 L .301 0 0 r
F
.48649 .92445 m .49062 .91859 L .48637 .92449 L F
.48637 .92449 m .48665 .92042 L .48507 .92405 L F
.48705 .92427 m .48789 .92415 L .48726 .9244 L .498 .652 0 r
F
.48763 .92409 m .48789 .92415 L .48705 .92427 L F
.48763 .92409 m .49062 .91859 L .48648 .92446 L .301 0 0 r
F
.48637 .92448 m .48893 .92536 L .48637 .92449 L .498 .652 0 r
F
.48612 .92374 m .48704 .92427 L .48637 .92448 L F
.48704 .92427 m .48893 .92536 L .48637 .92448 L F
.48789 .92415 m .4909 .92483 L .48726 .9244 L F
.48637 .92449 m .48893 .92536 L .48684 .92592 L F
.49427 .92225 m .49097 .92445 L .48812 .92378 L .416 .379 0 r
F
.49941 .92561 m .49093 .92707 L .4891 .92693 L .185 .172 0 r
F
.49662 .92537 m .4891 .92693 L .48725 .92667 L .226 .179 0 r
F
.49662 .92537 m .49941 .92561 L .4891 .92693 L F
.49381 .92498 m .49662 .92537 L .48725 .92667 L .269 .185 0 r
F
.48684 .92592 m .49071 .92685 L .4854 .92781 L .409 .416 0 r
F
.4909 .92483 m .49071 .92685 L .48684 .92592 L .444 .508 0 r
F
.49047 .92143 m .49427 .92225 L .48812 .92378 L .469 .513 0 r
F
.48964 .92331 m .49062 .91859 L .48771 .92394 L .2 0 0 r
F
.48964 .92331 m .48771 .92394 L .48763 .92409 L F
.49805 .9229 m .49381 .92498 L .49097 .92445 L .369 .262 0 r
F
.49427 .92225 m .49805 .9229 L .49097 .92445 L .416 .379 0 r
F
.49754 .91692 m .48328 .91815 L .48246 .91862 L 0 0 0 r
F
.49754 .91692 m .49925 .91647 L .48328 .91815 L F
.4958 .91724 m .48246 .91862 L .48164 .91896 L F
.4958 .91724 m .49754 .91692 L .48246 .91862 L F
.49405 .91742 m .4958 .91724 L .48699 .91831 L .094 .156 0 r
F
.48692 .9183 m .48699 .91831 L .48164 .91896 L F
.49405 .91742 m .48699 .91831 L .48692 .9183 L F
.49405 .91742 m .48692 .9183 L .48081 .91917 L F
.48692 .9183 m .48164 .91896 L .48081 .91917 L F
.48665 .91828 m .48081 .91917 L .47998 .91926 L .142 .165 0 r
F
.49228 .91746 m .48673 .91829 L .48665 .91828 L F
.48673 .91829 m .48081 .91917 L .48665 .91828 L F
.51468 .91423 m .50096 .91589 L .49925 .91647 L 0 0 0 r
F
.51468 .91423 m .51726 .91365 L .50096 .91589 L F
.51208 .91467 m .49925 .91647 L .49754 .91692 L F
.51208 .91467 m .51468 .91423 L .50578 .91553 L F
.50506 .91566 m .50578 .91553 L .49925 .91647 L F
.51208 .91467 m .50578 .91553 L .50506 .91566 L F
.50258 .91611 m .49754 .91692 L .4958 .91724 L .135 .163 0 r
F
.50946 .91496 m .51208 .91467 L .49754 .91692 L F
.50946 .91496 m .50339 .91596 L .50258 .91611 L F
.50339 .91596 m .49754 .91692 L .50258 .91611 L F
.50681 .91512 m .4958 .91724 L .49405 .91742 L .184 .172 0 r
F
.49228 .91746 m .49405 .91742 L .48081 .91917 L .142 .165 0 r
F
.51726 .91365 m .50264 .91518 L .50096 .91589 L .002 0 0 r
F
.50414 .91513 m .49405 .91742 L .49228 .91746 L .235 .181 0 r
F
.50414 .91513 m .50681 .91512 L .49405 .91742 L F
.50145 .915 m .49228 .91746 L .4905 .91737 L .288 .189 0 r
F
.51981 .91294 m .50431 .91434 L .50264 .91518 L .043 0 0 r
F
.51726 .91365 m .51981 .91294 L .50264 .91518 L .002 0 0 r
F
.50145 .915 m .50414 .91513 L .49228 .91746 L .288 .189 0 r
F
.49873 .91472 m .4905 .91737 L .48871 .91714 L .343 .197 0 r
F
.49873 .91472 m .50145 .915 L .4905 .91737 L F
.496 .91429 m .49873 .91472 L .48871 .91714 L .399 .255 0 r
F
.50456 .91121 m .49873 .91472 L .496 .91429 L .501 .52 0 r
F
.49531 .91963 m .49427 .92225 L .49047 .92143 L .522 .663 0 r
F
.49062 .91859 m .49531 .91963 L .49047 .92143 L .608 .818 0 r
F
.4942 .91647 m .49531 .91963 L .49112 .9187 L .704 .935 0 r
F
.4942 .91647 m .49112 .9187 L .49062 .91859 L F
.50681 .91512 m .50946 .91496 L .4958 .91724 L .184 .172 0 r
F
.4942 .91647 m .49968 .91756 L .49531 .91963 L .704 .935 0 r
F
.49733 .91405 m .49968 .91756 L .49477 .91659 L .776 1 0 r
F
.49733 .91405 m .49477 .91659 L .4942 .91647 L F
.49035 .92417 m .49457 .92359 L .4909 .92483 L .527 .741 0 r
F
.48985 .92356 m .49119 .92357 L .49035 .92417 L F
.49119 .92357 m .49457 .92359 L .49035 .92417 L F
.50091 .91052 m .50456 .91121 L .496 .91429 L .558 .671 0 r
F
.49531 .91963 m .49998 .92044 L .49427 .92225 L .522 .663 0 r
F
.49968 .91756 m .49998 .92044 L .49531 .91963 L .584 .797 0 r
F
.52483 .91112 m .50759 .91228 L .50596 .91337 L .119 0 0 r
F
.52233 .9121 m .50596 .91337 L .50431 .91434 L .082 0 0 r
F
.52233 .9121 m .52483 .91112 L .50596 .91337 L F
.51981 .91294 m .52233 .9121 L .50431 .91434 L .043 0 0 r
F
.51177 .91207 m .50414 .91513 L .50145 .915 L .39 .235 0 r
F
.50818 .91173 m .50145 .915 L .49873 .91472 L .445 .372 0 r
F
.52729 .91001 m .5092 .91106 L .50759 .91228 L .153 0 0 r
F
.52483 .91112 m .52729 .91001 L .50759 .91228 L .119 0 0 r
F
.50818 .91173 m .51177 .91207 L .50145 .915 L .445 .372 0 r
F
.50456 .91121 m .50818 .91173 L .49873 .91472 L .501 .52 0 r
F
.49733 .91405 m .50351 .91519 L .49968 .91756 L .776 1 0 r
F
.49994 .9113 m .50351 .91519 L .49733 .91405 L .817 1 0 r
F
.49507 .92029 m .4998 .91159 L .49733 .91405 L 0 0 0 r
F
.49501 .92048 m .49513 .92024 L .49507 .92029 L F
.49513 .92024 m .4998 .91159 L .49507 .92029 L F
.49998 .92044 m .50461 .92105 L .49805 .9229 L .471 .524 0 r
F
.50514 .91834 m .50461 .92105 L .49998 .92044 L .52 .665 0 r
F
.49968 .91756 m .50514 .91834 L .49998 .92044 L .584 .797 0 r
F
.51534 .91225 m .50681 .91512 L .50414 .91513 L .336 .196 0 r
F
.51177 .91207 m .51534 .91225 L .50414 .91513 L .39 .235 0 r
F
.50351 .91519 m .50514 .91834 L .49968 .91756 L .666 .899 0 r
F
.50351 .91519 m .50966 .91595 L .50514 .91834 L F
.51888 .91227 m .50946 .91496 L .50681 .91512 L .283 .188 0 r
F
.51534 .91225 m .51888 .91227 L .50681 .91512 L .336 .196 0 r
F
.50672 .91255 m .50966 .91595 L .50423 .91528 L .728 .966 0 r
F
.50672 .91255 m .50423 .91528 L .50351 .91519 L F
.52729 .91001 m .52973 .90878 L .5092 .91106 L .153 0 0 r
F
.51687 .90811 m .51177 .91207 L .50818 .91173 L .537 .641 0 r
F
.51242 .90748 m .50818 .91173 L .50456 .91121 L .605 .784 0 r
F
.51242 .90748 m .51687 .90811 L .50818 .91173 L F
.50461 .92105 m .5018 .92339 L .49805 .9229 L .426 .399 0 r
F
.52598 .92047 m .50831 .92097 L .50666 .92217 L .177 0 0 r
F
.50461 .92105 m .50922 .92149 L .5018 .92339 L .426 .399 0 r
F
.50514 .91834 m .51056 .9189 L .50461 .92105 L .52 .665 0 r
F
.50966 .91595 m .51056 .9189 L .50514 .91834 L .575 .788 0 r
F
.52239 .91214 m .51208 .91467 L .50946 .91496 L .232 .18 0 r
F
.51888 .91227 m .52239 .91214 L .50946 .91496 L .283 .188 0 r
F
.50672 .91255 m .51347 .91327 L .50966 .91595 L .728 .966 0 r
F
.5018 .92339 m .49662 .92537 L .49381 .92498 L .326 .193 0 r
F
.52088 .92257 m .50498 .92324 L .50329 .92418 L .115 0 0 r
F
.5018 .92339 m .50552 .92373 L .49662 .92537 L .326 .193 0 r
F
.52345 .92158 m .50666 .92217 L .50498 .92324 L .147 0 0 r
F
.52345 .92158 m .52598 .92047 L .50666 .92217 L F
.52088 .92257 m .52345 .92158 L .50498 .92324 L .115 0 0 r
F
.50922 .92149 m .50552 .92373 L .5018 .92339 L .384 .286 0 r
F
.49953 .92383 m .50408 .92291 L .50013 .92439 L .5 .673 0 r
F
.49805 .9229 m .5018 .92339 L .49381 .92498 L .369 .262 0 r
F
.49998 .92044 m .49805 .9229 L .49427 .92225 L .471 .524 0 r
F
.49781 .92219 m .50107 .92257 L .49953 .92383 L .5 .673 0 r
F
.50107 .92257 m .50408 .92291 L .49953 .92383 L F
.52129 .90855 m .51534 .91225 L .51177 .91207 L .486 .493 0 r
F
.51687 .90811 m .52129 .90855 L .51177 .91207 L .537 .641 0 r
F
.50926 .90963 m .51347 .91327 L .50747 .91263 L .769 .998 0 r
F
.50926 .90963 m .50747 .91263 L .50672 .91255 L F
.50795 .90663 m .51242 .90748 L .50456 .91121 L .714 .915 0 r
F
.51418 .9019 m .51242 .90748 L .50795 .90663 L .86 1 0 r
F
.52598 .92047 m .52849 .91923 L .50831 .92097 L .177 0 0 r
F
.51056 .9189 m .50922 .92149 L .50461 .92105 L .478 .543 0 r
F
.50926 .90963 m .51649 .9103 L .51347 .91327 L .769 .998 0 r
F
.5031 .92229 m .50743 .92128 L .50408 .92291 L .518 .734 0 r
F
.50406 .92098 m .50743 .92128 L .5031 .92229 L F
.50056 .92067 m .50408 .92291 L .49781 .92219 L F
.50211 .91951 m .50421 .91973 L .50056 .92067 L .537 .775 0 r
F
.50421 .91973 m .50298 .92088 L .50056 .92067 L F
.50205 .92162 m .50406 .92098 L .5031 .92229 L .518 .734 0 r
F
.50056 .92067 m .50294 .92088 L .50205 .92162 L F
.50294 .92088 m .50406 .92098 L .50205 .92162 L F
.49701 .91885 m .50211 .91951 L .49994 .9113 L 1 .451 0 r
F
.49515 .92036 m .4998 .91159 L .49501 .92048 L 0 0 0 r
F
.49501 .92048 m .50056 .92067 L .49781 .92219 L .605 .854 0 r
F
.49253 .92197 m .49457 .92359 L .49104 .92292 L .571 .81 0 r
F
.49501 .92048 m .49781 .92219 L .4938 .92154 L .605 .854 0 r
F
.49025 .92334 m .49457 .92359 L .48985 .92356 L .527 .741 0 r
F
.49091 .92289 m .49457 .92359 L .48964 .92331 L F
.49457 .92359 m .49564 .92571 L .4909 .92483 L .475 .596 0 r
F
.49262 .92192 m .49715 .91434 L .49253 .92197 L .064 0 0 r
F
.49342 .92147 m .49364 .92151 L .49251 .92195 L .571 .81 0 r
F
.49364 .92151 m .49781 .92219 L .49257 .92195 L F
.49364 .92151 m .49257 .92195 L .49251 .92195 L F
.48964 .92331 m .4909 .92483 L .48789 .92415 L .527 .741 0 r
F
.48964 .92331 m .48789 .92415 L .48763 .92409 L F
.48964 .92331 m .49407 .91672 L .49062 .91859 L .2 0 0 r
F
.48961 .92346 m .48974 .92326 L .48964 .92331 L F
.48974 .92326 m .49407 .91672 L .48964 .92331 L F
.4909 .92483 m .49564 .92571 L .49071 .92685 L .444 .508 0 r
F
.49168 .92477 m .49253 .92197 L .48912 .92578 L .064 0 0 r
F
.49253 .92197 m .4942 .91647 L .49081 .92269 L F
.49253 .92197 m .49104 .92292 L .49072 .92285 L .571 .81 0 r
F
.49253 .92197 m .49081 .92269 L .49072 .92285 L .064 0 0 r
F
.49061 .92306 m .49072 .92285 L .48961 .92346 L .2 0 0 r
F
.49072 .92285 m .49407 .91672 L .48974 .92327 L F
.48899 .92253 m .49072 .92285 L .48964 .92331 L .527 .741 0 r
F
.49072 .92285 m .49091 .92289 L .48964 .92331 L F
.49072 .92285 m .48974 .92327 L .48965 .92339 L .2 0 0 r
F
.49072 .92285 m .48965 .92339 L .48961 .92346 L F
.49245 .92198 m .49072 .92285 L .48899 .92253 L .571 .81 0 r
F
.49253 .92197 m .49072 .92285 L .49245 .92198 L F
.49253 .92197 m .49072 .92285 L .48912 .92578 L .064 0 0 r
F
.4933 .9217 m .49342 .92147 L .49248 .92214 L F
.49342 .92147 m .49733 .91405 L .49261 .92193 L F
.49342 .92147 m .49261 .92193 L .49248 .92214 L F
.49253 .92197 m .49781 .92219 L .49457 .92359 L .571 .81 0 r
F
.49251 .92195 m .49256 .92195 L .49253 .92197 L F
.49256 .92195 m .49781 .92219 L .49253 .92197 L F
.49258 .92182 m .49715 .91434 L .4942 .91647 L .064 0 0 r
F
.49253 .92197 m .49265 .92178 L .49258 .92182 L F
.49265 .92178 m .49715 .91434 L .49258 .92182 L F
.49152 .92116 m .49342 .92147 L .49251 .92195 L .571 .81 0 r
F
.49501 .92048 m .49352 .92128 L .49342 .92147 L 0 0 0 r
F
.4948 .92075 m .49342 .92147 L .49168 .92477 L F
.49501 .92048 m .49733 .91405 L .49352 .92128 L F
.49501 .92048 m .4938 .92154 L .49152 .92116 L .605 .854 0 r
F
.49501 .92048 m .49342 .92147 L .4948 .92075 L 0 0 0 r
F
.49385 .92367 m .49501 .92048 L .49168 .92477 L F
.4958 .91997 m .49592 .91999 L .49496 .92045 L .605 .854 0 r
F
.49592 .91999 m .50056 .92067 L .49505 .92046 L F
.49592 .91999 m .49505 .92046 L .49496 .92045 L F
.49496 .92045 m .49504 .92046 L .49501 .92048 L F
.49504 .92046 m .50056 .92067 L .49501 .92048 L F
.4954 .92052 m .49568 .91995 L .49485 .92092 L 0 0 0 r
F
.49568 .91995 m .4998 .91159 L .49513 .92038 L F
.49568 .91995 m .49513 .92038 L .49485 .92092 L F
.49701 .91885 m .4971 .91861 L .4958 .91972 L 1 .451 0 r
F
.4971 .91861 m .49994 .9113 L .49594 .91943 L F
.4971 .91861 m .49594 .91943 L .4958 .91972 L F
.49994 .9113 m .50672 .91255 L .50351 .91519 L .817 1 0 r
F
.50211 .91951 m .50672 .91255 L .49994 .9113 L 0 0 0 r
F
.50415 .91991 m .50421 .91973 L .50211 .91951 L F
.50421 .91973 m .50672 .91255 L .50214 .91946 L F
.50421 .91973 m .50214 .91946 L .50211 .91951 L F
.50424 .91963 m .50914 .90989 L .50672 .91255 L F
.50421 .91973 m .50427 .9196 L .50424 .91963 L F
.50427 .9196 m .50914 .90989 L .50424 .91963 L F
.50485 .91917 m .50914 .90989 L .5043 .91964 L F
.50431 .91963 m .50914 .90989 L .50421 .91973 L F
.50276 .91903 m .50501 .9195 L .50421 .91973 L .537 .775 0 r
F
.50501 .9195 m .50891 .92032 L .50479 .9198 L F
.50501 .9195 m .50479 .9198 L .50421 .91973 L F
.50623 .91976 m .51013 .91953 L .50891 .92032 L F
.50457 .91941 m .50633 .91945 L .50623 .91976 L F
.50633 .91945 m .51013 .91953 L .50623 .91976 L F
.51943 .90297 m .51687 .90811 L .51242 .90748 L .763 .981 0 r
F
.51418 .9019 m .51943 .90297 L .51242 .90748 L .86 1 0 r
F
.51109 .90652 m .51649 .9103 L .51 .9097 L .791 1 0 r
F
.51109 .90652 m .51 .9097 L .50926 .90963 L F
.50966 .91595 m .51578 .91645 L .51056 .9189 L .575 .788 0 r
F
.53611 .91011 m .52233 .9121 L .51981 .91294 L 0 0 0 r
F
.53273 .91084 m .51981 .91294 L .51726 .91365 L F
.53273 .91084 m .53611 .91011 L .51981 .91294 L F
.51896 .91326 m .51468 .91423 L .51208 .91467 L .183 .172 0 r
F
.52587 .91185 m .52018 .91306 L .51896 .91326 L F
.52018 .91306 m .51468 .91423 L .51896 .91326 L F
.52931 .91142 m .53273 .91084 L .52375 .91247 L .136 .163 0 r
F
.52267 .91265 m .52375 .91247 L .51726 .91365 L F
.52931 .91142 m .52375 .91247 L .52267 .91265 L F
.52239 .91214 m .52587 .91185 L .51208 .91467 L .232 .18 0 r
F
.51347 .91327 m .51578 .91645 L .50966 .91595 L .65 .884 0 r
F
.50737 .91622 m .51339 .91579 L .51213 .91768 L .544 .794 0 r
F
.50736 .91622 m .51018 .90868 L .50656 .91731 L .697 .185 0 r
F
.51056 .9189 m .51595 .91928 L .50922 .92149 L .478 .543 0 r
F
.51578 .91645 m .51595 .91928 L .51056 .9189 L .524 .68 0 r
F
.50612 .91799 m .51213 .91768 L .51013 .91953 L .549 .795 0 r
F
.50613 .91798 m .51213 .91768 L .50612 .91799 L F
.50612 .91799 m .511 .90672 L .50926 .90963 L 0 0 0 r
F
.50612 .91799 m .50926 .90963 L .50491 .91904 L F
.50438 .91732 m .50612 .91799 L .50276 .91903 L .549 .795 0 r
F
.50672 .91743 m .50693 .91744 L .50612 .91798 L F
.50693 .91744 m .51213 .91768 L .50675 .91795 L F
.50693 .91744 m .50675 .91795 L .50612 .91798 L F
.50612 .91799 m .51013 .91953 L .5053 .9192 L F
.50654 .91736 m .511 .90672 L .50617 .91791 L 0 0 0 r
F
.50617 .91791 m .511 .90672 L .50612 .91799 L F
.5054 .91561 m .50755 .91566 L .50737 .91622 L .544 .794 0 r
F
.5054 .91561 m .50737 .91622 L .50438 .91732 L F
.50737 .91622 m .50798 .9164 L .50652 .91742 L F
.50798 .9164 m .51213 .91768 L .50798 .91749 L F
.50798 .9164 m .50798 .91749 L .50652 .91742 L F
.511 .90672 m .51109 .90652 L .50926 .90963 L 0 0 0 r
F
.50892 .90052 m .51418 .9019 L .50795 .90663 L .953 1 0 r
F
.51352 .89425 m .51418 .9019 L .50892 .90052 L 1 1 0 r
F
.50799 .91439 m .51256 .90023 L .51219 .90331 L .861 .206 0 r
F
.50736 .91622 m .50736 .91622 L .50652 .91742 L .697 .185 0 r
F
.50736 .91622 m .50656 .91731 L .50652 .91742 L F
.50737 .91622 m .50652 .91742 L .50438 .91732 L .544 .794 0 r
F
.50733 .91632 m .50737 .91622 L .50652 .91742 L .697 .185 0 r
F
.50726 .91651 m .50733 .91632 L .50644 .91759 L F
.50457 .91941 m .51013 .91953 L .50457 .91941 L .537 .775 0 r
F
.50485 .91917 m .51013 .91953 L .50457 .91941 L F
.50421 .91973 m .50891 .92032 L .50743 .92128 L F
.50421 .91973 m .50743 .92128 L .50298 .92088 L F
.50577 .92038 m .50726 .91651 L .50471 .92172 L .697 .185 0 r
F
.50652 .91742 m .50672 .91743 L .50611 .91796 L .549 .795 0 r
F
.50726 .91651 m .50644 .91759 L .50471 .92172 L .697 .185 0 r
F
.50581 .91401 m .50794 .91451 L .5054 .91561 L .526 .775 0 r
F
.50794 .91451 m .50755 .91566 L .5054 .91561 L F
.50789 .91465 m .50794 .91451 L .5075 .91578 L .861 .206 0 r
F
.50794 .91451 m .51219 .90331 L .50756 .91561 L F
.50737 .91622 m .51215 .90341 L .51109 .90652 L .697 .185 0 r
F
.50739 .91616 m .51215 .90341 L .50737 .91622 L F
.50741 .91602 m .51219 .90331 L .50726 .91651 L F
.50794 .91451 m .5139 .91391 L .51339 .91579 L .526 .775 0 r
F
.50797 .91445 m .50799 .9138 L .50799 .91439 L .861 .206 0 r
F
.50794 .91451 m .50796 .91433 L .50797 .91445 L F
.50796 .91433 m .50799 .9138 L .50797 .91445 L F
.50784 .91301 m .50793 .91399 L .50581 .91401 L .507 .744 0 r
F
.50914 .90989 m .50926 .90963 L .50672 .91255 L 0 0 0 r
F
.50784 .913 m .51256 .90023 L .50793 .91399 L 1 .486 0 r
F
.50785 .913 m .50785 .91303 L .50784 .91301 L .507 .744 0 r
F
.50785 .91303 m .50793 .91399 L .50784 .91301 L F
.50784 .913 m .51222 .89758 L .51256 .90023 L 1 .486 0 r
F
.50561 .91266 m .50784 .913 L .50581 .91401 L .507 .744 0 r
F
.50784 .913 m .50784 .91301 L .50581 .91401 L F
.50581 .91401 m .50793 .91399 L .50794 .91451 L .526 .775 0 r
F
.50793 .91399 m .50793 .91397 L .50794 .91451 L .861 .206 0 r
F
.50793 .91397 m .50799 .9138 L .50794 .91451 L F
.50799 .9138 m .51256 .90023 L .50799 .91439 L F
.50793 .91399 m .50813 .91398 L .50794 .91451 L .526 .775 0 r
F
.50621 .91908 m .50793 .91399 L .50794 .91451 L .861 .206 0 r
F
.50438 .91732 m .50652 .91742 L .5061 .91798 L .549 .795 0 r
F
.52931 .91142 m .51726 .91365 L .51468 .91423 L .136 .163 0 r
F
.52587 .91185 m .52931 .91142 L .51468 .91423 L .183 .172 0 r
F
.51347 .91327 m .52018 .91368 L .51578 .91645 L .65 .884 0 r
F
.52569 .9088 m .51888 .91227 L .51534 .91225 L .435 .346 0 r
F
.52129 .90855 m .52569 .9088 L .51534 .91225 L .486 .493 0 r
F
.51649 .9103 m .52018 .91368 L .51347 .91327 L .713 .952 0 r
F
.50784 .913 m .51365 .91216 L .5139 .91391 L .507 .744 0 r
F
.50561 .91266 m .50766 .91253 L .50784 .913 L F
.50766 .91253 m .51222 .89758 L .50788 .91286 L 1 .486 0 r
F
.50766 .91253 m .50788 .91286 L .50784 .913 L F
.50711 .91184 m .50766 .91253 L .50561 .91266 L .508 .718 0 r
F
.50706 .9118 m .51222 .89758 L .50766 .91253 L 1 .723 0 r
F
.50718 .9118 m .50734 .91205 L .50711 .91184 L .508 .718 0 r
F
.50734 .91205 m .50766 .91253 L .50711 .91184 L F
.50755 .89189 m .51352 .89425 L .50892 .90052 L 1 1 0 r
F
.50706 .9118 m .51122 .89562 L .51222 .89758 L 1 .723 0 r
F
.5048 .91167 m .50706 .9118 L .50561 .91266 L .508 .718 0 r
F
.50706 .9118 m .5071 .91184 L .50561 .91266 L F
.50706 .9118 m .51265 .9106 L .51365 .91216 L F
.5048 .91167 m .50676 .91141 L .50706 .9118 L F
.50676 .91141 m .51122 .89562 L .50706 .9118 L 1 .723 0 r
F
.50676 .91141 m .51265 .9106 L .50706 .9118 L .508 .718 0 r
F
.50674 .9115 m .50676 .91141 L .50706 .9118 L 1 .723 0 r
F
.50521 .91691 m .50674 .9115 L .50706 .9118 L F
.50521 .91691 m .50706 .9118 L .50602 .91791 L F
.50706 .9118 m .50766 .91253 L .50602 .91791 L F
.50706 .9118 m .50718 .9118 L .5071 .91184 L .508 .718 0 r
F
.50718 .9118 m .51365 .91216 L .50766 .91253 L F
.50766 .91253 m .51365 .91216 L .50784 .913 L .507 .744 0 r
F
.50765 .91256 m .50766 .91253 L .50784 .913 L 1 .486 0 r
F
.50602 .91791 m .50765 .91256 L .50784 .913 L F
.50672 .91743 m .50612 .91798 L .50617 .91792 L .549 .795 0 r
F
.50633 .91787 m .50654 .91736 L .50599 .91834 L 0 0 0 r
F
.50654 .91736 m .50617 .91791 L .50599 .91834 L F
.50599 .91834 m .50617 .91791 L .50612 .91799 L F
.50617 .91792 m .50612 .91798 L .5061 .91798 L .549 .795 0 r
F
.50733 .91632 m .50652 .91742 L .50644 .91759 L .697 .185 0 r
F
.50652 .91742 m .50611 .91796 L .5061 .91798 L .549 .795 0 r
F
.5061 .91798 m .50613 .91798 L .50612 .91799 L F
.50602 .91791 m .50784 .913 L .50621 .91908 L 1 .486 0 r
F
.50784 .913 m .50793 .91399 L .50621 .91908 L F
.50784 .913 m .50785 .913 L .50784 .91301 L .507 .744 0 r
F
.50785 .913 m .5139 .91391 L .50793 .91399 L F
.50813 .91398 m .5139 .91391 L .50794 .91451 L .526 .775 0 r
F
.50794 .91451 m .50756 .91561 L .50755 .91566 L .861 .206 0 r
F
.50794 .91451 m .50755 .91566 L .5075 .91578 L F
.50794 .91451 m .50796 .91567 L .50755 .91566 L .526 .775 0 r
F
.50794 .91451 m .51339 .91579 L .50796 .91567 L F
.50621 .91908 m .50789 .91465 L .50577 .92038 L .861 .206 0 r
F
.50789 .91465 m .5075 .91578 L .50577 .92038 L F
.50612 .91799 m .5053 .9192 L .50485 .91917 L .549 .795 0 r
F
.50612 .91799 m .50491 .91904 L .50485 .91917 L 0 0 0 r
F
.50612 .91799 m .50485 .91917 L .50276 .91903 L .549 .795 0 r
F
.50612 .91799 m .50485 .91917 L .50476 .91936 L 0 0 0 r
F
.50726 .91651 m .50739 .91616 L .50737 .91622 L .697 .185 0 r
F
.50755 .91566 m .50778 .91566 L .50737 .91622 L .544 .794 0 r
F
.50778 .91566 m .51339 .91579 L .50737 .91622 L F
.51215 .90341 m .51219 .90331 L .51109 .90652 L .697 .185 0 r
F
.50577 .92038 m .50741 .91602 L .50726 .91651 L F
.50462 .91965 m .50485 .91917 L .50408 .92009 L 0 0 0 r
F
.50485 .91917 m .5043 .91964 L .50408 .92009 L F
.50457 .91941 m .50457 .91941 L .50457 .91941 L .537 .775 0 r
F
.50276 .91903 m .50485 .91917 L .50457 .91941 L F
.50599 .91834 m .50607 .91812 L .50476 .91936 L 0 0 0 r
F
.50607 .91812 m .50612 .91799 L .50552 .91859 L F
.50607 .91812 m .50552 .91859 L .50476 .91936 L F
.49896 .91731 m .50438 .91732 L .50276 .91903 L .599 .853 0 r
F
.4966 .91625 m .49984 .91669 L .49896 .91731 L F
.49984 .91669 m .50438 .91732 L .49896 .91731 L F
.49535 .91801 m .49701 .91885 L .49365 .91965 L .617 .87 0 r
F
.49701 .91885 m .50056 .92067 L .49568 .91995 L F
.49701 .91885 m .4958 .91972 L .49568 .91995 L 1 .451 0 r
F
.49701 .91885 m .49568 .91995 L .49365 .91965 L .617 .87 0 r
F
.49701 .91885 m .49568 .91995 L .49385 .92367 L 1 .451 0 r
F
.4956 .92249 m .49701 .91885 L .49385 .92367 L F
.49704 .91883 m .49895 .91889 L .49917 .91913 L .617 .87 0 r
F
.49694 .91882 m .49705 .91882 L .49704 .91883 L F
.49705 .91882 m .49895 .91889 L .49704 .91883 L F
.49701 .91885 m .49917 .91913 L .50056 .92067 L F
.49694 .91882 m .49917 .91913 L .49701 .91885 L F
.49895 .91889 m .50211 .91951 L .50056 .92067 L F
.49684 .9193 m .50211 .91951 L .49701 .91885 L 1 .451 0 r
F
.49781 .92219 m .50013 .92439 L .49457 .92359 L .5 .673 0 r
F
.4956 .92249 m .50305 .92306 L .50211 .91951 L 1 .451 0 r
F
.4956 .92249 m .50211 .91951 L .49684 .9193 L F
.50276 .91903 m .50391 .91958 L .50211 .91951 L .537 .775 0 r
F
.50391 .91958 m .50421 .91973 L .50211 .91951 L F
.50408 .92009 m .50431 .91963 L .50421 .91973 L 0 0 0 r
F
.50471 .92172 m .50599 .91834 L .50305 .92306 L F
.50599 .91834 m .50476 .91936 L .50305 .92306 L F
.50471 .92172 m .50633 .91787 L .50599 .91834 L F
.50305 .92306 m .50462 .91965 L .50408 .92009 L F
.50305 .92306 m .50415 .91991 L .50211 .91951 L F
.49895 .91889 m .50276 .91903 L .50211 .91951 L .617 .87 0 r
F
.49535 .91801 m .49758 .91831 L .49694 .91882 L F
.49758 .91831 m .50276 .91903 L .49694 .91882 L F
.49365 .91965 m .4958 .91997 L .49496 .92045 L .605 .854 0 r
F
.49248 .92214 m .49262 .92192 L .49253 .92197 L .064 0 0 r
F
.49152 .92116 m .49253 .92197 L .48899 .92253 L .571 .81 0 r
F
.49365 .91965 m .49501 .92048 L .49152 .92116 L .605 .854 0 r
F
.49485 .92092 m .49515 .92036 L .49501 .92048 L 0 0 0 r
F
.49385 .92367 m .4954 .92052 L .49485 .92092 L F
.4998 .91159 m .49994 .9113 L .49733 .91405 L F
.49715 .91434 m .49733 .91405 L .4942 .91647 L .064 0 0 r
F
.49168 .92477 m .4933 .9217 L .49248 .92214 L F
.48964 .92331 m .49025 .92334 L .48985 .92356 L .527 .741 0 r
F
.48899 .92253 m .48964 .92331 L .48612 .92374 L F
.48964 .92331 m .48763 .92409 L .48612 .92374 L F
.48961 .92346 m .48964 .92331 L .48763 .92409 L .2 0 0 r
F
.48912 .92578 m .48961 .92346 L .48622 .92668 L F
.48961 .92346 m .48763 .92409 L .48622 .92668 L F
.48753 .92427 m .48763 .92409 L .48636 .92463 L .301 0 0 r
F
.48763 .92409 m .48648 .92446 L .48636 .92463 L F
.48612 .92374 m .48763 .92409 L .48705 .92427 L .498 .652 0 r
F
.48912 .92578 m .49061 .92306 L .48961 .92346 L .2 0 0 r
F
.49407 .91672 m .4942 .91647 L .49062 .91859 L F
.48636 .92463 m .48649 .92445 L .48637 .92449 L .301 0 0 r
F
.48636 .92463 m .48637 .92449 L .48505 .9241 L F
.48463 .92398 m .48505 .9241 L .48493 .92384 L 1 .376 0 r
F
.4819 .92322 m .48493 .92384 L .4828 .91916 L F
.48328 .92339 m .48612 .92374 L .48505 .9241 L .605 .834 0 r
F
.48622 .92668 m .48636 .92463 L .48505 .9241 L .301 0 0 r
F
.48622 .92668 m .48753 .92427 L .48636 .92463 L F
.48139 .92549 m .48622 .92668 L .48505 .9241 L 1 .376 0 r
F
.48139 .92549 m .48505 .9241 L .48463 .92398 L F
.48132 .92235 m .48303 .92285 L .4819 .92322 L .605 .834 0 r
F
.48303 .92285 m .48612 .92374 L .4819 .92322 L F
.48188 .92319 m .4819 .92322 L .48185 .92321 L F
.47953 .9257 m .48247 .92684 L .47787 .92759 L .424 .446 0 r
F
.48139 .92549 m .48181 .92364 L .47909 .92624 L 1 .376 0 r
F
.47922 .92426 m .47953 .9257 L .47756 .92483 L .535 .725 0 r
F
.47909 .92624 m .47922 .92426 L .4766 .92688 L .309 0 0 r
F
.47922 .92426 m .47944 .92079 L .47756 .92483 L F
.47922 .92426 m .47756 .92483 L .4766 .92688 L F
.4776 .92473 m .47944 .92079 L .47634 .92514 L .381 0 0 r
F
.47904 .92345 m .47922 .92426 L .47657 .92439 L .535 .725 0 r
F
.47922 .92426 m .47756 .92483 L .47657 .92439 L F
.48181 .92364 m .4802 .92411 L .47909 .92624 L 1 .376 0 r
F
.48132 .92235 m .48188 .92319 L .47904 .92345 L .605 .834 0 r
F
.48188 .92319 m .48032 .92389 L .47904 .92345 L F
.47904 .92345 m .48032 .92389 L .47922 .92426 L .535 .725 0 r
F
.4792 .92442 m .47934 .92422 L .47922 .92426 L .309 0 0 r
F
.47909 .92624 m .4802 .92411 L .4792 .92442 L F
.47634 .92514 m .47669 .9252 L .47628 .92533 L .49 .599 0 r
F
.47756 .92483 m .4776 .92473 L .47634 .92514 L .381 0 0 r
F
.47657 .92439 m .47756 .92483 L .47634 .92514 L .49 .599 0 r
F
.4766 .92688 m .47756 .92483 L .47634 .92514 L .381 0 0 r
F
.47634 .92514 m .47593 .92646 L .47472 .92566 L .49 .599 0 r
F
.47593 .92646 m .47787 .92759 L .47311 .92817 L .383 .347 0 r
F
.4766 .92688 m .47634 .92514 L .47398 .92741 L .381 0 0 r
F
.47634 .92514 m .47588 .92213 L .47463 .92561 L F
.47634 .92514 m .47472 .92566 L .47463 .92561 L .49 .599 0 r
F
.47634 .92514 m .47463 .92561 L .47398 .92741 L .381 0 0 r
F
.47634 .92514 m .47463 .92561 L .47397 .92517 L .49 .599 0 r
F
.47657 .92439 m .47634 .92514 L .47397 .92517 L F
.47651 .92044 m .47904 .92345 L .47511 .92175 L .831 1 0 r
F
.47651 .92044 m .48132 .92235 L .47904 .92345 L F
.47511 .92175 m .47904 .92345 L .47657 .92439 L .737 .958 0 r
F
.48003 .92455 m .48349 .92463 L .48139 .92549 L .668 .913 0 r
F
.47783 .92305 m .48055 .92381 L .47998 .92452 L F
.48339 .92109 m .48612 .92374 L .48132 .92235 L .673 .915 0 r
F
.47895 .92201 m .48349 .92463 L .47783 .92305 L .707 .949 0 r
F
.48181 .92366 m .48533 .92368 L .48349 .92463 L F
.47895 .92201 m .48194 .92279 L .48158 .92353 L F
.47777 .91888 m .48339 .92109 L .48132 .92235 L .89 1 0 r
F
.4905 .91737 m .47998 .91926 L .47914 .91921 L .192 .174 0 r
F
.4905 .91737 m .49228 .91746 L .47998 .91926 L F
.48871 .91714 m .47914 .91921 L .47829 .91904 L .243 .182 0 r
F
.48871 .91714 m .4905 .91737 L .47914 .91921 L F
.47506 .91532 m .47894 .91756 L .47652 .91939 L 1 1 0 r
F
.47641 .91228 m .47894 .91756 L .47506 .91532 L F
.47729 .91411 m .48117 .91534 L .47894 .91756 L F
.47641 .91228 m .47772 .91312 L .47729 .91411 L F
.47772 .91312 m .48117 .91534 L .47729 .91411 L F
.47761 .90821 m .48117 .91534 L .47641 .91228 L F
.48056 .85164 m .48272 .85455 L .48222 .87777 L .927 .502 0 r
F
.48272 .85455 m .48318 .85517 L .4829 .86171 L F
.48272 .85455 m .4829 .86171 L .48222 .87777 L F
.48107 .84581 m .48318 .85517 L .48056 .85164 L F
.48039 .82756 m .48318 .85517 L .47984 .84036 L F
.47984 .84036 m .48107 .84581 L .48056 .85164 L F
.47673 .79132 m .48039 .82756 L .47984 .84036 L F
.4787 .9104 m .4829 .91248 L .48117 .91534 L 1 1 0 r
F
.47898 .90929 m .48316 .91261 L .4787 .9104 L F
.48063 .89133 m .48065 .89135 L .48065 .89143 L F
.47677 .84938 m .48063 .89133 L .47603 .87907 L 1 .69 0 r
F
.47909 .87456 m .48214 .87768 L .48063 .89133 L F
.48214 .87768 m .48222 .87777 L .48215 .87832 L F
.48214 .87768 m .48215 .87832 L .48063 .89133 L F
.47997 .86604 m .48222 .87777 L .47909 .87456 L F
.48222 .87777 m .48523 .89682 L .48265 .89374 L 1 .854 0 r
F
.48215 .87832 m .48265 .89374 L .48063 .89133 L F
.48222 .87777 m .48265 .89374 L .48215 .87832 L F
.47852 .86841 m .47997 .86604 L .47909 .87456 L 1 .69 0 r
F
.47837 .85833 m .47997 .86604 L .47852 .86841 L F
.47697 .85044 m .47836 .85768 L .47697 .85156 L F
.47836 .85768 m .47997 .86604 L .47837 .85833 L F
.47836 .85768 m .47837 .85833 L .47697 .85156 L F
.47754 .82431 m .48161 .83965 L .47673 .79132 L 1 .722 0 r
F
.47764 .89206 m .48063 .89133 L .47864 .9001 L 1 .884 0 r
F
.47603 .87907 m .47852 .8857 L .47764 .89206 L F
.47852 .8857 m .48063 .89133 L .47764 .89206 L F
.47862 .90254 m .47933 .90412 L .47761 .90821 L 1 .875 0 r
F
.47933 .90412 m .47994 .90548 L .47903 .90933 L F
.47994 .90548 m .48316 .91261 L .47971 .90987 L F
.47994 .90548 m .47971 .90987 L .47903 .90933 L F
.47994 .90548 m .48468 .90906 L .48316 .91261 L F
.47862 .90254 m .48009 .90411 L .47994 .90548 L F
.48009 .90411 m .48129 .90539 L .47994 .90548 L F
.48129 .90539 m .48487 .90921 L .4816 .90673 L F
.48129 .90539 m .4816 .90673 L .47994 .90548 L F
.48022 .8967 m .48318 .85517 L .48161 .83965 L 1 .722 0 r
F
.48021 .89691 m .48023 .89672 L .48022 .8967 L F
.48023 .89672 m .48318 .85517 L .48022 .8967 L F
.48074 .89791 m .48318 .85517 L .48021 .89691 L F
.48148 .8849 m .48158 .86591 L .48181 .87908 L F
.48105 .89248 m .48121 .88006 L .48148 .8849 L F
.48092 .89108 m .48121 .88006 L .48105 .89248 L F
.48066 .89683 m .48158 .86591 L .48074 .89791 L F
.48029 .8964 m .48043 .89583 L .48064 .89725 L .944 .693 0 r
F
.47887 .9004 m .47886 .90052 L .47868 .9007 L 1 1 0 r
F
.47929 .89518 m .48016 .89737 L .47862 .90254 L .944 .693 0 r
F
.48016 .89737 m .48082 .89901 L .47982 .90062 L F
.48016 .89737 m .47982 .90062 L .47862 .90254 L F
.48059 .89688 m .48158 .86591 L .48064 .89728 L 1 .722 0 r
F
.48411 .89549 m .48523 .89682 L .485 .89736 L 1 1 0 r
F
.48523 .89682 m .48531 .89761 L .485 .89736 L F
.4854 .90041 m .48535 .89749 L .48531 .89761 L .22 .032 0 r
F
.48591 .91723 m .48558 .90004 L .4854 .90041 L F
.48222 .87777 m .48762 .88781 L .48523 .89682 L 1 .854 0 r
F
.48121 .88612 m .48729 .89929 L .48626 .90491 L .796 .486 0 r
F
.48121 .88006 m .48158 .86591 L .48148 .8849 L 1 .722 0 r
F
.48165 .86673 m .48162 .86471 L .48171 .86556 L F
.48165 .86673 m .48171 .86556 L .48226 .87126 L F
.48181 .87908 m .48165 .86673 L .48226 .87126 L F
.48158 .86591 m .48162 .86471 L .48181 .87908 L F
.48173 .86581 m .48318 .81648 L .48226 .87126 L F
.48162 .86471 m .48166 .86366 L .48173 .86581 L F
.48166 .86366 m .48318 .81648 L .48173 .86581 L F
.48192 .86104 m .48193 .86074 L .48169 .86273 L 1 .821 0 r
F
.48193 .86074 m .48246 .8419 L .48173 .86151 L F
.48193 .86074 m .48173 .86151 L .48169 .86273 L F
.48762 .88781 m .48798 .88817 L .4878 .88884 L 1 .983 0 r
F
.48783 .88964 m .48781 .88882 L .4878 .88884 L .236 .036 0 r
F
.48921 .87622 m .48851 .88303 L .48762 .88781 L 1 .815 0 r
F
.48318 .85517 m .48762 .88781 L .48222 .87777 L 1 .674 0 r
F
.48351 .85455 m .48798 .87962 L .48789 .89152 L .356 .064 0 r
F
.48025 .89657 m .48064 .89725 L .48074 .89791 L .944 .693 0 r
F
.48082 .89901 m .48129 .90539 L .4796 .90359 L F
.48082 .89901 m .4796 .90359 L .47963 .90307 L F
.48082 .89901 m .47963 .90307 L .47982 .90062 L F
.47963 .90307 m .47951 .90349 L .47976 .90117 L F
.47963 .90307 m .47976 .90117 L .47982 .90062 L F
.48043 .89583 m .48154 .86384 L .48059 .89688 L 1 .722 0 r
F
.48154 .86384 m .4821 .84755 L .48159 .86433 L F
.48154 .86384 m .48159 .86433 L .48059 .89688 L F
.4821 .84755 m .48318 .81648 L .48214 .84862 L F
.4821 .84755 m .48214 .84862 L .48059 .89688 L F
.48296 .82438 m .48287 .82534 L .4816 .86203 L 1 .821 0 r
F
.48163 .86193 m .4816 .86203 L .48107 .87749 L F
.48108 .87743 m .48107 .87749 L .48068 .88853 L F
.48163 .86193 m .48107 .87749 L .48108 .87743 L F
.48163 .86193 m .48068 .88853 L .48069 .88851 L F
.48296 .82438 m .48048 .8944 L .48049 .89428 L F
.48021 .89691 m .48018 .8972 L .47929 .89518 L .944 .693 0 r
F
.48014 .89548 m .48155 .84241 L .47754 .82431 L 1 .722 0 r
F
.4802 .89717 m .48025 .89543 L .48014 .89548 L F
.48025 .89543 m .48155 .84241 L .48014 .89548 L F
.47928 .89451 m .48018 .89662 L .47754 .82431 L F
.47982 .90062 m .47951 .90349 L .47862 .90254 L .944 .693 0 r
F
.47924 .90473 m .47903 .90933 L .47863 .90902 L 1 .875 0 r
F
.47933 .90412 m .47903 .90933 L .47924 .90473 L F
.47933 .90412 m .47863 .90902 L .47761 .90821 L F
.47697 .85156 m .47837 .85833 L .47852 .86841 L 1 .69 0 r
F
.47677 .84938 m .47697 .85044 L .47697 .85156 L F
.47761 .90821 m .47898 .90929 L .4787 .9104 L 1 1 0 r
F
.4735 .90328 m .47471 .90448 L .47389 .91047 L F
.47471 .90448 m .47636 .90613 L .47524 .9081 L F
.47471 .90448 m .47524 .9081 L .47389 .91047 L F
.47205 .91368 m .47488 .89436 L .47184 .91441 L 1 .329 0 r
F
.47319 .90553 m .47488 .89436 L .47298 .9068 L 0 0 0 r
F
.47405 .90003 m .475 .8879 L .47488 .89436 L 1 .329 0 r
F
.47228 .91145 m .4735 .90328 L .47185 .91323 L 0 0 0 r
F
.47205 .91368 m .4738 .89834 L .47405 .90003 L 1 .329 0 r
F
.4738 .89834 m .475 .8879 L .47405 .90003 L F
.47357 .91765 m .47248 .91929 L .472 .91947 L .934 1 0 r
F
.47117 .92254 m .47357 .91765 L .47149 .91564 L 0 0 0 r
F
.47145 .91697 m .47228 .91145 L .47137 .91629 L F
.47124 .91733 m .47137 .91629 L .47115 .91749 L F
.47117 .92254 m .47146 .91562 L .47096 .91954 L F
.47145 .91697 m .47137 .91629 L .47124 .91733 L F
.47145 .91597 m .47149 .91564 L .47146 .91562 L F
.47228 .91145 m .47185 .91323 L .47115 .91749 L F
.47197 .91171 m .47267 .90641 L .47198 .909 L F
.4727 .90392 m .47272 .90413 L .47214 .91229 L 1 .843 0 r
F
.47272 .90413 m .47273 .90429 L .47262 .90573 L F
.47272 .90413 m .47262 .90573 L .47214 .91229 L F
.472 .91345 m .47235 .91051 L .47205 .91368 L 1 .329 0 r
F
.47235 .91051 m .475 .8879 L .47228 .91166 L F
.47235 .91051 m .47228 .91166 L .47205 .91368 L F
.47304 .90093 m .47211 .87317 L .47284 .90184 L .382 .057 0 r
F
.47559 .86519 m .47597 .81211 L .47677 .84938 L 1 .843 0 r
F
.47478 .84475 m .47597 .81211 L .47559 .86519 L F
.47253 .90619 m .47478 .84475 L .47559 .86519 L F
.47597 .81211 m .47673 .79132 L .47676 .84341 L F
.47597 .81211 m .47676 .84341 L .47677 .84938 L F
.4735 .8775 m .4748 .84293 L .4735 .87918 L 1 .746 0 r
F
.4748 .84293 m .47478 .84475 L .47253 .90619 L F
.47284 .89527 m .4735 .8775 L .47253 .90619 L F
.4735 .8775 m .4735 .87918 L .47253 .90619 L F
.47284 .89527 m .47323 .89638 L .4738 .87928 L F
.4748 .84293 m .47598 .81141 L .47478 .84475 L F
.47598 .81141 m .47673 .79132 L .47597 .81211 L F
.47598 .81141 m .47597 .81211 L .47478 .84475 L F
.4735 .8775 m .4738 .87928 L .47673 .79132 L F
.47679 .80632 m .47836 .85768 L .47697 .85044 L .927 .502 0 r
F
.47673 .79132 m .47836 .85768 L .47679 .80632 L F
.47676 .84341 m .47697 .85044 L .47677 .84938 L F
.47673 .79132 m .47697 .85044 L .47676 .84341 L F
.4727 .90392 m .47405 .88587 L .47273 .90429 L 1 .843 0 r
F
.47559 .86519 m .47677 .84938 L .47555 .86592 L F
.47494 .84498 m .47815 .84876 L .47673 .79132 L 1 .746 0 r
F
.47405 .88587 m .47559 .86519 L .47397 .88736 L 1 .843 0 r
F
.47559 .86519 m .47555 .86592 L .47397 .88736 L F
.47405 .88587 m .47397 .88736 L .47273 .90429 L F
.47576 .8814 m .47677 .84938 L .47603 .87907 L 1 .749 0 r
F
.47241 .90999 m .47239 .91017 L .472 .91345 L F
.47241 .90999 m .472 .91345 L .47204 .91312 L F
.47241 .90999 m .47308 .90432 L .47239 .91017 L F
.47308 .90432 m .47427 .89411 L .47303 .90471 L F
.47427 .89411 m .47603 .87907 L .47417 .89493 L F
.47427 .89411 m .47417 .89493 L .47303 .90471 L F
.47308 .90432 m .47303 .90471 L .47239 .91017 L F
.47214 .91229 m .47555 .86592 L .47576 .8814 L F
.47555 .86592 m .47677 .84938 L .47576 .8814 L F
.475 .8879 m .47603 .87907 L .47488 .89436 L 1 .329 0 r
F
.47886 .90052 m .47878 .90077 L .47868 .9007 L 1 1 0 r
F
.47864 .9001 m .47891 .90033 L .47868 .9007 L F
.47488 .89436 m .47864 .9001 L .47636 .90613 L F
.47603 .87907 m .47864 .9001 L .47488 .89436 L 1 .884 0 r
F
.47323 .89638 m .47608 .90438 L .47815 .84876 L 1 .746 0 r
F
.47608 .90438 m .47929 .89518 L .47815 .84876 L F
.47323 .89638 m .47641 .86556 L .47494 .84498 L F
.47284 .89527 m .4738 .87928 L .4735 .8775 L F
.47301 .87128 m .47736 .89925 L .47284 .89527 L .462 .125 0 r
F
.47868 .89594 m .47938 .8942 L .47868 .89636 L 1 .901 0 r
F
.47866 .897 m .47938 .8942 L .47929 .89518 L 1 .962 0 r
F
.47535 .88513 m .47708 .89416 L .47527 .88581 L .462 .125 0 r
F
.47702 .89312 m .47861 .88626 L .47722 .89671 L 1 .901 0 r
F
.47708 .89416 m .47721 .89482 L .47709 .89426 L .462 .125 0 r
F
.47708 .89416 m .47709 .89426 L .47527 .88581 L F
.47722 .89671 m .47861 .88626 L .47861 .89613 L 1 .901 0 r
F
.47715 .89454 m .47724 .89567 L .47527 .88581 L .462 .125 0 r
F
.47721 .89482 m .47723 .89548 L .47715 .89454 L F
.47723 .89548 m .47724 .89567 L .47715 .89454 L F
.47736 .89925 m .47731 .89947 L .47284 .89527 L F
.47736 .89925 m .4774 .90032 L .47608 .90438 L 1 .901 0 r
F
.47741 .89957 m .47608 .90438 L .47284 .89527 L .462 .125 0 r
F
.47527 .88581 m .47714 .89516 L .47736 .89925 L F
.47316 .90976 m .47731 .89829 L .47736 .89925 L 1 .901 0 r
F
.47731 .89829 m .478 .89638 L .47736 .89925 L F
.47437 .87914 m .47704 .89346 L .47434 .87983 L .462 .125 0 r
F
.47731 .89829 m .47722 .89671 L .478 .89638 L 1 .901 0 r
F
.4774 .90062 m .47868 .89636 L .47866 .897 L 1 .962 0 r
F
.4774 .90032 m .47868 .89636 L .4774 .90062 L F
.47736 .89925 m .47868 .89594 L .4774 .90032 L 1 .901 0 r
F
.47868 .89594 m .47868 .89636 L .4774 .90032 L F
.47736 .89925 m .478 .89638 L .47861 .89613 L F
.47431 .91081 m .47608 .90438 L .47735 .90346 L 1 .962 0 r
F
.47732 .90519 m .47735 .90346 L .47862 .90254 L F
.47693 .90598 m .47735 .90346 L .47732 .90519 L F
.4729 .91422 m .47657 .90535 L .47693 .90598 L F
.47657 .90535 m .47735 .90346 L .47693 .90598 L F
.47316 .90976 m .47607 .8972 L .47722 .89671 L 1 .901 0 r
F
.47316 .90976 m .47722 .89671 L .47731 .89829 L F
.47704 .89346 m .47708 .89416 L .47434 .87983 L .462 .125 0 r
F
.47735 .90346 m .47929 .89518 L .47862 .90254 L 1 .962 0 r
F
.47608 .90438 m .4774 .90062 L .47735 .90346 L F
.4774 .90062 m .47929 .89518 L .47735 .90346 L F
.47911 .8664 m .47944 .86279 L .47918 .86965 L 1 .818 0 r
F
.47944 .86279 m .47952 .86554 L .47859 .88517 L F
.47859 .88517 m .47952 .86554 L .47984 .88099 L F
.47952 .86554 m .47986 .85829 L .47984 .87782 L F
.47952 .86554 m .47984 .87782 L .47984 .88099 L F
.47944 .86279 m .47986 .85829 L .47952 .86554 L F
.47641 .86556 m .47815 .84876 L .47494 .84498 L 1 .746 0 r
F
.47625 .85224 m .47822 .8757 L .47859 .88517 L .185 .03 0 r
F
.47512 .83404 m .47806 .87141 L .47515 .83619 L F
.47806 .87141 m .47812 .87312 L .47515 .83619 L F
.47803 .87074 m .47941 .86138 L .47823 .87592 L 1 .818 0 r
F
.47941 .86138 m .47986 .85829 L .47944 .86279 L F
.47941 .86138 m .47944 .86279 L .47823 .87592 L F
.48155 .84241 m .48152 .83931 L .47754 .82431 L 1 .722 0 r
F
.47827 .82639 m .47826 .81811 L .4785 .82462 L 1 .684 0 r
F
.47702 .79053 m .47714 .78811 L .47827 .82639 L F
.47714 .78811 m .47771 .80352 L .47827 .82639 L F
.47727 .78542 m .47824 .8076 L .47827 .82639 L F
.48003 .88146 m .48069 .88308 L .48006 .88183 L .796 .486 0 r
F
.48069 .88308 m .48069 .88313 L .48006 .88183 L F
.4808 .88334 m .48083 .88355 L .48078 .88345 L F
.48069 .88313 m .4807 .88326 L .48006 .88183 L F
.48113 .87718 m .48113 .87627 L .48049 .89428 L 1 .821 0 r
F
.48246 .8419 m .48113 .87627 L .48113 .87718 L F
.48246 .8419 m .48227 .84371 L .48113 .87627 L F
.48246 .8419 m .48049 .89428 L .48053 .89392 L F
.48192 .86104 m .48169 .86273 L .48116 .87707 L F
.48124 .87666 m .48116 .87707 L .48074 .88827 L F
.48192 .86104 m .48116 .87707 L .48124 .87666 L F
.48192 .86104 m .48074 .88827 L .48078 .88811 L F
.48192 .86104 m .48053 .89392 L .48061 .89315 L F
.48074 .89791 m .48092 .89108 L .48105 .89248 L 1 .722 0 r
F
.48116 .88684 m .48192 .86104 L .48058 .89399 L 1 .821 0 r
F
.48121 .88612 m .48626 .90491 L .48223 .89863 L .796 .486 0 r
F
.48121 .88612 m .48223 .89863 L .48043 .89583 L F
.48116 .88801 m .48192 .86104 L .48114 .88746 L 1 .821 0 r
F
.48116 .88801 m .48114 .88746 L .48099 .8925 L F
.48107 .89118 m .48116 .88801 L .48099 .8925 L F
.47984 .88099 m .48069 .88416 L .47949 .89333 L .796 .486 0 r
F
.48069 .88416 m .48121 .88612 L .48054 .8891 L F
.48059 .88641 m .48054 .8891 L .48046 .88946 L F
.48069 .88416 m .48054 .8891 L .48059 .88641 L F
.48093 .88264 m .48103 .86144 L .48115 .8853 L 1 .821 0 r
F
.48152 .87539 m .48103 .86144 L .48163 .8713 L F
.48108 .87077 m .48103 .86144 L .48152 .87539 L F
.48069 .88851 m .48068 .88853 L .48048 .8944 L F
.48074 .89791 m .482 .90136 L .4803 .89749 L .944 .693 0 r
F
.48074 .89791 m .4803 .89749 L .48031 .89737 L F
.48074 .89791 m .48018 .8972 L .48021 .89691 L F
.482 .90136 m .48202 .90199 L .47948 .89564 L F
.47948 .8956 m .47948 .89564 L .47929 .89518 L F
.482 .90136 m .47948 .89564 L .47948 .8956 L F
.47351 .87399 m .47715 .89381 L .47351 .87448 L .462 .125 0 r
F
.47715 .89381 m .47716 .89391 L .47351 .87448 L F
.47748 .8956 m .47747 .89579 L .47351 .87448 L F
.47434 .87983 m .47535 .88513 L .47527 .88581 L F
.48031 .89737 m .4803 .89749 L .48018 .8972 L .944 .693 0 r
F
.48452 .90826 m .48455 .90839 L .47948 .89564 L F
.47948 .89564 m .47948 .89564 L .47929 .89518 L F
.48452 .90826 m .47948 .89564 L .47948 .89564 L F
.47977 .91473 m .48074 .89791 L .48021 .89691 L 1 .722 0 r
F
.47984 .91367 m .48012 .90479 L .48031 .90533 L F
.47977 .91473 m .47983 .91325 L .47984 .91367 L F
.47983 .91325 m .48012 .90479 L .47984 .91367 L F
.48029 .8964 m .48064 .89725 L .48025 .89657 L .944 .693 0 r
F
.47977 .91473 m .4802 .89717 L .48018 .89662 L 1 .722 0 r
F
.47963 .90307 m .4796 .90359 L .47951 .90349 L .944 .693 0 r
F
.47977 .91473 m .48018 .89662 L .47928 .89451 L 1 .722 0 r
F
.47938 .8942 m .48074 .89791 L .47929 .89518 L .944 .693 0 r
F
.48012 .90479 m .48043 .89583 L .48031 .90533 L 1 .722 0 r
F
.48099 .89671 m .48122 .89706 L .48099 .89747 L .944 .693 0 r
F
.48122 .89706 m .48185 .89804 L .48124 .89764 L F
.48122 .89706 m .48124 .89764 L .48099 .89747 L F
.48185 .89804 m .48186 .89831 L .48098 .89755 L F
.48099 .89747 m .48098 .89755 L .48064 .89725 L F
.48185 .89804 m .48098 .89755 L .48099 .89747 L F
.47986 .85829 m .47993 .85866 L .47984 .88099 L .59 .244 0 r
F
.48081 .88346 m .48103 .86144 L .48092 .8842 L 1 .821 0 r
F
.48098 .86911 m .48082 .8811 L .48084 .88066 L 1 .816 0 r
F
.48296 .82438 m .4816 .86203 L .48163 .86193 L 1 .821 0 r
F
.48155 .84241 m .48161 .83965 L .48152 .83931 L 1 .722 0 r
F
.48103 .86144 m .48207 .76597 L .48163 .8713 L 1 .821 0 r
F
.48207 .76597 m .48208 .7646 L .48208 .76616 L F
.48207 .76597 m .48208 .76616 L .48163 .8713 L F
.48145 .82924 m .48122 .84806 L .48123 .84797 L 1 .816 0 r
F
.48187 .79311 m .48144 .82931 L .48145 .82924 L F
.48144 .82931 m .48122 .84806 L .48145 .82924 L F
.48296 .82438 m .48318 .81648 L .48287 .82534 L 1 .821 0 r
F
.48226 .87126 m .48318 .81648 L .48318 .85517 L 1 .722 0 r
F
.48246 .8419 m .48296 .82438 L .48227 .84371 L 1 .821 0 r
F
.48163 .8713 m .48208 .7646 L .48318 .81648 L F
.48262 .81815 m .48536 .83827 L .48474 .8425 L .283 .048 0 r
F
.48187 .79311 m .48174 .7961 L .48138 .82992 L 1 .816 0 r
F
.48141 .82958 m .48138 .82992 L .48117 .84843 L F
.48187 .79311 m .48138 .82992 L .48141 .82958 L F
.48187 .79311 m .48117 .84843 L .48122 .84806 L F
.48121 .88612 m .48108 .87077 L .48152 .87539 L 1 .821 0 r
F
.48115 .88569 m .48108 .87077 L .48121 .88612 L F
.48408 .85234 m .48399 .85266 L .48213 .84005 L .356 .064 0 r
F
.48146 .8459 m .48187 .79311 L .48123 .84797 L 1 .816 0 r
F
.48028 .73369 m .48022 .72236 L .48029 .73385 L 1 .747 0 r
F
.48082 .6477 m .48146 .64814 L .48042 .65055 L 1 .974 0 r
F
.482 .64312 m .48134 .64496 L .47992 .64442 L .852 1 0 r
F
.48026 .64252 m .482 .64312 L .47992 .64442 L .928 1 0 r
F
.48184 .6413 m .482 .64312 L .48026 .64252 L .909 1 0 r
F
.47981 .64062 m .48184 .6413 L .48026 .64252 L .975 1 0 r
F
.48094 .6395 m .48184 .6413 L .47981 .64062 L .935 1 0 r
F
.48092 .64694 m .48094 .6395 L .48082 .64767 L .271 .036 0 r
F
.47995 .64949 m .48034 .65074 L .47982 .65032 L 1 .974 0 r
F
.47995 .64949 m .48082 .6477 L .48034 .65074 L F
.48082 .6477 m .48042 .65055 L .48034 .65074 L F
.47995 .64911 m .48094 .6395 L .47981 .64062 L .381 .059 0 r
F
.48039 .67665 m .48082 .64763 L .47995 .64911 L F
.48082 .64763 m .48094 .6395 L .47995 .64911 L F
.482 .64312 m .48373 .64364 L .48134 .64496 L .852 1 0 r
F
.48094 .6395 m .48322 .64012 L .48184 .6413 L .935 1 0 r
F
.4819 .63844 m .48322 .64012 L .48094 .6395 L .892 1 0 r
F
.48171 .64479 m .4819 .63844 L .48164 .64541 L 1 .691 0 r
F
.48168 .6451 m .48164 .64541 L .48164 .64546 L F
.48171 .64479 m .48164 .64541 L .48168 .6451 L F
.48387 .64185 m .48373 .64364 L .482 .64312 L .848 1 0 r
F
.48184 .6413 m .48387 .64185 L .482 .64312 L .909 1 0 r
F
.48322 .64012 m .48387 .64185 L .48184 .6413 L .884 1 0 r
F
.48322 .64012 m .4855 .64061 L .48387 .64185 L F
.48439 .63898 m .4855 .64061 L .48322 .64012 L .855 1 0 r
F
.4819 .63844 m .48439 .63898 L .48322 .64012 L .892 1 0 r
F
.4826 .64539 m .48439 .63898 L .4819 .63844 L .152 .015 0 r
F
.49126 .64853 m .49226 .64836 L .48494 .64968 L .135 .163 0 r
F
.49126 .64853 m .48494 .64968 L .48428 .64984 L F
.49226 .64836 m .49325 .64814 L .48559 .64947 L 0 0 0 r
F
.49025 .64864 m .49126 .64853 L .48428 .64984 L .179 .171 0 r
F
.48865 .64859 m .48699 .64298 L .48637 .64329 L 1 .455 0 r
F
.48866 .64858 m .48699 .64298 L .48865 .64859 L F
.48836 .64679 m .48511 .64839 L .48406 .64817 L .485 .489 0 r
F
.48696 .64654 m .48836 .64679 L .48406 .64817 L .521 .591 0 r
F
.48551 .66342 m .48326 .66851 L .48205 .66774 L 1 1 0 r
F
.48551 .66342 m .4871 .66426 L .48326 .66851 L F
.48392 .6625 m .48551 .66342 L .48205 .66774 L F
.48672 .65872 m .48551 .66342 L .48392 .6625 L F
.48479 .65771 m .48392 .6625 L .48233 .66149 L F
.48479 .65771 m .48672 .65872 L .48392 .6625 L F
.48287 .65659 m .48479 .65771 L .48233 .66149 L F
.48475 .65337 m .48479 .65771 L .48287 .65659 L F
.48254 .65216 m .48475 .65337 L .48287 .65659 L F
.48391 .64947 m .48475 .65337 L .48254 .65216 L F
.48391 .64947 m .48637 .65057 L .48475 .65337 L F
.48924 .64829 m .48934 .64825 L .48929 .64826 L .031 0 0 r
F
.4892 .64832 m .48929 .64826 L .48915 .64833 L F
.48934 .64825 m .4893 .64825 L .48929 .64826 L .069 0 0 r
F
.48915 .64833 m .48934 .64825 L .48699 .64298 L 1 .455 0 r
F
.48983 .64793 m .48761 .64262 L .48935 .64825 L .874 .558 0 r
F
.48934 .64825 m .48761 .64262 L .48699 .64298 L F
.48935 .64825 m .48761 .64262 L .48934 .64825 L F
.48974 .64699 m .48615 .64855 L .48511 .64839 L .448 .385 0 r
F
.48836 .64679 m .48974 .64699 L .48511 .64839 L .485 .489 0 r
F
.48505 .64713 m .48637 .65057 L .48457 .64976 L 1 1 0 r
F
.48482 .64761 m .48457 .64976 L .48391 .64947 L F
.48505 .64713 m .48457 .64976 L .48482 .64761 L F
.48719 .64449 m .48557 .64623 L .48416 .64587 L .651 .854 0 r
F
.48546 .6441 m .48416 .64587 L .48275 .64544 L .715 .927 0 r
F
.48546 .6441 m .48719 .64449 L .48416 .64587 L F
.48373 .64364 m .48546 .6441 L .48275 .64544 L .782 .995 0 r
F
.48697 .65443 m .48672 .65872 L .48479 .65771 L 1 1 0 r
F
.48475 .65337 m .48697 .65443 L .48479 .65771 L F
.48637 .65057 m .48697 .65443 L .48475 .65337 L F
.48936 .64829 m .48936 .64828 L .48934 .64825 L 1 .455 0 r
F
.4892 .64832 m .48934 .64825 L .48924 .64829 L .031 0 0 r
F
.48984 .64794 m .48983 .64793 L .48937 .64831 L .874 .558 0 r
F
.48983 .64793 m .48935 .64825 L .48937 .64831 L F
.48986 .648 m .48984 .64796 L .48966 .6481 L F
.48986 .648 m .48966 .6481 L .48937 .64831 L F
.48984 .64796 m .48984 .64794 L .48976 .64801 L F
.48984 .64796 m .48976 .64801 L .48937 .64831 L F
.49616 .64718 m .48983 .64793 L .48934 .64825 L .069 0 0 r
F
.48937 .64831 m .48935 .64825 L .48934 .64825 L .874 .558 0 r
F
.49248 .64722 m .48822 .6487 L .48719 .64865 L .373 .201 0 r
F
.49111 .64713 m .48719 .64865 L .48615 .64855 L .411 .283 0 r
F
.49111 .64713 m .49248 .64722 L .48719 .64865 L F
.48974 .64699 m .49111 .64713 L .48615 .64855 L .448 .385 0 r
F
.48505 .64713 m .48772 .64807 L .48637 .65057 L 1 1 0 r
F
.48891 .64482 m .48696 .64654 L .48557 .64623 L .59 .775 0 r
F
.48719 .64449 m .48891 .64482 L .48557 .64623 L .651 .854 0 r
F
.48595 .64507 m .48772 .64807 L .48553 .6473 L 1 1 0 r
F
.4856 .64588 m .48553 .6473 L .48505 .64713 L F
.48595 .64507 m .48553 .6473 L .4856 .64588 L F
.4879 .64273 m .48719 .64449 L .48546 .6441 L .735 .958 0 r
F
.48589 .64233 m .4879 .64273 L .48546 .6441 L .79 1 0 r
F
.4849 .64689 m .48595 .64507 L .48505 .64713 L .992 .962 0 r
F
.48589 .64233 m .48546 .6441 L .48373 .64364 L .79 1 0 r
F
.48387 .64185 m .48589 .64233 L .48373 .64364 L .848 1 0 r
F
.4855 .64061 m .48589 .64233 L .48387 .64185 L .835 1 0 r
F
.48447 .64619 m .48439 .63898 L .48264 .64527 L .152 .015 0 r
F
.48447 .64619 m .48264 .64527 L .4826 .64539 L F
.4826 .64539 m .48447 .64619 L .48239 .64594 L .992 .962 0 r
F
.48447 .64619 m .48422 .64676 L .48239 .64594 L F
.48239 .64594 m .48505 .64713 L .48391 .64947 L 1 .991 0 r
F
.48126 .66002 m .48468 .66576 L .4826 .64539 L 1 .691 0 r
F
.48171 .64479 m .48164 .64546 L .48164 .64549 L F
.48167 .64517 m .4821 .64547 L .48166 .64526 L .975 .89 0 r
F
.48171 .64479 m .48164 .64549 L .48171 .64484 L 1 .691 0 r
F
.48092 .64699 m .4819 .63844 L .48094 .6395 L .271 .036 0 r
F
.48164 .64549 m .4819 .63844 L .48092 .64699 L F
.48171 .64484 m .48185 .64506 L .47988 .64391 L .975 .89 0 r
F
.48185 .64506 m .4821 .64547 L .48177 .64523 L F
.48185 .64506 m .48177 .64523 L .47988 .64391 L F
.48092 .64697 m .48146 .64814 L .48082 .6477 L 1 .932 0 r
F
.48092 .64697 m .48164 .64549 L .48139 .64798 L F
.48164 .64549 m .48239 .64594 L .48139 .64798 L F
.48087 .66678 m .48164 .64549 L .48092 .64699 L .271 .036 0 r
F
.4821 .64547 m .48197 .64569 L .47974 .64436 L .975 .89 0 r
F
.48171 .64484 m .48164 .64549 L .48087 .66678 L 1 .691 0 r
F
.47988 .64391 m .48167 .64517 L .47974 .64436 L .975 .89 0 r
F
.48167 .64517 m .48166 .64526 L .47974 .64436 L F
.48031 .64257 m .48171 .64484 L .47988 .64391 L F
.48178 .64488 m .4826 .64539 L .48239 .64594 L F
.4817 .64505 m .48259 .64528 L .48171 .64484 L 1 .691 0 r
F
.48174 .64482 m .4826 .64539 L .48178 .64488 L .975 .89 0 r
F
.4823 .64521 m .4826 .64539 L .48259 .64528 L 1 .691 0 r
F
.4817 .64505 m .4826 .64539 L .4823 .64521 L F
.48171 .64484 m .48259 .64528 L .4819 .63844 L F
.48171 .64484 m .48174 .64482 L .48239 .64594 L .975 .89 0 r
F
.4821 .64547 m .48239 .64594 L .48197 .64569 L F
.48126 .66002 m .4826 .64539 L .4817 .64505 L 1 .691 0 r
F
.48313 .64405 m .4844 .64609 L .4826 .64539 L .992 .962 0 r
F
.4844 .64609 m .48447 .64619 L .4826 .64539 L F
.48447 .64619 m .48505 .64713 L .48422 .64676 L F
.48439 .63898 m .48688 .63938 L .4855 .64061 L .855 1 0 r
F
.48532 .63788 m .48688 .63938 L .48439 .63898 L .824 1 0 r
F
.48447 .64619 m .48532 .63788 L .48439 .63898 L .152 .015 0 r
F
.48459 .64595 m .48516 .64478 L .48496 .64644 L .992 .962 0 r
F
.48516 .64478 m .48516 .6446 L .48468 .6457 L .152 .015 0 r
F
.48516 .64478 m .48468 .6457 L .48447 .64619 L F
.48516 .6446 m .48532 .63788 L .4845 .64589 L F
.48491 .64517 m .4845 .64589 L .48447 .64619 L F
.48516 .6446 m .4845 .64589 L .48491 .64517 L F
.48536 .64439 m .48615 .64366 L .48595 .64507 L .925 .94 0 r
F
.4855 .64061 m .48777 .641 L .48589 .64233 L .835 1 0 r
F
.48688 .63938 m .48777 .641 L .4855 .64061 L .82 1 0 r
F
.48532 .63788 m .48797 .63817 L .48688 .63938 L .824 1 0 r
F
.486 .63683 m .48797 .63817 L .48532 .63788 L .795 1 0 r
F
.486 .63683 m .48877 .63698 L .48797 .63817 L F
.48642 .63584 m .48877 .63698 L .486 .63683 L .768 .993 0 r
F
.48576 .6425 m .48642 .63584 L .486 .63683 L 0 0 0 r
F
.48529 .6443 m .48573 .64366 L .48536 .64439 L .925 .94 0 r
F
.48573 .64366 m .48611 .64311 L .48571 .64379 L F
.48573 .64366 m .48571 .64379 L .48536 .64439 L F
.48609 .64124 m .48642 .63584 L .48578 .64234 L 0 0 0 r
F
.48589 .64202 m .48578 .64234 L .48576 .6425 L F
.48609 .64124 m .48578 .64234 L .48589 .64202 L F
.48608 .64077 m .48642 .63584 L .48609 .64124 L F
.48576 .64241 m .486 .63683 L .48574 .64294 L F
.48523 .64412 m .48532 .63788 L .48516 .64471 L F
.48523 .64424 m .48534 .64409 L .48529 .6443 L .925 .94 0 r
F
.48534 .64409 m .48611 .64311 L .48529 .6443 L F
.48523 .64424 m .486 .63683 L .48532 .63788 L 0 0 0 r
F
.48574 .64301 m .48611 .64311 L .48571 .64362 L .925 .94 0 r
F
.48574 .64301 m .48571 .64362 L .48523 .64424 L F
.48576 .64241 m .48574 .64294 L .48574 .64301 L 0 0 0 r
F
.48606 .6411 m .48618 .64117 L .48606 .64117 L .791 .922 0 r
F
.48618 .64117 m .48608 .64147 L .48601 .64145 L F
.49632 .64159 m .48821 .64221 L .48761 .64262 L .126 0 0 r
F
.48777 .641 m .4879 .64273 L .48589 .64233 L .79 1 0 r
F
.4859 .64266 m .48643 .64216 L .48653 .6432 L .857 .925 0 r
F
.48574 .64299 m .486 .63683 L .48526 .64399 L 0 0 0 r
F
.48608 .64077 m .48609 .64124 L .48608 .64147 L F
.48576 .64254 m .4861 .64203 L .4859 .64266 L .857 .925 0 r
F
.48576 .64254 m .48609 .64124 L .48576 .6425 L 0 0 0 r
F
.48608 .64147 m .48609 .64124 L .48576 .64254 L F
.48398 .64103 m .48608 .64147 L .48576 .64254 L .857 .925 0 r
F
.48608 .64147 m .48623 .6415 L .48576 .64254 L F
.48623 .6415 m .48643 .64154 L .48624 .64183 L F
.48623 .6415 m .48624 .64183 L .48576 .64254 L F
.48642 .63584 m .48927 .63584 L .48877 .63698 L .768 .993 0 r
F
.48658 .63493 m .48927 .63584 L .48642 .63584 L .748 .98 0 r
F
.48608 .64077 m .48658 .63493 L .48642 .63584 L 0 0 0 r
F
.48617 .63953 m .48647 .63411 L .48658 .63493 L .849 .173 0 r
F
.48643 .64154 m .48698 .64165 L .4859 .64266 L .857 .925 0 r
F
.48398 .64103 m .48576 .64254 L .48366 .64242 L F
.48576 .64254 m .4859 .64266 L .48575 .64264 L F
.48576 .64254 m .48575 .64264 L .48366 .64242 L F
.48611 .64311 m .4866 .64325 L .48536 .64439 L .925 .94 0 r
F
.48576 .64257 m .48574 .64301 L .48564 .6453 L 0 0 0 r
F
.48576 .64251 m .48574 .64301 L .48576 .64257 L F
.4859 .64266 m .4866 .64325 L .48574 .64301 L .857 .925 0 r
F
.48576 .64241 m .48574 .64301 L .48576 .64251 L 0 0 0 r
F
.48575 .64264 m .48574 .64301 L .48366 .64242 L .857 .925 0 r
F
.4859 .64266 m .48574 .64301 L .48575 .64264 L F
.48576 .64256 m .48564 .6453 L .48562 .64588 L 0 0 0 r
F
.48576 .64251 m .48576 .64257 L .48576 .64256 L F
.48576 .64257 m .48564 .6453 L .48576 .64256 L F
.48536 .64439 m .48595 .64507 L .48516 .64478 L .925 .94 0 r
F
.48516 .64478 m .48595 .64507 L .4849 .64689 L .992 .962 0 r
F
.48518 .65643 m .48608 .64147 L .48576 .64254 L 0 0 0 r
F
.48605 .64116 m .48601 .64145 L .48398 .64103 L .791 .922 0 r
F
.48562 .64588 m .48564 .6453 L .48512 .65759 L 0 0 0 r
F
.48513 .65737 m .48512 .65759 L .48501 .6603 L F
.48562 .64588 m .48512 .65759 L .48513 .65737 L F
.48409 .63992 m .48606 .6411 L .48398 .64103 L .791 .922 0 r
F
.48606 .6411 m .48606 .64117 L .48398 .64103 L F
.48608 .64077 m .48608 .64147 L .48607 .64106 L 0 0 0 r
F
.48625 .63944 m .48658 .63493 L .48608 .64077 L F
.48617 .63953 m .48621 .63992 L .48619 .64016 L .849 .173 0 r
F
.48606 .6411 m .48625 .63944 L .48608 .64077 L 0 0 0 r
F
.48619 .64018 m .48625 .63944 L .48606 .6411 L F
.48601 .64014 m .48619 .64016 L .48606 .6411 L .791 .922 0 r
F
.48619 .64016 m .4871 .64027 L .48606 .6411 L F
.48619 .64019 m .48619 .64018 L .48606 .6411 L 0 0 0 r
F
.48608 .64145 m .48608 .64147 L .48608 .64147 L F
.48607 .64106 m .48608 .64147 L .48608 .64145 L F
.48606 .64117 m .48601 .64145 L .48605 .64116 L .791 .922 0 r
F
.48607 .64106 m .48608 .64147 L .48606 .64113 L 0 0 0 r
F
.48618 .64117 m .48607 .64135 L .48606 .64117 L .791 .922 0 r
F
.48607 .64135 m .48601 .64145 L .48606 .64117 L F
.48606 .64113 m .48608 .64147 L .48518 .65643 L 0 0 0 r
F
.4861 .64203 m .48611 .64222 L .4859 .64266 L .857 .925 0 r
F
.48366 .64242 m .48523 .64424 L .48313 .64405 L .925 .94 0 r
F
.48523 .64424 m .48536 .64439 L .48521 .64437 L F
.48523 .64424 m .48521 .64437 L .48313 .64405 L F
.48521 .64437 m .48516 .64478 L .48313 .64405 L F
.48536 .64439 m .48516 .64478 L .48521 .64437 L F
.48523 .64421 m .48523 .64422 L .48523 .64425 L 0 0 0 r
F
.48523 .64424 m .48523 .64425 L .48468 .66576 L F
.48523 .64421 m .48523 .64425 L .48523 .64424 L F
.48523 .64424 m .48523 .64424 L .48468 .66576 L F
.48501 .6603 m .48574 .64301 L .48523 .64424 L F
.48518 .65643 m .48576 .64241 L .48501 .6603 L F
.48519 .65383 m .48608 .64077 L .48518 .65643 L F
.48547 .64976 m .48619 .64019 L .48606 .6411 L F
.48519 .65383 m .48545 .65034 L .48547 .64976 L F
.48618 .64117 m .48698 .64165 L .48608 .64147 L .791 .922 0 r
F
.48545 .65034 m .48619 .64016 L .48547 .64976 L 0 0 0 r
F
.48619 .64016 m .48625 .63944 L .48619 .64018 L F
.48619 .64016 m .48619 .64018 L .48547 .64976 L F
.48615 .63984 m .48619 .64016 L .48615 .63993 L .849 .173 0 r
F
.48623 .63994 m .48619 .64016 L .48616 .64016 L .739 .933 0 r
F
.48614 .63994 m .48616 .64016 L .48409 .63992 L F
.48617 .63953 m .48619 .64016 L .48615 .63984 L .849 .173 0 r
F
.48623 .63994 m .48616 .64016 L .48614 .63994 L .739 .933 0 r
F
.48614 .63991 m .48614 .63835 L .48617 .63953 L .849 .173 0 r
F
.48399 .6391 m .48614 .63991 L .48409 .63992 L .739 .933 0 r
F
.48614 .63991 m .48615 .63994 L .48409 .63992 L F
.48409 .63992 m .48601 .64014 L .48606 .6411 L .791 .922 0 r
F
.48614 .63991 m .48696 .63911 L .4871 .64027 L .739 .933 0 r
F
.48399 .6391 m .48608 .63911 L .48614 .63991 L F
.48608 .63916 m .48608 .63913 L .48614 .63991 L .849 .173 0 r
F
.48608 .63913 m .48614 .63835 L .48614 .63938 L F
.48608 .63913 m .48614 .63938 L .48614 .63991 L F
.48601 .63897 m .48608 .63911 L .48399 .6391 L .724 .958 0 r
F
.486 .63897 m .48647 .63411 L .48608 .63911 L 1 .392 0 r
F
.48605 .63897 m .48607 .63906 L .48601 .63897 L .724 .958 0 r
F
.48607 .63906 m .48608 .63911 L .48601 .63897 L F
.486 .63897 m .4861 .63338 L .48647 .63411 L 1 .392 0 r
F
.48368 .63862 m .486 .63897 L .48399 .6391 L .724 .958 0 r
F
.486 .63897 m .48601 .63897 L .48399 .6391 L F
.48574 .64301 m .48574 .64299 L .48524 .64409 L 0 0 0 r
F
.48574 .64299 m .48526 .64399 L .48524 .64409 L F
.48574 .64301 m .48524 .64409 L .48523 .64424 L F
.48541 .64291 m .48574 .64301 L .48523 .64424 L .925 .94 0 r
F
.48501 .6603 m .48523 .64424 L .48468 .66576 L 0 0 0 r
F
.48447 .64619 m .48496 .64644 L .4849 .64689 L .992 .962 0 r
F
.48313 .64405 m .48496 .64644 L .48447 .64619 L F
.48468 .66576 m .48516 .64478 L .48447 .64619 L .152 .015 0 r
F
.48523 .64412 m .48516 .64471 L .48468 .66576 L 0 0 0 r
F
.48575 .64328 m .48607 .63919 L .48566 .64535 L .849 .173 0 r
F
.48607 .63919 m .48614 .63835 L .48608 .63923 L F
.48607 .63919 m .48608 .63923 L .48566 .64535 L F
.48614 .63835 m .48647 .63411 L .48617 .63953 L F
.48617 .63953 m .48658 .63493 L .48621 .63992 L F
.48605 .63897 m .48656 .63819 L .48696 .63911 L .724 .958 0 r
F
.486 .63897 m .48604 .63891 L .48605 .63897 L F
.48604 .63891 m .48656 .63819 L .48605 .63897 L F
.48368 .63862 m .48574 .63831 L .486 .63897 L F
.48574 .63831 m .4861 .63338 L .486 .63897 L 1 .392 0 r
F
.48574 .63831 m .48656 .63819 L .486 .63897 L .724 .958 0 r
F
.48572 .63854 m .48574 .63831 L .486 .63897 L 1 .392 0 r
F
.48468 .66576 m .48447 .64664 L .4826 .64539 L .152 .015 0 r
F
.48126 .66002 m .48171 .64484 L .48087 .66678 L 1 .691 0 r
F
.48171 .64484 m .48171 .64485 L .48087 .66678 L F
.48154 .64755 m .48504 .65243 L .48519 .65383 L .087 .063 0 r
F
.47974 .64436 m .48092 .64697 L .47901 .64646 L 1 .932 0 r
F
.48092 .64697 m .48082 .6477 L .47901 .64646 L F
.48092 .64697 m .48092 .64697 L .48039 .67665 L .271 .036 0 r
F
.48087 .66678 m .48089 .65935 L .48039 .67665 L F
.48089 .65935 m .48092 .64698 L .48067 .66078 L F
.48089 .65935 m .48067 .66078 L .48039 .67665 L F
.47901 .64646 m .48035 .64738 L .47995 .64949 L 1 .974 0 r
F
.48035 .64738 m .48082 .6477 L .47995 .64949 L F
.48092 .64698 m .48092 .64698 L .48039 .67665 L .271 .036 0 r
F
.48092 .64694 m .48082 .64767 L .48039 .67665 L F
.47829 .64318 m .48166 .64892 L .48167 .65154 L .508 .28 0 r
F
.48092 .64697 m .48092 .64694 L .48092 .64697 L .271 .036 0 r
F
.47974 .64436 m .4812 .64523 L .48092 .64697 L 1 .932 0 r
F
.47751 .64063 m .48031 .64257 L .47974 .64436 L .975 .822 0 r
F
.4778 .63917 m .48031 .64257 L .47751 .64063 L .879 .767 0 r
F
.47814 .64035 m .48166 .64892 L .47829 .64318 L 0 .032 0 r
F
.48154 .64755 m .48519 .65383 L .48166 .64892 L .087 .063 0 r
F
.48138 .64873 m .48326 .65063 L .48154 .64755 L .589 .019 0 r
F
.48326 .65063 m .48504 .65243 L .48154 .64755 L F
.48092 .64698 m .48092 .64697 L .48092 .64698 L .271 .036 0 r
F
.4812 .64523 m .48164 .64549 L .48092 .64697 L 1 .932 0 r
F
.47985 .6445 m .48154 .64755 L .48166 .64892 L 0 .032 0 r
F
.47814 .64035 m .48154 .64755 L .47985 .6445 L F
.48166 .64892 m .48518 .65643 L .48167 .65154 L .463 .299 0 r
F
.48166 .64892 m .48519 .65383 L .48518 .65643 L F
.48138 .64873 m .48474 .65224 L .48504 .65243 L .589 .019 0 r
F
.48474 .65224 m .48572 .63854 L .486 .63897 L 1 .392 0 r
F
.48474 .65224 m .486 .63897 L .48504 .65243 L F
.486 .63897 m .48608 .63911 L .48504 .65243 L F
.486 .63897 m .48605 .63897 L .48601 .63897 L .724 .958 0 r
F
.48605 .63897 m .48696 .63911 L .48608 .63911 L F
.48608 .63911 m .48696 .63911 L .48614 .63991 L .739 .933 0 r
F
.48608 .63927 m .48608 .63916 L .48614 .63991 L .849 .173 0 r
F
.48566 .64535 m .48608 .63927 L .48614 .63991 L F
.48615 .63993 m .48619 .64016 L .48519 .65383 L F
.48614 .63991 m .48623 .63994 L .48615 .63994 L .739 .933 0 r
F
.48623 .63994 m .4871 .64027 L .48619 .64016 L F
.48633 .64126 m .4871 .64027 L .48698 .64165 L .791 .922 0 r
F
.48606 .6411 m .48629 .64092 L .48633 .64126 L F
.48629 .64092 m .4871 .64027 L .48633 .64126 L F
.48504 .65243 m .48575 .64328 L .48566 .64535 L .849 .173 0 r
F
.4861 .64203 m .48643 .64154 L .48611 .64222 L .857 .925 0 r
F
.48504 .65243 m .48617 .63953 L .48519 .65383 L .849 .173 0 r
F
.48653 .6432 m .48698 .64165 L .4866 .64325 L .857 .925 0 r
F
.48643 .64216 m .48698 .64165 L .48653 .6432 L F
.48523 .64424 m .48523 .64421 L .48523 .64424 L 0 0 0 r
F
.48523 .64421 m .48523 .64412 L .48523 .64422 L F
.48366 .64242 m .48541 .64291 L .48523 .64424 L .925 .94 0 r
F
.48615 .64366 m .4866 .64325 L .48617 .64444 L F
.48615 .64366 m .48617 .64444 L .48595 .64507 L F
.48313 .64405 m .48516 .64478 L .48459 .64595 L .992 .962 0 r
F
.48447 .64664 m .48447 .64619 L .4826 .64539 L .152 .015 0 r
F
.48174 .64482 m .48313 .64405 L .4826 .64539 L .975 .89 0 r
F
.48171 .64484 m .48171 .64479 L .48171 .64485 L 1 .691 0 r
F
.48031 .64257 m .48187 .64339 L .48171 .64484 L .975 .89 0 r
F
.48187 .64339 m .48313 .64405 L .48171 .64484 L F
.48061 .67202 m .48087 .66678 L .48061 .67204 L 1 .695 0 r
F
.48039 .67665 m .48037 .67572 L .47986 .6875 L .381 .059 0 r
F
.48035 .67442 m .47996 .64981 L .47988 .68148 L F
.47975 .6884 m .47881 .65295 L .47907 .68641 L .528 .09 0 r
F
.47881 .65295 m .47864 .65378 L .47923 .71052 L F
.47925 .71003 m .47923 .71052 L .47931 .71775 L F
.47881 .65295 m .47923 .71052 L .47925 .71003 L F
.48037 .67572 m .48035 .67442 L .47987 .68485 L .381 .059 0 r
F
.48035 .67442 m .47988 .68148 L .47987 .68485 L F
.48037 .67572 m .47987 .68485 L .47986 .6875 L F
.48039 .67665 m .47986 .6875 L .47986 .68954 L F
.47994 .68962 m .47986 .68954 L .47985 .69209 L F
.48039 .67665 m .47986 .68954 L .47994 .68962 L F
.47973 .68885 m .47907 .68641 L .47917 .69956 L .528 .09 0 r
F
.47975 .6884 m .47907 .68641 L .47973 .68885 L F
.47975 .6884 m .47917 .69956 L .47921 .70517 L F
.47985 .69209 m .47981 .69047 L .47931 .71775 L F
.47981 .69047 m .47921 .70517 L .47931 .71775 L F
.47996 .64981 m .47982 .65057 L .47985 .68781 L .381 .059 0 r
F
.47986 .6875 m .47985 .68781 L .47985 .69209 L F
.47996 .64981 m .47985 .68781 L .47986 .6875 L F
.47768 .65902 m .48061 .67202 L .48037 .67657 L 1 .695 0 r
F
.48061 .67202 m .48061 .67204 L .48057 .67278 L F
.48061 .67202 m .48057 .67278 L .48037 .67657 L F
.4773 .6671 m .48037 .67661 L .47985 .69209 L 1 .751 0 r
F
.48037 .67661 m .48039 .67665 L .47985 .69209 L F
.47799 .65345 m .48126 .66002 L .48092 .66599 L 1 .635 0 r
F
.48086 .66675 m .48092 .66599 L .48087 .66678 L F
.47799 .65345 m .48092 .66599 L .48086 .66675 L F
.47799 .65345 m .48086 .66675 L .47768 .65902 L F
.48086 .66675 m .48087 .66678 L .48086 .66676 L F
.48086 .66675 m .48086 .66676 L .47768 .65902 L F
.47768 .65902 m .48086 .66676 L .48061 .67202 L 1 .695 0 r
F
.48086 .66676 m .48087 .66678 L .48061 .67202 L F
.48997 .87766 m .49004 .87773 L .49001 .87788 L 1 .815 0 r
F
.49312 .9091 m .49098 .85842 L .49111 .91225 L .174 .025 0 r
F
.49098 .85842 m .48365 .68482 L .48991 .8755 L F
.49098 .85842 m .4903 .87607 L .48991 .8755 L .974 .642 0 r
F
.49098 .85842 m .48991 .8755 L .49111 .91225 L .174 .025 0 r
F
.49098 .85842 m .48991 .8755 L .48941 .87477 L .974 .642 0 r
F
.48289 .69289 m .48509 .70849 L .48432 .70568 L 0 0 0 r
F
.48037 .67657 m .48061 .67204 L .48039 .67665 L 1 .695 0 r
F
.48569 .66983 m .48151 .67491 L .4807 .67448 L 1 1 0 r
F
.48448 .66921 m .48569 .66983 L .4807 .67448 L F
.47881 .6565 m .48325 .69329 L .48289 .69289 L 0 0 0 r
F
.48325 .69329 m .48509 .70849 L .48289 .69289 L F
.48022 .72236 m .48001 .68721 L .48029 .73385 L 1 .747 0 r
F
.48092 .81352 m .48087 .7159 L .4816 .82777 L 1 .816 0 r
F
.48105 .80976 m .48087 .71591 L .48092 .81352 L 1 .747 0 r
F
.48087 .7159 m .48087 .71579 L .48087 .71589 L 1 .816 0 r
F
.48087 .71591 m .48087 .71579 L .48087 .7159 L 1 .747 0 r
F
.48087 .71591 m .48087 .7159 L .48092 .81352 L F
.48105 .80976 m .48028 .73369 L .48092 .74469 L F
.48087 .80562 m .48028 .73369 L .48105 .80976 L F
.4813 .86626 m .48146 .8459 L .48098 .86911 L 1 .816 0 r
F
.48146 .8459 m .48123 .84797 L .48098 .86911 L F
.4813 .86626 m .48098 .86911 L .48082 .8824 L F
.48123 .84797 m .48097 .86923 L .48098 .86911 L F
.48122 .84806 m .48097 .86923 L .48123 .84797 L F
.48122 .84806 m .48117 .84843 L .48095 .8694 L F
.48083 .88355 m .48086 .88375 L .48077 .88354 L .796 .486 0 r
F
.48078 .88345 m .48077 .88354 L .48006 .88183 L F
.48083 .88355 m .48077 .88354 L .48078 .88345 L F
.4813 .86626 m .4823 .87176 L .481 .87665 L .59 .244 0 r
F
.48043 .89583 m .48099 .89671 L .48064 .89725 L .944 .693 0 r
F
.48099 .89671 m .48099 .89747 L .48064 .89725 L F
.48223 .89863 m .48251 .89979 L .48189 .89895 L F
.48186 .89831 m .48189 .89895 L .48064 .89725 L F
.48223 .89863 m .48189 .89895 L .48186 .89831 L F
.4808 .88334 m .48103 .86144 L .48081 .88346 L 1 .821 0 r
F
.4808 .88334 m .48081 .88346 L .48081 .88377 L F
.48096 .86924 m .48095 .8694 L .4808 .88334 L 1 .816 0 r
F
.48097 .86923 m .48082 .8811 L .48098 .86911 L F
.48082 .8811 m .4808 .88321 L .48084 .88066 L F
.4808 .88321 m .48081 .88275 L .48084 .88066 L F
.48122 .84806 m .4808 .88334 L .4808 .88332 L F
.481 .87665 m .4808 .88334 L .48061 .87809 L .59 .244 0 r
F
.48187 .87337 m .4808 .88334 L .481 .87665 L F
.4819 .87482 m .4808 .88334 L .48187 .87337 L F
.4813 .86626 m .48082 .8824 L .48081 .8832 L 1 .816 0 r
F
.4813 .86626 m .48081 .8832 L .48086 .88288 L F
.48069 .88416 m .48086 .88375 L .48121 .88612 L .796 .486 0 r
F
.48099 .88464 m .48143 .88513 L .48121 .88612 L F
.48121 .88612 m .48113 .8872 L .4811 .88661 L F
.48048 .89515 m .48007 .90615 L .48008 .90618 L 1 .821 0 r
F
.48053 .89392 m .48048 .89516 L .48048 .89515 L F
.48048 .89516 m .48007 .90615 L .48048 .89515 L F
.48053 .89392 m .48049 .89428 L .48007 .90615 L F
.48113 .8872 m .48043 .89583 L .4811 .88661 L .796 .486 0 r
F
.48061 .89315 m .48053 .89392 L .48046 .89569 L 1 .821 0 r
F
.48078 .88811 m .48074 .88827 L .48053 .89392 L F
.4811 .88661 m .48043 .89583 L .47938 .8942 L .796 .486 0 r
F
.48091 .88652 m .48093 .88264 L .48116 .88801 L 1 .821 0 r
F
.48086 .88375 m .481 .88408 L .48099 .88464 L .796 .486 0 r
F
.481 .88408 m .48143 .88513 L .48099 .88464 L F
.47993 .78462 m .48031 .7883 L .48003 .78688 L .283 .048 0 r
F
.48067 .80118 m .48028 .73369 L .48087 .80562 L 1 .747 0 r
F
.48191 .87533 m .48146 .88498 L .481 .88384 L .59 .244 0 r
F
.4823 .87176 m .481 .88384 L .48099 .88184 L F
.48121 .879 m .4813 .86626 L .48086 .88288 L 1 .816 0 r
F
.48121 .879 m .48086 .88288 L .48105 .88137 L F
.48122 .84806 m .48095 .8694 L .48096 .86924 L F
.4813 .86626 m .48092 .81352 L .4816 .82777 L F
.48095 .8628 m .48092 .81352 L .4813 .86626 L F
.4813 .86623 m .48144 .86505 L .4813 .86626 L .59 .244 0 r
F
.48094 .86424 m .48124 .86423 L .4813 .86623 L F
.48089 .86399 m .48094 .86402 L .48094 .86424 L F
.48094 .86402 m .48124 .86423 L .48094 .86424 L F
.48101 .83629 m .48105 .80976 L .481 .83652 L 1 .747 0 r
F
.4811 .83421 m .48183 .86646 L .48095 .8628 L .356 .064 0 r
F
.48094 .86299 m .48094 .863 L .48089 .86399 L .59 .244 0 r
F
.48094 .863 m .48124 .86423 L .48094 .86402 L F
.48094 .863 m .48094 .86402 L .48089 .86399 L F
.47993 .85866 m .4813 .86623 L .48061 .87809 L F
.4813 .86623 m .4813 .86626 L .4813 .86634 L F
.4813 .86623 m .4813 .86634 L .48061 .87809 L F
.48116 .86333 m .4811 .83421 L .48098 .85819 L 1 .747 0 r
F
.4811 .83421 m .48105 .80976 L .48101 .83629 L F
.4811 .83421 m .48101 .83629 L .48098 .85819 L F
.48099 .88184 m .481 .88384 L .4808 .88334 L .59 .244 0 r
F
.48105 .88137 m .48086 .88288 L .48079 .88538 L 1 .816 0 r
F
.48105 .80976 m .48092 .81352 L .48094 .83808 L 1 .747 0 r
F
.48105 .80976 m .48094 .83808 L .481 .83656 L F
.481 .83652 m .48095 .8628 L .48095 .86274 L F
.48105 .80976 m .481 .83656 L .481 .83652 L F
.481 .83656 m .48095 .8628 L .481 .83652 L F
.48221 .8393 m .48215 .83982 L .48114 .83323 L .356 .064 0 r
F
.48083 .82985 m .48067 .80118 L .4811 .83421 L 1 .747 0 r
F
.4811 .83421 m .48087 .80562 L .48105 .80976 L F
.48115 .83296 m .48114 .83323 L .48097 .83215 L .356 .064 0 r
F
.48086 .83117 m .48086 .8314 L .48081 .8311 L F
.48081 .83092 m .48081 .8311 L .48046 .82876 L F
.48086 .83117 m .48081 .8311 L .48081 .83092 L F
.48082 .82957 m .48076 .81921 L .48082 .82962 L 1 .747 0 r
F
.48071 .81055 m .48025 .72914 L .48073 .81123 L F
.48025 .72914 m .48026 .72905 L .48078 .82006 L F
.48054 .77634 m .48029 .73326 L .48052 .77761 L 1 .672 0 r
F
.48208 .7646 m .48219 .76643 L .48318 .81648 L 1 .821 0 r
F
.48187 .79311 m .48211 .7623 L .48174 .7961 L 1 .816 0 r
F
.48087 .7159 m .48087 .71589 L .4816 .82777 L F
.48208 .7646 m .48211 .7623 L .48219 .76643 L 1 .821 0 r
F
.4816 .82777 m .48087 .71579 L .48211 .7623 L 1 .816 0 r
F
.48211 .7623 m .49039 .85516 L .48318 .81648 L .752 .342 0 r
F
.48318 .81648 m .49039 .85516 L .48941 .87477 L .891 .493 0 r
F
.48059 .77488 m .48472 .79788 L .48728 .85725 L .669 .236 0 r
F
.48076 .81921 m .48071 .81055 L .48078 .82006 L 1 .747 0 r
F
.48054 .77634 m .48052 .77761 L .48066 .80086 L 1 .672 0 r
F
.48066 .79838 m .48066 .80086 L .48082 .82957 L F
.48054 .77634 m .48066 .80086 L .48066 .79838 L F
.48076 .81921 m .48078 .82006 L .48083 .82985 L 1 .747 0 r
F
.48076 .81921 m .48083 .82985 L .48082 .82962 L F
.48067 .80118 m .48087 .80562 L .4811 .83421 L F
.48066 .7957 m .48054 .77634 L .48066 .79806 L 1 .672 0 r
F
.48071 .81055 m .48073 .81123 L .48078 .82006 L 1 .747 0 r
F
.48066 .79806 m .48082 .82957 L .48082 .829 L 1 .672 0 r
F
.48054 .77634 m .48066 .79838 L .48066 .79806 L F
.48066 .79838 m .48082 .82957 L .48066 .79806 L F
.48063 .79499 m .48003 .74148 L .48066 .7957 L F
.48052 .79244 m .48049 .78953 L .48063 .79499 L F
.48049 .78953 m .48003 .74148 L .48063 .79499 L F
.48061 .7915 m .48003 .74148 L .48063 .79165 L F
.48029 .73326 m .48025 .72914 L .48052 .77761 L F
.48063 .79165 m .48003 .74148 L .48029 .73326 L F
.48003 .78688 m .48034 .78967 L .48019 .79029 L .283 .048 0 r
F
.48034 .78967 m .48044 .79049 L .48037 .79043 L F
.48034 .78967 m .48037 .79043 L .48019 .79029 L F
.48 .78834 m .47995 .78178 L .47971 .78194 L .22 .032 0 r
F
.47818 .76727 m .48066 .7957 L .47926 .81871 L .283 .048 0 r
F
.48031 .7883 m .48034 .78967 L .48003 .78688 L F
.47993 .78462 m .48003 .78688 L .47936 .78088 L F
.47936 .78088 m .48003 .78688 L .48019 .79029 L F
.4774 .73562 m .47998 .76741 L .47818 .76727 L .669 .236 0 r
F
.48037 .78895 m .48032 .78263 L .48052 .79244 L 1 .672 0 r
F
.48032 .78263 m .47999 .74261 L .48049 .78953 L F
.47999 .74261 m .48003 .74148 L .48049 .78953 L F
.47962 .75448 m .47977 .75579 L .47985 .76383 L .669 .236 0 r
F
.48016 .76958 m .48 .74897 L .48032 .78263 L 1 .71 0 r
F
.47768 .65902 m .48037 .67657 L .4773 .6671 L 1 .695 0 r
F
.48037 .67657 m .48037 .67661 L .4773 .6671 L F
.4773 .6671 m .47985 .69209 L .47686 .67986 L 1 .751 0 r
F
.47686 .67986 m .47985 .69209 L .47931 .71775 L 1 .803 0 r
F
.48 .74897 m .47939 .66946 L .47999 .74261 L 1 .71 0 r
F
.48 .74897 m .47999 .74261 L .48032 .78263 L F
.48 .74897 m .47881 .6565 L .47939 .66946 L F
.47998 .76741 m .48016 .76958 L .48031 .7883 L .669 .236 0 r
F
.48016 .76958 m .48728 .85725 L .48068 .79196 L F
.48016 .76958 m .48032 .78263 L .48037 .78895 L 1 .71 0 r
F
.48016 .76958 m .48037 .78895 L .48031 .7883 L .669 .236 0 r
F
.48044 .79049 m .48049 .79169 L .48041 .79136 L .283 .048 0 r
F
.4804 .79046 m .48041 .79136 L .48019 .79029 L F
.48044 .79049 m .48041 .79136 L .4804 .79046 L F
.48037 .78895 m .48044 .79049 L .48034 .78967 L F
.48035 .78809 m .48037 .78895 L .48039 .7916 L 1 .71 0 r
F
.48016 .76958 m .48037 .78895 L .48035 .78809 L F
.48032 .78263 m .48049 .78953 L .48052 .79244 L 1 .672 0 r
F
.48016 .76958 m .48068 .79196 L .48037 .78895 L .669 .236 0 r
F
.47985 .7585 m .47977 .75579 L .47981 .75461 L 1 .71 0 r
F
.48016 .76958 m .47981 .75461 L .48 .74897 L F
.47977 .75579 m .47995 .76229 L .47992 .76436 L .669 .236 0 r
F
.47995 .76229 m .48003 .7651 L .47992 .76436 L F
.47977 .75579 m .47992 .76436 L .47985 .76383 L F
.47998 .76741 m .48031 .7883 L .47818 .76727 L F
.47985 .7585 m .47981 .75461 L .48016 .76958 L 1 .71 0 r
F
.47992 .76668 m .48057 .76884 L .48059 .77488 L .669 .236 0 r
F
.47985 .76383 m .48057 .76884 L .47992 .76668 L F
.48066 .7957 m .48061 .7915 L .48063 .79165 L 1 .672 0 r
F
.48066 .79249 m .48066 .79374 L .48043 .79206 L .283 .048 0 r
F
.48041 .79136 m .48043 .79206 L .48019 .79029 L F
.48066 .79249 m .48043 .79206 L .48041 .79136 L F
.48031 .7883 m .48037 .78895 L .48034 .78967 L F
.48032 .79083 m .48026 .78287 L .48039 .7916 L 1 .71 0 r
F
.48026 .78287 m .48016 .76958 L .48035 .78809 L F
.48026 .78287 m .48035 .78809 L .48039 .7916 L F
.48066 .7957 m .48066 .79806 L .48082 .829 L 1 .672 0 r
F
.48066 .7957 m .48082 .82957 L .47926 .81871 L .283 .048 0 r
F
.48019 .79029 m .48066 .79374 L .48066 .7957 L F
.48082 .82958 m .48082 .83043 L .48046 .82876 L .356 .064 0 r
F
.48038 .82649 m .48082 .82957 L .48046 .82876 L F
.48082 .82957 m .48082 .82958 L .48046 .82876 L F
.48119 .83215 m .48115 .83296 L .48103 .83221 L F
.48084 .83055 m .48086 .83117 L .48046 .82876 L F
.47926 .81871 m .48088 .83236 L .47986 .85829 L F
.48088 .83236 m .4811 .83421 L .48094 .83736 L F
.48088 .83236 m .48094 .83736 L .47986 .85829 L F
.48097 .83215 m .48099 .83236 L .48046 .82876 L F
.48046 .82876 m .48086 .83152 L .48088 .83236 L F
.48055 .81754 m .48074 .83466 L .48069 .83296 L 1 .71 0 r
F
.48038 .79773 m .48059 .81928 L .48055 .81754 L F
.48059 .81928 m .48074 .83466 L .48055 .81754 L F
.481 .83127 m .48103 .83221 L .48086 .83117 L .356 .064 0 r
F
.481 .83127 m .48086 .83117 L .48084 .83055 L F
.48119 .83215 m .48103 .83221 L .481 .83127 L F
.4801 .79431 m .48017 .79772 L .48031 .81228 L 1 .758 0 r
F
.48094 .86294 m .48094 .86299 L .48004 .8593 L .59 .244 0 r
F
.481 .88403 m .481 .88408 L .48086 .88375 L .796 .486 0 r
F
.48093 .88264 m .48115 .8853 L .48116 .88801 L 1 .821 0 r
F
.48146 .88498 m .48086 .88375 L .48083 .88355 L .796 .486 0 r
F
.48099 .8925 m .48116 .88684 L .4805 .89591 L 1 .821 0 r
F
.48116 .88684 m .48058 .89399 L .4805 .89591 L F
.48105 .89209 m .48107 .89118 L .48099 .8925 L F
.4808 .88334 m .48146 .88498 L .48083 .88355 L .796 .486 0 r
F
.48064 .89725 m .48196 .90044 L .48074 .89791 L .944 .693 0 r
F
.48196 .90044 m .48362 .90446 L .48197 .90071 L F
.48196 .90044 m .48197 .90071 L .48074 .89791 L F
.48043 .89583 m .48059 .89688 L .48031 .90533 L 1 .722 0 r
F
.48043 .9017 m .48059 .89688 L .4805 .90201 L F
.48059 .89688 m .48064 .89728 L .4805 .90201 L F
.48064 .89725 m .48251 .89979 L .48362 .90446 L .944 .693 0 r
F
.4805 .90201 m .48066 .89683 L .48074 .89791 L 1 .722 0 r
F
.48101 .8935 m .48105 .89209 L .48001 .90789 L 1 .821 0 r
F
.48362 .90446 m .4837 .90479 L .48074 .89791 L .944 .693 0 r
F
.48074 .89791 m .48518 .90825 L .48487 .90921 L F
.48082 .89901 m .48487 .90921 L .48129 .90539 L F
.48031 .90533 m .48043 .9017 L .4805 .90201 L 1 .722 0 r
F
.48064 .90645 m .48101 .8935 L .48001 .90789 L 1 .821 0 r
F
.48093 .89379 m .4805 .89591 L .48001 .90789 L F
.48105 .89209 m .48062 .89505 L .48093 .89379 L F
.48062 .89505 m .4805 .89591 L .48093 .89379 L F
.48048 .91196 m .48064 .90645 L .47977 .91473 L F
.48064 .90645 m .48001 .90789 L .47977 .91473 L F
.48052 .90847 m .4807 .89221 L .48055 .90955 L F
.4807 .89221 m .4808 .88334 L .48071 .89227 L F
.4807 .89221 m .48071 .89227 L .48055 .90955 L F
.48362 .90446 m .48431 .90225 L .48518 .90825 L .944 .693 0 r
F
.48251 .89979 m .48431 .90225 L .48362 .90446 L F
.48431 .90225 m .48626 .90491 L .48554 .90716 L F
.48431 .90225 m .48554 .90716 L .48518 .90825 L F
.48085 .89887 m .48088 .89298 L .48101 .8935 L 1 .821 0 r
F
.48101 .8935 m .48091 .88652 L .48116 .88801 L F
.48088 .89298 m .48091 .88652 L .48101 .8935 L F
.4808 .88334 m .48081 .88377 L .48055 .90955 L F
.48146 .88498 m .48143 .88513 L .481 .88408 L .796 .486 0 r
F
.48146 .88498 m .481 .88408 L .481 .88403 L F
.48072 .89232 m .48081 .88377 L .48088 .89298 L 1 .821 0 r
F
.48081 .88377 m .48091 .88667 L .48088 .89298 L F
.48066 .89837 m .48072 .89232 L .48085 .89887 L F
.48072 .89232 m .48088 .89298 L .48085 .89887 L F
.48055 .90955 m .48066 .89837 L .48085 .89887 L F
.48104 .90096 m .48121 .879 L .48058 .90279 L 1 .816 0 r
F
.48098 .90853 m .48104 .90096 L .48048 .91196 L F
.48048 .91196 m .48052 .90847 L .48055 .90955 L 1 .821 0 r
F
.48104 .90096 m .48058 .90279 L .48048 .91196 L 1 .816 0 r
F
.48098 .90853 m .48097 .88886 L .48109 .89338 L F
.48081 .88377 m .48081 .88346 L .48091 .88667 L 1 .821 0 r
F
.48081 .88346 m .48092 .8842 L .48091 .88667 L F
.48121 .879 m .48079 .88538 L .48058 .90279 L 1 .816 0 r
F
.48097 .88886 m .48096 .88008 L .48105 .88921 L F
.48097 .88886 m .48105 .88921 L .48109 .89338 L F
.4813 .86626 m .481 .87665 L .48061 .87809 L .59 .244 0 r
F
.48095 .8628 m .48124 .86399 L .48095 .86285 L F
.48124 .86399 m .48124 .86403 L .48095 .86288 L F
.48095 .86285 m .48095 .86288 L .48004 .8593 L F
.48124 .86399 m .48095 .86288 L .48095 .86285 L F
.48098 .86308 m .48099 .86319 L .48094 .86299 L F
.48098 .86308 m .48094 .86299 L .48094 .86294 L F
.48146 .8649 m .48145 .86499 L .48124 .86414 L F
.48124 .86403 m .48124 .86414 L .48094 .86294 L F
.48124 .86403 m .48094 .86294 L .48094 .86287 L F
.4811 .89234 m .48095 .8628 L .4813 .86626 L 1 .816 0 r
F
.48109 .89338 m .48099 .87131 L .4811 .89234 L F
.48099 .87131 m .48095 .8628 L .4811 .89234 L F
.48106 .86055 m .481 .86181 L .48102 .86538 L 1 .747 0 r
F
.481 .83656 m .48094 .83808 L .48095 .8628 L F
.48098 .85699 m .48101 .83629 L .48096 .86191 L F
.48101 .83629 m .481 .83652 L .48095 .86274 L F
.4811 .83421 m .48095 .8628 L .47986 .85829 L .356 .064 0 r
F
.48145 .86499 m .48144 .86505 L .48099 .86319 L .59 .244 0 r
F
.48145 .86499 m .48099 .86319 L .48098 .86308 L F
.48116 .86333 m .48106 .86055 L .48102 .86538 L 1 .747 0 r
F
.48106 .86055 m .48098 .85819 L .481 .86181 L F
.48095 .83173 m .48097 .83215 L .48086 .8314 L .356 .064 0 r
F
.48095 .83173 m .48086 .8314 L .48086 .83117 L F
.48116 .88801 m .48115 .88569 L .48121 .88612 L 1 .821 0 r
F
.48103 .87541 m .48116 .86333 L .48097 .86616 L 1 .747 0 r
F
.48124 .90432 m .48117 .87115 L .48103 .87541 L F
.48117 .87115 m .48116 .86333 L .48103 .87541 L F
.48086 .83152 m .48399 .85266 L .48088 .83236 L .356 .064 0 r
F
.48123 .89798 m .48083 .82985 L .4811 .83421 L 1 .747 0 r
F
.48108 .86633 m .48099 .85209 L .48106 .86748 L 1 .672 0 r
F
.48099 .85209 m .48092 .83984 L .48099 .85335 L F
.48099 .85209 m .48099 .85335 L .48106 .86748 L F
.48094 .86287 m .48094 .86294 L .48004 .8593 L .59 .244 0 r
F
.48146 .8649 m .48124 .86414 L .48124 .86403 L F
.48002 .85897 m .48095 .8628 L .48004 .8593 L F
.48095 .8628 m .48095 .86285 L .48004 .8593 L F
.48004 .8593 m .48094 .86299 L .48089 .86399 L F
.48088 .86399 m .48074 .84553 L .48098 .86567 L 1 .71 0 r
F
.48074 .84553 m .48051 .81539 L .48082 .84847 L F
.48096 .88008 m .48095 .8628 L .48109 .89338 L 1 .816 0 r
F
.48095 .86274 m .48095 .8628 L .48095 .86391 L 1 .747 0 r
F
.48074 .84553 m .48082 .84847 L .48098 .86567 L 1 .71 0 r
F
.48102 .86538 m .481 .86181 L .48097 .86616 L 1 .747 0 r
F
.481 .86181 m .48098 .85819 L .48097 .86235 L F
.481 .86181 m .48097 .86235 L .48097 .86616 L F
.48124 .86399 m .48146 .8649 L .48124 .86403 L .59 .244 0 r
F
.48053 .81669 m .48055 .81754 L .48083 .84901 L 1 .71 0 r
F
.48082 .84879 m .48083 .84901 L .48098 .86567 L F
.48053 .81669 m .48083 .84901 L .48082 .84879 L F
.48097 .86235 m .48098 .85699 L .48095 .86274 L 1 .747 0 r
F
.48098 .85699 m .48096 .86191 L .48095 .86274 L F
.4812 .89726 m .48082 .82957 L .48123 .89798 L F
.48109 .88354 m .48097 .8668 L .48096 .88597 L F
.48097 .8668 m .48095 .86391 L .48095 .86775 L F
.48097 .8668 m .48095 .86775 L .48096 .88597 L F
.48088 .86399 m .48098 .86567 L .48112 .88198 L 1 .71 0 r
F
.48082 .82958 m .48084 .83055 L .48082 .83043 L .356 .064 0 r
F
.48082 .82963 m .48084 .83055 L .48082 .82958 L F
.48082 .82962 m .48083 .82985 L .48123 .89798 L 1 .747 0 r
F
.48082 .82957 m .48082 .82962 L .48123 .89798 L F
.48115 .88406 m .48114 .88484 L .48124 .90432 L 1 .672 0 r
F
.48127 .89943 m .48117 .88249 L .48118 .88532 L F
.48127 .89943 m .48118 .88532 L .48124 .90432 L F
.48124 .90432 m .4812 .89726 L .48121 .89754 L 1 .747 0 r
F
.48124 .90432 m .48122 .89778 L .48123 .89798 L F
.48117 .88249 m .48115 .88406 L .48124 .90432 L 1 .672 0 r
F
.48113 .88183 m .48111 .88224 L .48124 .90432 L F
.48106 .88074 m .48112 .88198 L .48127 .89943 L 1 .71 0 r
F
.48088 .86399 m .48112 .88198 L .48106 .88074 L F
.48362 .90446 m .48518 .90825 L .4837 .90479 L .944 .693 0 r
F
.48006 .88183 m .48077 .88354 L .48069 .88416 L .796 .486 0 r
F
.48061 .87809 m .4808 .88334 L .47984 .88099 L .59 .244 0 r
F
.48077 .88354 m .48086 .88375 L .48069 .88416 L .796 .486 0 r
F
.47993 .85866 m .48061 .87809 L .47984 .88099 L .59 .244 0 r
F
.47976 .85877 m .47986 .85829 L .47977 .85892 L 1 .741 0 r
F
.48008 .90618 m .48007 .90615 L .48001 .90789 L 1 .821 0 r
F
.47604 .91104 m .47709 .90625 L .47761 .90821 L 1 .927 0 r
F
.47568 .90969 m .47709 .90625 L .47604 .91104 L F
.47319 .91028 m .47389 .91047 L .47326 .91124 L 1 1 0 r
F
.47389 .91047 m .47357 .91122 L .47338 .91109 L .943 .955 0 r
F
.47316 .90976 m .47736 .89925 L .4729 .91422 L 1 .901 0 r
F
.47736 .89925 m .47608 .90438 L .4729 .91422 L F
.4729 .91422 m .47608 .90438 L .47431 .91081 L 1 .962 0 r
F
.47886 .917 m .48339 .92109 L .47956 .91959 L .911 1 0 r
F
.47885 .91703 m .47956 .91959 L .47777 .91888 L F
.47886 .917 m .47956 .91959 L .47885 .91703 L F
.47886 .917 m .48517 .91962 L .48339 .92109 L F
.48517 .91962 m .4852 .91963 L .48506 .91975 L F
.48517 .91962 m .48506 .91975 L .48339 .92109 L F
.47777 .91888 m .48132 .92235 L .47651 .92044 L .89 1 0 r
F
.47951 .92109 m .4852 .91963 L .47886 .917 L .636 .222 0 r
F
.4798 .9212 m .4852 .91963 L .47951 .92109 L F
.4822 .92204 m .4852 .91963 L .47954 .92127 L F
.47989 .92084 m .48262 .92153 L .48234 .92186 L .725 .954 0 r
F
.48339 .92109 m .48899 .92253 L .48612 .92374 L .673 .915 0 r
F
.48219 .92204 m .48584 .92333 L .4822 .92204 L .725 .954 0 r
F
.47989 .92084 m .48234 .92186 L .48219 .92204 L F
.48244 .92185 m .48672 .91798 L .4852 .91963 L .636 .222 0 r
F
.48252 .92175 m .48672 .91798 L .48244 .92185 L F
.48234 .92187 m .48672 .91798 L .4822 .92204 L F
.48665 .91804 m .48664 .91805 L .48293 .92127 L .803 .524 0 r
F
.48293 .92127 m .48293 .92127 L .48262 .92153 L F
.48665 .91804 m .48293 .92127 L .48293 .92127 L F
.48064 .91952 m .48326 .92082 L .47989 .92084 L .721 .932 0 r
F
.48326 .92082 m .48324 .92084 L .47989 .92084 L F
.4833 .92084 m .48262 .92153 L .47989 .92084 L F
.496 .91429 m .48871 .91714 L .4869 .91678 L .399 .255 0 r
F
.49324 .91371 m .496 .91429 L .4869 .91678 L .457 .39 0 r
F
.48357 .92061 m .48792 .91609 L .48672 .91798 L .803 .524 0 r
F
.48362 .9205 m .48792 .91609 L .48357 .92061 L F
.48338 .92065 m .48792 .91609 L .4833 .92084 L F
.48442 .91924 m .48792 .91609 L .48391 .91993 L 1 .919 0 r
F
.48442 .91924 m .48391 .91993 L .48388 .91996 L F
.48064 .91952 m .48355 .92027 L .48326 .92082 L .721 .932 0 r
F
.48119 .91804 m .48196 .91842 L .48064 .91952 L .697 .888 0 r
F
.48196 .91842 m .48259 .9195 L .48064 .91952 L F
.48402 .9195 m .48355 .92027 L .48064 .91952 L F
.48414 .9195 m .48371 .92007 L .48402 .9195 L F
.48371 .92007 m .48355 .92027 L .48402 .9195 L F
.48196 .91842 m .48395 .9194 L .48259 .9195 L F
.48316 .91261 m .48869 .91494 L .48591 .91723 L 1 1 0 r
F
.48487 .90921 m .48869 .91494 L .48316 .91261 L F
.48487 .90921 m .49111 .91225 L .48869 .91494 L F
.48442 .91925 m .48879 .9139 L .48792 .91609 L 1 .919 0 r
F
.48444 .91914 m .48879 .9139 L .48442 .91925 L F
.48316 .91261 m .48591 .91723 L .48117 .91534 L 1 1 0 r
F
.48422 .91887 m .48879 .9139 L .48414 .9195 L 1 .919 0 r
F
.48501 .91771 m .48879 .9139 L .48458 .91848 L 1 1 0 r
F
.48501 .91771 m .48458 .91848 L .48454 .91853 L F
.48119 .91804 m .48422 .91887 L .48405 .91945 L .697 .888 0 r
F
.48395 .9194 m .48393 .91947 L .48259 .9195 L F
.48409 .91947 m .48408 .9195 L .48259 .9195 L F
.47954 .92127 m .48197 .92228 L .47895 .92201 L .725 .954 0 r
F
.48197 .92228 m .48533 .92368 L .48158 .9227 L F
.48197 .92228 m .48158 .9227 L .47895 .92201 L F
.4822 .92204 m .48533 .92368 L .47954 .92127 L F
.48193 .92213 m .48295 .92124 L .48166 .92247 L .636 .222 0 r
F
.48295 .92124 m .48672 .91798 L .48247 .92175 L F
.48295 .92124 m .48247 .92175 L .48166 .92247 L F
.47995 .92385 m .4822 .92204 L .47954 .92127 L F
.47954 .92127 m .4798 .9212 L .47951 .92109 L F
.47989 .92084 m .4822 .92204 L .47954 .92127 L .725 .954 0 r
F
.48545 .9158 m .48516 .91656 L .48491 .91689 L 1 1 0 r
F
.48152 .91642 m .48348 .9174 L .48119 .91804 L .666 .832 0 r
F
.48348 .9174 m .48451 .91792 L .48337 .91796 L F
.48348 .9174 m .48337 .91796 L .48119 .91804 L F
.48451 .91792 m .48447 .91802 L .48119 .91804 L F
.4847 .91802 m .48422 .91887 L .48119 .91804 L F
.48626 .90491 m .49111 .91225 L .48487 .90921 L .967 .927 0 r
F
.4847 .91802 m .48929 .91125 L .48879 .9139 L 1 1 0 r
F
.48451 .91792 m .48463 .9176 L .48463 .91798 L .666 .832 0 r
F
.48463 .9176 m .48466 .91778 L .48463 .91798 L F
.48152 .91642 m .48458 .91731 L .48451 .91792 L F
.48458 .91731 m .48473 .91735 L .48451 .91792 L F
.48451 .91792 m .4847 .91802 L .48447 .91802 L F
.48463 .91798 m .48471 .91799 L .4847 .91802 L F
.48163 .92111 m .48458 .91731 L .4847 .91802 L 1 1 0 r
F
.48482 .91701 m .48929 .91125 L .48488 .91775 L F
.48521 .91613 m .48491 .91689 L .48482 .91701 L F
.48486 .91679 m .48482 .91701 L .48458 .91731 L F
.48521 .91613 m .48482 .91701 L .48486 .91679 L F
.48545 .9158 m .48491 .91689 L .48521 .91613 L F
.48492 .91642 m .48545 .9158 L .4849 .91656 L F
.48533 .91385 m .48513 .91466 L .48477 .91525 L 1 .97 0 r
F
.48163 .91476 m .48451 .91621 L .48152 .91642 L .669 .794 0 r
F
.48451 .91621 m .48445 .91642 L .48152 .91642 L F
.48492 .91642 m .48458 .91731 L .48152 .91642 L F
.48626 .90491 m .49312 .9091 L .49111 .91225 L .967 .927 0 r
F
.48492 .91642 m .4894 .9077 L .48929 .91125 L 1 1 0 r
F
.48451 .91621 m .48465 .91579 L .48476 .91633 L .669 .794 0 r
F
.48465 .91579 m .48473 .91598 L .48476 .91633 L F
.48163 .91476 m .48456 .91559 L .48451 .91621 L F
.48456 .91559 m .4847 .91563 L .48451 .91621 L F
.48451 .91621 m .48492 .91642 L .48445 .91642 L F
.48476 .91633 m .48493 .91636 L .48492 .91642 L F
.48176 .92015 m .48456 .91559 L .48492 .91642 L 1 1 0 r
F
.48456 .91559 m .4894 .9077 L .48492 .91642 L F
.48465 .91579 m .4847 .91563 L .48473 .91598 L .669 .794 0 r
F
.48497 .91448 m .48477 .91525 L .48456 .91559 L 1 .97 0 r
F
.4829 .91248 m .48302 .9128 L .48117 .91534 L 1 1 0 r
F
.48153 .91346 m .48468 .91484 L .48163 .91476 L .796 .819 0 r
F
.48497 .91448 m .48456 .91559 L .48464 .91507 L 1 .97 0 r
F
.48533 .91385 m .48477 .91525 L .48497 .91448 L F
.48468 .91484 m .48456 .91559 L .48163 .91476 L .796 .819 0 r
F
.48167 .91938 m .48468 .91484 L .48176 .92015 L 1 .97 0 r
F
.48468 .91484 m .48533 .91385 L .48463 .91509 L F
.48468 .91484 m .48463 .91509 L .48176 .92015 L F
.48545 .9158 m .48929 .91125 L .48516 .91656 L 1 1 0 r
F
.48271 .92129 m .48792 .91609 L .48269 .92135 L .803 .524 0 r
F
.48283 .92097 m .48315 .92066 L .48271 .92129 L F
.48355 .92027 m .48792 .91609 L .48341 .92059 L F
.48355 .92027 m .48372 .92032 L .48335 .92071 L .721 .932 0 r
F
.48355 .92027 m .48335 .92071 L .48326 .92082 L F
.48315 .92066 m .48355 .92027 L .48271 .92129 L .803 .524 0 r
F
.48355 .92027 m .48341 .92059 L .48271 .92129 L F
.48467 .9181 m .48454 .91853 L .48422 .91887 L 1 1 0 r
F
.48467 .9181 m .48422 .91887 L .48462 .91816 L F
.48501 .91771 m .48454 .91853 L .48467 .9181 L F
.4847 .91802 m .48493 .91813 L .48422 .91887 L .666 .832 0 r
F
.48665 .91804 m .48293 .92127 L .48293 .92127 L .803 .524 0 r
F
.48301 .92108 m .48357 .92061 L .48262 .92153 L F
.48357 .92061 m .48665 .91804 L .48323 .921 L F
.48357 .92061 m .48323 .921 L .48262 .92153 L F
.4852 .91963 m .48899 .92253 L .48339 .92109 L .721 .961 0 r
F
.4852 .91963 m .49152 .92116 L .48899 .92253 L F
.48672 .91798 m .49152 .92116 L .4852 .91963 L .744 .97 0 r
F
.48442 .91963 m .48904 .92019 L .48813 .92146 L .697 .888 0 r
F
.48414 .9195 m .48449 .91955 L .48442 .91963 L F
.48449 .91955 m .48904 .92019 L .48442 .91963 L F
.48493 .91813 m .48904 .92019 L .48438 .91891 L .666 .832 0 r
F
.48493 .91813 m .48438 .91891 L .48422 .91887 L F
.48792 .91609 m .49365 .91965 L .48672 .91798 L .736 .943 0 r
F
.48792 .91609 m .49535 .91801 L .49365 .91965 L F
.48879 .9139 m .49535 .91801 L .48792 .91609 L .689 .873 0 r
F
.48468 .91484 m .48961 .91472 L .4898 .91708 L .796 .819 0 r
F
.48457 .9118 m .48438 .9128 L .48395 .91384 L 1 .756 0 r
F
.48153 .91346 m .48395 .91384 L .48386 .91448 L .796 .819 0 r
F
.48125 .91352 m .48368 .91387 L .48153 .91346 L .99 .845 0 r
F
.48379 .91386 m .48395 .91384 L .48324 .91557 L 1 .756 0 r
F
.48347 .91469 m .48324 .91557 L .48167 .91938 L F
.48379 .91386 m .48324 .91557 L .48347 .91469 L F
.48386 .91448 m .48427 .91427 L .48468 .91484 L .796 .819 0 r
F
.48729 .89929 m .49312 .9091 L .48626 .90491 L .878 .766 0 r
F
.49312 .9091 m .49189 .8767 L .49177 .87723 L .174 .025 0 r
F
.49211 .86463 m .49156 .86796 L .49312 .9091 L 1 .692 0 r
F
.49466 .9054 m .49313 .87145 L .49312 .9091 L F
.49313 .87145 m .49234 .87481 L .49312 .9091 L F
.48729 .89929 m .49466 .9054 L .49312 .9091 L .878 .766 0 r
F
.48395 .91384 m .48905 .90143 L .48468 .91484 L 1 .97 0 r
F
.48427 .91427 m .48485 .91398 L .48468 .91484 L .796 .819 0 r
F
.48468 .91484 m .48905 .90143 L .4894 .9077 L 1 .97 0 r
F
.48167 .91938 m .48395 .91384 L .48468 .91484 L F
.48533 .91385 m .4894 .9077 L .48513 .91466 L F
.48485 .91398 m .48961 .91472 L .48468 .91484 L .796 .819 0 r
F
.48368 .91387 m .48395 .91384 L .48153 .91346 L .99 .845 0 r
F
.48174 .92011 m .48167 .91938 L .48176 .92015 L 0 0 0 r
F
.48059 .91953 m .48119 .91804 L .48064 .91952 L 1 1 0 r
F
.47371 .91882 m .47395 .92087 L .47318 .92032 L .934 1 0 r
F
.47351 .92272 m .47651 .92044 L .47511 .92175 L .632 .224 0 r
F
.47169 .92382 m .47397 .92222 L .47351 .92272 L F
.47397 .92222 m .47651 .92044 L .47351 .92272 L F
.47216 .92286 m .474 .92184 L .47169 .92382 L .854 .645 0 r
F
.474 .92184 m .47651 .92044 L .47397 .92222 L F
.474 .92184 m .47397 .92222 L .47169 .92382 L F
.47367 .9187 m .47424 .91904 L .47363 .91876 L .706 .788 0 r
F
.474 .92184 m .47777 .91888 L .47651 .92044 L .854 .645 0 r
F
.47216 .92286 m .47426 .92137 L .474 .92184 L F
.47426 .92137 m .47777 .91888 L .474 .92184 L F
.47257 .92168 m .47416 .92083 L .47216 .92286 L 1 1 0 r
F
.47416 .92083 m .47777 .91888 L .47426 .92137 L F
.47416 .92083 m .47426 .92137 L .47216 .92286 L F
.47416 .92083 m .47886 .917 L .47777 .91888 L F
.47257 .92168 m .47425 .92044 L .47416 .92083 L F
.47511 .9198 m .47886 .917 L .47504 .92012 L F
.47425 .92044 m .47511 .9198 L .47416 .92083 L F
.47511 .9198 m .47504 .92012 L .47416 .92083 L F
.47292 .92023 m .47594 .91859 L .47257 .92168 L 1 .608 0 r
F
.47594 .91859 m .47886 .917 L .47607 .91908 L F
.47594 .91859 m .47607 .91908 L .47257 .92168 L F
.4763 .92332 m .47895 .92201 L .47783 .92305 L .858 .919 0 r
F
.4736 .92284 m .47397 .92517 L .47217 .92387 L .616 .812 0 r
F
.4736 .92284 m .47217 .92387 L .472 .92374 L F
.47061 .92359 m .47121 .92462 L .47002 .92443 L .734 .941 0 r
F
.47126 .92472 m .47361 .92542 L .472 .92599 L F
.47018 .92516 m .472 .92374 L .47035 .92449 L 0 0 0 r
F
.4704 .92507 m .472 .92374 L .47018 .92516 L F
.47078 .92503 m .472 .92374 L .47015 .92528 L F
.47121 .92462 m .472 .92374 L .47096 .92484 L F
.47121 .92462 m .47096 .92484 L .47078 .92503 L F
.47121 .92462 m .47198 .92442 L .47126 .92472 L .734 .941 0 r
F
.47061 .92359 m .47165 .92422 L .47121 .92462 L F
.47105 .9248 m .47143 .92451 L .47121 .92462 L 0 0 0 r
F
.47143 .92451 m .47192 .92413 L .47121 .92462 L F
.47165 .92422 m .4718 .92431 L .47121 .92462 L .734 .941 0 r
F
.4718 .92431 m .47198 .92442 L .47121 .92462 L F
.47198 .92442 m .47361 .92542 L .47126 .92472 L F
.47015 .92528 m .4704 .92507 L .47018 .92516 L 0 0 0 r
F
.47078 .92503 m .47041 .92536 L .47018 .92527 L .577 .734 0 r
F
.47015 .92525 m .472 .92599 L .47034 .92647 L F
.47001 .92585 m .47078 .92503 L .47015 .92528 L 0 0 0 r
F
.47078 .92503 m .47018 .92527 L .47015 .92525 L .577 .734 0 r
F
.47071 .92497 m .47078 .92503 L .47015 .92525 L F
.47121 .92462 m .472 .92599 L .47078 .92503 L .734 .941 0 r
F
.47105 .9248 m .47121 .92462 L .47096 .92488 L 0 0 0 r
F
.4711 .92528 m .472 .92599 L .47095 .92557 L .577 .734 0 r
F
.47117 .92594 m .47361 .92542 L .4718 .92431 L .391 .202 0 r
F
.47092 .92491 m .4718 .92431 L .47061 .92359 L F
.47061 .92529 m .47146 .92459 L .47105 .9248 L 0 0 0 r
F
.47161 .9243 m .47146 .92459 L .47061 .92529 L F
.47117 .92594 m .4718 .92431 L .47092 .92491 L .391 .202 0 r
F
.47117 .92462 m .47161 .9243 L .47113 .92477 L 0 0 0 r
F
.47092 .92491 m .47113 .92477 L .47061 .92529 L F
.47117 .92462 m .47113 .92477 L .47092 .92491 L F
.47192 .92413 m .4736 .92284 L .47121 .92462 L F
.47146 .92459 m .4736 .92284 L .47105 .9248 L F
.47161 .9243 m .4736 .92284 L .47146 .92459 L F
.47078 .92503 m .4711 .92528 L .47041 .92536 L .577 .734 0 r
F
.4711 .92528 m .47095 .92557 L .47041 .92536 L F
.47061 .92529 m .47105 .9248 L .47001 .92585 L 0 0 0 r
F
.47105 .9248 m .47096 .92488 L .47001 .92585 L F
.47121 .92462 m .47078 .92503 L .47001 .92585 L F
.47121 .92462 m .47078 .92503 L .47071 .92497 L .734 .941 0 r
F
.47121 .92462 m .47071 .92497 L .47002 .92443 L F
.47121 .92462 m .4736 .92284 L .472 .92374 L 0 0 0 r
F
.47002 .92443 m .47071 .92497 L .47015 .92525 L .577 .734 0 r
F
.47117 .92462 m .47491 .9219 L .4736 .92284 L 0 0 0 r
F
.47511 .92175 m .47657 .92439 L .4736 .92284 L .737 .958 0 r
F
.47491 .9219 m .47511 .92175 L .4736 .92284 L 0 0 0 r
F
.4736 .92284 m .47657 .92439 L .47397 .92517 L .616 .812 0 r
F
.47258 .924 m .47682 .92267 L .4763 .92332 L .858 .919 0 r
F
.47682 .92267 m .47895 .92201 L .4763 .92332 L F
.47169 .92382 m .47511 .92175 L .47117 .92462 L .632 .224 0 r
F
.47293 .92312 m .47474 .92279 L .47258 .924 L 1 1 0 r
F
.47474 .92279 m .47895 .92201 L .47401 .92355 L F
.47474 .92279 m .47401 .92355 L .47258 .924 L F
.47754 .922 m .47954 .92127 L .47895 .92201 L F
.47635 .922 m .47769 .9217 L .47754 .922 L F
.47769 .9217 m .47954 .92127 L .47754 .922 L F
.4749 .91915 m .47788 .92187 L .47886 .917 L 1 .608 0 r
F
.47788 .92187 m .47814 .92184 L .47886 .917 L F
.47392 .91969 m .47704 .92184 L .4771 .92183 L F
.47676 .92242 m .47697 .922 L .47895 .92201 L 1 1 0 r
F
.47392 .91969 m .47993 .92374 L .4749 .91915 L 1 .608 0 r
F
.47474 .92279 m .47635 .922 L .47697 .922 L 1 1 0 r
F
.47474 .92279 m .47697 .922 L .47676 .92242 L F
.47292 .92023 m .47995 .92385 L .47392 .91969 L 1 .608 0 r
F
.47643 .92101 m .47691 .9214 L .47578 .9217 L .706 .788 0 r
F
.47811 .92208 m .47976 .92266 L .47886 .917 L 1 .608 0 r
F
.47691 .9214 m .47989 .92084 L .47709 .92176 L 1 1 0 r
F
.47691 .9214 m .47709 .92176 L .47635 .922 L F
.47691 .9214 m .47764 .92164 L .47747 .92185 L .706 .788 0 r
F
.4767 .92123 m .47686 .9213 L .47691 .9214 L F
.47691 .9214 m .48064 .91952 L .47989 .92084 L 1 1 0 r
F
.47686 .9213 m .47693 .92133 L .47691 .9214 L .706 .788 0 r
F
.47668 .92058 m .47712 .92084 L .4767 .92123 L F
.47706 .92076 m .47786 .92048 L .47691 .9214 L 1 1 0 r
F
.47764 .92008 m .48064 .91952 L .47786 .92048 L F
.47764 .92008 m .47786 .92048 L .47706 .92076 L F
.47786 .92048 m .47946 .91993 L .47774 .92098 L F
.47946 .91993 m .47945 .92012 L .47774 .92098 L F
.47786 .92048 m .47774 .92098 L .47691 .9214 L F
.47704 .92184 m .47989 .92084 L .47954 .92127 L F
.47635 .922 m .47709 .92176 L .47704 .92184 L F
.47709 .92176 m .47989 .92084 L .47704 .92184 L F
.47521 .91964 m .47746 .92101 L .47518 .91969 L .706 .788 0 r
F
.47746 .92101 m .48072 .92299 L .47744 .92104 L F
.47746 .92101 m .47744 .92104 L .47518 .91969 L F
.47169 .92122 m .47443 .91641 L .47117 .92254 L .778 .207 0 r
F
.47443 .91641 m .47442 .9165 L .47117 .92254 L F
.47474 .9159 m .47506 .91532 L .47357 .91765 L 0 0 0 r
F
.47169 .92122 m .4752 .91457 L .47475 .91585 L .778 .207 0 r
F
.4747 .9152 m .47761 .90821 L .47641 .91228 L 1 .625 0 r
F
.47215 .91953 m .4747 .91425 L .4747 .9152 L F
.4747 .91425 m .47761 .90821 L .4747 .9152 L F
.47256 .91729 m .47568 .90969 L .47604 .91104 L 1 .927 0 r
F
.47475 .91585 m .47641 .91228 L .47506 .91532 L .778 .207 0 r
F
.4752 .91457 m .47641 .91228 L .47475 .91585 L F
.47741 .89957 m .47747 .89992 L .47608 .90438 L .462 .125 0 r
F
.47263 .91669 m .47693 .90598 L .47256 .91729 L 1 .962 0 r
F
.47398 .91202 m .47693 .90598 L .47263 .91669 L F
.47693 .90598 m .47732 .90519 L .47709 .90625 L F
.47732 .90519 m .47862 .90254 L .47731 .90573 L F
.47732 .90519 m .47731 .90573 L .47709 .90625 L F
.47747 .89619 m .47756 .89666 L .47746 .89678 L .462 .125 0 r
F
.47723 .90644 m .47862 .90254 L .47779 .90722 L 1 .927 0 r
F
.47709 .90625 m .47731 .90573 L .47723 .90644 L F
.47731 .90573 m .47862 .90254 L .47723 .90644 L F
.4774 .90062 m .47977 .91473 L .47929 .89518 L 1 .746 0 r
F
.47799 .89891 m .47803 .89914 L .47798 .89894 L .462 .125 0 r
F
.47799 .89891 m .47798 .89894 L .47754 .89721 L F
.47756 .89666 m .47799 .89891 L .47754 .89721 L F
.47803 .89914 m .48048 .91196 L .478 .89947 L F
.47803 .89914 m .478 .89947 L .47754 .89721 L F
.47756 .89666 m .47754 .89721 L .47746 .89678 L F
.47693 .90598 m .47709 .90625 L .47256 .91729 L 1 .962 0 r
F
.47709 .90625 m .47779 .90722 L .47761 .90821 L 1 .927 0 r
F
.47256 .91729 m .47761 .90821 L .47215 .91953 L F
.47608 .90438 m .47977 .91473 L .4774 .90062 L 1 .746 0 r
F
.47608 .90438 m .4774 .90032 L .4774 .90062 L 1 .962 0 r
F
.47747 .89992 m .47977 .91473 L .47614 .90453 L .462 .125 0 r
F
.47747 .89992 m .47614 .90453 L .47608 .90438 L F
.4729 .91422 m .47398 .91202 L .47263 .91669 L 1 .962 0 r
F
.4729 .80485 m .47859 .88517 L .47567 .88578 L .185 .03 0 r
F
.47714 .78811 m .47727 .78542 L .47771 .80352 L 1 .684 0 r
F
.47544 .74256 m .4768 .77916 L .47524 .74289 L .717 .135 0 r
F
.4768 .77916 m .47679 .7824 L .47437 .72274 L F
.47696 .77778 m .4774 .73562 L .47818 .76727 L 1 .667 0 r
F
.4768 .77916 m .47686 .77535 L .47696 .77778 L F
.47686 .77535 m .4774 .73562 L .47696 .77778 L F
.4768 .77916 m .47696 .77778 L .47702 .79053 L F
.47696 .77778 m .47818 .76727 L .47727 .78542 L F
.47696 .77778 m .47727 .78542 L .47702 .79053 L F
.4768 .77916 m .4783 .81955 L .47692 .78562 L .717 .135 0 r
F
.4768 .77916 m .47692 .78562 L .47679 .7824 L F
.47293 .8246 m .47567 .88578 L .47301 .87128 L .185 .03 0 r
F
.4729 .80485 m .47567 .88578 L .47293 .8246 L F
.47464 .75948 m .47617 .79249 L .47615 .7949 L 0 0 0 r
F
.47357 .8144 m .47492 .83147 L .4749 .83311 L .185 .03 0 r
F
.4729 .80485 m .4735 .81264 L .47357 .8144 L F
.47859 .88517 m .47984 .88099 L .47861 .88626 L 1 .818 0 r
F
.4735 .81264 m .47803 .87074 L .47357 .8144 L .185 .03 0 r
F
.47984 .88099 m .47949 .89333 L .47948 .8914 L .796 .486 0 r
F
.48069 .88416 m .48046 .88946 L .47938 .8942 L F
.47823 .87592 m .47911 .8664 L .47859 .88517 L 1 .818 0 r
F
.47911 .8664 m .47918 .86965 L .47859 .88517 L F
.47861 .88626 m .47984 .88099 L .47868 .89528 L 1 .901 0 r
F
.47868 .89594 m .47984 .88099 L .47938 .8942 L F
.47861 .89613 m .47868 .89528 L .47868 .89594 L F
.47868 .89528 m .47984 .88099 L .47868 .89594 L F
.47803 .87074 m .47855 .8774 L .47808 .87164 L .185 .03 0 r
F
.48049 .89428 m .48048 .8944 L .48001 .90789 L 1 .821 0 r
F
.47938 .8942 m .48029 .8964 L .48025 .89657 L .944 .693 0 r
F
.48052 .89548 m .48046 .89569 L .48001 .90789 L 1 .821 0 r
F
.47938 .8942 m .48043 .89583 L .48029 .8964 L .944 .693 0 r
F
.47855 .8774 m .48098 .90853 L .47855 .87771 L .185 .03 0 r
F
.47855 .8774 m .47855 .87771 L .47808 .87164 L F
.47803 .87074 m .47808 .87164 L .47357 .8144 L F
.47633 .85083 m .47818 .87386 L .47625 .85224 L F
.47818 .87386 m .4782 .87428 L .47625 .85224 L F
.47835 .87599 m .4784 .87783 L .47625 .85224 L F
.47236 .8194 m .47206 .84766 L .47191 .84758 L 1 .867 0 r
F
.47118 .91001 m .47293 .78432 L .47223 .76725 L .877 .169 0 r
F
.47207 .83279 m .47341 .71687 L .47227 .83137 L F
.47325 .73385 m .4732 .7358 L .47226 .81627 L 0 0 0 r
F
.47325 .73385 m .47226 .81627 L .47229 .81571 L F
.47247 .81701 m .47295 .76662 L .47293 .78432 L .877 .169 0 r
F
.47227 .83137 m .47295 .76662 L .47247 .81701 L F
.47227 .83137 m .47295 .76346 L .47295 .76662 L F
.47118 .90948 m .47207 .83279 L .47227 .83137 L F
.47118 .91001 m .47118 .90949 L .47118 .90948 L F
.47168 .90175 m .47325 .73385 L .47118 .91001 L 0 0 0 r
F
.47325 .73385 m .47341 .71687 L .4732 .7358 L F
.47198 .87014 m .47315 .74753 L .47197 .87016 L F
.47315 .74753 m .47355 .70559 L .47314 .74783 L F
.47315 .74753 m .47314 .74783 L .47197 .87016 L F
.47355 .70559 m .47354 .70627 L .47314 .74793 L F
.47314 .74783 m .47314 .74793 L .47197 .87016 L F
.47355 .70559 m .47314 .74793 L .47314 .74783 L F
.47355 .70559 m .47377 .68218 L .47354 .70627 L F
.47211 .8556 m .47354 .70627 L .47212 .85426 L F
.47354 .70627 m .47377 .68218 L .47354 .70673 L F
.47354 .70627 m .47354 .70673 L .47212 .85426 L F
.47212 .85426 m .47329 .73215 L .4731 .75028 L F
.47253 .83518 m .47271 .81512 L .47248 .83812 L F
.47259 .83185 m .47271 .81512 L .47253 .83518 L F
.47259 .83185 m .47337 .74729 L .47271 .81512 L F
.47337 .74729 m .47335 .74738 L .47248 .83812 L F
.47248 .83812 m .47335 .74738 L .47323 .74803 L F
.4721 .88467 m .47259 .83185 L .47248 .83812 L F
.4721 .88467 m .47365 .69706 L .47168 .90175 L F
.47365 .69706 m .47377 .68218 L .47364 .69658 L F
.47365 .69706 m .47364 .69658 L .47168 .90175 L F
.4783 .81955 m .47824 .82189 L .47437 .72274 L .717 .135 0 r
F
.47236 .83738 m .4734 .73536 L .4721 .88467 L 0 0 0 r
F
.4734 .73536 m .47361 .71532 L .47342 .73621 L F
.4734 .73536 m .47342 .73621 L .4721 .88467 L F
.47361 .71532 m .47364 .7168 L .4721 .88467 L F
.47339 .66021 m .47338 .66606 L .47251 .66726 L 1 .989 0 r
F
.47338 .66606 m .47314 .66797 L .47251 .66726 L F
.47231 .6567 m .47352 .65923 L .47251 .66726 L 1 .928 0 r
F
.47231 .65663 m .47232 .65664 L .47231 .6567 L F
.47232 .65664 m .47352 .65923 L .47231 .6567 L F
.47287 .65065 m .47442 .65374 L .47352 .65923 L 1 .978 0 r
F
.47287 .65064 m .47287 .65064 L .47287 .65065 L F
.47287 .65064 m .47442 .65374 L .47287 .65065 L F
.47336 .64657 m .47442 .65374 L .47287 .65064 L 1 .951 0 r
F
.47287 .65064 m .47352 .65923 L .47231 .65663 L 1 .978 0 r
F
.47106 .80649 m .47123 .76774 L .47078 .82284 L .534 .089 0 r
F
.47123 .76774 m .47169 .66624 L .47094 .77716 L F
.47123 .76774 m .47094 .77716 L .47007 .9074 L F
.4715 .75814 m .47165 .75293 L .47152 .7586 L 1 .86 0 r
F
.47118 .91001 m .47223 .76725 L .47165 .75293 L .877 .169 0 r
F
.47161 .75421 m .47168 .74495 L .47168 .74345 L .534 .089 0 r
F
.47165 .75293 m .47231 .65663 L .47161 .75421 L F
.47169 .66624 m .47175 .66632 L .47169 .66716 L 1 .615 0 r
F
.472 .67674 m .47206 .67501 L .47199 .67547 L .896 .44 0 r
F
.47123 .76774 m .47226 .65741 L .47169 .66624 L .534 .089 0 r
F
.47123 .76774 m .47152 .7586 L .47125 .76988 L 1 .86 0 r
F
.4715 .75814 m .47152 .7586 L .47123 .76774 L F
.47066 .89642 m .47161 .75421 L .47123 .76774 L .534 .089 0 r
F
.47161 .75421 m .47226 .65741 L .47123 .76774 L F
.47094 .77716 m .47169 .66624 L .47052 .7932 L .423 .064 0 r
F
.47101 .74137 m .4715 .75814 L .47123 .76774 L 1 .86 0 r
F
.47101 .74137 m .47165 .75293 L .4715 .75814 L F
.47066 .89642 m .47165 .75293 L .47161 .75421 L .534 .089 0 r
F
.47122 .76656 m .47123 .76774 L .47048 .84674 L 1 .86 0 r
F
.47109 .83412 m .47079 .87825 L .47079 .87825 L .535 .09 0 r
F
.47164 .75565 m .47109 .83413 L .47109 .83412 L F
.47166 .75248 m .47164 .75564 L .47164 .75565 L F
.47164 .75564 m .47109 .83413 L .47164 .75565 L F
.47109 .83413 m .47079 .87825 L .47109 .83412 L F
.47041 .84822 m .47094 .77716 L .47029 .85079 L .423 .064 0 r
F
.47097 .73625 m .47122 .76656 L .47027 .84661 L 1 .86 0 r
F
.47122 .76656 m .47048 .84674 L .47027 .84661 L F
.47103 .73767 m .47161 .75197 L .47101 .74137 L F
.47161 .75197 m .47165 .75293 L .4716 .75214 L F
.47161 .75197 m .4716 .75214 L .47101 .74137 L F
.47097 .73625 m .47103 .73767 L .47101 .74137 L F
.47115 .88492 m .47165 .75293 L .47113 .87354 L .877 .169 0 r
F
.47118 .91001 m .47165 .75293 L .47115 .88492 L F
.47166 .7525 m .47079 .87825 L .47166 .75248 L .535 .09 0 r
F
.47213 .68425 m .47212 .68448 L .47079 .87825 L F
.47075 .89188 m .47213 .68425 L .47066 .89642 L F
.4712 .87015 m .47138 .83583 L .47075 .89188 L F
.47138 .83583 m .4723 .65928 L .47075 .89188 L F
.4723 .65928 m .47229 .65934 L .47066 .89642 L F
.47113 .87354 m .47165 .75293 L .47097 .73625 L .877 .169 0 r
F
.47168 .74345 m .47231 .65663 L .47226 .65741 L .534 .089 0 r
F
.47168 .74495 m .47231 .65663 L .47168 .74345 L F
.47203 .70999 m .47287 .65064 L .47231 .65663 L .535 .09 0 r
F
.4712 .87015 m .47245 .70581 L .47203 .70999 L F
.47245 .70581 m .47287 .65064 L .47203 .70999 L F
.47243 .69856 m .47281 .65693 L .47227 .72951 L .441 .065 0 r
F
.47224 .71985 m .47243 .69856 L .47227 .72951 L F
.47281 .65693 m .47287 .65064 L .47282 .65698 L F
.47281 .65693 m .47282 .65698 L .47227 .72951 L F
.47261 .67847 m .47335 .64782 L .47285 .65206 L F
.47257 .68367 m .47271 .6772 L .47261 .67847 L F
.47271 .6772 m .47335 .64782 L .47261 .67847 L F
.47272 .6827 m .47335 .64782 L .47257 .68367 L F
.47277 .69493 m .4729 .68395 L .47243 .69856 L F
.4729 .68395 m .47335 .64782 L .47266 .68571 L F
.4729 .68395 m .47266 .68571 L .47243 .69856 L F
.47448 .65393 m .47454 .65367 L .47419 .64137 L .229 .03 0 r
F
.47454 .65367 m .47658 .64428 L .47485 .64218 L F
.47454 .65367 m .47485 .64218 L .47419 .64137 L F
.47335 .64782 m .47336 .64657 L .47285 .65206 L .441 .065 0 r
F
.47277 .66433 m .47336 .64657 L .47308 .66984 L .229 .027 0 r
F
.47243 .69856 m .47272 .6827 L .47257 .68367 L .441 .065 0 r
F
.47162 .78805 m .47224 .71985 L .4712 .87015 L F
.47224 .71985 m .47227 .72951 L .4712 .87015 L F
.47162 .78805 m .47277 .69493 L .47243 .69856 L F
.47277 .66433 m .47308 .66984 L .47162 .78805 L .229 .027 0 r
F
.47213 .68425 m .47166 .7525 L .47166 .75248 L .535 .09 0 r
F
.4718 .69348 m .47277 .66433 L .47162 .78805 L .229 .027 0 r
F
.47334 .6474 m .4738 .64361 L .47336 .64657 L F
.47305 .65598 m .47377 .64437 L .47334 .6474 L F
.47312 .65554 m .47377 .64437 L .47305 .65598 L F
.47317 .65728 m .47377 .64437 L .47299 .65775 L F
.47258 .67001 m .47317 .65728 L .47299 .65775 L F
.47261 .66983 m .47289 .66353 L .47258 .67001 L F
.47496 .67464 m .47579 .65913 L .47448 .65393 L .229 .03 0 r
F
.47579 .65913 m .47658 .64428 L .47448 .65393 L F
.47656 .64904 m .47658 .64428 L .47496 .67464 L F
.47583 .65686 m .47634 .65515 L .47605 .65811 L 1 .683 0 r
F
.47471 .65046 m .4761 .65445 L .47583 .65686 L F
.4761 .65445 m .47634 .65515 L .47583 .65686 L F
.47744 .64407 m .4778 .63917 L .47777 .63933 L 0 0 0 r
F
.47634 .65515 m .47662 .65597 L .47605 .65811 L 1 .683 0 r
F
.4768 .65621 m .47663 .65719 L .47658 .65881 L .229 .03 0 r
F
.47696 .65421 m .47658 .65881 L .47675 .65756 L F
.47662 .65597 m .47693 .65685 L .4763 .65956 L 1 .683 0 r
F
.47675 .65462 m .47681 .65247 L .47678 .65507 L .029 0 0 r
F
.47681 .65247 m .47685 .65093 L .47697 .65361 L F
.47685 .65093 m .4771 .6423 L .47699 .65175 L F
.47685 .65093 m .47699 .65175 L .47697 .65361 L F
.47729 .64676 m .47751 .64063 L .47705 .64981 L F
.47681 .65247 m .47697 .65361 L .47693 .65666 L F
.47681 .65247 m .47693 .65666 L .47692 .65655 L F
.47681 .65247 m .47693 .65685 L .47678 .65507 L F
.47693 .65685 m .47713 .65926 L .47656 .66105 L 1 .683 0 r
F
.47736 .64524 m .4775 .64348 L .47744 .64407 L 0 0 0 r
F
.47674 .65474 m .47681 .65549 L .4767 .65522 L 1 .629 0 r
F
.47674 .65474 m .4767 .65522 L .4764 .65452 L F
.47674 .65474 m .47675 .65462 L .47675 .65477 L .029 0 0 r
F
.47674 .65474 m .47697 .65213 L .47675 .65462 L F
.47692 .65655 m .47693 .65666 L .47693 .65685 L F
.47705 .64981 m .47733 .64137 L .47688 .65122 L F
.47717 .64589 m .47751 .64063 L .4773 .64631 L 0 0 0 r
F
.47749 .64232 m .47777 .63933 L .47766 .63989 L F
.47717 .64589 m .47766 .63989 L .4773 .64385 L F
.47701 .64844 m .47717 .64589 L .47719 .64938 L F
.47717 .64589 m .4773 .64631 L .47719 .64938 L F
.47729 .64696 m .47778 .64695 L .47762 .64782 L .867 .538 0 r
F
.47696 .64931 m .47729 .64542 L .47717 .64589 L 0 0 0 r
F
.47709 .64839 m .47729 .64542 L .47696 .64931 L F
.47729 .64542 m .47766 .63989 L .47717 .64589 L F
.47696 .64728 m .47733 .64137 L .4771 .6423 L .029 0 0 r
F
.47711 .64162 m .47743 .63981 L .47722 .64207 L 1 .74 0 r
F
.47743 .63981 m .47801 .63656 L .47755 .63982 L F
.47743 .63981 m .47755 .63982 L .47722 .64207 L F
.47711 .64162 m .47792 .63517 L .47801 .63656 L F
.47695 .64766 m .47733 .64137 L .47696 .64728 L .029 0 0 r
F
.47681 .65247 m .47709 .64638 L .47695 .64766 L F
.47709 .64638 m .47733 .64137 L .47695 .64766 L F
.47682 .65238 m .47733 .64137 L .47681 .65247 L F
.47718 .643 m .47801 .63656 L .47797 .63785 L .92 .215 0 r
F
.47719 .64287 m .47801 .63656 L .47718 .643 L F
.47741 .64473 m .4775 .64348 L .47736 .64524 L 0 0 0 r
F
.47713 .64768 m .47777 .63933 L .47749 .64232 L F
.47723 .64709 m .47777 .63933 L .47713 .64768 L F
.4775 .64348 m .4778 .63917 L .47744 .64407 L F
.47723 .64446 m .4778 .63917 L .47739 .64497 L F
.47793 .64271 m .47791 .64279 L .4775 .64236 L .877 .574 0 r
F
.47696 .65421 m .47663 .65719 L .4768 .65621 L .229 .03 0 r
F
.47681 .65549 m .47693 .65685 L .47662 .65597 L 1 .629 0 r
F
.47669 .65531 m .47662 .65597 L .4761 .65445 L F
.47681 .65549 m .47662 .65597 L .47669 .65531 L F
.4772 .65077 m .47802 .64899 L .47753 .65188 L .936 .578 0 r
F
.47698 .65189 m .47729 .64676 L .47705 .64981 L .029 0 0 r
F
.47696 .65244 m .477 .65176 L .47698 .65189 L F
.477 .65176 m .47729 .64676 L .47698 .65189 L F
.47696 .65243 m .477 .65175 L .47696 .65244 L F
.477 .65175 m .47729 .64676 L .477 .65176 L F
.477 .65175 m .477 .65176 L .47696 .65244 L F
.47804 .64889 m .47802 .64899 L .47757 .64817 L .867 .538 0 r
F
.47715 .65058 m .47729 .64676 L .47696 .65251 L .029 0 0 r
F
.4774 .64617 m .47801 .64561 L .47778 .64695 L .867 .538 0 r
F
.47719 .64766 m .47741 .64473 L .47736 .64524 L 0 0 0 r
F
.47719 .64766 m .47741 .64473 L .47719 .64766 L F
.47721 .64752 m .47741 .64473 L .47718 .64775 L F
.47723 .64446 m .47739 .64497 L .47722 .64746 L F
.47721 .64743 m .47722 .64746 L .47721 .64752 L F
.47723 .64446 m .47722 .64746 L .47721 .64743 L F
.47703 .64631 m .47723 .64446 L .47709 .64668 L F
.47707 .64598 m .47727 .64414 L .47723 .64446 L F
.47703 .64631 m .47708 .64587 L .47707 .64598 L F
.47708 .64587 m .47727 .64414 L .47707 .64598 L F
.47762 .64469 m .47757 .64498 L .47725 .64451 L .833 .528 0 r
F
.47717 .64412 m .47725 .64451 L .47652 .64347 L F
.47655 .64332 m .47652 .64347 L .47529 .64168 L F
.47717 .64412 m .47652 .64347 L .47655 .64332 L F
.4753 .64179 m .4766 .64362 L .47681 .64495 L .867 .538 0 r
F
.4766 .64362 m .47724 .64453 L .47681 .64495 L F
.47724 .64453 m .47757 .64499 L .47719 .64497 L F
.47724 .64453 m .47719 .64497 L .47681 .64495 L F
.4778 .63917 m .48072 .64104 L .48031 .64257 L .879 .767 0 r
F
.47797 .63785 m .48072 .64104 L .4778 .63917 L .753 .691 0 r
F
.47722 .64469 m .47785 .63895 L .47722 .64475 L 0 0 0 r
F
.47725 .64451 m .47785 .63895 L .47722 .64474 L F
.47708 .64365 m .47718 .643 L .47725 .64451 L .92 .215 0 r
F
.47733 .64368 m .47785 .63895 L .47774 .63989 L 0 0 0 r
F
.47734 .64364 m .47785 .63895 L .47733 .64368 L F
.47734 .64349 m .47774 .63989 L .47734 .64348 L F
.47734 .64349 m .47734 .64348 L .47732 .64368 L F
.47723 .64446 m .47734 .64349 L .47732 .64368 L F
.47727 .64414 m .47774 .63989 L .47723 .64446 L F
.4773 .64385 m .47766 .63989 L .47751 .64063 L F
.47732 .64368 m .47734 .64348 L .47734 .64348 L F
.47734 .64348 m .47794 .63807 L .47734 .64348 L F
.47734 .64348 m .47794 .63807 L .47743 .64262 L F
.47774 .63989 m .47794 .63807 L .47732 .64368 L F
.47774 .63989 m .47797 .63785 L .47794 .63807 L F
.47785 .63895 m .47797 .63785 L .47774 .63989 L F
.47743 .64262 m .47794 .63807 L .4778 .63917 L F
.47718 .643 m .47797 .63785 L .47735 .64353 L .92 .215 0 r
F
.47721 .64482 m .47734 .64364 L .47733 .64368 L 0 0 0 r
F
.47719 .645 m .47721 .6448 L .47721 .64482 L F
.47721 .6448 m .47734 .64364 L .47721 .64482 L F
.4773 .64407 m .4783 .6442 L .47803 .64551 L .833 .528 0 r
F
.47721 .64483 m .47721 .64482 L .47703 .64631 L 0 0 0 r
F
.47721 .64482 m .47774 .63989 L .47706 .64603 L F
.47721 .64482 m .47706 .64603 L .47703 .64631 L F
.47728 .64167 m .47801 .63656 L .47719 .64287 L .92 .215 0 r
F
.47721 .64243 m .47719 .64287 L .4771 .64354 L F
.47728 .64167 m .47719 .64287 L .47721 .64243 L F
.47751 .64229 m .4775 .64236 L .47722 .64207 L .877 .574 0 r
F
.47722 .64202 m .47722 .64207 L .47671 .64154 L F
.47751 .64229 m .47722 .64207 L .47722 .64202 L F
.47717 .63992 m .47792 .63517 L .47733 .63986 L 1 .74 0 r
F
.47717 .63992 m .47733 .63986 L .47711 .64162 L F
.47691 .64136 m .47717 .63992 L .47711 .64162 L .877 .574 0 r
F
.47515 .63902 m .47717 .63992 L .47691 .64136 L F
.4771 .63995 m .47718 .63998 L .47717 .63992 L .989 .684 0 r
F
.47725 .6395 m .47723 .63958 L .47718 .63996 L 1 .881 0 r
F
.47725 .6395 m .47718 .63996 L .47718 .63997 L F
.47723 .63958 m .47718 .63989 L .47717 .63992 L F
.47718 .63998 m .47724 .63716 L .47729 .63925 L F
.47545 .64022 m .47735 .64221 L .47547 .64033 L .833 .528 0 r
F
.47735 .64221 m .47735 .64221 L .47547 .64033 L F
.4775 .64236 m .4775 .64238 L .47547 .64033 L F
.47718 .643 m .47735 .64353 L .47725 .64451 L .92 .215 0 r
F
.47708 .64365 m .47743 .64301 L .4773 .64407 L .833 .528 0 r
F
.47519 .63995 m .47683 .64219 L .47708 .64365 L F
.47708 .64365 m .47721 .64233 L .4771 .64354 L .92 .215 0 r
F
.47683 .64219 m .47717 .64266 L .47708 .64365 L .833 .528 0 r
F
.47705 .64385 m .47714 .64305 L .47708 .64365 L .92 .215 0 r
F
.47714 .64305 m .47721 .64233 L .47708 .64365 L F
.47721 .64233 m .47721 .64243 L .4771 .64354 L F
.4771 .64354 m .47719 .64287 L .47718 .643 L F
.47717 .64266 m .47743 .64301 L .47708 .64365 L .833 .528 0 r
F
.47751 .64229 m .47671 .64154 L .47669 .64146 L .877 .574 0 r
F
.47547 .64033 m .47722 .6421 L .47717 .64266 L .833 .528 0 r
F
.47552 .64059 m .47708 .64365 L .47587 .64243 L F
.47708 .64365 m .47707 .64381 L .47587 .64243 L F
.4773 .64407 m .47728 .64425 L .47587 .64243 L F
.47708 .64856 m .47723 .64709 L .47713 .64768 L 0 0 0 r
F
.47701 .64844 m .47719 .64938 L .47712 .65133 L F
.47696 .65251 m .47696 .65243 L .47696 .65244 L .029 0 0 r
F
.47678 .65507 m .47693 .65685 L .47678 .65519 L F
.47702 .65599 m .47693 .65685 L .47681 .65549 L 1 .629 0 r
F
.47681 .65549 m .4761 .65445 L .47616 .65393 L F
.47649 .66188 m .47719 .66467 L .47713 .66606 L 1 .683 0 r
F
.47656 .661 m .47657 .66062 L .47649 .66188 L .229 .03 0 r
F
.47649 .66188 m .47657 .66056 L .47649 .66168 L F
.47657 .66056 m .47654 .66084 L .47649 .66168 L F
.47471 .65046 m .47656 .66105 L .47649 .66188 L 1 .683 0 r
F
.47656 .66105 m .47719 .66467 L .47649 .66188 L F
.47647 .66414 m .47656 .661 L .47649 .66188 L .229 .03 0 r
F
.47686 .67986 m .47931 .71775 L .4764 .70205 L 1 .803 0 r
F
.47614 .72491 m .47693 .65685 L .47675 .65891 L .229 .03 0 r
F
.47678 .65519 m .47693 .65685 L .47614 .72491 L .029 0 0 r
F
.47614 .72491 m .47649 .66188 L .47496 .67464 L .229 .03 0 r
F
.47579 .68775 m .47674 .65474 L .47669 .66056 L .029 0 0 r
F
.47579 .68775 m .47667 .66381 L .47614 .72491 L F
.47674 .65474 m .47675 .65477 L .47614 .72491 L F
.47674 .65474 m .47702 .65599 L .47681 .65549 L 1 .629 0 r
F
.47675 .65462 m .47678 .65507 L .47614 .72491 L .029 0 0 r
F
.47674 .65474 m .47728 .65294 L .47702 .65599 L 1 .629 0 r
F
.47696 .65012 m .47712 .65133 L .47712 .65146 L 0 0 0 r
F
.47693 .64975 m .47701 .64844 L .47696 .65005 L F
.47692 .64984 m .47709 .64839 L .47696 .64931 L F
.47692 .64984 m .47699 .65037 L .47688 .65018 L .936 .578 0 r
F
.47697 .65213 m .47705 .64981 L .47677 .65432 L .029 0 0 r
F
.4768 .65406 m .47677 .65432 L .47675 .65462 L F
.47697 .65213 m .47677 .65432 L .4768 .65406 L F
.47753 .65188 m .47747 .65227 L .47712 .65146 L .936 .578 0 r
F
.47705 .64981 m .47682 .65238 L .47687 .65213 L .029 0 0 r
F
.47675 .65443 m .47705 .64981 L .47679 .65315 L F
.47675 .65462 m .47677 .65432 L .47675 .65443 L F
.47677 .65432 m .47705 .64981 L .47675 .65443 L F
.47705 .65088 m .47712 .65146 L .47493 .6465 L .936 .578 0 r
F
.47712 .65146 m .47715 .65058 L .47694 .65297 L .029 0 0 r
F
.4772 .65077 m .47716 .65111 L .47705 .65088 L .936 .578 0 r
F
.47705 .64981 m .47688 .65122 L .47696 .6508 L .029 0 0 r
F
.47699 .65037 m .47705 .65088 L .47493 .6465 L .936 .578 0 r
F
.47705 .65088 m .47712 .65146 L .47705 .65088 L 0 0 0 r
F
.47705 .65088 m .47705 .65088 L .47696 .65014 L F
.47696 .65012 m .47705 .65088 L .47696 .65014 L F
.47701 .64844 m .47712 .65133 L .47696 .65012 L F
.4772 .65077 m .47705 .65088 L .47699 .65037 L .936 .578 0 r
F
.47687 .65213 m .47682 .65238 L .47679 .65315 L .029 0 0 r
F
.47712 .65146 m .47747 .65227 L .47674 .65474 L 1 .629 0 r
F
.47579 .68775 m .47694 .65297 L .47674 .65474 L .029 0 0 r
F
.47694 .65297 m .47696 .65251 L .47674 .65474 L F
.47695 .65281 m .47715 .65058 L .47696 .65251 L F
.47694 .65297 m .47698 .6526 L .47695 .65281 L F
.47698 .6526 m .47715 .65058 L .47695 .65281 L F
.47696 .6508 m .47688 .65122 L .47682 .65238 L F
.47696 .65251 m .47697 .65213 L .47674 .65474 L F
.47679 .65315 m .47682 .65238 L .47681 .65247 L F
.47621 .64941 m .47712 .65146 L .47674 .65474 L 1 .629 0 r
F
.47674 .65474 m .4764 .65452 L .47643 .6543 L F
.47674 .65474 m .47616 .65393 L .4762 .65359 L F
.47493 .6465 m .47674 .65474 L .47471 .65046 L F
.47493 .6465 m .47621 .64941 L .47674 .65474 L F
.47649 .66188 m .4759 .65956 L .47589 .65978 L .229 .03 0 r
F
.47471 .65046 m .47649 .66188 L .4745 .65491 L 1 .683 0 r
F
.47649 .66188 m .47589 .65978 L .47496 .67464 L .229 .03 0 r
F
.47566 .66959 m .47692 .64984 L .47579 .68775 L 0 0 0 r
F
.47692 .64984 m .47693 .64975 L .47692 .64986 L F
.47692 .64984 m .47692 .64986 L .47579 .68775 L F
.47716 .65111 m .47712 .65146 L .47705 .65088 L .936 .578 0 r
F
.47753 .65188 m .47712 .65146 L .47716 .65111 L F
.47579 .68775 m .47712 .65146 L .47694 .65297 L .029 0 0 r
F
.47696 .65014 m .47712 .65146 L .47579 .68775 L 0 0 0 r
F
.47692 .64984 m .4772 .65077 L .47699 .65037 L .936 .578 0 r
F
.47692 .64984 m .47757 .64817 L .4772 .65077 L F
.47721 .64752 m .47757 .64817 L .47692 .64984 L F
.47693 .64975 m .47696 .65005 L .47579 .68775 L 0 0 0 r
F
.47566 .66959 m .47708 .64847 L .47692 .64984 L F
.47708 .64847 m .47709 .64839 L .47692 .64984 L F
.47692 .64984 m .47688 .65018 L .47493 .6465 L .936 .578 0 r
F
.47509 .64365 m .47692 .64984 L .47493 .6465 L F
.4772 .65077 m .47753 .65188 L .47716 .65111 L F
.47509 .64365 m .47643 .64608 L .47692 .64984 L F
.47707 .6487 m .47718 .64775 L .47708 .64856 L 0 0 0 r
F
.47718 .64779 m .47718 .64775 L .47707 .6487 L F
.47718 .64775 m .47723 .64709 L .47708 .64856 L F
.47718 .64775 m .47719 .64766 L .47719 .64766 L F
.47643 .64608 m .47721 .64752 L .47692 .64984 L .936 .578 0 r
F
.47566 .66959 m .47718 .64779 L .47707 .6487 L 0 0 0 r
F
.47723 .64446 m .47721 .64752 L .47709 .6467 L F
.47703 .64631 m .47709 .64668 L .47709 .6467 L F
.47703 .64631 m .47709 .64666 L .47509 .64365 L .867 .538 0 r
F
.47729 .64696 m .47725 .64722 L .47509 .64365 L F
.47699 .64703 m .47699 .64711 L .47509 .64365 L F
.4772 .64739 m .47699 .64711 L .47699 .64703 L F
.4772 .64739 m .47721 .64752 L .47699 .64711 L F
.47762 .64782 m .47758 .64808 L .47509 .64365 L F
.47703 .64631 m .47709 .6467 L .47566 .66959 L 0 0 0 r
F
.47517 .64152 m .47703 .64631 L .47509 .64365 L .867 .538 0 r
F
.47703 .64631 m .47729 .64696 L .47709 .64666 L F
.47729 .64696 m .47762 .64782 L .47725 .64722 L F
.47723 .64189 m .47722 .642 L .47545 .64022 L .877 .574 0 r
F
.47711 .64168 m .47712 .64179 L .47604 .64078 L F
.47572 .63977 m .47711 .64162 L .47604 .64078 L F
.47711 .64162 m .47713 .64169 L .47604 .64078 L F
.47517 .64152 m .47681 .64495 L .47691 .64555 L .867 .538 0 r
F
.47517 .64152 m .47691 .64555 L .47688 .64591 L F
.47529 .64168 m .47801 .64561 L .4753 .64179 L F
.47543 .65103 m .47706 .64064 L .47711 .64162 L 1 .74 0 r
F
.47706 .64064 m .47717 .63992 L .47711 .64162 L F
.47718 .63997 m .47718 .63996 L .47714 .64015 L 1 .881 0 r
F
.47716 .64005 m .47714 .64015 L .47543 .65103 L F
.47718 .63997 m .47714 .64015 L .47716 .64005 L F
.47717 .63992 m .47814 .64035 L .47711 .64162 L .877 .574 0 r
F
.47718 .63998 m .47814 .64035 L .47726 .63996 L .989 .684 0 r
F
.47718 .63998 m .47726 .63996 L .47717 .63992 L F
.47718 .63998 m .47787 .63767 L .47814 .64035 L F
.47723 .63958 m .47717 .63992 L .47543 .65103 L 1 .881 0 r
F
.4767 .63979 m .4771 .63995 L .4769 .6398 L .989 .684 0 r
F
.4771 .63995 m .47717 .63992 L .4769 .6398 L F
.47505 .63915 m .4767 .63979 L .47515 .63902 L F
.4767 .63979 m .4769 .6398 L .47515 .63902 L F
.47505 .63915 m .47713 .63806 L .47718 .63998 L F
.47687 .64004 m .47713 .63806 L .47718 .63998 L 1 .881 0 r
F
.47713 .63806 m .47724 .63716 L .47718 .63998 L F
.4775 .63786 m .47792 .63517 L .4775 .63787 L F
.4775 .63786 m .4775 .63787 L .47718 .63989 L F
.47725 .6395 m .4775 .63786 L .47718 .63989 L F
.47724 .63716 m .4777 .63365 L .47729 .63925 L F
.47713 .63806 m .47756 .63783 L .47718 .63998 L .989 .684 0 r
F
.47756 .63783 m .47787 .63767 L .47718 .63998 L F
.47669 .64146 m .47671 .64154 L .47545 .64022 L .877 .574 0 r
F
.47616 .65393 m .4761 .65445 L .47471 .65046 L 1 .629 0 r
F
.4762 .65359 m .47616 .65393 L .47471 .65046 L F
.47543 .65103 m .47711 .64162 L .47552 .6539 L 1 .74 0 r
F
.47533 .65186 m .47564 .6499 L .47543 .65103 L 1 .881 0 r
F
.47564 .6499 m .47725 .6395 L .47543 .65103 L F
.47521 .65219 m .47543 .65103 L .47552 .6539 L .321 .06 0 r
F
.47292 .66305 m .47303 .66066 L .4729 .66313 L .229 .027 0 r
F
.47303 .66066 m .47377 .64437 L .47301 .66081 L F
.47303 .66066 m .47301 .66081 L .4729 .66313 L F
.47449 .64828 m .47493 .64482 L .47493 .6465 L 1 .937 0 r
F
.47276 .66963 m .47377 .64437 L .47254 .67136 L .229 .027 0 r
F
.47377 .64437 m .4738 .64361 L .47334 .6474 L F
.47285 .65206 m .47336 .64657 L .47287 .65064 L .441 .065 0 r
F
.47289 .66353 m .47288 .66362 L .47258 .67001 L .229 .027 0 r
F
.47299 .65775 m .47312 .65554 L .47305 .65598 L F
.47254 .67136 m .47261 .66983 L .47258 .67001 L F
.47229 .67862 m .47276 .66963 L .47254 .67136 L F
.4718 .69348 m .4725 .67595 L .47229 .67862 L F
.4725 .67595 m .47276 .66963 L .47229 .67862 L F
.4723 .65928 m .47231 .65663 L .47229 .65934 L .535 .09 0 r
F
.47192 .66285 m .47349 .64678 L .4718 .69348 L 0 0 0 r
F
.47285 .65725 m .47303 .65963 L .47314 .6564 L 1 .791 0 r
F
.47349 .66073 m .47338 .66606 L .47339 .66021 L 1 .989 0 r
F
.47217 .64106 m .47218 .64113 L .47211 .64478 L .956 .505 0 r
F
.47529 .66628 m .47527 .66641 L .4749 .66337 L .843 .409 0 r
F
.47401 .67586 m .47402 .67651 L .47359 .72321 L 0 0 0 r
F
.47359 .7223 m .47359 .72321 L .47259 .83185 L F
.47401 .67586 m .47359 .72321 L .47359 .7223 L F
.47352 .72925 m .47259 .83185 L .47259 .83133 L F
.47401 .67586 m .47352 .72938 L .47352 .72925 L F
.47352 .72938 m .47259 .83185 L .47352 .72925 L F
.47397 .67978 m .47401 .67586 L .47398 .67979 L F
.47401 .67586 m .47412 .66552 L .47402 .67651 L F
.4739 .68705 m .47444 .65626 L .47412 .66552 L F
.47435 .67485 m .47518 .68764 L .4745 .65491 L 1 .791 0 r
F
.47518 .68764 m .47528 .688 L .4745 .65491 L F
.4745 .65504 m .4745 .65491 L .4745 .65483 L F
.47435 .67485 m .4745 .65491 L .4745 .65504 L F
.47379 .69759 m .47397 .67978 L .47381 .69803 L 0 0 0 r
F
.47376 .70045 m .47401 .68453 L .4739 .68705 L F
.47401 .68453 m .47444 .65626 L .4739 .68705 L F
.47361 .71532 m .47403 .69202 L .47376 .70045 L F
.47236 .83738 m .47372 .71863 L .47361 .71532 L F
.47336 .72935 m .47339 .73013 L .47327 .73893 L F
.47375 .68902 m .47394 .67691 L .47383 .68038 L F
.47375 .68902 m .47383 .68038 L .47377 .68218 L F
.47367 .69426 m .47375 .68902 L .47377 .68218 L F
.47394 .67691 m .47392 .67526 L .47377 .68218 L F
.47387 .67605 m .47339 .73013 L .47336 .72935 L F
.47403 .69202 m .47415 .68102 L .47376 .70045 L F
.47415 .68102 m .47444 .65626 L .47401 .68453 L F
.47415 .68102 m .47401 .68453 L .47376 .70045 L F
.47394 .67691 m .47412 .66552 L .47392 .67526 L F
.47387 .67605 m .47444 .65626 L .47396 .6901 L F
.47379 .68538 m .47396 .6901 L .47339 .73013 L F
.47387 .67605 m .47396 .6901 L .47379 .68538 L F
.47441 .65822 m .47444 .65626 L .47442 .65789 L F
.47441 .65822 m .47442 .65789 L .47403 .69202 L F
.47396 .6901 m .47441 .65822 L .47403 .69202 L F
.474 .67295 m .47402 .67264 L .4745 .65491 L F
.47262 .71958 m .47387 .67605 L .47327 .73893 L F
.47373 .68295 m .47376 .68212 L .47388 .67783 L F
.47371 .68353 m .47376 .68212 L .47373 .68295 L F
.47371 .68353 m .47388 .67783 L .47385 .67839 L F
.47352 .65923 m .47349 .66073 L .47339 .66021 L 1 .989 0 r
F
.47491 .66323 m .47457 .66061 L .47491 .66318 L .843 .409 0 r
F
.47388 .67555 m .47393 .67452 L .47444 .65626 L 0 0 0 r
F
.47376 .6806 m .47383 .67885 L .47395 .67454 L F
.47393 .67452 m .47398 .67354 L .47444 .65626 L F
.47383 .67885 m .4745 .65491 L .47444 .65626 L F
.47365 .68577 m .47385 .67839 L .47383 .67885 L F
.47385 .67839 m .4745 .65491 L .47383 .67885 L F
.47289 .66353 m .47292 .66305 L .47288 .66362 L .229 .027 0 r
F
.47292 .66305 m .4729 .66313 L .47288 .66362 L F
.47349 .64678 m .47342 .65306 L .4718 .69348 L 0 0 0 r
F
.47314 .6564 m .47435 .67485 L .47445 .65271 L 1 .791 0 r
F
.47322 .66216 m .47531 .68964 L .47338 .65997 L F
.47402 .67264 m .47417 .66778 L .47416 .66761 L 0 0 0 r
F
.47435 .67485 m .4745 .65483 L .47445 .65271 L 1 .791 0 r
F
.47422 .66609 m .47471 .65046 L .47418 .66692 L 0 0 0 r
F
.47416 .66761 m .47471 .65046 L .4745 .65491 L F
.47407 .67157 m .47471 .65046 L .47402 .67264 L F
.4739 .67566 m .47395 .67454 L .47398 .67354 L F
.4739 .67566 m .47398 .67354 L .47393 .67452 L F
.47376 .6806 m .47395 .67454 L .4739 .67566 L F
.47376 .6797 m .47376 .6806 L .47393 .67452 L F
.47376 .6797 m .47393 .67452 L .47388 .67555 L F
.47376 .6806 m .47376 .68163 L .47383 .67885 L F
.47385 .67839 m .47388 .67783 L .47402 .67264 L F
.47385 .67839 m .47402 .67264 L .474 .67295 L F
.4735 .68994 m .47365 .68577 L .47376 .68163 L F
.47318 .69984 m .4735 .6899 L .47348 .68945 L F
.47319 .69984 m .4735 .68994 L .47318 .69984 L F
.4735 .68994 m .47376 .68163 L .4735 .6899 L F
.4735 .68994 m .4735 .6899 L .47318 .69984 L F
.47374 .71686 m .47403 .69202 L .47361 .71532 L F
.47348 .68945 m .47376 .68163 L .47376 .6797 L F
.4735 .6899 m .47376 .68163 L .47348 .68945 L F
.47311 .70254 m .47319 .69984 L .47318 .69984 L F
.47365 .68577 m .47374 .68264 L .47371 .68353 L F
.47374 .68264 m .47376 .68212 L .47371 .68353 L F
.47229 .7309 m .47262 .71958 L .47236 .83738 L F
.47262 .71958 m .47343 .7439 L .47236 .83738 L F
.47319 .69984 m .47351 .69015 L .4735 .68994 L F
.47311 .70254 m .47319 .69983 L .47319 .69984 L F
.47319 .69983 m .47351 .69015 L .47319 .69984 L F
.47351 .69015 m .47365 .68577 L .4735 .68994 L F
.47229 .7309 m .47317 .70175 L .47311 .70254 L F
.47317 .70175 m .47323 .69983 L .47311 .70254 L F
.47323 .69983 m .47365 .68577 L .47319 .69983 L F
.47323 .69983 m .47319 .69983 L .47311 .70254 L F
.47344 .69981 m .47364 .70437 L .47364 .70485 L F
.47223 .6762 m .47245 .67703 L .47229 .7309 L 1 .341 0 r
F
.47245 .67703 m .47376 .68212 L .47323 .69983 L F
.47245 .67703 m .47323 .69983 L .47229 .7309 L F
.47317 .69259 m .47346 .69981 L .47344 .69981 L 0 0 0 r
F
.47346 .69981 m .47364 .70437 L .47344 .69981 L F
.47372 .71863 m .4737 .71631 L .47361 .71532 L F
.47327 .73893 m .47396 .6901 L .47343 .7439 L F
.47372 .71863 m .47374 .71686 L .4737 .71631 L F
.47396 .6901 m .47403 .69202 L .47343 .7439 L F
.47319 .68186 m .47447 .71638 L .47316 .68855 L .717 .135 0 r
F
.47373 .69647 m .47373 .69641 L .47367 .6949 L F
.47368 .69515 m .47367 .6949 L .47319 .68186 L F
.47373 .69647 m .47367 .6949 L .47368 .69515 L F
.47316 .68121 m .47368 .69518 L .47319 .68186 L F
.47368 .69518 m .47373 .69647 L .47368 .69515 L F
.47368 .69518 m .47368 .69515 L .47319 .68186 L F
.47365 .70429 m .47364 .70437 L .47346 .69981 L 0 0 0 r
F
.47346 .69981 m .47346 .69981 L .47317 .69259 L F
.47365 .70429 m .47346 .69981 L .47346 .69981 L F
.47426 .65516 m .4748 .64882 L .47458 .65178 L 1 .341 0 r
F
.47363 .66162 m .47427 .65463 L .47426 .65516 L F
.47427 .65463 m .4748 .64882 L .47426 .65516 L F
.4738 .65936 m .47386 .65875 L .47363 .66162 L F
.47349 .64678 m .4738 .64361 L .47342 .65306 L 0 0 0 r
F
.47285 .65725 m .47445 .65271 L .47419 .64137 L 1 .791 0 r
F
.4735 .64668 m .47419 .64137 L .4738 .64361 L 0 0 0 r
F
.47312 .65062 m .47358 .64661 L .4735 .64668 L F
.47358 .64661 m .47419 .64137 L .4735 .64668 L F
.47321 .65026 m .47341 .64843 L .47312 .65062 L F
.47341 .64843 m .47419 .64137 L .4733 .64901 L F
.47341 .64843 m .4733 .64901 L .47312 .65062 L F
.47462 .64197 m .47519 .63995 L .47517 .64152 L 1 .929 0 r
F
.4732 .6407 m .47347 .64225 L .47331 .64247 L 1 .955 0 r
F
.47331 .64247 m .47347 .64225 L .47326 .64286 L 1 .929 0 r
F
.47331 .64247 m .47326 .64286 L .47315 .64316 L F
.47323 .6431 m .47347 .64225 L .47352 .64286 L F
.47315 .64316 m .47326 .64286 L .47323 .6431 L F
.47326 .64286 m .47347 .64225 L .47323 .6431 L F
.47412 .65608 m .4748 .64882 L .4741 .65648 L 1 .341 0 r
F
.47281 .65442 m .47309 .6518 L .47266 .65526 L 0 0 0 r
F
.47309 .6518 m .47419 .64137 L .473 .65223 L F
.47309 .6518 m .473 .65223 L .47266 .65526 L F
.47375 .65123 m .47497 .6442 L .47449 .64828 L 1 .937 0 r
F
.47513 .68742 m .47614 .72491 L .47531 .68964 L 1 .791 0 r
F
.4721 .661 m .47271 .65537 L .47266 .65526 L 0 0 0 r
F
.47216 .66056 m .47281 .65442 L .4721 .661 L F
.47271 .65537 m .47281 .65442 L .47272 .65492 L F
.47271 .65537 m .47272 .65492 L .47266 .65526 L F
.47192 .66285 m .47216 .66056 L .4721 .661 L F
.47266 .65526 m .47321 .65026 L .47312 .65062 L F
.47202 .65092 m .47419 .64137 L .47192 .66285 L 1 .791 0 r
F
.47202 .65092 m .47376 .68212 L .47513 .68742 L F
.47376 .68212 m .47614 .72491 L .47513 .68742 L F
.47318 .66616 m .47336 .67095 L .47311 .66718 L 1 .58 0 r
F
.47318 .66616 m .47311 .66718 L .47202 .65092 L F
.47392 .67676 m .47391 .67662 L .47388 .67783 L 0 0 0 r
F
.47202 .65092 m .47531 .68964 L .47228 .6498 L 1 .791 0 r
F
.47473 .65723 m .47559 .65969 L .47562 .66386 L .843 .409 0 r
F
.47406 .67199 m .47471 .65046 L .47403 .67264 L 0 0 0 r
F
.47392 .67676 m .47406 .67199 L .47391 .67662 L F
.47406 .67199 m .47403 .67264 L .47391 .67662 L F
.47417 .66778 m .47422 .66609 L .47416 .66761 L F
.47422 .66609 m .47418 .66692 L .47416 .66761 L F
.47388 .67783 m .47407 .67157 L .47402 .67264 L F
.47333 .66467 m .47471 .65046 L .47392 .67676 L 1 .341 0 r
F
.47453 .65577 m .47476 .6566 L .47473 .65723 L .843 .409 0 r
F
.47476 .6566 m .47559 .65969 L .47473 .65723 L F
.47376 .68212 m .47392 .67676 L .47388 .67783 L 0 0 0 r
F
.47333 .66467 m .47392 .67676 L .47376 .68212 L 1 .341 0 r
F
.47318 .66616 m .47333 .66467 L .47366 .6795 L F
.47366 .6795 m .47333 .66467 L .47376 .68212 L F
.47364 .67516 m .47363 .67984 L .473 .66852 L 1 .58 0 r
F
.47311 .66718 m .473 .66852 L .47202 .65092 L F
.47364 .67516 m .473 .66852 L .47311 .66718 L F
.47228 .6498 m .47285 .65725 L .47419 .64137 L 1 .791 0 r
F
.47347 .6599 m .47245 .64866 L .47245 .64853 L .956 .505 0 r
F
.47347 .65992 m .47245 .64866 L .47347 .6599 L F
.47358 .66119 m .47245 .64866 L .47358 .66117 L F
.47315 .65366 m .47325 .65326 L .47355 .66158 L 1 .937 0 r
F
.47347 .65235 m .47493 .6465 L .47392 .65748 L F
.47382 .64973 m .47497 .6442 L .47375 .65123 L F
.47315 .64316 m .47335 .6455 L .47271 .64163 L .678 .272 0 r
F
.47279 .64148 m .47271 .64163 L .47241 .63984 L F
.47279 .64148 m .47241 .63984 L .47244 .63983 L F
.47222 .63683 m .47312 .64295 L .47233 .63932 L F
.47312 .64295 m .47312 .64299 L .47233 .63932 L F
.47328 .65315 m .47382 .64973 L .47375 .65123 L 1 .937 0 r
F
.47325 .65326 m .4733 .65297 L .47328 .65315 L F
.4733 .65297 m .47382 .64973 L .47328 .65315 L F
.4738 .65425 m .47382 .65453 L .47345 .65151 L .843 .409 0 r
F
.47343 .65125 m .47345 .65151 L .47301 .6479 L F
.47301 .64787 m .47301 .6479 L .47217 .64106 L F
.47346 .65144 m .47301 .6479 L .47301 .64787 L F
.47425 .66871 m .47399 .66582 L .47425 .6687 L .956 .505 0 r
F
.47325 .65326 m .47369 .66001 L .47355 .66158 L 1 .937 0 r
F
.47342 .66346 m .47372 .65967 L .47362 .66132 L 1 .341 0 r
F
.47348 .66252 m .47372 .65967 L .47342 .66346 L F
.47355 .66158 m .47372 .65967 L .47348 .66252 L F
.47303 .65963 m .47322 .66216 L .47314 .6564 L 1 .791 0 r
F
.47322 .66216 m .47338 .65997 L .47314 .6564 L F
.47269 .65154 m .47355 .66158 L .47318 .66616 L 1 .58 0 r
F
.47355 .66158 m .47348 .66252 L .47335 .66407 L 1 .341 0 r
F
.47329 .66475 m .47348 .66252 L .47342 .66346 L F
.47318 .66616 m .47336 .66421 L .47333 .66467 L F
.47336 .66421 m .4738 .65936 L .47333 .66467 L F
.47329 .66475 m .47342 .66346 L .47318 .66616 L F
.47342 .66346 m .4738 .65936 L .47336 .66421 L F
.47342 .66346 m .47336 .66421 L .47318 .66616 L F
.47358 .66119 m .47267 .65117 L .47267 .65105 L .956 .505 0 r
F
.47333 .66467 m .4738 .65936 L .47363 .66162 L 1 .341 0 r
F
.47425 .66871 m .47358 .66121 L .47358 .66119 L .956 .505 0 r
F
.47358 .66121 m .47267 .65117 L .47358 .66119 L F
.47355 .66158 m .47366 .6629 L .47318 .66616 L 1 .58 0 r
F
.47355 .66158 m .47335 .66407 L .47329 .66475 L 1 .341 0 r
F
.47348 .66237 m .47355 .66158 L .47329 .66475 L F
.47399 .66582 m .47358 .66119 L .47399 .66579 L .956 .505 0 r
F
.47358 .66119 m .47245 .64866 L .47358 .66119 L F
.47358 .66119 m .47358 .66119 L .47399 .66579 L F
.47399 .66582 m .47399 .66579 L .47425 .6687 L F
.47425 .66872 m .47399 .66586 L .47425 .66871 L F
.47399 .66586 m .47267 .65117 L .47399 .66584 L F
.47399 .66586 m .47399 .66584 L .47425 .66871 L F
.47425 .66872 m .47424 .66903 L .47267 .65117 L F
.47239 .65026 m .47269 .65154 L .47318 .66616 L 1 .58 0 r
F
.47211 .64478 m .47254 .6498 L .47239 .65026 L F
.47254 .6498 m .47269 .65154 L .47239 .65026 L F
.4732 .6407 m .47344 .64061 L .47347 .64225 L 1 .955 0 r
F
.47344 .64061 m .47519 .63995 L .47376 .64187 L F
.47344 .64061 m .47376 .64187 L .47347 .64225 L F
.47339 .64109 m .47365 .64239 L .4734 .6413 L 1 .542 0 r
F
.47393 .64571 m .47511 .64309 L .47499 .64381 L 1 .969 0 r
F
.47393 .64569 m .47511 .64309 L .47393 .64571 L F
.47419 .6449 m .47511 .64309 L .47393 .64569 L F
.47393 .64567 m .47393 .64569 L .4739 .64577 L F
.47419 .6449 m .47393 .64569 L .47393 .64567 L F
.47316 .64709 m .47325 .64692 L .47345 .65151 L F
.47325 .64692 m .47509 .64365 L .4736 .65079 L F
.47325 .64692 m .4736 .65079 L .47345 .65151 L F
.47323 .6431 m .47517 .64152 L .47352 .6456 L 1 .929 0 r
F
.47362 .64405 m .47331 .64247 L .47331 .64245 L .321 .06 0 r
F
.4736 .64607 m .47517 .64152 L .47511 .64309 L 1 .969 0 r
F
.47347 .64632 m .4736 .64595 L .4736 .64607 L F
.4736 .64595 m .47517 .64152 L .4736 .64607 L F
.47359 .64632 m .47419 .6449 L .4739 .64577 L F
.47345 .64657 m .47359 .64625 L .47359 .64632 L F
.47359 .64625 m .47419 .6449 L .47359 .64632 L F
.47286 .64255 m .47289 .64281 L .47221 .63858 L .678 .272 0 r
F
.47367 .64255 m .47368 .64267 L .4732 .64039 L 1 .542 0 r
F
.47358 .63955 m .47515 .63902 L .47349 .64018 L .075 0 0 r
F
.4731 .63972 m .47433 .63937 L .47358 .63955 L F
.47239 .64022 m .47326 .64656 L .47316 .64709 L .843 .409 0 r
F
.47325 .64692 m .47346 .64648 L .47345 .64657 L 1 .969 0 r
F
.47235 .63966 m .47327 .64648 L .47239 .64022 L .843 .409 0 r
F
.47328 .64668 m .47347 .64632 L .47325 .64692 L 1 .969 0 r
F
.47347 .64632 m .47419 .6449 L .47346 .64648 L F
.47347 .64632 m .47346 .64648 L .47325 .64692 L F
.47352 .6456 m .47517 .64152 L .47347 .64632 L F
.47398 .64591 m .47362 .64407 L .47398 .64588 L .321 .06 0 r
F
.47362 .64407 m .47331 .64247 L .47362 .64406 L F
.47362 .64407 m .47362 .64406 L .47398 .64588 L F
.47334 .65242 m .47337 .65227 L .47325 .65326 L 1 .937 0 r
F
.47337 .65227 m .47382 .64973 L .4733 .65297 L F
.47337 .65227 m .4733 .65297 L .47325 .65326 L F
.47221 .63858 m .47316 .64709 L .47217 .64106 L .843 .409 0 r
F
.47316 .64709 m .47309 .64744 L .47217 .64106 L F
.47355 .65059 m .4735 .651 L .47217 .64106 L F
.47218 .64113 m .47315 .65366 L .47245 .64853 L .956 .505 0 r
F
.47315 .65366 m .47365 .66014 L .47305 .65439 L F
.47315 .65366 m .47305 .65439 L .47245 .64853 L F
.47315 .65366 m .47334 .65242 L .47325 .65326 L 1 .937 0 r
F
.47325 .65326 m .47347 .65235 L .47369 .66001 L F
.47347 .65235 m .47392 .65748 L .47369 .66001 L F
.47386 .65875 m .47412 .65608 L .47382 .65951 L 1 .341 0 r
F
.47412 .65608 m .4741 .65648 L .47382 .65951 L F
.47386 .65875 m .47382 .65951 L .47363 .66162 L F
.47437 .64588 m .47448 .6464 L .47435 .64589 L 1 .542 0 r
F
.47461 .65088 m .47493 .6465 L .4748 .64882 L 1 .341 0 r
F
.47459 .65045 m .47493 .6465 L .47461 .65088 L F
.47413 .65563 m .47429 .65384 L .47412 .65608 L F
.47429 .65384 m .47493 .6465 L .47428 .65411 L F
.47429 .65384 m .47428 .65411 L .47412 .65608 L F
.47435 .64589 m .47448 .64651 L .47418 .64654 L .321 .06 0 r
F
.47387 .65849 m .47414 .6554 L .47385 .65893 L 1 .341 0 r
F
.47414 .6554 m .47493 .6465 L .47413 .65563 L F
.47414 .6554 m .47413 .65563 L .47385 .65893 L F
.47372 .65967 m .47392 .65748 L .47362 .66132 L F
.47443 .64821 m .47414 .64675 L .47414 .64673 L .321 .06 0 r
F
.47416 .65487 m .47493 .6465 L .47414 .6554 L 1 .341 0 r
F
.47458 .65178 m .4748 .64882 L .47471 .65046 L F
.47518 .65205 m .47443 .64824 L .47443 .64821 L .321 .06 0 r
F
.47443 .64824 m .47414 .64675 L .47443 .64821 L F
.47392 .65748 m .47416 .65487 L .47387 .65849 L 1 .341 0 r
F
.47416 .65487 m .47414 .6554 L .47387 .65849 L F
.47392 .65748 m .47387 .65849 L .47362 .66132 L F
.47346 .64648 m .47419 .6449 L .47345 .64657 L 1 .969 0 r
F
.47427 .65114 m .47338 .64592 L .47339 .64585 L .678 .272 0 r
F
.47412 .65608 m .47459 .65045 L .47461 .65088 L 1 .341 0 r
F
.47476 .65407 m .47427 .65117 L .47427 .65114 L .678 .272 0 r
F
.47427 .65117 m .47338 .64592 L .47427 .65114 L F
.47518 .65205 m .47517 .65209 L .47443 .64827 L .321 .06 0 r
F
.47443 .64824 m .47443 .64827 L .47414 .64675 L F
.47518 .65205 m .47443 .64827 L .47443 .64824 L F
.47497 .6442 m .47509 .64365 L .47449 .64828 L 1 .937 0 r
F
.47448 .64651 m .47543 .65103 L .47445 .64752 L .321 .06 0 r
F
.47448 .64651 m .47445 .64752 L .47418 .64654 L F
.47448 .6464 m .47543 .65103 L .47448 .64651 L 1 .542 0 r
F
.47448 .6464 m .47448 .64651 L .47435 .64589 L F
.47385 .65893 m .47413 .65563 L .47412 .65608 L 1 .341 0 r
F
.47443 .6482 m .47398 .64591 L .47398 .64588 L .321 .06 0 r
F
.47518 .65205 m .47443 .64821 L .47443 .6482 L F
.47443 .64821 m .47398 .64591 L .47443 .6482 L F
.47476 .65407 m .47472 .65427 L .47426 .65138 L .678 .272 0 r
F
.47427 .65117 m .47426 .65138 L .47338 .64592 L F
.47476 .65407 m .47426 .65138 L .47427 .65117 L F
.47362 .66132 m .47387 .65849 L .47385 .65893 L 1 .341 0 r
F
.47365 .66014 m .47566 .66959 L .47579 .68775 L .956 .505 0 r
F
.47315 .65366 m .47382 .6579 L .47365 .66014 L F
.47382 .6579 m .47566 .66959 L .47365 .66014 L F
.47217 .64106 m .47345 .65151 L .47315 .65366 L F
.47325 .65295 m .47334 .65242 L .47315 .65366 L 1 .937 0 r
F
.47331 .65216 m .47344 .65156 L .47306 .65403 L F
.47403 .65492 m .47398 .65567 L .47346 .65144 L .843 .409 0 r
F
.4735 .651 m .47346 .65144 L .47217 .64106 L F
.47403 .65492 m .47346 .65144 L .4735 .651 L F
.47344 .65156 m .47345 .65151 L .47334 .65242 L 1 .937 0 r
F
.47345 .65151 m .47382 .64973 L .47337 .65227 L F
.47345 .65151 m .47337 .65227 L .47334 .65242 L F
.47344 .65156 m .47334 .65242 L .47306 .65403 L F
.47327 .64648 m .47367 .64944 L .47326 .64656 L .843 .409 0 r
F
.47367 .64944 m .47473 .65723 L .47367 .64951 L F
.47367 .64944 m .47367 .64951 L .47326 .64656 L F
.47345 .65151 m .47566 .66959 L .47315 .65366 L .956 .505 0 r
F
.47322 .65312 m .47325 .65295 L .47315 .65366 L 1 .937 0 r
F
.47306 .65403 m .47322 .65312 L .47315 .65366 L F
.47211 .64478 m .47318 .66616 L .47202 .65092 L 1 .58 0 r
F
.47511 .67896 m .47507 .67934 L .47211 .64478 L .956 .505 0 r
F
.47226 .6487 m .4732 .64684 L .47316 .64709 L 1 .969 0 r
F
.4732 .64684 m .47321 .64683 L .47316 .64709 L F
.47316 .64709 m .47355 .65059 L .47309 .64744 L .843 .409 0 r
F
.47355 .65059 m .47403 .65492 L .4735 .651 L F
.47327 .64648 m .47326 .64656 L .47239 .64022 L F
.47316 .64709 m .47328 .64668 L .47325 .64692 L 1 .969 0 r
F
.47321 .64683 m .47328 .64668 L .47316 .64709 L F
.4733 .6424 m .47331 .64247 L .47323 .64207 L .321 .06 0 r
F
.47323 .64203 m .47323 .64207 L .47303 .64103 L F
.47303 .64102 m .47303 .64103 L .47222 .63683 L F
.47323 .64203 m .47303 .64103 L .47303 .64102 L F
.47367 .64255 m .4732 .64039 L .47318 .64025 L 1 .542 0 r
F
.47368 .64267 m .47435 .64589 L .47367 .64301 L .321 .06 0 r
F
.47368 .64267 m .47367 .64301 L .47313 .64073 L F
.47437 .64588 m .47368 .64267 L .47367 .64255 L 1 .542 0 r
F
.47365 .64239 m .47398 .64406 L .47367 .64255 L F
.47404 .64244 m .47492 .64031 L .47462 .64197 L 1 .929 0 r
F
.47352 .64286 m .4739 .64216 L .47404 .64244 L F
.4739 .64216 m .47492 .64031 L .47404 .64244 L F
.47365 .64239 m .47367 .64255 L .4734 .6413 L 1 .542 0 r
F
.47347 .64225 m .47376 .64187 L .47352 .64286 L 1 .929 0 r
F
.47376 .64187 m .47492 .64031 L .4739 .64216 L F
.47376 .64187 m .4739 .64216 L .47352 .64286 L F
.47313 .64073 m .47334 .64042 L .47321 .6407 L 1 .955 0 r
F
.47318 .64025 m .4732 .64039 L .47305 .63971 L 1 .542 0 r
F
.47335 .64218 m .47331 .64245 L .4733 .64238 L .321 .06 0 r
F
.47321 .64153 m .4733 .64238 L .47222 .63683 L F
.47335 .64218 m .4733 .64238 L .47321 .64153 L F
.47313 .64073 m .47315 .64089 L .47314 .6409 L 1 .955 0 r
F
.47315 .64316 m .47271 .64163 L .47279 .64148 L .678 .272 0 r
F
.47222 .63683 m .47331 .64247 L .47315 .64316 L F
.4732 .64072 m .47331 .64247 L .47314 .6409 L 1 .955 0 r
F
.47264 .63803 m .47365 .64362 L .47284 .63978 L .321 .06 0 r
F
.47328 .64668 m .47352 .6456 L .47347 .64632 L 1 .969 0 r
F
.47321 .64683 m .47333 .64634 L .47328 .64668 L F
.47333 .64634 m .47352 .6456 L .47328 .64668 L F
.4732 .64312 m .47321 .64322 L .47317 .6434 L 1 .929 0 r
F
.47335 .6455 m .47289 .64281 L .47286 .64255 L .678 .272 0 r
F
.47335 .64552 m .47289 .64281 L .47335 .6455 L F
.47323 .6431 m .47352 .6456 L .47338 .64592 L 1 .929 0 r
F
.47339 .64585 m .47336 .64568 L .4734 .64581 L .678 .272 0 r
F
.47336 .64568 m .47289 .64281 L .47335 .64552 L F
.47336 .64568 m .47335 .64552 L .4734 .64581 L F
.47349 .64807 m .47472 .65427 L .47453 .65577 L .843 .409 0 r
F
.47322 .64678 m .47352 .6456 L .47321 .64683 L 1 .969 0 r
F
.47221 .63858 m .47338 .64592 L .47327 .64648 L .843 .409 0 r
F
.47336 .64599 m .47338 .64592 L .4732 .64684 L 1 .969 0 r
F
.47338 .64592 m .47352 .6456 L .47322 .64678 L F
.47338 .64592 m .47322 .64678 L .4732 .64684 L F
.47327 .64648 m .47338 .64592 L .47349 .64807 L .843 .409 0 r
F
.47338 .64592 m .47472 .65427 L .47349 .64807 L F
.47339 .64585 m .47338 .64592 L .47289 .64281 L .678 .272 0 r
F
.47245 .64853 m .47245 .64866 L .47211 .64478 L .956 .505 0 r
F
.47218 .64113 m .47245 .64853 L .47211 .64478 L F
.47317 .6434 m .47338 .64592 L .47226 .6487 L 1 .929 0 r
F
.47323 .6431 m .47338 .64592 L .47317 .6434 L F
.47317 .64332 m .47317 .6434 L .47226 .6487 L F
.4732 .64312 m .47317 .6434 L .47317 .64332 L F
.4734 .64581 m .47335 .64552 L .47335 .6455 L .678 .272 0 r
F
.47476 .65407 m .47339 .64585 L .4734 .64581 L F
.47313 .64073 m .47314 .6409 L .47225 .64389 L 1 .955 0 r
F
.4722 .63563 m .47291 .63903 L .47313 .64073 L .321 .06 0 r
F
.47339 .64109 m .4734 .6413 L .47318 .64025 L 1 .542 0 r
F
.47313 .63992 m .47318 .64025 L .4722 .63563 L F
.47319 .63999 m .4732 .64039 L .47315 .64004 L .075 0 0 r
F
.47325 .64035 m .47349 .64018 L .4732 .64062 L 1 .955 0 r
F
.4732 .64051 m .4732 .64062 L .47313 .64073 L F
.47325 .64035 m .4732 .64062 L .4732 .64051 L F
.47319 .64021 m .47318 .64025 L .47313 .63992 L 1 .542 0 r
F
.47339 .64109 m .4732 .64032 L .47319 .64021 L F
.4732 .64032 m .47318 .64025 L .47319 .64021 L F
.47319 .63999 m .47325 .64035 L .4732 .64039 L .075 0 0 r
F
.47315 .64004 m .4732 .64039 L .47223 .64107 L F
.47326 .63991 m .47326 .64023 L .47319 .63999 L F
.47326 .64023 m .47325 .64035 L .47319 .63999 L F
.47306 .63971 m .47305 .63971 L .4722 .63563 L 1 .542 0 r
F
.47265 .63749 m .47281 .63845 L .4722 .63563 L F
.4725 .63692 m .47291 .63906 L .47265 .63749 L F
.47223 .64107 m .47325 .64035 L .47313 .64073 L 1 .955 0 r
F
.47306 .63973 m .4731 .63972 L .47307 .63977 L .075 0 0 r
F
.47306 .63973 m .47307 .63977 L .47223 .64107 L F
.47218 .64003 m .47306 .63973 L .47223 .64107 L F
.47218 .64003 m .47304 .63977 L .4731 .63972 L F
.47318 .64025 m .47305 .63971 L .47306 .63971 L 1 .542 0 r
F
.47321 .6407 m .47515 .63902 L .47519 .63995 L 1 .955 0 r
F
.47349 .64018 m .47515 .63902 L .47321 .6407 L F
.47265 .63749 m .47339 .64109 L .47281 .63845 L 1 .542 0 r
F
.47265 .63749 m .47311 .64 L .47319 .64016 L F
.4731 .63972 m .47317 .63969 L .47311 .63978 L .075 0 0 r
F
.4731 .63972 m .47311 .63978 L .47223 .64107 L F
.47304 .63977 m .47317 .63973 L .4731 .63972 L F
.47291 .63903 m .4732 .64039 L .47313 .64073 L .321 .06 0 r
F
.47291 .63906 m .47304 .63977 L .47298 .6393 L 1 .542 0 r
F
.47317 .63969 m .47318 .64 L .47223 .64107 L .075 0 0 r
F
.4732 .64039 m .47368 .64267 L .47323 .64109 L .321 .06 0 r
F
.47304 .63977 m .47383 .64393 L .47306 .63975 L 1 .542 0 r
F
.47304 .63977 m .47306 .63975 L .47298 .6393 L F
.47291 .63906 m .47298 .6393 L .47265 .63749 L F
.47311 .64 m .47326 .64083 L .47319 .64016 L F
.47326 .64083 m .47383 .64393 L .47333 .64098 L F
.47326 .64083 m .47333 .64098 L .47319 .64016 L F
.47339 .64109 m .47383 .64393 L .474 .64407 L F
.47319 .64016 m .47333 .64098 L .47339 .64109 L F
.47333 .64098 m .47383 .64393 L .47339 .64109 L F
.47365 .64239 m .47437 .64588 L .47398 .64406 L F
.47334 .64042 m .47349 .64018 L .47335 .64044 L 1 .955 0 r
F
.47334 .64042 m .47335 .64044 L .47321 .6407 L F
.47331 .64245 m .47323 .64207 L .47323 .64203 L .321 .06 0 r
F
.47314 .6409 m .47331 .64247 L .47225 .64389 L 1 .955 0 r
F
.47331 .64245 m .47331 .64247 L .4733 .6424 L .321 .06 0 r
F
.47358 .63955 m .47349 .64018 L .47325 .64035 L .075 0 0 r
F
.47358 .63955 m .47325 .64035 L .47326 .63991 L F
.47317 .63973 m .47433 .63937 L .4731 .63972 L F
.47317 .63969 m .47358 .63955 L .47318 .64 L F
.47313 .64073 m .4732 .6407 L .47315 .64089 L 1 .955 0 r
F
.4732 .64039 m .47323 .64109 L .47313 .64073 L .321 .06 0 r
F
.47365 .64362 m .47435 .64589 L .47418 .64654 L F
.4732 .6407 m .47331 .64247 L .4732 .64072 L 1 .955 0 r
F
.47313 .64073 m .47367 .64301 L .47365 .64362 L .321 .06 0 r
F
.47367 .64301 m .47435 .64589 L .47365 .64362 L F
.47398 .64588 m .47362 .64406 L .47362 .64405 L F
.47362 .64406 m .47331 .64247 L .47362 .64405 L F
.47437 .64588 m .47435 .64589 L .47368 .64267 L 1 .542 0 r
F
.47216 .63513 m .47265 .63749 L .4722 .63563 L F
.47216 .63513 m .4725 .63692 L .47265 .63749 L F
.4739 .64577 m .47393 .64569 L .47393 .64571 L 1 .969 0 r
F
.47365 .66014 m .47358 .66113 L .47245 .64853 L .956 .505 0 r
F
.47463 .67282 m .47463 .67292 L .47245 .64853 L F
.47316 .64709 m .47323 .64824 L .47224 .6573 L 1 .969 0 r
F
.47323 .64824 m .47345 .65151 L .47339 .65181 L F
.47323 .64824 m .47339 .65181 L .47224 .6573 L F
.47267 .65105 m .47267 .65117 L .47245 .64866 L .956 .505 0 r
F
.47226 .6487 m .47316 .64709 L .47224 .6573 L 1 .969 0 r
F
.47346 .65144 m .47345 .65151 L .47343 .65125 L .843 .409 0 r
F
.47316 .64709 m .47367 .64951 L .47355 .65059 L F
.47326 .64656 m .47367 .64951 L .47316 .64709 L F
.4732 .64684 m .47322 .64678 L .47321 .64683 L 1 .969 0 r
F
.47226 .6487 m .47336 .64599 L .4732 .64684 L F
.4738 .65425 m .47345 .65151 L .47346 .65144 L .843 .409 0 r
F
.47355 .65059 m .47473 .65723 L .4746 .66005 L F
.47367 .64951 m .47473 .65723 L .47355 .65059 L F
.47312 .64295 m .47315 .64316 L .47312 .64299 L .678 .272 0 r
F
.47358 .63955 m .47505 .63915 L .47515 .63902 L .075 0 0 r
F
.47433 .63937 m .47505 .63915 L .47358 .63955 L F
.47244 .63983 m .47241 .63984 L .47233 .63932 L .678 .272 0 r
F
.47225 .64389 m .47315 .64316 L .47226 .6487 L 1 .929 0 r
F
.47315 .64316 m .4732 .64312 L .47317 .64332 L F
.47315 .64316 m .47317 .64332 L .47226 .6487 L F
.47315 .64316 m .47476 .65407 L .47335 .6455 L .678 .272 0 r
F
.47221 .63796 m .47233 .63932 L .47221 .63858 L F
.47222 .63683 m .47233 .63932 L .47221 .63796 L F
.47221 .63858 m .47235 .63966 L .47239 .64022 L .843 .409 0 r
F
.47224 .6573 m .47315 .65366 L .47223 .67595 L 1 .937 0 r
F
.47315 .65366 m .47355 .66158 L .47223 .67595 L F
.47358 .66117 m .47347 .65992 L .47347 .6599 L .956 .505 0 r
F
.47425 .6687 m .47358 .66119 L .47358 .66117 L F
.47246 .67345 m .47303 .66724 L .47246 .6736 L 1 .341 0 r
F
.47223 .67595 m .47318 .66616 L .47372 .68196 L F
.47223 .67595 m .47376 .68212 L .47223 .6762 L F
.47308 .66726 m .47329 .66475 L .47318 .66616 L F
.47224 .6573 m .47331 .65216 L .47306 .65403 L 1 .937 0 r
F
.47225 .6542 m .47272 .66717 L .47231 .6582 L 1 .249 0 r
F
.47245 .6737 m .47306 .66725 L .47308 .66726 L 1 .341 0 r
F
.47246 .6736 m .47306 .66725 L .47245 .6737 L F
.47277 .67032 m .47303 .66724 L .47306 .66725 L F
.47276 .67021 m .47303 .66724 L .47277 .67032 L F
.47272 .66717 m .47373 .69456 L .47269 .66796 L 1 .249 0 r
F
.47272 .66717 m .47269 .66796 L .47231 .6582 L F
.47223 .67595 m .47246 .6736 L .47245 .6737 L 1 .341 0 r
F
.47306 .66725 m .47329 .66475 L .47308 .66726 L F
.4725 .66118 m .47271 .66716 L .4725 .66106 L 1 .249 0 r
F
.47271 .66716 m .47311 .67854 L .47271 .66716 L F
.47271 .66716 m .47271 .66716 L .4725 .66106 L F
.47246 .6736 m .47276 .67021 L .47277 .67032 L 1 .341 0 r
F
.47231 .6582 m .47319 .68186 L .47239 .67212 L .717 .135 0 r
F
.47268 .66831 m .47316 .68121 L .47319 .68186 L F
.47231 .6582 m .47268 .66821 L .47268 .66831 L F
.47268 .66821 m .47316 .68121 L .47268 .66831 L F
.47239 .67227 m .47315 .69158 L .47317 .69259 L 0 0 0 r
F
.47239 .67212 m .47239 .67226 L .47239 .67227 L F
.47239 .67226 m .47315 .69158 L .47239 .67227 L F
.47236 .67457 m .47246 .67345 L .47246 .6736 L 1 .341 0 r
F
.47223 .67595 m .47236 .67451 L .47236 .67457 L F
.47236 .67451 m .47246 .67345 L .47236 .67457 L F
.47319 .68186 m .47367 .6949 L .47366 .69467 L .717 .135 0 r
F
.47374 .69566 m .47373 .69647 L .47268 .66821 L 1 .249 0 r
F
.47269 .66807 m .47268 .66821 L .47231 .6582 L F
.47374 .69566 m .47268 .66821 L .47269 .66807 L F
.47272 .66717 m .47311 .67854 L .47314 .67859 L F
.4725 .66106 m .47271 .66716 L .47272 .66717 L F
.47271 .66716 m .47311 .67854 L .47272 .66717 L F
.47306 .66725 m .47348 .66237 L .47329 .66475 L 1 .341 0 r
F
.47303 .66724 m .47348 .66237 L .47306 .66725 L F
.47225 .6542 m .4725 .66118 L .4725 .66106 L 1 .249 0 r
F
.47414 .64673 m .47414 .64675 L .47331 .64247 L .321 .06 0 r
F
.47365 .64362 m .47362 .64405 L .47331 .64245 L F
.47365 .64362 m .47331 .64245 L .47335 .64218 L F
.4732 .64312 m .47323 .6431 L .47321 .64322 L 1 .929 0 r
F
.47315 .64316 m .47331 .64247 L .4735 .64552 L .678 .272 0 r
F
.47225 .64389 m .47331 .64247 L .47315 .64316 L 1 .929 0 r
F
.4735 .64552 m .47414 .64675 L .47389 .64817 L .678 .272 0 r
F
.47331 .64247 m .47414 .64675 L .4735 .64552 L F
.47223 .64107 m .47313 .64073 L .47225 .64389 L 1 .955 0 r
F
.47492 .64031 m .47519 .63995 L .47462 .64197 L 1 .929 0 r
F
.47365 .64362 m .47444 .64797 L .47362 .64405 L .321 .06 0 r
F
.47444 .64797 m .47518 .65205 L .47443 .6482 L F
.47444 .64797 m .47443 .6482 L .47362 .64405 L F
.47429 .65086 m .47502 .65134 L .47476 .65407 L .678 .272 0 r
F
.47389 .64817 m .47436 .64949 L .47429 .65086 L F
.47436 .64949 m .47502 .65134 L .47429 .65086 L F
.47444 .64797 m .47543 .65103 L .47521 .65219 L .321 .06 0 r
F
.47418 .64654 m .47445 .64752 L .47444 .64797 L F
.47445 .64752 m .47543 .65103 L .47444 .64797 L F
.47414 .64675 m .47502 .65134 L .47389 .64817 L .678 .272 0 r
F
.47502 .65134 m .47517 .65209 L .47492 .65331 L F
.47502 .65134 m .47492 .65331 L .47476 .65407 L F
.47472 .67388 m .47425 .66871 L .47425 .6687 L .956 .505 0 r
F
.47442 .65848 m .4746 .66005 L .47442 .6588 L .843 .409 0 r
F
.47442 .65848 m .47442 .6588 L .47398 .65567 L F
.47403 .65492 m .47442 .65848 L .47398 .65567 L F
.4746 .66005 m .47529 .66628 L .47458 .66051 L F
.4746 .66005 m .47458 .66051 L .47398 .65567 L F
.4746 .66005 m .47562 .66386 L .47529 .66628 L F
.47473 .65723 m .47562 .66386 L .4746 .66005 L F
.47457 .66061 m .47424 .65798 L .47458 .66058 L F
.47457 .66061 m .47458 .66058 L .47491 .66318 L F
.47472 .67388 m .47425 .66872 L .47425 .66871 L .956 .505 0 r
F
.47458 .66051 m .47424 .65798 L .47426 .65789 L .843 .409 0 r
F
.47491 .66318 m .47458 .66058 L .47458 .66051 L F
.47458 .66058 m .47424 .65798 L .47458 .66051 L F
.47472 .67388 m .47469 .67417 L .47424 .66903 L .956 .505 0 r
F
.47472 .67388 m .47424 .66903 L .47425 .66872 L F
.47364 .67516 m .47384 .67928 L .47376 .68212 L 1 .58 0 r
F
.47384 .67928 m .47386 .67952 L .47376 .68212 L F
.47386 .67952 m .47614 .72491 L .47376 .68212 L F
.47363 .67863 m .47376 .68212 L .47363 .67984 L F
.47364 .67516 m .47376 .68212 L .47363 .67863 L F
.47318 .66616 m .47366 .6795 L .47372 .68196 L 1 .341 0 r
F
.47372 .68196 m .47366 .6795 L .47376 .68212 L F
.47318 .66616 m .47364 .67516 L .47336 .67095 L 1 .58 0 r
F
.47318 .66616 m .47366 .6629 L .47364 .67516 L F
.47529 .66628 m .47491 .66323 L .47491 .66318 L .843 .409 0 r
F
.47255 .71029 m .47902 .86246 L .4729 .80485 L 0 0 0 r
F
.47458 .75721 m .47706 .8116 L .47464 .75948 L F
.47516 .74301 m .47679 .78464 L .47508 .74148 L F
.47679 .78464 m .47702 .79053 L .47681 .7852 L F
.47679 .78464 m .47681 .7852 L .47508 .74148 L F
.47447 .71638 m .47544 .74256 L .47437 .72274 L .717 .135 0 r
F
.47566 .74846 m .47605 .75909 L .47565 .74821 L F
.47605 .75909 m .47644 .76955 L .47639 .77258 L 1 .667 0 r
F
.47605 .75909 m .47617 .7621 L .47606 .75923 L .717 .135 0 r
F
.47618 .7624 m .47662 .77417 L .47623 .76367 L F
.4768 .77916 m .47673 .77708 L .47699 .78426 L F
.47623 .76367 m .47662 .77417 L .4768 .77916 L F
.47665 .78054 m .47668 .77585 L .4768 .77916 L 1 .667 0 r
F
.47662 .77417 m .47673 .77708 L .4768 .77916 L .717 .135 0 r
F
.47643 .77441 m .47649 .7708 L .47665 .78054 L 1 .667 0 r
F
.47649 .7708 m .47692 .74398 L .47668 .77585 L F
.47649 .7708 m .47668 .77585 L .47665 .78054 L F
.47638 .77291 m .47639 .77258 L .47643 .77441 L F
.47639 .77258 m .47692 .74398 L .47643 .77441 L F
.476 .75737 m .47566 .74846 L .47567 .74858 L 1 .249 0 r
F
.476 .75744 m .47566 .74846 L .476 .75737 L F
.47604 .75861 m .47566 .74846 L .47603 .75828 L F
.47544 .74256 m .47609 .7601 L .47623 .76367 L .717 .135 0 r
F
.47561 .74712 m .47609 .7601 L .47544 .74256 L F
.47602 .75808 m .47605 .75909 L .47566 .74846 L 1 .249 0 r
F
.47576 .74969 m .4774 .73562 L .47605 .75909 L .649 .164 0 r
F
.47604 .75861 m .47605 .75909 L .47602 .75808 L 1 .249 0 r
F
.47605 .75909 m .47606 .75923 L .47565 .74817 L .717 .135 0 r
F
.47565 .74821 m .47565 .74817 L .47458 .71935 L F
.47605 .75909 m .47565 .74817 L .47565 .74821 L F
.474 .74389 m .47757 .82266 L .47398 .74399 L 0 0 0 r
F
.47757 .82266 m .4776 .82349 L .47398 .74399 L F
.47902 .86246 m .47926 .81871 L .47986 .85829 L 1 .741 0 r
F
.47401 .74405 m .47809 .83413 L .474 .74389 L 0 0 0 r
F
.47809 .83413 m .47809 .83414 L .474 .74389 L F
.47758 .80547 m .47767 .8076 L .47789 .81557 L F
.47838 .82953 m .47859 .82697 L .47876 .84143 L 1 .741 0 r
F
.47806 .83339 m .47838 .82953 L .47902 .86246 L F
.47814 .83531 m .47815 .83547 L .47811 .83461 L 0 0 0 r
F
.4781 .83448 m .47811 .83461 L .474 .74389 L F
.47814 .83531 m .47811 .83461 L .4781 .83448 L F
.47838 .82953 m .47876 .84143 L .47902 .86246 L 1 .741 0 r
F
.47859 .82697 m .47913 .84163 L .47908 .85126 L F
.47876 .84143 m .47908 .85126 L .47902 .86246 L F
.47859 .82697 m .47908 .85126 L .47876 .84143 L F
.4785 .82462 m .47859 .82697 L .47806 .83339 L 1 .684 0 r
F
.47827 .82639 m .47879 .83789 L .47896 .8446 L 0 0 0 r
F
.47765 .81027 m .47803 .81946 L .47827 .82639 L F
.47827 .82639 m .4785 .82462 L .47833 .82807 L 1 .684 0 r
F
.47803 .81946 m .47879 .83789 L .47827 .82639 L 0 0 0 r
F
.47827 .82639 m .47833 .82807 L .47806 .83339 L 1 .684 0 r
F
.47902 .86246 m .47976 .85877 L .47808 .8703 L 1 .741 0 r
F
.47976 .85877 m .47977 .85892 L .47869 .86626 L F
.47976 .85877 m .47869 .86626 L .47869 .86619 L F
.47976 .85877 m .47803 .87074 L .47803 .87068 L F
.48079 .88538 m .48077 .88566 L .48058 .90279 L 1 .816 0 r
F
.48124 .90432 m .48117 .89391 L .48098 .90853 L 1 .747 0 r
F
.48117 .89391 m .48104 .8951 L .48098 .90853 L F
.48109 .88354 m .48096 .88597 L .48098 .90853 L F
.47239 .67212 m .48124 .90432 L .47255 .71029 L 0 0 0 r
F
.47791 .82919 m .47827 .82639 L .47806 .83339 L 1 .684 0 r
F
.4785 .82462 m .47926 .81871 L .47859 .82697 L F
.48117 .89391 m .48109 .88354 L .48104 .8951 L 1 .747 0 r
F
.4783 .81955 m .48127 .89943 L .47824 .82189 L .717 .135 0 r
F
.47719 .78959 m .47905 .83969 L .47906 .84001 L F
.47699 .78426 m .47711 .78752 L .47719 .78959 L F
.47711 .78752 m .47905 .83969 L .47719 .78959 L F
.47864 .83236 m .47879 .83789 L .47813 .82177 L 0 0 0 r
F
.47801 .81833 m .47813 .82177 L .47765 .81027 L F
.47864 .83236 m .47813 .82177 L .47801 .81833 L F
.47757 .82266 m .47906 .8556 L .4776 .82349 L F
.47902 .86246 m .47803 .87074 L .4729 .80485 L F
.47705 .81608 m .47874 .84942 L .47903 .86282 L F
.4749 .83311 m .47633 .85083 L .47625 .85224 L .185 .03 0 r
F
.47351 .87448 m .47437 .87914 L .47434 .87983 L .462 .125 0 r
F
.47301 .87128 m .47351 .87399 L .47351 .87448 L F
.47706 .8116 m .47906 .8556 L .47705 .81608 L 0 0 0 r
F
.47404 .74366 m .47411 .7452 L .474 .74386 L F
.47411 .7452 m .47906 .8556 L .47401 .74405 L F
.47411 .7452 m .47401 .74405 L .474 .74386 L F
.47605 .75909 m .47639 .77258 L .47638 .77291 L 1 .667 0 r
F
.47681 .78524 m .47684 .78628 L .47507 .74134 L 0 0 0 r
F
.47681 .7852 m .47507 .74134 L .47508 .74148 L F
.47702 .79053 m .47681 .78524 L .47681 .7852 L F
.47681 .78524 m .47507 .74134 L .47681 .7852 L F
.47713 .79348 m .47737 .80015 L .47505 .74098 L F
.47757 .80476 m .47505 .74098 L .47507 .74134 L F
.47702 .79053 m .47711 .79306 L .47684 .78628 L F
.47702 .79053 m .47684 .78628 L .47681 .78524 L F
.47492 .83147 m .47512 .83404 L .4749 .83311 L .185 .03 0 r
F
.47615 .7949 m .47706 .8116 L .47705 .81608 L 0 0 0 r
F
.47617 .79249 m .47706 .8116 L .47615 .7949 L F
.47493 .73892 m .47758 .80547 L .47765 .81027 L F
.47391 .71202 m .47505 .74098 L .47493 .73892 L F
.47505 .74098 m .47758 .80547 L .47493 .73892 L F
.47568 .74873 m .47526 .73772 L .47523 .73661 L 1 .249 0 r
F
.47668 .77585 m .47671 .77204 L .4768 .77916 L 1 .667 0 r
F
.47609 .7601 m .47617 .76222 L .47623 .76367 L .717 .135 0 r
F
.47605 .75909 m .47692 .74398 L .47644 .76955 L 1 .667 0 r
F
.47602 .75788 m .47567 .74858 L .47568 .74873 L 1 .249 0 r
F
.47671 .77204 m .47682 .77452 L .4768 .77916 L 1 .667 0 r
F
.47692 .74398 m .4774 .73562 L .4768 .77916 L F
.47778 .80461 m .47603 .75828 L .47602 .75788 L 1 .249 0 r
F
.47603 .75828 m .47567 .74858 L .47602 .75788 L F
.47567 .74858 m .47526 .73772 L .47568 .74873 L F
.47576 .74969 m .47743 .73942 L .47685 .74035 L .649 .164 0 r
F
.47458 .71773 m .47576 .74969 L .47454 .71824 L 1 .249 0 r
F
.47576 .74969 m .47778 .80461 L .47568 .74873 L F
.47576 .74969 m .47568 .74873 L .47454 .71824 L F
.47573 .75035 m .47605 .75909 L .47305 .81175 L .649 .164 0 r
F
.4757 .7528 m .47579 .75206 L .47566 .75205 L F
.47565 .74817 m .47607 .7594 L .47562 .74727 L .717 .135 0 r
F
.47576 .74969 m .47605 .75909 L .47573 .75035 L .649 .164 0 r
F
.47607 .7594 m .47617 .7621 L .47609 .7601 L .717 .135 0 r
F
.4768 .77916 m .47702 .79053 L .47669 .78186 L 1 .667 0 r
F
.47617 .7621 m .47699 .7844 L .47673 .77708 L .717 .135 0 r
F
.47609 .7601 m .47617 .7621 L .47617 .76222 L F
.47603 .75828 m .476 .75744 L .476 .75737 L 1 .249 0 r
F
.47778 .80461 m .47604 .75861 L .47603 .75828 L F
.47617 .76219 m .47673 .77708 L .47662 .77417 L .717 .135 0 r
F
.47617 .76219 m .47662 .77417 L .47618 .7624 L F
.47699 .7844 m .47905 .83969 L .47729 .79218 L F
.47699 .7844 m .47729 .79218 L .47673 .77708 L F
.47665 .78054 m .4768 .77916 L .47669 .78186 L 1 .667 0 r
F
.47617 .7621 m .47673 .77708 L .47617 .76219 L .717 .135 0 r
F
.47673 .77708 m .47905 .83969 L .47699 .78426 L F
.47778 .80461 m .4778 .80607 L .47605 .75909 L 1 .249 0 r
F
.47778 .80461 m .47605 .75909 L .47604 .75861 L F
.47579 .75142 m .47762 .80513 L .47595 .75501 L F
.47579 .75206 m .47581 .75196 L .47578 .75187 L .649 .164 0 r
F
.47581 .75196 m .4758 .75184 L .47578 .75187 L F
.47607 .7594 m .47609 .7601 L .47561 .74712 L .717 .135 0 r
F
.47607 .7594 m .47561 .74712 L .47562 .74727 L F
.47398 .74399 m .47458 .75721 L .47464 .75948 L 0 0 0 r
F
.4728 .77515 m .47572 .75004 L .47305 .81175 L .649 .164 0 r
F
.47572 .75004 m .47573 .75035 L .47305 .81175 L F
.47589 .75133 m .47578 .74993 L .47576 .75001 L F
.47579 .75123 m .47576 .75001 L .4756 .75105 L F
.47589 .75133 m .47576 .75001 L .47579 .75123 L F
.47578 .75187 m .47578 .75167 L .47566 .75205 L F
.47579 .75206 m .47578 .75187 L .47566 .75205 L F
.47566 .75205 m .4758 .75161 L .4756 .75105 L F
.4758 .75161 m .47589 .75133 L .47579 .75123 L F
.4758 .75161 m .47579 .75123 L .4756 .75105 L F
.47572 .75004 m .47576 .74969 L .47573 .75025 L F
.47573 .75025 m .47574 .75019 L .47573 .75035 L F
.4756 .75105 m .47578 .74993 L .47576 .74969 L F
.47596 .7607 m .47605 .75909 L .47608 .76399 L 1 .667 0 r
F
.47605 .75909 m .47638 .77291 L .47608 .76399 L F
.47592 .75748 m .47762 .80513 L .47591 .75672 L 1 .249 0 r
F
.47591 .75672 m .47762 .80513 L .47586 .75448 L F
.47592 .75697 m .47576 .75397 L .4754 .75511 L .649 .164 0 r
F
.47595 .75735 m .47592 .75697 L .4754 .75511 L F
.47536 .74162 m .47592 .75748 L .47543 .74336 L 1 .249 0 r
F
.4757 .7528 m .47582 .75292 L .47579 .75206 L .649 .164 0 r
F
.47592 .75748 m .47591 .75672 L .47543 .74336 L 1 .249 0 r
F
.47585 .75368 m .47582 .75292 L .4757 .7528 L .649 .164 0 r
F
.47542 .74296 m .47591 .75672 L .4756 .74706 L 1 .249 0 r
F
.47598 .75716 m .47585 .75368 L .47576 .75397 L .649 .164 0 r
F
.47598 .75716 m .47576 .75397 L .47592 .75697 L F
.47591 .75672 m .47586 .75448 L .4756 .74706 L 1 .249 0 r
F
.47566 .74846 m .47565 .74821 L .47458 .71935 L .717 .135 0 r
F
.47567 .74858 m .47566 .74846 L .47526 .73772 L 1 .249 0 r
F
.47458 .71773 m .4756 .74706 L .47579 .75142 L F
.47576 .74969 m .47579 .75142 L .47595 .75501 L F
.47458 .71773 m .47579 .75142 L .47576 .74969 L F
.47582 .75181 m .47589 .75133 L .4758 .75161 L .649 .164 0 r
F
.4758 .75174 m .4758 .75161 L .47578 .75167 L F
.47582 .75181 m .4758 .75161 L .4758 .75174 L F
.47582 .75181 m .47578 .75167 L .47578 .75187 L F
.47562 .74727 m .47561 .74712 L .47447 .71638 L .717 .135 0 r
F
.4756 .74706 m .47586 .75448 L .47579 .75142 L 1 .249 0 r
F
.47586 .75448 m .47762 .80513 L .47579 .75142 L F
.47581 .75196 m .47582 .75181 L .4758 .75184 L .649 .164 0 r
F
.47452 .71782 m .47565 .74817 L .47447 .71638 L .717 .135 0 r
F
.47565 .74817 m .47562 .74727 L .47447 .71638 L F
.47589 .75133 m .47743 .73942 L .47578 .74993 L .649 .164 0 r
F
.47578 .74993 m .47743 .73942 L .47576 .74969 L F
.4728 .77515 m .4757 .7528 L .4756 .75105 L F
.47669 .78186 m .47702 .79053 L .47332 .86462 L 1 .667 0 r
F
.47757 .80476 m .47758 .80547 L .47737 .80015 L 0 0 0 r
F
.47757 .80476 m .47737 .80015 L .47713 .79348 L F
.47507 .74134 m .47505 .74098 L .47391 .71202 L F
.47555 .76797 m .47596 .7607 L .47616 .7847 L 1 .667 0 r
F
.47596 .7607 m .47608 .76399 L .47616 .7847 L F
.47608 .76399 m .47638 .77291 L .47616 .7847 L F
.47508 .74148 m .47507 .74134 L .47391 .71202 L 0 0 0 r
F
.47553 .75967 m .47595 .75735 L .4754 .75511 L .649 .164 0 r
F
.47595 .75735 m .47598 .75716 L .47592 .75697 L F
.47525 .76126 m .4754 .76042 L .47527 .76081 L F
.47525 .76126 m .47527 .76081 L .47425 .76392 L F
.47429 .76672 m .47525 .76126 L .47425 .76392 L F
.4754 .76042 m .47553 .75967 L .47538 .76018 L F
.4754 .76042 m .47538 .76018 L .47425 .76392 L F
.47332 .86462 m .47791 .82919 L .4734 .89034 L 1 .684 0 r
F
.47791 .82919 m .47806 .83339 L .4734 .89034 L F
.47767 .8076 m .47864 .83236 L .47801 .81833 L 0 0 0 r
F
.47767 .8076 m .47801 .81833 L .47789 .81557 L F
.47859 .82697 m .47926 .81871 L .47913 .84163 L 1 .741 0 r
F
.4734 .89034 m .47806 .83339 L .47902 .86246 L F
.47809 .83413 m .47814 .83531 L .47809 .83414 L 0 0 0 r
F
.47814 .83531 m .47906 .8556 L .47815 .83547 L F
.47762 .8077 m .47789 .81557 L .47765 .81027 L F
.47791 .82919 m .47702 .79053 L .47827 .82639 L 1 .684 0 r
F
.47512 .83404 m .47515 .83619 L .4749 .83311 L .185 .03 0 r
F
.47332 .86462 m .47669 .79707 L .47791 .82919 L 1 .684 0 r
F
.47669 .79707 m .47702 .79053 L .47791 .82919 L F
.47671 .77204 m .47692 .74398 L .47682 .77452 L 1 .667 0 r
F
.48006 .86683 m .48111 .89533 L .48037 .87522 L .717 .135 0 r
F
.48111 .89533 m .48111 .8954 L .48037 .87522 L F
.48 .86531 m .48004 .8664 L .48006 .86683 L F
.48004 .8664 m .48111 .8954 L .48006 .86683 L F
.47998 .86478 m .48111 .8954 L .48004 .8664 L F
.47999 .86505 m .48004 .8664 L .48002 .86578 L F
.47998 .86478 m .48004 .8664 L .47999 .86505 L F
.4785 .82462 m .47818 .76727 L .47926 .81871 L 1 .684 0 r
F
.47826 .81811 m .47818 .76727 L .4785 .82462 L F
.47905 .83969 m .47998 .86478 L .47906 .84001 L .717 .135 0 r
F
.47998 .86478 m .48002 .86578 L .47906 .84001 L F
.47906 .84001 m .48 .86531 L .48037 .87522 L F
.47778 .80461 m .48111 .8954 L .4778 .80607 L 1 .249 0 r
F
.47595 .75501 m .47762 .80513 L .47807 .81263 L F
.47598 .75716 m .47752 .74845 L .47585 .75368 L .649 .164 0 r
F
.47576 .75397 m .47585 .75368 L .4757 .7528 L F
.47585 .75368 m .47603 .75312 L .47582 .75292 L F
.47447 .71638 m .47561 .74712 L .47544 .74256 L .717 .135 0 r
F
.47579 .75206 m .47603 .75312 L .47589 .75133 L .649 .164 0 r
F
.47582 .75292 m .47603 .75312 L .47579 .75206 L F
.47454 .71824 m .47566 .74846 L .47458 .71935 L .717 .135 0 r
F
.47523 .73661 m .47526 .73772 L .47454 .71824 L 1 .249 0 r
F
.47544 .74256 m .47524 .74289 L .47437 .72274 L .717 .135 0 r
F
.47463 .72056 m .47542 .74296 L .47481 .72426 L 1 .249 0 r
F
.47542 .74296 m .4756 .74706 L .47481 .72426 L F
.47616 .7847 m .47638 .77291 L .47665 .78054 L 1 .667 0 r
F
.47305 .81175 m .47555 .76797 L .47616 .7847 L F
.474 .74386 m .47401 .74405 L .474 .74389 L 0 0 0 r
F
.47513 .75718 m .47553 .75967 L .4754 .75511 L .649 .164 0 r
F
.47425 .76392 m .47538 .76018 L .47513 .75718 L F
.47538 .76018 m .47553 .75967 L .47513 .75718 L F
.4728 .77515 m .47429 .76672 L .47425 .76392 L F
.47377 .70751 m .47447 .72526 L .47391 .71202 L 0 0 0 r
F
.47447 .72526 m .47516 .74301 L .47442 .72478 L F
.47447 .72526 m .47442 .72478 L .47391 .71202 L F
.47491 .66323 m .4749 .66337 L .47457 .66067 L .843 .409 0 r
F
.47457 .66061 m .47457 .66067 L .47424 .65798 L F
.47491 .66323 m .47457 .66067 L .47457 .66061 L F
.47365 .66014 m .47427 .66817 L .47358 .66113 L .956 .505 0 r
F
.47427 .66817 m .47463 .67282 L .47426 .66862 L F
.47427 .66817 m .47426 .66862 L .47358 .66113 L F
.47518 .68764 m .47531 .68964 L .47528 .688 L 1 .791 0 r
F
.47386 .67952 m .47579 .68775 L .47614 .72491 L 1 .58 0 r
F
.47364 .67516 m .47395 .67698 L .47386 .67952 L F
.47395 .67698 m .47579 .68775 L .47386 .67952 L F
.47366 .6629 m .47579 .68775 L .47364 .67516 L F
.47529 .66628 m .4749 .66337 L .47491 .66323 L .843 .409 0 r
F
.47463 .67282 m .47472 .67388 L .47463 .67292 L .956 .505 0 r
F
.474 .64407 m .47533 .65186 L .47543 .65103 L 1 .542 0 r
F
.47383 .64393 m .47533 .65186 L .474 .64407 L F
.47493 .64482 m .47509 .64365 L .47502 .64489 L 1 .937 0 r
F
.47493 .64482 m .47502 .64489 L .47493 .6465 L F
.47533 .65186 m .47687 .64004 L .47718 .63998 L 1 .881 0 r
F
.47729 .63925 m .4777 .63365 L .47792 .63517 L F
.47735 .64221 m .4775 .64236 L .47735 .64221 L .833 .528 0 r
F
.4775 .64236 m .47829 .64318 L .4775 .64238 L F
.47743 .64301 m .4783 .6442 L .4773 .64407 L F
.47717 .64266 m .4775 .64238 L .47743 .64301 L F
.47722 .64207 m .47728 .64167 L .47714 .64305 L .92 .215 0 r
F
.47721 .64233 m .47728 .64167 L .47721 .64243 L F
.47722 .6421 m .4775 .64238 L .47717 .64266 L .833 .528 0 r
F
.47721 .64217 m .47722 .64207 L .47712 .64317 L .92 .215 0 r
F
.47722 .64207 m .47714 .64305 L .47712 .64317 L F
.47719 .6423 m .47721 .64217 L .47705 .64385 L F
.47721 .64217 m .47712 .64317 L .47705 .64385 L F
.47708 .64365 m .4773 .64407 L .47707 .64381 L .833 .528 0 r
F
.4773 .64407 m .47762 .64469 L .47728 .64425 L F
.47722 .64474 m .47722 .64469 L .47721 .6448 L 0 0 0 r
F
.47722 .64469 m .47722 .64475 L .47721 .6448 L F
.47724 .64454 m .47725 .64451 L .47722 .64474 L F
.47681 .64495 m .47757 .64499 L .4774 .64617 L .867 .538 0 r
F
.47681 .64495 m .47712 .64558 L .47703 .64631 L F
.47552 .6539 m .47708 .64365 L .47559 .65969 L .92 .215 0 r
F
.47722 .64473 m .47724 .64454 L .47719 .645 L 0 0 0 r
F
.47724 .64454 m .47721 .6448 L .47719 .645 L F
.47643 .6543 m .4764 .65452 L .47616 .65393 L 1 .629 0 r
F
.47559 .65969 m .47703 .64631 L .47566 .66959 L 0 0 0 r
F
.47559 .65969 m .47722 .64473 L .47719 .645 L F
.47688 .64591 m .47691 .64555 L .47703 .64631 L .867 .538 0 r
F
.47559 .65969 m .47721 .64483 L .47703 .64631 L 0 0 0 r
F
.47708 .64365 m .47725 .64451 L .47559 .65969 L .92 .215 0 r
F
.47728 .64425 m .47725 .64451 L .47717 .64412 L .833 .528 0 r
F
.47762 .64469 m .47725 .64451 L .47728 .64425 L F
.47757 .64499 m .47801 .64561 L .4774 .64617 L .867 .538 0 r
F
.47566 .66959 m .47721 .64752 L .47718 .64775 L 0 0 0 r
F
.47722 .64745 m .47721 .64752 L .4772 .64739 L .867 .538 0 r
F
.47758 .64808 m .47721 .64752 L .47722 .64745 L F
.47709 .6467 m .47721 .64752 L .47566 .66959 L 0 0 0 r
F
.47758 .64808 m .47757 .64817 L .47721 .64752 L .867 .538 0 r
F
.47804 .64889 m .47757 .64817 L .47758 .64808 L F
.47762 .64782 m .47804 .64889 L .47758 .64808 L F
.47757 .64817 m .47802 .64899 L .4772 .65077 L .936 .578 0 r
F
.47743 .64301 m .47829 .64318 L .4783 .6442 L .833 .528 0 r
F
.4775 .64238 m .47829 .64318 L .47743 .64301 L F
.47793 .64271 m .4775 .64236 L .47751 .64229 L .877 .574 0 r
F
.47753 .64217 m .47814 .64035 L .47829 .64318 L F
.47723 .64178 m .47765 .64112 L .47753 .64217 L F
.47765 .64112 m .47814 .64035 L .47753 .64217 L F
.47753 .64217 m .47751 .64229 L .47722 .642 L F
.47753 .64217 m .47722 .642 L .47723 .64189 L F
.47552 .6539 m .47719 .6423 L .47705 .64385 L .92 .215 0 r
F
.47711 .64162 m .47726 .64143 L .47723 .64178 L .877 .574 0 r
F
.47726 .64143 m .47814 .64035 L .47723 .64178 L F
.47723 .64178 m .47723 .64189 L .47712 .64179 L F
.47723 .64178 m .47712 .64179 L .47711 .64168 L F
.47711 .64162 m .47722 .64207 L .47552 .6539 L 1 .74 0 r
F
.47711 .64162 m .47723 .64178 L .47713 .64169 L .877 .574 0 r
F
.47723 .64178 m .47753 .64217 L .47723 .64189 L F
.47515 .63902 m .47572 .63977 L .47545 .64022 L F
.47572 .63977 m .47604 .64078 L .47545 .64022 L F
.47753 .64217 m .47793 .64271 L .47751 .64229 L F
.47703 .64631 m .4774 .64617 L .47729 .64696 L .867 .538 0 r
F
.47712 .64558 m .4774 .64617 L .47703 .64631 L F
.4774 .64617 m .47778 .64695 L .47729 .64696 L F
.47793 .64271 m .47829 .64318 L .47791 .64279 L .877 .574 0 r
F
.47516 .63926 m .47545 .64022 L .47519 .63995 L F
.47515 .63902 m .47545 .64022 L .47516 .63926 L F
.47519 .63995 m .47545 .64022 L .47547 .64033 L .833 .528 0 r
F
.47803 .64551 m .4783 .6442 L .47831 .64605 L F
.47762 .64782 m .47825 .64795 L .47804 .64889 L .867 .538 0 r
F
.47778 .64695 m .47825 .64795 L .47762 .64782 L F
.47728 .65294 m .47747 .65227 L .47733 .65343 L 1 .629 0 r
F
.47728 .65294 m .47733 .65343 L .47702 .65599 L F
.47693 .65685 m .47744 .65831 L .47713 .65926 L 1 .683 0 r
F
.47519 .63995 m .47552 .64059 L .47529 .64168 L .833 .528 0 r
F
.47552 .64059 m .47587 .64243 L .47529 .64168 L F
.47762 .64469 m .47831 .64605 L .47757 .64498 L F
.47518 .64104 m .47529 .64168 L .47517 .64152 L F
.47519 .63995 m .47529 .64168 L .47518 .64104 L F
.47476 .65407 m .47552 .6539 L .47559 .65969 L .678 .272 0 r
F
.47517 .65209 m .47552 .6539 L .47476 .65407 L F
.47476 .65407 m .47559 .65969 L .47472 .65427 L F
.47426 .65789 m .47424 .65798 L .47382 .65453 L .843 .409 0 r
F
.47426 .65789 m .47382 .65453 L .4738 .65425 L F
.4722 .63563 m .47264 .63803 L .47222 .63683 L .321 .06 0 r
F
.47264 .63803 m .47284 .63978 L .47222 .63683 L F
.47499 .64381 m .47511 .64309 L .47509 .64365 L 1 .969 0 r
F
.47518 .65205 m .47552 .6539 L .47517 .65209 L .321 .06 0 r
F
.47472 .65427 m .47559 .65969 L .47453 .65577 L .843 .409 0 r
F
.47529 .66628 m .47562 .66386 L .47566 .66959 L F
.47529 .66628 m .47566 .66959 L .47527 .66641 L F
.47472 .67388 m .47511 .67896 L .47469 .67417 L .956 .505 0 r
F
.47511 .67896 m .47579 .68775 L .47507 .67934 L F
.47319 .68186 m .47316 .68855 L .47239 .67212 L .717 .135 0 r
F
.47259 .83133 m .47259 .83185 L .4721 .88467 L 0 0 0 r
F
.47516 .74301 m .47508 .74148 L .47391 .71202 L F
.4754 .75511 m .47576 .75397 L .4757 .7528 L .649 .164 0 r
F
.4766 .78096 m .47665 .78054 L .47665 .78283 L 1 .667 0 r
F
.47665 .78054 m .47669 .78186 L .47665 .78283 L F
.47702 .79053 m .47757 .80476 L .47711 .79306 L 0 0 0 r
F
.47589 .75133 m .47752 .74845 L .47743 .73942 L .649 .164 0 r
F
.47603 .75312 m .47752 .74845 L .47589 .75133 L F
.47284 .7169 m .4734 .72927 L .47284 .71729 L 0 0 0 r
F
.4734 .72927 m .4734 .72934 L .4734 .72927 L F
.4734 .72927 m .4734 .72927 L .47284 .71729 L F
.47339 .73004 m .4734 .72934 L .4735 .73266 L F
.47284 .71729 m .4734 .72927 L .47339 .73004 L F
.4734 .72927 m .4734 .72934 L .47339 .73004 L F
.47869 .86619 m .47869 .86626 L .47803 .87074 L 1 .741 0 r
F
.47902 .86246 m .48098 .90853 L .47803 .87074 L 0 0 0 r
F
.4779 .86801 m .47902 .86246 L .47803 .87068 L 1 .741 0 r
F
.47902 .86246 m .47808 .8703 L .47803 .87068 L F
.47688 .87309 m .4779 .86801 L .4767 .87984 L F
.4779 .86801 m .47803 .87068 L .4767 .87984 L F
.47305 .81175 m .4766 .78096 L .47332 .86462 L 1 .667 0 r
F
.4766 .78096 m .47665 .78283 L .47332 .86462 L F
.47461 .7192 m .47481 .72426 L .47458 .71773 L 1 .249 0 r
F
.47463 .72056 m .47481 .72426 L .47461 .7192 L F
.47685 .74035 m .47743 .73942 L .4774 .73562 L .649 .164 0 r
F
.47454 .71824 m .47458 .71935 L .47373 .69641 L .717 .135 0 r
F
.47373 .69647 m .47454 .71824 L .47373 .69641 L F
.47803 .87068 m .47803 .87074 L .4767 .87984 L 1 .741 0 r
F
.47818 .87386 m .47835 .87599 L .4782 .87428 L .185 .03 0 r
F
.47835 .87599 m .48098 .90853 L .4784 .87783 L F
.47859 .88517 m .47861 .88626 L .47702 .89312 L 1 .818 0 r
F
.47861 .88626 m .47868 .89528 L .47861 .89613 L 1 .901 0 r
F
.47868 .89636 m .47938 .8942 L .47866 .897 L 1 .962 0 r
F
.47859 .88517 m .48048 .91196 L .47702 .89312 L .185 .03 0 r
F
.47859 .88517 m .47702 .89312 L .47567 .88578 L F
.47684 .89102 m .47859 .88517 L .47702 .89312 L 1 .818 0 r
F
.4734 .89034 m .47688 .87309 L .47333 .90274 L 1 .741 0 r
F
.47688 .87309 m .4767 .87984 L .47333 .90274 L F
.48033 .91835 m .48119 .91804 L .48059 .91953 L 1 1 0 r
F
.47333 .90274 m .47607 .88412 L .47684 .89102 L 1 .818 0 r
F
.47333 .90274 m .47684 .89102 L .47316 .90976 L F
.47345 .90233 m .47418 .90454 L .47348 .90315 L .829 .107 0 r
F
.47336 .89971 m .47418 .90454 L .47345 .90233 L F
.47684 .89102 m .47702 .89312 L .47316 .90976 L 1 .818 0 r
F
.47215 .91953 m .47641 .91228 L .47169 .92122 L 1 .625 0 r
F
.47339 .91605 m .47764 .92008 L .47319 .91841 L .576 .615 0 r
F
.47764 .92008 m .47668 .92054 L .47319 .91841 L F
.47319 .91841 m .47643 .92101 L .47292 .92023 L .706 .788 0 r
F
.47643 .92101 m .47578 .9217 L .47292 .92023 L F
.47447 .91944 m .47592 .92012 L .47566 .9204 L F
.4745 .91931 m .47592 .92012 L .47447 .91944 L F
.47381 .91886 m .47592 .92012 L .47382 .91891 L F
.47465 .91929 m .47521 .91964 L .47461 .91932 L F
.47521 .91964 m .47518 .91969 L .47423 .91912 L F
.47354 .91944 m .47554 .91907 L .47341 .92088 L 1 1 0 r
F
.47552 .91807 m .47719 .91923 L .47737 .91956 L .576 .615 0 r
F
.47741 .91986 m .47737 .91956 L .47764 .92008 L F
.47552 .91807 m .47737 .91956 L .47741 .91986 L F
.47336 .89971 m .47799 .91066 L .47418 .90454 L .829 .107 0 r
F
.47929 .91507 m .47982 .91469 L .48 .91498 L 1 1 0 r
F
.47741 .89957 m .48048 .91196 L .47977 .91473 L .462 .125 0 r
F
.47906 .9142 m .48153 .91346 L .47929 .91507 L 1 1 0 r
F
.48027 .91821 m .48097 .91672 L .48119 .91804 L F
.4801 .91756 m .48097 .91672 L .48027 .91821 L F
.47915 .91772 m .48002 .91725 L .47924 .9184 L F
.48002 .91725 m .48097 .91672 L .4801 .91756 L F
.48002 .91725 m .4801 .91756 L .47924 .9184 L F
.47685 .90987 m .4791 .91431 L .47698 .91034 L 0 0 0 r
F
.4791 .91431 m .47914 .9144 L .47698 .91034 L F
.47932 .91382 m .47906 .9142 L .47773 .91156 L .829 .107 0 r
F
.47894 .91388 m .47932 .91382 L .47906 .9142 L 0 0 0 r
F
.47932 .91382 m .48153 .91346 L .47906 .9142 L F
.47799 .91066 m .47932 .91382 L .47773 .91156 L .829 .107 0 r
F
.47929 .91507 m .48163 .91476 L .47949 .91555 L 1 1 0 r
F
.47719 .91923 m .47767 .91956 L .47764 .92008 L .576 .615 0 r
F
.47765 .91988 m .48033 .91835 L .48042 .91878 L 1 1 0 r
F
.47767 .91956 m .47802 .91981 L .47764 .92008 L .576 .615 0 r
F
.47668 .92027 m .47766 .91975 L .47765 .91988 L 1 1 0 r
F
.47766 .91975 m .48033 .91835 L .47765 .91988 L F
.4756 .91774 m .47768 .91932 L .47552 .91807 L .576 .615 0 r
F
.47764 .92008 m .48042 .91878 L .48059 .91953 L 1 1 0 r
F
.47668 .92027 m .47765 .91988 L .47764 .92008 L F
.47765 .91988 m .48042 .91878 L .47764 .92008 L F
.47768 .91932 m .47767 .91956 L .47552 .91807 L .576 .615 0 r
F
.4783 .91857 m .47853 .91901 L .47768 .91932 L 1 1 0 r
F
.4783 .91857 m .47821 .91867 L .47815 .91864 L .377 .361 0 r
F
.4783 .91857 m .47815 .91864 L .47339 .91605 L F
.47443 .91641 m .47506 .91532 L .47442 .9165 L .778 .207 0 r
F
.47351 .91292 m .4783 .91857 L .47339 .91605 L .377 .361 0 r
F
.47854 .91885 m .47768 .91932 L .47339 .91605 L F
.478 .91822 m .47823 .9178 L .4783 .91857 L F
.47489 .91455 m .47787 .91746 L .478 .91822 L F
.47787 .91746 m .47823 .9178 L .478 .91822 L F
.47879 .91644 m .47961 .91596 L .47887 .91685 L 1 1 0 r
F
.47961 .91596 m .48163 .91476 L .47969 .91623 L F
.47961 .91596 m .47969 .91623 L .47887 .91685 L F
.47844 .91619 m .47869 .91589 L .47887 .91685 L .158 .074 0 r
F
.47471 .91045 m .47837 .91544 L .47844 .91619 L F
.47837 .91544 m .47869 .91589 L .47844 .91619 L F
.47698 .91034 m .47923 .91468 L .47944 .9154 L 0 0 0 r
F
.47936 .9148 m .47938 .91485 L .47447 .90518 L F
.47471 .91028 m .47868 .91584 L .47471 .91045 L .158 .074 0 r
F
.47871 .91599 m .48163 .91476 L .47879 .91644 L 1 1 0 r
F
.47868 .91584 m .47895 .91622 L .47868 .91586 L .158 .074 0 r
F
.47868 .91584 m .47868 .91586 L .47471 .91045 L F
.47726 .91876 m .47915 .91772 L .4792 .91814 L 1 1 0 r
F
.4783 .91857 m .4792 .91814 L .47924 .9184 L F
.47726 .91876 m .4792 .91814 L .4783 .91857 L F
.47853 .91901 m .48033 .91835 L .47852 .9193 L F
.4783 .91857 m .48119 .91804 L .47853 .91901 L F
.47822 .91767 m .4791 .91734 L .47825 .91799 L F
.4791 .91734 m .48152 .91642 L .47915 .91772 L F
.4791 .91734 m .47915 .91772 L .47726 .91876 L F
.47924 .9184 m .4801 .91756 L .48027 .91821 L F
.47946 .91993 m .48064 .91952 L .47945 .92012 L F
.47354 .90863 m .47887 .91685 L .47351 .91292 L .158 .074 0 r
F
.47887 .91685 m .48152 .91642 L .47822 .91767 L 1 1 0 r
F
.47887 .91685 m .48163 .92111 L .47822 .91767 L .158 .074 0 r
F
.47887 .91685 m .47822 .91767 L .47351 .91292 L F
.47741 .91686 m .47822 .91767 L .47756 .91715 L .377 .361 0 r
F
.47822 .91767 m .47857 .91802 L .47829 .91778 L F
.47822 .91767 m .47829 .91778 L .47756 .91715 L F
.47741 .91686 m .47756 .91715 L .47489 .91455 L F
.47339 .91605 m .4756 .91774 L .47552 .91807 L .576 .615 0 r
F
.47382 .91891 m .4745 .91931 L .47447 .91944 L .706 .788 0 r
F
.47363 .91876 m .47381 .91886 L .47382 .91891 L F
.47424 .91904 m .47423 .91912 L .47363 .91876 L F
.47358 .91771 m .4778 .91703 L .47354 .91944 L 1 1 0 r
F
.4778 .91703 m .47887 .91685 L .47797 .91729 L F
.47857 .91802 m .47856 .91813 L .47842 .91799 L .377 .361 0 r
F
.47829 .91778 m .47842 .91799 L .47756 .91715 L F
.47857 .91802 m .47842 .91799 L .47829 .91778 L F
.47797 .91729 m .47822 .91767 L .47354 .91944 L 1 1 0 r
F
.47887 .91685 m .47822 .91767 L .47797 .91729 L F
.4778 .91703 m .47797 .91729 L .47354 .91944 L F
.47769 .91641 m .47871 .91599 L .4778 .91703 L F
.47871 .91599 m .47879 .91644 L .4778 .91703 L F
.47766 .91622 m .47868 .91584 L .47769 .91641 L F
.47895 .91622 m .47895 .91625 L .47869 .91589 L .158 .074 0 r
F
.47868 .91586 m .47869 .91589 L .47471 .91045 L F
.47895 .91622 m .47869 .91589 L .47868 .91586 L F
.47868 .91584 m .48163 .91476 L .47871 .91599 L 1 1 0 r
F
.47868 .91584 m .47871 .91599 L .47769 .91641 L F
.47929 .91507 m .47949 .91555 L .47868 .91584 L F
.47929 .91507 m .47923 .91515 L .47354 .90863 L 0 0 0 r
F
.47944 .9154 m .47868 .91584 L .47354 .90863 L F
.47481 .91423 m .47741 .91686 L .47489 .91455 L .377 .361 0 r
F
.47929 .91507 m .47868 .91584 L .47358 .91771 L 1 1 0 r
F
.47348 .90315 m .47929 .91507 L .47354 .90863 L 0 0 0 r
F
.47929 .91507 m .47944 .9154 L .47923 .91515 L F
.47887 .91685 m .48163 .91476 L .48152 .91642 L 1 1 0 r
F
.47944 .9154 m .48176 .92015 L .47868 .91584 L 0 0 0 r
F
.47834 .9152 m .47906 .9142 L .47929 .91507 L 1 1 0 r
F
.47354 .91584 m .47827 .91443 L .47834 .9152 L F
.47938 .91485 m .47883 .91389 L .47884 .91389 L 0 0 0 r
F
.47827 .91443 m .47906 .9142 L .47834 .9152 L 1 1 0 r
F
.47944 .9154 m .47972 .91561 L .47986 .91626 L 0 0 0 r
F
.47923 .91468 m .47972 .91561 L .47944 .9154 L F
.47887 .91685 m .47895 .91625 L .47908 .91718 L .158 .074 0 r
F
.47869 .91589 m .47895 .91625 L .47887 .91685 L F
.4778 .91703 m .47879 .91644 L .47887 .91685 L 1 1 0 r
F
.47358 .91771 m .47766 .91622 L .4778 .91703 L F
.4783 .91857 m .47768 .91932 L .4752 .92023 L F
.4783 .91857 m .47854 .91885 L .47821 .91867 L .377 .361 0 r
F
.47667 .91988 m .47853 .91901 L .47668 .92027 L 1 1 0 r
F
.47853 .91901 m .47852 .9193 L .47668 .92027 L F
.47854 .91885 m .48128 .92208 L .47768 .91932 L .377 .361 0 r
F
.47666 .9197 m .47768 .91932 L .47667 .91988 L 1 1 0 r
F
.47768 .91932 m .47853 .91901 L .47667 .91988 L F
.47857 .91802 m .48163 .92111 L .47856 .91813 L .377 .361 0 r
F
.47768 .91932 m .47804 .91982 L .47767 .91956 L .576 .615 0 r
F
.47768 .91932 m .48128 .92208 L .47804 .91982 L F
.47554 .91907 m .47726 .91876 L .4752 .92023 L 1 1 0 r
F
.47726 .91876 m .4783 .91857 L .47745 .91902 L F
.47726 .91876 m .47745 .91902 L .4752 .92023 L F
.4783 .91857 m .48163 .92111 L .48128 .92208 L .377 .361 0 r
F
.47823 .9178 m .48163 .92111 L .4783 .91857 L F
.47717 .91806 m .47822 .91767 L .47726 .91876 L 1 1 0 r
F
.47822 .91767 m .47825 .91799 L .47726 .91876 L F
.47895 .91622 m .47968 .91724 L .47895 .91625 L .158 .074 0 r
F
.47932 .91382 m .48167 .91938 L .47906 .9142 L .829 .107 0 r
F
.47891 .91317 m .47919 .91386 L .47894 .91323 L F
.47919 .91386 m .48138 .91919 L .4792 .91385 L F
.47894 .91388 m .4793 .91383 L .47932 .91382 L 0 0 0 r
F
.47919 .91386 m .4792 .91385 L .47894 .91323 L .829 .107 0 r
F
.47932 .91382 m .48125 .91352 L .48153 .91346 L 0 0 0 r
F
.47799 .91066 m .47773 .91156 L .47418 .90454 L .829 .107 0 r
F
.47476 .90302 m .47888 .91309 L .47931 .91382 L F
.47932 .91382 m .47931 .91382 L .47937 .91393 L F
.47476 .90302 m .47931 .91382 L .47932 .91382 L F
.47914 .91386 m .47919 .91386 L .47894 .91388 L 0 0 0 r
F
.47919 .91386 m .48125 .91352 L .4793 .91383 L F
.47919 .91386 m .4793 .91383 L .47894 .91388 L F
.4793 .91383 m .48125 .91352 L .47932 .91382 L F
.47938 .91485 m .47858 .91341 L .47843 .91307 L F
.47443 .90503 m .47906 .9142 L .47447 .90518 L F
.47906 .9142 m .47906 .9142 L .47447 .90518 L F
.47343 .91479 m .47894 .91388 L .47354 .91584 L F
.47343 .91479 m .47914 .91386 L .47894 .91388 L F
.47938 .91485 m .47943 .91506 L .47883 .91389 L F
.47884 .91389 m .47883 .91389 L .47858 .91341 L F
.47843 .91307 m .47858 .91341 L .47698 .91034 L F
.47354 .91584 m .47929 .91507 L .47358 .91771 L 1 1 0 r
F
.47894 .91388 m .47906 .9142 L .47354 .91584 L 0 0 0 r
F
.4791 .91431 m .47938 .91485 L .47914 .9144 L F
.47938 .91485 m .48167 .91938 L .47943 .91506 L F
.47794 .91083 m .47891 .91317 L .47794 .91082 L .829 .107 0 r
F
.47794 .91083 m .47794 .91082 L .47476 .90302 L F
.47468 .90291 m .47794 .91083 L .47476 .90302 L F
.47891 .91317 m .47894 .91323 L .47476 .90302 L F
.48 .91498 m .48153 .91346 L .48163 .91476 L 1 1 0 r
F
.47982 .91469 m .48153 .91346 L .48 .91498 L F
.47906 .9142 m .47936 .9148 L .47906 .9142 L 0 0 0 r
F
.47936 .9148 m .48167 .91938 L .47938 .91485 L F
.47908 .91718 m .47968 .91724 L .47962 .91801 L .158 .074 0 r
F
.47895 .91625 m .47968 .91724 L .47908 .91718 L F
.47366 .90044 m .47913 .91372 L .47367 .90046 L .829 .107 0 r
F
.47913 .91372 m .48138 .91919 L .47913 .91372 L F
.47913 .91372 m .47913 .91372 L .47367 .90046 L F
.48097 .91672 m .48152 .91642 L .48134 .91732 L 1 1 0 r
F
.48097 .91672 m .48134 .91732 L .48119 .91804 L F
.47465 .91929 m .47461 .91932 L .47423 .91912 L .706 .788 0 r
F
.47424 .91904 m .47465 .91929 L .47423 .91912 L F
.47354 .91944 m .47717 .91806 L .47726 .91876 L 1 1 0 r
F
.47554 .91907 m .4752 .92023 L .47341 .92088 L F
.47351 .90007 m .47366 .90044 L .47352 .90009 L .829 .107 0 r
F
.47366 .90044 m .47367 .90046 L .47352 .90009 L F
.47354 .90863 m .47471 .91028 L .47471 .91045 L .158 .074 0 r
F
.47764 .92008 m .48072 .92299 L .47668 .92054 L .576 .615 0 r
F
.47668 .92027 m .47764 .92008 L .47706 .92076 L 1 1 0 r
F
.47764 .92008 m .47802 .91981 L .4779 .92032 L .576 .615 0 r
F
.47962 .91801 m .48176 .92015 L .48163 .92111 L .158 .074 0 r
F
.47968 .91724 m .48176 .92015 L .47962 .91801 L F
.4779 .92032 m .47844 .9201 L .4782 .92061 L .576 .615 0 r
F
.47802 .91981 m .47844 .9201 L .4779 .92032 L F
.47712 .92084 m .47744 .92104 L .4773 .92108 L .706 .788 0 r
F
.47712 .92084 m .4773 .92108 L .4767 .92123 L F
.47566 .9204 m .47668 .92058 L .4767 .92123 L F
.47341 .92088 m .47668 .92027 L .47321 .9221 L 1 1 0 r
F
.47668 .92027 m .47706 .92076 L .47321 .9221 L F
.47321 .9221 m .47706 .92076 L .47691 .9214 L F
.47693 .92133 m .47764 .92164 L .47691 .9214 L .706 .788 0 r
F
.47691 .9214 m .47716 .9216 L .47669 .92164 L F
.47691 .9214 m .47669 .92164 L .47578 .9217 L F
.47716 .9216 m .47635 .922 L .47578 .9217 L F
.47321 .9221 m .47691 .9214 L .47635 .922 L 1 1 0 r
F
.47316 .92228 m .47635 .922 L .47293 .92312 L F
.47321 .9221 m .47635 .922 L .47316 .92228 L F
.47788 .92187 m .47811 .92208 L .47814 .92184 L 1 .608 0 r
F
.4782 .92061 m .47832 .92067 L .47831 .92071 L .576 .615 0 r
F
.47832 .92067 m .48128 .92208 L .47831 .92071 L F
.47831 .92071 m .48128 .92208 L .48072 .92299 L F
.47844 .9201 m .48128 .92208 L .4782 .92061 L F
.47744 .92104 m .48072 .92299 L .47723 .92146 L .706 .788 0 r
F
.47744 .92104 m .47723 .92146 L .4767 .92123 L F
.47293 .92312 m .47635 .922 L .47474 .92279 L 1 1 0 r
F
.4771 .92183 m .47995 .92385 L .47993 .92374 L 1 .608 0 r
F
.47704 .92184 m .47995 .92385 L .4771 .92183 L F
.47716 .9216 m .47995 .92385 L .47635 .922 L .706 .788 0 r
F
.47811 .92208 m .47993 .92374 L .47976 .92266 L 1 .608 0 r
F
.47747 .92185 m .48072 .92299 L .47995 .92385 L .706 .788 0 r
F
.47764 .92164 m .48072 .92299 L .47747 .92185 L F
.47351 .91292 m .47481 .91423 L .47489 .91455 L .377 .361 0 r
F
.47592 .92012 m .47668 .92058 L .47566 .9204 L .706 .788 0 r
F
.47341 .92088 m .47666 .9197 L .47668 .92027 L 1 1 0 r
F
.47986 .91626 m .48167 .91938 L .48174 .92011 L 0 0 0 r
F
.47972 .91561 m .48167 .91938 L .47986 .91626 L F
.48138 .91919 m .48161 .91866 L .48167 .91938 L 1 .756 0 r
F
.48161 .91866 m .48457 .9118 L .48167 .91938 L F
.48368 .91387 m .48961 .91472 L .48395 .91384 L .99 .845 0 r
F
.48457 .9118 m .48395 .91384 L .48405 .91316 L 1 .756 0 r
F
.48879 .9139 m .4966 .91625 L .49535 .91801 L .689 .873 0 r
F
.49725 .90965 m .49324 .91371 L .49047 .91297 L .649 .82 0 r
F
.48929 .91125 m .4966 .91625 L .48879 .9139 L .575 .739 0 r
F
.48368 .91387 m .48901 .91104 L .48961 .91472 L .99 .845 0 r
F
.4811 .83421 m .48789 .89152 L .48183 .86646 L .356 .064 0 r
F
.48223 .89863 m .48626 .90491 L .48251 .89979 L .944 .693 0 r
F
.4823 .87176 m .48729 .89929 L .48146 .88498 L .59 .244 0 r
F
.48268 .86997 m .48789 .89152 L .48266 .87006 L F
.48146 .88498 m .48729 .89929 L .48143 .88513 L .796 .486 0 r
F
.48452 .90826 m .48487 .90921 L .48455 .90839 L .944 .693 0 r
F
.4823 .87176 m .48789 .89152 L .48729 .89929 L .59 .244 0 r
F
.48266 .87006 m .48789 .89152 L .4823 .87176 L F
.48143 .88513 m .48729 .89929 L .48121 .88612 L .796 .486 0 r
F
.48468 .90906 m .48487 .90921 L .48479 .90937 L 1 .875 0 r
F
.48468 .90906 m .48479 .90937 L .48316 .91261 L F
.48941 .87477 m .48973 .87645 L .48851 .88303 L 1 .815 0 r
F
.48941 .87477 m .48851 .88303 L .48921 .87622 L F
.50864 .83219 m .49787 .84868 L .49646 .84949 L .992 .842 0 r
F
.50651 .83226 m .49646 .84949 L .49503 .85016 L 1 .936 0 r
F
.50651 .83226 m .50864 .83219 L .49646 .84949 L F
.50436 .83214 m .50651 .83226 L .49503 .85016 L 1 1 0 r
F
.5015 .80209 m .49778 .83056 L .49555 .82963 L F
.49861 .79941 m .5015 .80209 L .49555 .82963 L F
.49861 .79941 m .49555 .82963 L .49331 .82849 L F
.49637 .67218 m .48858 .67593 L .48782 .67607 L .467 .214 0 r
F
.49637 .67218 m .49752 .67209 L .48858 .67593 L F
.49521 .6722 m .48782 .67607 L .48705 .67615 L .516 .316 0 r
F
.49521 .6722 m .49637 .67218 L .48782 .67607 L F
.49404 .67215 m .48705 .67615 L .48627 .67617 L .563 .444 0 r
F
.49404 .67215 m .49521 .6722 L .48705 .67615 L F
.49287 .67204 m .48627 .67617 L .48549 .67612 L .607 .571 0 r
F
.49287 .67204 m .49404 .67215 L .48627 .67617 L F
.49169 .67185 m .48549 .67612 L .4847 .67601 L .651 .69 0 r
F
.49169 .67185 m .49287 .67204 L .48549 .67612 L F
.4905 .67159 m .49169 .67185 L .4847 .67601 L .731 .799 0 r
F
.49501 .66728 m .4905 .67159 L .4893 .67126 L .873 1 0 r
F
.49344 .66683 m .4893 .67126 L .48811 .67086 L .933 1 0 r
F
.49344 .66683 m .49501 .66728 L .4893 .67126 L F
.49186 .66631 m .48811 .67086 L .4869 .67038 L .99 1 0 r
F
.49186 .66631 m .49344 .66683 L .48811 .67086 L F
.49028 .6657 m .4869 .67038 L .48569 .66983 L 1 1 0 r
F
.49028 .6657 m .49186 .66631 L .4869 .67038 L F
.48869 .66502 m .49028 .6657 L .48569 .66983 L F
.4925 .66126 m .49028 .6657 L .48869 .66502 L F
.49057 .6605 m .48869 .66502 L .4871 .66426 L F
.49057 .6605 m .4925 .66126 L .48869 .66502 L F
.48864 .65965 m .49057 .6605 L .4871 .66426 L F
.49141 .65628 m .49057 .6605 L .48864 .65965 L F
.48919 .65539 m .48864 .65965 L .48672 .65872 L F
.48919 .65539 m .49141 .65628 L .48864 .65965 L F
.48697 .65443 m .48919 .65539 L .48672 .65872 L F
.49044 .69685 m .49393 .70155 L .49308 .72302 L 1 .834 0 r
F
.4911 .68293 m .49393 .70155 L .49044 .69685 L 1 .805 0 r
F
.50092 .67143 m .49159 .67474 L .49085 .67513 L .256 .181 0 r
F
.48815 .67001 m .49163 .67309 L .4911 .68293 L 1 .76 0 r
F
.49658 .66765 m .49169 .67185 L .4905 .67159 L .808 .952 0 r
F
.49501 .66728 m .49658 .66765 L .4905 .67159 L .873 1 0 r
F
.48869 .66502 m .48569 .66983 L .48448 .66921 L 1 1 0 r
F
.4871 .66426 m .48869 .66502 L .48448 .66921 L F
.4885 .66373 m .49163 .67309 L .48815 .67001 L 1 .751 0 r
F
.49635 .66257 m .49344 .66683 L .49186 .66631 L .985 1 0 r
F
.49443 .66196 m .49186 .66631 L .49028 .6657 L 1 1 0 r
F
.49443 .66196 m .49635 .66257 L .49186 .66631 L F
.4925 .66126 m .49443 .66196 L .49028 .6657 L F
.4885 .66373 m .49197 .66586 L .49163 .67309 L 1 .751 0 r
F
.48764 .67877 m .4911 .68293 L .49044 .69685 L 1 .783 0 r
F
.48815 .67001 m .4911 .68293 L .48764 .67877 L 1 .76 0 r
F
.48867 .65916 m .49197 .66586 L .4885 .66373 L .989 .764 0 r
F
.49364 .65709 m .4925 .66126 L .49057 .6605 L 1 1 0 r
F
.49141 .65628 m .49364 .65709 L .49057 .6605 L F
.48867 .65916 m .49208 .66041 L .49197 .66586 L .989 .764 0 r
F
.48863 .65586 m .49208 .66041 L .48867 .65916 L .974 .814 0 r
F
.49251 .717 m .48863 .65586 L .48867 .65916 L 0 0 0 r
F
.49573 .79638 m .49861 .79941 L .49512 .81859 L 1 1 0 r
F
.51487 .83081 m .50199 .84538 L .50063 .84662 L .731 .405 0 r
F
.51282 .83145 m .50063 .84662 L .49926 .84772 L .794 .574 0 r
F
.51282 .83145 m .51487 .83081 L .50063 .84662 L F
.51075 .83192 m .49926 .84772 L .49787 .84868 L .898 .722 0 r
F
.51075 .83192 m .51282 .83145 L .49926 .84772 L F
.50864 .83219 m .51075 .83192 L .49787 .84868 L .992 .842 0 r
F
.50725 .80645 m .50219 .83182 L .49999 .83129 L 1 1 0 r
F
.50438 .80443 m .49999 .83129 L .49778 .83056 L F
.50438 .80443 m .50725 .80645 L .49999 .83129 L F
.5015 .80209 m .50438 .80443 L .49778 .83056 L F
.49753 .77521 m .49861 .79941 L .49573 .79638 L 1 .976 0 r
F
.49856 .76303 m .4986 .78895 L .49753 .77521 L F
.4986 .78895 m .49861 .79941 L .49753 .77521 L F
.49658 .72832 m .49856 .76303 L .49716 .76099 L 1 .899 0 r
F
.49584 .7447 m .49716 .76099 L .49523 .75817 L F
.49658 .72832 m .49716 .76099 L .49584 .7447 L F
.49044 .69685 m .49308 .72302 L .48966 .7172 L 1 .834 0 r
F
.49308 .72302 m .49523 .75817 L .49195 .75278 L 1 .887 0 r
F
.48966 .7172 m .49308 .72302 L .49195 .75278 L 1 .874 0 r
F
.49477 .75099 m .49249 .71632 L .49251 .717 L 0 0 0 r
F
.49308 .72302 m .49658 .72832 L .49523 .75817 L 1 .887 0 r
F
.49523 .75817 m .49716 .76099 L .49573 .79638 L 1 .958 0 r
F
.49716 .76099 m .49856 .76303 L .49794 .77032 L F
.49716 .76099 m .49794 .77032 L .49573 .79638 L F
.49243 .71365 m .48863 .65586 L .49251 .717 L 0 0 0 r
F
.48884 .65152 m .48919 .65539 L .48697 .65443 L 1 1 0 r
F
.48938 .66758 m .48837 .65359 L .48861 .65568 L .787 .143 0 r
F
.49732 .78926 m .49595 .7686 L .49594 .7685 L 0 0 0 r
F
.49729 .78853 m .49249 .71632 L .49732 .78926 L F
.49741 .79069 m .49757 .79145 L .49834 .80778 L .66 .306 0 r
F
.49757 .79145 m .49778 .79441 L .49834 .80778 L F
.49768 .79194 m .49895 .80946 L .4988 .80904 L F
.49778 .79441 m .4988 .80904 L .49834 .80778 L F
.49768 .79194 m .4988 .80904 L .49778 .79441 L F
.49734 .78935 m .49243 .71365 L .49249 .71632 L 0 0 0 r
F
.49733 .78914 m .49243 .71365 L .49734 .78935 L F
.51012 .80816 m .50436 .83214 L .50219 .83182 L 1 1 0 r
F
.50725 .80645 m .51012 .80816 L .50219 .83182 L F
.50534 .77157 m .50438 .80443 L .5015 .80209 L F
.50193 .76748 m .50534 .77157 L .5015 .80209 L 1 .994 0 r
F
.50193 .76748 m .5015 .80209 L .49861 .79941 L F
.49856 .76303 m .50193 .76748 L .49861 .79941 L 1 .976 0 r
F
.49757 .79145 m .50289 .80155 L .50465 .82506 L .66 .306 0 r
F
.49741 .79069 m .49754 .79093 L .49757 .79145 L F
.49754 .79093 m .50289 .80155 L .49757 .79145 L F
.49716 .78563 m .49243 .71365 L .49736 .78957 L 0 0 0 r
F
.49689 .78167 m .49704 .78385 L .49716 .78563 L .787 .143 0 r
F
.49716 .78563 m .50289 .80155 L .49754 .79093 L .66 .306 0 r
F
.49716 .78563 m .49754 .79093 L .49741 .79069 L F
.49741 .79022 m .49739 .78987 L .49745 .79093 L 0 0 0 r
F
.49728 .7874 m .49739 .78987 L .49741 .79022 L F
.49728 .7874 m .49716 .78563 L .49739 .78987 L F
.49716 .78563 m .49736 .78957 L .49745 .79093 L F
.50363 .89876 m .50892 .90052 L .50345 .90556 L 1 1 0 r
F
.50755 .89189 m .50892 .90052 L .50559 .89941 L F
.50525 .89591 m .50559 .89941 L .50363 .89876 L F
.50755 .89189 m .50559 .89941 L .50525 .89591 L F
.50345 .90556 m .50091 .91052 L .49725 .90965 L .827 1 0 r
F
.49892 .9042 m .50345 .90556 L .49725 .90965 L .941 1 0 r
F
.50363 .89876 m .50345 .90556 L .49892 .9042 L 1 1 0 r
F
.49832 .89642 m .50363 .89876 L .49892 .9042 L F
.50155 .88864 m .50363 .89876 L .49832 .89642 L F
.51487 .83081 m .51689 .82998 L .50199 .84538 L .731 .405 0 r
F
.49842 .81195 m .50143 .82674 L .4995 .83351 L .73 .378 0 r
F
.50143 .82674 m .50556 .84708 L .50268 .84064 L F
.50143 .82674 m .50268 .84064 L .4995 .83351 L F
.50206 .89111 m .50476 .89037 L .50363 .89876 L 1 1 0 r
F
.50206 .88891 m .50476 .89037 L .50206 .89111 L F
.50476 .89037 m .50525 .89591 L .50363 .89876 L F
.49573 .79638 m .49512 .81859 L .49488 .80926 L F
.49573 .79638 m .49377 .82598 L .49374 .82288 L F
.48764 .67877 m .49044 .69685 L .48701 .69143 L 1 .783 0 r
F
.49573 .79638 m .49331 .82849 L .49107 .82715 L 1 1 0 r
F
.48701 .69143 m .49044 .69685 L .48966 .7172 L 1 .817 0 r
F
.49523 .75817 m .49573 .79638 L .49286 .79293 L 1 .958 0 r
F
.49195 .75278 m .49523 .75817 L .49286 .79293 L 1 .94 0 r
F
.49286 .79293 m .49573 .79638 L .49107 .82715 L 1 1 0 r
F
.49888 .83483 m .49755 .81439 L .49855 .84166 L 0 0 0 r
F
.49888 .83483 m .49855 .84166 L .49886 .85012 L F
.49755 .81439 m .48815 .67001 L .49698 .82207 L F
.49741 .79069 m .49251 .717 L .49777 .79927 L F
.49774 .79836 m .49777 .79927 L .49781 .79986 L F
.49741 .79069 m .49777 .79927 L .49774 .79836 L F
.497 .77343 m .49917 .76985 L .50029 .77754 L .877 .57 0 r
F
.50002 .84015 m .50104 .84085 L .50148 .84698 L .831 .494 0 r
F
.49986 .83663 m .50087 .83847 L .50002 .84015 L F
.50087 .83847 m .50283 .84208 L .50104 .84085 L F
.50087 .83847 m .50104 .84085 L .50002 .84015 L F
.49659 .77296 m .5009 .78176 L .49684 .77828 L .657 .314 0 r
F
.49684 .77471 m .5009 .78176 L .49659 .77296 L .877 .57 0 r
F
.49705 .77507 m .50029 .77754 L .50008 .78033 L F
.49251 .717 m .49254 .71917 L .49782 .8011 L 0 0 0 r
F
.49251 .717 m .49782 .8011 L .49781 .80052 L F
.49251 .717 m .4982 .80665 L .49805 .80358 L F
.49673 .77786 m .49659 .77296 L .49684 .77828 L .657 .314 0 r
F
.499 .8324 m .4995 .83351 L .49894 .83471 L .831 .494 0 r
F
.49894 .83362 m .49894 .83471 L .49888 .83483 L F
.499 .8324 m .49894 .83471 L .49894 .83362 L F
.49974 .83406 m .5007 .83621 L .49986 .83652 L F
.5007 .83621 m .50268 .84064 L .50083 .83794 L F
.5007 .83621 m .50083 .83794 L .49986 .83652 L F
.50268 .84064 m .50283 .84208 L .50087 .83847 L F
.49854 .8077 m .49729 .78853 L .49732 .78926 L 0 0 0 r
F
.50083 .83794 m .50087 .83847 L .49986 .83663 L .831 .494 0 r
F
.50083 .83794 m .49986 .83663 L .49986 .83652 L F
.49932 .81637 m .50038 .81608 L .50143 .82674 L .73 .378 0 r
F
.49842 .81195 m .49911 .81339 L .49932 .81637 L F
.49911 .81339 m .50038 .81608 L .49932 .81637 L F
.49832 .81142 m .48867 .65916 L .4885 .66373 L 0 0 0 r
F
.49842 .81195 m .49889 .82136 L .49873 .82256 L .73 .378 0 r
F
.49842 .81195 m .49873 .82256 L .49855 .81768 L F
.49842 .81195 m .49867 .82303 L .49837 .81331 L F
.49826 .80883 m .49824 .80751 L .4983 .80895 L F
.49824 .80751 m .49808 .80504 L .49832 .81142 L 0 0 0 r
F
.49808 .80504 m .48867 .65916 L .49832 .81142 L F
.49832 .81142 m .4885 .66373 L .49841 .82356 L F
.49836 .82687 m .4885 .66373 L .48815 .67001 L F
.4995 .83351 m .4996 .83614 L .49888 .83483 L .831 .494 0 r
F
.49888 .83483 m .49986 .83663 L .50002 .84015 L F
.49888 .83483 m .49841 .82356 L .49836 .82687 L 0 0 0 r
F
.49895 .83227 m .49841 .82356 L .49888 .83483 L F
.49888 .83483 m .49915 .83606 L .49886 .85432 L .831 .494 0 r
F
.49741 .79069 m .49834 .80778 L .49824 .80751 L .66 .306 0 r
F
.49741 .79069 m .49773 .79799 L .49807 .80337 L 0 0 0 r
F
.49969 .83859 m .5019 .84894 L .50053 .85706 L .831 .494 0 r
F
.5019 .84894 m .50532 .86489 L .50278 .86074 L F
.5019 .84894 m .50278 .86074 L .50053 .85706 L F
.49841 .82356 m .4885 .66373 L .49836 .82687 L 0 0 0 r
F
.49521 .7802 m .49716 .78563 L .49741 .79069 L .66 .306 0 r
F
.49418 .76804 m .49622 .77282 L .49654 .77713 L .657 .314 0 r
F
.49651 .77674 m .49648 .7763 L .49654 .77713 L .787 .143 0 r
F
.49621 .77291 m .49616 .77208 L .49652 .7768 L F
.49615 .7711 m .49689 .78167 L .49704 .78399 L F
.49605 .76955 m .49615 .77107 L .49615 .7711 L F
.49615 .77107 m .49689 .78167 L .49615 .7711 L F
.49616 .77113 m .49704 .78399 L .4967 .77919 L F
.49605 .76955 m .49615 .7711 L .49616 .77113 L F
.49615 .7711 m .49704 .78399 L .49616 .77113 L F
.49418 .76804 m .49616 .77208 L .49622 .77282 L .657 .314 0 r
F
.49605 .77096 m .49616 .77208 L .49634 .77479 L .964 .177 0 r
F
.496 .7726 m .49616 .77208 L .49418 .76804 L .877 .57 0 r
F
.49424 .74703 m .49614 .77215 L .49562 .76749 L .964 .177 0 r
F
.49614 .77215 m .49634 .77479 L .49609 .7723 L F
.49614 .77215 m .49609 .7723 L .49562 .76749 L F
.49609 .7723 m .49634 .77479 L .49601 .77258 L F
.49616 .773 m .49616 .77208 L .496 .7726 L .877 .57 0 r
F
.49621 .77313 m .49616 .77208 L .49616 .773 L F
.49616 .77208 m .49616 .77139 L .49651 .77674 L .787 .143 0 r
F
.49622 .77282 m .49616 .77208 L .49624 .77288 L .657 .314 0 r
F
.49652 .77675 m .49616 .77131 L .49616 .77126 L .787 .143 0 r
F
.49648 .7763 m .496 .76896 L .49652 .77675 L F
.49664 .77852 m .49716 .78563 L .49521 .7802 L .657 .314 0 r
F
.49662 .77819 m .49697 .78318 L .49664 .77843 L .787 .143 0 r
F
.49616 .77122 m .49686 .78153 L .49662 .77819 L F
.49686 .78153 m .49697 .78318 L .49662 .77819 L F
.49689 .78167 m .49716 .78563 L .49704 .78399 L F
.49067 .68719 m .49077 .68846 L .49704 .78385 L F
.49067 .68719 m .49704 .78385 L .49689 .78167 L F
.49605 .76955 m .49067 .68719 L .49689 .78167 L F
.49684 .77828 m .49716 .78563 L .49664 .77852 L .657 .314 0 r
F
.49616 .77113 m .4974 .78939 L .49616 .77122 L .787 .143 0 r
F
.49851 .80703 m .49728 .7874 L .49745 .79093 L 0 0 0 r
F
.4974 .78939 m .49742 .78965 L .4974 .78939 L .787 .143 0 r
F
.4974 .78939 m .4974 .78939 L .49616 .77122 L F
.49635 .77423 m .49605 .76955 L .49642 .77516 L F
.49652 .7768 m .48895 .66242 L .48938 .66758 L F
.49624 .77288 m .49659 .77296 L .49673 .77786 L .657 .314 0 r
F
.49418 .76804 m .49654 .77713 L .49521 .7802 L F
.49654 .77713 m .49665 .77851 L .49664 .77852 L F
.49654 .77713 m .49664 .77852 L .49521 .7802 L F
.49745 .79093 m .49733 .78914 L .49734 .78935 L 0 0 0 r
F
.49766 .79429 m .49654 .77713 L .49788 .79735 L .787 .143 0 r
F
.49654 .77713 m .49635 .77423 L .49657 .77755 L F
.49654 .77713 m .49657 .77755 L .49788 .79735 L F
.4967 .77958 m .49621 .77291 L .49652 .7768 L F
.49824 .80751 m .49895 .80946 L .49842 .81195 L .73 .378 0 r
F
.49895 .80946 m .49927 .81374 L .49842 .81195 L F
.49769 .7952 m .49773 .796 L .49797 .79971 L 0 0 0 r
F
.49773 .796 m .49807 .80337 L .49797 .79971 L F
.50093 .85771 m .50241 .86014 L .50129 .86702 L .937 .634 0 r
F
.49839 .80437 m .4984 .80462 L .50213 .86151 L 0 0 0 r
F
.49832 .80334 m .49839 .80437 L .49949 .82104 L .787 .143 0 r
F
.50241 .86014 m .50254 .86178 L .50129 .86702 L .937 .634 0 r
F
.50278 .86074 m .50321 .866 L .50287 .86618 L F
.50254 .86178 m .50287 .86618 L .50129 .86702 L F
.50278 .86074 m .50287 .86618 L .50254 .86178 L F
.50371 .87746 m .50532 .86489 L .50393 .87843 L F
.50129 .86702 m .50287 .86618 L .50371 .87746 L F
.50287 .86618 m .50532 .86489 L .50371 .87746 L F
.49766 .79429 m .49788 .79735 L .49917 .8168 L .787 .143 0 r
F
.50213 .86151 m .4984 .80462 L .49851 .80703 L 0 0 0 r
F
.49908 .81561 m .49917 .8168 L .50174 .85556 L .787 .143 0 r
F
.49908 .81561 m .50174 .85556 L .50255 .8678 L F
.49905 .81519 m .49908 .81561 L .50255 .8678 L F
.50117 .84717 m .49851 .80703 L .49854 .8077 L 0 0 0 r
F
.50382 .87892 m .50401 .88128 L .50203 .88721 L 1 .895 0 r
F
.50382 .87892 m .50203 .88721 L .50202 .88665 L F
.50439 .88014 m .50539 .89072 L .50155 .88864 L F
.49797 .79971 m .49807 .80337 L .50068 .84448 L 0 0 0 r
F
.50134 .88776 m .50377 .87824 L .50155 .88864 L 1 .785 0 r
F
.50115 .87522 m .50377 .87824 L .50134 .88776 L F
.50377 .87824 m .50382 .87892 L .50155 .88864 L F
.49755 .81439 m .49698 .82207 L .4988 .85337 L 0 0 0 r
F
.49873 .85597 m .49973 .86027 L .49848 .86555 L .937 .634 0 r
F
.49915 .83606 m .49969 .83859 L .49975 .85577 L .831 .494 0 r
F
.49915 .83606 m .49975 .85577 L .49886 .85432 L F
.49895 .83227 m .499 .8324 L .49888 .83483 L F
.49955 .84504 m .49895 .83227 L .49888 .83483 L 0 0 0 r
F
.49931 .85848 m .50093 .85771 L .50129 .86702 L .937 .634 0 r
F
.49898 .85705 m .49934 .85717 L .49931 .85848 L F
.49934 .85717 m .50093 .85771 L .49931 .85848 L F
.49973 .86027 m .50075 .86468 L .49995 .87384 L F
.50075 .86468 m .50393 .87843 L .50115 .87522 L F
.50075 .86468 m .50115 .87522 L .49995 .87384 L F
.49887 .81645 m .49894 .81837 L .49908 .82059 L 0 0 0 r
F
.49901 .81866 m .49908 .82059 L .50431 .90167 L F
.49887 .81645 m .49908 .82059 L .49901 .81866 L F
.50431 .90167 m .49982 .83406 L .50345 .90498 L F
.49982 .83406 m .49897 .82131 L .49977 .83628 L F
.49902 .8562 m .49936 .85646 L .49898 .85705 L .937 .634 0 r
F
.49936 .85646 m .50093 .85771 L .49934 .85717 L F
.49936 .85646 m .49934 .85717 L .49898 .85705 L F
.49889 .82136 m .4995 .83351 L .499 .8324 L .73 .378 0 r
F
.49897 .82131 m .49895 .83227 L .49963 .84331 L 0 0 0 r
F
.49886 .85432 m .50093 .85771 L .49873 .85597 L .937 .634 0 r
F
.49969 .83859 m .50053 .85706 L .49975 .85577 L .831 .494 0 r
F
.49977 .83628 m .49963 .84331 L .50345 .90498 L 0 0 0 r
F
.49986 .83652 m .49986 .83663 L .4996 .83614 L .831 .494 0 r
F
.4995 .83351 m .49974 .83406 L .4996 .83614 L F
.49974 .83406 m .49986 .83652 L .4996 .83614 L F
.49897 .82131 m .49963 .84331 L .49977 .83628 L 0 0 0 r
F
.49982 .83406 m .49977 .83628 L .50345 .90498 L F
.50345 .90498 m .49963 .84331 L .49955 .84504 L F
.49963 .84331 m .49895 .83227 L .49955 .84504 L F
.49873 .85597 m .49902 .8562 L .49898 .85705 L .937 .634 0 r
F
.49871 .85588 m .48815 .67001 L .48764 .67877 L .093 .012 0 r
F
.49871 .85588 m .49886 .85432 L .49873 .85597 L .937 .634 0 r
F
.49796 .85498 m .49873 .85597 L .49726 .87074 L F
.49873 .85597 m .49848 .86555 L .49726 .87074 L F
.49973 .86027 m .49995 .87384 L .49831 .87196 L F
.49848 .86555 m .49831 .87196 L .49726 .87074 L F
.49973 .86027 m .49831 .87196 L .49848 .86555 L F
.49807 .87412 m .50115 .87522 L .50134 .88776 L 1 .785 0 r
F
.49726 .87074 m .49831 .87196 L .49807 .87412 L F
.49831 .87196 m .50115 .87522 L .49807 .87412 L F
.49915 .83988 m .49929 .86178 L .49935 .8629 L 0 0 0 r
F
.49669 .88903 m .50155 .88864 L .49832 .89642 L 1 .938 0 r
F
.49686 .88805 m .50155 .88864 L .49669 .88903 L F
.49706 .88493 m .50155 .88864 L .49647 .888 L F
.50202 .88665 m .50203 .88721 L .50155 .88864 L 1 .895 0 r
F
.50155 .88864 m .50206 .88891 L .50206 .89111 L 1 1 0 r
F
.49726 .87074 m .50077 .88538 L .49551 .88366 L 1 .785 0 r
F
.50077 .88538 m .50155 .88864 L .50128 .88841 L F
.50077 .88538 m .50128 .88841 L .49551 .88366 L F
.49551 .88366 m .49706 .88493 L .49647 .888 L 1 .938 0 r
F
.49647 .888 m .49686 .88805 L .49669 .88903 L F
.49892 .9042 m .49725 .90965 L .49356 .90856 L .941 1 0 r
F
.49488 .80926 m .49512 .81859 L .49377 .82598 L 1 1 0 r
F
.49374 .82288 m .49377 .82598 L .49331 .82849 L F
.48701 .69143 m .48966 .7172 L .48631 .71046 L 1 .817 0 r
F
.48966 .7172 m .49195 .75278 L .48871 .74662 L 1 .874 0 r
F
.48631 .71046 m .48966 .7172 L .48871 .74662 L 1 .857 0 r
F
.49195 .75278 m .49286 .79293 L .49 .78896 L 1 .94 0 r
F
.48871 .74662 m .49195 .75278 L .49 .78896 L 1 .922 0 r
F
.49139 .83263 m .49796 .85498 L .48421 .67349 L 1 .692 0 r
F
.48728 .74145 m .48421 .67349 L .48669 .73897 L F
.49886 .85432 m .48815 .67001 L .49871 .85588 L .093 .012 0 r
F
.49367 .76635 m .49418 .76804 L .49451 .77199 L 0 0 0 r
F
.49334 .76704 m .49451 .77199 L .49521 .7802 L F
.49302 .76476 m .49451 .77199 L .49334 .76704 L F
.48669 .73897 m .48421 .67349 L .48612 .73666 L .174 .025 0 r
F
.48421 .67349 m .48764 .67877 L .48701 .69143 L 1 .751 0 r
F
.49796 .85498 m .48764 .67877 L .48421 .67349 L .093 .012 0 r
F
.50199 .90826 m .49889 .85872 L .49796 .85498 L F
.49871 .85588 m .48764 .67877 L .49796 .85498 L F
.49858 .85529 m .49871 .85588 L .49796 .85498 L .937 .634 0 r
F
.49871 .85588 m .49873 .85597 L .49796 .85498 L F
.49889 .85872 m .49871 .85588 L .49796 .85498 L .093 .012 0 r
F
.49157 .83047 m .49354 .83734 L .49796 .85498 L .829 .463 0 r
F
.49354 .83734 m .49804 .85299 L .49796 .85498 L F
.48536 .71077 m .49408 .76909 L .49302 .76476 L 0 0 0 r
F
.49408 .76909 m .49451 .77199 L .49302 .76476 L F
.48752 .7609 m .48669 .73897 L .48684 .76043 L .174 .025 0 r
F
.48669 .73897 m .48612 .73666 L .48684 .76043 L F
.4938 .76942 m .49546 .77231 L .49418 .76804 L .877 .57 0 r
F
.49546 .77231 m .49587 .77302 L .49418 .76804 L F
.48536 .71077 m .49418 .76804 L .49367 .76635 L 0 0 0 r
F
.49135 .83304 m .48972 .79628 L .49059 .84217 L 1 .692 0 r
F
.48972 .79628 m .48728 .74145 L .48922 .80063 L F
.48972 .79628 m .48922 .80063 L .49059 .84217 L F
.49153 .78028 m .49662 .80308 L .49777 .82965 L .459 .097 0 r
F
.49136 .83213 m .49056 .81438 L .49135 .83304 L 1 .692 0 r
F
.49056 .81438 m .48728 .74145 L .49054 .81472 L F
.49056 .81438 m .49054 .81472 L .49135 .83304 L F
.49141 .80349 m .49777 .82965 L .49804 .85299 L .656 .279 0 r
F
.4891 .7863 m .49172 .79941 L .49141 .80349 L F
.49172 .79941 m .49777 .82965 L .49141 .80349 L F
.48728 .74145 m .48669 .73897 L .49059 .84217 L 1 .692 0 r
F
.4874 .74758 m .49206 .77563 L .49153 .78028 L .459 .097 0 r
F
.49206 .77563 m .49662 .80308 L .49153 .78028 L F
.48603 .72101 m .49215 .76843 L .4874 .74758 L .26 .048 0 r
F
.49215 .76843 m .49662 .80308 L .49206 .77563 L F
.49215 .76843 m .49206 .77563 L .4874 .74758 L F
.49139 .83263 m .49136 .83213 L .49135 .83304 L 1 .692 0 r
F
.49139 .83263 m .49059 .84217 L .49114 .85687 L F
.49031 .82564 m .49159 .83017 L .49157 .83047 L .829 .463 0 r
F
.49159 .83017 m .49804 .85299 L .49157 .83047 L F
.49139 .83263 m .49796 .85498 L .49726 .87074 L F
.49031 .82564 m .49796 .85498 L .49139 .83263 L F
.49227 .85216 m .49796 .85498 L .49139 .83263 L 1 .692 0 r
F
.49466 .9054 m .50199 .90826 L .49796 .85498 L F
.49466 .9054 m .49796 .85498 L .49227 .85216 L F
.49139 .83263 m .49114 .85687 L .49156 .86796 L F
.49139 .83263 m .49156 .86796 L .49211 .86463 L F
.49313 .87145 m .49139 .83263 L .49234 .87481 L F
.4954 .88348 m .49604 .88759 L .49633 .89094 L 0 0 0 r
F
.49141 .85145 m .49604 .88759 L .4954 .88348 L F
.49189 .8767 m .49156 .86796 L .49177 .87723 L .174 .025 0 r
F
.49156 .86796 m .49114 .85687 L .49142 .86888 L F
.49134 .83237 m .49139 .83263 L .49114 .85687 L .829 .463 0 r
F
.49036 .84303 m .49076 .84628 L .49039 .85516 L F
.49031 .82564 m .49076 .84628 L .49036 .84303 L F
.49031 .82564 m .49134 .83237 L .49076 .84628 L F
.49099 .85829 m .49099 .85816 L .49098 .85842 L .174 .025 0 r
F
.49039 .85516 m .49114 .85687 L .49098 .85842 L .974 .642 0 r
F
.49111 .86146 m .49099 .85829 L .49098 .85842 L .174 .025 0 r
F
.49039 .85516 m .49098 .85842 L .48941 .87477 L .974 .642 0 r
F
.49134 .83237 m .49114 .85687 L .49039 .85516 L .829 .463 0 r
F
.48211 .7623 m .49031 .82564 L .49039 .85516 L .752 .342 0 r
F
.48472 .79788 m .49633 .89094 L .48728 .85725 L 0 0 0 r
F
.48728 .85725 m .49633 .89094 L .49627 .89613 L .079 .027 0 r
F
.50345 .90498 m .50083 .86477 L .50199 .90826 L 0 0 0 r
F
.50083 .86477 m .50031 .86783 L .50199 .90826 L F
.50199 .90826 m .49981 .87076 L .49968 .87141 L .093 .012 0 r
F
.49991 .85807 m .49935 .8629 L .50199 .90826 L 0 0 0 r
F
.49633 .89094 m .50431 .90167 L .49627 .89613 L .321 .284 0 r
F
.50431 .90167 m .49908 .82059 L .49913 .82371 L 0 0 0 r
F
.50066 .84283 m .50068 .84448 L .50431 .90167 L F
.49773 .79799 m .49787 .80077 L .50431 .90167 L F
.5046 .89874 m .49741 .79069 L .5041 .89827 L F
.49633 .89094 m .5046 .89874 L .50431 .90167 L .321 .284 0 r
F
.49604 .88759 m .5046 .89874 L .49633 .89094 L 0 .06 0 r
F
.49568 .89092 m .49665 .89158 L .49604 .88759 L 0 .043 0 r
F
.49604 .88759 m .50435 .89677 L .5046 .89874 L 0 .06 0 r
F
.49665 .89158 m .50435 .89677 L .49604 .88759 L 0 .043 0 r
F
.49112 .84861 m .49604 .88759 L .49141 .85145 L 0 0 0 r
F
.48582 .80654 m .49604 .88759 L .48596 .80777 L F
.48001 .68721 m .4891 .7863 L .48087 .71579 L .628 .217 0 r
F
.48087 .71579 m .49031 .82564 L .48211 .7623 L .684 .27 0 r
F
.48087 .71579 m .4891 .7863 L .49031 .82564 L F
.4891 .7863 m .49804 .85299 L .49031 .82564 L .656 .279 0 r
F
.48061 .70495 m .49604 .88759 L .48472 .79788 L 1 .211 0 r
F
.49094 .82719 m .49568 .89092 L .49604 .88759 L F
.48061 .70495 m .49012 .82239 L .49094 .82719 L F
.49012 .82239 m .49568 .89092 L .49094 .82719 L F
.50083 .86477 m .49905 .8374 L .50031 .86783 L 0 0 0 r
F
.49968 .87141 m .49886 .85432 L .49871 .85588 L .093 .012 0 r
F
.49981 .87076 m .49886 .85432 L .49968 .87141 L F
.49915 .83988 m .49935 .8629 L .49991 .85807 L 0 0 0 r
F
.49905 .8374 m .4991 .84206 L .49915 .83988 L F
.4991 .84206 m .49929 .86178 L .49915 .83988 L F
.49804 .85299 m .49858 .85529 L .49796 .85498 L .937 .634 0 r
F
.49804 .85299 m .49886 .85432 L .49871 .85588 L F
.49888 .8505 m .4988 .85337 L .49886 .85432 L 0 0 0 r
F
.49896 .85288 m .49886 .85432 L .49929 .86178 L F
.49888 .8505 m .49886 .85432 L .49896 .85288 L F
.49755 .81439 m .4988 .85337 L .49888 .8505 L F
.49913 .82371 m .49831 .80864 L .49846 .81362 L F
.49908 .82059 m .49831 .80864 L .49913 .82371 L F
.49797 .79971 m .50068 .84448 L .50066 .84283 L F
.50377 .87824 m .50393 .87843 L .50382 .87892 L 1 .785 0 r
F
.50213 .86119 m .49949 .82104 L .50213 .86151 L 0 0 0 r
F
.49944 .82041 m .49949 .82104 L .50055 .83719 L .787 .143 0 r
F
.50052 .83683 m .50055 .83719 L .5046 .89874 L F
.49944 .82041 m .50055 .83719 L .50052 .83683 L F
.5046 .89874 m .50117 .847 L .50117 .84717 L 0 0 0 r
F
.50117 .847 m .49851 .80703 L .50117 .84717 L F
.49851 .80703 m .49729 .78853 L .49854 .8077 L F
.49766 .79429 m .49917 .8168 L .49905 .81519 L .787 .143 0 r
F
.50227 .8649 m .49885 .81251 L .50255 .8678 L F
.49885 .81251 m .49766 .79429 L .49905 .81519 L F
.49885 .81251 m .49905 .81519 L .50255 .8678 L F
.49949 .82104 m .49839 .80437 L .4995 .82129 L 0 0 0 r
F
.49832 .80334 m .49949 .82104 L .49944 .82041 L .787 .143 0 r
F
.50241 .86014 m .50278 .86074 L .50254 .86178 L .937 .634 0 r
F
.50278 .86074 m .50532 .86489 L .50321 .866 L F
.49885 .81251 m .49651 .77674 L .49654 .77713 L .787 .143 0 r
F
.50435 .89677 m .49884 .81233 L .49885 .81251 L F
.49884 .81233 m .49651 .77674 L .49885 .81251 L F
.49949 .82104 m .4995 .82129 L .50213 .86151 L 0 0 0 r
F
.4984 .80462 m .49728 .7874 L .49851 .80703 L F
.49686 .78188 m .49742 .78965 L .50113 .84607 L .787 .143 0 r
F
.5046 .89874 m .50213 .86119 L .50213 .86151 L 0 0 0 r
F
.50103 .84486 m .50113 .84607 L .5046 .89874 L .787 .143 0 r
F
.49686 .78188 m .50113 .84607 L .50103 .84486 L F
.50393 .87843 m .50439 .88014 L .50401 .88128 L 1 .895 0 r
F
.50393 .87843 m .50401 .88128 L .50382 .87892 L F
.50439 .88014 m .50755 .89189 L .50539 .89072 L F
.49741 .79069 m .49807 .80337 L .49769 .7952 L 0 0 0 r
F
.49781 .80052 m .49782 .8011 L .49894 .81837 L F
.49773 .79799 m .49781 .79986 L .49787 .80077 L F
.49741 .79069 m .49824 .80751 L .49662 .80308 L .66 .306 0 r
F
.49521 .7802 m .49741 .79069 L .49662 .80308 L F
.50068 .84058 m .49634 .77479 L .4967 .77958 L .787 .143 0 r
F
.50435 .89677 m .50061 .83979 L .50068 .84058 L F
.50061 .83979 m .49634 .77479 L .50068 .84058 L F
.49634 .77479 m .49621 .77291 L .4967 .77958 L F
.49895 .80946 m .50465 .82506 L .49927 .81374 L .73 .378 0 r
F
.49623 .77364 m .49684 .77471 L .49621 .77313 L .877 .57 0 r
F
.49654 .77713 m .49648 .7763 L .49652 .77675 L .787 .143 0 r
F
.49635 .77423 m .49658 .77766 L .49658 .77765 L F
.49654 .77713 m .49624 .77288 L .49673 .77786 L .657 .314 0 r
F
.49623 .77364 m .497 .77343 L .49705 .77507 L .877 .57 0 r
F
.49616 .77352 m .49623 .77364 L .49616 .773 L F
.49601 .77258 m .49634 .77479 L .49667 .77982 L .964 .177 0 r
F
.49635 .77715 m .49667 .77982 L .49737 .79058 L F
.49601 .77258 m .49667 .77982 L .49635 .77715 L F
.49597 .77269 m .49737 .79058 L .49684 .78555 L F
.49562 .76749 m .49601 .77258 L .49597 .77269 L F
.49601 .77258 m .49737 .79058 L .49597 .77269 L F
.49616 .77352 m .49616 .773 L .496 .7726 L .877 .57 0 r
F
.49592 .77286 m .496 .7726 L .49418 .76804 L F
.49587 .77302 m .49592 .77286 L .49418 .76804 L F
.49587 .77302 m .49424 .74703 L .49616 .77551 L .964 .177 0 r
F
.49616 .77352 m .496 .7726 L .49592 .77286 L .877 .57 0 r
F
.49587 .77302 m .49616 .77352 L .49592 .77286 L F
.49587 .77302 m .49613 .77234 L .49623 .77364 L F
.49251 .717 m .48867 .65916 L .49254 .71917 L 0 0 0 r
F
.48864 .65965 m .4871 .66426 L .48551 .66342 L 1 1 0 r
F
.48672 .65872 m .48864 .65965 L .48551 .66342 L F
.48637 .65057 m .48884 .65152 L .48697 .65443 L F
.49587 .77302 m .4879 .65221 L .48837 .65359 L .964 .177 0 r
F
.4938 .76942 m .49573 .77183 L .49587 .77302 L .877 .57 0 r
F
.49662 .80308 m .49824 .80751 L .49826 .80883 L .73 .378 0 r
F
.49832 .81142 m .49841 .82356 L .49895 .83227 L 0 0 0 r
F
.49837 .81331 m .49867 .82303 L .49777 .82965 L .73 .378 0 r
F
.49855 .81768 m .49873 .82256 L .49867 .82303 L F
.49889 .82136 m .499 .8324 L .49777 .82965 L F
.49662 .80308 m .49842 .81195 L .49777 .82965 L F
.49897 .82131 m .49832 .81142 L .49895 .83227 L 0 0 0 r
F
.49662 .80308 m .4983 .80895 L .49832 .81142 L .73 .378 0 r
F
.4938 .76942 m .49547 .76955 L .49573 .77184 L .877 .57 0 r
F
.50361 .89619 m .49545 .76955 L .49587 .77302 L .964 .177 0 r
F
.49545 .76955 m .4879 .65221 L .49587 .77302 L F
.49573 .77183 m .49573 .77184 L .49587 .77302 L .877 .57 0 r
F
.49573 .77184 m .49613 .77234 L .49587 .77302 L F
.49618 .77214 m .49659 .77296 L .49624 .77288 L .657 .314 0 r
F
.49623 .77364 m .49621 .77313 L .49616 .773 L .877 .57 0 r
F
.49616 .77208 m .49618 .77214 L .49624 .77288 L .657 .314 0 r
F
.49684 .77471 m .49619 .77219 L .49621 .77313 L .877 .57 0 r
F
.49619 .77219 m .49616 .77208 L .49621 .77313 L F
.49684 .77471 m .49659 .77296 L .49618 .77214 L F
.49684 .77471 m .49618 .77214 L .49619 .77219 L F
.49613 .77234 m .497 .77343 L .49623 .77364 L F
.49664 .77843 m .49742 .78965 L .49686 .78188 L .787 .143 0 r
F
.49697 .78318 m .49742 .78965 L .49664 .77843 L F
.49605 .76955 m .49616 .77113 L .49616 .77122 L F
.49619 .77219 m .49618 .77214 L .49616 .77208 L .877 .57 0 r
F
.49594 .7685 m .49249 .71632 L .49477 .75099 L 0 0 0 r
F
.49595 .7686 m .49249 .71632 L .49594 .7685 L F
.49616 .77208 m .48895 .66242 L .49616 .77139 L .787 .143 0 r
F
.49616 .77208 m .49651 .77674 L .49652 .7768 L F
.49622 .77282 m .49624 .77288 L .49654 .77713 L .657 .314 0 r
F
.49562 .76749 m .49609 .7723 L .49601 .77258 L .964 .177 0 r
F
.49616 .77126 m .496 .76896 L .49605 .76955 L .787 .143 0 r
F
.49616 .77131 m .496 .76896 L .49616 .77126 L F
.49832 .81142 m .4983 .80895 L .49842 .81195 L .73 .378 0 r
F
.49846 .81362 m .49824 .80751 L .49832 .81142 L 0 0 0 r
F
.49831 .80864 m .49824 .80751 L .49846 .81362 L F
.49777 .82965 m .49895 .83227 L .49888 .83483 L .831 .494 0 r
F
.4967 .77919 m .49704 .78399 L .49742 .78965 L .787 .143 0 r
F
.50268 .84064 m .50087 .83847 L .50083 .83794 L .831 .494 0 r
F
.49839 .80437 m .49728 .7874 L .4984 .80462 L 0 0 0 r
F
.49704 .78399 m .49716 .78563 L .49839 .80437 L .787 .143 0 r
F
.49704 .78399 m .49839 .80437 L .49832 .80334 L F
.50268 .84064 m .50556 .84708 L .50283 .84208 L .831 .494 0 r
F
.49684 .78555 m .49737 .79058 L .50435 .89677 L .964 .177 0 r
F
.49658 .77765 m .49789 .79741 L .49788 .79735 L .787 .143 0 r
F
.49658 .77766 m .49789 .79741 L .49658 .77765 L F
.49424 .74703 m .49525 .75818 L .49616 .77208 L .964 .177 0 r
F
.49424 .74703 m .49616 .77208 L .49605 .77096 L F
.51296 .80956 m .50651 .83226 L .50436 .83214 L 1 1 0 r
F
.51012 .80816 m .51296 .80956 L .50436 .83214 L F
.50143 .82674 m .50465 .82506 L .50556 .84708 L .73 .378 0 r
F
.50038 .81608 m .50465 .82506 L .50143 .82674 L F
.49813 .80487 m .49894 .81837 L .49887 .81645 L 0 0 0 r
F
.49805 .80358 m .49814 .80511 L .49813 .80487 L F
.49814 .80511 m .49894 .81837 L .49813 .80487 L F
.4982 .80665 m .49894 .81837 L .49805 .80358 L F
.497 .77343 m .50029 .77754 L .49705 .77507 L .877 .57 0 r
F
.49788 .79735 m .50207 .86051 L .50206 .86045 L .787 .143 0 r
F
.49789 .79741 m .50207 .86051 L .49788 .79735 L F
.49672 .7844 m .49676 .78452 L .49684 .78555 L .964 .177 0 r
F
.49639 .78133 m .49676 .78452 L .49672 .7844 L F
.49639 .78133 m .49587 .77302 L .49676 .78452 L F
.49587 .77302 m .49616 .77551 L .49684 .78555 L F
.49573 .77184 m .49689 .76967 L .497 .77343 L .877 .57 0 r
F
.49547 .76955 m .49689 .76967 L .49573 .77184 L F
.49689 .76967 m .49917 .76985 L .497 .77343 L F
.49635 .77423 m .49642 .77516 L .49792 .79791 L .787 .143 0 r
F
.49789 .79741 m .49792 .79791 L .50207 .86051 L F
.49635 .77423 m .49792 .79791 L .49789 .79741 L F
.50148 .84698 m .50283 .84208 L .50519 .86428 L .831 .494 0 r
F
.50104 .84085 m .50283 .84208 L .50148 .84698 L F
.50361 .89619 m .49639 .78133 L .50435 .89677 L .964 .177 0 r
F
.49639 .78133 m .49684 .78555 L .50435 .89677 L F
.50519 .86428 m .50556 .84708 L .50532 .86489 L .831 .494 0 r
F
.50283 .84208 m .50556 .84708 L .50519 .86428 L F
.49777 .82965 m .49888 .83483 L .49804 .85299 L F
.49888 .83483 m .49886 .85432 L .49804 .85299 L F
.49905 .8374 m .49888 .83483 L .49929 .86178 L 0 0 0 r
F
.49888 .83483 m .49886 .85012 L .49929 .86178 L F
.50008 .78033 m .50029 .77754 L .5009 .78176 L .877 .57 0 r
F
.49424 .74703 m .48837 .65359 L .49525 .75818 L .964 .177 0 r
F
.50476 .89037 m .50755 .89189 L .50525 .89591 L 1 1 0 r
F
.50206 .86045 m .50207 .86051 L .5046 .89874 L .787 .143 0 r
F
.50435 .89677 m .50227 .8649 L .5046 .89874 L F
.50227 .8649 m .50255 .8678 L .5046 .89874 L F
.49757 .79145 m .49768 .79194 L .49778 .79441 L .66 .306 0 r
F
.49768 .79194 m .50465 .82506 L .49895 .80946 L F
.49605 .76955 m .48861 .65568 L .48865 .6562 L .787 .143 0 r
F
.496 .76896 m .48861 .65568 L .49605 .76955 L F
.49684 .77828 m .5009 .78176 L .50289 .80155 L .657 .314 0 r
F
.49654 .77713 m .49684 .77828 L .49665 .77851 L F
.49684 .77828 m .50289 .80155 L .49716 .78563 L F
.48895 .66242 m .48837 .65359 L .48938 .66758 L .787 .143 0 r
F
.48865 .6562 m .48861 .65568 L .48863 .65586 L F
.49067 .68719 m .48863 .65586 L .49077 .68846 L F
.48798 .87962 m .49572 .90108 L .48789 .89152 L .448 .233 0 r
F
.48789 .89152 m .49466 .9054 L .48729 .89929 L .725 .553 0 r
F
.48789 .89152 m .49572 .90108 L .49466 .9054 L F
.48368 .91387 m .48799 .88599 L .48905 .90143 L 1 .756 0 r
F
.48125 .91352 m .4826 .91309 L .48368 .91387 L .99 .845 0 r
F
.47937 .91393 m .48138 .91919 L .48167 .91938 L .829 .107 0 r
F
.48138 .91919 m .4826 .91309 L .48368 .91387 L 1 .756 0 r
F
.482 .90136 m .48452 .90826 L .48202 .90199 L .944 .693 0 r
F
.4829 .91248 m .48316 .91261 L .48302 .9128 L 1 1 0 r
F
.4826 .91309 m .48799 .88599 L .48368 .91387 L 1 .756 0 r
F
.4826 .91309 m .484 .91264 L .48368 .91387 L .99 .845 0 r
F
.48405 .91316 m .48395 .91384 L .48379 .91386 L 1 .756 0 r
F
.48457 .9118 m .48905 .90143 L .48438 .9128 L F
.484 .91264 m .48901 .91104 L .48368 .91387 L .99 .845 0 r
F
.48395 .91384 m .48485 .91398 L .48386 .91448 L .796 .819 0 r
F
.48468 .91484 m .4898 .91708 L .48456 .91559 L F
.48464 .91507 m .48456 .91559 L .48459 .91515 L 1 .97 0 r
F
.48459 .91515 m .48456 .91559 L .48176 .92015 L F
.48492 .91642 m .4849 .91656 L .48483 .91665 L 1 1 0 r
F
.48521 .91613 m .48458 .91731 L .48463 .91694 L F
.48672 .91798 m .49365 .91965 L .49152 .92116 L .744 .97 0 r
F
.48492 .91642 m .4896 .91877 L .48458 .91731 L .669 .794 0 r
F
.48492 .91642 m .48483 .91665 L .48163 .92111 L 1 1 0 r
F
.48176 .92015 m .48492 .91642 L .48163 .92111 L F
.4847 .91563 m .48504 .91573 L .48476 .91633 L .669 .794 0 r
F
.48504 .91573 m .4898 .91708 L .48493 .91636 L F
.48504 .91573 m .48493 .91636 L .48476 .91633 L F
.48492 .91642 m .4898 .91708 L .4896 .91877 L F
.48493 .91636 m .4898 .91708 L .48492 .91642 L F
.48458 .91731 m .48482 .91701 L .4847 .91802 L 1 1 0 r
F
.48482 .91701 m .48488 .91775 L .4847 .91802 L F
.48463 .9176 m .48473 .91735 L .48466 .91778 L .666 .832 0 r
F
.48463 .91694 m .48458 .91731 L .48163 .92111 L 1 1 0 r
F
.48462 .91816 m .48422 .91887 L .48128 .92208 L F
.4847 .91802 m .4896 .91877 L .48904 .92019 L .666 .832 0 r
F
.48471 .91799 m .4896 .91877 L .4847 .91802 L F
.48665 .91804 m .48672 .91798 L .48664 .91805 L .803 .524 0 r
F
.48473 .91735 m .4896 .91877 L .48463 .91798 L .666 .832 0 r
F
.48414 .9195 m .48444 .91914 L .48442 .91925 L 1 .919 0 r
F
.48405 .91945 m .48417 .91925 L .48411 .91948 L .697 .888 0 r
F
.48417 .91925 m .48416 .91938 L .48411 .91948 L F
.48395 .9194 m .48409 .91947 L .48393 .91947 L F
.48409 .91947 m .48414 .9195 L .48408 .9195 L F
.48411 .91948 m .48415 .91949 L .48414 .9195 L F
.48128 .92208 m .48422 .91887 L .48414 .9195 L 1 .919 0 r
F
.48417 .91925 m .48438 .91891 L .48416 .91938 L .697 .888 0 r
F
.48422 .91887 m .48438 .91891 L .48405 .91945 L F
.48163 .92111 m .48438 .91834 L .48128 .92208 L 1 1 0 r
F
.48438 .91834 m .48501 .91771 L .48433 .9185 L F
.48438 .91834 m .48433 .9185 L .48128 .92208 L F
.47888 .91309 m .48138 .91919 L .47937 .91393 L .829 .107 0 r
F
.48407 .91963 m .48388 .91996 L .48355 .92027 L 1 .919 0 r
F
.48407 .91963 m .48355 .92027 L .48393 .91978 L F
.48442 .91924 m .48388 .91996 L .48407 .91963 L F
.48414 .9195 m .48813 .92146 L .48355 .92027 L .697 .888 0 r
F
.48393 .91978 m .48355 .92027 L .48283 .92097 L 1 .919 0 r
F
.48415 .91949 m .48904 .92019 L .48414 .9195 L .697 .888 0 r
F
.48438 .91891 m .48904 .92019 L .48411 .91948 L F
.4833 .92084 m .48362 .9205 L .48357 .92061 L .803 .524 0 r
F
.48326 .92082 m .48335 .92071 L .48329 .92083 L .721 .932 0 r
F
.48335 .92071 m .48331 .92081 L .48329 .92083 L F
.48326 .92082 m .4833 .92084 L .48324 .92084 L F
.48329 .92083 m .4833 .92083 L .4833 .92084 L F
.48269 .92135 m .48338 .92065 L .4833 .92084 L .803 .524 0 r
F
.48335 .92071 m .48372 .92032 L .48331 .92081 L .721 .932 0 r
F
.48309 .92045 m .48382 .91978 L .48283 .92097 L 1 .919 0 r
F
.48382 .91978 m .48442 .91924 L .48368 .92005 L F
.48382 .91978 m .48368 .92005 L .48283 .92097 L F
.48293 .92127 m .48262 .92153 L .48262 .92153 L .803 .524 0 r
F
.48293 .92127 m .48262 .92153 L .48293 .92127 L F
.4833 .92084 m .48688 .92262 L .48262 .92153 L .721 .932 0 r
F
.48262 .92153 m .48262 .92153 L .48262 .92153 L .803 .524 0 r
F
.48372 .92032 m .48374 .92032 L .48329 .92083 L .721 .932 0 r
F
.48374 .92032 m .48813 .92146 L .4833 .92083 L F
.48374 .92032 m .4833 .92083 L .48329 .92083 L F
.4833 .92084 m .48813 .92146 L .48688 .92262 L F
.4833 .92083 m .48813 .92146 L .4833 .92084 L F
.4822 .92204 m .48252 .92175 L .48244 .92185 L .636 .222 0 r
F
.48234 .92186 m .48234 .92187 L .48219 .92204 L .725 .954 0 r
F
.48234 .92187 m .4822 .92204 L .48219 .92204 L F
.48166 .92247 m .48234 .92187 L .4822 .92204 L .636 .222 0 r
F
.48234 .92187 m .48584 .92333 L .4822 .92204 L .725 .954 0 r
F
.48262 .92153 m .48262 .92153 L .48193 .92213 L .803 .524 0 r
F
.48232 .92165 m .48301 .92108 L .48193 .92213 L F
.48301 .92108 m .48262 .92153 L .48193 .92213 L F
.48234 .92186 m .48688 .92262 L .48584 .92333 L .725 .954 0 r
F
.48262 .92153 m .48688 .92262 L .48234 .92186 L F
.4822 .92204 m .48584 .92333 L .48533 .92368 L F
.47447 .90518 m .47685 .90987 L .47698 .91034 L 0 0 0 r
F
.47348 .90315 m .47443 .90503 L .47447 .90518 L F
.47352 .90009 m .47468 .90291 L .47476 .90302 L .829 .107 0 r
F
.48063 .88206 m .48111 .8954 L .48127 .89943 L .717 .135 0 r
F
.47926 .81871 m .48038 .82649 L .48046 .82876 L .356 .064 0 r
F
.48026 .8109 m .48031 .81228 L .48111 .8954 L 1 .758 0 r
F
.4801 .79431 m .48031 .81228 L .48026 .8109 L F
.48068 .83877 m .47985 .7585 L .48016 .76958 L 1 .71 0 r
F
.48043 .82201 m .47985 .7585 L .48068 .83877 L F
.48001 .75784 m .48011 .76563 L .48003 .7651 L .669 .236 0 r
F
.48001 .75784 m .48003 .7651 L .47995 .76229 L F
.47977 .75579 m .48001 .75784 L .47995 .76229 L F
.47962 .75448 m .47985 .76383 L .47948 .76123 L F
.47948 .76123 m .47985 .76383 L .47992 .76668 L F
.48111 .8954 m .47977 .75579 L .47985 .7585 L 1 .71 0 r
F
.47977 .75579 m .47881 .6565 L .48 .74897 L F
.48001 .75877 m .48001 .75784 L .47977 .75579 L .976 .508 0 r
F
.47976 .75606 m .47977 .75579 L .47962 .75448 L F
.47977 .75613 m .47977 .75579 L .47976 .75606 L F
.48001 .75877 m .47977 .75579 L .47977 .75613 L F
.47941 .72552 m .47952 .73008 L .47977 .75579 L 1 .758 0 r
F
.47976 .75767 m .47977 .75579 L .47997 .77662 L F
.48003 .75961 m .48162 .77619 L .48011 .76563 L .669 .236 0 r
F
.48001 .75784 m .48162 .77619 L .48003 .75961 L F
.48001 .75784 m .48472 .79788 L .48162 .77619 L F
.47975 .75982 m .47994 .77543 L .47989 .77386 L 1 .758 0 r
F
.47977 .75613 m .47962 .75448 L .47977 .75681 L .976 .508 0 r
F
.47923 .75117 m .47962 .75448 L .47948 .76123 L .669 .236 0 r
F
.4774 .73562 m .47923 .75117 L .47948 .76123 L F
.47976 .75758 m .47923 .75117 L .47919 .75187 L .976 .508 0 r
F
.48057 .76884 m .48472 .79788 L .48059 .77488 L .669 .236 0 r
F
.48173 .77731 m .47977 .75681 L .47976 .75758 L .976 .508 0 r
F
.47977 .75681 m .47923 .75117 L .47976 .75758 L F
.47976 .75878 m .47994 .77543 L .47975 .75905 L 1 .758 0 r
F
.47975 .75905 m .47994 .77543 L .47975 .75982 L F
.4794 .76134 m .47973 .76363 L .47958 .75572 L .976 .508 0 r
F
.47976 .75853 m .47994 .77543 L .47976 .75878 L 1 .758 0 r
F
.47973 .76363 m .47976 .75817 L .47958 .75572 L .976 .508 0 r
F
.47977 .75681 m .47962 .75448 L .4796 .75506 L F
.47976 .75853 m .47997 .77662 L .47994 .77543 L 1 .758 0 r
F
.47941 .72552 m .47976 .75767 L .47976 .75853 L F
.47976 .75767 m .47997 .77662 L .47976 .75853 L F
.48061 .76964 m .48057 .76574 L .47976 .75758 L .976 .508 0 r
F
.47976 .75817 m .47976 .75758 L .47958 .75572 L F
.48061 .76964 m .47976 .75758 L .47976 .75817 L F
.48009 .7939 m .47941 .72552 L .4801 .79409 L 1 .758 0 r
F
.47919 .77733 m .47993 .78462 L .47936 .78088 L .283 .048 0 r
F
.47996 .79056 m .47973 .76363 L .48009 .7939 L 1 .758 0 r
F
.47973 .76363 m .47941 .72552 L .48009 .7939 L F
.47973 .76363 m .48061 .76964 L .47976 .75817 L .976 .508 0 r
F
.48173 .77731 m .47977 .75613 L .47977 .75681 L F
.48173 .77731 m .48165 .77175 L .48001 .75784 L F
.48173 .77731 m .48001 .75784 L .48001 .75877 L F
.48025 .72914 m .48001 .68721 L .48026 .72905 L 1 .747 0 r
F
.48029 .73326 m .48001 .68721 L .48025 .72914 L 1 .672 0 r
F
.48061 .76964 m .48173 .77731 L .48057 .76574 L .976 .508 0 r
F
.48029 .73326 m .47973 .711 L .48022 .72253 L 1 .672 0 r
F
.48003 .74148 m .47973 .711 L .48029 .73326 L F
.48173 .77731 m .48472 .79788 L .48165 .77175 L .976 .508 0 r
F
.48088 .74398 m .48088 .74202 L .48092 .74469 L 1 .747 0 r
F
.48029 .73385 m .48088 .74202 L .48088 .74398 L F
.48029 .73385 m .48001 .68721 L .48088 .74202 L F
.48092 .74469 m .48001 .68721 L .48087 .71579 L F
.47973 .76363 m .48061 .70495 L .48472 .79788 L .976 .508 0 r
F
.4796 .75506 m .47962 .75448 L .47923 .75117 L F
.47901 .64646 m .47995 .64949 L .47814 .64897 L 1 .974 0 r
F
.47995 .64949 m .47982 .6502 L .47982 .65032 L .381 .059 0 r
F
.47995 .64949 m .47982 .65032 L .47814 .64897 L 1 .974 0 r
F
.47995 .64949 m .47982 .65032 L .47982 .65057 L .381 .059 0 r
F
.47996 .64981 m .47995 .64949 L .47982 .65057 L F
.47831 .64605 m .48153 .65516 L .47821 .64933 L .757 .466 0 r
F
.47821 .64933 m .48126 .66002 L .47799 .65345 L .897 .564 0 r
F
.47821 .64933 m .48153 .65516 L .48126 .66002 L F
.47973 .76363 m .47824 .64698 L .47881 .6565 L 1 .758 0 r
F
.47955 .76237 m .47963 .75788 L .47973 .76363 L .976 .508 0 r
F
.47919 .75187 m .47923 .75117 L .47856 .74553 L F
.47805 .7521 m .4794 .76134 L .47856 .74553 L F
.4794 .76134 m .47958 .75572 L .47856 .74553 L F
.47752 .74845 m .47805 .7521 L .4774 .73562 L F
.47805 .7521 m .47856 .74553 L .4774 .73562 L F
.47752 .74845 m .47903 .72723 L .47955 .76237 L F
.47908 .72646 m .47824 .64698 L .47973 .76363 L 1 .758 0 r
F
.47957 .74114 m .47976 .75853 L .47955 .73948 L F
.47976 .75853 m .47976 .75878 L .47955 .73948 L F
.47965 .74929 m .47976 .75878 L .47963 .7483 L F
.47976 .75878 m .47975 .75905 L .47963 .7483 L F
.47963 .7483 m .47975 .75905 L .47975 .75982 L F
.47941 .72552 m .47977 .75579 L .47976 .75767 L F
.47955 .73948 m .47965 .74929 L .47963 .7483 L F
.47999 .74261 m .47973 .711 L .48003 .74148 L 1 .672 0 r
F
.47941 .72552 m .47957 .74114 L .47955 .73948 L 1 .758 0 r
F
.48022 .72253 m .47939 .66946 L .48001 .68721 L 1 .672 0 r
F
.47973 .711 m .47939 .66946 L .48022 .72253 L F
.47941 .72552 m .47881 .6565 L .47952 .73008 L 1 .758 0 r
F
.47903 .72723 m .48061 .70495 L .47955 .76237 L .976 .508 0 r
F
.4808 .88321 m .48077 .88566 L .48081 .88275 L 1 .816 0 r
F
.48059 .88109 m .48111 .8954 L .48063 .88206 L .717 .135 0 r
F
.47981 .87249 m .48124 .90432 L .4798 .87372 L 0 0 0 r
F
.48061 .89315 m .48046 .89569 L .48052 .89548 L 1 .821 0 r
F
.47984 .88099 m .48003 .88146 L .48006 .88183 L .796 .486 0 r
F
.4798 .87372 m .48124 .90432 L .47972 .87873 L 0 0 0 r
F
.48084 .88066 m .48077 .88566 L .48079 .88538 L 1 .816 0 r
F
.4808 .88334 m .48078 .88345 L .4807 .88326 L .796 .486 0 r
F
.4808 .88334 m .4807 .88326 L .48069 .88313 L F
.4808 .88332 m .4808 .88334 L .48077 .88566 L 1 .816 0 r
F
.48069 .88308 m .4808 .88334 L .48069 .88313 L .796 .486 0 r
F
.47864 .83236 m .48056 .88118 L .47879 .83789 L 0 0 0 r
F
.47896 .8446 m .48056 .88118 L .48042 .88278 L F
.47879 .83789 m .48056 .88118 L .47896 .8446 L F
.47862 .83148 m .48056 .88118 L .47864 .83236 L F
.48042 .88278 m .48127 .89943 L .48124 .90432 L F
.48056 .88118 m .48127 .89943 L .48042 .88278 L F
.47899 .8377 m .48087 .89664 L .48111 .8954 L 1 .249 0 r
F
.48087 .89664 m .47908 .72646 L .47973 .76363 L 1 .758 0 r
F
.47963 .75788 m .47965 .75679 L .47973 .76363 L .976 .508 0 r
F
.47965 .75679 m .48061 .70495 L .47973 .76363 L F
.48111 .8954 m .48043 .82201 L .48068 .83877 L 1 .71 0 r
F
.47989 .77386 m .48017 .79772 L .4801 .79431 L 1 .758 0 r
F
.47994 .77543 m .48017 .79772 L .47989 .77386 L F
.48066 .7957 m .48798 .87962 L .48082 .82957 L .283 .048 0 r
F
.48083 .82457 m .48066 .7957 L .48082 .829 L 1 .672 0 r
F
.48063 .82115 m .48037 .78895 L .48083 .82457 L F
.48037 .78895 m .48052 .79244 L .48083 .82457 L F
.48044 .79049 m .48066 .79249 L .48049 .79169 L .283 .048 0 r
F
.48066 .79249 m .48142 .79927 L .48066 .79374 L F
.48066 .7957 m .48142 .79927 L .48129 .80293 L F
.48066 .79374 m .48142 .79927 L .48066 .7957 L F
.48037 .78895 m .48066 .7918 L .48044 .79049 L F
.48066 .7918 m .48142 .79927 L .48066 .79249 L F
.48066 .7918 m .48066 .79249 L .48044 .79049 L F
.48082 .82959 m .48082 .82963 L .48082 .82958 L .356 .064 0 r
F
.48082 .82957 m .48082 .82959 L .48082 .82958 L F
.48082 .829 m .48082 .82957 L .48088 .84026 L 1 .672 0 r
F
.48082 .82958 m .48082 .83043 L .48082 .82958 L .356 .064 0 r
F
.48082 .82959 m .48119 .83215 L .48084 .83055 L F
.48041 .80318 m .48045 .80593 L .48055 .81754 L 1 .71 0 r
F
.48041 .80318 m .48055 .81754 L .48053 .81669 L F
.48092 .83984 m .48083 .82457 L .48088 .84026 L 1 .672 0 r
F
.48083 .82457 m .48082 .829 L .48088 .84026 L F
.48051 .81539 m .48041 .80318 L .48053 .81669 L 1 .71 0 r
F
.48051 .81539 m .48053 .81669 L .48098 .86567 L F
.48115 .83296 m .48097 .83215 L .48095 .83173 L .356 .064 0 r
F
.48221 .8393 m .48114 .83323 L .48115 .83296 L F
.48119 .83215 m .48221 .8393 L .48115 .83296 L F
.48114 .83323 m .48099 .83236 L .48097 .83215 L F
.48143 .8351 m .48114 .8333 L .48114 .83323 L F
.48114 .8333 m .48099 .83236 L .48114 .83323 L F
.48041 .80318 m .48032 .79083 L .48045 .80593 L 1 .71 0 r
F
.48099 .85335 m .48111 .88224 L .48113 .88183 L 1 .672 0 r
F
.48092 .83984 m .48098 .85388 L .48099 .85335 L F
.48098 .85388 m .48111 .88224 L .48099 .85335 L F
.48143 .8351 m .48145 .8355 L .48114 .83336 L .356 .064 0 r
F
.48114 .8333 m .48114 .83336 L .48099 .83236 L F
.48143 .8351 m .48114 .83336 L .48114 .8333 L F
.48092 .83984 m .48088 .84026 L .48097 .85678 L 1 .672 0 r
F
.48098 .85388 m .48097 .85678 L .48111 .88224 L F
.48092 .83984 m .48097 .85678 L .48098 .85388 L F
.48097 .86616 m .48097 .86235 L .48095 .86391 L 1 .747 0 r
F
.48097 .86235 m .48095 .86274 L .48095 .86391 L F
.48124 .86423 m .48144 .86505 L .4813 .86623 L .59 .244 0 r
F
.48069 .83296 m .48074 .83466 L .48087 .85064 L 1 .71 0 r
F
.48085 .84967 m .48087 .85064 L .48098 .86338 L F
.48069 .83296 m .48087 .85064 L .48085 .84967 L F
.48083 .82457 m .48052 .79244 L .48066 .7957 L 1 .672 0 r
F
.47994 .77543 m .47997 .77662 L .48017 .79772 L 1 .758 0 r
F
.4823 .87176 m .48196 .8772 L .48191 .87533 L .59 .244 0 r
F
.48196 .8772 m .48146 .88498 L .48191 .87533 L F
.4811 .87102 m .48114 .88484 L .48115 .88406 L 1 .672 0 r
F
.48108 .86633 m .48109 .87131 L .4811 .87102 L F
.48109 .87131 m .48114 .88484 L .4811 .87102 L F
.47996 .79056 m .48009 .79392 L .48111 .8954 L 1 .758 0 r
F
.48009 .79392 m .4801 .79409 L .4801 .79431 L F
.48009 .79392 m .4801 .79431 L .48111 .8954 L F
.4823 .87176 m .4819 .87482 L .48187 .87337 L .59 .244 0 r
F
.48086 .88288 m .48081 .8832 L .48079 .88538 L 1 .816 0 r
F
.48111 .8954 m .48099 .87916 L .48127 .89943 L 1 .71 0 r
F
.48099 .87916 m .48088 .86399 L .48106 .88074 L F
.48099 .87916 m .48106 .88074 L .48127 .89943 L F
.4813 .86626 m .48266 .87006 L .4823 .87176 L .59 .244 0 r
F
.48144 .86505 m .48266 .87006 L .4813 .86626 L F
.48108 .86633 m .48106 .86748 L .48108 .87278 L 1 .672 0 r
F
.48109 .87131 m .48108 .87278 L .48114 .88484 L F
.48108 .86633 m .48108 .87278 L .48109 .87131 L F
.48117 .88249 m .48108 .86633 L .48115 .88406 L F
.48127 .89943 m .48063 .82115 L .48083 .82457 L F
.48215 .83982 m .48213 .84005 L .48145 .8355 L .356 .064 0 r
F
.48215 .83982 m .48145 .8355 L .48143 .8351 L F
.48408 .85234 m .48213 .84005 L .48215 .83982 L F
.48268 .86997 m .48266 .87006 L .48144 .86505 L .59 .244 0 r
F
.48268 .86997 m .48144 .86505 L .48145 .86499 L F
.48142 .79927 m .48298 .81472 L .48129 .80293 L .283 .048 0 r
F
.48298 .81472 m .48536 .83827 L .48282 .81622 L F
.48298 .81472 m .48282 .81622 L .48129 .80293 L F
.48129 .80293 m .48145 .80432 L .48145 .8048 L F
.48145 .80432 m .48282 .81622 L .48145 .8048 L F
.48145 .8048 m .48282 .81622 L .48262 .81815 L F
.48282 .81622 m .48536 .83827 L .48262 .81815 L F
.48221 .8393 m .48408 .85234 L .48215 .83982 L .356 .064 0 r
F
.48037 .87522 m .48059 .88109 L .48063 .88206 L .717 .135 0 r
F
.48185 .89804 m .48223 .89863 L .48186 .89831 L .944 .693 0 r
F
.48094 .86215 m .48098 .86338 L .48113 .88227 L 1 .71 0 r
F
.48112 .88198 m .48113 .88227 L .48127 .89943 L F
.48094 .86215 m .48113 .88227 L .48112 .88198 L F
.47947 .89765 m .48098 .90853 L .48048 .91196 L .185 .03 0 r
F
.47893 .89003 m .47939 .89421 L .47947 .89765 L F
.47939 .89421 m .48098 .90853 L .47947 .89765 L F
.4792 .85876 m .47981 .87249 L .47922 .86158 L 0 0 0 r
F
.47981 .87249 m .4798 .87372 L .47922 .86158 L F
.47922 .86158 m .4798 .87372 L .47968 .87796 L F
.4798 .87372 m .47972 .87873 L .47968 .87796 L F
.48146 .8649 m .48268 .86997 L .48145 .86499 L .59 .244 0 r
F
.47906 .8556 m .4792 .85876 L .47922 .86158 L 0 0 0 r
F
.47948 .8914 m .47949 .89333 L .47938 .8942 L .796 .486 0 r
F
.47727 .78542 m .47818 .76727 L .47824 .8076 L 1 .684 0 r
F
.47464 .72153 m .47536 .74162 L .47463 .72056 L 1 .249 0 r
F
.47536 .74162 m .47543 .74336 L .47463 .72056 L F
.47758 .80547 m .47789 .81557 L .47762 .8077 L 0 0 0 r
F
.47607 .88412 m .47803 .87074 L .47684 .89102 L 1 .818 0 r
F
.47803 .87074 m .47823 .87592 L .47684 .89102 L F
.47806 .87141 m .48098 .90853 L .47812 .87312 L .185 .03 0 r
F
.47903 .86282 m .47906 .8556 L .47968 .87796 L 0 0 0 r
F
.47874 .84942 m .47906 .8556 L .47903 .86282 L F
.47757 .80476 m .47862 .83148 L .47758 .80547 L F
.47862 .83148 m .47864 .83236 L .47758 .80547 L F
.47859 .88517 m .47857 .87982 L .47861 .88548 L .185 .03 0 r
F
.47822 .8757 m .47857 .87982 L .47859 .88517 L F
.47684 .89102 m .47823 .87592 L .47859 .88517 L 1 .818 0 r
F
.47715 .89381 m .47748 .8956 L .47716 .89391 L .462 .125 0 r
F
.47748 .8956 m .48048 .91196 L .47747 .89579 L F
.47336 .89971 m .47351 .90007 L .47352 .90009 L .829 .107 0 r
F
.47704 .89346 m .48048 .91196 L .47708 .89416 L .462 .125 0 r
F
.47736 .89925 m .47746 .89678 L .47741 .89957 L F
.47714 .89516 m .47746 .89678 L .47736 .89925 L F
.47607 .8972 m .47702 .89312 L .47722 .89671 L 1 .901 0 r
F
.47861 .88548 m .47876 .88212 L .47873 .88723 L .185 .03 0 r
F
.47857 .87982 m .47876 .88212 L .47861 .88548 L F
.47721 .89482 m .47747 .89619 L .47724 .89567 L .462 .125 0 r
F
.47747 .89619 m .47746 .89678 L .47724 .89567 L F
.47873 .88723 m .47896 .88936 L .47893 .89003 L .185 .03 0 r
F
.47896 .88936 m .48098 .90853 L .47893 .89003 L F
.47876 .88212 m .48098 .90853 L .47873 .88723 L F
.47736 .89925 m .47731 .89947 L .47731 .89947 L .462 .125 0 r
F
.47736 .89925 m .47741 .89957 L .47731 .89947 L F
.47746 .89678 m .48048 .91196 L .47741 .89957 L F
.48408 .85234 m .48798 .87962 L .48399 .85266 L .356 .064 0 r
F
.48069 .83296 m .48098 .86338 L .48094 .86215 L 1 .71 0 r
F
.47762 .80513 m .47865 .83417 L .47807 .81263 L 1 .249 0 r
F
.47865 .83417 m .48087 .89664 L .47886 .83635 L F
.47865 .83417 m .47886 .83635 L .47807 .81263 L F
.48087 .89664 m .47996 .79056 L .48111 .8954 L 1 .758 0 r
F
.48196 .84149 m .48399 .85266 L .48351 .85455 L .356 .064 0 r
F
.48088 .83236 m .4821 .8403 L .48196 .84149 L F
.4821 .8403 m .48399 .85266 L .48196 .84149 L F
.48038 .79773 m .48048 .80291 L .48063 .82115 L 1 .71 0 r
F
.48059 .81928 m .48063 .82115 L .48074 .83466 L F
.48038 .79773 m .48063 .82115 L .48059 .81928 L F
.48399 .85266 m .48798 .87962 L .48351 .85455 L .356 .064 0 r
F
.47986 .85829 m .48002 .85897 L .48004 .8593 L .59 .244 0 r
F
.48006 .88703 m .48124 .90432 L .48098 .90853 L 0 0 0 r
F
.47968 .87796 m .48013 .8856 L .48006 .88703 L F
.48013 .8856 m .48124 .90432 L .48006 .88703 L F
.48036 .79604 m .48045 .80097 L .48038 .79773 L 1 .71 0 r
F
.48045 .80097 m .48048 .80291 L .48038 .79773 L F
.48032 .79083 m .48039 .7916 L .48048 .80291 L F
.48032 .79083 m .48048 .80291 L .48036 .79604 L F
.47807 .81263 m .47886 .83635 L .47899 .8377 L 1 .249 0 r
F
.47886 .83635 m .48087 .89664 L .47899 .8377 L F
.48128 .92208 m .48309 .92045 L .48072 .92299 L 1 .919 0 r
F
.48309 .92045 m .48283 .92097 L .48072 .92299 L F
.48158 .92353 m .48212 .92284 L .48181 .92366 L .707 .949 0 r
F
.48194 .92279 m .48212 .92284 L .48158 .92353 L F
.48212 .92284 m .48533 .92368 L .48181 .92366 L F
.48072 .92299 m .48283 .92097 L .48269 .92135 L .803 .524 0 r
F
.48072 .92299 m .48232 .92165 L .47995 .92385 L F
.48232 .92165 m .48193 .92213 L .47995 .92385 L F
.47998 .92452 m .4806 .92382 L .48003 .92455 L .668 .913 0 r
F
.48055 .92381 m .4806 .92382 L .47998 .92452 L F
.4806 .92382 m .48349 .92463 L .48003 .92455 L F
.47995 .92385 m .48193 .92213 L .48166 .92247 L .636 .222 0 r
F
.47319 .91841 m .47367 .9187 L .47363 .91876 L .706 .788 0 r
F
.47145 .91697 m .47115 .91749 L .47061 .92072 L 0 0 0 r
F
.47096 .91954 m .47146 .91562 L .47095 .91947 L F
.47117 .9188 m .47145 .91697 L .47107 .91868 L F
.47096 .91954 m .47107 .91868 L .47061 .92072 L F
.47117 .9188 m .47107 .91868 L .47096 .91954 L F
.47117 .92254 m .47149 .91564 L .47145 .91597 L F
.47168 .91615 m .47205 .91368 L .47117 .9188 L 1 .329 0 r
F
.47205 .91368 m .47184 .91441 L .47117 .9188 L F
.47168 .91615 m .472 .91345 L .47205 .91368 L F
.47204 .91312 m .472 .91345 L .47168 .91615 L 1 .749 0 r
F
.47117 .9188 m .47184 .91441 L .47175 .91497 L 0 0 0 r
F
.47111 .91647 m .47197 .91171 L .47198 .909 L F
.47095 .91788 m .47126 .91612 L .47111 .91647 L F
.47063 .91481 m .47146 .91562 L .47111 .91647 L 1 1 0 r
F
.47061 .92072 m .47115 .91749 L .47095 .91788 L 0 0 0 r
F
.47095 .91947 m .47146 .91562 L .47063 .91481 L F
.47078 .9193 m .47095 .91788 L .47039 .91968 L F
.47095 .91788 m .47059 .91836 L .47039 .91968 L F
.46969 .92032 m .47038 .91294 L .46918 .92074 L .248 0 0 r
F
.47004 .91793 m .47015 .91895 L .46943 .92009 L 1 1 0 r
F
.47015 .91895 m .46969 .92032 L .46943 .92009 L F
.47011 .91996 m .47015 .91895 L .46969 .92032 L .051 0 0 r
F
.47002 .92217 m .47011 .91996 L .46941 .92328 L F
.47011 .91996 m .46969 .92032 L .46941 .92328 L F
.46941 .92328 m .46969 .92032 L .46918 .92074 L .248 0 0 r
F
.46943 .92009 m .46969 .92032 L .46918 .92074 L .665 .424 0 r
F
.46946 .91326 m .46952 .88918 L .46883 .91687 L .252 .035 0 r
F
.46952 .88918 m .4689 .90235 L .46891 .90346 L 0 0 0 r
F
.46952 .88918 m .46995 .71984 L .46891 .90346 L .252 .035 0 r
F
.46952 .88918 m .46891 .90346 L .46883 .91687 L F
.46952 .88918 m .46891 .90346 L .46891 .90382 L 0 0 0 r
F
.46957 .88876 m .46952 .88918 L .46891 .90382 L F
.46957 .88876 m .46962 .88822 L .46952 .88918 L F
.46952 .88918 m .47095 .68366 L .46995 .71984 L .252 .035 0 r
F
.4695 .89521 m .46955 .88892 L .46952 .88918 L F
.46955 .88892 m .47095 .68366 L .46952 .88918 L F
.46946 .91326 m .46962 .88822 L .4695 .89521 L F
.47027 .84661 m .47028 .84861 L .46957 .88876 L 1 .525 0 r
F
.47028 .84861 m .47029 .8505 L .46992 .87012 L F
.47028 .84861 m .46992 .87012 L .46957 .88876 L F
.47029 .8505 m .46964 .88806 L .46957 .88876 L F
.47118 .90949 m .47207 .83279 L .47118 .90948 L .877 .169 0 r
F
.47229 .81571 m .47226 .81627 L .47118 .91001 L 0 0 0 r
F
.47019 .87799 m .47041 .84822 L .47029 .85079 L .423 .064 0 r
F
.47027 .84661 m .47048 .84674 L .47029 .85079 L 1 .525 0 r
F
.47315 .69158 m .47347 .69981 L .47317 .69259 L 0 0 0 r
F
.47347 .69981 m .47365 .70429 L .47346 .69981 L F
.47347 .69981 m .47346 .69981 L .47317 .69259 L F
.47365 .70429 m .47377 .70751 L .47364 .70437 L F
.47366 .69467 m .47452 .71782 L .47447 .71638 L .717 .135 0 r
F
.47367 .6949 m .47452 .71782 L .47366 .69467 L F
.47458 .71773 m .47454 .71824 L .47373 .69647 L 1 .249 0 r
F
.47458 .71773 m .47373 .69647 L .47374 .69566 L F
.47373 .69456 m .47371 .69484 L .47231 .6582 L F
.47447 .71638 m .47437 .72274 L .47239 .67212 L .717 .135 0 r
F
.47311 .67854 m .47464 .72153 L .47314 .67859 L 1 .249 0 r
F
.47464 .72153 m .47463 .72056 L .47314 .67859 L F
.47364 .70485 m .47377 .70751 L .47391 .71202 L 0 0 0 r
F
.47364 .70437 m .47377 .70751 L .47364 .70485 L F
.47255 .71029 m .47284 .7169 L .47284 .71729 L F
.4735 .73266 m .474 .74386 L .47398 .74399 L F
.47373 .69456 m .47458 .71773 L .47371 .69484 L 1 .249 0 r
F
.47373 .69456 m .47463 .72056 L .47458 .71773 L F
.47314 .67859 m .47373 .69516 L .47373 .69456 L F
.47373 .69516 m .47463 .72056 L .47373 .69456 L F
.47713 .65926 m .47744 .65831 L .47731 .66147 L 1 .683 0 r
F
.47713 .65926 m .47731 .66147 L .47719 .66467 L F
.47517 .64152 m .47529 .64168 L .4753 .64179 L .867 .538 0 r
F
.47801 .64561 m .47831 .64605 L .47778 .64695 L F
.47747 .65227 m .47799 .65345 L .47702 .65599 L 1 .629 0 r
F
.47702 .65599 m .47768 .65902 L .47693 .65685 L F
.47802 .64899 m .47821 .64933 L .47753 .65188 L .936 .578 0 r
F
.47753 .65188 m .47799 .65345 L .47747 .65227 L F
.47804 .64889 m .47825 .64795 L .47821 .64933 L .867 .538 0 r
F
.47804 .64889 m .47821 .64933 L .47802 .64899 L F
.47712 .66644 m .4773 .6671 L .47679 .67921 L 1 .739 0 r
F
.47679 .67921 m .47686 .67986 L .47678 .67948 L F
.47744 .65831 m .47768 .65902 L .47713 .66606 L 1 .683 0 r
F
.47678 .67948 m .47686 .67986 L .4764 .70205 L 1 .792 0 r
F
.47713 .66606 m .4773 .6671 L .47712 .66644 L 1 .683 0 r
F
.4734 .72934 m .47404 .74366 L .4735 .73266 L 0 0 0 r
F
.47404 .74366 m .474 .74386 L .4735 .73266 L F
.47818 .76727 m .47919 .77733 L .47936 .78088 L .283 .048 0 r
F
.48536 .83827 m .48728 .85725 L .48474 .8425 L F
.48596 .80777 m .49112 .84861 L .49141 .85145 L 0 0 0 r
F
.48472 .79788 m .48582 .80654 L .48596 .80777 L F
.48536 .71077 m .49302 .76476 L .48603 .72101 L F
.49302 .76476 m .49521 .7802 L .49279 .7646 L F
.49302 .76476 m .49279 .7646 L .48603 .72101 L F
.48432 .70568 m .48536 .71077 L .48603 .72101 L F
.48509 .70849 m .48536 .71077 L .48432 .70568 L F
.48037 .67657 m .48039 .67665 L .48037 .67661 L 1 .695 0 r
F
.47253 .90619 m .4727 .90392 L .47214 .91229 L 1 .843 0 r
F
.47061 .92072 m .47078 .9193 L .47002 .92217 L 0 0 0 r
F
.47078 .9193 m .47039 .91968 L .47002 .92217 L F
.46911 .92092 m .46913 .92092 L .46909 .92096 L .665 .424 0 r
F
.47002 .92217 m .47039 .91968 L .47011 .91996 L .051 0 0 r
F
.46941 .92328 m .46918 .92074 L .46879 .92415 L .248 0 0 r
F
.46918 .92074 m .46872 .91577 L .46876 .92107 L F
.46918 .92074 m .46876 .92107 L .46877 .92177 L F
.46943 .92009 m .46918 .92074 L .4688 .92166 L .665 .424 0 r
F
.46918 .92074 m .46868 .92206 L .46877 .92177 L F
.46918 .92074 m .46877 .92177 L .4688 .92166 L F
.46918 .92074 m .46877 .92177 L .46879 .92415 L .248 0 0 r
F
.46822 .92208 m .467 .92296 L .46784 .92287 L .412 .202 0 r
F
.46879 .92415 m .46822 .92208 L .46817 .92484 L .372 .02 0 r
F
.46822 .92208 m .46784 .92287 L .46785 .92287 L .412 .202 0 r
F
.46822 .92208 m .46705 .91787 L .46785 .92287 L .372 .02 0 r
F
.46822 .92208 m .46785 .92287 L .46817 .92484 L F
.46822 .92208 m .46785 .92287 L .46818 .92284 L .412 .202 0 r
F
.4688 .92166 m .46822 .92208 L .46818 .92284 L F
.46876 .92094 m .46872 .91577 L .46822 .92208 L .372 .02 0 r
F
.46817 .92284 m .467 .92296 L .46817 .9228 L 0 0 0 r
F
.46817 .92484 m .46785 .92287 L .46755 .92245 L .493 .032 0 r
F
.46784 .92284 m .467 .92296 L .46653 .91836 L 0 0 0 r
F
.46705 .91787 m .46627 .91818 L .46653 .91836 L F
.46682 .91789 m .4659 .91797 L .46621 .91818 L F
.46682 .91789 m .46621 .91818 L .46622 .91818 L F
.46682 .91789 m .46615 .91822 L .46615 .91869 L .719 .15 0 r
F
.46682 .91789 m .46622 .91818 L .46623 .91819 L 0 0 0 r
F
.46622 .91818 m .46621 .91818 L .46622 .91818 L F
.46682 .91789 m .46614 .89939 L .46615 .91822 L .719 .15 0 r
F
.46607 .91826 m .46614 .89939 L .4635 .90535 L F
.46615 .91822 m .46614 .89939 L .46607 .91826 L F
.46705 .91787 m .46682 .91789 L .46623 .91819 L 0 0 0 r
F
.46653 .91836 m .4635 .90535 L .46556 .90878 L .719 .15 0 r
F
.46615 .91869 m .46615 .91822 L .46607 .91826 L F
.467 .92296 m .46607 .91826 L .46653 .91836 L F
.46627 .91818 m .46607 .91826 L .46653 .91836 L 0 0 0 r
F
.46623 .91819 m .46622 .91818 L .46607 .91826 L F
.46607 .91826 m .4635 .90535 L .46653 .91836 L .719 .15 0 r
F
.46607 .91826 m .46324 .91939 L .46653 .91836 L 0 0 0 r
F
.46695 .92246 m .46685 .92146 L .46541 .91944 L .493 .032 0 r
F
.46708 .92271 m .46685 .92146 L .46695 .92246 L F
.46708 .92271 m .46755 .92245 L .46685 .92146 L F
.46817 .92484 m .46755 .92245 L .46708 .92271 L F
.46785 .92287 m .46705 .91787 L .46653 .91836 L F
.46785 .92287 m .46653 .91836 L .46541 .91944 L F
.46817 .9228 m .46784 .92284 L .46653 .91836 L 0 0 0 r
F
.46661 .91842 m .46653 .91836 L .46651 .91815 L F
.46817 .9228 m .46653 .91836 L .46661 .91842 L F
.46653 .91836 m .46324 .91939 L .46541 .91944 L F
.46818 .91619 m .46803 .91631 L .46682 .91789 L .459 .203 0 r
F
.46682 .91556 m .46651 .91815 L .46556 .90878 L 0 0 0 r
F
.46735 .91724 m .46682 .91789 L .46683 .91789 L .459 .203 0 r
F
.46818 .91619 m .46682 .91789 L .46735 .91724 L F
.46872 .91577 m .46818 .91619 L .46705 .91787 L F
.46818 .91619 m .46683 .91789 L .46705 .91787 L F
.46729 .91808 m .46695 .91811 L .46682 .91556 L 0 0 0 r
F
.46695 .91811 m .46651 .91815 L .46682 .91556 L F
.46858 .88592 m .46848 .88461 L .46301 .89381 L F
.46858 .88592 m .46301 .89381 L .46404 .89516 L F
.46817 .88849 m .46858 .88592 L .46404 .89516 L F
.46867 .88768 m .4686 .88625 L .46817 .88849 L F
.4686 .88625 m .46858 .88592 L .46817 .88849 L F
.46638 .90538 m .46624 .90332 L .46626 .90497 L .485 .065 0 r
F
.46811 .88913 m .46404 .89516 L .46508 .89692 L 0 0 0 r
F
.46867 .88768 m .46817 .88849 L .46811 .88913 L F
.46817 .88849 m .46404 .89516 L .46811 .88913 L F
.46614 .89939 m .46508 .89692 L .46147 .9031 L .004 0 0 r
F
.46614 .89939 m .46147 .9031 L .4635 .90535 L F
.46556 .90878 m .4635 .90535 L .46093 .90943 L .252 0 0 r
F
.46556 .90878 m .46093 .90943 L .46396 .91246 L F
.46818 .92284 m .46651 .91815 L .46729 .91808 L 0 0 0 r
F
.46607 .91826 m .4659 .91797 L .46324 .91939 L F
.4659 .91797 m .46475 .91845 L .46484 .91836 L .252 .18 0 r
F
.4659 .91797 m .46108 .91972 L .46324 .91939 L F
.46817 .92484 m .46541 .91944 L .46716 .92067 L .493 .032 0 r
F
.46817 .92484 m .46716 .92067 L .46793 .92322 L F
.46757 .92374 m .46716 .92067 L .46666 .9209 L .628 .068 0 r
F
.46759 .92098 m .46674 .9209 L .467 .92223 L .193 0 0 r
F
.46652 .92088 m .46647 .92088 L .46628 .92187 L F
.46647 .92088 m .46382 .92063 L .46625 .92186 L F
.46647 .92088 m .46625 .92186 L .46628 .92187 L F
.46555 .92282 m .46231 .92153 L .46506 .92293 L .381 0 0 r
F
.46576 .924 m .46534 .92287 L .46505 .92293 L .84 .129 0 r
F
.46555 .92282 m .46506 .92293 L .46508 .92294 L .381 0 0 r
F
.46388 .9235 m .46091 .92221 L .45964 .92269 L .421 0 0 r
F
.46586 .92359 m .46579 .92342 L .46576 .924 L .84 .129 0 r
F
.46579 .92342 m .46555 .92282 L .46566 .92343 L F
.46579 .92342 m .46566 .92343 L .46576 .924 L F
.46609 .92259 m .46583 .92206 L .46586 .92359 L .749 .094 0 r
F
.46583 .92206 m .46382 .92063 L .46231 .92153 L .31 0 0 r
F
.46584 .92205 m .46382 .92063 L .46583 .92206 L F
.46628 .92187 m .46382 .92063 L .46585 .92206 L F
.46647 .92088 m .46541 .91944 L .46382 .92063 L .193 0 0 r
F
.46652 .92088 m .4665 .92086 L .46647 .92088 L F
.4665 .92086 m .46541 .91944 L .46647 .92088 L F
.46757 .92374 m .46691 .92169 L .46698 .92445 L .628 .068 0 r
F
.46691 .92169 m .46666 .9209 L .46674 .92175 L F
.46691 .92169 m .46674 .92175 L .46698 .92445 L F
.46583 .92206 m .46617 .92122 L .46559 .92155 L .749 .094 0 r
F
.46698 .92445 m .46634 .9219 L .46583 .92206 L F
.46603 .922 m .46628 .92187 L .46594 .92202 L .31 0 0 r
F
.46634 .9219 m .46628 .92187 L .46589 .92207 L F
.46634 .9219 m .46617 .92122 L .46583 .92206 L .749 .094 0 r
F
.46589 .92207 m .46603 .922 L .46585 .92206 L .31 0 0 r
F
.46603 .922 m .46594 .92202 L .46585 .92206 L F
.46641 .92168 m .46652 .92088 L .46632 .92189 L .193 0 0 r
F
.46666 .9209 m .46649 .92143 L .46698 .92445 L .628 .068 0 r
F
.46674 .9209 m .46666 .9209 L .46641 .92168 L .193 0 0 r
F
.46666 .9209 m .46652 .92088 L .46641 .92168 L F
.46666 .9209 m .46643 .92105 L .46649 .92143 L .628 .068 0 r
F
.46643 .92105 m .46617 .92122 L .46622 .92144 L F
.46652 .92088 m .46628 .92187 L .46632 .92189 L .193 0 0 r
F
.46643 .92105 m .46622 .92144 L .46698 .92445 L .628 .068 0 r
F
.467 .92223 m .46589 .92207 L .46644 .92317 L .31 0 0 r
F
.46589 .92207 m .46583 .92206 L .46586 .92212 L F
.46589 .92207 m .46586 .92212 L .46644 .92317 L F
.467 .92223 m .46634 .9219 L .46589 .92207 L F
.46583 .92206 m .46231 .92153 L .46555 .92282 L F
.46583 .92206 m .46555 .92282 L .46586 .92359 L .749 .094 0 r
F
.46613 .92268 m .46609 .92259 L .4661 .92269 L F
.46583 .92206 m .46555 .92282 L .46644 .92317 L .31 0 0 r
F
.46583 .92206 m .46534 .92229 L .46555 .92282 L .749 .094 0 r
F
.46583 .92206 m .46559 .92155 L .46534 .92229 L F
.46541 .91944 m .46324 .91939 L .46065 .92045 L 0 0 0 r
F
.46541 .91944 m .46065 .92045 L .46382 .92063 L F
.46559 .92155 m .46308 .91635 L .46517 .92187 L .749 .094 0 r
F
.46308 .91635 m .46298 .91639 L .46517 .92187 L F
.46517 .92187 m .46244 .91504 L .46501 .92198 L .84 .129 0 r
F
.46559 .92155 m .46517 .92187 L .46534 .92229 L .749 .094 0 r
F
.46585 .92206 m .46584 .92205 L .46583 .92206 L .31 0 0 r
F
.46555 .92282 m .46534 .92229 L .46534 .92287 L .84 .129 0 r
F
.46534 .92229 m .46517 .92187 L .46525 .92233 L F
.46534 .92229 m .46525 .92233 L .46534 .92287 L F
.46517 .92187 m .46501 .92198 L .46534 .92287 L F
.46555 .92282 m .46534 .92287 L .46576 .924 L F
.46324 .91939 m .46108 .91972 L .45752 .92064 L 0 0 0 r
F
.46324 .91939 m .45752 .92064 L .46065 .92045 L F
.46273 .92075 m .46065 .92045 L .45821 .92122 L .083 0 0 r
F
.46382 .92063 m .46311 .92059 L .46273 .92075 L F
.46311 .92059 m .46065 .92045 L .46273 .92075 L F
.46007 .91478 m .45847 .9123 L .45619 .91436 L .466 .016 0 r
F
.46244 .91504 m .46065 .9138 L .46007 .91478 L F
.46065 .9138 m .45847 .9123 L .46007 .91478 L F
.45917 .91661 m .45619 .91436 L .45412 .91584 L .538 .018 0 r
F
.46103 .91689 m .4596 .91614 L .45917 .91661 L F
.4596 .91614 m .45619 .91436 L .45917 .91661 L F
.46244 .91504 m .46138 .91492 L .46103 .91689 L .466 .016 0 r
F
.46138 .91492 m .45619 .91436 L .46043 .91657 L F
.46138 .91492 m .46043 .91657 L .46103 .91689 L F
.46231 .92153 m .45821 .92122 L .45593 .92177 L .149 0 0 r
F
.46382 .92063 m .45821 .92122 L .46231 .92153 L .083 0 0 r
F
.46091 .92221 m .45593 .92177 L .45387 .92211 L .182 0 0 r
F
.46231 .92153 m .45593 .92177 L .46091 .92221 L .149 0 0 r
F
.45847 .91779 m .45412 .91584 L .45363 .91612 L .562 .014 0 r
F
.45896 .91796 m .45851 .91776 L .45847 .91779 L F
.45851 .91776 m .45412 .91584 L .45847 .91779 L F
.45904 .91793 m .45412 .91584 L .45896 .91796 L F
.46091 .92221 m .45387 .92211 L .45964 .92269 L .182 0 0 r
F
.45964 .92269 m .45387 .92211 L .45363 .91612 L .489 .111 0 r
F
.45964 .92269 m .45363 .91612 L .45822 .91796 L F
.45822 .91796 m .45363 .91612 L .4523 .91688 L .562 .014 0 r
F
.45976 .91824 m .45822 .91796 L .45864 .91922 L F
.45822 .91796 m .4523 .91688 L .45749 .9188 L F
.45805 .91815 m .45782 .91841 L .45767 .91873 L .489 .111 0 r
F
.45772 .91872 m .45767 .91873 L .45754 .91901 L F
.45805 .91815 m .45767 .91873 L .45772 .91872 L F
.45749 .9188 m .4523 .91688 L .45702 .91886 L .54 .004 0 r
F
.45709 .9193 m .45726 .91883 L .45693 .91887 L 1 .542 0 r
F
.4578 .92114 m .45737 .91931 L .45709 .9193 L F
.45737 .91931 m .45726 .91883 L .45709 .9193 L F
.45451 .9192 m .45076 .9176 L .44953 .91806 L .509 0 0 r
F
.45746 .9188 m .45726 .91883 L .45731 .91901 L 1 .542 0 r
F
.45749 .919 m .45731 .91901 L .4578 .92114 L F
.45746 .9188 m .45731 .91901 L .45749 .919 L F
.45799 .92082 m .45747 .91871 L .4578 .92114 L F
.45747 .91871 m .45742 .9185 L .45745 .91871 L F
.45747 .91871 m .45745 .91871 L .4578 .92114 L F
.45946 .92209 m .45829 .91817 L .45841 .92253 L .489 .111 0 r
F
.45829 .91817 m .4582 .9179 L .45822 .91821 L F
.45829 .91817 m .45822 .91821 L .45841 .92253 L F
.45832 .9179 m .45363 .91612 L .45822 .91796 L .562 .014 0 r
F
.45896 .91796 m .45847 .91779 L .45871 .91805 L F
.45847 .91779 m .45363 .91612 L .45832 .9179 L F
.45847 .91779 m .45832 .9179 L .45871 .91805 L F
.45796 .91814 m .45742 .91852 L .45754 .91901 L .489 .111 0 r
F
.45815 .91772 m .45749 .91845 L .45796 .91814 L F
.45749 .91845 m .45742 .91852 L .45796 .91814 L F
.46103 .91689 m .45412 .91584 L .45976 .91824 L .538 .018 0 r
F
.45822 .91796 m .45363 .91612 L .45302 .90057 L .489 .111 0 r
F
.4582 .9179 m .45754 .91901 L .45841 .92253 L F
.45864 .91922 m .45716 .91891 L .45719 .91898 L .54 .004 0 r
F
.45864 .91922 m .45719 .91898 L .45832 .91946 L F
.45864 .91922 m .45749 .9188 L .45716 .91891 L F
.45822 .91796 m .45749 .9188 L .45864 .91922 L .562 .014 0 r
F
.45813 .91802 m .45796 .91814 L .45782 .91841 L .489 .111 0 r
F
.45813 .91802 m .45782 .91841 L .45805 .91815 L F
.4582 .9179 m .45815 .91772 L .45796 .91814 L F
.4582 .9179 m .45796 .91814 L .45813 .91802 L F
.45742 .9185 m .45302 .90057 L .4572 .91857 L 1 .542 0 r
F
.45006 .90966 m .45008 .90717 L .44912 .90905 L 1 .178 0 r
F
.45815 .91772 m .45478 .90646 L .45742 .9185 L .489 .111 0 r
F
.45478 .90646 m .4546 .90659 L .45742 .9185 L F
.45376 .90306 m .45368 .90327 L .45369 .90331 L F
.45377 .9031 m .45369 .90331 L .45742 .9185 L F
.45376 .90306 m .45369 .90331 L .45377 .9031 L F
.45815 .91772 m .45742 .9185 L .45749 .91845 L F
.45686 .91869 m .45302 .90057 L .45338 .90965 L 1 .542 0 r
F
.4572 .91857 m .45302 .90057 L .45686 .91869 L F
.45338 .90965 m .45302 .90057 L .45138 .90447 L F
.45832 .91946 m .45138 .90447 L .45793 .91255 L F
.45749 .9188 m .45702 .91886 L .45716 .91891 L .54 .004 0 r
F
.45742 .9185 m .4572 .91857 L .45726 .91883 L 1 .542 0 r
F
.45742 .9185 m .45726 .91883 L .45746 .9188 L F
.45693 .91887 m .4572 .91857 L .45686 .91869 L F
.45726 .91883 m .4572 .91857 L .45693 .91887 L F
.45716 .91891 m .45702 .91886 L .45693 .91887 L .54 .004 0 r
F
.45702 .91886 m .4523 .91688 L .45693 .91887 L F
.45749 .91845 m .45742 .9185 L .45742 .91852 L .489 .111 0 r
F
.45693 .91887 m .45138 .90447 L .45832 .91946 L 1 .542 0 r
F
.45793 .91255 m .4517 .90828 L .45715 .91426 L 1 .251 0 r
F
.4517 .90828 m .45008 .90717 L .45155 .90865 L F
.4517 .90828 m .45155 .90865 L .45715 .91426 L F
.45715 .91426 m .45155 .90865 L .45006 .90966 L 1 .178 0 r
F
.45155 .90865 m .45008 .90717 L .45006 .90966 L F
.45478 .90646 m .45376 .90306 L .4546 .90659 L .489 .111 0 r
F
.45376 .90306 m .45302 .90057 L .45368 .90327 L F
.4517 .90828 m .45138 .90447 L .45008 .90717 L 1 .251 0 r
F
.45793 .91255 m .45261 .90598 L .4517 .90828 L F
.45261 .90598 m .45138 .90447 L .4517 .90828 L F
.45853 .92303 m .45799 .92082 L .4578 .92114 L 1 .542 0 r
F
.45853 .92303 m .45693 .91887 L .45832 .91946 L F
.45832 .91946 m .45719 .91898 L .4577 .91993 L .54 .004 0 r
F
.45716 .91891 m .45693 .91887 L .45702 .919 L F
.45716 .91891 m .45702 .919 L .4577 .91993 L F
.45693 .91887 m .45076 .9176 L .45565 .91924 L F
.45693 .91887 m .45565 .91924 L .4577 .91993 L F
.4577 .91993 m .45451 .9192 L .45695 .92043 L .509 0 0 r
F
.45451 .9192 m .44953 .91806 L .45334 .91928 L F
.45451 .9192 m .45334 .91928 L .45695 .92043 L F
.4577 .91993 m .45565 .91924 L .45451 .9192 L F
.45565 .91924 m .45076 .9176 L .45451 .9192 L F
.45693 .91887 m .4523 .91688 L .45076 .9176 L .54 .004 0 r
F
.45871 .91805 m .45832 .9179 L .45822 .91796 L .562 .014 0 r
F
.45976 .91824 m .45896 .91796 L .45871 .91805 L F
.45976 .91824 m .45904 .91793 L .45896 .91796 L F
.45964 .92269 m .45946 .92209 L .45853 .92303 L .489 .111 0 r
F
.45946 .92209 m .45841 .92253 L .45853 .92303 L F
.46505 .92293 m .46244 .91504 L .46103 .91689 L .84 .129 0 r
F
.46534 .92287 m .46244 .91504 L .46505 .92293 L F
.46508 .92294 m .46506 .92293 L .46505 .92293 L .381 0 0 r
F
.46609 .92259 m .46586 .92359 L .46642 .92499 L .749 .094 0 r
F
.46644 .92317 m .46555 .92282 L .46508 .92294 L .381 0 0 r
F
.46613 .92268 m .4661 .92269 L .46642 .92499 L .749 .094 0 r
F
.46642 .92499 m .46586 .92359 L .46576 .924 L .84 .129 0 r
F
.46559 .92155 m .46396 .91246 L .46244 .91504 L .749 .094 0 r
F
.4666 .92083 m .46541 .91944 L .46652 .92088 L .193 0 0 r
F
.46685 .92078 m .46541 .91944 L .46666 .9209 L F
.46713 .92065 m .46541 .91944 L .46687 .9208 L F
.46617 .92122 m .46396 .91246 L .46559 .92155 L .749 .094 0 r
F
.46698 .92445 m .46613 .92268 L .46642 .92499 L F
.46644 .92317 m .46505 .92293 L .46623 .92347 L .381 0 0 r
F
.46606 .92339 m .46304 .9199 L .46584 .92132 L .84 .129 0 r
F
.46618 .92464 m .46505 .92293 L .46606 .92339 L F
.46505 .92293 m .46304 .9199 L .46606 .92339 L F
.46642 .92499 m .46618 .92464 L .46596 .92138 L F
.46618 .92464 m .46584 .92132 L .46596 .92138 L F
.46623 .92347 m .46091 .92221 L .46592 .92389 L .381 0 0 r
F
.46505 .92293 m .46091 .92221 L .46623 .92347 L F
.46556 .92382 m .46467 .92347 L .46388 .9235 L .421 0 0 r
F
.46592 .92389 m .46562 .92379 L .46556 .92382 L F
.46562 .92379 m .46467 .92347 L .46556 .92382 L F
.46403 .9204 m .46122 .91706 L .45976 .91824 L .697 .051 0 r
F
.46122 .91706 m .46068 .91726 L .45976 .91824 L F
.46467 .92347 m .46091 .92221 L .46388 .9235 L .421 0 0 r
F
.46505 .92293 m .46231 .92153 L .46091 .92221 L .381 0 0 r
F
.46506 .92293 m .46231 .92153 L .46505 .92293 L F
.46391 .92166 m .45976 .91824 L .45864 .91922 L .752 .051 0 r
F
.46548 .92238 m .4641 .92138 L .46391 .92166 L F
.4641 .92138 m .45976 .91824 L .46391 .92166 L F
.46596 .92138 m .45976 .91824 L .46548 .92238 L .697 .051 0 r
F
.46532 .92441 m .45964 .92269 L .45853 .92303 L .437 0 0 r
F
.46546 .92444 m .46534 .9244 L .46532 .92441 L F
.46534 .9244 m .45964 .92269 L .46532 .92441 L F
.46592 .92389 m .45964 .92269 L .46546 .92444 L .421 0 0 r
F
.46546 .92444 m .45853 .92303 L .46505 .92486 L .437 0 0 r
F
.46505 .92486 m .45853 .92303 L .45832 .91946 L .592 .217 0 r
F
.46383 .92245 m .45864 .91922 L .45832 .91946 L .769 .046 0 r
F
.46507 .92313 m .46389 .92241 L .46383 .92245 L F
.46389 .92241 m .45864 .91922 L .46383 .92245 L F
.46505 .92486 m .45832 .91946 L .4637 .92253 L .592 .217 0 r
F
.46507 .92313 m .46383 .92245 L .4637 .92253 L .769 .046 0 r
F
.46383 .92245 m .45832 .91946 L .4637 .92253 L F
.46406 .92357 m .46442 .92465 L .46448 .92464 L .592 .217 0 r
F
.46384 .92303 m .46403 .92357 L .46406 .92357 L F
.46403 .92357 m .46442 .92465 L .46406 .92357 L F
.46278 .92343 m .45695 .92043 L .4564 .92077 L .646 .019 0 r
F
.46368 .92263 m .46382 .92304 L .46384 .92303 L .592 .217 0 r
F
.4637 .92253 m .4577 .91993 L .46358 .92308 L .769 .046 0 r
F
.46365 .92257 m .46368 .92264 L .46368 .92263 L .592 .217 0 r
F
.46368 .92264 m .46382 .92304 L .46368 .92263 L F
.46507 .92313 m .4637 .92253 L .46473 .9237 L .769 .046 0 r
F
.4637 .92253 m .45832 .91946 L .4577 .91993 L F
.46469 .92424 m .46392 .92292 L .46438 .92439 L .592 .217 0 r
F
.4647 .92518 m .46358 .92308 L .46325 .92307 L 1 .386 0 r
F
.46448 .92464 m .46442 .92465 L .4647 .92518 L .592 .217 0 r
F
.46469 .92424 m .46438 .92439 L .4647 .92518 L F
.4647 .92518 m .46343 .92334 L .46461 .92394 L 1 .386 0 r
F
.46445 .92413 m .46278 .92343 L .46425 .92445 L .646 .019 0 r
F
.46278 .92343 m .4564 .92077 L .46241 .92359 L F
.46278 .92343 m .46241 .92359 L .46425 .92445 L F
.46392 .92292 m .46373 .92257 L .46386 .92294 L .592 .217 0 r
F
.46392 .92292 m .46386 .92294 L .46438 .92439 L F
.46548 .92238 m .45864 .91922 L .46507 .92313 L .752 .051 0 r
F
.4637 .92253 m .45832 .91946 L .45793 .91255 L .592 .217 0 r
F
.46373 .92257 m .4635 .92218 L .46368 .92264 L F
.46373 .92257 m .46368 .92264 L .46438 .92439 L F
.46364 .92257 m .46339 .92274 L .46442 .92465 L F
.46473 .9237 m .46335 .92312 L .4634 .92317 L .738 .036 0 r
F
.46473 .9237 m .4634 .92317 L .46461 .92388 L F
.4637 .92253 m .46358 .92308 L .46473 .9237 L .769 .046 0 r
F
.46364 .92257 m .46442 .92465 L .46365 .92257 L .592 .217 0 r
F
.46473 .9237 m .46358 .92308 L .46335 .92312 L .738 .036 0 r
F
.4635 .92218 m .46364 .92257 L .46365 .92257 L .592 .217 0 r
F
.4635 .92218 m .46335 .92266 L .46339 .92274 L F
.4635 .92218 m .46339 .92274 L .46364 .92257 L F
.4635 .92218 m .45914 .91465 L .46331 .92258 L F
.45914 .91465 m .45793 .91255 L .45908 .91469 L F
.45914 .91465 m .45908 .91469 L .46331 .92258 L F
.45724 .91604 m .45715 .91426 L .45659 .91549 L 1 .202 0 r
F
.4635 .92218 m .46331 .92258 L .46343 .92238 L .592 .217 0 r
F
.46358 .92308 m .4577 .91993 L .46335 .92312 L .738 .036 0 r
F
.46318 .92297 m .45793 .91255 L .45715 .91426 L 1 .386 0 r
F
.46335 .92266 m .45793 .91255 L .46318 .92297 L F
.46461 .92388 m .45715 .91426 L .46448 .92207 L F
.46453 .92383 m .45715 .91426 L .46461 .92388 L F
.46382 .92304 m .46442 .92465 L .46384 .92303 L .592 .217 0 r
F
.46343 .92334 m .46325 .92307 L .46461 .92394 L 1 .386 0 r
F
.46335 .92312 m .46325 .92307 L .46334 .92313 L .738 .036 0 r
F
.46325 .92307 m .46335 .92266 L .46318 .92297 L 1 .386 0 r
F
.46358 .92308 m .46335 .92266 L .46325 .92307 L F
.46335 .92312 m .46327 .92308 L .46325 .92307 L .738 .036 0 r
F
.46327 .92308 m .4577 .91993 L .46325 .92307 L F
.46343 .92238 m .46331 .92258 L .46335 .92266 L .592 .217 0 r
F
.46325 .92307 m .45715 .91426 L .46453 .92383 L 1 .386 0 r
F
.46325 .92307 m .46453 .92383 L .46461 .92394 L F
.46334 .92313 m .45695 .92043 L .46311 .92347 L .738 .036 0 r
F
.46325 .92307 m .45695 .92043 L .46334 .92313 L F
.46448 .92207 m .45818 .91535 L .45724 .91604 L 1 .202 0 r
F
.45818 .91535 m .45715 .91426 L .45724 .91604 L F
.46461 .92394 m .46453 .92383 L .46461 .92388 L 1 .386 0 r
F
.46461 .92388 m .4634 .92317 L .46445 .92413 L .738 .036 0 r
F
.46335 .92312 m .46311 .92347 L .46445 .92413 L F
.46445 .92413 m .46311 .92347 L .46278 .92343 L .646 .019 0 r
F
.46311 .92347 m .45695 .92043 L .46278 .92343 L F
.46325 .92307 m .4577 .91993 L .45695 .92043 L .738 .036 0 r
F
.46505 .92486 m .46469 .92424 L .4647 .92518 L .592 .217 0 r
F
.46448 .92063 m .46409 .92021 L .46403 .9204 L .697 .051 0 r
F
.46409 .92021 m .46122 .91706 L .46403 .9204 L F
.46596 .92138 m .4647 .92023 L .46448 .92063 L F
.4647 .92023 m .46122 .91706 L .46448 .92063 L F
.46666 .9209 m .46643 .91834 L .46396 .91246 L .628 .068 0 r
F
.46643 .91834 m .46432 .91162 L .46396 .91246 L F
.46666 .9209 m .4666 .92083 L .46652 .92088 L .193 0 0 r
F
.46666 .9209 m .46396 .91246 L .46617 .92122 L .628 .068 0 r
F
.46643 .91834 m .46556 .90878 L .46432 .91162 L F
.46749 .91913 m .46556 .90878 L .46708 .9201 L 0 0 0 r
F
.46687 .9208 m .46685 .92078 L .46666 .9209 L .193 0 0 r
F
.46716 .92067 m .46713 .92065 L .46687 .9208 L F
.46716 .92067 m .46556 .90878 L .46666 .9209 L .628 .068 0 r
F
.46638 .91292 m .4629 .89291 L .4614 .90137 L .658 .126 0 r
F
.46639 .91237 m .4629 .89291 L .46638 .91292 L F
.46769 .89221 m .46811 .88913 L .46646 .89336 L 0 0 0 r
F
.46665 .89409 m .46646 .89336 L .46508 .89692 L F
.46769 .89221 m .46646 .89336 L .46665 .89409 L F
.46693 .89665 m .46508 .89692 L .46614 .89939 L F
.46877 .89025 m .46665 .89409 L .46693 .89665 L F
.46665 .89409 m .46508 .89692 L .46693 .89665 L F
.4672 .90329 m .46829 .77126 L .46776 .7975 L 1 .569 0 r
F
.46732 .88921 m .4672 .90329 L .4673 .88891 L 0 0 0 r
F
.46877 .89025 m .46867 .88768 L .46811 .88913 L F
.46877 .89025 m .46811 .88913 L .46769 .89221 L F
.46885 .89453 m .46913 .72947 L .4672 .90329 L .993 .526 0 r
F
.46913 .72947 m .46912 .7296 L .46911 .73076 L 0 0 0 r
F
.46899 .7426 m .46829 .77126 L .4672 .90329 L .993 .526 0 r
F
.46913 .72947 m .46859 .75627 L .46899 .7426 L F
.46859 .75627 m .46829 .77126 L .46899 .7426 L F
.46796 .8108 m .4673 .88877 L .46794 .80068 L 0 0 0 r
F
.4688 .90369 m .46885 .89453 L .46744 .90203 L F
.46882 .90371 m .46882 .90362 L .4688 .90369 L F
.46882 .90362 m .46885 .89453 L .4688 .90369 L F
.46883 .91687 m .46879 .90378 L .46821 .91928 L .13 .012 0 r
F
.46891 .90382 m .46744 .90203 L .46755 .9034 L 0 0 0 r
F
.46823 .91866 m .46822 .91078 L .46821 .91928 L .13 .012 0 r
F
.46879 .90378 m .46822 .91078 L .46823 .91866 L F
.46879 .90378 m .46755 .9034 L .46822 .91078 L 0 0 0 r
F
.46755 .9034 m .4672 .90329 L .46777 .90751 L F
.46755 .9034 m .46777 .90751 L .46822 .91078 L F
.46822 .91078 m .46837 .78752 L .46794 .80068 L .232 .03 0 r
F
.46822 .90995 m .46777 .90751 L .46732 .88921 L 0 0 0 r
F
.46822 .90997 m .46822 .90996 L .46822 .90995 L F
.46822 .90996 m .46777 .90751 L .46822 .90995 L F
.46822 .91078 m .46777 .90751 L .46822 .90997 L F
.46879 .90378 m .46837 .78752 L .46822 .90689 L .13 .012 0 r
F
.46833 .88874 m .46732 .88877 L .46799 .80722 L 0 0 0 r
F
.46732 .88877 m .4673 .88877 L .46799 .80722 L F
.46829 .77126 m .46834 .76493 L .46776 .7975 L 1 .569 0 r
F
.46834 .76493 m .46851 .74423 L .4681 .7733 L F
.46834 .76493 m .4681 .7733 L .46776 .7975 L F
.46763 .79005 m .46761 .79011 L .46762 .79035 L .14 .012 0 r
F
.46815 .74108 m .46479 .76277 L .46552 .79728 L .081 0 0 r
F
.46763 .79005 m .46852 .65651 L .46813 .6582 L 1 .569 0 r
F
.4672 .90329 m .46785 .78245 L .46763 .79005 L F
.46785 .78245 m .46852 .65651 L .46763 .79005 L F
.4672 .90329 m .46754 .81274 L .46794 .80068 L F
.46763 .79056 m .46763 .79005 L .46794 .80068 L F
.46794 .80068 m .46762 .79035 L .46639 .84796 L .14 .012 0 r
F
.46762 .79035 m .46761 .79011 L .46757 .79207 L F
.46762 .79035 m .46757 .79207 L .46639 .84796 L F
.46763 .79005 m .46762 .79035 L .46794 .80068 L F
.46788 .7892 m .46763 .79005 L .46794 .80068 L F
.46794 .80068 m .46763 .79005 L .46796 .79808 L 1 .569 0 r
F
.46833 .88899 m .4673 .88891 L .4673 .88877 L 0 0 0 r
F
.46833 .88899 m .4673 .88877 L .46833 .88874 L F
.46879 .90378 m .46822 .91078 L .46827 .91115 L F
.46879 .90378 m .46822 .90689 L .46822 .91078 L .13 .012 0 r
F
.46827 .91115 m .4673 .88891 L .46833 .88899 L 0 0 0 r
F
.46821 .91928 m .46822 .91078 L .46639 .84796 L .232 .03 0 r
F
.46809 .91325 m .46795 .90825 L .46799 .90878 L F
.46812 .91479 m .46807 .91299 L .46809 .91325 L F
.46807 .91299 m .46795 .90825 L .46809 .91325 L F
.46827 .91115 m .46822 .91078 L .46822 .90997 L 0 0 0 r
F
.46883 .91687 m .46891 .90346 L .46879 .90378 L .13 .012 0 r
F
.46891 .90382 m .46879 .90378 L .46827 .91115 L 0 0 0 r
F
.46885 .89453 m .46998 .70943 L .46913 .72947 L .993 .526 0 r
F
.46879 .90378 m .46995 .71984 L .46837 .78752 L .13 .012 0 r
F
.46885 .90362 m .46885 .89453 L .46882 .90371 L 0 0 0 r
F
.46889 .90352 m .46885 .89453 L .46885 .90375 L F
.46891 .90367 m .46885 .89453 L .46889 .9038 L F
.46891 .90346 m .46995 .71984 L .46879 .90378 L .13 .012 0 r
F
.46885 .90375 m .46885 .90362 L .46882 .90371 L 0 0 0 r
F
.46889 .9038 m .46889 .90352 L .46885 .90375 L F
.46764 .9154 m .46765 .91068 L .46704 .91814 L .867 .395 0 r
F
.46755 .9034 m .46744 .90203 L .4672 .90329 L 0 0 0 r
F
.46777 .90751 m .4672 .90329 L .46728 .89369 L F
.46777 .90751 m .46728 .89369 L .46732 .88921 L F
.46822 .91078 m .46794 .80068 L .46639 .84796 L .232 .03 0 r
F
.46761 .79011 m .46552 .79728 L .46622 .83812 L .14 .012 0 r
F
.46761 .79011 m .46622 .83812 L .46639 .84796 L F
.46785 .9051 m .46639 .84796 L .46787 .90533 L .232 .03 0 r
F
.46768 .89475 m .46639 .84796 L .46768 .89471 L F
.46769 .8983 m .46639 .84796 L .46768 .89475 L F
.46702 .9077 m .46636 .89971 L .46638 .90538 L .485 .065 0 r
F
.46707 .90721 m .46456 .87796 L .46702 .9077 L F
.46773 .89705 m .46768 .89475 L .46774 .8968 L .232 .03 0 r
F
.46769 .8983 m .46768 .89475 L .46773 .89705 L F
.46828 .90719 m .46775 .89695 L .46799 .90878 L 0 0 0 r
F
.46775 .89695 m .46774 .89675 L .46774 .89702 L F
.46775 .89695 m .46774 .89702 L .46799 .90878 L F
.46769 .8983 m .46774 .8968 L .46778 .89865 L .232 .03 0 r
F
.468 .90884 m .46769 .8983 L .46778 .89865 L F
.46795 .90633 m .46778 .89865 L .46779 .8987 L F
.468 .90884 m .46778 .89865 L .46795 .90633 L F
.46798 .80895 m .46796 .8108 L .46794 .80068 L 0 0 0 r
F
.46799 .80722 m .46798 .80895 L .46796 .79808 L F
.46798 .80895 m .46794 .80068 L .46796 .79808 L F
.46837 .78752 m .46788 .7892 L .46794 .80068 L .14 .012 0 r
F
.46835 .76811 m .46829 .77126 L .46831 .77581 L 0 0 0 r
F
.46835 .76811 m .46831 .77581 L .46837 .78752 L F
.46912 .7296 m .46835 .76811 L .46837 .78752 L F
.46913 .72947 m .46926 .65328 L .46829 .77126 L .993 .526 0 r
F
.46995 .71984 m .46913 .72947 L .46837 .78752 L 0 0 0 r
F
.46913 .72947 m .46911 .73076 L .46837 .78752 L F
.46837 .78752 m .46829 .77126 L .46784 .78418 L .14 .012 0 r
F
.46788 .7892 m .46784 .78418 L .46763 .79005 L F
.46837 .78752 m .46784 .78418 L .46788 .7892 L F
.46784 .78418 m .46851 .74423 L .46798 .75697 L 1 .569 0 r
F
.46803 .77868 m .46851 .74423 L .46784 .78418 L F
.46798 .75697 m .46926 .65328 L .46852 .65651 L F
.46851 .74423 m .46926 .65328 L .46798 .75697 L F
.46842 .85231 m .46796 .79808 L .46891 .66575 L 0 0 0 r
F
.46833 .88874 m .46796 .79808 L .46842 .85231 L F
.46814 .77222 m .46813 .6582 L .46891 .66575 L 1 .569 0 r
F
.46796 .79808 m .46799 .77066 L .46814 .77222 L F
.46799 .77066 m .46813 .6582 L .46814 .77222 L F
.46763 .79005 m .46813 .6582 L .46796 .79808 L F
.46767 .89378 m .46891 .66575 L .46796 .68176 L .867 .395 0 r
F
.46795 .90825 m .46769 .8983 L .468 .90884 L .232 .03 0 r
F
.46764 .9154 m .46774 .89714 L .46767 .89787 L .867 .395 0 r
F
.46765 .91068 m .46767 .89787 L .46706 .9141 L F
.46767 .89787 m .46456 .87796 L .46694 .90573 L .312 .043 0 r
F
.46767 .89787 m .46694 .90573 L .46705 .90708 L F
.46767 .89787 m .46639 .84796 L .46456 .87796 L F
.46774 .89714 m .46774 .89675 L .46767 .89787 L .867 .395 0 r
F
.46778 .89857 m .46774 .8968 L .46779 .89866 L .232 .03 0 r
F
.46778 .89857 m .46779 .89866 L .46779 .8987 L F
.46778 .89865 m .46778 .89857 L .46779 .8987 L F
.46779 .8987 m .46768 .89475 L .46779 .89866 L F
.46779 .89866 m .46773 .89644 L .46767 .89787 L .312 .043 0 r
F
.46768 .89475 m .46768 .89471 L .46779 .89866 L .232 .03 0 r
F
.46773 .89644 m .46639 .84796 L .46767 .89787 L .312 .043 0 r
F
.46767 .89787 m .46767 .89378 L .46743 .90173 L .867 .395 0 r
F
.46767 .89787 m .46743 .90173 L .46706 .9141 L F
.46753 .90016 m .46767 .89787 L .46705 .90708 L .312 .043 0 r
F
.46768 .89795 m .46767 .89787 L .46753 .90016 L F
.46767 .89787 m .46774 .89675 L .46767 .89378 L .867 .395 0 r
F
.46774 .89675 m .46891 .66575 L .46767 .89378 L F
.4681 .91483 m .46785 .9051 L .46812 .91479 L .232 .03 0 r
F
.46785 .9051 m .46787 .90533 L .46812 .91479 L F
.46799 .90878 m .46774 .89675 L .46767 .91059 L 0 0 0 r
F
.46753 .90016 m .46705 .90708 L .46709 .90745 L .312 .043 0 r
F
.46767 .89378 m .46722 .87234 L .46709 .90745 L .867 .395 0 r
F
.46703 .9119 m .46702 .9077 L .46683 .90996 L .759 .293 0 r
F
.46703 .9119 m .46681 .90977 L .46648 .92003 L F
.46679 .90995 m .46638 .90815 L .46645 .91274 L .485 .065 0 r
F
.46638 .90815 m .4629 .89291 L .46639 .91237 L F
.46638 .90815 m .46639 .91237 L .46645 .91274 L F
.46702 .9077 m .46638 .90538 L .46679 .90995 L F
.46638 .90538 m .4629 .89291 L .46638 .90815 L F
.46638 .90538 m .46638 .90815 L .46679 .90995 L F
.46641 .91583 m .46639 .91448 L .4664 .91583 L .67 .209 0 r
F
.46636 .89971 m .46456 .87796 L .46638 .90538 L .485 .065 0 r
F
.46638 .91436 m .4614 .90137 L .46602 .91652 L .658 .126 0 r
F
.46639 .91448 m .46638 .91389 L .46639 .91459 L .67 .209 0 r
F
.46638 .91389 m .46638 .91397 L .46639 .91459 L F
.46638 .91292 m .46638 .91367 L .46641 .91583 L F
.46648 .92003 m .46648 .91292 L .46639 .91311 L F
.46655 .91331 m .46648 .91292 L .46638 .91292 L .658 .126 0 r
F
.46648 .91292 m .46639 .91237 L .46638 .91292 L F
.46763 .79005 m .46681 .76978 L .46552 .79728 L .14 .012 0 r
F
.46639 .84796 m .46552 .79728 L .46254 .84376 L .337 .049 0 r
F
.46639 .84796 m .46254 .84376 L .46456 .87796 L F
.46638 .91292 m .46663 .71314 L .4645 .77178 L .67 .209 0 r
F
.46639 .91311 m .46639 .91292 L .46638 .91292 L F
.46639 .91292 m .46663 .71314 L .46638 .91292 L F
.46681 .90977 m .46648 .91292 L .46648 .92003 L .759 .293 0 r
F
.46692 .85887 m .46677 .85157 L .46683 .90996 L F
.46683 .90996 m .46677 .85157 L .46649 .90669 L F
.46702 .9077 m .46796 .68176 L .46663 .71314 L F
.46704 .91814 m .46709 .90745 L .46702 .9077 L F
.46709 .90745 m .46707 .90721 L .46702 .9077 L .485 .065 0 r
F
.46709 .90745 m .46796 .68176 L .46702 .9077 L .759 .293 0 r
F
.46732 .9056 m .46709 .90751 L .46706 .9141 L .867 .395 0 r
F
.46715 .90814 m .46709 .90745 L .46702 .9077 L .485 .065 0 r
F
.46705 .9078 m .46679 .90995 L .46648 .91292 L F
.46679 .90995 m .46645 .91274 L .46648 .91292 L F
.46702 .9077 m .46692 .85887 L .46683 .90957 L .759 .293 0 r
F
.46702 .9077 m .46683 .90957 L .46683 .90996 L F
.46648 .91292 m .46663 .71314 L .46639 .91311 L .67 .209 0 r
F
.46661 .91267 m .46648 .91292 L .46655 .91331 L .485 .065 0 r
F
.46705 .9078 m .46648 .91292 L .46661 .91267 L F
.46655 .91331 m .46638 .91292 L .46638 .91436 L .658 .126 0 r
F
.46638 .91292 m .4614 .90137 L .46638 .91436 L F
.46638 .91389 m .46618 .89898 L .46638 .91397 L .67 .209 0 r
F
.46639 .91448 m .46639 .91459 L .4664 .91583 L F
.46632 .90784 m .4663 .90799 L .46639 .91448 L F
.46639 .91421 m .46639 .91448 L .46641 .91583 L F
.46632 .90784 m .46639 .91448 L .46639 .91421 L F
.46681 .90977 m .46649 .90669 L .46648 .91292 L .759 .293 0 r
F
.46705 .9078 m .46702 .9077 L .46679 .90995 L .485 .065 0 r
F
.46715 .90814 m .46705 .9078 L .46655 .91331 L F
.46743 .90173 m .46709 .90745 L .46709 .90751 L .867 .395 0 r
F
.46743 .90173 m .46709 .90751 L .46732 .9056 L F
.46767 .89378 m .46709 .90745 L .46743 .90173 L F
.46768 .89795 m .46753 .90016 L .46715 .90814 L .312 .043 0 r
F
.46753 .90016 m .46709 .90745 L .46715 .90814 L F
.46779 .89866 m .46768 .89795 L .46715 .90814 L F
.46692 .85887 m .46663 .71314 L .46677 .85157 L .759 .293 0 r
F
.46828 .90719 m .46891 .66575 L .46774 .89675 L 0 0 0 r
F
.46767 .89378 m .46796 .68176 L .46722 .87234 L .867 .395 0 r
F
.46765 .91068 m .46706 .9141 L .46704 .91814 L F
.46812 .91479 m .46799 .90878 L .46807 .91249 L .232 .03 0 r
F
.46828 .90719 m .46767 .91059 L .46764 .9154 L 0 0 0 r
F
.46807 .91249 m .46799 .90878 L .468 .90884 L .232 .03 0 r
F
.46827 .91115 m .46828 .90719 L .46803 .91044 L 0 0 0 r
F
.46807 .91249 m .46803 .91044 L .46764 .9154 L F
.46827 .91115 m .46803 .91044 L .46807 .91249 L F
.46891 .90382 m .46891 .90367 L .46889 .9038 L F
.46677 .85157 m .46663 .71314 L .46654 .84052 L .759 .293 0 r
F
.46677 .85157 m .46654 .84052 L .46649 .90669 L F
.46626 .90361 m .46625 .90271 L .46626 .90356 L .67 .209 0 r
F
.46626 .90361 m .46626 .90356 L .4663 .90799 L F
.46632 .90784 m .46626 .90361 L .4663 .90799 L F
.46619 .8984 m .4645 .77178 L .46612 .89449 L F
.46624 .90332 m .46456 .87796 L .46626 .90497 L .485 .065 0 r
F
.46626 .90497 m .46456 .87796 L .4629 .89291 L F
.46618 .89898 m .4645 .77178 L .46618 .89899 L .67 .209 0 r
F
.46625 .90454 m .4645 .77178 L .46618 .90307 L F
.46543 .90882 m .46015 .86747 L .46512 .91329 L .808 .327 0 r
F
.46549 .90881 m .46015 .86747 L .46562 .9103 L F
.46565 .91005 m .46203 .83315 L .46166 .83992 L F
.46549 .90881 m .46166 .83992 L .46015 .86747 L F
.46565 .91005 m .46166 .83992 L .46549 .90881 L F
.46663 .71314 m .46484 .69904 L .46492 .76026 L .782 .297 0 r
F
.46484 .69904 m .464 .69239 L .46492 .76026 L F
.46492 .76026 m .464 .69239 L .4645 .77178 L F
.46618 .90326 m .4645 .77178 L .46203 .83315 L .693 .227 0 r
F
.46618 .90326 m .46203 .83315 L .46565 .91005 L F
.46396 .91246 m .46093 .90943 L .45847 .9123 L .374 .008 0 r
F
.46396 .91246 m .45847 .9123 L .46244 .91504 L F
.46602 .91652 m .4614 .90137 L .46007 .90663 L .789 .208 0 r
F
.4652 .91405 m .46015 .86747 L .46002 .86918 L .925 .422 0 r
F
.46546 .91857 m .46007 .90663 L .45891 .91013 L .891 .258 0 r
F
.46553 .91866 m .46547 .91852 L .46546 .91857 L F
.46547 .91852 m .46007 .90663 L .46546 .91857 L F
.46602 .91652 m .46007 .90663 L .46553 .91866 L .789 .208 0 r
F
.46308 .91635 m .46244 .91504 L .46298 .91639 L .749 .094 0 r
F
.46553 .91866 m .45891 .91013 L .46511 .92017 L .891 .258 0 r
F
.46511 .92017 m .46476 .9196 L .46476 .91142 L .611 .159 0 r
F
.46511 .92017 m .46476 .91142 L .4648 .91167 L F
.46511 .92017 m .46476 .91062 L .46511 .91361 L F
.46497 .92062 m .46511 .9142 L .46476 .92126 L F
.46511 .92017 m .46511 .92002 L .46497 .92062 L F
.46511 .92002 m .46511 .9142 L .46497 .92062 L F
.4648 .91167 m .46476 .91142 L .46476 .91062 L F
.4652 .91405 m .46002 .86918 L .46511 .91361 L .925 .422 0 r
F
.46203 .83315 m .46139 .81829 L .46166 .83992 L .937 .462 0 r
F
.46325 .74711 m .464 .69239 L .4619 .72048 L .898 .421 0 r
F
.4645 .77178 m .46417 .71964 L .46325 .74711 L F
.46417 .71964 m .464 .69239 L .46325 .74711 L F
.46 .85339 m .46042 .83126 L .45988 .85636 L 1 .846 0 r
F
.4619 .72048 m .46104 .69892 L .46017 .70878 L .967 .474 0 r
F
.46042 .71419 m .46017 .70878 L .45989 .71196 L F
.4619 .72048 m .46017 .70878 L .46042 .71419 L F
.46164 .80145 m .46075 .73785 L .46108 .72875 L .486 .071 0 r
F
.46248 .71269 m .46123 .69591 L .4619 .72048 L .845 .336 0 r
F
.46123 .69591 m .46104 .69892 L .4619 .72048 L F
.464 .69239 m .46169 .68871 L .46248 .71269 L F
.464 .69239 m .46277 .67828 L .46197 .68564 L F
.4665 .65458 m .46568 .65406 L .4634 .65672 L .109 0 0 r
F
.4665 .65458 m .4634 .65672 L .46459 .65792 L F
.46577 .66018 m .46459 .65792 L .46266 .66215 L .387 .034 0 r
F
.46577 .66018 m .46266 .66215 L .46416 .66622 L F
.46559 .67563 m .46416 .66622 L .46245 .67464 L .685 .157 0 r
F
.46559 .67563 m .46245 .67464 L .464 .69239 L F
.4645 .77178 m .4619 .72048 L .46203 .83315 L .898 .421 0 r
F
.46232 .75574 m .46108 .72875 L .46383 .65427 L .486 .071 0 r
F
.46164 .80145 m .46108 .72875 L .46232 .75574 L F
.46042 .83126 m .46383 .65427 L .46031 .83479 L 1 .846 0 r
F
.46042 .83126 m .46031 .83479 L .45988 .85636 L F
.46476 .9196 m .46065 .91295 L .46352 .74027 L .611 .159 0 r
F
.46065 .91295 m .45891 .91013 L .45994 .87194 L F
.46015 .86747 m .46 .85339 L .45975 .86041 L .974 .494 0 r
F
.46015 .86747 m .45975 .86041 L .45979 .86276 L F
.46065 .91295 m .45994 .87194 L .46002 .86918 L .611 .159 0 r
F
.46015 .86747 m .45979 .86276 L .46002 .86918 L .974 .494 0 r
F
.46113 .8247 m .46 .85339 L .46015 .86747 L .937 .462 0 r
F
.46095 .89483 m .46002 .86918 L .46352 .74027 L .611 .159 0 r
F
.46065 .91295 m .46002 .86918 L .46095 .89483 L F
.45979 .86276 m .4597 .86166 L .46002 .86918 L .974 .494 0 r
F
.45979 .86276 m .45975 .86041 L .4597 .86166 L F
.46169 .68871 m .46125 .69226 L .46104 .69892 L .352 .054 0 r
F
.46169 .68871 m .46138 .67926 L .46186 .6812 L F
.46169 .68871 m .46116 .68298 L .46056 .68689 L .845 .336 0 r
F
.46666 .65221 m .46623 .65239 L .46244 .65372 L .254 .18 0 r
F
.46666 .65221 m .46244 .65372 L .46324 .6537 L F
.46186 .6812 m .46133 .67904 L .46263 .64766 L .352 .054 0 r
F
.46169 .68871 m .46263 .64766 L .46125 .69226 L F
.46015 .70227 m .46263 .64766 L .46158 .64945 L 1 .85 0 r
F
.46123 .68373 m .46116 .68298 L .46123 .68364 L .352 .054 0 r
F
.46123 .68364 m .46116 .68298 L .46133 .67904 L F
.46125 .69226 m .46263 .64766 L .46015 .70227 L 1 .85 0 r
F
.46277 .67828 m .46245 .67464 L .46197 .68564 L .845 .336 0 r
F
.46709 .65203 m .46666 .65221 L .46324 .6537 L 0 0 0 r
F
.46709 .65203 m .46324 .6537 L .46405 .65372 L F
.46108 .72875 m .46158 .64945 L .46383 .65427 L 1 .85 0 r
F
.45971 .8608 m .46383 .65427 L .46303 .65861 L 1 .846 0 r
F
.45988 .85636 m .46383 .65427 L .45971 .8608 L F
.46113 .8247 m .46112 .82422 L .46 .85339 L .937 .462 0 r
F
.46139 .81829 m .46383 .65427 L .46 .85339 L .486 .071 0 r
F
.45891 .91013 m .45946 .88125 L .45928 .88735 L 1 .846 0 r
F
.45891 .91013 m .46303 .65861 L .46484 .69202 L F
.46002 .86918 m .4597 .86166 L .4588 .88487 L .974 .494 0 r
F
.46476 .9196 m .46352 .74027 L .46484 .69202 L .611 .159 0 r
F
.46509 .91371 m .46471 .91193 L .46476 .91627 L .925 .422 0 r
F
.46471 .91193 m .4588 .88487 L .46473 .91608 L F
.46471 .91193 m .46473 .91608 L .46476 .91627 L F
.46473 .91631 m .4588 .88487 L .4578 .89461 L 1 .494 0 r
F
.46511 .91361 m .4588 .88487 L .46509 .91371 L .925 .422 0 r
F
.46511 .91361 m .46509 .91371 L .46519 .91414 L F
.4651 .91368 m .46476 .91838 L .46476 .92126 L .611 .159 0 r
F
.46511 .91348 m .46509 .91377 L .4651 .91368 L F
.46509 .91377 m .46476 .91838 L .4651 .91368 L F
.46511 .91361 m .46002 .86918 L .4588 .88487 L .925 .422 0 r
F
.46511 .91361 m .46476 .91062 L .46484 .69202 L .611 .159 0 r
F
.465 .82863 m .4648 .81648 L .46476 .91627 L F
.46477 .91632 m .46476 .91634 L .46476 .91838 L F
.46474 .91784 m .46473 .91636 L .46473 .91758 L 1 .607 0 r
F
.46473 .9165 m .4578 .89461 L .4644 .91792 L 1 .494 0 r
F
.46473 .91608 m .4588 .88487 L .46473 .91631 L F
.46473 .91631 m .46484 .69202 L .4634 .72486 L 1 .607 0 r
F
.46476 .92126 m .46476 .91627 L .46473 .91631 L F
.46475 .91629 m .46473 .91608 L .46473 .91631 L 1 .494 0 r
F
.46476 .91627 m .46473 .91608 L .46475 .91639 L F
.46476 .91627 m .46484 .69202 L .46473 .91631 L 1 .607 0 r
F
.46475 .91639 m .46475 .91629 L .46473 .91631 L 1 .494 0 r
F
.46475 .91639 m .46473 .91631 L .46473 .9165 L F
.46473 .91631 m .4578 .89461 L .46473 .9165 L F
.46473 .91725 m .46472 .9157 L .46472 .91567 L 1 .607 0 r
F
.46473 .91758 m .46473 .91683 L .46473 .91725 L F
.46473 .91662 m .4644 .91792 L .46454 .91841 L 1 .494 0 r
F
.46475 .91639 m .46473 .9165 L .46473 .91662 L F
.46473 .9165 m .4644 .91792 L .46473 .91662 L F
.46473 .91626 m .46472 .9157 L .46473 .91683 L 1 .607 0 r
F
.46473 .9164 m .46473 .91683 L .46473 .91758 L F
.46473 .91626 m .46473 .91683 L .46473 .9164 L F
.46473 .91683 m .46472 .9157 L .46473 .91725 L F
.46473 .91636 m .46473 .91626 L .46473 .9164 L F
.46473 .91636 m .46473 .9164 L .46473 .91758 L F
.46509 .91377 m .46477 .91623 L .46476 .91838 L .611 .159 0 r
F
.46483 .91664 m .46475 .91639 L .46473 .91662 L 1 .494 0 r
F
.46473 .91725 m .46473 .91662 L .46454 .91841 L F
.46473 .91631 m .46473 .91626 L .46474 .91784 L 1 .607 0 r
F
.46483 .91664 m .46473 .91662 L .46473 .91725 L 1 .494 0 r
F
.46477 .91622 m .46476 .91627 L .46476 .91634 L .611 .159 0 r
F
.46477 .91622 m .46476 .91634 L .46477 .91632 L F
.465 .82863 m .46476 .91627 L .46477 .91622 L F
.46483 .91664 m .46476 .91627 L .46475 .91639 L 1 .494 0 r
F
.46476 .92126 m .46473 .91631 L .46474 .91784 L 1 .607 0 r
F
.46511 .91348 m .465 .82863 L .46477 .91623 L .611 .159 0 r
F
.46511 .91348 m .46477 .91623 L .46509 .91377 L F
.46511 .9142 m .46511 .91348 L .46508 .91398 L F
.46519 .91414 m .46509 .91371 L .46483 .91664 L .925 .422 0 r
F
.46509 .91371 m .46476 .91627 L .46483 .91664 L F
.4652 .91405 m .46511 .91361 L .46519 .91414 L F
.465 .82863 m .46484 .69202 L .4648 .81648 L .611 .159 0 r
F
.46625 .90271 m .46619 .8984 L .46623 .90282 L .67 .209 0 r
F
.46619 .8984 m .46612 .89449 L .46623 .90282 L F
.46625 .90271 m .46623 .90282 L .4663 .90799 L F
.46511 .9142 m .46508 .91398 L .46476 .92126 L .611 .159 0 r
F
.46117 .9171 m .46103 .91689 L .46122 .91706 L .84 .129 0 r
F
.46122 .91706 m .46103 .91689 L .46068 .91726 L .697 .051 0 r
F
.46674 .9209 m .46632 .92189 L .467 .92223 L .193 0 0 r
F
.46818 .92284 m .46749 .91913 L .46716 .92067 L 0 0 0 r
F
.46749 .91913 m .46708 .9201 L .46716 .92067 L F
.46793 .92322 m .46716 .92067 L .46757 .92374 L F
.46818 .92284 m .46817 .92284 L .46817 .9228 L F
.46818 .92284 m .46716 .92067 L .46793 .92322 L F
.46793 .92322 m .46716 .92067 L .4679 .92305 L .493 .032 0 r
F
.4679 .92305 m .46716 .92067 L .46759 .92098 L F
.46759 .92098 m .46716 .92067 L .46666 .9209 L .193 0 0 r
F
.4664 .91424 m .46638 .91292 L .46641 .91583 L .67 .209 0 r
F
.46638 .91292 m .46632 .90784 L .46638 .91367 L F
.46618 .89898 m .46618 .89899 L .4664 .91583 L F
.46642 .91584 m .4664 .91424 L .46641 .91583 L F
.4664 .91583 m .46625 .90454 L .46618 .90326 L F
.46625 .90454 m .46618 .90307 L .46618 .90326 L F
.46704 .91814 m .46703 .9119 L .46648 .92003 L .759 .293 0 r
F
.46648 .92003 m .46642 .91584 L .4664 .91583 L .67 .209 0 r
F
.46562 .9103 m .46543 .90882 L .4652 .91405 L .808 .327 0 r
F
.46543 .90882 m .46512 .91329 L .4652 .91405 L F
.4597 .86166 m .45969 .86159 L .45968 .86189 L .974 .494 0 r
F
.4597 .86166 m .45968 .86189 L .4588 .88487 L F
.45969 .86159 m .45579 .81145 L .45847 .87683 L F
.45969 .86159 m .45847 .87683 L .4588 .88487 L F
.46565 .91005 m .46549 .90881 L .46562 .9103 L .808 .327 0 r
F
.46464 .90363 m .46458 .89492 L .46464 .90373 L 1 .607 0 r
F
.46458 .89492 m .4634 .72486 L .46458 .89496 L F
.46458 .89492 m .46458 .89496 L .46464 .90373 L F
.46472 .9157 m .46464 .90363 L .46472 .91567 L F
.46464 .90363 m .46464 .90373 L .46472 .91567 L F
.46472 .91567 m .46457 .89366 L .46468 .90989 L F
.46457 .89366 m .4634 .72486 L .46456 .8937 L F
.46457 .89366 m .46456 .8937 L .46468 .90989 L F
.46821 .91928 m .4681 .91483 L .46812 .91479 L .232 .03 0 r
F
.47079 .87825 m .47079 .87825 L .47066 .89642 L .535 .09 0 r
F
.47214 .91229 m .47241 .90999 L .47168 .91615 L 1 .749 0 r
F
.47037 .6948 m .47035 .64964 L .47004 .69996 L .941 .475 0 r
F
.47095 .68366 m .47064 .69061 L .47053 .69235 L .803 .164 0 r
F
.47095 .68366 m .47037 .6948 L .46995 .71984 L F
.47037 .6948 m .46998 .70951 L .46995 .71984 L F
.47197 .87016 m .47211 .8556 L .47212 .85426 L 0 0 0 r
F
.47168 .90175 m .47198 .87014 L .47197 .87016 L F
.46998 .70943 m .46998 .70895 L .46913 .72947 L F
.46998 .70943 m .47035 .64964 L .46913 .72947 L .993 .526 0 r
F
.46995 .71984 m .46998 .70943 L .46913 .72947 L 0 0 0 r
F
.46075 .73785 m .45989 .71196 L .46108 .72875 L 1 .85 0 r
F
.46075 .73785 m .45831 .70526 L .45902 .7639 L .967 .474 0 r
F
.45989 .71196 m .45831 .70526 L .46075 .73785 L F
.45902 .7639 m .45866 .73457 L .45747 .75009 L 1 .571 0 r
F
.45866 .73457 m .45831 .70526 L .45747 .75009 L F
.45989 .71196 m .46125 .69226 L .46015 .70227 L 1 .85 0 r
F
.46068 .70304 m .46125 .69226 L .45989 .71196 L F
.45989 .71196 m .46158 .64945 L .46108 .72875 L F
.45989 .71196 m .45981 .71078 L .45975 .71135 L .967 .474 0 r
F
.45817 .66848 m .45665 .669 L .4592 .67302 L .751 .12 0 r
F
.4592 .67302 m .45756 .66869 L .45931 .67091 L 1 .844 0 r
F
.4592 .67302 m .45665 .669 L .45868 .67492 L .751 .12 0 r
F
.45924 .6732 m .4592 .67302 L .45931 .67091 L .346 .053 0 r
F
.45975 .67183 m .45931 .67091 L .46057 .64621 L F
.45817 .66848 m .45741 .66802 L .45756 .66869 L .751 .12 0 r
F
.45792 .66796 m .45741 .66802 L .45817 .66848 L F
.45741 .66802 m .45706 .66806 L .45726 .66831 L F
.45741 .66802 m .45726 .66831 L .45756 .66869 L F
.45868 .67492 m .45712 .67036 L .45523 .67539 L .895 .302 0 r
F
.45712 .67036 m .45665 .669 L .45523 .67539 L F
.45756 .66869 m .45925 .66424 L .4576 .6677 L 1 .844 0 r
F
.45923 .66465 m .45925 .66424 L .45756 .66869 L F
.45756 .66869 m .45706 .66806 L .45665 .669 L .751 .12 0 r
F
.4576 .6677 m .45766 .66712 L .45763 .66703 L 1 .844 0 r
F
.45766 .66712 m .4602 .64479 L .45763 .66703 L F
.45763 .66703 m .4602 .64479 L .4585 .64543 L F
.45936 .66311 m .45832 .66248 L .45892 .66388 L .487 .031 0 r
F
.45925 .66424 m .4602 .64479 L .4576 .6677 L 1 .844 0 r
F
.45931 .67091 m .45763 .66703 L .45944 .66842 L F
.45756 .66869 m .45763 .66703 L .45931 .67091 L F
.45937 .66312 m .45936 .66311 L .45938 .66269 L .204 .027 0 r
F
.45951 .6638 m .4602 .64479 L .45925 .66424 L F
.45944 .66842 m .4585 .64543 L .46057 .64621 L 1 .844 0 r
F
.45763 .66703 m .4585 .64543 L .45944 .66842 L F
.45784 .66138 m .45758 .66109 L .45705 .66172 L .487 .031 0 r
F
.45765 .66117 m .45759 .66088 L .45766 .66096 L .194 .025 0 r
F
.45758 .66109 m .45759 .66088 L .45765 .66117 L F
.45784 .66138 m .45766 .66096 L .45785 .66117 L F
.45668 .6597 m .45605 .65993 L .45758 .66109 L .418 .008 0 r
F
.45758 .6611 m .45758 .66109 L .45759 .66088 L .194 .025 0 r
F
.45758 .66109 m .45606 .65985 L .4576 .66051 L 1 .818 0 r
F
.45605 .65993 m .45606 .65985 L .45758 .66109 L F
.45758 .66109 m .45521 .66024 L .45705 .66172 L .418 .008 0 r
F
.45605 .65993 m .45521 .66024 L .45758 .66109 L F
.45705 .66172 m .45557 .66053 L .45294 .66303 L .64 .047 0 r
F
.45557 .66053 m .45521 .66024 L .45294 .66303 L F
.45606 .65985 m .45664 .64445 L .4576 .66038 L 1 .818 0 r
F
.45665 .6601 m .4576 .66038 L .4576 .66051 L F
.45606 .65985 m .4576 .66038 L .45665 .6601 L F
.45605 .65993 m .45584 .65987 L .45521 .66024 L .418 .008 0 r
F
.45785 .66117 m .45759 .66088 L .45761 .66039 L .194 .025 0 r
F
.45787 .66057 m .45761 .66039 L .45842 .64457 L F
.45785 .66117 m .45761 .66039 L .45787 .66057 L F
.45398 .65899 m .45338 .65917 L .4556 .6599 L .377 0 0 r
F
.4582 .64878 m .45664 .64445 L .45842 .64457 L 1 .818 0 r
F
.45765 .65967 m .45664 .64445 L .4582 .64878 L F
.4576 .66051 m .45755 .65965 L .45765 .65967 L F
.45755 .65965 m .45664 .64445 L .45765 .65967 L F
.456 .6564 m .4558 .65635 L .45505 .65667 L .155 0 0 r
F
.4558 .65635 m .4558 .65635 L .4558 .65626 L .021 0 0 r
F
.45505 .65667 m .45384 .65637 L .45002 .65765 L .298 0 0 r
F
.45384 .65637 m .45354 .6563 L .45002 .65765 L F
.45457 .65607 m .45474 .64446 L .45577 .65608 L 1 .789 0 r
F
.45457 .65607 m .45426 .65606 L .45354 .6563 L .129 0 0 r
F
.4558 .65637 m .4557 .65525 L .45584 .65521 L 1 .789 0 r
F
.4557 .65525 m .45474 .64446 L .45584 .65521 L F
.45584 .65521 m .45474 .64446 L .45619 .64439 L F
.46476 .65278 m .46476 .65279 L .46372 .65293 L .137 .164 0 r
F
.46507 .65273 m .46372 .65293 L .4651 .65278 L F
.46507 .65273 m .4638 .65291 L .4638 .65293 L 0 0 0 r
F
.464 .6529 m .4638 .65293 L .46413 .65293 L .137 .164 0 r
F
.46507 .65273 m .46507 .65274 L .46506 .65272 L 0 0 0 r
F
.46507 .65273 m .46506 .65272 L .46406 .64516 L F
.46507 .65274 m .46505 .65267 L .46506 .65267 L F
.4647 .65262 m .4643 .65266 L .46473 .65271 L F
.4644 .65265 m .46472 .65265 L .46473 .65271 L F
.46473 .65271 m .46472 .65264 L .46472 .65264 L F
.4644 .65264 m .46438 .65258 L .46439 .65258 L 1 .681 0 r
F
.46439 .65264 m .46438 .65258 L .4644 .65264 L F
.46507 .65273 m .46406 .64516 L .4638 .65291 L 0 0 0 r
F
.46967 .64501 m .46963 .6449 L .46965 .64501 L .084 0 0 r
F
.4696 .64478 m .46959 .64473 L .46963 .6449 L .994 .647 0 r
F
.4952 .64755 m .49616 .64718 L .48934 .64825 L .031 0 0 r
F
.4952 .64755 m .48934 .64825 L .4892 .64832 L F
.4952 .64755 m .4892 .64832 L .4887 .64861 L F
.49864 .64649 m .49632 .64159 L .49692 .64683 L 1 .519 0 r
F
.49868 .64649 m .49869 .64648 L .49864 .64649 L 0 0 0 r
F
.49869 .64648 m .49889 .6464 L .49864 .64649 L F
.49892 .64646 m .49891 .6464 L .49889 .6464 L 1 .517 0 r
F
.50434 .64554 m .49889 .6464 L .49868 .64649 L 0 0 0 r
F
.49966 .64609 m .49965 .64606 L .49938 .6462 L 1 .517 0 r
F
.49966 .64609 m .49938 .6462 L .49892 .64646 L F
.49965 .64606 m .49964 .64604 L .4995 .64612 L F
.49965 .64606 m .4995 .64612 L .49892 .64646 L F
.50434 .64554 m .49868 .64649 L .49793 .64682 L 0 0 0 r
F
.49996 .64608 m .49993 .64596 L .49991 .64598 L .807 .51 0 r
F
.5056 .64508 m .49963 .64603 L .49889 .6464 L .019 0 0 r
F
.49889 .6464 m .49724 .64116 L .49632 .64159 L 1 .517 0 r
F
.49891 .6464 m .49724 .64116 L .49889 .6464 L F
.50685 .64458 m .50061 .64551 L .49988 .64592 L .053 0 0 r
F
.49988 .64592 m .49815 .64069 L .49724 .64116 L .807 .51 0 r
F
.49989 .64592 m .49815 .64069 L .49988 .64592 L F
.65487 .5006 m .65761 .50684 L .6568 .5098 L .974 .354 0 r
F
.65487 .5006 m .65559 .49767 L .65761 .50684 L F
.3789 .6139 m .36867 .6083 L .37035 .60993 L .71 .042 0 r
F
.38047 .61542 m .3789 .6139 L .37035 .60993 L .692 .036 0 r
F
.76664 .43629 m .77046 .4451 L .77116 .44995 L .769 .117 0 r
F
.76664 .43629 m .76554 .43159 L .77046 .4451 L F
.90322 .44413 m .90065 .45775 L .90095 .46471 L 0 0 0 r
F
.90322 .44413 m .90359 .43704 L .90065 .45775 L F
.72966 .63593 m .72309 .64276 L .72065 .64674 L F
.72966 .63593 m .73223 .63182 L .72309 .64276 L F
.39749 .68575 m .38247 .684 L .38428 .68637 L .913 .066 0 r
F
.39912 .68778 m .39749 .68575 L .38428 .68637 L .905 .066 0 r
F
.30694 .60093 m .29783 .59052 L .29888 .59369 L 1 .131 0 r
F
.30805 .60398 m .30694 .60093 L .29888 .59369 L 1 .128 0 r
F
.57785 .90908 m .56067 .9104 L .5575 .91221 L .139 0 0 r
F
.62157 .54357 m .61765 .54785 L .61674 .55023 L 0 0 0 r
F
.62157 .54357 m .62252 .54114 L .61765 .54785 L F
.40986 .64114 m .39805 .63825 L .39973 .63946 L .626 .016 0 r
F
.41132 .64223 m .40986 .64114 L .39973 .63946 L .601 .011 0 r
F
.60254 .89117 m .58684 .89369 L .58308 .89566 L .024 0 0 r
F
.60254 .89117 m .60697 .88911 L .58684 .89369 L F
.6003 .37418 m .60086 .37883 L .60261 .38089 L 0 .036 0 r
F
.6003 .37418 m .59854 .37222 L .60086 .37883 L F
.37445 .62434 m .36294 .61942 L .36476 .62115 L .777 .049 0 r
F
.37613 .62595 m .37445 .62434 L .36476 .62115 L .748 .044 0 r
F
.63408 .49037 m .6319 .4953 L .63176 .49791 L 0 0 0 r
F
.63408 .49037 m .63424 .48774 L .6319 .4953 L F
.62986 .42701 m .62916 .43215 L .63009 .4347 L F
.62986 .42701 m .6289 .4245 L .62916 .43215 L F
.59885 .37538 m .60035 .37923 L .60216 .38124 L 0 .035 0 r
F
.59885 .37538 m .59696 .37357 L .60035 .37923 L F
.33191 .63956 m .31993 .63136 L .32145 .63441 L 1 .133 0 r
F
.33344 .64242 m .33191 .63956 L .32145 .63441 L 1 .124 0 r
F
.55206 .79229 m .55509 .79157 L .5421 .80793 L 1 1 0 r
F
.49815 .64069 m .48941 .64126 L .48882 .64176 L .186 0 0 r
F
.49815 .64069 m .49905 .64016 L .48941 .64126 L F
.58158 .60625 m .57559 .60907 L .57394 .61073 L 0 0 0 r
F
.58158 .60625 m .58336 .60451 L .57559 .60907 L F
.32681 .57976 m .3172 .57158 L .31857 .57405 L .939 .103 0 r
F
.32813 .5821 m .32681 .57976 L .31857 .57405 L .914 .099 0 r
F
.53119 .63158 m .52382 .63313 L .52244 .63397 L .022 0 0 r
F
.53119 .63158 m .53281 .63068 L .52382 .63313 L F
.44825 .64882 m .43705 .6478 L .43803 .64855 L .459 0 0 r
F
.44893 .64947 m .44825 .64882 L .43803 .64855 L .435 0 0 r
F
.6467 .72074 m .65052 .71847 L .63997 .7284 L .595 .226 0 r
F
.50821 .63869 m .49994 .63959 L .49905 .64016 L .133 0 0 r
F
.50821 .63869 m .50938 .63809 L .49994 .63959 L F
.63862 .56038 m .63672 .56631 L .63537 .56891 L .714 .198 0 r
F
.63862 .56038 m .63992 .55771 L .63672 .56631 L F
.62816 .42758 m .62714 .43277 L .62796 .43532 L 0 0 0 r
F
.62816 .42758 m .62734 .42505 L .62714 .43277 L F
.57541 .89922 m .55877 .90126 L .55565 .90291 L .072 0 0 r
F
.57541 .89922 m .57927 .8975 L .55877 .90126 L F
.603 .58393 m .59773 .58736 L .59628 .5894 L 0 0 0 r
F
.603 .58393 m .60453 .58182 L .59773 .58736 L F
.63851 .49336 m .63577 .49835 L .63563 .50103 L F
.63851 .49336 m .63865 .49065 L .63577 .49835 L F
.27184 .84427 m .24638 .83618 L .25106 .83994 L .747 .04 0 r
F
.27609 .84778 m .27184 .84427 L .25106 .83994 L .718 .035 0 r
F
.62481 .54784 m .62055 .55206 L .61958 .55449 L 0 0 0 r
F
.62481 .54784 m .62582 .54535 L .62055 .55206 L F
.87066 .28558 m .8704 .30115 L .87373 .30739 L F
.87066 .28558 m .86726 .27945 L .8704 .30115 L F
.87032 .28575 m .86926 .30167 L .87241 .30796 L F
.87032 .28575 m .86708 .27954 L .86926 .30167 L F
.68501 .68974 m .68844 .68657 L .67809 .69619 L .482 .196 0 r
F
.68501 .68974 m .67809 .69619 L .67493 .69932 L F
.76565 .55213 m .76183 .56067 L .7606 .56535 L 0 0 0 r
F
.76565 .55213 m .76681 .54734 L .76183 .56067 L F
.42442 .64541 m .4128 .64329 L .4143 .6443 L .56 .001 0 r
F
.42566 .6463 m .42442 .64541 L .4143 .6443 L .541 0 0 r
F
.33673 .56995 m .329 .56163 L .33017 .56394 L .85 .102 0 r
F
.33788 .57217 m .33673 .56995 L .33017 .56394 L .836 .097 0 r
F
.33847 .90203 m .31255 .89543 L .31707 .89808 L .546 0 0 r
F
.34239 .90442 m .33847 .90203 L .31707 .89808 L .523 0 0 r
F
.37601 .8771 m .35126 .87528 L .35486 .87774 L .601 .013 0 r
F
.37896 .87939 m .37601 .8771 L .35486 .87774 L .572 .008 0 r
F
.35931 .59777 m .35003 .59094 L .35157 .59289 L .769 .065 0 r
F
.36078 .59961 m .35931 .59777 L .35157 .59289 L .753 .06 0 r
F
.61434 .60022 m .61021 .60525 L .60839 .60737 L .548 .196 0 r
F
.61434 .60022 m .6162 .59799 L .61021 .60525 L F
.39763 .62557 m .387 .62112 L .3887 .62245 L .637 .018 0 r
F
.39917 .62678 m .39763 .62557 L .3887 .62245 L .616 .012 0 r
F
.57871 .60298 m .57295 .60581 L .57133 .60742 L 0 0 0 r
F
.57871 .60298 m .58045 .60129 L .57295 .60581 L F
.20911 .83661 m .18419 .82338 L .18909 .82803 L .711 .042 0 r
F
.2137 .84096 m .20911 .83661 L .18909 .82803 L .694 .037 0 r
F
.3527 .6083 m .34186 .60199 L .34358 .60405 L .845 .07 0 r
F
.35432 .61024 m .3527 .6083 L .34358 .60405 L .818 .066 0 r
F
.65416 .50352 m .6568 .5098 L .65598 .51273 L .965 .34 0 r
F
.65416 .50352 m .65487 .5006 L .6568 .5098 L F
.54439 .62582 m .53754 .62773 L .53599 .62876 L 0 0 0 r
F
.54439 .62582 m .54614 .62472 L .53754 .62773 L F
.60202 .37617 m .60261 .38089 L .60432 .38298 L 0 .03 0 r
F
.60202 .37617 m .6003 .37418 L .60261 .38089 L F
.63078 .42954 m .63009 .4347 L .63098 .43727 L 0 0 0 r
F
.63078 .42954 m .62986 .42701 L .63009 .4347 L F
.5995 .58118 m .59452 .58466 L .59311 .58663 L F
.5995 .58118 m .601 .57913 L .59452 .58466 L F
.63389 .493 m .63176 .49791 L .63157 .50053 L F
.63389 .493 m .63408 .49037 L .63176 .49791 L F
.60069 .37724 m .60216 .38124 L .60393 .38327 L 0 .03 0 r
F
.60069 .37724 m .59885 .37538 L .60216 .38124 L F
.43705 .6478 m .42566 .6463 L .42693 .64716 L .505 0 0 r
F
.43803 .64855 m .43705 .6478 L .42693 .64716 L .483 0 0 r
F
.46941 .6432 m .46937 .64275 L .45956 .64266 L .327 0 0 r
F
.62058 .54598 m .61674 .55023 L .61578 .55259 L 0 0 0 r
F
.62058 .54598 m .62157 .54357 L .61674 .55023 L F
.4209 .91899 m .39646 .91585 L .39905 .91756 L .436 0 0 r
F
.4227 .9205 m .4209 .91899 L .39905 .91756 L .41 0 0 r
F
.34053 .89552 m .315 .88902 L .31944 .89168 L .553 0 0 r
F
.34437 .89791 m .34053 .89552 L .31944 .89168 L .531 0 0 r
F
.59038 .62472 m .58502 .62904 L .583 .6307 L 0 0 0 r
F
.59038 .62472 m .59253 .62296 L .58502 .62904 L F
.41313 .63261 m .40232 .62908 L .40393 .63017 L .579 .001 0 r
F
.41453 .63358 m .41313 .63261 L .40393 .63017 L .557 0 0 r
F
.21368 .8304 m .18935 .81723 L .19411 .82186 L .718 .045 0 r
F
.21815 .83473 m .21368 .8304 L .19411 .82186 L .701 .039 0 r
F
.62893 .43013 m .62796 .43532 L .62872 .43788 L 0 0 0 r
F
.62893 .43013 m .62816 .42758 L .62796 .43532 L F
.44924 .64164 m .43864 .6401 L .43959 .64074 L .438 0 0 r
F
.4499 .64219 m .44924 .64164 L .43959 .64074 L .411 0 0 r
F
.45956 .64266 m .44924 .64164 L .4499 .64219 L .389 0 0 r
F
.41551 .68987 m .40077 .68982 L .40244 .69186 L .774 .046 0 r
F
.41694 .69155 m .41551 .68987 L .40244 .69186 L .762 .045 0 r
F
.37895 .67929 m .3643 .67581 L .36616 .67848 L 1 .082 0 r
F
.3807 .68164 m .37895 .67929 L .36616 .67848 L 1 .081 0 r
F
.42172 .91188 m .39764 .90899 L .40019 .91069 L .434 0 0 r
F
.42349 .91337 m .42172 .91188 L .40019 .91069 L .409 0 0 r
F
.30805 .60398 m .29888 .59369 L .29998 .59686 L 1 .128 0 r
F
.3092 .60703 m .30805 .60398 L .29998 .59686 L 1 .126 0 r
F
.63832 .49606 m .63563 .50103 L .63544 .50371 L 0 0 0 r
F
.63832 .49606 m .63851 .49336 L .63563 .50103 L F
.38047 .61542 m .37035 .60993 L .37206 .61153 L .692 .036 0 r
F
.38206 .6169 m .38047 .61542 L .37206 .61153 L .673 .03 0 r
F
.35716 .66527 m .34342 .65958 L .34521 .66247 L 1 .113 0 r
F
.3589 .66789 m .35716 .66527 L .34521 .66247 L 1 .109 0 r
F
.76763 .44102 m .77116 .44995 L .77178 .45481 L .768 .12 0 r
F
.76763 .44102 m .76664 .43629 L .77116 .44995 L F
.89573 .61359 m .8857 .624 L .88381 .63079 L 0 0 0 r
F
.89573 .61359 m .89771 .60661 L .8857 .624 L F
.39476 .6357 m .38313 .632 L .38495 .63342 L .678 .028 0 r
F
.39639 .63699 m .39476 .6357 L .38495 .63342 L .647 .022 0 r
F
.39646 .91585 m .37145 .91177 L .37479 .91369 L .468 0 0 r
F
.39905 .91756 m .39646 .91585 L .37479 .91369 L .443 0 0 r
F
.14856 .78309 m .12558 .76615 L .12986 .77177 L .788 .072 0 r
F
.15266 .78842 m .14856 .78309 L .12986 .77177 L .773 .067 0 r
F
.32813 .5821 m .31857 .57405 L .31998 .57649 L .914 .099 0 r
F
.3295 .58443 m .32813 .5821 L .31998 .57649 L .89 .095 0 r
F
.62375 .55031 m .61958 .55449 L .61857 .55689 L 0 0 0 r
F
.62375 .55031 m .62481 .54784 L .61958 .55449 L F
.3037 .88979 m .27777 .88156 L .28269 .88471 L .588 .004 0 r
F
.30809 .89267 m .3037 .88979 L .28269 .88471 L .566 0 0 r
F
.63729 .56303 m .63537 .56891 L .63399 .57148 L .715 .2 0 r
F
.63729 .56303 m .63862 .56038 L .63537 .56891 L F
.77334 .80534 m .7604 .81036 L .75589 .8151 L 0 0 0 r
F
.77334 .80534 m .7782 .80039 L .7604 .81036 L F
.42675 .63725 m .41596 .63451 L .4174 .6354 L .524 0 0 r
F
.42795 .63803 m .42675 .63725 L .4174 .6354 L .499 0 0 r
F
.60142 .586 m .59628 .5894 L .5948 .5914 L 0 0 0 r
F
.60142 .586 m .603 .58393 L .59628 .5894 L F
.63164 .43209 m .63098 .43727 L .63183 .43985 L F
.63164 .43209 m .63078 .42954 L .63098 .43727 L F
.6037 .37819 m .60432 .38298 L .60599 .3851 L 0 .025 0 r
F
.6037 .37819 m .60202 .37617 L .60432 .38298 L F
.57976 .60795 m .57394 .61073 L .57226 .61235 L 0 0 0 r
F
.57976 .60795 m .58158 .60625 L .57394 .61073 L F
.51819 .63622 m .51055 .63743 L .50938 .63809 L .063 0 0 r
F
.51819 .63622 m .51962 .63551 L .51055 .63743 L F
.45992 .64313 m .45956 .64266 L .4499 .64219 L .361 0 0 r
F
.46941 .6432 m .45956 .64266 L .45992 .64313 L .327 0 0 r
F
.91544 .45035 m .90944 .46439 L .91011 .47148 L 0 0 0 r
F
.91544 .45035 m .91474 .44316 L .90944 .46439 L F
.37613 .62595 m .36476 .62115 L .36662 .62285 L .748 .044 0 r
F
.37783 .62752 m .37613 .62595 L .36662 .62285 L .719 .039 0 r
F
.60248 .37914 m .60393 .38327 L .60567 .38533 L 0 .025 0 r
F
.60248 .37914 m .60069 .37724 L .60393 .38327 L F
.39764 .90899 m .373 .90511 L .37628 .90703 L .47 0 0 r
F
.40019 .91069 m .39764 .90899 L .37628 .90703 L .446 0 0 r
F
.63365 .49563 m .63157 .50053 L .63134 .50313 L 0 0 0 r
F
.63365 .49563 m .63389 .493 L .63157 .50053 L F
.33788 .57217 m .33017 .56394 L .33138 .56622 L .836 .097 0 r
F
.33907 .57436 m .33788 .57217 L .33138 .56622 L .822 .092 0 r
F
.15485 .77721 m .13259 .76036 L .1367 .76594 L .793 .074 0 r
F
.1588 .78248 m .15485 .77721 L .1367 .76594 L .779 .069 0 r
F
.43864 .6401 m .42795 .63803 L .42917 .63876 L .475 0 0 r
F
.43959 .64074 m .43864 .6401 L .42917 .63876 L .449 0 0 r
F
.30633 .88338 m .28083 .87523 L .28565 .87838 L .596 .006 0 r
F
.31063 .88626 m .30633 .88338 L .28565 .87838 L .575 0 0 r
F
.727 .63998 m .72065 .64674 L .71813 .65067 L 0 0 0 r
F
.727 .63998 m .72966 .63593 L .72065 .64674 L F
.65346 .50644 m .65598 .51273 L .65516 .51565 L .955 .326 0 r
F
.65346 .50644 m .65416 .50352 L .65598 .51273 L F
.44468 .68845 m .43112 .69037 L .43227 .6917 L .439 0 0 r
F
.44549 .68946 m .44468 .68845 L .43227 .6917 L .42 0 0 r
F
.33344 .64242 m .32145 .63441 L .32302 .63747 L 1 .124 0 r
F
.33502 .64527 m .33344 .64242 L .32302 .63747 L 1 .117 0 r
F
.22421 .81611 m .19954 .80506 L .20414 .80952 L .79 .054 0 r
F
.22848 .82029 m .22421 .81611 L .20414 .80952 L .762 .05 0 r
F
.88176 .60921 m .87511 .62034 L .87315 .62691 L 0 0 0 r
F
.88176 .60921 m .88372 .60247 L .87511 .62034 L F
.83643 .73353 m .82453 .74064 L .82087 .74644 L F
.83643 .73353 m .84031 .72751 L .82453 .74064 L F
.62964 .43269 m .62872 .43788 L .62944 .44046 L F
.62964 .43269 m .62893 .43013 L .62872 .43788 L F
.61955 .54838 m .61578 .55259 L .61477 .55492 L F
.61955 .54838 m .62058 .54598 L .61578 .55259 L F
.34772 .87272 m .32262 .86913 L .32676 .87188 L .645 .019 0 r
F
.35126 .87528 m .34772 .87272 L .32676 .87188 L .616 .014 0 r
F
.41132 .64223 m .39973 .63946 L .40144 .64064 L .601 .011 0 r
F
.4128 .64329 m .41132 .64223 L .40144 .64064 L .583 .005 0 r
F
.76542 .79682 m .75355 .80253 L .74908 .80709 L 0 0 0 r
F
.76542 .79682 m .77019 .79204 L .75355 .80253 L F
.36078 .59961 m .35157 .59289 L .35316 .5948 L .753 .06 0 r
F
.36229 .60141 m .36078 .59961 L .35316 .5948 L .736 .054 0 r
F
.90263 .45122 m .90095 .46471 L .90112 .47167 L 0 0 0 r
F
.90263 .45122 m .90322 .44413 L .90095 .46471 L F
.59797 .5832 m .59311 .58663 L .59165 .58857 L F
.59797 .5832 m .5995 .58118 L .59311 .58663 L F
.43112 .69037 m .41694 .69155 L .41839 .69324 L .601 .021 0 r
F
.43227 .6917 m .43112 .69037 L .41839 .69324 L .582 .019 0 r
F
.61244 .60241 m .60839 .60737 L .60654 .60946 L .555 .199 0 r
F
.61244 .60241 m .61434 .60022 L .60839 .60737 L F
.57694 .60462 m .57133 .60742 L .56969 .60899 L 0 0 0 r
F
.57694 .60462 m .57871 .60298 L .57133 .60742 L F
.35432 .61024 m .34358 .60405 L .34534 .60608 L .818 .066 0 r
F
.35598 .61214 m .35432 .61024 L .34534 .60608 L .79 .061 0 r
F
.63808 .49877 m .63544 .50371 L .6352 .50639 L 0 0 0 r
F
.63808 .49877 m .63832 .49606 L .63544 .50371 L F
.7644 .5569 m .7606 .56535 L .75929 .57001 L F
.7644 .5569 m .76565 .55213 L .7606 .56535 L F
.52956 .63243 m .52244 .63397 L .52104 .63477 L F
.52956 .63243 m .53119 .63158 L .52244 .63397 L F
.82617 .72642 m .81589 .73428 L .81227 .73989 L F
.82617 .72642 m .82997 .72058 L .81589 .73428 L F
.53464 .81106 m .53717 .81021 L .52274 .82647 L .871 .749 0 r
F
.63246 .43466 m .63183 .43985 L .63262 .44245 L 0 0 0 r
F
.63246 .43466 m .63164 .43209 L .63183 .43985 L F
.16605 .76671 m .1431 .75168 L .14716 .75702 L .851 .078 0 r
F
.16991 .77176 m .16605 .76671 L .14716 .75702 L .825 .074 0 r
F
.39912 .68778 m .38428 .68637 L .38611 .68877 L .905 .066 0 r
F
.40077 .68982 m .39912 .68778 L .38611 .68877 L .897 .065 0 r
F
.39917 .62678 m .3887 .62245 L .39043 .62374 L .616 .012 0 r
F
.40073 .62795 m .39917 .62678 L .39043 .62374 L .595 .005 0 r
F
.60533 .38025 m .60599 .3851 L .60761 .38725 L 0 .019 0 r
F
.60533 .38025 m .6037 .37819 L .60599 .3851 L F
.62265 .55275 m .61857 .55689 L .61751 .55928 L 0 0 0 r
F
.62265 .55275 m .62375 .55031 L .61857 .55689 L F
.60423 .38108 m .60567 .38533 L .60737 .38742 L 0 .02 0 r
F
.60423 .38108 m .60248 .37914 L .60567 .38533 L F
.49724 .64116 m .48882 .64176 L .48821 .64221 L .157 0 0 r
F
.49724 .64116 m .49815 .64069 L .48882 .64176 L F
.50702 .63925 m .49905 .64016 L .49815 .64069 L .105 0 0 r
F
.50702 .63925 m .50821 .63869 L .49905 .64016 L F
.63336 .49825 m .63134 .50313 L .63106 .50574 L 0 0 0 r
F
.63336 .49825 m .63365 .49563 L .63134 .50313 L F
.3092 .60703 m .29998 .59686 L .30112 .60003 L 1 .126 0 r
F
.31039 .61008 m .3092 .60703 L .30112 .60003 L .994 .124 0 r
F
.5426 .62688 m .53599 .62876 L .53441 .62974 L 0 0 0 r
F
.5426 .62688 m .54439 .62582 L .53599 .62876 L F
.3295 .58443 m .31998 .57649 L .32144 .5789 L .89 .095 0 r
F
.3309 .58672 m .3295 .58443 L .32144 .5789 L .864 .09 0 r
F
.5882 .62644 m .583 .6307 L .58094 .63231 L .453 .197 0 r
F
.5882 .62644 m .59038 .62472 L .583 .6307 L F
.6303 .43527 m .62944 .44046 L .63012 .44304 L 0 0 0 r
F
.6303 .43527 m .62964 .43269 L .62944 .44046 L F
.63591 .56566 m .63399 .57148 L .63258 .57403 L .716 .202 0 r
F
.63591 .56566 m .63729 .56303 L .63399 .57148 L F
.31454 .86335 m .28926 .85779 L .29379 .86095 L .686 .027 0 r
F
.31855 .86629 m .31454 .86335 L .29379 .86095 L .656 .022 0 r
F
.87393 .2918 m .87373 .30739 L .87695 .3137 L 0 0 0 r
F
.87393 .2918 m .87066 .28558 L .87373 .30739 L F
.42566 .87768 m .40273 .87942 L .40503 .88146 L .461 0 0 r
F
.42723 .87959 m .42566 .87768 L .40503 .88146 L .442 0 0 r
F
.44893 .64947 m .43803 .64855 L .43903 .64925 L .435 0 0 r
F
.44962 .65007 m .44893 .64947 L .43903 .64925 L .41 0 0 r
F
.87343 .29203 m .87241 .30796 L .87544 .31432 L 0 0 0 r
F
.87343 .29203 m .87032 .28575 L .87241 .30796 L F
.38206 .6169 m .37206 .61153 L .3738 .61309 L .673 .03 0 r
F
.38368 .61835 m .38206 .6169 L .3738 .61309 L .653 .024 0 r
F
.42566 .6463 m .4143 .6443 L .41582 .64527 L .541 0 0 r
F
.42693 .64716 m .42566 .6463 L .41582 .64527 L .521 0 0 r
F
.65275 .50934 m .65516 .51565 L .65432 .51856 L .945 .313 0 r
F
.65275 .50934 m .65346 .50644 L .65516 .51565 L F
.6815 .69283 m .67493 .69932 L .67168 .70235 L .506 .202 0 r
F
.6815 .69283 m .68501 .68974 L .67493 .69932 L F
.59981 .58805 m .5948 .5914 L .59328 .59338 L 0 0 0 r
F
.59981 .58805 m .60142 .586 L .5948 .5914 L F
.76851 .44578 m .77178 .45481 L .77231 .45967 L .769 .124 0 r
F
.76851 .44578 m .76763 .44102 L .77178 .45481 L F
.33907 .57436 m .33138 .56622 L .33263 .56848 L .822 .092 0 r
F
.3403 .57652 m .33907 .57436 L .33263 .56848 L .808 .087 0 r
F
.61847 .55075 m .61477 .55492 L .61373 .55724 L 0 0 0 r
F
.61847 .55075 m .61955 .54838 L .61477 .55492 L F
.40273 .87942 m .37896 .87939 L .38196 .88159 L .524 .003 0 r
F
.40503 .88146 m .40273 .87942 L .38196 .88159 L .502 0 0 r
F
.41453 .63358 m .40393 .63017 L .40556 .63122 L .557 0 0 r
F
.41596 .63451 m .41453 .63358 L .40556 .63122 L .533 0 0 r
F
.63779 .50147 m .6352 .50639 L .63492 .50906 L 0 0 0 r
F
.63779 .50147 m .63808 .49877 L .6352 .50639 L F
.57791 .6096 m .57226 .61235 L .57054 .61394 L F
.57791 .6096 m .57976 .60795 L .57226 .61235 L F
.63323 .43724 m .63262 .44245 L .63337 .44506 L F
.63323 .43724 m .63246 .43466 L .63262 .44245 L F
.39639 .63699 m .38495 .63342 L .3868 .63481 L .647 .022 0 r
F
.39805 .63825 m .39639 .63699 L .3868 .63481 L .629 .017 0 r
F
.43803 .64855 m .42693 .64716 L .4282 .64797 L .483 0 0 r
F
.43903 .64925 m .43803 .64855 L .4282 .64797 L .461 0 0 r
F
.60692 .38235 m .60761 .38725 L .60919 .38943 L 0 .014 0 r
F
.60692 .38235 m .60533 .38025 L .60761 .38725 L F
.59639 .58519 m .59165 .58857 L .59016 .59049 L 0 0 0 r
F
.59639 .58519 m .59797 .5832 L .59165 .58857 L F
.60593 .38307 m .60737 .38742 L .60903 .38954 L 0 .014 0 r
F
.60593 .38307 m .60423 .38108 L .60737 .38742 L F
.37783 .62752 m .36662 .62285 L .36851 .62451 L .719 .039 0 r
F
.37957 .62905 m .37783 .62752 L .36851 .62451 L .69 .034 0 r
F
.3589 .66789 m .34521 .66247 L .34703 .66538 L 1 .109 0 r
F
.36067 .67052 m .3589 .66789 L .34703 .66538 L 1 .108 0 r
F
.46944 .6436 m .46941 .6432 L .45992 .64313 L .297 0 0 r
F
.36229 .60141 m .35316 .5948 L .35478 .59669 L .736 .054 0 r
F
.36384 .60318 m .36229 .60141 L .35478 .59669 L .719 .048 0 r
F
.26348 .87148 m .23799 .86125 L .24311 .865 L .633 .017 0 r
F
.26817 .87494 m .26348 .87148 L .24311 .865 L .613 .011 0 r
F
.63304 .50087 m .63106 .50574 L .63074 .50833 L 0 0 0 r
F
.63304 .50087 m .63336 .49825 L .63106 .50574 L F
.63091 .43786 m .63012 .44304 L .63074 .44564 L F
.63091 .43786 m .6303 .43527 L .63012 .44304 L F
.4499 .64219 m .43959 .64074 L .44055 .64133 L .411 0 0 r
F
.45057 .64269 m .4499 .64219 L .44055 .64133 L .383 0 0 r
F
.45992 .64313 m .4499 .64219 L .45057 .64269 L .361 0 0 r
F
.33502 .64527 m .32302 .63747 L .32462 .64053 L 1 .117 0 r
F
.33662 .64812 m .33502 .64527 L .32462 .64053 L 1 .111 0 r
F
.62151 .55518 m .61751 .55928 L .61641 .56164 L 0 0 0 r
F
.62151 .55518 m .62265 .55275 L .61751 .55928 L F
.3807 .68164 m .36616 .67848 L .36805 .68117 L 1 .081 0 r
F
.38247 .684 m .3807 .68164 L .36805 .68117 L F
.6105 .60457 m .60654 .60946 L .60465 .61151 L .561 .202 0 r
F
.6105 .60457 m .61244 .60241 L .60654 .60946 L F
.57513 .60624 m .56969 .60899 L .56801 .61052 L 0 0 0 r
F
.57513 .60624 m .57694 .60462 L .56969 .60899 L F
.35598 .61214 m .34534 .60608 L .34713 .60808 L .79 .061 0 r
F
.35767 .61401 m .35598 .61214 L .34713 .60808 L .763 .056 0 r
F
.26685 .86514 m .24184 .85497 L .24684 .85873 L .641 .019 0 r
F
.27143 .86861 m .26685 .86514 L .24684 .85873 L .622 .013 0 r
F
.42795 .63803 m .4174 .6354 L .41886 .63625 L .499 0 0 r
F
.42917 .63876 m .42795 .63803 L .41886 .63625 L .474 0 0 r
F
.72427 .64398 m .71813 .65067 L .71553 .65455 L 0 0 0 r
F
.72427 .64398 m .727 .63998 L .71813 .65067 L F
.89361 .62055 m .88381 .63079 L .88178 .63754 L F
.89361 .62055 m .89573 .61359 L .88381 .63079 L F
.51675 .63687 m .50938 .63809 L .50821 .63869 L .037 0 0 r
F
.51675 .63687 m .51819 .63622 L .50938 .63809 L F
.55195 .92041 m .53408 .92105 L .53161 .92256 L .183 0 0 r
F
.55195 .92041 m .55523 .91882 L .53408 .92105 L F
.76305 .56164 m .75929 .57001 L .7579 .57464 L 0 0 0 r
F
.76305 .56164 m .7644 .5569 L .75929 .57001 L F
.3309 .58672 m .32144 .5789 L .32293 .58129 L .864 .09 0 r
F
.33235 .58899 m .3309 .58672 L .32293 .58129 L .839 .086 0 r
F
.916 .45755 m .91011 .47148 L .91065 .47858 L 0 0 0 r
F
.916 .45755 m .91544 .45035 L .91011 .47148 L F
.65203 .51224 m .65432 .51856 L .65347 .52145 L .936 .301 0 r
F
.65203 .51224 m .65275 .50934 L .65432 .51856 L F
.63745 .50416 m .63492 .50906 L .63458 .51172 L 0 0 0 r
F
.63745 .50416 m .63779 .50147 L .63492 .50906 L F
.6345 .56827 m .63258 .57403 L .63112 .57655 L .718 .204 0 r
F
.6345 .56827 m .63591 .56566 L .63258 .57403 L F
.61735 .55311 m .61373 .55724 L .61264 .55954 L 0 0 0 r
F
.61735 .55311 m .61847 .55075 L .61373 .55724 L F
.3403 .57652 m .33263 .56848 L .33392 .57072 L .808 .087 0 r
F
.34157 .57867 m .3403 .57652 L .33392 .57072 L .793 .082 0 r
F
.41694 .69155 m .40244 .69186 L .40413 .69392 L .762 .045 0 r
F
.41839 .69324 m .41694 .69155 L .40413 .69392 L .75 .044 0 r
F
.31039 .61008 m .30112 .60003 L .3023 .60321 L .994 .124 0 r
F
.31163 .61312 m .31039 .61008 L .3023 .60321 L .986 .121 0 r
F
.63395 .43984 m .63337 .44506 L .63408 .44768 L 0 0 0 r
F
.63395 .43984 m .63323 .43724 L .63337 .44506 L F
.55105 .91547 m .53341 .91636 L .53097 .91785 L .167 0 0 r
F
.43959 .64074 m .42917 .63876 L .4304 .63945 L .449 0 0 r
F
.44055 .64133 m .43959 .64074 L .4304 .63945 L .422 0 0 r
F
.4128 .64329 m .40144 .64064 L .40317 .64178 L .583 .005 0 r
F
.4143 .6443 m .4128 .64329 L .40317 .64178 L .565 0 0 r
F
.46027 .64355 m .45992 .64313 L .45057 .64269 L .331 0 0 r
F
.46944 .6436 m .45992 .64313 L .46027 .64355 L .297 0 0 r
F
.59816 .59007 m .59328 .59338 L .59172 .59532 L 0 0 0 r
F
.59816 .59007 m .59981 .58805 L .59328 .59338 L F
.60846 .38448 m .60919 .38943 L .61073 .39164 L 0 .008 0 r
F
.60846 .38448 m .60692 .38235 L .60919 .38943 L F
.60758 .38509 m .60903 .38954 L .61066 .39168 L 0 .009 0 r
F
.60758 .38509 m .60593 .38307 L .60903 .38954 L F
.87968 .61593 m .87315 .62691 L .87108 .63344 L 0 0 0 r
F
.87968 .61593 m .88176 .60921 L .87315 .62691 L F
.90183 .45829 m .90263 .45122 L .90112 .47167 L .731 .158 0 r
F
.90183 .45829 m .90112 .47167 L .90116 .47863 L F
.40073 .62795 m .39043 .62374 L .39219 .62499 L .595 .005 0 r
F
.40232 .62908 m .40073 .62795 L .39219 .62499 L .572 0 0 r
F
.63146 .44046 m .63074 .44564 L .63131 .44824 L 0 0 0 r
F
.63146 .44046 m .63091 .43786 L .63074 .44564 L F
.5279 .63324 m .52104 .63477 L .51962 .63551 L F
.5279 .63324 m .52956 .63243 L .52104 .63477 L F
.71244 .3533 m .72768 .35525 L .73069 .35892 L .67 .029 0 r
F
.63267 .50348 m .63074 .50833 L .63037 .51092 L 0 0 0 r
F
.63267 .50348 m .63304 .50087 L .63074 .50833 L F
.58599 .62811 m .58094 .63231 L .57885 .63387 L .465 .201 0 r
F
.58599 .62811 m .5882 .62644 L .58094 .63231 L F
.54928 .90584 m .53214 .90742 L .52973 .90878 L .103 0 0 r
F
.54928 .90584 m .55248 .90444 L .53214 .90742 L F
.76929 .45057 m .77231 .45967 L .77276 .46454 L .769 .127 0 r
F
.76929 .45057 m .76851 .44578 L .77231 .45967 L F
.38368 .61835 m .3738 .61309 L .37558 .61462 L .653 .024 0 r
F
.38532 .61975 m .38368 .61835 L .37558 .61462 L .632 .018 0 r
F
.2137 .84096 m .18909 .82803 L .1941 .83258 L .694 .037 0 r
F
.21838 .84521 m .2137 .84096 L .1941 .83258 L .676 .031 0 r
F
.27609 .84778 m .25106 .83994 L .25581 .84362 L .718 .035 0 r
F
.2804 .8512 m .27609 .84778 L .25581 .84362 L .689 .03 0 r
F
.5408 .62789 m .53441 .62974 L .53281 .63068 L 0 0 0 r
F
.5408 .62789 m .5426 .62688 L .53441 .62974 L F
.59478 .58715 m .59016 .59049 L .58863 .59237 L F
.59478 .58715 m .59639 .58519 L .59016 .59049 L F
.15266 .78842 m .12986 .77177 L .13425 .77732 L .773 .067 0 r
F
.15685 .79366 m .15266 .78842 L .13425 .77732 L .758 .062 0 r
F
.62031 .55758 m .61641 .56164 L .61526 .56398 L 0 0 0 r
F
.62031 .55758 m .62151 .55518 L .61641 .56164 L F
.57603 .61123 m .57054 .61394 L .5688 .61548 L F
.57603 .61123 m .57791 .6096 L .57054 .61394 L F
.54898 .79277 m .53966 .80916 L .53717 .81021 L 1 1 0 r
F
.54898 .79277 m .55206 .79229 L .53966 .80916 L F
.21815 .83473 m .19411 .82186 L .19897 .8264 L .701 .039 0 r
F
.22272 .83896 m .21815 .83473 L .19897 .8264 L .684 .034 0 r
F
.36384 .60318 m .35478 .59669 L .35643 .59854 L .719 .048 0 r
F
.36541 .60492 m .36384 .60318 L .35643 .59854 L .7 .042 0 r
F
.83244 .73948 m .82087 .74644 L .8171 .75217 L 0 0 0 r
F
.83244 .73948 m .83643 .73353 L .82087 .74644 L F
.63706 .50685 m .63458 .51172 L .6342 .51437 L F
.63706 .50685 m .63745 .50416 L .63458 .51172 L F
.44549 .68946 m .43227 .6917 L .43344 .69302 L .42 0 0 r
F
.44631 .69044 m .44549 .68946 L .43344 .69302 L .402 0 0 r
F
.63462 .44245 m .63408 .44768 L .63473 .45032 L 0 0 0 r
F
.63462 .44245 m .63395 .43984 L .63408 .44768 L F
.37145 .91177 m .34636 .9067 L .35039 .90886 L .489 0 0 r
F
.37479 .91369 m .37145 .91177 L .35039 .90886 L .464 0 0 r
F
.1588 .78248 m .1367 .76594 L .14093 .77144 L .779 .069 0 r
F
.16286 .78769 m .1588 .78248 L .14093 .77144 L .764 .064 0 r
F
.60281 .90861 m .58699 .9102 L .58308 .91225 L .088 0 0 r
F
.60281 .90861 m .60741 .90643 L .58699 .9102 L F
.5291 .92394 m .51034 .9241 L .50869 .92543 L .22 0 0 r
F
.5291 .92394 m .53161 .92256 L .51034 .9241 L F
.49632 .64159 m .49724 .64116 L .48821 .64221 L .126 0 0 r
F
.65131 .51513 m .65347 .52145 L .6526 .52433 L .927 .291 0 r
F
.65131 .51513 m .65203 .51224 L .65347 .52145 L F
.41596 .63451 m .40556 .63122 L .40721 .63223 L .533 0 0 r
F
.4174 .6354 m .41596 .63451 L .40721 .63223 L .508 0 0 r
F
.76838 .8102 m .75589 .8151 L .75127 .81975 L 0 0 0 r
F
.76838 .8102 m .77334 .80534 L .75589 .8151 L F
.60996 .38663 m .61073 .39164 L .61181 .39326 L 0 .003 0 r
F
.60996 .38663 m .60846 .38448 L .61073 .39164 L F
.60919 .38715 m .61066 .39168 L .61181 .39326 L F
.61215 .39364 m .61181 .39326 L .61224 .39386 L F
.60996 .38663 m .61181 .39326 L .61215 .39364 L F
.60919 .38715 m .61181 .39326 L .61215 .39364 L F
.61215 .39364 m .61181 .39326 L .61222 .39387 L F
.60919 .38715 m .60758 .38509 L .61066 .39168 L F
.61618 .55545 m .61264 .55954 L .61151 .56181 L 0 0 0 r
F
.61618 .55545 m .61735 .55311 L .61264 .55954 L F
.60852 .60669 m .60465 .61151 L .60272 .61352 L .568 .205 0 r
F
.60852 .60669 m .6105 .60457 L .60465 .61151 L F
.56551 .77516 m .56904 .77475 L .55806 .79065 L 1 1 0 r
F
.40077 .68982 m .38611 .68877 L .38796 .69119 L .897 .065 0 r
F
.40244 .69186 m .40077 .68982 L .38796 .69119 L .891 .065 0 r
F
.57329 .60781 m .56801 .61052 L .5663 .61202 L 0 0 0 r
F
.57329 .60781 m .57513 .60624 L .56801 .61052 L F
.87709 .29808 m .87695 .3137 L .88005 .32006 L F
.87709 .29808 m .87393 .2918 L .87695 .3137 L F
.37957 .62905 m .36851 .62451 L .37043 .62614 L .69 .034 0 r
F
.38134 .63054 m .37957 .62905 L .37043 .62614 L .672 .029 0 r
F
.43227 .6917 m .41839 .69324 L .41986 .69493 L .582 .019 0 r
F
.43344 .69302 m .43227 .6917 L .41986 .69493 L .564 .017 0 r
F
.35767 .61401 m .34713 .60808 L .34896 .61005 L .763 .056 0 r
F
.35939 .61585 m .35767 .61401 L .34896 .61005 L .737 .051 0 r
F
.60119 .90334 m .58563 .90515 L .58177 .90717 L .07 0 0 r
F
.60119 .90334 m .60574 .9012 L .58563 .90515 L F
.87642 .29839 m .87544 .31432 L .87834 .32073 L 0 0 0 r
F
.87642 .29839 m .87343 .29203 L .87544 .31432 L F
.373 .90511 m .34827 .90019 L .35222 .90237 L .495 0 0 r
F
.37628 .90703 m .373 .90511 L .35222 .90237 L .471 0 0 r
F
.63195 .44307 m .63131 .44824 L .63184 .45085 L 0 0 0 r
F
.63195 .44307 m .63146 .44046 L .63131 .44824 L F
.42693 .64716 m .41582 .64527 L .41736 .6462 L .521 0 0 r
F
.4282 .64797 m .42693 .64716 L .41736 .6462 L .5 0 0 r
F
.63303 .57085 m .63112 .57655 L .62962 .57905 L .719 .206 0 r
F
.63303 .57085 m .6345 .56827 L .63112 .57655 L F
.82226 .73218 m .81227 .73989 L .80853 .74544 L 0 0 0 r
F
.82226 .73218 m .82617 .72642 L .81227 .73989 L F
.34157 .57867 m .33392 .57072 L .33526 .57293 L .793 .082 0 r
F
.34288 .58078 m .34157 .57867 L .33526 .57293 L .777 .077 0 r
F
.33235 .58899 m .32293 .58129 L .32447 .58365 L .839 .086 0 r
F
.33384 .59123 m .33235 .58899 L .32447 .58365 L .814 .082 0 r
F
.39805 .63825 m .3868 .63481 L .38868 .63615 L .629 .017 0 r
F
.39973 .63946 m .39805 .63825 L .38868 .63615 L .612 .012 0 r
F
.67791 .69582 m .67168 .70235 L .66836 .7053 L .529 .208 0 r
F
.67791 .69582 m .6815 .69283 L .67168 .70235 L F
.63226 .50609 m .63037 .51092 L .62997 .5135 L 0 0 0 r
F
.63226 .50609 m .63267 .50348 L .63037 .51092 L F
.44962 .65007 m .43903 .64925 L .44003 .6499 L .41 0 0 r
F
.45032 .65062 m .44962 .65007 L .44003 .6499 L .383 0 0 r
F
.33662 .64812 m .32462 .64053 L .32626 .6436 L 1 .111 0 r
F
.33827 .65098 m .33662 .64812 L .32626 .6436 L 1 .107 0 r
F
.22848 .82029 m .20414 .80952 L .20883 .81389 L .762 .05 0 r
F
.23284 .82438 m .22848 .82029 L .20883 .81389 L .734 .045 0 r
F
.76055 .8015 m .74908 .80709 L .74452 .81157 L 0 0 0 r
F
.76055 .8015 m .76542 .79682 L .74908 .80709 L F
.59647 .59205 m .59172 .59532 L .59012 .59722 L F
.59647 .59205 m .59816 .59007 L .59172 .59532 L F
.59805 .8931 m .58308 .89566 L .57927 .8975 L F
.59805 .8931 m .60254 .89117 L .58308 .89566 L F
.36067 .67052 m .34703 .66538 L .34888 .66831 L 1 .108 0 r
F
.36247 .67316 m .36067 .67052 L .34888 .66831 L F
.16991 .77176 m .14716 .75702 L .15132 .7623 L .825 .074 0 r
F
.17386 .77673 m .16991 .77176 L .15132 .7623 L .799 .069 0 r
F
.31163 .61312 m .3023 .60321 L .30353 .60639 L .986 .121 0 r
F
.31291 .61616 m .31163 .61312 L .30353 .60639 L .979 .119 0 r
F
.76162 .56636 m .7579 .57464 L .75643 .57924 L 0 0 0 r
F
.76162 .56636 m .76305 .56164 L .7579 .57464 L F
.63524 .44507 m .63473 .45032 L .63534 .45296 L F
.63524 .44507 m .63462 .44245 L .63473 .45032 L F
.43903 .64925 m .4282 .64797 L .4295 .64873 L .461 0 0 r
F
.44003 .6499 m .43903 .64925 L .4295 .64873 L .437 0 0 r
F
.61907 .55997 m .61526 .56398 L .61407 .5663 L 0 0 0 r
F
.61907 .55997 m .62031 .55758 L .61526 .56398 L F
.57512 .916 m .55848 .91711 L .55523 .91882 L .132 0 0 r
F
.57512 .916 m .57912 .91419 L .55848 .91711 L F
.63662 .50954 m .6342 .51437 L .63376 .51702 L 0 0 0 r
F
.63662 .50954 m .63706 .50685 L .6342 .51437 L F
.72144 .64793 m .71553 .65455 L .71284 .65837 L F
.72144 .64793 m .72427 .64398 L .71553 .65455 L F
.71616 .35623 m .73069 .35892 L .73359 .36268 L .685 .033 0 r
F
.71616 .35623 m .71244 .3533 L .73069 .35892 L F
.59313 .58907 m .58863 .59237 L .58706 .59422 L 0 0 0 r
F
.59313 .58907 m .59478 .58715 L .58863 .59237 L F
.46948 .64396 m .46944 .6436 L .46027 .64355 L .265 0 0 r
F
.61332 .395 m .61224 .39386 L .61245 .39415 L 0 0 0 r
F
.61333 .39503 m .61245 .39415 L .61379 .39606 L F
.61332 .395 m .61245 .39415 L .61333 .39503 L F
.6155 .39764 m .61529 .39829 L .61675 .40055 L F
.6165 .39889 m .61675 .40055 L .61817 .40284 L F
.61756 .40039 m .61817 .40284 L .61954 .40515 L F
.61744 .4001 m .61751 .40034 L .61756 .40039 L F
.61751 .40034 m .61817 .40284 L .61756 .40039 L F
.61828 .40116 m .61954 .40515 L .62087 .40749 L F
.618 .4002 m .61678 .39787 L .61733 .39975 L F
.6174 .39999 m .61742 .40008 L .61744 .4001 L F
.61734 .39981 m .61736 .39994 L .6174 .39999 L F
.61678 .39787 m .61708 .39952 L .61734 .39981 L F
.61646 .3988 m .61647 .39886 L .6165 .39889 L F
.61678 .39787 m .6155 .39557 L .61646 .3988 L F
.61709 .39957 m .61646 .3988 L .6165 .39889 L F
.61709 .39957 m .6165 .39889 L .61817 .40284 L F
.61708 .39952 m .61709 .39957 L .61734 .39981 L F
.61709 .39957 m .61773 .40307 L .61735 .39987 L F
.61709 .39957 m .61735 .39987 L .61734 .39981 L F
.61709 .39957 m .61646 .3988 L .61773 .40307 L F
.61678 .39787 m .61646 .3988 L .61709 .39957 L F
.6155 .39557 m .61596 .39812 L .6164 .39859 L F
.6155 .39557 m .61419 .39329 L .61547 .39757 L F
.61596 .39814 m .61547 .39757 L .6155 .39764 L F
.61596 .39814 m .6155 .39764 L .61675 .40055 L F
.61596 .39812 m .61596 .39814 L .6164 .39859 L F
.61596 .39814 m .61675 .40055 L .61646 .3988 L F
.61596 .39814 m .61642 .40073 L .6164 .39862 L F
.61596 .39814 m .6164 .39862 L .6164 .39859 L F
.61596 .39814 m .61547 .39757 L .61642 .40073 L F
.6155 .39557 m .61547 .39757 L .61596 .39814 L F
.61419 .39329 m .61477 .39669 L .6154 .39734 L F
.61445 .39636 m .61379 .39606 L .61529 .39829 L F
.61419 .39329 m .61282 .39104 L .61443 .39631 L F
.61477 .39669 m .61443 .39631 L .61529 .39829 L F
.61477 .39669 m .61443 .39631 L .61507 .39842 L F
.61419 .39329 m .61443 .39631 L .61477 .39669 L F
.61282 .39104 m .61351 .39521 L .61434 .39604 L F
.61282 .39104 m .61141 .38882 L .61332 .395 L F
.61351 .39521 m .61332 .395 L .61379 .39606 L F
.61351 .39521 m .61332 .395 L .61367 .39613 L F
.61282 .39104 m .61332 .395 L .61351 .39521 L F
.61141 .38882 m .61219 .39368 L .61332 .395 L F
.61141 .38882 m .60996 .38663 L .61215 .39364 L F
.61219 .39368 m .61215 .39364 L .61224 .39386 L F
.61219 .39368 m .61215 .39364 L .61222 .39387 L F
.61141 .38882 m .61215 .39364 L .61219 .39368 L F
.61076 .38925 m .60919 .38715 L .61215 .39364 L F
.61076 .38925 m .61215 .39364 L .61219 .39368 L F
.61228 .39139 m .61076 .38925 L .61332 .395 L F
.61228 .39139 m .61332 .395 L .61351 .39521 L F
.61375 .39356 m .61228 .39139 L .61443 .39631 L F
.61375 .39356 m .61443 .39631 L .61477 .39669 L F
.61518 .39576 m .61375 .39356 L .61547 .39757 L F
.61518 .39576 m .61547 .39757 L .61596 .39814 L F
.61657 .39799 m .61518 .39576 L .61646 .3988 L F
.61657 .39799 m .61646 .3988 L .61709 .39957 L F
.6179 .40025 m .61657 .39799 L .6174 .39999 L F
.61854 .40127 m .61823 .401 L .61827 .40112 L F
.61816 .40101 m .61756 .40039 L .61954 .40515 L F
.61816 .40101 m .61954 .40515 L .61828 .40116 L F
.6192 .40254 m .61894 .40209 L .62087 .40749 L F
.61858 .40145 m .61827 .40112 L .61828 .40116 L F
.61858 .40145 m .61828 .40116 L .61863 .40166 L F
.61854 .40127 m .61827 .40112 L .61858 .40145 L F
.618 .4002 m .61813 .40088 L .61823 .401 L F
.61894 .40209 m .6179 .40025 L .61828 .40116 L F
.61894 .40209 m .61828 .40116 L .62087 .40749 L F
.61863 .40166 m .61828 .40116 L .62021 .40781 L F
.61815 .40097 m .6174 .39999 L .61756 .40039 L F
.61815 .40097 m .61756 .40039 L .61816 .40101 L F
.61815 .40097 m .61733 .39975 L .6174 .39999 L F
.618 .4002 m .61733 .39975 L .61815 .40097 L F
.6179 .40025 m .6174 .39999 L .61815 .40097 L F
.61815 .40097 m .6174 .39999 L .61899 .40543 L F
.6179 .40025 m .61815 .40097 L .61828 .40116 L F
.61815 .40097 m .61816 .40101 L .61824 .40111 L F
.61815 .40097 m .61824 .40111 L .61828 .40116 L F
.61917 .40255 m .61883 .40187 L .62021 .40781 L F
.61883 .40187 m .61854 .40127 L .61862 .40159 L F
.61883 .40187 m .61862 .40159 L .62021 .40781 L F
.61854 .40127 m .618 .4002 L .61823 .401 L F
.61823 .401 m .61899 .40543 L .62021 .40781 L F
.61813 .40088 m .61899 .40543 L .61823 .401 L F
.61742 .40008 m .61817 .40284 L .61744 .4001 L F
.61657 .39799 m .61709 .39957 L .6174 .39999 L F
.61709 .39957 m .61817 .40284 L .6174 .39999 L F
.6174 .39999 m .61773 .40307 L .61899 .40543 L F
.61736 .39994 m .61773 .40307 L .6174 .39999 L F
.61647 .39886 m .61675 .40055 L .6165 .39889 L F
.6164 .39859 m .6164 .39872 L .61646 .3988 L F
.61518 .39576 m .61596 .39814 L .61646 .3988 L F
.61646 .3988 m .61642 .40073 L .61773 .40307 L F
.6164 .39872 m .61642 .40073 L .61646 .3988 L F
.61547 .39757 m .61547 .3976 L .6155 .39764 L F
.61547 .3976 m .61529 .39829 L .6155 .39764 L F
.6154 .39734 m .61537 .39744 L .61547 .39757 L F
.61375 .39356 m .61477 .39669 L .61547 .39757 L F
.61477 .39669 m .61529 .39829 L .61547 .39757 L F
.61547 .39757 m .61507 .39842 L .61642 .40073 L F
.61537 .39744 m .61507 .39842 L .61547 .39757 L F
.61477 .39669 m .61507 .39842 L .6154 .39734 L F
.61443 .39631 m .61439 .3963 L .61445 .39636 L F
.61439 .3963 m .61379 .39606 L .61445 .39636 L F
.61434 .39604 m .61422 .39606 L .61443 .39631 L F
.61228 .39139 m .61351 .39521 L .61443 .39631 L F
.61351 .39521 m .61379 .39606 L .61443 .39631 L F
.61443 .39631 m .61367 .39613 L .61507 .39842 L F
.61422 .39606 m .61367 .39613 L .61443 .39631 L F
.61351 .39521 m .61367 .39613 L .61434 .39604 L F
.61332 .395 m .61222 .39387 L .61367 .39613 L F
.61219 .39368 m .61224 .39386 L .61332 .395 L F
.61219 .39368 m .61222 .39387 L .61332 .395 L F
.61076 .38925 m .61219 .39368 L .61332 .395 L F
.57389 .91085 m .5575 .91221 L .55429 .9139 L .114 0 0 r
F
.57389 .91085 m .57785 .90908 L .5575 .91221 L F
.42917 .63876 m .41886 .63625 L .42034 .63705 L .474 0 0 r
F
.4304 .63945 m .42917 .63876 L .42034 .63705 L .447 0 0 r
F
.45057 .64269 m .44055 .64133 L .44152 .64187 L .383 0 0 r
F
.45125 .64314 m .45057 .64269 L .44152 .64187 L .353 0 0 r
F
.46027 .64355 m .45057 .64269 L .45125 .64314 L .331 0 0 r
F
.6324 .44569 m .63184 .45085 L .63231 .45347 L 0 0 0 r
F
.6324 .44569 m .63195 .44307 L .63184 .45085 L F
.38247 .684 m .36805 .68117 L .36997 .6839 L 1 .081 0 r
F
.38428 .68637 m .38247 .684 L .36997 .6839 L .998 .08 0 r
F
.76997 .45538 m .77276 .46454 L .77312 .46943 L .77 .13 0 r
F
.76997 .45538 m .76929 .45057 L .77276 .46454 L F
.71151 .35379 m .70149 .36806 L .7001 .37328 L 0 0 0 r
F
.38532 .61975 m .37558 .61462 L .37738 .61611 L .632 .018 0 r
F
.387 .62112 m .38532 .61975 L .37738 .61611 L .611 .011 0 r
F
.65056 .51801 m .6526 .52433 L .65171 .52719 L .918 .283 0 r
F
.65056 .51801 m .65131 .51513 L .6526 .52433 L F
.34239 .90442 m .31707 .89808 L .32166 .90061 L .523 0 0 r
F
.34636 .9067 m .34239 .90442 L .32166 .90061 L .499 0 0 r
F
.37896 .87939 m .35486 .87774 L .35851 .88011 L .572 .008 0 r
F
.38196 .88159 m .37896 .87939 L .35851 .88011 L .542 .003 0 r
F
.40232 .62908 m .39219 .62499 L .39397 .6262 L .572 0 0 r
F
.40393 .63017 m .40232 .62908 L .39397 .6262 L .549 0 0 r
F
.61497 .55776 m .61151 .56181 L .61034 .56406 L 0 0 0 r
F
.61497 .55776 m .61618 .55545 L .61151 .56181 L F
.58373 .62973 m .58599 .62811 L .57885 .63387 L .476 .204 0 r
F
.63181 .50869 m .62997 .5135 L .62951 .51607 L 0 0 0 r
F
.63181 .50869 m .63226 .50609 L .62997 .5135 L F
.36541 .60492 m .35643 .59854 L .35812 .60036 L .7 .042 0 r
F
.36703 .60663 m .36541 .60492 L .35812 .60036 L .681 .037 0 r
F
.57411 .61281 m .5688 .61548 L .56702 .61699 L 0 0 0 r
F
.57411 .61281 m .57603 .61123 L .5688 .61548 L F
.91643 .46478 m .91065 .47858 L .91106 .4857 L F
.91643 .46478 m .916 .45755 L .91065 .47858 L F
.5715 .90081 m .55565 .90291 L .55248 .90444 L .041 0 0 r
F
.5715 .90081 m .57541 .89922 L .55565 .90291 L F
.4143 .6443 m .40317 .64178 L .40492 .64287 L .565 0 0 r
F
.41582 .64527 m .4143 .6443 L .40492 .64287 L .546 0 0 r
F
.34437 .89791 m .31944 .89168 L .32394 .89423 L .531 0 0 r
F
.34827 .90019 m .34437 .89791 L .32394 .89423 L .508 0 0 r
F
.89136 .62747 m .88178 .63754 L .87963 .64425 L 0 0 0 r
F
.89136 .62747 m .89361 .62055 L .88178 .63754 L F
.34288 .58078 m .33526 .57293 L .33664 .57512 L .777 .077 0 r
F
.34423 .58287 m .34288 .58078 L .33664 .57512 L .761 .071 0 r
F
.63153 .57341 m .62962 .57905 L .62809 .58152 L .721 .208 0 r
F
.63153 .57341 m .63303 .57085 L .62962 .57905 L F
.44055 .64133 m .4304 .63945 L .43165 .6401 L .422 0 0 r
F
.44152 .64187 m .44055 .64133 L .43165 .6401 L .393 0 0 r
F
.53897 .62885 m .53281 .63068 L .53119 .63158 L 0 0 0 r
F
.53897 .62885 m .5408 .62789 L .53281 .63068 L F
.52622 .634 m .51962 .63551 L .51819 .63622 L F
.52622 .634 m .5279 .63324 L .51962 .63551 L F
.30809 .89267 m .28269 .88471 L .28768 .88775 L .566 0 0 r
F
.31255 .89543 m .30809 .89267 L .28768 .88775 L .544 0 0 r
F
.33384 .59123 m .32447 .58365 L .32606 .58599 L .814 .082 0 r
F
.33536 .59344 m .33384 .59123 L .32606 .58599 L .797 .077 0 r
F
.90088 .46533 m .90116 .47863 L .90107 .48558 L .771 .168 0 r
F
.90088 .46533 m .90183 .45829 L .90116 .47863 L F
.60649 .60877 m .60272 .61352 L .60075 .61549 L .574 .207 0 r
F
.60649 .60877 m .60852 .60669 L .60272 .61352 L F
.63581 .44771 m .63534 .45296 L .63589 .45561 L 0 0 0 r
F
.63581 .44771 m .63524 .44507 L .63534 .45296 L F
.57142 .60935 m .57329 .60781 L .5663 .61202 L F
.35939 .61585 m .34896 .61005 L .35083 .61198 L .737 .051 0 r
F
.36115 .61765 m .35939 .61585 L .35083 .61198 L .723 .046 0 r
F
.46064 .64393 m .46027 .64355 L .45125 .64314 L .299 0 0 r
F
.46948 .64396 m .46027 .64355 L .46064 .64393 L .265 0 0 r
F
.31063 .88626 m .28565 .87838 L .29053 .88143 L .575 0 0 r
F
.315 .88902 m .31063 .88626 L .29053 .88143 L .553 0 0 r
F
.63613 .51221 m .63376 .51702 L .63328 .51966 L 0 0 0 r
F
.63613 .51221 m .63662 .50954 L .63376 .51702 L F
.87749 .62262 m .87108 .63344 L .86889 .63995 L F
.87749 .62262 m .87968 .61593 L .87108 .63344 L F
.59473 .594 m .59012 .59722 L .58848 .5991 L F
.59473 .594 m .59647 .59205 L .59012 .59722 L F
.38134 .63054 m .37043 .62614 L .37238 .62773 L .672 .029 0 r
F
.38313 .632 m .38134 .63054 L .37238 .62773 L .656 .024 0 r
F
.63278 .44832 m .63231 .45347 L .63274 .45609 L 0 0 0 r
F
.63278 .44832 m .6324 .44569 L .63231 .45347 L F
.61779 .56233 m .61407 .5663 L .61283 .56859 L F
.61779 .56233 m .61907 .55997 L .61407 .5663 L F
.6645 .45161 m .66828 .45722 L .66702 .46059 L 1 .751 0 r
F
.41839 .69324 m .40413 .69392 L .40585 .69601 L .75 .044 0 r
F
.41986 .69493 m .41839 .69324 L .40585 .69601 L .74 .044 0 r
F
.31291 .61616 m .30353 .60639 L .3048 .60957 L .979 .119 0 r
F
.31423 .6192 m .31291 .61616 L .3048 .60957 L .972 .117 0 r
F
.4174 .6354 m .40721 .63223 L .40889 .63319 L .508 0 0 r
F
.41886 .63625 m .4174 .6354 L .40889 .63319 L .483 0 0 r
F
.63131 .51129 m .62951 .51607 L .62901 .51863 L 0 0 0 r
F
.63131 .51129 m .63181 .50869 L .62951 .51607 L F
.35126 .87528 m .32676 .87188 L .33096 .87455 L .616 .014 0 r
F
.35486 .87774 m .35126 .87528 L .33096 .87455 L .586 .009 0 r
F
.33827 .65098 m .32626 .6436 L .32794 .64669 L 1 .107 0 r
F
.33995 .65384 m .33827 .65098 L .32794 .64669 L 1 .104 0 r
F
.59144 .59097 m .58706 .59422 L .58546 .59604 L 0 0 0 r
F
.59144 .59097 m .59313 .58907 L .58706 .59422 L F
.64979 .52088 m .65171 .52719 L .65079 .53004 L .911 .277 0 r
F
.64979 .52088 m .65056 .51801 L .65171 .52719 L F
.39973 .63946 m .38868 .63615 L .39058 .63746 L .612 .012 0 r
F
.40144 .64064 m .39973 .63946 L .39058 .63746 L .594 .006 0 r
F
.61372 .56006 m .61034 .56406 L .60913 .56629 L 0 0 0 r
F
.61372 .56006 m .61497 .55776 L .61034 .56406 L F
.71973 .3593 m .73359 .36268 L .73639 .36652 L .698 .038 0 r
F
.71973 .3593 m .71616 .35623 L .73359 .36268 L F
.76009 .57106 m .75643 .57924 L .75487 .58381 L 0 0 0 r
F
.76009 .57106 m .76162 .56636 L .75643 .57924 L F
.31855 .86629 m .29379 .86095 L .29839 .86402 L .656 .022 0 r
F
.32262 .86913 m .31855 .86629 L .29839 .86402 L .627 .017 0 r
F
.63634 .45036 m .63589 .45561 L .6364 .45828 L 0 0 0 r
F
.63634 .45036 m .63581 .44771 L .63589 .45561 L F
.53206 .81171 m .52083 .82781 L .51887 .82898 L .973 .894 0 r
F
.53206 .81171 m .53464 .81106 L .52083 .82781 L F
.88012 .30444 m .88005 .32006 L .88303 .32649 L 0 0 0 r
F
.88012 .30444 m .87709 .29808 L .88005 .32006 L F
.4282 .64797 m .41736 .6462 L .41891 .64709 L .5 0 0 r
F
.4295 .64873 m .4282 .64797 L .41891 .64709 L .478 0 0 r
F
.4227 .9205 m .39905 .91756 L .40168 .91914 L .41 0 0 r
F
.87927 .30481 m .87834 .32073 L .88111 .32721 L 0 0 0 r
F
.87927 .30481 m .87642 .29839 L .87834 .32073 L F
.34423 .58287 m .33664 .57512 L .33806 .57728 L .761 .071 0 r
F
.34562 .58493 m .34423 .58287 L .33806 .57728 L .744 .066 0 r
F
.36703 .60663 m .35812 .60036 L .35985 .60215 L .681 .037 0 r
F
.36867 .6083 m .36703 .60663 L .35985 .60215 L .661 .031 0 r
F
.77054 .46021 m .77312 .46943 L .77339 .47431 L .772 .133 0 r
F
.77054 .46021 m .76997 .45538 L .77312 .46943 L F
.71048 .35911 m .7001 .37328 L .69857 .37843 L 0 0 0 r
F
.71048 .35911 m .71151 .35379 L .7001 .37328 L F
.36247 .67316 m .34888 .66831 L .35076 .67126 L 1 .108 0 r
F
.3643 .67581 m .36247 .67316 L .35076 .67126 L 1 .109 0 r
F
.63559 .51488 m .63328 .51966 L .63275 .52229 L 0 0 0 r
F
.63559 .51488 m .63613 .51221 L .63328 .51966 L F
.67423 .69871 m .66836 .7053 L .66496 .70815 L .551 .214 0 r
F
.67423 .69871 m .67791 .69582 L .66836 .7053 L F
.63311 .45095 m .63274 .45609 L .63311 .45872 L 0 0 0 r
F
.63311 .45095 m .63278 .44832 L .63274 .45609 L F
.62998 .57595 m .62809 .58152 L .62651 .58396 L .722 .21 0 r
F
.62998 .57595 m .63153 .57341 L .62809 .58152 L F
.42349 .91337 m .40019 .91069 L .40277 .91227 L .409 0 0 r
F
.42528 .91474 m .42349 .91337 L .40277 .91227 L .382 0 0 r
F
.387 .62112 m .37738 .61611 L .37922 .61756 L .611 .011 0 r
F
.3887 .62245 m .387 .62112 L .37922 .61756 L .588 .005 0 r
F
.39905 .91756 m .37479 .91369 L .37818 .91549 L .443 0 0 r
F
.40168 .91914 m .39905 .91756 L .37818 .91549 L .416 0 0 r
F
.82832 .74537 m .8171 .75217 L .81321 .75783 L 0 0 0 r
F
.82832 .74537 m .83244 .73948 L .8171 .75217 L F
.57216 .61435 m .57411 .61281 L .56702 .61699 L F
.33536 .59344 m .32606 .58599 L .32768 .58829 L .797 .077 0 r
F
.33693 .59562 m .33536 .59344 L .32768 .58829 L .784 .072 0 r
F
.40244 .69186 m .38796 .69119 L .38984 .69365 L .891 .065 0 r
F
.40413 .69392 m .40244 .69186 L .38984 .69365 L .885 .065 0 r
F
.71853 .65181 m .71284 .65837 L .71008 .66214 L 0 0 0 r
F
.71853 .65181 m .72144 .64793 L .71284 .65837 L F
.45032 .65062 m .44003 .6499 L .44105 .65052 L .383 0 0 r
F
.45102 .65113 m .45032 .65062 L .44105 .65052 L .356 0 0 r
F
.26817 .87494 m .24311 .865 L .24831 .86866 L .613 .011 0 r
F
.27293 .87831 m .26817 .87494 L .24831 .86866 L .592 .004 0 r
F
.15685 .79366 m .13425 .77732 L .13875 .78279 L .758 .062 0 r
F
.16115 .79883 m .15685 .79366 L .13875 .78279 L .742 .057 0 r
F
.40019 .91069 m .37628 .90703 L .3796 .90884 L .446 0 0 r
F
.40277 .91227 m .40019 .91069 L .3796 .90884 L .42 0 0 r
F
.61646 .56467 m .61283 .56859 L .61156 .57086 L 0 0 0 r
F
.61646 .56467 m .61779 .56233 L .61283 .56859 L F
.40393 .63017 m .39397 .6262 L .39578 .62737 L .549 0 0 r
F
.40556 .63122 m .40393 .63017 L .39578 .62737 L .524 0 0 r
F
.63076 .51387 m .62901 .51863 L .62847 .52118 L 0 0 0 r
F
.63076 .51387 m .63131 .51129 L .62901 .51863 L F
.44631 .69044 m .43344 .69302 L .43462 .69433 L .402 0 0 r
F
.44714 .69141 m .44631 .69044 L .43462 .69433 L .383 0 0 r
F
.60443 .61081 m .60075 .61549 L .59875 .61742 L .58 .21 0 r
F
.60443 .61081 m .60649 .60877 L .60075 .61549 L F
.6625 .45506 m .66702 .46059 L .66581 .46389 L 1 .83 0 r
F
.6625 .45506 m .6645 .45161 L .66702 .46059 L F
.27143 .86861 m .24684 .85873 L .25192 .86239 L .622 .013 0 r
F
.2761 .87197 m .27143 .86861 L .25192 .86239 L .601 .007 0 r
F
.81824 .73788 m .80853 .74544 L .80469 .75091 L 0 0 0 r
F
.81824 .73788 m .82226 .73218 L .80853 .74544 L F
.59296 .59592 m .58848 .5991 L .58681 .60094 L F
.59296 .59592 m .59473 .594 L .58848 .5991 L F
.16286 .78769 m .14093 .77144 L .14527 .77687 L .764 .064 0 r
F
.16702 .79281 m .16286 .78769 L .14527 .77687 L .748 .059 0 r
F
.36115 .61765 m .35083 .61198 L .35273 .61388 L .723 .046 0 r
F
.36294 .61942 m .36115 .61765 L .35273 .61388 L .708 .041 0 r
F
.43344 .69302 m .41986 .69493 L .42135 .69663 L .564 .017 0 r
F
.43462 .69433 m .43344 .69302 L .42135 .69663 L .547 .016 0 r
F
.4304 .63945 m .42034 .63705 L .42184 .63781 L .447 0 0 r
F
.43165 .6401 m .4304 .63945 L .42184 .63781 L .419 0 0 r
F
.44003 .6499 m .4295 .64873 L .43081 .64946 L .437 0 0 r
F
.44105 .65052 m .44003 .6499 L .43081 .64946 L .412 0 0 r
F
.64899 .52375 m .65079 .53004 L .64985 .53287 L .908 .272 0 r
F
.64899 .52375 m .64979 .52088 L .65079 .53004 L F
.63097 .89961 m .61644 .9017 L .61195 .90412 L .023 0 0 r
F
.63097 .89961 m .63608 .89704 L .61644 .9017 L F
.63681 .45302 m .6364 .45828 L .63686 .46095 L 0 0 0 r
F
.63681 .45302 m .63634 .45036 L .6364 .45828 L F
.61242 .56233 m .60913 .56629 L .60788 .56849 L F
.61242 .56233 m .61372 .56006 L .60913 .56629 L F
.21838 .84521 m .1941 .83258 L .1992 .83704 L .676 .031 0 r
F
.22315 .84937 m .21838 .84521 L .1992 .83704 L .657 .025 0 r
F
.53711 .62978 m .53119 .63158 L .52956 .63243 L 0 0 0 r
F
.53711 .62978 m .53897 .62885 L .53119 .63158 L F
.62895 .89429 m .61467 .89656 L .61024 .89894 L .007 0 0 r
F
.45125 .64314 m .44152 .64187 L .44251 .64237 L .353 0 0 r
F
.45193 .64354 m .45125 .64314 L .44251 .64237 L .322 0 0 r
F
.46064 .64393 m .45125 .64314 L .45193 .64354 L .299 0 0 r
F
.41582 .64527 m .40492 .64287 L .40669 .64393 L .546 0 0 r
F
.41736 .6462 m .41582 .64527 L .40669 .64393 L .527 0 0 r
F
.58971 .59284 m .58546 .59604 L .58383 .59782 L 0 0 0 r
F
.58971 .59284 m .59144 .59097 L .58546 .59604 L F
.38428 .68637 m .36997 .6839 L .37191 .68666 L .998 .08 0 r
F
.38611 .68877 m .38428 .68637 L .37191 .68666 L .996 .08 0 r
F
.46951 .64426 m .46948 .64396 L .46064 .64393 L .232 0 0 r
F
.31423 .6192 m .3048 .60957 L .30612 .61276 L .972 .117 0 r
F
.3156 .62224 m .31423 .6192 L .30612 .61276 L .967 .115 0 r
F
.63338 .4536 m .63311 .45872 L .63344 .46135 L 0 0 0 r
F
.63338 .4536 m .63311 .45095 L .63311 .45872 L F
.22272 .83896 m .19897 .8264 L .20393 .83084 L .684 .034 0 r
F
.22737 .84311 m .22272 .83896 L .20393 .83084 L .665 .028 0 r
F
.91672 .47202 m .91106 .4857 L .91133 .49283 L 0 0 0 r
F
.91672 .47202 m .91643 .46478 L .91106 .4857 L F
.76332 .81497 m .75127 .81975 L .74655 .82431 L F
.76332 .81497 m .76838 .8102 L .75127 .81975 L F
.17386 .77673 m .15132 .7623 L .15558 .7675 L .799 .069 0 r
F
.17791 .78164 m .17386 .77673 L .15558 .7675 L .774 .065 0 r
F
.38313 .632 m .37238 .62773 L .37436 .62928 L .656 .024 0 r
F
.38495 .63342 m .38313 .632 L .37436 .62928 L .64 .019 0 r
F
.635 .51754 m .63275 .52229 L .63217 .5249 L 0 0 0 r
F
.635 .51754 m .63559 .51488 L .63275 .52229 L F
.2804 .8512 m .25581 .84362 L .26065 .84721 L .689 .03 0 r
F
.28479 .85454 m .2804 .8512 L .26065 .84721 L .66 .025 0 r
F
.62499 .8839 m .61135 .88692 L .60697 .88911 L 0 0 0 r
F
.62499 .8839 m .62998 .8816 L .61135 .88692 L F
.42723 .87959 m .40503 .88146 L .40736 .88341 L .442 0 0 r
F
.42883 .8814 m .42723 .87959 L .40736 .88341 L .422 0 0 r
F
.34562 .58493 m .33806 .57728 L .33952 .57942 L .744 .066 0 r
F
.34705 .58696 m .34562 .58493 L .33952 .57942 L .726 .06 0 r
F
.40503 .88146 m .38196 .88159 L .385 .88369 L .502 0 0 r
F
.40736 .88341 m .40503 .88146 L .385 .88369 L .484 0 0 r
F
.44152 .64187 m .43165 .6401 L .43291 .6407 L .393 0 0 r
F
.44251 .64237 m .44152 .64187 L .43291 .6407 L .363 0 0 r
F
.89986 .47235 m .90107 .48558 L .90087 .49254 L .803 .175 0 r
F
.89986 .47235 m .90088 .46533 L .90107 .48558 L F
.75558 .8061 m .74452 .81157 L .73987 .81595 L 0 0 0 r
F
.75558 .8061 m .76055 .8015 L .74452 .81157 L F
.88898 .63436 m .87963 .64425 L .87735 .65094 L F
.88898 .63436 m .89136 .62747 L .87963 .64425 L F
.72315 .36252 m .73639 .36652 L .73908 .37043 L .711 .043 0 r
F
.72315 .36252 m .71973 .3593 L .73639 .36652 L F
.63018 .51645 m .62847 .52118 L .62788 .52372 L 0 0 0 r
F
.63018 .51645 m .63076 .51387 L .62847 .52118 L F
.62838 .57846 m .62651 .58396 L .62489 .58638 L .724 .212 0 r
F
.62838 .57846 m .62998 .57595 L .62651 .58396 L F
.51884 .66382 m .51176 .66731 L .51029 .66766 L .44 .211 0 r
F
.51884 .66382 m .52064 .66345 L .51176 .66731 L F
.33995 .65384 m .32794 .64669 L .32965 .64979 L 1 .104 0 r
F
.34167 .6567 m .33995 .65384 L .32965 .64979 L 1 .103 0 r
F
.36867 .6083 m .35985 .60215 L .36162 .6039 L .661 .031 0 r
F
.37035 .60993 m .36867 .6083 L .36162 .6039 L .64 .024 0 r
F
.23284 .82438 m .20883 .81389 L .2136 .81819 L .734 .045 0 r
F
.23727 .8284 m .23284 .82438 L .2136 .81819 L .706 .04 0 r
F
.33693 .59562 m .32768 .58829 L .32935 .59057 L .784 .072 0 r
F
.33853 .59777 m .33693 .59562 L .32935 .59057 L .77 .067 0 r
F
.61508 .56699 m .61156 .57086 L .61023 .57311 L 0 0 0 r
F
.61508 .56699 m .61646 .56467 L .61156 .57086 L F
.41886 .63625 m .40889 .63319 L .41059 .63411 L .483 0 0 r
F
.42034 .63705 m .41886 .63625 L .41059 .63411 L .456 0 0 r
F
.75847 .57573 m .75487 .58381 L .75323 .58836 L 0 0 0 r
F
.75847 .57573 m .76009 .57106 L .75487 .58381 L F
.63723 .4557 m .63686 .46095 L .63727 .46363 L F
.63723 .4557 m .63681 .45302 L .63686 .46095 L F
.40144 .64064 m .39058 .63746 L .39251 .63873 L .594 .006 0 r
F
.40317 .64178 m .40144 .64064 L .39251 .63873 L .577 .001 0 r
F
.70925 .36442 m .69857 .37843 L .69694 .3835 L 0 0 0 r
F
.70925 .36442 m .71048 .35911 L .69857 .37843 L F
.461 .64425 m .46064 .64393 L .45193 .64354 L .266 0 0 r
F
.46951 .64426 m .46064 .64393 L .461 .64425 L .232 0 0 r
F
.77101 .46506 m .77339 .47431 L .77358 .4792 L .774 .137 0 r
F
.77101 .46506 m .77054 .46021 L .77339 .47431 L F
.66058 .45842 m .66581 .46389 L .66465 .46715 L 1 .895 0 r
F
.66058 .45842 m .6625 .45506 L .66581 .46389 L F
.87518 .62928 m .86889 .63995 L .86659 .64642 L 0 0 0 r
F
.87518 .62928 m .87749 .62262 L .86889 .63995 L F
.64817 .52661 m .64985 .53287 L .64888 .5357 L .905 .27 0 r
F
.64817 .52661 m .64899 .52375 L .64985 .53287 L F
.5619 .77531 m .55509 .79157 L .55206 .79229 L 1 1 0 r
F
.5619 .77531 m .56551 .77516 L .55509 .79157 L F
.3887 .62245 m .37922 .61756 L .38108 .61898 L .588 .005 0 r
F
.39043 .62374 m .3887 .62245 L .38108 .61898 L .565 0 0 r
F
.6336 .45624 m .63344 .46135 L .63373 .46399 L 0 0 0 r
F
.6336 .45624 m .63338 .4536 L .63344 .46135 L F
.61109 .56458 m .60788 .56849 L .60658 .57067 L F
.61109 .56458 m .61242 .56233 L .60788 .56849 L F
.59115 .59781 m .58681 .60094 L .5851 .60274 L F
.59115 .59781 m .59296 .59592 L .58681 .60094 L F
.54584 .79302 m .53717 .81021 L .53464 .81106 L 1 1 0 r
F
.54584 .79302 m .54898 .79277 L .53717 .81021 L F
.63437 .52019 m .63217 .5249 L .63155 .52751 L 0 0 0 r
F
.63437 .52019 m .635 .51754 L .63217 .5249 L F
.60233 .61281 m .59875 .61742 L .59671 .61931 L .586 .212 0 r
F
.60233 .61281 m .60443 .61081 L .59875 .61742 L F
.36294 .61942 m .35273 .61388 L .35467 .61575 L .708 .041 0 r
F
.36476 .62115 m .36294 .61942 L .35467 .61575 L .692 .036 0 r
F
.58795 .59467 m .58383 .59782 L .58216 .59958 L 0 0 0 r
F
.58795 .59467 m .58971 .59284 L .58383 .59782 L F
.3643 .67581 m .35076 .67126 L .35267 .67425 L 1 .109 0 r
F
.36616 .67848 m .3643 .67581 L .35267 .67425 L 1 .113 0 r
F
.4295 .64873 m .41891 .64709 L .42049 .64793 L .478 0 0 r
F
.43081 .64946 m .4295 .64873 L .42049 .64793 L .456 0 0 r
F
.40556 .63122 m .39578 .62737 L .39762 .62851 L .524 0 0 r
F
.40721 .63223 m .40556 .63122 L .39762 .62851 L .499 0 0 r
F
.62954 .51902 m .62788 .52372 L .62725 .52625 L 0 0 0 r
F
.62954 .51902 m .63018 .51645 L .62788 .52372 L F
.41986 .69493 m .40585 .69601 L .40759 .69814 L .74 .044 0 r
F
.42135 .69663 m .41986 .69493 L .40759 .69814 L .73 .044 0 r
F
.88304 .31087 m .88303 .32649 L .8859 .33298 L 0 0 0 r
F
.88304 .31087 m .88012 .30444 L .88303 .32649 L F
.71553 .65563 m .71008 .66214 L .70723 .66584 L F
.71553 .65563 m .71853 .65181 L .71008 .66214 L F
.882 .3113 m .88111 .32721 L .88374 .33374 L F
.882 .3113 m .87927 .30481 L .88111 .32721 L F
.34705 .58696 m .33952 .57942 L .34103 .58153 L .726 .06 0 r
F
.34852 .58897 m .34705 .58696 L .34103 .58153 L .708 .055 0 r
F
.3156 .62224 m .30612 .61276 L .30747 .61596 L .967 .115 0 r
F
.317 .62528 m .3156 .62224 L .30747 .61596 L .962 .113 0 r
F
.6376 .45838 m .63727 .46363 L .63763 .46631 L 0 0 0 r
F
.6376 .45838 m .63723 .4557 L .63727 .46363 L F
.67047 .7015 m .66496 .70815 L .66147 .7109 L .572 .219 0 r
F
.67047 .7015 m .67423 .69871 L .66496 .70815 L F
.61366 .56928 m .61023 .57311 L .60887 .57533 L 0 0 0 r
F
.61366 .56928 m .61508 .56699 L .61023 .57311 L F
.62674 .58094 m .62489 .58638 L .62324 .58876 L .725 .214 0 r
F
.62674 .58094 m .62838 .57846 L .62489 .58638 L F
.63376 .45889 m .63373 .46399 L .63396 .46663 L 0 0 0 r
F
.63376 .45889 m .6336 .45624 L .63373 .46399 L F
.65874 .4617 m .66465 .46715 L .66353 .47035 L 1 .944 0 r
F
.65874 .4617 m .66058 .45842 L .66465 .46715 L F
.53524 .63065 m .52956 .63243 L .5279 .63324 L 0 0 0 r
F
.53524 .63065 m .53711 .62978 L .52956 .63243 L F
.38495 .63342 m .37436 .62928 L .37637 .6308 L .64 .019 0 r
F
.3868 .63481 m .38495 .63342 L .37637 .6308 L .623 .014 0 r
F
.33853 .59777 m .32935 .59057 L .33105 .59283 L .77 .067 0 r
F
.34018 .5999 m .33853 .59777 L .33105 .59283 L .756 .063 0 r
F
.64731 .52946 m .64888 .5357 L .64788 .5385 L .902 .269 0 r
F
.64731 .52946 m .64817 .52661 L .64888 .5357 L F
.43165 .6401 m .42184 .63781 L .42336 .63852 L .419 0 0 r
F
.43291 .6407 m .43165 .6401 L .42336 .63852 L .39 0 0 r
F
.37035 .60993 m .36162 .6039 L .36342 .60562 L .64 .024 0 r
F
.37206 .61153 m .37035 .60993 L .36342 .60562 L .618 .018 0 r
F
.45102 .65113 m .44105 .65052 L .44208 .65108 L .356 0 0 r
F
.45174 .65159 m .45102 .65113 L .44208 .65108 L .327 0 0 r
F
.72642 .36586 m .73908 .37043 L .74167 .37442 L .724 .048 0 r
F
.72642 .36586 m .72315 .36252 L .73908 .37043 L F
.54863 .92187 m .53161 .92256 L .5291 .92394 L .157 0 0 r
F
.54863 .92187 m .55195 .92041 L .53161 .92256 L F
.6097 .56681 m .60658 .57067 L .60525 .57283 L 0 0 0 r
F
.6097 .56681 m .61109 .56458 L .60658 .57067 L F
.63368 .52283 m .63155 .52751 L .63087 .5301 L F
.63368 .52283 m .63437 .52019 L .63155 .52751 L F
.40413 .69392 m .38984 .69365 L .39174 .69616 L .885 .065 0 r
F
.40585 .69601 m .40413 .69392 L .39174 .69616 L .879 .065 0 r
F
.54776 .9169 m .53097 .91785 L .52849 .91923 L .139 0 0 r
F
.54776 .9169 m .55105 .91547 L .53097 .91785 L F
.50732 .66814 m .4998 .67171 L .49867 .67193 L .451 .212 0 r
F
.50732 .66814 m .50881 .66793 L .4998 .67171 L F
.41736 .6462 m .40669 .64393 L .40849 .64495 L .527 0 0 r
F
.41891 .64709 m .41736 .6462 L .40849 .64495 L .507 0 0 r
F
.70784 .3697 m .69694 .3835 L .69522 .38848 L 0 0 0 r
F
.70784 .3697 m .70925 .36442 L .69694 .3835 L F
.44105 .65052 m .43081 .64946 L .43213 .65014 L .412 0 0 r
F
.44208 .65108 m .44105 .65052 L .43213 .65014 L .387 0 0 r
F
.82409 .75118 m .81321 .75783 L .80922 .76341 L 0 0 0 r
F
.82409 .75118 m .82832 .74537 L .81321 .75783 L F
.62887 .52158 m .62725 .52625 L .62657 .52876 L F
.62887 .52158 m .62954 .51902 L .62725 .52625 L F
.58931 .59966 m .5851 .60274 L .58336 .60451 L F
.58931 .59966 m .59115 .59781 L .5851 .60274 L F
.59814 .91067 m .58308 .91225 L .57912 .91419 L .067 0 0 r
F
.59814 .91067 m .60281 .90861 L .58308 .91225 L F
.77137 .46993 m .77358 .4792 L .77367 .4841 L .777 .14 0 r
F
.77137 .46993 m .77101 .46506 L .77358 .4792 L F
.54605 .90711 m .52973 .90878 L .52729 .91001 L .069 0 0 r
F
.54605 .90711 m .54928 .90584 L .52973 .90878 L F
.34167 .6567 m .32965 .64979 L .3314 .65292 L 1 .103 0 r
F
.34342 .65958 m .34167 .6567 L .3314 .65292 L F
.63793 .46107 m .63763 .46631 L .63795 .469 L 0 0 0 r
F
.63793 .46107 m .6376 .45838 L .63763 .46631 L F
.91688 .47929 m .91133 .49283 L .91148 .49997 L F
.91688 .47929 m .91672 .47202 L .91133 .49283 L F
.75676 .58038 m .75323 .58836 L .75151 .59287 L F
.75676 .58038 m .75847 .57573 L .75323 .58836 L F
.45193 .64354 m .44251 .64237 L .4435 .64282 L .322 0 0 r
F
.45262 .64391 m .45193 .64354 L .4435 .64282 L .289 0 0 r
F
.461 .64425 m .45193 .64354 L .45262 .64391 L .266 0 0 r
F
.59658 .90536 m .58177 .90717 L .57785 .90908 L .047 0 0 r
F
.59658 .90536 m .60119 .90334 L .58177 .90717 L F
.37479 .91369 m .35039 .90886 L .35447 .9109 L .464 0 0 r
F
.37818 .91549 m .37479 .91369 L .35447 .9109 L .438 0 0 r
F
.38611 .68877 m .37191 .68666 L .37388 .68947 L .996 .08 0 r
F
.38796 .69119 m .38611 .68877 L .37388 .68947 L .994 .08 0 r
F
.8141 .74352 m .80469 .75091 L .80075 .75632 L 0 0 0 r
F
.8141 .74352 m .81824 .73788 L .80469 .75091 L F
.39043 .62374 m .38108 .61898 L .38298 .62036 L .565 0 0 r
F
.39219 .62499 m .39043 .62374 L .38298 .62036 L .541 0 0 r
F
.46955 .64452 m .46951 .64426 L .461 .64425 L .197 0 0 r
F
.58615 .59647 m .58216 .59958 L .58045 .60129 L 0 0 0 r
F
.58615 .59647 m .58795 .59467 L .58216 .59958 L F
.60018 .61478 m .59671 .61931 L .59464 .62116 L .592 .215 0 r
F
.60018 .61478 m .60233 .61281 L .59671 .61931 L F
.37628 .90703 m .35222 .90237 L .35623 .90442 L .471 0 0 r
F
.3796 .90884 m .37628 .90703 L .35623 .90442 L .446 0 0 r
F
.63387 .46155 m .63396 .46663 L .63415 .46926 L 0 0 0 r
F
.63387 .46155 m .63376 .45889 L .63396 .46663 L F
.89884 .47934 m .90087 .49254 L .90055 .49948 L .827 .179 0 r
F
.89884 .47934 m .89986 .47235 L .90087 .49254 L F
.5935 .89491 m .57927 .8975 L .57541 .89922 L 0 0 0 r
F
.5935 .89491 m .59805 .8931 L .57927 .8975 L F
.40317 .64178 m .39251 .63873 L .39447 .63996 L .577 .001 0 r
F
.40492 .64287 m .40317 .64178 L .39447 .63996 L .558 0 0 r
F
.34852 .58897 m .34103 .58153 L .34257 .58361 L .708 .055 0 r
F
.35003 .59094 m .34852 .58897 L .34257 .58361 L .689 .049 0 r
F
.44251 .64237 m .43291 .6407 L .43419 .64126 L .363 0 0 r
F
.4435 .64282 m .44251 .64237 L .43419 .64126 L .332 0 0 r
F
.42034 .63705 m .41059 .63411 L .41231 .63499 L .456 0 0 r
F
.42184 .63781 m .42034 .63705 L .41231 .63499 L .428 0 0 r
F
.16115 .79883 m .13875 .78279 L .14336 .78818 L .742 .057 0 r
F
.16556 .80391 m .16115 .79883 L .14336 .78818 L .725 .051 0 r
F
.36476 .62115 m .35467 .61575 L .35664 .61758 L .692 .036 0 r
F
.36662 .62285 m .36476 .62115 L .35664 .61758 L .676 .031 0 r
F
.44714 .69141 m .43462 .69433 L .43582 .69565 L .383 0 0 r
F
.44799 .69235 m .44714 .69141 L .43582 .69565 L .364 0 0 r
F
.6192 .40254 m .62087 .40749 L .62215 .40985 L 0 0 0 r
F
.43462 .69433 m .42135 .69663 L .42285 .69836 L .547 .016 0 r
F
.43582 .69565 m .43462 .69433 L .42285 .69836 L .531 .015 0 r
F
.61917 .40255 m .62021 .40781 L .62138 .41021 L 0 0 0 r
F
.6122 .57154 m .60887 .57533 L .60747 .57752 L F
.6122 .57154 m .61366 .56928 L .60887 .57533 L F
.16702 .79281 m .14527 .77687 L .14972 .78222 L .748 .059 0 r
F
.17128 .79786 m .16702 .79281 L .14972 .78222 L .732 .054 0 r
F
.65703 .46491 m .66353 .47035 L .66247 .47351 L 1 .978 0 r
F
.65703 .46491 m .65874 .4617 L .66353 .47035 L F
.88647 .64122 m .87735 .65094 L .87495 .65758 L 0 0 0 r
F
.88647 .64122 m .88898 .63436 L .87735 .65094 L F
.63294 .52546 m .63087 .5301 L .63015 .53268 L F
.63294 .52546 m .63368 .52283 L .63087 .5301 L F
.64641 .5323 m .64788 .5385 L .64685 .5413 L .899 .27 0 r
F
.64641 .5323 m .64731 .52946 L .64788 .5385 L F
.62506 .5834 m .62324 .58876 L .62154 .59112 L .726 .216 0 r
F
.62506 .5834 m .62674 .58094 L .62324 .58876 L F
.317 .62528 m .30747 .61596 L .30887 .61917 L .962 .113 0 r
F
.31844 .62832 m .317 .62528 L .30887 .61917 L .959 .112 0 r
F
.31255 .89543 m .28768 .88775 L .29274 .89067 L .544 0 0 r
F
.31707 .89808 m .31255 .89543 L .29274 .89067 L .52 0 0 r
F
.52859 .65952 m .52242 .66302 L .52064 .66345 L .472 .225 0 r
F
.52859 .65952 m .53066 .65904 L .52242 .66302 L F
.60828 .56901 m .60525 .57283 L .60387 .57496 L 0 0 0 r
F
.60828 .56901 m .6097 .56681 L .60525 .57283 L F
.51703 .66412 m .51029 .66766 L .50881 .66793 L .477 .26 0 r
F
.51703 .66412 m .51884 .66382 L .51029 .66766 L F
.38196 .88159 m .35851 .88011 L .36222 .88238 L .542 .003 0 r
F
.385 .88369 m .38196 .88159 L .36222 .88238 L .524 0 0 r
F
.34636 .9067 m .32166 .90061 L .32631 .90303 L .499 0 0 r
F
.35039 .90886 m .34636 .9067 L .32631 .90303 L .474 0 0 r
F
.315 .88902 m .29053 .88143 L .29549 .88438 L .553 0 0 r
F
.31944 .89168 m .315 .88902 L .29549 .88438 L .53 0 0 r
F
.87275 .63591 m .86659 .64642 L .86417 .65285 L 0 0 0 r
F
.87275 .63591 m .87518 .62928 L .86659 .64642 L F
.34018 .5999 m .33105 .59283 L .3328 .59505 L .756 .063 0 r
F
.34186 .60199 m .34018 .5999 L .3328 .59505 L .741 .058 0 r
F
.17791 .78164 m .15558 .7675 L .15994 .77264 L .774 .065 0 r
F
.18205 .78647 m .17791 .78164 L .15994 .77264 L .758 .06 0 r
F
.62814 .52413 m .62657 .52876 L .62585 .53127 L 0 0 0 r
F
.62814 .52413 m .62887 .52158 L .62657 .52876 L F
.40721 .63223 m .39762 .62851 L .39947 .6296 L .499 0 0 r
F
.40889 .63319 m .40721 .63223 L .39947 .6296 L .472 0 0 r
F
.46955 .64452 m .461 .64425 L .46137 .64453 L .197 0 0 r
F
.6382 .46377 m .63795 .469 L .63821 .4717 L 0 0 0 r
F
.6382 .46377 m .63793 .46107 L .63795 .469 L F
.52657 .92519 m .50869 .92543 L .50701 .92664 L .192 0 0 r
F
.52657 .92519 m .5291 .92394 L .50869 .92543 L F
.34827 .90019 m .32394 .89423 L .3285 .89667 L .508 0 0 r
F
.35222 .90237 m .34827 .90019 L .3285 .89667 L .484 0 0 r
F
.37206 .61153 m .36342 .60562 L .36525 .60731 L .618 .018 0 r
F
.3738 .61309 m .37206 .61153 L .36525 .60731 L .596 .012 0 r
F
.71245 .65938 m .71553 .65563 L .70723 .66584 L .551 .196 0 r
F
.71245 .65938 m .70723 .66584 L .70431 .66947 L F
.63393 .4642 m .63415 .46926 L .6343 .47191 L .717 .137 0 r
F
.63393 .4642 m .63387 .46155 L .63415 .46926 L F
.72955 .36933 m .74167 .37442 L .74415 .37848 L .736 .053 0 r
F
.72955 .36933 m .72642 .36586 L .74167 .37442 L F
.36616 .67848 m .35267 .67425 L .35462 .67728 L 1 .113 0 r
F
.36805 .68117 m .36616 .67848 L .35462 .67728 L 1 .119 0 r
F
.57106 .91768 m .55523 .91882 L .55195 .92041 L .109 0 0 r
F
.57106 .91768 m .57512 .916 L .55523 .91882 L F
.57769 .75963 m .57251 .77411 L .56904 .77475 L 1 1 0 r
F
.57769 .75963 m .58169 .75944 L .57251 .77411 L F
.62044 .40486 m .62215 .40985 L .62339 .41224 L 0 0 0 r
F
.62044 .40486 m .6192 .40254 L .62215 .40985 L F
.58742 .60147 m .58336 .60451 L .58158 .60625 L F
.58742 .60147 m .58931 .59966 L .58336 .60451 L F
.3868 .63481 m .37637 .6308 L .37841 .63229 L .623 .014 0 r
F
.38868 .63615 m .3868 .63481 L .37841 .63229 L .606 .008 0 r
F
.75816 .81966 m .74655 .82431 L .74174 .82878 L 0 0 0 r
F
.75816 .81966 m .76332 .81497 L .74655 .82431 L F
.32262 .86913 m .29839 .86402 L .30306 .867 L .627 .017 0 r
F
.32676 .87188 m .32262 .86913 L .30306 .867 L .602 .011 0 r
F
.70624 .37494 m .69522 .38848 L .6934 .39338 L 0 0 0 r
F
.70624 .37494 m .70784 .3697 L .69522 .38848 L F
.56988 .91251 m .55429 .9139 L .55105 .91547 L .088 0 0 r
F
.56988 .91251 m .57389 .91085 L .55429 .9139 L F
.6203 .40493 m .62138 .41021 L .6225 .41264 L 0 0 0 r
F
.6203 .40493 m .61917 .40255 L .62138 .41021 L F
.43081 .64946 m .42049 .64793 L .42209 .64874 L .456 0 0 r
F
.43213 .65014 m .43081 .64946 L .42209 .64874 L .434 0 0 r
F
.22315 .84937 m .1992 .83704 L .20439 .84141 L .657 .025 0 r
F
.22801 .85343 m .22315 .84937 L .20439 .84141 L .637 .019 0 r
F
.88583 .31736 m .8859 .33298 L .88864 .33952 L 0 0 0 r
F
.88583 .31736 m .88304 .31087 L .8859 .33298 L F
.35486 .87774 m .33096 .87455 L .33522 .87711 L .586 .009 0 r
F
.35851 .88011 m .35486 .87774 L .33522 .87711 L .563 .004 0 r
F
.88459 .31785 m .88374 .33374 L .88624 .34033 L 0 0 0 r
F
.88459 .31785 m .882 .3113 L .88374 .33374 L F
.75051 .81061 m .73987 .81595 L .73512 .82025 L F
.75051 .81061 m .75558 .8061 L .73987 .81595 L F
.56755 .90227 m .55248 .90444 L .54928 .90584 L .007 0 0 r
F
.56755 .90227 m .5715 .90081 L .55248 .90444 L F
.58432 .59824 m .58045 .60129 L .57871 .60298 L 0 0 0 r
F
.58432 .59824 m .58615 .59647 L .58045 .60129 L F
.22737 .84311 m .20393 .83084 L .20899 .8352 L .665 .028 0 r
F
.2321 .84716 m .22737 .84311 L .20899 .8352 L .646 .022 0 r
F
.27293 .87831 m .24831 .86866 L .2536 .8722 L .592 .004 0 r
F
.27777 .88156 m .27293 .87831 L .2536 .8722 L .57 0 0 r
F
.35003 .59094 m .34257 .58361 L .34416 .58567 L .689 .049 0 r
F
.35157 .59289 m .35003 .59094 L .34416 .58567 L .669 .043 0 r
F
.77163 .47481 m .77367 .4841 L .77368 .48899 L .779 .144 0 r
F
.77163 .47481 m .77137 .46993 L .77367 .4841 L F
.63215 .52808 m .63015 .53268 L .62938 .53525 L 0 0 0 r
F
.63215 .52808 m .63294 .52546 L .63015 .53268 L F
.65545 .46804 m .66247 .47351 L .66146 .47663 L 1 .996 0 r
F
.65545 .46804 m .65703 .46491 L .66247 .47351 L F
.61069 .57378 m .60747 .57752 L .60602 .57968 L 0 0 0 r
F
.61069 .57378 m .6122 .57154 L .60747 .57752 L F
.66662 .70417 m .66147 .7109 L .6579 .71354 L .593 .223 0 r
F
.66662 .70417 m .67047 .7015 L .66147 .7109 L F
.2761 .87197 m .25192 .86239 L .25708 .86594 L .601 .007 0 r
F
.28083 .87523 m .2761 .87197 L .25708 .86594 L .58 .001 0 r
F
.64548 .53513 m .64685 .5413 L .64579 .54407 L .896 .273 0 r
F
.64548 .53513 m .64641 .5323 L .64685 .5413 L F
.598 .6167 m .59464 .62116 L .59253 .62296 L .597 .217 0 r
F
.598 .6167 m .60018 .61478 L .59464 .62116 L F
.63842 .46648 m .63821 .4717 L .63842 .4744 L 0 0 0 r
F
.63842 .46648 m .6382 .46377 L .63821 .4717 L F
.75496 .58499 m .75151 .59287 L .74971 .59736 L F
.75496 .58499 m .75676 .58038 L .75151 .59287 L F
.62737 .52667 m .62585 .53127 L .62508 .53376 L F
.62737 .52667 m .62814 .52413 L .62585 .53127 L F
.43291 .6407 m .42336 .63852 L .42489 .6392 L .39 0 0 r
F
.43419 .64126 m .43291 .6407 L .42489 .6392 L .359 0 0 r
F
.52944 .81214 m .51887 .82898 L .51689 .82998 L 1 1 0 r
F
.52944 .81214 m .53206 .81171 L .51887 .82898 L F
.39219 .62499 m .38298 .62036 L .3849 .6217 L .541 0 0 r
F
.39397 .6262 m .39219 .62499 L .3849 .6217 L .516 0 0 r
F
.60682 .57118 m .60387 .57496 L .60245 .57706 L 0 0 0 r
F
.60682 .57118 m .60828 .56901 L .60387 .57496 L F
.34342 .65958 m .3314 .65292 L .33318 .65606 L 1 .103 0 r
F
.34521 .66247 m .34342 .65958 L .33318 .65606 L 1 .105 0 r
F
.23727 .8284 m .2136 .81819 L .21846 .8224 L .706 .04 0 r
F
.24179 .83233 m .23727 .8284 L .21846 .8224 L .69 .035 0 r
F
.36662 .62285 m .35664 .61758 L .35865 .61938 L .676 .031 0 r
F
.36851 .62451 m .36662 .62285 L .35865 .61938 L .66 .026 0 r
F
.62333 .58583 m .62154 .59112 L .6198 .59344 L .728 .218 0 r
F
.62333 .58583 m .62506 .5834 L .62154 .59112 L F
.41891 .64709 m .40849 .64495 L .41031 .64593 L .507 0 0 r
F
.42049 .64793 m .41891 .64709 L .41031 .64593 L .487 0 0 r
F
.63395 .46685 m .6343 .47191 L .63439 .47455 L .737 .143 0 r
F
.63395 .46685 m .63393 .4642 L .6343 .47191 L F
.42135 .69663 m .40759 .69814 L .40934 .70031 L .73 .044 0 r
F
.42285 .69836 m .42135 .69663 L .40934 .70031 L .721 .044 0 r
F
.28479 .85454 m .26065 .84721 L .26556 .85071 L .66 .025 0 r
F
.28926 .85779 m .28479 .85454 L .26556 .85071 L .64 .02 0 r
F
.34186 .60199 m .3328 .59505 L .33459 .59724 L .741 .058 0 r
F
.34358 .60405 m .34186 .60199 L .33459 .59724 L .726 .053 0 r
F
.62164 .40721 m .62339 .41224 L .62459 .41464 L 0 0 0 r
F
.62164 .40721 m .62044 .40486 L .62339 .41224 L F
.45174 .65159 m .44208 .65108 L .44312 .6516 L .327 0 0 r
F
.45246 .652 m .45174 .65159 L .44312 .6516 L .297 0 0 r
F
.31844 .62832 m .30887 .61917 L .3103 .62238 L .959 .112 0 r
F
.31993 .63136 m .31844 .62832 L .3103 .62238 L .957 .11 0 r
F
.62138 .40734 m .6225 .41264 L .62357 .41508 L 0 0 0 r
F
.62138 .40734 m .6203 .40493 L .6225 .41264 L F
.40492 .64287 m .39447 .63996 L .39645 .64115 L .558 0 0 r
F
.40669 .64393 m .40492 .64287 L .39645 .64115 L .54 0 0 r
F
.44208 .65108 m .43213 .65014 L .43347 .65078 L .387 0 0 r
F
.44312 .6516 m .44208 .65108 L .43347 .65078 L .361 0 0 r
F
.9169 .48656 m .91148 .49997 L .91149 .50711 L 0 0 0 r
F
.9169 .48656 m .91688 .47929 L .91148 .49997 L F
.42184 .63781 m .41231 .63499 L .41405 .63583 L .428 0 0 r
F
.42336 .63852 m .42184 .63781 L .41405 .63583 L .399 0 0 r
F
.3738 .61309 m .36525 .60731 L .36712 .60896 L .596 .012 0 r
F
.37558 .61462 m .3738 .61309 L .36712 .60896 L .573 .006 0 r
F
.40585 .69601 m .39174 .69616 L .39366 .69873 L .879 .065 0 r
F
.40759 .69814 m .40585 .69601 L .39366 .69873 L .875 .065 0 r
F
.45262 .64391 m .4435 .64282 L .4445 .64323 L .289 0 0 r
F
.45332 .64422 m .45262 .64391 L .4445 .64323 L .255 0 0 r
F
.63131 .53069 m .62938 .53525 L .62856 .5378 L 0 0 0 r
F
.63131 .53069 m .63215 .52808 L .62938 .53525 L F
.89786 .4863 m .90055 .49948 L .90012 .50642 L .843 .181 0 r
F
.89786 .4863 m .89884 .47934 L .90055 .49948 L F
.50581 .66829 m .49867 .67193 L .49752 .67209 L .494 .301 0 r
F
.50581 .66829 m .50732 .66814 L .49867 .67193 L F
.5855 .60325 m .58158 .60625 L .57976 .60795 L 0 0 0 r
F
.5855 .60325 m .58742 .60147 L .58158 .60625 L F
.38796 .69119 m .37388 .68947 L .37588 .69234 L .994 .08 0 r
F
.38984 .69365 m .38796 .69119 L .37588 .69234 L .992 .081 0 r
F
.65405 .47111 m .66146 .47663 L .6605 .47971 L 1 .998 0 r
F
.65405 .47111 m .65545 .46804 L .66146 .47663 L F
.63859 .46919 m .63842 .4744 L .63858 .4771 L 0 0 0 r
F
.63859 .46919 m .63842 .46648 L .63842 .4744 L F
.4435 .64282 m .43419 .64126 L .43548 .64177 L .332 0 0 r
F
.4445 .64323 m .4435 .64282 L .43548 .64177 L .3 0 0 r
F
.73253 .37292 m .74415 .37848 L .74652 .38261 L .747 .059 0 r
F
.73253 .37292 m .72955 .36933 L .74415 .37848 L F
.55824 .7752 m .55206 .79229 L .54898 .79277 L 1 1 0 r
F
.55824 .7752 m .5619 .77531 L .55206 .79229 L F
.70448 .38014 m .6934 .39338 L .69152 .39818 L 0 0 0 r
F
.70448 .38014 m .70624 .37494 L .6934 .39338 L F
.62656 .52919 m .62737 .52667 L .62508 .53376 L F
.62656 .52919 m .62508 .53376 L .62427 .53623 L F
.60914 .57599 m .60602 .57968 L .60453 .58182 L F
.60914 .57599 m .61069 .57378 L .60602 .57968 L F
.35157 .59289 m .34416 .58567 L .34578 .5877 L .669 .043 0 r
F
.35316 .5948 m .35157 .59289 L .34578 .5877 L .649 .037 0 r
F
.40889 .63319 m .39947 .6296 L .40136 .63065 L .472 0 0 r
F
.41059 .63411 m .40889 .63319 L .40136 .63065 L .445 0 0 r
F
.46959 .64473 m .46955 .64452 L .46137 .64453 L .161 0 0 r
F
.62579 .90206 m .61195 .90412 L .60741 .90643 L .005 0 0 r
F
.62579 .90206 m .63097 .89961 L .61195 .90412 L F
.6445 .53794 m .64579 .54407 L .64469 .54683 L .893 .278 0 r
F
.6445 .53794 m .64548 .53513 L .64579 .54407 L F
.58245 .59997 m .57871 .60298 L .57694 .60462 L 0 0 0 r
F
.58245 .59997 m .58432 .59824 L .57871 .60298 L F
.63392 .46951 m .63439 .47455 L .63445 .47719 L .756 .148 0 r
F
.63392 .46951 m .63395 .46685 L .63439 .47455 L F
.62382 .89669 m .61024 .89894 L .60574 .9012 L 0 0 0 r
F
.62382 .89669 m .62895 .89429 L .61024 .89894 L F
.81974 .75693 m .80922 .76341 L .80511 .76893 L F
.81974 .75693 m .82409 .75118 L .80922 .76341 L F
.60531 .57334 m .60245 .57706 L .601 .57913 L F
.60531 .57334 m .60682 .57118 L .60245 .57706 L F
.61994 .88608 m .60697 .88911 L .60254 .89117 L F
.61994 .88608 m .62499 .8839 L .60697 .88911 L F
.38868 .63615 m .37841 .63229 L .38048 .63373 L .606 .008 0 r
F
.39058 .63746 m .38868 .63615 L .38048 .63373 L .588 .003 0 r
F
.6228 .40958 m .62459 .41464 L .62574 .41708 L 0 0 0 r
F
.6228 .40958 m .62164 .40721 L .62459 .41464 L F
.80986 .74908 m .80075 .75632 L .79669 .76165 L F
.80986 .74908 m .8141 .74352 L .80075 .75632 L F
.70928 .66307 m .70431 .66947 L .7013 .67304 L .563 .2 0 r
F
.70928 .66307 m .71245 .65938 L .70431 .66947 L F
.62241 .40976 m .62357 .41508 L .62459 .41755 L 0 0 0 r
F
.62241 .40976 m .62138 .40734 L .62357 .41508 L F
.77179 .4797 m .77368 .48899 L .77361 .49389 L .782 .147 0 r
F
.77179 .4797 m .77163 .47481 L .77368 .48899 L F
.88382 .64804 m .87495 .65758 L .87242 .66418 L 0 0 0 r
F
.88382 .64804 m .88647 .64122 L .87495 .65758 L F
.62156 .58822 m .6198 .59344 L .61802 .59573 L .729 .22 0 r
F
.62156 .58822 m .62333 .58583 L .6198 .59344 L F
.5265 .65994 m .52064 .66345 L .51884 .66382 L .501 .323 0 r
F
.5265 .65994 m .52859 .65952 L .52064 .66345 L F
.59578 .61858 m .59253 .62296 L .59038 .62472 L .602 .219 0 r
F
.59578 .61858 m .598 .6167 L .59253 .62296 L F
.40168 .91914 m .37818 .91549 L .3816 .91717 L .416 0 0 r
F
.40434 .9206 m .40168 .91914 L .3816 .91717 L .387 0 0 r
F
.8702 .64251 m .86417 .65285 L .86164 .65924 L 0 0 0 r
F
.8702 .64251 m .87275 .63591 L .86417 .65285 L F
.42637 .92315 m .42452 .92189 L .40434 .9206 L .353 0 0 r
F
.54265 .79301 m .53464 .81106 L .53206 .81171 L 1 1 0 r
F
.54265 .79301 m .54584 .79302 L .53464 .81106 L F
.36805 .68117 m .35462 .67728 L .35659 .68035 L 1 .119 0 r
F
.36997 .6839 m .36805 .68117 L .35659 .68035 L 1 .126 0 r
F
.40277 .91227 m .3796 .90884 L .38297 .91053 L .42 0 0 r
F
.40539 .91373 m .40277 .91227 L .38297 .91053 L .393 0 0 r
F
.42528 .91474 m .40277 .91227 L .40539 .91373 L .382 0 0 r
F
.46959 .64473 m .46137 .64453 L .46175 .64476 L .161 0 0 r
F
.36851 .62451 m .35865 .61938 L .36069 .62115 L .66 .026 0 r
F
.37043 .62614 m .36851 .62451 L .36069 .62115 L .643 .021 0 r
F
.4271 .91599 m .42528 .91474 L .40539 .91373 L .353 0 0 r
F
.34358 .60405 m .33459 .59724 L .33642 .59941 L .726 .053 0 r
F
.34534 .60608 m .34358 .60405 L .33642 .59941 L .711 .048 0 r
F
.39397 .6262 m .3849 .6217 L .38685 .623 L .516 0 0 r
F
.39578 .62737 m .39397 .6262 L .38685 .623 L .49 0 0 r
F
.63043 .53328 m .62856 .5378 L .62769 .54033 L 0 0 0 r
F
.63043 .53328 m .63131 .53069 L .62856 .5378 L F
.51521 .66435 m .50881 .66793 L .50732 .66814 L .513 .373 0 r
F
.51521 .66435 m .51703 .66412 L .50881 .66793 L F
.43582 .69565 m .42285 .69836 L .42437 .70012 L .531 .015 0 r
F
.43703 .69697 m .43582 .69565 L .42437 .70012 L .516 .015 0 r
F
.44799 .69235 m .43582 .69565 L .43703 .69697 L .364 0 0 r
F
.63871 .47191 m .63858 .4771 L .6387 .47981 L 0 0 0 r
F
.63871 .47191 m .63859 .46919 L .63858 .4771 L F
.75307 .58958 m .74971 .59736 L .74782 .6018 L F
.75307 .58958 m .75496 .58499 L .74971 .59736 L F
.50179 .64628 m .4952 .64755 L .49423 .64787 L F
.50179 .64628 m .50307 .64594 L .4952 .64755 L F
.44883 .69328 m .44799 .69235 L .43703 .69697 L .346 0 0 r
F
.16556 .80391 m .14336 .78818 L .14809 .79349 L .725 .051 0 r
F
.17006 .80891 m .16556 .80391 L .14809 .79349 L .708 .046 0 r
F
.6257 .53171 m .62427 .53623 L .62342 .5387 L .681 .178 0 r
F
.6257 .53171 m .62656 .52919 L .62427 .53623 L F
.65282 .47413 m .6605 .47971 L .65958 .48276 L 1 .985 0 r
F
.65282 .47413 m .65405 .47111 L .6605 .47971 L F
.63385 .47216 m .63445 .47719 L .63446 .47983 L .772 .153 0 r
F
.63385 .47216 m .63392 .46951 L .63445 .47719 L F
.43213 .65014 m .42209 .64874 L .4237 .64951 L .434 0 0 r
F
.43347 .65078 m .43213 .65014 L .4237 .64951 L .411 0 0 r
F
.34521 .66247 m .33318 .65606 L .335 .65924 L 1 .105 0 r
F
.34703 .66538 m .34521 .66247 L .335 .65924 L 1 .109 0 r
F
.31993 .63136 m .3103 .62238 L .31178 .62561 L .957 .11 0 r
F
.32145 .63441 m .31993 .63136 L .31178 .62561 L .956 .109 0 r
F
.17128 .79786 m .14972 .78222 L .15428 .7875 L .732 .054 0 r
F
.17565 .80283 m .17128 .79786 L .15428 .7875 L .715 .048 0 r
F
.40736 .88341 m .385 .88369 L .38808 .88569 L .484 0 0 r
F
.40973 .88526 m .40736 .88341 L .38808 .88569 L .466 0 0 r
F
.42883 .8814 m .40736 .88341 L .40973 .88526 L .422 0 0 r
F
.8885 .32392 m .88864 .33952 L .89126 .34612 L 0 0 0 r
F
.8885 .32392 m .88583 .31736 L .88864 .33952 L F
.64348 .54075 m .64469 .54683 L .64355 .54958 L .891 .284 0 r
F
.64348 .54075 m .6445 .53794 L .64469 .54683 L F
.60755 .57818 m .60453 .58182 L .603 .58393 L 0 0 0 r
F
.60755 .57818 m .60914 .57599 L .60453 .58182 L F
.88705 .32447 m .88624 .34033 L .88859 .34697 L F
.88705 .32447 m .88459 .31785 L .88624 .34033 L F
.37558 .61462 m .36712 .60896 L .36902 .61058 L .573 .006 0 r
F
.37738 .61611 m .37558 .61462 L .36902 .61058 L .55 0 0 r
F
.43045 .88311 m .42883 .8814 L .40973 .88526 L .401 0 0 r
F
.35316 .5948 m .34578 .5877 L .34745 .5897 L .649 .037 0 r
F
.35478 .59669 m .35316 .5948 L .34745 .5897 L .628 .031 0 r
F
.58354 .605 m .57976 .60795 L .57791 .6096 L 0 0 0 r
F
.58354 .605 m .5855 .60325 L .57976 .60795 L F
.18205 .78647 m .15994 .77264 L .16441 .7777 L .758 .06 0 r
F
.18629 .79123 m .18205 .78647 L .16441 .7777 L .744 .055 0 r
F
.62391 .41198 m .62574 .41708 L .62684 .41953 L 0 0 0 r
F
.62391 .41198 m .6228 .40958 L .62574 .41708 L F
.62339 .41221 m .62459 .41755 L .62556 .42003 L F
.62339 .41221 m .62241 .40976 L .62459 .41755 L F
.60376 .57546 m .601 .57913 L .5995 .58118 L F
.60376 .57546 m .60531 .57334 L .601 .57913 L F
.43419 .64126 m .42489 .6392 L .42644 .63982 L .359 0 0 r
F
.43548 .64177 m .43419 .64126 L .42644 .63982 L .328 0 0 r
F
.66268 .70673 m .6579 .71354 L .65425 .71606 L .611 .229 0 r
F
.66268 .70673 m .66662 .70417 L .6579 .71354 L F
.58054 .60167 m .57694 .60462 L .57513 .60624 L 0 0 0 r
F
.58054 .60167 m .58245 .59997 L .57694 .60462 L F
.70257 .38527 m .69152 .39818 L .68958 .40289 L F
.70257 .38527 m .70448 .38014 L .69152 .39818 L F
.42049 .64793 m .41031 .64593 L .41215 .64687 L .487 0 0 r
F
.42209 .64874 m .42049 .64793 L .41215 .64687 L .466 0 0 r
F
.40669 .64393 m .39645 .64115 L .39845 .64231 L .54 0 0 r
F
.40849 .64495 m .40669 .64393 L .39845 .64231 L .521 0 0 r
F
.51038 .64407 m .50434 .64554 L .50307 .64594 L 0 0 0 r
F
.51038 .64407 m .51195 .64363 L .50434 .64554 L F
.73537 .37662 m .74652 .38261 L .74878 .3868 L .758 .064 0 r
F
.73537 .37662 m .73253 .37292 L .74652 .38261 L F
.63878 .47463 m .6387 .47981 L .63876 .48252 L 0 0 0 r
F
.63878 .47463 m .63871 .47191 L .6387 .47981 L F
.61974 .59059 m .61802 .59573 L .6162 .59799 L .73 .221 0 r
F
.61974 .59059 m .62156 .58822 L .61802 .59573 L F
.62949 .53585 m .62769 .54033 L .62678 .54285 L 0 0 0 r
F
.62949 .53585 m .63043 .53328 L .62769 .54033 L F
.42336 .63852 m .41405 .63583 L .4158 .63663 L .399 0 0 r
F
.42489 .6392 m .42336 .63852 L .4158 .63663 L .37 0 0 r
F
.63376 .47481 m .63446 .47983 L .63443 .48247 L .785 .157 0 r
F
.63376 .47481 m .63385 .47216 L .63446 .47983 L F
.62479 .53421 m .62342 .5387 L .62252 .54114 L .689 .182 0 r
F
.62479 .53421 m .6257 .53171 L .62342 .5387 L F
.41059 .63411 m .40136 .63065 L .40326 .63166 L .445 0 0 r
F
.41231 .63499 m .41059 .63411 L .40326 .63166 L .417 0 0 r
F
.53785 .65498 m .53271 .65849 L .53066 .65904 L .506 .295 0 r
F
.53785 .65498 m .54016 .65436 L .53271 .65849 L F
.54358 .62683 m .53897 .62885 L .53711 .62978 L 0 0 0 r
F
.91678 .49384 m .91149 .50711 L .91137 .51426 L F
.91678 .49384 m .9169 .48656 L .91149 .50711 L F
.65178 .4771 m .65958 .48276 L .65871 .48578 L 1 .959 0 r
F
.65178 .4771 m .65282 .47413 L .65958 .48276 L F
.77185 .48461 m .77361 .49389 L .77344 .49878 L .786 .15 0 r
F
.77185 .48461 m .77179 .4797 L .77361 .49389 L F
.59352 .62042 m .59038 .62472 L .5882 .62644 L .607 .221 0 r
F
.59352 .62042 m .59578 .61858 L .59038 .62472 L F
.45246 .652 m .44312 .6516 L .44417 .65208 L .297 0 0 r
F
.45319 .65237 m .45246 .652 L .44417 .65208 L .266 0 0 r
F
.34534 .60608 m .33642 .59941 L .33828 .60154 L .711 .048 0 r
F
.34713 .60808 m .34534 .60608 L .33828 .60154 L .695 .043 0 r
F
.39058 .63746 m .38048 .63373 L .38258 .63514 L .588 .003 0 r
F
.39251 .63873 m .39058 .63746 L .38258 .63514 L .57 0 0 r
F
.7529 .82424 m .74174 .82878 L .73684 .83316 L 0 0 0 r
F
.7529 .82424 m .75816 .81966 L .74174 .82878 L F
.89695 .49325 m .90012 .50642 L .89959 .51335 L .853 .181 0 r
F
.89695 .49325 m .89786 .4863 L .90012 .50642 L F
.44312 .6516 m .43347 .65078 L .43482 .65138 L .361 0 0 r
F
.44417 .65208 m .44312 .6516 L .43482 .65138 L .334 0 0 r
F
.62497 .41441 m .62684 .41953 L .62789 .422 L 0 0 0 r
F
.62497 .41441 m .62391 .41198 L .62684 .41953 L F
.62432 .41468 m .62556 .42003 L .62648 .42253 L F
.62432 .41468 m .62339 .41221 L .62556 .42003 L F
.64242 .54354 m .64355 .54958 L .64238 .55231 L .889 .292 0 r
F
.64242 .54354 m .64348 .54075 L .64355 .54958 L F
.74534 .81502 m .73512 .82025 L .73028 .82444 L 0 0 0 r
F
.74534 .81502 m .75051 .81061 L .73512 .82025 L F
.57361 .75956 m .56904 .77475 L .56551 .77516 L 1 1 0 r
F
.57361 .75956 m .57769 .75963 L .56904 .77475 L F
.37043 .62614 m .36069 .62115 L .36276 .62288 L .643 .021 0 r
F
.37238 .62773 m .37043 .62614 L .36276 .62288 L .626 .016 0 r
F
.42285 .69836 m .40934 .70031 L .41111 .70254 L .721 .044 0 r
F
.42437 .70012 m .42285 .69836 L .41111 .70254 L .712 .045 0 r
F
.60591 .58033 m .603 .58393 L .60142 .586 L 0 0 0 r
F
.60591 .58033 m .60755 .57818 L .603 .58393 L F
.45332 .64422 m .4445 .64323 L .44552 .64359 L .255 0 0 r
F
.45402 .64449 m .45332 .64422 L .44552 .64359 L .22 0 0 r
F
.4445 .64323 m .43548 .64177 L .43678 .64224 L .3 0 0 r
F
.44552 .64359 m .4445 .64323 L .43678 .64224 L .266 0 0 r
F
.60217 .57756 m .5995 .58118 L .59797 .5832 L .571 .195 0 r
F
.60217 .57756 m .60376 .57546 L .5995 .58118 L F
.39578 .62737 m .38685 .623 L .38883 .62426 L .49 0 0 r
F
.39762 .62851 m .39578 .62737 L .38883 .62426 L .464 0 0 r
F
.70602 .66669 m .7013 .67304 L .69821 .67654 L .576 .204 0 r
F
.70602 .66669 m .70928 .66307 L .7013 .67304 L F
.35478 .59669 m .34745 .5897 L .34915 .59167 L .628 .031 0 r
F
.35643 .59854 m .35478 .59669 L .34915 .59167 L .607 .025 0 r
F
.38984 .69365 m .37588 .69234 L .37789 .69527 L .992 .081 0 r
F
.39174 .69616 m .38984 .69365 L .37789 .69527 L .991 .088 0 r
F
.22801 .85343 m .20439 .84141 L .20968 .84568 L .637 .019 0 r
F
.23296 .85739 m .22801 .85343 L .20968 .84568 L .617 .013 0 r
F
.75108 .59413 m .74782 .6018 L .74584 .60621 L .653 .183 0 r
F
.75108 .59413 m .75307 .58958 L .74782 .6018 L F
.6388 .47735 m .63876 .48252 L .63877 .48523 L 0 0 0 r
F
.6388 .47735 m .63878 .47463 L .63876 .48252 L F
.40759 .69814 m .39366 .69873 L .3956 .70137 L .875 .065 0 r
F
.40934 .70031 m .40759 .69814 L .3956 .70137 L .87 .066 0 r
F
.58155 .6067 m .57791 .6096 L .57603 .61123 L 0 0 0 r
F
.58155 .6067 m .58354 .605 L .57791 .6096 L F
.32145 .63441 m .31178 .62561 L .3133 .62886 L .956 .109 0 r
F
.32302 .63747 m .32145 .63441 L .3133 .62886 L .957 .107 0 r
F
.37738 .61611 m .36902 .61058 L .37095 .61216 L .55 0 0 r
F
.37922 .61756 m .37738 .61611 L .37095 .61216 L .526 0 0 r
F
.46963 .6449 m .46959 .64473 L .46175 .64476 L .123 0 0 r
F
.2321 .84716 m .20899 .8352 L .21414 .83947 L .646 .022 0 r
F
.23693 .85111 m .2321 .84716 L .21414 .83947 L .626 .016 0 r
F
.63363 .47745 m .63443 .48247 L .63436 .48511 L .797 .16 0 r
F
.63363 .47745 m .63376 .47481 L .63443 .48247 L F
.62851 .53842 m .62678 .54285 L .62582 .54535 L 0 0 0 r
F
.62851 .53842 m .62949 .53585 L .62678 .54285 L F
.5786 .60333 m .57513 .60624 L .57329 .60781 L F
.5786 .60333 m .58054 .60167 L .57513 .60624 L F
.70052 .39035 m .68958 .40289 L .68758 .4075 L F
.70052 .39035 m .70257 .38527 L .68958 .40289 L F
.5043 .66836 m .49752 .67209 L .49637 .67218 L .535 .424 0 r
F
.5043 .66836 m .50581 .66829 L .49752 .67209 L F
.24179 .83233 m .21846 .8224 L .22341 .82653 L .69 .035 0 r
F
.24638 .83618 m .24179 .83233 L .22341 .82653 L .674 .03 0 r
F
.62384 .53669 m .62252 .54114 L .62157 .54357 L .697 .185 0 r
F
.62384 .53669 m .62479 .53421 L .62252 .54114 L F
.36997 .6839 m .35659 .68035 L .35859 .68347 L 1 .126 0 r
F
.37191 .68666 m .36997 .6839 L .35859 .68347 L 1 .136 0 r
F
.34703 .66538 m .335 .65924 L .33684 .66245 L 1 .109 0 r
F
.34888 .66831 m .34703 .66538 L .33684 .66245 L 1 .114 0 r
F
.88105 .65482 m .87242 .66418 L .86977 .67074 L 0 0 0 r
F
.88105 .65482 m .88382 .64804 L .87242 .66418 L F
.52439 .66028 m .51884 .66382 L .51703 .66412 L .529 .427 0 r
F
.52439 .66028 m .5265 .65994 L .51884 .66382 L F
.61787 .59293 m .6162 .59799 L .61434 .60022 L .731 .223 0 r
F
.61787 .59293 m .61974 .59059 L .6162 .59799 L F
.65092 .48005 m .65871 .48578 L .65788 .48878 L 1 .923 0 r
F
.65092 .48005 m .65178 .4771 L .65871 .48578 L F
.31707 .89808 m .29274 .89067 L .29788 .89349 L .52 0 0 r
F
.32166 .90061 m .31707 .89808 L .29788 .89349 L .495 0 0 r
F
.59342 .9126 m .57912 .91419 L .57512 .916 L .045 0 0 r
F
.59342 .9126 m .59814 .91067 L .57912 .91419 L F
.62598 .41685 m .62789 .422 L .6289 .4245 L 0 0 0 r
F
.62598 .41685 m .62497 .41441 L .62789 .422 L F
.86753 .64907 m .86164 .65924 L .85899 .66559 L F
.86753 .64907 m .8702 .64251 L .86164 .65924 L F
.31944 .89168 m .29549 .88438 L .30052 .88721 L .53 0 0 r
F
.32394 .89423 m .31944 .89168 L .30052 .88721 L .507 0 0 r
F
.6252 .41717 m .62648 .42253 L .62734 .42505 L 0 0 0 r
F
.6252 .41717 m .62432 .41468 L .62648 .42253 L F
.59191 .90725 m .57785 .90908 L .57389 .91085 L .023 0 0 r
F
.59191 .90725 m .59658 .90536 L .57785 .90908 L F
.73808 .38042 m .74878 .3868 L .75094 .39106 L .768 .07 0 r
F
.73808 .38042 m .73537 .37662 L .74878 .3868 L F
.81528 .7626 m .80511 .76893 L .80089 .77437 L 0 0 0 r
F
.81528 .7626 m .81974 .75693 L .80511 .76893 L F
.5889 .89657 m .57541 .89922 L .5715 .90081 L F
.5889 .89657 m .5935 .89491 L .57541 .89922 L F
.46963 .6449 m .46175 .64476 L .46213 .64495 L .123 0 0 r
F
.8055 .75457 m .79669 .76165 L .79253 .76691 L 0 0 0 r
F
.8055 .75457 m .80986 .74908 L .79669 .76165 L F
.64132 .54632 m .64238 .55231 L .64117 .55502 L .886 .301 0 r
F
.64132 .54632 m .64242 .54354 L .64238 .55231 L F
.27777 .88156 m .2536 .8722 L .25897 .87565 L .57 0 0 r
F
.28269 .88471 m .27777 .88156 L .25897 .87565 L .546 0 0 r
F
.32676 .87188 m .30306 .867 L .3078 .86989 L .602 .011 0 r
F
.33096 .87455 m .32676 .87188 L .3078 .86989 L .585 .006 0 r
F
.50049 .64658 m .49423 .64787 L .49325 .64814 L 0 0 0 r
F
.50049 .64658 m .50179 .64628 L .49423 .64787 L F
.43347 .65078 m .4237 .64951 L .42533 .65024 L .411 0 0 r
F
.43482 .65138 m .43347 .65078 L .42533 .65024 L .387 0 0 r
F
.28083 .87523 m .25708 .86594 L .26233 .8694 L .58 .001 0 r
F
.28565 .87838 m .28083 .87523 L .26233 .8694 L .558 0 0 r
F
.34713 .60808 m .33828 .60154 L .34019 .60364 L .695 .043 0 r
F
.34896 .61005 m .34713 .60808 L .34019 .60364 L .678 .038 0 r
F
.60424 .58246 m .60142 .586 L .59981 .58805 L 0 0 0 r
F
.60424 .58246 m .60591 .58033 L .60142 .586 L F
.37818 .91549 m .35447 .9109 L .3586 .91283 L .438 0 0 r
F
.3816 .91717 m .37818 .91549 L .3586 .91283 L .41 0 0 r
F
.63877 .48008 m .63877 .48523 L .63873 .48794 L .713 .141 0 r
F
.63877 .48008 m .6388 .47735 L .63877 .48523 L F
.51886 .64148 m .5135 .64314 L .51195 .64363 L .213 .174 0 r
F
.3796 .90884 m .35623 .90442 L .36029 .90637 L .446 0 0 r
F
.38297 .91053 m .3796 .90884 L .36029 .90637 L .419 0 0 r
F
.51337 .66451 m .50732 .66814 L .50581 .66829 L .546 .488 0 r
F
.51337 .66451 m .51521 .66435 L .50732 .66814 L F
.60054 .57963 m .59797 .5832 L .59639 .58519 L .578 .199 0 r
F
.60054 .57963 m .60217 .57756 L .59797 .5832 L F
.54526 .9232 m .5291 .92394 L .52657 .92519 L .131 0 0 r
F
.54526 .9232 m .54863 .92187 L .5291 .92394 L F
.89105 .33054 m .89126 .34612 L .89377 .35277 L 0 0 0 r
F
.89105 .33054 m .8885 .32392 L .89126 .34612 L F
.28926 .85779 m .26556 .85071 L .27054 .85412 L .64 .02 0 r
F
.29379 .86095 m .28926 .85779 L .27054 .85412 L .624 .015 0 r
F
.59122 .62221 m .5882 .62644 L .58599 .62811 L .611 .223 0 r
F
.59122 .62221 m .59352 .62042 L .5882 .62644 L F
.88937 .33114 m .88859 .34697 L .8908 .35366 L 0 0 0 r
F
.88937 .33114 m .88705 .32447 L .88859 .34697 L F
.63349 .4801 m .63436 .48511 L .63424 .48774 L .806 .163 0 r
F
.63349 .4801 m .63363 .47745 L .63436 .48511 L F
.40849 .64495 m .39845 .64231 L .40048 .64343 L .521 0 0 r
F
.41031 .64593 m .40849 .64495 L .40048 .64343 L .502 0 0 r
F
.43548 .64177 m .42644 .63982 L .428 .64041 L .328 0 0 r
F
.43678 .64224 m .43548 .64177 L .428 .64041 L .297 0 0 r
F
.54443 .91821 m .52849 .91923 L .52598 .92047 L .11 0 0 r
F
.54443 .91821 m .54776 .9169 L .52849 .91923 L F
.7718 .48952 m .77344 .49878 L .77318 .50367 L .789 .154 0 r
F
.7718 .48952 m .77185 .48461 L .77344 .49878 L F
.42209 .64874 m .41215 .64687 L .41401 .64778 L .466 0 0 r
F
.4237 .64951 m .42209 .64874 L .41401 .64778 L .446 0 0 r
F
.54277 .90825 m .52729 .91001 L .52483 .91112 L .033 0 0 r
F
.54277 .90825 m .54605 .90711 L .52729 .91001 L F
.35643 .59854 m .34915 .59167 L .35089 .59361 L .607 .025 0 r
F
.35812 .60036 m .35643 .59854 L .35089 .59361 L .585 .019 0 r
F
.62748 .54096 m .62582 .54535 L .62481 .54784 L .666 .182 0 r
F
.62748 .54096 m .62851 .53842 L .62582 .54535 L F
.385 .88369 m .36222 .88238 L .36598 .88456 L .524 0 0 r
F
.38808 .88569 m .385 .88369 L .36598 .88456 L .507 0 0 r
F
.35039 .90886 m .32631 .90303 L .33103 .90534 L .474 0 0 r
F
.35447 .9109 m .35039 .90886 L .33103 .90534 L .447 0 0 r
F
.35222 .90237 m .3285 .89667 L .33312 .899 L .484 0 0 r
F
.35623 .90442 m .35222 .90237 L .33312 .899 L .459 0 0 r
F
.65866 .70916 m .65425 .71606 L .65052 .71847 L .628 .324 0 r
F
.65866 .70916 m .66268 .70673 L .65425 .71606 L F
.62284 .53917 m .62157 .54357 L .62058 .54598 L .704 .189 0 r
F
.62284 .53917 m .62384 .53669 L .62157 .54357 L F
.41231 .63499 m .40326 .63166 L .40519 .63262 L .417 0 0 r
F
.41405 .63583 m .41231 .63499 L .40519 .63262 L .389 0 0 r
F
.37238 .62773 m .36276 .62288 L .36487 .62458 L .626 .016 0 r
F
.37436 .62928 m .37238 .62773 L .36487 .62458 L .609 .011 0 r
F
.42489 .6392 m .4158 .63663 L .41758 .63738 L .37 0 0 r
F
.42644 .63982 m .42489 .6392 L .41758 .63738 L .34 0 0 r
F
.39251 .63873 m .38258 .63514 L .3847 .63652 L .57 0 0 r
F
.39447 .63996 m .39251 .63873 L .3847 .63652 L .552 0 0 r
F
.5088 .64446 m .50307 .64594 L .50179 .64628 L .183 .17 0 r
F
.5088 .64446 m .51038 .64407 L .50307 .64594 L F
.57952 .60837 m .57603 .61123 L .57411 .61281 L 0 0 0 r
F
.57952 .60837 m .58155 .6067 L .57603 .61123 L F
.43703 .69697 m .42437 .70012 L .4259 .70192 L .516 .015 0 r
F
.43824 .69831 m .43703 .69697 L .4259 .70192 L .502 .015 0 r
F
.44883 .69328 m .43703 .69697 L .43824 .69831 L .346 0 0 r
F
.35851 .88011 m .33522 .87711 L .33954 .87959 L .563 .004 0 r
F
.36222 .88238 m .35851 .88011 L .33954 .87959 L .546 0 0 r
F
.62694 .41932 m .6289 .4245 L .62986 .42701 L 0 0 0 r
F
.62694 .41932 m .62598 .41685 L .6289 .4245 L F
.6502 .48297 m .65788 .48878 L .65709 .49176 L 1 .881 0 r
F
.6502 .48297 m .65092 .48005 L .65788 .48878 L F
.57663 .60495 m .57329 .60781 L .57142 .60935 L .462 .197 0 r
F
.57663 .60495 m .5786 .60333 L .57329 .60781 L F
.62603 .41968 m .62734 .42505 L .62816 .42758 L 0 0 0 r
F
.62603 .41968 m .6252 .41717 L .62734 .42505 L F
.37922 .61756 m .37095 .61216 L .37292 .61371 L .526 0 0 r
F
.38108 .61898 m .37922 .61756 L .37292 .61371 L .501 0 0 r
F
.44969 .69421 m .44883 .69328 L .43824 .69831 L .329 0 0 r
F
.69833 .39535 m .70052 .39035 L .68758 .4075 L 0 0 0 r
F
.39762 .62851 m .38883 .62426 L .39084 .62549 L .464 0 0 r
F
.39947 .6296 m .39762 .62851 L .39084 .62549 L .437 0 0 r
F
.32302 .63747 m .3133 .62886 L .31485 .63212 L .957 .107 0 r
F
.32462 .64053 m .32302 .63747 L .31485 .63212 L .959 .106 0 r
F
.53553 .65554 m .53066 .65904 L .52859 .65952 L .528 .384 0 r
F
.53553 .65554 m .53785 .65498 L .53066 .65904 L F
.17006 .80891 m .14809 .79349 L .15292 .79872 L .708 .046 0 r
F
.17467 .81382 m .17006 .80891 L .15292 .79872 L .69 .04 0 r
F
.55452 .77479 m .54898 .79277 L .54584 .79302 L 1 1 0 r
F
.55452 .77479 m .55824 .7752 L .54898 .79277 L F
.61597 .59523 m .61434 .60022 L .61244 .60241 L .732 .225 0 r
F
.61597 .59523 m .61787 .59293 L .61434 .60022 L F
.17565 .80283 m .15428 .7875 L .15895 .79269 L .715 .048 0 r
F
.18011 .80771 m .17565 .80283 L .15895 .79269 L .697 .043 0 r
F
.52678 .81235 m .51689 .82998 L .51487 .83081 L 1 1 0 r
F
.52678 .81235 m .52944 .81214 L .51689 .82998 L F
.91653 .50114 m .91137 .51426 L .91112 .52141 L 0 0 0 r
F
.91653 .50114 m .91678 .49384 L .91137 .51426 L F
.74901 .59864 m .74584 .60621 L .74379 .61059 L .659 .187 0 r
F
.74901 .59864 m .75108 .59413 L .74584 .60621 L F
.63869 .48281 m .63873 .48794 L .63865 .49065 L .725 .146 0 r
F
.63869 .48281 m .63877 .48008 L .63873 .48794 L F
.64017 .54908 m .64117 .55502 L .63992 .55771 L .884 .312 0 r
F
.64017 .54908 m .64132 .54632 L .64117 .55502 L F
.18629 .79123 m .16441 .7777 L .16897 .78269 L .744 .055 0 r
F
.19061 .79592 m .18629 .79123 L .16897 .78269 L .729 .05 0 r
F
.89612 .5002 m .89959 .51335 L .89896 .52028 L .858 .18 0 r
F
.89612 .5002 m .89695 .49325 L .89959 .51335 L F
.63331 .48274 m .63424 .48774 L .63408 .49037 L .814 .166 0 r
F
.63331 .48274 m .63349 .4801 L .63424 .48774 L F
.70268 .67023 m .69821 .67654 L .69503 .67996 L .587 .209 0 r
F
.70268 .67023 m .70602 .66669 L .69821 .67654 L F
.60252 .58456 m .59981 .58805 L .59816 .59007 L .562 .198 0 r
F
.60252 .58456 m .60424 .58246 L .59981 .58805 L F
.44417 .65208 m .43482 .65138 L .43619 .65194 L .334 0 0 r
F
.44523 .65252 m .44417 .65208 L .43619 .65194 L .307 0 0 r
F
.45319 .65237 m .44417 .65208 L .44523 .65252 L .266 0 0 r
F
.59887 .58167 m .59639 .58519 L .59478 .58715 L .585 .202 0 r
F
.59887 .58167 m .60054 .57963 L .59639 .58519 L F
.6264 .54349 m .62481 .54784 L .62375 .55031 L .675 .186 0 r
F
.6264 .54349 m .62748 .54096 L .62481 .54784 L F
.45392 .6527 m .45319 .65237 L .44523 .65252 L .234 0 0 r
F
.34896 .61005 m .34019 .60364 L .34213 .60571 L .678 .038 0 r
F
.35083 .61198 m .34896 .61005 L .34213 .60571 L .662 .032 0 r
F
.6218 .54162 m .62058 .54598 L .61955 .54838 L .711 .192 0 r
F
.6218 .54162 m .62284 .53917 L .62058 .54598 L F
.44552 .64359 m .43678 .64224 L .4381 .64266 L .266 0 0 r
F
.44654 .64391 m .44552 .64359 L .4381 .64266 L .232 0 0 r
F
.45402 .64449 m .44552 .64359 L .44654 .64391 L .22 0 0 r
F
.56696 .91924 m .55195 .92041 L .54863 .92187 L .084 0 0 r
F
.56696 .91924 m .57106 .91768 L .55195 .92041 L F
.74065 .38432 m .75094 .39106 L .75299 .39537 L .778 .075 0 r
F
.74065 .38432 m .73808 .38042 L .75094 .39106 L F
.56583 .91403 m .55105 .91547 L .54776 .9169 L .061 0 0 r
F
.56583 .91403 m .56988 .91251 L .55105 .91547 L F
.56355 .90359 m .54928 .90584 L .54605 .90711 L 0 0 0 r
F
.56355 .90359 m .56755 .90227 L .54928 .90584 L F
.34888 .66831 m .33684 .66245 L .33872 .6657 L 1 .114 0 r
F
.35076 .67126 m .34888 .66831 L .33872 .6657 L 1 .122 0 r
F
.35812 .60036 m .35089 .59361 L .35267 .59551 L .585 .019 0 r
F
.35985 .60215 m .35812 .60036 L .35267 .59551 L .563 .013 0 r
F
.62786 .42182 m .62986 .42701 L .63078 .42954 L .671 .084 0 r
F
.62786 .42182 m .62694 .41932 L .62986 .42701 L F
.62681 .42221 m .62816 .42758 L .62893 .43013 L 0 0 0 r
F
.62681 .42221 m .62603 .41968 L .62816 .42758 L F
.6496 .48588 m .65709 .49176 L .65633 .49472 L 1 .837 0 r
F
.6496 .48588 m .6502 .48297 L .65709 .49176 L F
.58888 .62395 m .58599 .62811 L .58373 .62973 L .615 .224 0 r
F
.58888 .62395 m .59122 .62221 L .58599 .62811 L F
.39174 .69616 m .37789 .69527 L .37994 .69829 L .991 .088 0 r
F
.39366 .69873 m .39174 .69616 L .37994 .69829 L .99 .099 0 r
F
.52401 .92632 m .50701 .92664 L .50532 .92771 L .164 0 0 r
F
.52401 .92632 m .52657 .92519 L .50701 .92664 L F
.37191 .68666 m .35859 .68347 L .36061 .68666 L 1 .136 0 r
F
.37388 .68947 m .37191 .68666 L .36061 .68666 L 1 .148 0 r
F
.77165 .49444 m .77318 .50367 L .77284 .50856 L .793 .157 0 r
F
.77165 .49444 m .7718 .48952 L .77318 .50367 L F
.63855 .48555 m .63865 .49065 L .63851 .49336 L .737 .151 0 r
F
.63855 .48555 m .63869 .48281 L .63865 .49065 L F
.57745 .61 m .57411 .61281 L .57216 .61435 L .457 .198 0 r
F
.57745 .61 m .57952 .60837 L .57411 .61281 L F
.63312 .48538 m .63408 .49037 L .63389 .493 L .82 .168 0 r
F
.63312 .48538 m .63331 .48274 L .63408 .49037 L F
.42437 .70012 m .41111 .70254 L .4129 .70485 L .712 .045 0 r
F
.4259 .70192 m .42437 .70012 L .4129 .70485 L .705 .046 0 r
F
.57462 .60654 m .57142 .60935 L .56952 .61085 L .471 .2 0 r
F
.57462 .60654 m .57663 .60495 L .57142 .60935 L F
.69602 .40027 m .69833 .39535 L .68554 .412 L 0 0 0 r
F
.37436 .62928 m .36487 .62458 L .36701 .62624 L .609 .011 0 r
F
.37637 .6308 m .37436 .62928 L .36701 .62624 L .591 .006 0 r
F
.53942 .79272 m .53206 .81171 L .52944 .81214 L 1 1 0 r
F
.53942 .79272 m .54265 .79301 L .53206 .81171 L F
.62054 .90439 m .60741 .90643 L .60281 .90861 L 0 0 0 r
F
.62054 .90439 m .62579 .90206 L .60741 .90643 L F
.40934 .70031 m .3956 .70137 L .39756 .70409 L .87 .066 0 r
F
.41111 .70254 m .40934 .70031 L .39756 .70409 L .866 .067 0 r
F
.61863 .89896 m .60574 .9012 L .60119 .90334 L 0 0 0 r
F
.61863 .89896 m .62382 .89669 L .60574 .9012 L F
.63897 .55183 m .63992 .55771 L .63862 .56038 L .882 .324 0 r
F
.63897 .55183 m .64017 .54908 L .63992 .55771 L F
.52227 .66056 m .51703 .66412 L .51521 .66435 L .556 .529 0 r
F
.52227 .66056 m .52439 .66028 L .51703 .66412 L F
.61482 .88812 m .60254 .89117 L .59805 .8931 L 0 0 0 r
F
.61482 .88812 m .61994 .88608 L .60254 .89117 L F
.38108 .61898 m .37292 .61371 L .37492 .61522 L .501 0 0 r
F
.38298 .62036 m .38108 .61898 L .37492 .61522 L .476 0 0 r
F
.61401 .5975 m .61244 .60241 L .6105 .60457 L .732 .226 0 r
F
.61401 .5975 m .61597 .59523 L .61244 .60241 L F
.87814 .66155 m .86977 .67074 L .86699 .67725 L 0 0 0 r
F
.87814 .66155 m .88105 .65482 L .86977 .67074 L F
.41031 .64593 m .40048 .64343 L .40254 .64452 L .502 0 0 r
F
.41215 .64687 m .41031 .64593 L .40254 .64452 L .484 0 0 r
F
.86474 .65559 m .85899 .66559 L .85622 .6719 L 0 0 0 r
F
.86474 .65559 m .86753 .64907 L .85899 .66559 L F
.62528 .546 m .62375 .55031 L .62265 .55275 L .683 .19 0 r
F
.62528 .546 m .6264 .54349 L .62375 .55031 L F
.50277 .66837 m .49637 .67218 L .49521 .6722 L .574 .547 0 r
F
.50277 .66837 m .5043 .66836 L .49637 .67218 L F
.62071 .54406 m .61955 .54838 L .61847 .55075 L .718 .195 0 r
F
.62071 .54406 m .6218 .54162 L .61955 .54838 L F
.74754 .82873 m .73684 .83316 L .73184 .83743 L 0 0 0 r
F
.74754 .82873 m .7529 .82424 L .73684 .83316 L F
.51703 .64197 m .51195 .64363 L .51038 .64407 L .244 .181 0 r
F
.51703 .64197 m .51886 .64148 L .51195 .64363 L F
.39447 .63996 m .3847 .63652 L .38686 .63786 L .552 0 0 r
F
.39645 .64115 m .39447 .63996 L .38686 .63786 L .535 0 0 r
F
.41405 .63583 m .40519 .63262 L .40715 .63355 L .389 0 0 r
F
.4158 .63663 m .41405 .63583 L .40715 .63355 L .36 0 0 r
F
.60076 .58663 m .59816 .59007 L .59647 .59205 L .57 .201 0 r
F
.60076 .58663 m .60252 .58456 L .59816 .59007 L F
.74008 .81933 m .73028 .82444 L .72535 .82854 L 0 0 0 r
F
.74008 .81933 m .74534 .81502 L .73028 .82444 L F
.59717 .58368 m .59478 .58715 L .59313 .58907 L .592 .205 0 r
F
.59717 .58368 m .59887 .58167 L .59478 .58715 L F
.43482 .65138 m .42533 .65024 L .42698 .65093 L .387 0 0 r
F
.43619 .65194 m .43482 .65138 L .42698 .65093 L .364 0 0 r
F
.32462 .64053 m .31485 .63212 L .31644 .63539 L .959 .106 0 r
F
.32626 .6436 m .32462 .64053 L .31644 .63539 L .962 .105 0 r
F
.39947 .6296 m .39084 .62549 L .39288 .62667 L .437 0 0 r
F
.40136 .63065 m .39947 .6296 L .39288 .62667 L .41 0 0 r
F
.46967 .64501 m .46213 .64495 L .46251 .64508 L .084 0 0 r
F
.43678 .64224 m .428 .64041 L .42958 .64095 L .297 0 0 r
F
.4381 .64266 m .43678 .64224 L .42958 .64095 L .264 0 0 r
F
.62873 .42433 m .63078 .42954 L .63164 .43209 L .689 .089 0 r
F
.62873 .42433 m .62786 .42182 L .63078 .42954 L F
.49918 .64682 m .49325 .64814 L .49226 .64836 L .173 .169 0 r
F
.49918 .64682 m .50049 .64658 L .49325 .64814 L F
.4237 .64951 m .41401 .64778 L .41589 .64864 L .446 0 0 r
F
.42533 .65024 m .4237 .64951 L .41589 .64864 L .426 0 0 r
F
.62753 .42476 m .62893 .43013 L .62964 .43269 L 0 0 0 r
F
.62753 .42476 m .62681 .42221 L .62893 .43013 L F
.42644 .63982 m .41758 .63738 L .41938 .63809 L .34 0 0 r
F
.428 .64041 m .42644 .63982 L .41938 .63809 L .309 0 0 r
F
.89347 .33723 m .89377 .35277 L .89615 .35947 L 0 0 0 r
F
.89347 .33723 m .89105 .33054 L .89377 .35277 L F
.89154 .33788 m .8908 .35366 L .89286 .36041 L F
.89154 .33788 m .88937 .33114 L .8908 .35366 L F
.56947 .7592 m .56551 .77516 L .5619 .77531 L 1 1 0 r
F
.56947 .7592 m .57361 .75956 L .56551 .77516 L F
.64909 .48877 m .65633 .49472 L .65559 .49767 L 1 .795 0 r
F
.64909 .48877 m .6496 .48588 L .65633 .49472 L F
.35083 .61198 m .34213 .60571 L .34411 .60775 L .662 .032 0 r
F
.35273 .61388 m .35083 .61198 L .34411 .60775 L .645 .027 0 r
F
.74684 .60312 m .74379 .61059 L .74164 .61492 L .666 .19 0 r
F
.74684 .60312 m .74901 .59864 L .74379 .61059 L F
.35985 .60215 m .35267 .59551 L .35449 .59739 L .563 .013 0 r
F
.36162 .6039 m .35985 .60215 L .35449 .59739 L .541 .007 0 r
F
.63837 .48828 m .63851 .49336 L .63832 .49606 L .749 .155 0 r
F
.63837 .48828 m .63855 .48555 L .63851 .49336 L F
.63289 .48803 m .63389 .493 L .63365 .49563 L .826 .171 0 r
F
.63289 .48803 m .63312 .48538 L .63389 .493 L F
.65455 .71146 m .65052 .71847 L .6467 .72074 L .644 .426 0 r
F
.65455 .71146 m .65866 .70916 L .65052 .71847 L F
.51152 .6646 m .50581 .66829 L .5043 .66836 L .578 .599 0 r
F
.51152 .6646 m .51337 .66451 L .50581 .66829 L F
.8107 .76819 m .80089 .77437 L .79657 .77973 L 0 0 0 r
F
.8107 .76819 m .81528 .7626 L .80089 .77437 L F
.80103 .75999 m .79253 .76691 L .78827 .7721 L F
.80103 .75999 m .8055 .75457 L .79253 .76691 L F
.50721 .64479 m .50179 .64628 L .50049 .64658 L .219 .177 0 r
F
.50721 .64479 m .5088 .64446 L .50179 .64628 L F
.74308 .38831 m .75299 .39537 L .75493 .39973 L .788 .081 0 r
F
.74308 .38831 m .74065 .38432 L .75299 .39537 L F
.23296 .85739 m .20968 .84568 L .21506 .84984 L .617 .013 0 r
F
.23799 .86125 m .23296 .85739 L .21506 .84984 L .595 .007 0 r
F
.23693 .85111 m .21414 .83947 L .21938 .84363 L .626 .016 0 r
F
.24184 .85497 m .23693 .85111 L .21938 .84363 L .605 .01 0 r
F
.53318 .65602 m .52859 .65952 L .5265 .65994 L .549 .475 0 r
F
.53318 .65602 m .53553 .65554 L .52859 .65952 L F
.24638 .83618 m .22341 .82653 L .22844 .83057 L .674 .03 0 r
F
.25106 .83994 m .24638 .83618 L .22844 .83057 L .658 .025 0 r
F
.63773 .55456 m .63862 .56038 L .63729 .56303 L .88 .337 0 r
F
.63773 .55456 m .63897 .55183 L .63862 .56038 L F
.69925 .67369 m .69503 .67996 L .69178 .6833 L .599 .212 0 r
F
.69925 .67369 m .70268 .67023 L .69503 .67996 L F
.52702 .63851 m .52247 .64035 L .52067 .64094 L .289 .187 0 r
F
.52702 .63851 m .52905 .63786 L .52247 .64035 L F
.5865 .62565 m .58373 .62973 L .58145 .63131 L .619 .226 0 r
F
.5865 .62565 m .58888 .62395 L .58373 .62973 L F
.69361 .40511 m .69602 .40027 L .68347 .41641 L 0 0 0 r
F
.6241 .5485 m .62265 .55275 L .62151 .55518 L .691 .193 0 r
F
.6241 .5485 m .62528 .546 L .62265 .55275 L F
.61958 .54648 m .61847 .55075 L .61735 .55311 L .724 .199 0 r
F
.61958 .54648 m .62071 .54406 L .61847 .55075 L F
.57536 .61159 m .57216 .61435 L .57017 .61586 L .467 .201 0 r
F
.57536 .61159 m .57745 .61 L .57216 .61435 L F
.57258 .60809 m .56952 .61085 L .56758 .61231 L .48 .203 0 r
F
.57258 .60809 m .57462 .60654 L .56952 .61085 L F
.91614 .50844 m .91112 .52141 L .91074 .52856 L 0 0 0 r
F
.91614 .50844 m .91653 .50114 L .91112 .52141 L F
.89534 .50714 m .89896 .52028 L .89823 .52719 L .86 .179 0 r
F
.89534 .50714 m .89612 .5002 L .89896 .52028 L F
.62955 .42687 m .63164 .43209 L .63246 .43466 L .706 .095 0 r
F
.62955 .42687 m .62873 .42433 L .63164 .43209 L F
.62821 .42732 m .62964 .43269 L .6303 .43527 L .686 .099 0 r
F
.62821 .42732 m .62753 .42476 L .62964 .43269 L F
.61202 .59973 m .6105 .60457 L .60852 .60669 L .732 .228 0 r
F
.61202 .59973 m .61401 .5975 L .6105 .60457 L F
.35076 .67126 m .33872 .6657 L .34063 .66899 L 1 .122 0 r
F
.35267 .67425 m .35076 .67126 L .34063 .66899 L 1 .132 0 r
F
.59896 .58866 m .59647 .59205 L .59473 .594 L .577 .204 0 r
F
.59896 .58866 m .60076 .58663 L .59647 .59205 L F
.7714 .49937 m .77284 .50856 L .7724 .51344 L .797 .161 0 r
F
.7714 .49937 m .77165 .49444 L .77284 .50856 L F
.59542 .58566 m .59313 .58907 L .59144 .59097 L .599 .207 0 r
F
.59542 .58566 m .59717 .58368 L .59313 .58907 L F
.37637 .6308 m .36701 .62624 L .36918 .62787 L .591 .006 0 r
F
.37841 .63229 m .37637 .6308 L .36918 .62787 L .574 .001 0 r
F
.38298 .62036 m .37492 .61522 L .37694 .61669 L .476 0 0 r
F
.3849 .6217 m .38298 .62036 L .37694 .61669 L .45 0 0 r
F
.64864 .49167 m .65559 .49767 L .65487 .5006 L 1 .756 0 r
F
.64864 .49167 m .64909 .48877 L .65559 .49767 L F
.40434 .9206 m .3816 .91717 L .38507 .91873 L .387 0 0 r
F
.40703 .92194 m .40434 .9206 L .38507 .91873 L .358 0 0 r
F
.42637 .92315 m .40434 .9206 L .40703 .92194 L .353 0 0 r
F
.40539 .91373 m .38297 .91053 L .38638 .91211 L .393 0 0 r
F
.40804 .91507 m .40539 .91373 L .38638 .91211 L .364 0 0 r
F
.4271 .91599 m .40539 .91373 L .40804 .91507 L .353 0 0 r
F
.63813 .49101 m .63832 .49606 L .63808 .49877 L .76 .16 0 r
F
.63813 .49101 m .63837 .48828 L .63832 .49606 L F
.63263 .49067 m .63365 .49563 L .63336 .49825 L .832 .173 0 r
F
.63263 .49067 m .63289 .48803 L .63365 .49563 L F
.40973 .88526 m .38808 .88569 L .39121 .8876 L .466 0 0 r
F
.41213 .88701 m .40973 .88526 L .39121 .8876 L .448 0 0 r
F
.43045 .88311 m .40973 .88526 L .41213 .88701 L .401 0 0 r
F
.43824 .69831 m .4259 .70192 L .42745 .70379 L .502 .015 0 r
F
.43947 .69969 m .43824 .69831 L .42745 .70379 L .489 .015 0 r
F
.44969 .69421 m .43824 .69831 L .43947 .69969 L .329 0 0 r
F
.44523 .65252 m .43619 .65194 L .43757 .65245 L .307 0 0 r
F
.4463 .65291 m .44523 .65252 L .43757 .65245 L .28 0 0 r
F
.45392 .6527 m .44523 .65252 L .4463 .65291 L .234 0 0 r
F
.44654 .64391 m .4381 .64266 L .43943 .64304 L .232 0 0 r
F
.44758 .64418 m .44654 .64391 L .43943 .64304 L .198 0 0 r
F
.65324 .89179 m .64113 .89435 L .63608 .89704 L 0 0 0 r
F
.65324 .89179 m .65885 .88893 L .64113 .89435 L F
.65087 .88643 m .63899 .88914 L .634 .89177 L F
.64613 .87571 m .6349 .87917 L .62998 .8816 L F
.64613 .87571 m .6516 .87313 L .6349 .87917 L F
.58884 .7461 m .58562 .75899 L .58169 .75944 L 1 1 0 r
F
.58884 .7461 m .59325 .74598 L .58562 .75899 L F
.54644 .65018 m .54244 .65367 L .54016 .65436 L .545 .377 0 r
F
.54644 .65018 m .54893 .6494 L .54244 .65367 L F
.53908 .63354 m .53502 .63558 L .53305 .63639 L .336 .193 0 r
F
.53908 .63354 m .54125 .63266 L .53502 .63558 L F
.45056 .69514 m .44969 .69421 L .43947 .69969 L .312 0 0 r
F
.43209 .88472 m .43045 .88311 L .41213 .88701 L .379 0 0 r
F
.42894 .91712 m .4271 .91599 L .40804 .91507 L .323 0 0 r
F
.42824 .92428 m .42637 .92315 L .40703 .92194 L F
.36162 .6039 m .35449 .59739 L .35634 .59924 L .541 .007 0 r
F
.36342 .60562 m .36162 .6039 L .35634 .59924 L .517 .001 0 r
F
.35273 .61388 m .34411 .60775 L .34613 .60976 L .645 .027 0 r
F
.35467 .61575 m .35273 .61388 L .34613 .60976 L .628 .022 0 r
F
.32626 .6436 m .31644 .63539 L .31807 .63869 L .962 .105 0 r
F
.32794 .64669 m .32626 .6436 L .31807 .63869 L .968 .105 0 r
F
.40136 .63065 m .39288 .62667 L .39494 .62781 L .41 0 0 r
F
.40326 .63166 m .40136 .63065 L .39494 .62781 L .382 0 0 r
F
.39645 .64115 m .38686 .63786 L .38904 .63916 L .535 0 0 r
F
.39845 .64231 m .39645 .64115 L .38904 .63916 L .517 0 0 r
F
.19061 .79592 m .16897 .78269 L .17362 .7876 L .729 .05 0 r
F
.19503 .80053 m .19061 .79592 L .17362 .7876 L .714 .045 0 r
F
.18011 .80771 m .15895 .79269 L .16372 .79781 L .697 .043 0 r
F
.18468 .81251 m .18011 .80771 L .16372 .79781 L .679 .037 0 r
F
.37388 .68947 m .36061 .68666 L .36266 .68993 L 1 .148 0 r
F
.37588 .69234 m .37388 .68947 L .36266 .68993 L 1 .162 0 r
F
.17467 .81382 m .15292 .79872 L .15785 .80386 L .69 .04 0 r
F
.17938 .81865 m .17467 .81382 L .15785 .80386 L .671 .034 0 r
F
.6184 .54888 m .61735 .55311 L .61618 .55545 L .73 .202 0 r
F
.6184 .54888 m .61958 .54648 L .61735 .55311 L F
.62288 .55097 m .62151 .55518 L .62031 .55758 L .699 .197 0 r
F
.62288 .55097 m .6241 .5485 L .62151 .55518 L F
.4158 .63663 m .40715 .63355 L .40912 .63444 L .36 0 0 r
F
.41758 .63738 m .4158 .63663 L .40912 .63444 L .331 0 0 r
F
.41215 .64687 m .40254 .64452 L .40461 .64557 L .484 0 0 r
F
.41401 .64778 m .41215 .64687 L .40461 .64557 L .466 0 0 r
F
.63644 .55727 m .63729 .56303 L .63591 .56566 L .878 .351 0 r
F
.63644 .55727 m .63773 .55456 L .63729 .56303 L F
.62882 .4299 m .6303 .43527 L .63091 .43786 L .705 .105 0 r
F
.62882 .4299 m .62821 .42732 L .6303 .43527 L F
.63032 .42942 m .63246 .43466 L .63323 .43724 L .722 .1 0 r
F
.63032 .42942 m .62955 .42687 L .63246 .43466 L F
.39366 .69873 m .37994 .69829 L .382 .7014 L .99 .099 0 r
F
.3956 .70137 m .39366 .69873 L .382 .7014 L .989 .113 0 r
F
.29379 .86095 m .27054 .85412 L .2756 .85745 L .624 .015 0 r
F
.29839 .86402 m .29379 .86095 L .2756 .85745 L .607 .01 0 r
F
.69109 .40986 m .69361 .40511 L .68137 .42071 L 0 0 0 r
F
.28565 .87838 m .26233 .8694 L .26765 .87275 L .558 0 0 r
F
.29053 .88143 m .28565 .87838 L .26765 .87275 L .535 0 0 r
F
.28269 .88471 m .25897 .87565 L .26441 .87898 L .546 0 0 r
F
.28768 .88775 m .28269 .88471 L .26441 .87898 L .522 0 0 r
F
.74458 .60756 m .74164 .61492 L .73942 .61921 L .672 .194 0 r
F
.74458 .60756 m .74684 .60312 L .74164 .61492 L F
.51518 .64241 m .51038 .64407 L .5088 .64446 L .275 .186 0 r
F
.51518 .64241 m .51703 .64197 L .51038 .64407 L F
.63233 .49331 m .63336 .49825 L .63304 .50087 L .837 .176 0 r
F
.63233 .49331 m .63263 .49067 L .63336 .49825 L F
.63784 .49374 m .63808 .49877 L .63779 .50147 L .771 .164 0 r
F
.63784 .49374 m .63813 .49101 L .63808 .49877 L F
.59363 .58761 m .59144 .59097 L .58971 .59284 L .604 .21 0 r
F
.59363 .58761 m .59542 .58566 L .59144 .59097 L F
.52013 .66076 m .51521 .66435 L .51337 .66451 L .581 .627 0 r
F
.52013 .66076 m .52227 .66056 L .51521 .66435 L F
.57051 .60961 m .56758 .61231 L .56562 .61373 L .488 .206 0 r
F
.57051 .60961 m .57258 .60809 L .56758 .61231 L F
.64822 .49456 m .65487 .5006 L .65416 .50352 L 1 .723 0 r
F
.64822 .49456 m .64864 .49167 L .65487 .5006 L F
.59711 .59066 m .59473 .594 L .59296 .59592 L .584 .207 0 r
F
.59711 .59066 m .59896 .58866 L .59473 .594 L F
.57322 .61314 m .57017 .61586 L .56815 .61732 L .476 .204 0 r
F
.57322 .61314 m .57536 .61159 L .57017 .61586 L F
.74538 .39238 m .75493 .39973 L .75676 .40415 L .798 .086 0 r
F
.74538 .39238 m .74308 .38831 L .75493 .39973 L F
.428 .64041 m .41938 .63809 L .4212 .63876 L .309 0 0 r
F
.42958 .64095 m .428 .64041 L .4212 .63876 L .278 0 0 r
F
.42533 .65024 m .41589 .64864 L .41779 .64948 L .426 0 0 r
F
.42698 .65093 m .42533 .65024 L .41779 .64948 L .406 0 0 r
F
.60998 .60193 m .60852 .60669 L .60649 .60877 L .733 .245 0 r
F
.60998 .60193 m .61202 .59973 L .60852 .60669 L F
.33096 .87455 m .3078 .86989 L .31261 .87268 L .585 .006 0 r
F
.33522 .87711 m .33096 .87455 L .31261 .87268 L .568 .001 0 r
F
.4381 .64266 m .42958 .64095 L .43118 .64145 L .264 0 0 r
F
.43943 .64304 m .4381 .64266 L .43118 .64145 L .231 0 0 r
F
.58409 .6273 m .58145 .63131 L .57913 .63284 L .623 .227 0 r
F
.58409 .6273 m .5865 .62565 L .58145 .63131 L F
.86183 .66207 m .85622 .6719 L .85335 .67817 L 0 0 0 r
F
.86183 .66207 m .86474 .65559 L .85622 .6719 L F
.87511 .66825 m .86699 .67725 L .86408 .68372 L F
.87511 .66825 m .87814 .66155 L .86699 .67725 L F
.32394 .89423 m .30052 .88721 L .30562 .88993 L .507 0 0 r
F
.3285 .89667 m .32394 .89423 L .30562 .88993 L .482 0 0 r
F
.43619 .65194 m .42698 .65093 L .42864 .65158 L .364 0 0 r
F
.43757 .65245 m .43619 .65194 L .42864 .65158 L .342 0 0 r
F
.32166 .90061 m .29788 .89349 L .30308 .89619 L .495 0 0 r
F
.32631 .90303 m .32166 .90061 L .30308 .89619 L .469 0 0 r
F
.41111 .70254 m .39756 .70409 L .39954 .70692 L .866 .067 0 r
F
.4129 .70485 m .41111 .70254 L .39954 .70692 L .862 .068 0 r
F
.49786 .64701 m .49226 .64836 L .49126 .64853 L .213 .177 0 r
F
.49786 .64701 m .49918 .64682 L .49226 .64836 L F
.89357 .34467 m .89286 .36041 L .89476 .36719 L 0 0 0 r
F
.89357 .34467 m .89154 .33788 L .89286 .36041 L F
.89577 .34397 m .89615 .35947 L .8984 .36622 L F
.89577 .34397 m .89347 .33723 L .89615 .35947 L F
.46971 .64508 m .46251 .64508 L .46289 .64517 L .045 0 0 r
F
.4259 .70192 m .4129 .70485 L .41471 .70725 L .705 .046 0 r
F
.42745 .70379 m .4259 .70192 L .41471 .70725 L .698 .047 0 r
F
.3849 .6217 m .37694 .61669 L .37901 .61812 L .45 0 0 r
F
.38685 .623 m .3849 .6217 L .37901 .61812 L .425 0 0 r
F
.77105 .50429 m .7724 .51344 L .77187 .51832 L .8 .164 0 r
F
.77105 .50429 m .7714 .49937 L .7724 .51344 L F
.55074 .77407 m .54584 .79302 L .54265 .79301 L 1 1 0 r
F
.55074 .77407 m .55452 .77479 L .54584 .79302 L F
.37841 .63229 m .36918 .62787 L .37138 .62947 L .574 .001 0 r
F
.38048 .63373 m .37841 .63229 L .37138 .62947 L .556 0 0 r
F
.50124 .6683 m .49521 .6722 L .49404 .67215 L .61 .664 0 r
F
.50124 .6683 m .50277 .66837 L .49521 .6722 L F
.61717 .55127 m .61618 .55545 L .61497 .55776 L .735 .205 0 r
F
.61717 .55127 m .6184 .54888 L .61618 .55545 L F
.62161 .55342 m .62031 .55758 L .61907 .55997 L .706 .2 0 r
F
.62161 .55342 m .62288 .55097 L .62031 .55758 L F
.62939 .4325 m .63091 .43786 L .63146 .44046 L .722 .111 0 r
F
.62939 .4325 m .62882 .4299 L .63091 .43786 L F
.69573 .67707 m .69178 .6833 L .68844 .68657 L .609 .216 0 r
F
.69573 .67707 m .69925 .67369 L .69178 .6833 L F
.52497 .63912 m .52067 .64094 L .51886 .64148 L .314 .192 0 r
F
.52497 .63912 m .52702 .63851 L .52067 .64094 L F
.36342 .60562 m .35634 .59924 L .35823 .60105 L .517 .001 0 r
F
.36525 .60731 m .36342 .60562 L .35823 .60105 L .494 0 0 r
F
.65035 .71362 m .6467 .72074 L .6428 .72289 L .657 .528 0 r
F
.65035 .71362 m .65455 .71146 L .6467 .72074 L F
.63105 .43199 m .63323 .43724 L .63395 .43984 L .738 .106 0 r
F
.63105 .43199 m .63032 .42942 L .63323 .43724 L F
.6351 .55997 m .63591 .56566 L .6345 .56827 L .876 .366 0 r
F
.6351 .55997 m .63644 .55727 L .63591 .56566 L F
.5056 .64507 m .50049 .64658 L .49918 .64682 L .255 .184 0 r
F
.5056 .64507 m .50721 .64479 L .50049 .64658 L F
.35467 .61575 m .34613 .60976 L .34819 .61174 L .628 .022 0 r
F
.35664 .61758 m .35467 .61575 L .34819 .61174 L .61 .017 0 r
F
.53081 .65644 m .5265 .65994 L .52439 .66028 L .568 .563 0 r
F
.53081 .65644 m .53318 .65602 L .5265 .65994 L F
.63199 .49594 m .63304 .50087 L .63267 .50348 L .842 .179 0 r
F
.63199 .49594 m .63233 .49331 L .63304 .50087 L F
.63751 .49647 m .63779 .50147 L .63745 .50416 L .781 .168 0 r
F
.63751 .49647 m .63784 .49374 L .63779 .50147 L F
.35267 .67425 m .34063 .66899 L .34257 .67233 L 1 .132 0 r
F
.35462 .67728 m .35267 .67425 L .34257 .67233 L 1 .145 0 r
F
.50966 .66462 m .5043 .66836 L .50277 .66837 L .607 .704 0 r
F
.50966 .66462 m .51152 .6646 L .5043 .66836 L F
.58424 .8981 m .5715 .90081 L .56755 .90227 L 0 0 0 r
F
.58424 .8981 m .5889 .89657 L .5715 .90081 L F
.58719 .90901 m .57389 .91085 L .56988 .91251 L F
.58719 .90901 m .59191 .90725 L .57389 .91085 L F
.64782 .49746 m .65416 .50352 L .65346 .50644 L 1 .695 0 r
F
.64782 .49746 m .64822 .49456 L .65416 .50352 L F
.8946 .51408 m .89823 .52719 L .89741 .5341 L .859 .179 0 r
F
.8946 .51408 m .89534 .50714 L .89823 .52719 L F
.58865 .91441 m .57512 .916 L .57106 .91768 L .023 0 0 r
F
.58865 .91441 m .59342 .9126 L .57512 .916 L F
.68848 .41451 m .69109 .40986 L .67925 .42491 L 0 0 0 r
F
.91561 .51574 m .91074 .52856 L .91022 .53571 L F
.91561 .51574 m .91614 .50844 L .91074 .52856 L F
.32794 .64669 m .31807 .63869 L .31973 .64202 L .968 .105 0 r
F
.32965 .64979 m .32794 .64669 L .31973 .64202 L .975 .104 0 r
F
.53689 .63438 m .53305 .63639 L .53106 .63715 L .355 .197 0 r
F
.53689 .63438 m .53908 .63354 L .53305 .63639 L F
.59181 .58953 m .58971 .59284 L .58795 .59467 L .61 .212 0 r
F
.59181 .58953 m .59363 .58761 L .58971 .59284 L F
.59523 .59264 m .59296 .59592 L .59115 .59781 L .59 .209 0 r
F
.59523 .59264 m .59711 .59066 L .59296 .59592 L F
.40326 .63166 m .39494 .62781 L .39702 .62892 L .382 0 0 r
F
.40519 .63262 m .40326 .63166 L .39702 .62892 L .355 0 0 r
F
.79646 .76533 m .78827 .7721 L .78391 .77721 L 0 0 0 r
F
.79646 .76533 m .80103 .75999 L .78827 .7721 L F
.73473 .82355 m .72535 .82854 L .72034 .83254 L F
.73473 .82355 m .74008 .81933 L .72535 .82854 L F
.36222 .88238 m .33954 .87959 L .34392 .88197 L .546 0 0 r
F
.36598 .88456 m .36222 .88238 L .34392 .88197 L .529 0 0 r
F
.80601 .7737 m .79657 .77973 L .79214 .78502 L 0 0 0 r
F
.80601 .7737 m .8107 .76819 L .79657 .77973 L F
.54392 .65089 m .54016 .65436 L .53785 .65498 L .559 .452 0 r
F
.54392 .65089 m .54644 .65018 L .54016 .65436 L F
.74208 .83313 m .73184 .83743 L .72675 .84162 L 0 0 0 r
F
.74208 .83313 m .74754 .82873 L .73184 .83743 L F
.50361 .92865 m .48608 .92856 L .48527 .92948 L .184 0 0 r
F
.50361 .92865 m .50532 .92771 L .48608 .92856 L F
.39845 .64231 m .38904 .63916 L .39125 .64043 L .517 0 0 r
F
.40048 .64343 m .39845 .64231 L .39125 .64043 L .5 0 0 r
F
.56841 .61108 m .57051 .60961 L .56562 .61373 L .495 .208 0 r
F
.35623 .90442 m .33312 .899 L .33781 .90121 L .459 0 0 r
F
.36029 .90637 m .35623 .90442 L .33781 .90121 L .432 0 0 r
F
.35447 .9109 m .33103 .90534 L .3358 .90752 L .447 0 0 r
F
.3586 .91283 m .35447 .9109 L .3358 .90752 L .419 0 0 r
F
.60789 .6041 m .60649 .60877 L .60443 .61081 L .732 .271 0 r
F
.60789 .6041 m .60998 .60193 L .60649 .60877 L F
.38808 .88569 m .36598 .88456 L .36979 .88665 L .507 0 0 r
F
.39121 .8876 m .38808 .88569 L .36979 .88665 L .49 0 0 r
F
.57106 .61465 m .56815 .61732 L .56611 .61874 L .485 .207 0 r
F
.57106 .61465 m .57322 .61314 L .56815 .61732 L F
.6159 .55363 m .61497 .55776 L .61372 .56006 L .74 .207 0 r
F
.6159 .55363 m .61717 .55127 L .61497 .55776 L F
.41758 .63738 m .40912 .63444 L .41112 .63528 L .331 0 0 r
F
.41938 .63809 m .41758 .63738 L .41112 .63528 L .301 0 0 r
F
.62989 .43511 m .63146 .44046 L .63195 .44307 L .74 .117 0 r
F
.62989 .43511 m .62939 .4325 L .63146 .44046 L F
.38297 .91053 m .36029 .90637 L .3644 .9082 L .419 0 0 r
F
.38638 .91211 m .38297 .91053 L .3644 .9082 L .392 0 0 r
F
.63172 .43458 m .63395 .43984 L .63462 .44245 L .754 .111 0 r
F
.63172 .43458 m .63105 .43199 L .63395 .43984 L F
.3816 .91717 m .3586 .91283 L .36279 .91463 L .41 0 0 r
F
.38507 .91873 m .3816 .91717 L .36279 .91463 L .38 0 0 r
F
.6203 .55586 m .61907 .55997 L .61779 .56233 L .712 .203 0 r
F
.6203 .55586 m .62161 .55342 L .61907 .55997 L F
.52408 .81232 m .51487 .83081 L .51282 .83145 L 1 1 0 r
F
.52408 .81232 m .52678 .81235 L .51487 .83081 L F
.44758 .64418 m .43943 .64304 L .44077 .64338 L .198 0 0 r
F
.44862 .64441 m .44758 .64418 L .44077 .64338 L .163 0 0 r
F
.74224 .61195 m .73942 .61921 L .73711 .62346 L .678 .197 0 r
F
.74224 .61195 m .74458 .60756 L .73942 .61921 L F
.58164 .6289 m .58409 .6273 L .57913 .63284 L .626 .264 0 r
F
.41401 .64778 m .40461 .64557 L .40671 .64658 L .466 0 0 r
F
.41589 .64864 m .41401 .64778 L .40671 .64658 L .448 0 0 r
F
.63161 .49858 m .63267 .50348 L .63226 .50609 L .847 .182 0 r
F
.63161 .49858 m .63199 .49594 L .63267 .50348 L F
.74755 .39653 m .75676 .40415 L .75849 .40862 L .807 .092 0 r
F
.74755 .39653 m .74538 .39238 L .75676 .40415 L F
.4463 .65291 m .43757 .65245 L .43896 .65293 L .28 0 0 r
F
.44738 .65326 m .4463 .65291 L .43896 .65293 L .253 0 0 r
F
.63712 .4992 m .63745 .50416 L .63706 .50685 L .79 .172 0 r
F
.63712 .4992 m .63751 .49647 L .63745 .50416 L F
.56526 .75853 m .5619 .77531 L .55824 .7752 L 1 1 0 r
F
.56526 .75853 m .56947 .7592 L .5619 .77531 L F
.63371 .56264 m .6345 .56827 L .63303 .57085 L .875 .382 0 r
F
.63371 .56264 m .6351 .55997 L .6345 .56827 L F
.36525 .60731 m .35823 .60105 L .36016 .60283 L .494 0 0 r
F
.36712 .60896 m .36525 .60731 L .36016 .60283 L .47 0 0 r
F
.38685 .623 m .37901 .61812 L .3811 .61952 L .425 0 0 r
F
.38883 .62426 m .38685 .623 L .3811 .61952 L .399 0 0 r
F
.37588 .69234 m .36266 .68993 L .36473 .69328 L 1 .162 0 r
F
.37789 .69527 m .37588 .69234 L .36473 .69328 L 1 .178 0 r
F
.64741 .50035 m .65346 .50644 L .65275 .50934 L 1 .671 0 r
F
.64741 .50035 m .64782 .49746 L .65346 .50644 L F
.35664 .61758 m .34819 .61174 L .35028 .61369 L .61 .017 0 r
F
.35865 .61938 m .35664 .61758 L .35028 .61369 L .593 .012 0 r
F
.38048 .63373 m .37138 .62947 L .37362 .63103 L .556 0 0 r
F
.38258 .63514 m .38048 .63373 L .37362 .63103 L .539 0 0 r
F
.77059 .50922 m .77187 .51832 L .77126 .52319 L .804 .168 0 r
F
.77059 .50922 m .77105 .50429 L .77187 .51832 L F
.53946 .90925 m .52483 .91112 L .52233 .9121 L 0 0 0 r
F
.53946 .90925 m .54277 .90825 L .52483 .91112 L F
.51331 .64279 m .5088 .64446 L .50721 .64479 L .305 .191 0 r
F
.51331 .64279 m .51518 .64241 L .5088 .64446 L F
.42958 .64095 m .4212 .63876 L .42303 .63938 L .278 0 0 r
F
.43118 .64145 m .42958 .64095 L .42303 .63938 L .247 0 0 r
F
.68578 .41907 m .68848 .41451 L .67713 .42901 L 0 0 0 r
F
.53613 .79214 m .52944 .81214 L .52678 .81235 L 1 1 0 r
F
.53613 .79214 m .53942 .79272 L .52944 .81214 L F
.54107 .91939 m .52598 .92047 L .52345 .92158 L .08 0 0 r
F
.54107 .91939 m .54443 .91821 L .52598 .92047 L F
.54186 .9244 m .52657 .92519 L .52401 .92632 L .103 0 0 r
F
.54186 .9244 m .54526 .9232 L .52657 .92519 L F
.25106 .83994 m .22844 .83057 L .23356 .83453 L .658 .025 0 r
F
.25581 .84362 m .25106 .83994 L .23356 .83453 L .642 .02 0 r
F
.58994 .59142 m .58795 .59467 L .58615 .59647 L .615 .215 0 r
F
.58994 .59142 m .59181 .58953 L .58795 .59467 L F
.59331 .59457 m .59115 .59781 L .58931 .59966 L .596 .212 0 r
F
.59331 .59457 m .59523 .59264 L .59115 .59781 L F
.42698 .65093 m .41779 .64948 L .41971 .65027 L .406 0 0 r
F
.42864 .65158 m .42698 .65093 L .41971 .65027 L .387 0 0 r
F
.24184 .85497 m .21938 .84363 L .22471 .8477 L .605 .01 0 r
F
.24684 .85873 m .24184 .85497 L .22471 .8477 L .584 .004 0 r
F
.43947 .69969 m .42745 .70379 L .42901 .70573 L .489 .015 0 r
F
.44072 .7011 m .43947 .69969 L .42901 .70573 L .477 .017 0 r
F
.45056 .69514 m .43947 .69969 L .44072 .7011 L .312 0 0 r
F
.43943 .64304 m .43118 .64145 L .43279 .6419 L .231 0 0 r
F
.44077 .64338 m .43943 .64304 L .43279 .6419 L .198 0 0 r
F
.23799 .86125 m .21506 .84984 L .22054 .85391 L .595 .007 0 r
F
.24311 .865 m .23799 .86125 L .22054 .85391 L .573 .001 0 r
F
.63034 .43773 m .63195 .44307 L .6324 .44569 L .757 .123 0 r
F
.63034 .43773 m .62989 .43511 L .63195 .44307 L F
.3956 .70137 m .382 .7014 L .38408 .70462 L .989 .113 0 r
F
.39756 .70409 m .3956 .70137 L .38408 .70462 L .988 .128 0 r
F
.61459 .55598 m .61372 .56006 L .61242 .56233 L .744 .21 0 r
F
.61459 .55598 m .6159 .55363 L .61372 .56006 L F
.63234 .43719 m .63462 .44245 L .63524 .44507 L .769 .116 0 r
F
.63234 .43719 m .63172 .43458 L .63462 .44245 L F
.58435 .74594 m .58169 .75944 L .57769 .75963 L 1 1 0 r
F
.58435 .74594 m .58884 .7461 L .58169 .75944 L F
.51798 .66089 m .51337 .66451 L .51152 .6646 L .605 .719 0 r
F
.51798 .66089 m .52013 .66076 L .51337 .66451 L F
.63119 .50121 m .63226 .50609 L .63181 .50869 L .851 .184 0 r
F
.63119 .50121 m .63161 .49858 L .63226 .50609 L F
.61894 .55827 m .61779 .56233 L .61646 .56467 L .718 .206 0 r
F
.61894 .55827 m .6203 .55586 L .61779 .56233 L F
.43757 .65245 m .42864 .65158 L .43032 .6522 L .342 0 0 r
F
.43896 .65293 m .43757 .65245 L .43032 .6522 L .319 0 0 r
F
.45143 .69608 m .45056 .69514 L .44072 .7011 L .296 0 0 r
F
.63668 .50192 m .63706 .50685 L .63662 .50954 L .799 .176 0 r
F
.63668 .50192 m .63712 .4992 L .63706 .50685 L F
.85879 .66851 m .85335 .67817 L .85035 .68438 L 0 0 0 r
F
.85879 .66851 m .86183 .66207 L .85335 .67817 L F
.52289 .63967 m .51886 .64148 L .51703 .64197 L .339 .196 0 r
F
.52289 .63967 m .52497 .63912 L .51886 .64148 L F
.60576 .60622 m .60443 .61081 L .60233 .61281 L .732 .299 0 r
F
.60576 .60622 m .60789 .6041 L .60443 .61081 L F
.69212 .68037 m .68844 .68657 L .68501 .68974 L .62 .219 0 r
F
.69212 .68037 m .69573 .67707 L .68844 .68657 L F
.19503 .80053 m .17362 .7876 L .17838 .79244 L .714 .045 0 r
F
.19954 .80506 m .19503 .80053 L .17838 .79244 L .699 .04 0 r
F
.32965 .64979 m .31973 .64202 L .32143 .64538 L .975 .104 0 r
F
.3314 .65292 m .32965 .64979 L .32143 .64538 L .984 .104 0 r
F
.60964 .89003 m .59805 .8931 L .5935 .89491 L 0 0 0 r
F
.60964 .89003 m .61482 .88812 L .59805 .8931 L F
.87194 .67489 m .86408 .68372 L .86105 .69014 L F
.87194 .67489 m .87511 .66825 L .86408 .68372 L F
.56886 .61612 m .57106 .61465 L .56611 .61874 L .494 .209 0 r
F
.61338 .90111 m .60119 .90334 L .59658 .90536 L 0 0 0 r
F
.61338 .90111 m .61863 .89896 L .60119 .90334 L F
.89545 .35152 m .89476 .36719 L .89651 .37403 L F
.89545 .35152 m .89357 .34467 L .89476 .36719 L F
.18468 .81251 m .16372 .79781 L .1686 .80284 L .679 .037 0 r
F
.18935 .81723 m .18468 .81251 L .1686 .80284 L .66 .031 0 r
F
.89794 .35077 m .8984 .36622 L .90053 .37302 L 0 0 0 r
F
.89794 .35077 m .89577 .34397 L .8984 .36622 L F
.61523 .9066 m .60281 .90861 L .59814 .91067 L F
.61523 .9066 m .62054 .90439 L .60281 .90861 L F
.40519 .63262 m .39702 .62892 L .39914 .62998 L .355 0 0 r
F
.40715 .63355 m .40519 .63262 L .39914 .62998 L .327 0 0 r
F
.63227 .56529 m .63303 .57085 L .63153 .57341 L .876 .399 0 r
F
.63227 .56529 m .63371 .56264 L .63303 .57085 L F
.53468 .63516 m .53106 .63715 L .52905 .63786 L .374 .2 0 r
F
.53468 .63516 m .53689 .63438 L .53106 .63715 L F
.35462 .67728 m .34257 .67233 L .34454 .67574 L 1 .145 0 r
F
.35659 .68035 m .35462 .67728 L .34454 .67574 L 1 .16 0 r
F
.49653 .64714 m .49126 .64853 L .49025 .64864 L .254 .184 0 r
F
.49653 .64714 m .49786 .64701 L .49126 .64853 L F
.17938 .81865 m .15785 .80386 L .1629 .80891 L .671 .034 0 r
F
.18419 .82338 m .17938 .81865 L .1629 .80891 L .652 .028 0 r
F
.64699 .50325 m .65275 .50934 L .65203 .51224 L 1 .653 0 r
F
.64699 .50325 m .64741 .50035 L .65275 .50934 L F
.55951 .90477 m .54605 .90711 L .54277 .90825 L 0 0 0 r
F
.55951 .90477 m .56355 .90359 L .54605 .90711 L F
.64607 .71564 m .6428 .72289 L .63881 .72488 L .667 .627 0 r
F
.64607 .71564 m .65035 .71362 L .6428 .72289 L F
.52843 .65678 m .52439 .66028 L .52227 .66056 L .586 .647 0 r
F
.52843 .65678 m .53081 .65644 L .52439 .66028 L F
.56172 .91543 m .54776 .9169 L .54443 .91821 L .032 0 0 r
F
.56172 .91543 m .56583 .91403 L .54776 .9169 L F
.36712 .60896 m .36016 .60283 L .36212 .60458 L .47 0 0 r
F
.36902 .61058 m .36712 .60896 L .36212 .60458 L 0 .018 0 r
F
.50398 .64529 m .49918 .64682 L .49786 .64701 L .291 .189 0 r
F
.50398 .64529 m .5056 .64507 L .49918 .64682 L F
.40048 .64343 m .39125 .64043 L .39348 .64167 L .5 0 0 r
F
.40254 .64452 m .40048 .64343 L .39348 .64167 L .483 0 0 r
F
.56281 .92067 m .54863 .92187 L .54526 .9232 L .058 0 0 r
F
.56281 .92067 m .56696 .91924 L .54863 .92187 L F
.683 .42354 m .68578 .41907 L .67499 .43302 L 0 0 0 r
F
.89385 .52103 m .89741 .5341 L .89649 .54099 L .857 .178 0 r
F
.89385 .52103 m .8946 .51408 L .89741 .5341 L F
.54137 .65154 m .53785 .65498 L .53553 .65554 L .572 .526 0 r
F
.54137 .65154 m .54392 .65089 L .53785 .65498 L F
.7496 .40076 m .75849 .40862 L .76011 .41313 L .816 .097 0 r
F
.7496 .40076 m .74755 .39653 L .75849 .40862 L F
.4129 .70485 m .39954 .70692 L .40153 .70988 L .862 .068 0 r
F
.41471 .70725 m .4129 .70485 L .40153 .70988 L .859 .07 0 r
F
.63073 .44037 m .6324 .44569 L .63278 .44832 L .774 .13 0 r
F
.63073 .44037 m .63034 .43773 L .6324 .44569 L F
.38883 .62426 m .3811 .61952 L .38322 .62088 L .399 0 0 r
F
.39288 .62667 m .38688 .6231 L .38754 .62349 L 0 .052 0 r
F
.39084 .62549 m .38322 .62088 L .38536 .62221 L .372 0 0 r
F
.38688 .6231 m .38536 .62221 L .3861 .62264 L 0 .052 0 r
F
.38688 .6231 m .3861 .62264 L .38754 .62349 L F
.38921 .6245 m .38883 .62426 L .38322 .62088 L .372 0 0 r
F
.39084 .62549 m .39009 .62503 L .38921 .6245 L F
.39009 .62503 m .38883 .62426 L .38921 .6245 L F
.58804 .59328 m .58615 .59647 L .58432 .59824 L .619 .217 0 r
F
.58804 .59328 m .58994 .59142 L .58615 .59647 L F
.7398 .61631 m .73711 .62346 L .73471 .62767 L .684 .2 0 r
F
.7398 .61631 m .74224 .61195 L .73711 .62346 L F
.63292 .43981 m .63524 .44507 L .63581 .44771 L .784 .122 0 r
F
.63292 .43981 m .63234 .43719 L .63524 .44507 L F
.35865 .61938 m .35028 .61369 L .35241 .6156 L .593 .012 0 r
F
.36069 .62115 m .35865 .61938 L .35241 .6156 L .575 .007 0 r
F
.63073 .50384 m .63181 .50869 L .63131 .51129 L .856 .187 0 r
F
.63073 .50384 m .63119 .50121 L .63181 .50869 L F
.61323 .5583 m .61242 .56233 L .61109 .56458 L .749 .213 0 r
F
.61323 .5583 m .61459 .55598 L .61242 .56233 L F
.91494 .52305 m .91022 .53571 L .90957 .54285 L 0 0 0 r
F
.91494 .52305 m .91561 .51574 L .91022 .53571 L F
.41938 .63809 m .41112 .63528 L .41314 .63608 L .301 0 0 r
F
.4212 .63876 m .41938 .63809 L .41314 .63608 L .272 0 0 r
F
.49969 .66815 m .49404 .67215 L .49287 .67204 L .668 .771 0 r
F
.49969 .66815 m .50124 .6683 L .49404 .67215 L F
.59136 .59648 m .58931 .59966 L .58742 .60147 L .602 .214 0 r
F
.59136 .59648 m .59331 .59457 L .58931 .59966 L F
.61753 .56066 m .61646 .56467 L .61508 .56699 L .723 .209 0 r
F
.61753 .56066 m .61894 .55827 L .61646 .56467 L F
.63619 .50464 m .63662 .50954 L .63613 .51221 L .808 .18 0 r
F
.63619 .50464 m .63668 .50192 L .63662 .50954 L F
.42745 .70379 m .41471 .70725 L .41653 .70976 L .698 .047 0 r
F
.42901 .70573 m .42745 .70379 L .41653 .70976 L .692 .049 0 r
F
.50779 .66456 m .50277 .66837 L .50124 .6683 L .665 .799 0 r
F
.50779 .66456 m .50966 .66462 L .50277 .66837 L F
.38258 .63514 m .37362 .63103 L .37588 .63255 L .539 0 0 r
F
.3847 .63652 m .38258 .63514 L .37588 .63255 L .522 0 0 r
F
.41589 .64864 m .40671 .64658 L .40883 .64756 L .448 0 0 r
F
.41779 .64948 m .41589 .64864 L .40883 .64756 L .431 0 0 r
F
.77004 .51415 m .77126 .52319 L .77055 .52804 L .808 .171 0 r
F
.77004 .51415 m .77059 .50922 L .77126 .52319 L F
.64059 .87815 m .62998 .8816 L .62499 .8839 L 0 0 0 r
F
.64059 .87815 m .64613 .87571 L .62998 .8816 L F
.64655 .50615 m .65203 .51224 L .65131 .51513 L 1 .638 0 r
F
.64655 .50615 m .64699 .50325 L .65203 .51224 L F
.60359 .60831 m .60233 .61281 L .60018 .61478 L .732 .327 0 r
F
.60359 .60831 m .60576 .60622 L .60233 .61281 L F
.63078 .56792 m .63153 .57341 L .62998 .57595 L .877 .416 0 r
F
.63078 .56792 m .63227 .56529 L .63153 .57341 L F
.44862 .64441 m .44077 .64338 L .44212 .64367 L .163 0 0 r
F
.44967 .64459 m .44862 .64441 L .44212 .64367 L .128 0 0 r
F
.64526 .88911 m .634 .89177 L .62895 .89429 L 0 0 0 r
F
.64526 .88911 m .65087 .88643 L .634 .89177 L F
.52141 .92731 m .50532 .92771 L .50361 .92865 L .134 0 0 r
F
.52141 .92731 m .52401 .92632 L .50532 .92771 L F
.64756 .89454 m .63608 .89704 L .63097 .89961 L 0 0 0 r
F
.64756 .89454 m .65324 .89179 L .63608 .89704 L F
.29839 .86402 m .2756 .85745 L .28074 .86068 L .607 .01 0 r
F
.30306 .867 m .29839 .86402 L .28074 .86068 L .59 .004 0 r
F
.79177 .77059 m .78391 .77721 L .77944 .78223 L 0 0 0 r
F
.79177 .77059 m .79646 .76533 L .78391 .77721 L F
.63106 .44301 m .63278 .44832 L .63311 .45095 L .791 .136 0 r
F
.63106 .44301 m .63073 .44037 L .63278 .44832 L F
.43118 .64145 m .42303 .63938 L .42488 .63997 L .247 0 0 r
F
.43279 .6419 m .43118 .64145 L .42488 .63997 L .216 0 0 r
F
.44738 .65326 m .43896 .65293 L .44037 .65338 L .253 0 0 r
F
.44848 .65358 m .44738 .65326 L .44037 .65338 L .226 0 0 r
F
.63022 .50646 m .63131 .51129 L .63076 .51387 L .86 .19 0 r
F
.63022 .50646 m .63073 .50384 L .63131 .51129 L F
.80121 .77914 m .79214 .78502 L .7876 .79023 L 0 0 0 r
F
.80121 .77914 m .80601 .7737 L .79214 .78502 L F
.29053 .88143 m .26765 .87275 L .27306 .87599 L .535 0 0 r
F
.29549 .88438 m .29053 .88143 L .27306 .87599 L .511 0 0 r
F
.63345 .44245 m .63581 .44771 L .63634 .45036 L .798 .127 0 r
F
.63345 .44245 m .63292 .43981 L .63581 .44771 L F
.36902 .61058 m .36212 .60458 L .36412 .60629 L 0 .018 0 r
F
.37095 .61216 m .36902 .61058 L .36412 .60629 L 0 .024 0 r
F
.37789 .69527 m .36473 .69328 L .36682 .69674 L 1 .178 0 r
F
.37994 .69829 m .37789 .69527 L .36682 .69674 L 1 .196 0 r
F
.68013 .4279 m .683 .42354 L .67286 .43692 L 0 0 0 r
F
.61183 .5606 m .61109 .56458 L .6097 .56681 L .752 .215 0 r
F
.61183 .5606 m .61323 .5583 L .61109 .56458 L F
.51143 .64312 m .50721 .64479 L .5056 .64507 L .335 .196 0 r
F
.51143 .64312 m .51331 .64279 L .50721 .64479 L F
.3314 .65292 m .32143 .64538 L .32316 .64877 L .984 .104 0 r
F
.33318 .65606 m .3314 .65292 L .32316 .64877 L .994 .104 0 r
F
.28768 .88775 m .26441 .87898 L .26994 .8822 L .522 0 0 r
F
.29274 .89067 m .28768 .88775 L .26994 .8822 L .497 0 0 r
F
.63565 .50735 m .63613 .51221 L .63559 .51488 L .816 .184 0 r
F
.63565 .50735 m .63619 .50464 L .63613 .51221 L F
.58611 .5951 m .58432 .59824 L .58245 .59997 L .624 .219 0 r
F
.58611 .5951 m .58804 .59328 L .58432 .59824 L F
.61608 .56302 m .61508 .56699 L .61366 .56928 L .728 .212 0 r
F
.61608 .56302 m .61753 .56066 L .61508 .56699 L F
.40715 .63355 m .39914 .62998 L .40127 .63101 L .327 0 0 r
F
.40912 .63444 m .40715 .63355 L .40127 .63101 L .299 0 0 r
F
.42864 .65158 m .41971 .65027 L .42165 .65104 L .387 0 0 r
F
.43032 .6522 m .42864 .65158 L .42165 .65104 L .369 0 0 r
F
.58936 .59835 m .58742 .60147 L .5855 .60325 L .607 .217 0 r
F
.58936 .59835 m .59136 .59648 L .58742 .60147 L F
.44077 .64338 m .43279 .6419 L .43442 .64231 L .198 0 0 r
F
.44212 .64367 m .44077 .64338 L .43442 .64231 L .166 0 0 r
F
.5208 .64017 m .51703 .64197 L .51518 .64241 L .363 .2 0 r
F
.5208 .64017 m .52289 .63967 L .51703 .64197 L F
.53244 .63589 m .52905 .63786 L .52702 .63851 L .392 .203 0 r
F
.53244 .63589 m .53468 .63516 L .52905 .63786 L F
.68843 .68357 m .68501 .68974 L .6815 .69283 L .629 .223 0 r
F
.68843 .68357 m .69212 .68037 L .68501 .68974 L F
.36069 .62115 m .35241 .6156 L .35457 .61748 L .575 .007 0 r
F
.36276 .62288 m .36069 .62115 L .35457 .61748 L .558 .002 0 r
F
.72928 .82766 m .73473 .82355 L .72034 .83254 L 0 0 0 r
F
.54691 .77303 m .54265 .79301 L .53942 .79272 L 1 1 0 r
F
.54691 .77303 m .55074 .77407 L .54265 .79301 L F
.39288 .62667 m .39084 .62549 L .38536 .62221 L 0 .052 0 r
F
.73653 .83742 m .72675 .84162 L .72157 .8457 L 0 0 0 r
F
.73653 .83742 m .74208 .83313 L .72675 .84162 L F
.64607 .50905 m .65131 .51513 L .65056 .51801 L 1 .628 0 r
F
.64607 .50905 m .64655 .50615 L .65131 .51513 L F
.40254 .64452 m .39348 .64167 L .39574 .64287 L .483 0 0 r
F
.40461 .64557 m .40254 .64452 L .39574 .64287 L .467 0 0 r
F
.33522 .87711 m .31261 .87268 L .31748 .87539 L .568 .001 0 r
F
.33954 .87959 m .33522 .87711 L .31748 .87539 L .551 0 0 r
F
.75151 .40507 m .76011 .41313 L .76163 .41769 L .825 .103 0 r
F
.75151 .40507 m .7496 .40076 L .76011 .41313 L F
.35659 .68035 m .34454 .67574 L .34653 .67922 L 1 .16 0 r
F
.35859 .68347 m .35659 .68035 L .34653 .67922 L 1 .177 0 r
F
.51581 .66095 m .51152 .6646 L .50966 .66462 L .655 .803 0 r
F
.51581 .66095 m .51798 .66089 L .51152 .6646 L F
.43896 .65293 m .43032 .6522 L .43202 .65278 L .319 0 0 r
F
.44037 .65338 m .43896 .65293 L .43202 .65278 L .299 0 0 r
F
.62924 .57053 m .62998 .57595 L .62838 .57846 L .878 .435 0 r
F
.62924 .57053 m .63078 .56792 L .62998 .57595 L F
.41213 .88701 m .39121 .8876 L .39438 .88942 L .448 0 0 r
F
.41457 .88867 m .41213 .88701 L .39438 .88942 L .428 0 0 r
F
.43209 .88472 m .41213 .88701 L .41457 .88867 L .379 0 0 r
F
.63132 .44567 m .63311 .45095 L .63338 .4536 L .808 .142 0 r
F
.63132 .44567 m .63106 .44301 L .63311 .45095 L F
.62966 .50908 m .63076 .51387 L .63018 .51645 L .864 .193 0 r
F
.62966 .50908 m .63022 .50646 L .63076 .51387 L F
.85564 .67491 m .85035 .68438 L .84724 .69055 L 0 0 0 r
F
.85564 .67491 m .85879 .66851 L .85035 .68438 L F
.39756 .70409 m .38408 .70462 L .38618 .70798 L .988 .128 0 r
F
.39954 .70692 m .39756 .70409 L .38618 .70798 L .987 .146 0 r
F
.73727 .62062 m .73471 .62767 L .73223 .63182 L .689 .203 0 r
F
.73727 .62062 m .7398 .61631 L .73471 .62767 L F
.54633 .62954 m .5434 .63173 L .54125 .63266 L .439 .208 0 r
F
.54633 .62954 m .54864 .62853 L .5434 .63173 L F
.60138 .61036 m .60018 .61478 L .598 .6167 L .731 .356 0 r
F
.60138 .61036 m .60359 .60831 L .60018 .61478 L F
.3285 .89667 m .30562 .88993 L .31079 .89255 L .482 0 0 r
F
.33312 .899 m .3285 .89667 L .31079 .89255 L .456 0 0 r
F
.3847 .63652 m .37588 .63255 L .37817 .63404 L .522 0 0 r
F
.38686 .63786 m .3847 .63652 L .37817 .63404 L .505 0 0 r
F
.89717 .35843 m .89651 .37403 L .89809 .3809 L 0 0 0 r
F
.89717 .35843 m .89545 .35152 L .89651 .37403 L F
.63392 .44511 m .63634 .45036 L .63681 .45302 L .811 .132 0 r
F
.63392 .44511 m .63345 .44245 L .63634 .45036 L F
.89998 .35762 m .90053 .37302 L .90253 .37986 L 0 0 0 r
F
.89998 .35762 m .89794 .35077 L .90053 .37302 L F
.52602 .65705 m .52227 .66056 L .52013 .66076 L .606 .726 0 r
F
.52602 .65705 m .52843 .65678 L .52227 .66056 L F
.61038 .56288 m .6097 .56681 L .60828 .56901 L .756 .217 0 r
F
.61038 .56288 m .61183 .5606 L .6097 .56681 L F
.32631 .90303 m .30308 .89619 L .30836 .89877 L .469 0 0 r
F
.33103 .90534 m .32631 .90303 L .30836 .89877 L .441 0 0 r
F
.63506 .51005 m .63559 .51488 L .635 .51754 L .823 .187 0 r
F
.63506 .51005 m .63565 .50735 L .63559 .51488 L F
.53881 .65211 m .53553 .65554 L .53318 .65602 L .585 .599 0 r
F
.53881 .65211 m .54137 .65154 L .53553 .65554 L F
.86865 .68149 m .86105 .69014 L .8579 .69651 L 0 0 0 r
F
.86865 .68149 m .87194 .67489 L .86105 .69014 L F
.4212 .63876 m .41314 .63608 L .41518 .63685 L .272 0 0 r
F
.42303 .63938 m .4212 .63876 L .41518 .63685 L .243 0 0 r
F
.76938 .51907 m .77055 .52804 L .76975 .53289 L .812 .175 0 r
F
.76938 .51907 m .77004 .51415 L .77055 .52804 L F
.67718 .43216 m .68013 .4279 L .67074 .44073 L 0 0 0 r
F
.6417 .71749 m .64607 .71564 L .63881 .72488 L .694 .719 0 r
F
.49519 .64722 m .49025 .64864 L .48924 .6487 L .294 .19 0 r
F
.49519 .64722 m .49653 .64714 L .49025 .64864 L F
.40804 .91507 m .38638 .91211 L .38983 .91357 L .364 0 0 r
F
.41072 .9163 m .40804 .91507 L .38983 .91357 L .335 0 0 r
F
.42894 .91712 m .40804 .91507 L .41072 .9163 L .323 0 0 r
F
.561 .75753 m .55824 .7752 L .55452 .77479 L 1 1 0 r
F
.561 .75753 m .56526 .75853 L .55824 .7752 L F
.61458 .56537 m .61366 .56928 L .6122 .57154 L .733 .214 0 r
F
.61458 .56537 m .61608 .56302 L .61366 .56928 L F
.50235 .64546 m .49786 .64701 L .49653 .64714 L .326 .195 0 r
F
.50235 .64546 m .50398 .64529 L .49786 .64701 L F
.40703 .92194 m .38507 .91873 L .38859 .92017 L .358 0 0 r
F
.40976 .92315 m .40703 .92194 L .38859 .92017 L .326 0 0 r
F
.42824 .92428 m .40703 .92194 L .40976 .92315 L .323 0 0 r
F
.43376 .88624 m .43209 .88472 L .41457 .88867 L .357 0 0 r
F
.37095 .61216 m .36412 .60629 L .36615 .60797 L 0 .024 0 r
F
.37292 .61371 m .37095 .61216 L .36615 .60797 L 0 .03 0 r
F
.89308 .52799 m .89649 .54099 L .89548 .54788 L .855 .179 0 r
F
.89308 .52799 m .89385 .52103 L .89649 .54099 L F
.58413 .59689 m .58245 .59997 L .58054 .60167 L .627 .221 0 r
F
.58413 .59689 m .58611 .5951 L .58245 .59997 L F
.44072 .7011 m .42901 .70573 L .43058 .70777 L .477 .017 0 r
F
.44197 .70258 m .44072 .7011 L .43058 .70777 L .467 .018 0 r
F
.45143 .69608 m .44072 .7011 L .44197 .70258 L .296 0 0 r
F
.57979 .74548 m .57769 .75963 L .57361 .75956 L 1 1 0 r
F
.57979 .74548 m .58435 .74594 L .57769 .75963 L F
.41779 .64948 m .40883 .64756 L .41097 .64851 L .431 0 0 r
F
.41971 .65027 m .41779 .64948 L .41097 .64851 L .416 0 0 r
F
.58732 .60018 m .5855 .60325 L .58354 .605 L .612 .219 0 r
F
.58732 .60018 m .58936 .59835 L .5855 .60325 L F
.91414 .53036 m .90957 .54285 L .90879 .54999 L 0 0 0 r
F
.91414 .53036 m .91494 .52305 L .90957 .54285 L F
.55414 .64509 m .5514 .64855 L .54893 .6494 L .589 .475 0 r
F
.55414 .64509 m .55678 .64414 L .5514 .64855 L F
.64555 .51194 m .65056 .51801 L .64979 .52088 L 1 .621 0 r
F
.64555 .51194 m .64607 .50905 L .65056 .51801 L F
.19954 .80506 m .17838 .79244 L .18323 .7972 L .699 .04 0 r
F
.20414 .80952 m .19954 .80506 L .18323 .7972 L .682 .035 0 r
F
.45231 .69705 m .45143 .69608 L .44197 .70258 L .281 0 0 r
F
.25581 .84362 m .23356 .83453 L .23876 .8384 L .642 .02 0 r
F
.26065 .84721 m .25581 .84362 L .23876 .8384 L .625 .014 0 r
F
.62905 .51169 m .63018 .51645 L .62954 .51902 L .868 .196 0 r
F
.62905 .51169 m .62966 .50908 L .63018 .51645 L F
.63152 .44834 m .63338 .4536 L .6336 .45624 L .826 .148 0 r
F
.63152 .44834 m .63132 .44567 L .63338 .4536 L F
.4308 .91813 m .42894 .91712 L .41072 .9163 L .292 0 0 r
F
.36276 .62288 m .35457 .61748 L .35677 .61932 L .558 .002 0 r
F
.36487 .62458 m .36276 .62288 L .35677 .61932 L .54 0 0 r
F
.33318 .65606 m .32316 .64877 L .32493 .6522 L .994 .104 0 r
F
.335 .65924 m .33318 .65606 L .32493 .6522 L 1 .104 0 r
F
.62766 .57311 m .62838 .57846 L .62674 .58094 L .88 .453 0 r
F
.62766 .57311 m .62924 .57053 L .62838 .57846 L F
.18935 .81723 m .1686 .80284 L .17359 .80779 L .66 .031 0 r
F
.19411 .82186 m .18935 .81723 L .17359 .80779 L .64 .025 0 r
F
.43013 .92529 m .42824 .92428 L .40976 .92315 L .291 0 0 r
F
.63435 .44777 m .63681 .45302 L .63723 .4557 L .824 .136 0 r
F
.63435 .44777 m .63392 .44511 L .63681 .45302 L F
.63442 .51275 m .635 .51754 L .63437 .52019 L .83 .191 0 r
F
.63442 .51275 m .63506 .51005 L .635 .51754 L F
.24684 .85873 m .22471 .8477 L .23013 .85168 L .584 .004 0 r
F
.25192 .86239 m .24684 .85873 L .23013 .85168 L .562 0 0 r
F
.40912 .63444 m .40127 .63101 L .40343 .63199 L .299 0 0 r
F
.41112 .63528 m .40912 .63444 L .40343 .63199 L 0 .074 0 r
F
.6089 .56513 m .60828 .56901 L .60682 .57118 L .759 .219 0 r
F
.6089 .56513 m .61038 .56288 L .60828 .56901 L F
.18419 .82338 m .1629 .80891 L .16804 .81388 L .652 .028 0 r
F
.18909 .82803 m .18419 .82338 L .16804 .81388 L .631 .022 0 r
F
.39494 .62781 m .39288 .62667 L .38754 .62349 L 0 .058 0 r
F
.49814 .66794 m .49287 .67204 L .49169 .67185 L .739 .868 0 r
F
.49814 .66794 m .49969 .66815 L .49287 .67204 L F
.5059 .66443 m .50124 .6683 L .49969 .66815 L .726 .884 0 r
F
.5059 .66443 m .50779 .66456 L .50124 .6683 L F
.41471 .70725 m .40153 .70988 L .40355 .71298 L .859 .07 0 r
F
.41653 .70976 m .41471 .70725 L .40355 .71298 L .855 .072 0 r
F
.24311 .865 m .22054 .85391 L .2261 .85788 L .573 .001 0 r
F
.24831 .86866 m .24311 .865 L .2261 .85788 L .55 0 0 r
F
.43279 .6419 m .42488 .63997 L .42675 .64051 L .216 0 0 r
F
.43442 .64231 m .43279 .6419 L .42675 .64051 L .185 0 0 r
F
.44967 .64459 m .44212 .64367 L .44348 .64392 L .128 0 0 r
F
.45073 .64472 m .44967 .64459 L .44348 .64392 L .093 0 0 r
F
.61304 .56769 m .6122 .57154 L .61069 .57378 L .737 .217 0 r
F
.61304 .56769 m .61458 .56537 L .6122 .57154 L F
.59912 .61236 m .598 .6167 L .59578 .61858 L .73 .385 0 r
F
.59912 .61236 m .60138 .61036 L .598 .6167 L F
.53018 .63657 m .52702 .63851 L .52497 .63912 L .409 .206 0 r
F
.53018 .63657 m .53244 .63589 L .52702 .63851 L F
.36598 .88456 m .34392 .88197 L .34836 .88426 L .529 0 0 r
F
.36979 .88665 m .36598 .88456 L .34836 .88426 L .512 0 0 r
F
.7533 .40943 m .76163 .41769 L .76304 .42228 L .833 .108 0 r
F
.7533 .40943 m .75151 .40507 L .76163 .41769 L F
.50953 .6434 m .5056 .64507 L .50398 .64529 L .365 .2 0 r
F
.50953 .6434 m .51143 .64312 L .5056 .64507 L F
.57953 .89949 m .56755 .90227 L .56355 .90359 L 0 0 0 r
F
.57953 .89949 m .58424 .8981 L .56755 .90227 L F
.58212 .59864 m .58054 .60167 L .5786 .60333 L .631 .223 0 r
F
.58212 .59864 m .58413 .59689 L .58054 .60167 L F
.51869 .64061 m .51518 .64241 L .51331 .64279 L .387 .204 0 r
F
.51869 .64061 m .5208 .64017 L .51518 .64241 L F
.42901 .70573 m .41653 .70976 L .41836 .71242 L .692 .049 0 r
F
.43058 .70777 m .42901 .70573 L .41836 .71242 L .686 .051 0 r
F
.68465 .68668 m .6815 .69283 L .67791 .69582 L .638 .225 0 r
F
.68465 .68668 m .68843 .68357 L .6815 .69283 L F
.40461 .64557 m .39574 .64287 L .39802 .64404 L .467 0 0 r
F
.40671 .64658 m .40461 .64557 L .39802 .64404 L .451 0 0 r
F
.54399 .63051 m .54125 .63266 L .53908 .63354 L .45 .211 0 r
F
.54399 .63051 m .54633 .62954 L .54125 .63266 L F
.37994 .69829 m .36682 .69674 L .36894 .70031 L 1 .196 0 r
F
.382 .7014 m .37994 .69829 L .36894 .70031 L 1 .215 0 r
F
.37292 .61371 m .36615 .60797 L .36822 .60961 L 0 .03 0 r
F
.37492 .61522 m .37292 .61371 L .36822 .60961 L 0 .036 0 r
F
.38686 .63786 m .37817 .63404 L .38049 .6355 L .505 0 0 r
F
.38904 .63916 m .38686 .63786 L .38049 .6355 L .488 0 0 r
F
.44848 .65358 m .44037 .65338 L .44179 .65378 L .226 0 0 r
F
.44958 .65385 m .44848 .65358 L .44179 .65378 L .201 0 0 r
F
.43032 .6522 m .42165 .65104 L .4236 .65177 L .369 0 0 r
F
.43202 .65278 m .43032 .6522 L .4236 .65177 L .353 0 0 r
F
.645 .51484 m .64979 .52088 L .64899 .52375 L 1 .617 0 r
F
.645 .51484 m .64555 .51194 L .64979 .52088 L F
.58241 .91064 m .56988 .91251 L .56583 .91403 L 0 0 0 r
F
.58241 .91064 m .58719 .90901 L .56988 .91251 L F
.6284 .51429 m .62954 .51902 L .62887 .52158 L .872 .199 0 r
F
.6284 .51429 m .62905 .51169 L .62954 .51902 L F
.52135 .81203 m .51282 .83145 L .51075 .83192 L 1 1 0 r
F
.52135 .81203 m .52408 .81232 L .51282 .83145 L F
.58525 .60198 m .58354 .605 L .58155 .6067 L .616 .221 0 r
F
.58525 .60198 m .58732 .60018 L .58354 .605 L F
.63165 .45102 m .6336 .45624 L .63376 .45889 L .844 .155 0 r
F
.63165 .45102 m .63152 .44834 L .6336 .45624 L F
.73465 .62488 m .73223 .63182 L .72966 .63593 L .694 .206 0 r
F
.73465 .62488 m .73727 .62062 L .73223 .63182 L F
.36029 .90637 m .33781 .90121 L .34255 .90331 L .432 0 0 r
F
.3644 .9082 m .36029 .90637 L .34255 .90331 L .405 0 0 r
F
.58382 .9161 m .57106 .91768 L .56696 .91924 L 0 0 0 r
F
.58382 .9161 m .58865 .91441 L .57106 .91768 L F
.5328 .79126 m .52678 .81235 L .52408 .81232 L 1 1 0 r
F
.5328 .79126 m .53613 .79214 L .52678 .81235 L F
.44212 .64367 m .43442 .64231 L .43605 .64268 L .166 0 0 r
F
.44348 .64392 m .44212 .64367 L .43605 .64268 L .133 0 0 r
F
.76862 .52399 m .76975 .53289 L .76886 .53772 L .816 .178 0 r
F
.76862 .52399 m .76938 .51907 L .76975 .53289 L F
.35859 .68347 m .34653 .67922 L .34855 .68277 L 1 .177 0 r
F
.36061 .68666 m .35859 .68347 L .34855 .68277 L 1 .196 0 r
F
.3586 .91283 m .3358 .90752 L .34064 .90959 L .419 0 0 r
F
.36279 .91463 m .3586 .91283 L .34064 .90959 L .39 0 0 r
F
.63473 .45045 m .63723 .4557 L .6376 .45838 L .836 .141 0 r
F
.63473 .45045 m .63435 .44777 L .63723 .4557 L F
.39121 .8876 m .36979 .88665 L .37366 .88864 L .49 0 0 r
F
.39438 .88942 m .39121 .8876 L .37366 .88864 L .472 0 0 r
F
.63373 .51544 m .63437 .52019 L .63368 .52283 L .837 .194 0 r
F
.63373 .51544 m .63442 .51275 L .63437 .52019 L F
.78698 .77578 m .77944 .78223 L .77487 .78718 L 0 0 0 r
F
.78698 .77578 m .79177 .77059 L .77944 .78223 L F
.62602 .57567 m .62674 .58094 L .62506 .5834 L .882 .472 0 r
F
.62602 .57567 m .62766 .57311 L .62674 .58094 L F
.60737 .56736 m .60682 .57118 L .60531 .57334 L .761 .222 0 r
F
.60737 .56736 m .6089 .56513 L .60682 .57118 L F
.42303 .63938 m .41518 .63685 L .41723 .63757 L .243 0 0 r
F
.42488 .63997 m .41723 .63757 L .41931 .63825 L .214 0 0 r
F
.42488 .63997 m .42303 .63938 L .42195 .63904 L F
.42488 .63997 m .42195 .63904 L .42194 .63904 L F
.42675 .64051 m .42488 .63997 L .41931 .63825 L 0 .096 0 r
F
.42192 .63904 m .41931 .63825 L .42141 .63889 L F
.42675 .64051 m .42193 .63904 L .42192 .63904 L F
.42193 .63904 m .41931 .63825 L .42192 .63904 L F
.42194 .63904 m .42195 .63904 L .41723 .63757 L .214 0 0 r
F
.7963 .78449 m .7876 .79023 L .78295 .79535 L 0 0 0 r
F
.7963 .78449 m .80121 .77914 L .7876 .79023 L F
.53622 .65261 m .53318 .65602 L .53081 .65644 L .596 .668 0 r
F
.53622 .65261 m .53881 .65211 L .53318 .65602 L F
.44037 .65338 m .43202 .65278 L .43373 .65333 L .299 0 0 r
F
.44179 .65378 m .44037 .65338 L .43373 .65333 L .279 0 0 r
F
.36487 .62458 m .35677 .61932 L .359 .62114 L .54 0 0 r
F
.36701 .62624 m .36487 .62458 L .359 .62114 L .523 0 0 r
F
.61146 .56998 m .61069 .57378 L .60914 .57599 L .74 .219 0 r
F
.61146 .56998 m .61304 .56769 L .61069 .57378 L F
.51363 .66092 m .50966 .66462 L .50779 .66456 L .706 .878 0 r
F
.51363 .66092 m .51581 .66095 L .50966 .66462 L F
.5236 .65724 m .52013 .66076 L .51798 .66089 L .646 .799 0 r
F
.5236 .65724 m .52602 .65705 L .52013 .66076 L F
.38638 .91211 m .3644 .9082 L .36856 .90991 L .392 0 0 r
F
.38983 .91357 m .38638 .91211 L .36856 .90991 L .363 0 0 r
F
.55148 .64599 m .54893 .6494 L .54644 .65018 L .596 .533 0 r
F
.55148 .64599 m .55414 .64509 L .54893 .6494 L F
.89872 .36538 m .89809 .3809 L .89949 .38781 L 0 0 0 r
F
.89872 .36538 m .89717 .35843 L .89809 .3809 L F
.85236 .68126 m .84724 .69055 L .84402 .69667 L F
.85236 .68126 m .85564 .67491 L .84724 .69055 L F
.38507 .91873 m .36279 .91463 L .36702 .91631 L .38 0 0 r
F
.38859 .92017 m .38507 .91873 L .36702 .91631 L .35 0 0 r
F
.6277 .51689 m .62887 .52158 L .62814 .52413 L .876 .201 0 r
F
.6277 .51689 m .6284 .51429 L .62887 .52158 L F
.59682 .61432 m .59578 .61858 L .59352 .62042 L .728 .413 0 r
F
.59682 .61432 m .59912 .61236 L .59578 .61858 L F
.90189 .36453 m .90253 .37986 L .90441 .38675 L 0 0 0 r
F
.90189 .36453 m .89998 .35762 L .90253 .37986 L F
.39494 .62781 m .38754 .62349 L .38975 .62474 L 0 .058 0 r
F
.39702 .62892 m .39494 .62781 L .38975 .62474 L 0 .064 0 r
F
.41971 .65027 m .41097 .64851 L .41314 .64943 L .416 0 0 r
F
.42165 .65104 m .41971 .65027 L .41314 .64943 L .401 0 0 r
F
.64439 .51773 m .64899 .52375 L .64817 .52661 L 1 .616 0 r
F
.64439 .51773 m .645 .51484 L .64899 .52375 L F
.63169 .4537 m .63376 .45889 L .63387 .46155 L .863 .163 0 r
F
.63169 .4537 m .63165 .45102 L .63376 .45889 L F
.58008 .60036 m .5786 .60333 L .57663 .60495 L .633 .224 0 r
F
.58008 .60036 m .58212 .59864 L .5786 .60333 L F
.335 .65924 m .32493 .6522 L .32672 .65567 L 1 .104 0 r
F
.33684 .66245 m .335 .65924 L .32672 .65567 L 1 .105 0 r
F
.89225 .53495 m .89548 .54788 L .89437 .55475 L .852 .179 0 r
F
.89225 .53495 m .89308 .52799 L .89548 .54788 L F
.50071 .64558 m .49653 .64714 L .49519 .64722 L .361 .2 0 r
F
.50071 .64558 m .50235 .64546 L .49653 .64714 L F
.86523 .68804 m .8579 .69651 L .85463 .70282 L 0 0 0 r
F
.86523 .68804 m .86865 .68149 L .8579 .69651 L F
.39954 .70692 m .38618 .70798 L .38829 .71149 L .987 .146 0 r
F
.40153 .70988 m .39954 .70692 L .38829 .71149 L .985 .165 0 r
F
.41112 .63528 m .40343 .63199 L .40561 .63294 L 0 .074 0 r
F
.41314 .63608 m .41112 .63528 L .40561 .63294 L 0 .08 0 r
F
.6044 .8918 m .5935 .89491 L .5889 .89657 L 0 0 0 r
F
.6044 .8918 m .60964 .89003 L .5935 .89491 L F
.49384 .64725 m .48924 .6487 L .48822 .6487 L .334 .196 0 r
F
.49384 .64725 m .49519 .64722 L .48924 .6487 L F
.63299 .51812 m .63368 .52283 L .63294 .52546 L .843 .197 0 r
F
.63299 .51812 m .63373 .51544 L .63368 .52283 L F
.63505 .45314 m .6376 .45838 L .63793 .46107 L .847 .146 0 r
F
.63505 .45314 m .63473 .45045 L .6376 .45838 L F
.37492 .61522 m .36822 .60961 L .37032 .61122 L 0 .036 0 r
F
.37694 .61669 m .37492 .61522 L .37032 .61122 L 0 .041 0 r
F
.58315 .60374 m .58155 .6067 L .57952 .60837 L .619 .222 0 r
F
.58315 .60374 m .58525 .60198 L .58155 .6067 L F
.9132 .53766 m .90879 .54999 L .90787 .55712 L 0 0 0 r
F
.9132 .53766 m .91414 .53036 L .90879 .54999 L F
.60579 .56957 m .60531 .57334 L .60376 .57546 L .763 .223 0 r
F
.60579 .56957 m .60737 .56736 L .60531 .57334 L F
.60806 .90313 m .59658 .90536 L .59191 .90725 L 0 0 0 r
F
.60806 .90313 m .61338 .90111 L .59658 .90536 L F
.75496 .41386 m .76304 .42228 L .76434 .42692 L .841 .113 0 r
F
.75496 .41386 m .7533 .40943 L .76304 .42228 L F
.62434 .5782 m .62506 .5834 L .62333 .58583 L .883 .492 0 r
F
.62434 .5782 m .62602 .57567 L .62506 .5834 L F
.60986 .90869 m .59814 .91067 L .59342 .9126 L 0 0 0 r
F
.60986 .90869 m .61523 .9066 L .59814 .91067 L F
.5279 .63719 m .52497 .63912 L .52289 .63967 L .427 .209 0 r
F
.5279 .63719 m .53018 .63657 L .52497 .63912 L F
.54163 .63143 m .53908 .63354 L .53689 .63438 L .462 .213 0 r
F
.54163 .63143 m .54399 .63051 L .53908 .63354 L F
.66774 .44436 m .6645 .45161 L .6625 .45506 L .698 .222 0 r
F
.66774 .44436 m .671 .44039 L .6645 .45161 L F
.50188 .92947 m .48527 .92948 L .48445 .93027 L .152 0 0 r
F
.50188 .92947 m .50361 .92865 L .48527 .92948 L F
.38904 .63916 m .38049 .6355 L .38284 .63693 L .488 0 0 r
F
.39125 .64043 m .38904 .63916 L .38284 .63693 L .473 0 0 r
F
.60983 .57224 m .60914 .57599 L .60755 .57818 L .743 .221 0 r
F
.60983 .57224 m .61146 .56998 L .60914 .57599 L F
.30306 .867 m .28074 .86068 L .28595 .86383 L .59 .004 0 r
F
.3078 .86989 m .30306 .867 L .28595 .86383 L .572 0 0 r
F
.73088 .84161 m .73653 .83742 L .72157 .8457 L 0 0 0 r
F
.43442 .64231 m .42675 .64051 L .42863 .64101 L .185 0 0 r
F
.43605 .64268 m .43442 .64231 L .42863 .64101 L 0 .105 0 r
F
.76776 .5289 m .76886 .53772 L .76788 .54254 L .82 .181 0 r
F
.76776 .5289 m .76862 .52399 L .76886 .53772 L F
.40671 .64658 m .39802 .64404 L .40032 .64518 L .451 0 0 r
F
.40883 .64756 m .40671 .64658 L .40032 .64518 L .437 0 0 r
F
.63499 .88047 m .62499 .8839 L .61994 .88608 L 0 0 0 r
F
.63499 .88047 m .64059 .87815 L .62499 .8839 L F
.62696 .51948 m .62814 .52413 L .62737 .52667 L .879 .204 0 r
F
.62696 .51948 m .6277 .51689 L .62814 .52413 L F
.53611 .91011 m .53946 .90925 L .52233 .9121 L 0 0 0 r
F
.73194 .62909 m .72966 .63593 L .727 .63998 L .699 .209 0 r
F
.73194 .62909 m .73465 .62488 L .72966 .63593 L F
.63165 .4564 m .63387 .46155 L .63393 .4642 L .884 .171 0 r
F
.63165 .4564 m .63169 .4537 L .63387 .46155 L F
.51657 .641 m .51331 .64279 L .51143 .64312 L .41 .207 0 r
F
.51657 .641 m .51869 .64061 L .51331 .64279 L F
.64374 .52062 m .64817 .52661 L .64731 .52946 L 1 .617 0 r
F
.64374 .52062 m .64439 .51773 L .64817 .52661 L F
.36701 .62624 m .359 .62114 L .36126 .62292 L .523 0 0 r
F
.36918 .62787 m .36701 .62624 L .36126 .62292 L .506 0 0 r
F
.68078 .68968 m .67791 .69582 L .67423 .69871 L .645 .228 0 r
F
.68078 .68968 m .68465 .68668 L .67791 .69582 L F
.29549 .88438 m .27306 .87599 L .27854 .87913 L .511 0 0 r
F
.30052 .88721 m .29549 .88438 L .27854 .87913 L .486 0 0 r
F
.63957 .89166 m .62895 .89429 L .62382 .89669 L 0 0 0 r
F
.63957 .89166 m .64526 .88911 L .62895 .89429 L F
.50762 .64361 m .50398 .64529 L .50235 .64546 L .394 .204 0 r
F
.50762 .64361 m .50953 .6434 L .50398 .64529 L F
.53767 .92044 m .52345 .92158 L .52088 .92257 L .048 0 0 r
F
.53767 .92044 m .54107 .91939 L .52345 .92158 L F
.45073 .64472 m .44348 .64392 L .44485 .64412 L .093 0 0 r
F
.4518 .64481 m .45073 .64472 L .44485 .64412 L 0 .126 0 r
F
.63219 .52079 m .63294 .52546 L .63215 .52808 L .848 .2 0 r
F
.63219 .52079 m .63299 .51812 L .63294 .52546 L F
.57516 .7447 m .57361 .75956 L .56947 .7592 L 1 1 0 r
F
.57516 .7447 m .57979 .74548 L .57361 .75956 L F
.63533 .45584 m .63793 .46107 L .6382 .46377 L .858 .15 0 r
F
.63533 .45584 m .63505 .45314 L .63793 .46107 L F
.53842 .92547 m .52401 .92632 L .52141 .92731 L .074 0 0 r
F
.53842 .92547 m .54186 .9244 L .52401 .92632 L F
.578 .60204 m .57663 .60495 L .57462 .60654 L .636 .225 0 r
F
.578 .60204 m .58008 .60036 L .57663 .60495 L F
.64181 .89716 m .63097 .89961 L .62579 .90206 L 0 0 0 r
F
.64181 .89716 m .64756 .89454 L .63097 .89961 L F
.44197 .70258 m .43058 .70777 L .43217 .70995 L .467 .018 0 r
F
.44323 .70413 m .44197 .70258 L .43217 .70995 L .458 .021 0 r
F
.45231 .69705 m .44197 .70258 L .44323 .70413 L .281 0 0 r
F
.54303 .77165 m .53942 .79272 L .53613 .79214 L 1 1 0 r
F
.54303 .77165 m .54691 .77303 L .53942 .79272 L F
.29274 .89067 m .26994 .8822 L .27555 .88532 L .497 0 0 r
F
.29788 .89349 m .29274 .89067 L .27555 .88532 L .471 0 0 r
F
.50401 .66421 m .49969 .66815 L .49814 .66794 L .784 .958 0 r
F
.50401 .66421 m .5059 .66443 L .49969 .66815 L F
.59448 .61624 m .59352 .62042 L .59122 .62221 L .727 .442 0 r
F
.59448 .61624 m .59682 .61432 L .59352 .62042 L F
.20414 .80952 m .18323 .7972 L .18817 .80188 L .682 .035 0 r
F
.20883 .81389 m .20414 .80952 L .18817 .80188 L .666 .03 0 r
F
.43202 .65278 m .4236 .65177 L .42558 .65247 L .353 0 0 r
F
.43373 .65333 m .43202 .65278 L .42558 .65247 L .338 0 0 r
F
.60418 .57175 m .60376 .57546 L .60217 .57756 L .765 .225 0 r
F
.60418 .57175 m .60579 .56957 L .60376 .57546 L F
.55667 .75619 m .55452 .77479 L .55074 .77407 L 1 1 0 r
F
.55667 .75619 m .561 .75753 L .55452 .77479 L F
.55542 .90581 m .54277 .90825 L .53946 .90925 L 0 0 0 r
F
.55542 .90581 m .55951 .90477 L .54277 .90825 L F
.36061 .68666 m .34855 .68277 L .35059 .68642 L 1 .196 0 r
F
.36266 .68993 m .36061 .68666 L .35059 .68642 L 1 .217 0 r
F
.49658 .66765 m .49814 .66794 L .49169 .67185 L .808 .952 0 r
F
.581 .60546 m .57952 .60837 L .57745 .61 L .623 .224 0 r
F
.581 .60546 m .58315 .60374 L .57952 .60837 L F
.39702 .62892 m .38975 .62474 L .39198 .62594 L 0 .064 0 r
F
.39914 .62998 m .39702 .62892 L .39198 .62594 L 0 .07 0 r
F
.44348 .64392 m .43605 .64268 L .43771 .64301 L .133 0 0 r
F
.44485 .64412 m .44348 .64392 L .43771 .64301 L 0 .117 0 r
F
.4532 .69806 m .45231 .69705 L .44323 .70413 L .268 0 0 r
F
.37694 .61669 m .37032 .61122 L .37245 .61279 L 0 .041 0 r
F
.37901 .61812 m .37694 .61669 L .37245 .61279 L 0 .047 0 r
F
.382 .7014 m .36894 .70031 L .37107 .70403 L 1 .215 0 r
F
.38408 .70462 m .382 .7014 L .37107 .70403 L 1 .236 0 r
F
.66432 .44823 m .6625 .45506 L .66058 .45842 L .746 .3 0 r
F
.66432 .44823 m .66774 .44436 L .6625 .45506 L F
.53361 .65304 m .53081 .65644 L .52843 .65678 L .612 .733 0 r
F
.53361 .65304 m .53622 .65261 L .53081 .65644 L F
.54879 .64681 m .54644 .65018 L .54392 .65089 L .602 .59 0 r
F
.54879 .64681 m .55148 .64599 L .54644 .65018 L F
.62261 .58071 m .62333 .58583 L .62156 .58822 L .884 .511 0 r
F
.62261 .58071 m .62434 .5782 L .62333 .58583 L F
.41653 .70976 m .40355 .71298 L .40557 .71628 L .855 .072 0 r
F
.41836 .71242 m .41653 .70976 L .40557 .71628 L .851 .074 0 r
F
.60816 .57448 m .60755 .57818 L .60591 .58033 L .746 .223 0 r
F
.60816 .57448 m .60983 .57224 L .60755 .57818 L F
.44958 .65385 m .44179 .65378 L .44322 .65416 L .201 0 0 r
F
.45069 .65409 m .44958 .65385 L .44322 .65416 L .177 0 0 r
F
.55757 .91669 m .54443 .91821 L .54107 .91939 L .002 0 0 r
F
.55757 .91669 m .56172 .91543 L .54443 .91821 L F
.19411 .82186 m .17359 .80779 L .17868 .81265 L .64 .025 0 r
F
.19897 .8264 m .19411 .82186 L .17868 .81265 L .62 .019 0 r
F
.62616 .52206 m .62737 .52667 L .62656 .52919 L .882 .209 0 r
F
.62616 .52206 m .62696 .51948 L .62737 .52667 L F
.55861 .92197 m .54526 .9232 L .54186 .9244 L .032 0 0 r
F
.55861 .92197 m .56281 .92067 L .54526 .9232 L F
.63149 .4591 m .63393 .4642 L .63395 .46685 L .908 .18 0 r
F
.63149 .4591 m .63165 .4564 L .63393 .4642 L F
.33684 .66245 m .32672 .65567 L .32855 .65919 L 1 .105 0 r
F
.33872 .6657 m .33684 .66245 L .32855 .65919 L 1 .106 0 r
F
.18909 .82803 m .16804 .81388 L .17329 .81875 L .631 .022 0 r
F
.1941 .83258 m .18909 .82803 L .17329 .81875 L .611 .016 0 r
F
.59912 .73459 m .59759 .7456 L .59325 .74598 L .945 1 0 r
F
.59912 .73459 m .60387 .73441 L .59759 .7456 L F
.41314 .63608 m .40561 .63294 L .40782 .63384 L 0 .08 0 r
F
.41518 .63685 m .41314 .63608 L .40782 .63384 L 0 .086 0 r
F
.26065 .84721 m .23876 .8384 L .24404 .84219 L .625 .014 0 r
F
.26556 .85071 m .26065 .84721 L .24404 .84219 L .607 .009 0 r
F
.64304 .52351 m .64731 .52946 L .64641 .5323 L 1 .62 0 r
F
.64304 .52351 m .64374 .52062 L .64731 .52946 L F
.63135 .52345 m .63215 .52808 L .63131 .53069 L .853 .203 0 r
F
.63135 .52345 m .63219 .52079 L .63215 .52808 L F
.33954 .87959 m .31748 .87539 L .32242 .878 L .551 0 0 r
F
.34392 .88197 m .33954 .87959 L .32242 .878 L .533 0 0 r
F
.52116 .65735 m .51798 .66089 L .51581 .66095 L .687 .864 0 r
F
.52116 .65735 m .5236 .65724 L .51798 .66089 L F
.63555 .45855 m .6382 .46377 L .63842 .46648 L .869 .154 0 r
F
.63555 .45855 m .63533 .45584 L .6382 .46377 L F
.44179 .65378 m .43373 .65333 L .43545 .65385 L .279 0 0 r
F
.44322 .65416 m .44179 .65378 L .43545 .65385 L .262 0 0 r
F
.42165 .65104 m .41314 .64943 L .41532 .65032 L .401 0 0 r
F
.4236 .65177 m .42165 .65104 L .41532 .65032 L .389 0 0 r
F
.7565 .41835 m .76434 .42692 L .76554 .43159 L .849 .118 0 r
F
.7565 .41835 m .75496 .41386 L .76434 .42692 L F
.51144 .66082 m .50779 .66456 L .5059 .66443 L .755 .944 0 r
F
.51144 .66082 m .51363 .66092 L .50779 .66456 L F
.53925 .63229 m .53689 .63438 L .53468 .63516 L .473 .214 0 r
F
.53925 .63229 m .54163 .63143 L .53689 .63438 L F
.43058 .70777 m .41836 .71242 L .42021 .71526 L .686 .051 0 r
F
.43217 .70995 m .43058 .70777 L .42021 .71526 L .68 .053 0 r
F
.39125 .64043 m .38284 .63693 L .38521 .63832 L .473 0 0 r
F
.39348 .64167 m .39125 .64043 L .38521 .63832 L .458 0 0 r
F
.60252 .5739 m .60217 .57756 L .60054 .57963 L .766 .236 0 r
F
.60252 .5739 m .60418 .57175 L .60217 .57756 L F
.57589 .60369 m .57462 .60654 L .57258 .60809 L .638 .227 0 r
F
.57589 .60369 m .578 .60204 L .57462 .60654 L F
.9001 .37239 m .89949 .38781 L .90072 .39476 L 0 0 0 r
F
.9001 .37239 m .89872 .36538 L .89949 .38781 L F
.78209 .78087 m .77487 .78718 L .77019 .79204 L F
.78209 .78087 m .78698 .77578 L .77487 .78718 L F
.36918 .62787 m .36126 .62292 L .36356 .62467 L .506 0 0 r
F
.37138 .62947 m .36918 .62787 L .36356 .62467 L .489 0 0 r
F
.25192 .86239 m .23013 .85168 L .23564 .85555 L .562 0 0 r
F
.25708 .86594 m .25192 .86239 L .23564 .85555 L .539 0 0 r
F
.5256 .63776 m .52289 .63967 L .5208 .64017 L .443 .211 0 r
F
.5256 .63776 m .5279 .63719 L .52289 .63967 L F
.89135 .54192 m .89437 .55475 L .89316 .56161 L .849 .18 0 r
F
.89135 .54192 m .89225 .53495 L .89437 .55475 L F
.76681 .5338 m .76788 .54254 L .76681 .54734 L .823 .184 0 r
F
.76681 .5338 m .76776 .5289 L .76788 .54254 L F
.90367 .37149 m .90441 .38675 L .90616 .39368 L 0 0 0 r
F
.90367 .37149 m .90189 .36453 L .90441 .38675 L F
.84896 .68756 m .84402 .69667 L .84068 .70273 L F
.84896 .68756 m .85236 .68126 L .84402 .69667 L F
.66069 .45201 m .66058 .45842 L .65874 .4617 L .791 .547 0 r
F
.66069 .45201 m .66432 .44823 L .66058 .45842 L F
.5921 .61812 m .59122 .62221 L .58888 .62395 L .725 .471 0 r
F
.5921 .61812 m .59448 .61624 L .59122 .62221 L F
.33312 .899 m .31079 .89255 L .31602 .89505 L .456 0 0 r
F
.33781 .90121 m .33312 .899 L .31602 .89505 L .429 0 0 r
F
.49905 .64564 m .49519 .64722 L .49384 .64725 L .395 .222 0 r
F
.49905 .64564 m .50071 .64558 L .49519 .64722 L F
.62532 .52463 m .62656 .52919 L .6257 .53171 L .884 .233 0 r
F
.62532 .52463 m .62616 .52206 L .62656 .52919 L F
.24831 .86866 m .2261 .85788 L .23175 .86174 L .55 0 0 r
F
.2536 .8722 m .24831 .86866 L .23175 .86174 L .526 0 0 r
F
.57882 .60715 m .57745 .61 L .57536 .61159 L .625 .225 0 r
F
.57882 .60715 m .581 .60546 L .57745 .61 L F
.60644 .5767 m .60591 .58033 L .60424 .58246 L .748 .225 0 r
F
.60644 .5767 m .60816 .57448 L .60591 .58033 L F
.79128 .78976 m .78295 .79535 L .7782 .80039 L 0 0 0 r
F
.79128 .78976 m .7963 .78449 L .78295 .79535 L F
.40883 .64756 m .40032 .64518 L .40265 .64629 L .437 0 0 r
F
.41097 .64851 m .40883 .64756 L .40265 .64629 L .425 0 0 r
F
.62083 .58319 m .62156 .58822 L .61974 .59059 L .886 .531 0 r
F
.62083 .58319 m .62261 .58071 L .62156 .58822 L F
.72914 .63324 m .727 .63998 L .72427 .64398 L .704 .212 0 r
F
.72914 .63324 m .73194 .62909 L .727 .63998 L F
.63072 .46485 m .63392 .46951 L .63389 .47075 L 1 .498 0 r
F
.63072 .46479 m .63392 .46951 L .63072 .46485 L F
.63055 .46453 m .63389 .47075 L .63374 .47067 L F
.6328 .46973 m .63374 .47067 L .63303 .47025 L F
.63055 .46453 m .63374 .47067 L .6328 .46973 L F
.63177 .46351 m .63395 .46685 L .63392 .46951 L .957 .259 0 r
F
.63601 .46205 m .63842 .46648 L .63859 .46919 L .879 .159 0 r
F
.63055 .46453 m .63117 .46181 L .63392 .46951 L 1 .498 0 r
F
.62369 .46777 m .63055 .46453 L .63385 .47216 L .911 1 0 r
F
.63726 .46937 m .63844 .47142 L .63734 .47065 L .896 .167 0 r
F
.6371 .46698 m .63859 .46919 L .63866 .47071 L .888 .163 0 r
F
.63614 .46467 m .63705 .46635 L .6371 .46698 L F
.63705 .46635 m .63859 .46919 L .6371 .46698 L F
.63725 .46919 m .63846 .47144 L .63739 .46958 L .896 .167 0 r
F
.63846 .47144 m .63871 .47191 L .63844 .47142 L F
.63846 .47144 m .63844 .47142 L .63739 .46958 L F
.63193 .46943 m .63729 .46984 L .63734 .47065 L .727 .966 0 r
F
.62429 .46771 m .63191 .46858 L .63193 .46943 L F
.63191 .46858 m .63725 .46919 L .63193 .46943 L F
.63725 .46919 m .63739 .46958 L .63726 .46937 L .896 .167 0 r
F
.63793 .46975 m .63866 .47071 L .6387 .47161 L .888 .163 0 r
F
.63857 .47152 m .6387 .47161 L .63871 .47191 L F
.63793 .46975 m .6387 .47161 L .63857 .47152 L F
.63734 .47065 m .6374 .47065 L .6374 .47066 L .727 .966 0 r
F
.63725 .46919 m .63729 .46984 L .63193 .46943 L F
.63045 .46876 m .63141 .46932 L .63734 .47065 L 0 .134 0 r
F
.63176 .46288 m .63395 .46685 L .63177 .46351 L .957 .259 0 r
F
.63117 .46181 m .63149 .4591 L .63395 .46685 L F
.62429 .46771 m .63589 .46523 L .63725 .46919 L .727 .966 0 r
F
.63066 .46745 m .63621 .46726 L .63066 .46759 L .604 .858 0 r
F
.63621 .46726 m .63621 .46727 L .63066 .46759 L F
.63621 .46726 m .63669 .46814 L .63622 .46754 L .896 .167 0 r
F
.63625 .46726 m .63626 .4674 L .63622 .4674 L .604 .858 0 r
F
.63622 .46727 m .63622 .4674 L .63066 .46759 L F
.63625 .46726 m .63622 .4674 L .63622 .46727 L F
.63622 .46754 m .63636 .4674 L .63637 .46754 L F
.63066 .46759 m .63622 .4674 L .63622 .46754 L F
.63622 .4674 m .63636 .4674 L .63622 .46754 L F
.63621 .46726 m .63614 .46479 L .63715 .46758 L .896 .167 0 r
F
.63595 .46948 m .63613 .46963 L .63614 .46983 L .904 .171 0 r
F
.63045 .46876 m .63734 .47065 L .63682 .47029 L 0 .134 0 r
F
.63504 .46954 m .63045 .46876 L .63682 .47029 L F
.63622 .4697 m .63734 .47065 L .63619 .46986 L .904 .171 0 r
F
.63681 .47028 m .63682 .47029 L .63684 .47029 L 0 .134 0 r
F
.63504 .46954 m .63682 .47029 L .63681 .47028 L F
.63504 .46954 m .63684 .47029 L .63671 .4702 L F
.63615 .46983 m .63671 .4702 L .63619 .46984 L F
.63504 .46954 m .63671 .4702 L .63615 .46983 L F
.63594 .4711 m .63613 .47018 L .6388 .47735 L .912 .174 0 r
F
.63597 .47115 m .63594 .4711 L .63616 .47005 L 1 .288 0 r
F
.63594 .4711 m .63504 .46954 L .63616 .47005 L F
.63594 .4711 m .63616 .47005 L .63616 .47005 L F
.63592 .47223 m .63594 .4711 L .6388 .47735 L .912 .174 0 r
F
.63594 .4711 m .63595 .4697 L .63613 .47018 L F
.63595 .4697 m .63595 .46948 L .63606 .46977 L F
.63504 .46954 m .63614 .46983 L .63616 .47002 L 0 .134 0 r
F
.63606 .46977 m .63878 .47463 L .6388 .47735 L .904 .171 0 r
F
.63616 .47005 m .63616 .47002 L .63616 .47005 L 0 .134 0 r
F
.63504 .46954 m .63616 .47002 L .63616 .47005 L F
.63595 .4697 m .63606 .46977 L .63616 .47005 L .912 .174 0 r
F
.63617 .47029 m .63616 .47005 L .6388 .47735 L F
.63595 .4697 m .63616 .47005 L .63617 .47029 L F
.63595 .46948 m .63614 .46983 L .63606 .46977 L .904 .171 0 r
F
.63614 .46983 m .63878 .47463 L .63606 .46977 L F
.63614 .46983 m .63734 .47065 L .63878 .47463 L F
.63734 .47065 m .63871 .47191 L .63878 .47463 L .896 .167 0 r
F
.63656 .47219 m .63597 .47115 L .65178 .4771 L 1 .288 0 r
F
.63725 .46919 m .63715 .46758 L .63857 .47152 L .896 .167 0 r
F
.63846 .47144 m .63857 .47152 L .63871 .47191 L F
.63725 .46919 m .63857 .47152 L .63846 .47144 L F
.63624 .46972 m .63622 .46754 L .63734 .47065 L .904 .171 0 r
F
.63684 .47029 m .63734 .47065 L .6374 .47066 L 0 .134 0 r
F
.63715 .46758 m .63866 .47071 L .63793 .46975 L .888 .163 0 r
F
.63585 .464 m .6371 .46698 L .63715 .46758 L F
.6371 .46698 m .63866 .47071 L .63715 .46758 L F
.63725 .46919 m .63728 .4692 L .63729 .46984 L .727 .966 0 r
F
.63728 .4692 m .65405 .47111 L .63733 .46984 L F
.63728 .4692 m .63733 .46984 L .63729 .46984 L F
.6374 .47066 m .65405 .47111 L .65282 .47413 L F
.6374 .47065 m .65405 .47111 L .6374 .47066 L F
.63729 .46984 m .65405 .47111 L .63734 .47065 L F
.63647 .46824 m .63726 .46937 L .63734 .47065 L .896 .167 0 r
F
.63622 .46754 m .6365 .46803 L .63647 .46824 L F
.6365 .46803 m .63726 .46937 L .63647 .46824 L F
.63597 .47115 m .63616 .47005 L .63621 .47007 L 1 .288 0 r
F
.63692 .47031 m .6374 .47066 L .64664 .47274 L 0 .134 0 r
F
.64402 .47202 m .64664 .47274 L .65282 .47413 L F
.63692 .47031 m .64664 .47274 L .64402 .47202 L F
.63844 .47142 m .63871 .47191 L .63734 .47065 L .896 .167 0 r
F
.63606 .47119 m .63621 .47007 L .65178 .4771 L 1 .288 0 r
F
.63597 .47115 m .63621 .47007 L .63606 .47119 L F
.63613 .46963 m .63622 .4697 L .63614 .46983 L .904 .171 0 r
F
.63622 .4697 m .63619 .46986 L .63614 .46983 L F
.63682 .47029 m .63734 .47065 L .63684 .47029 L 0 .134 0 r
F
.63684 .47029 m .6374 .47066 L .63692 .47031 L F
.63616 .47005 m .65282 .47413 L .65178 .4771 L F
.63619 .46984 m .63684 .47029 L .63684 .4703 L F
.6362 .46984 m .63684 .4703 L .65282 .47413 L F
.63619 .46984 m .63684 .4703 L .6362 .46984 L F
.63614 .46983 m .65282 .47413 L .63616 .47005 L F
.63621 .46726 m .63715 .46758 L .63725 .46919 L .896 .167 0 r
F
.63725 .46919 m .63729 .46984 L .63729 .46984 L .727 .966 0 r
F
.63613 .46452 m .63859 .46919 L .63614 .46467 L .888 .163 0 r
F
.63585 .464 m .63573 .46127 L .63601 .46205 L F
.63613 .46452 m .63601 .46205 L .63859 .46919 L F
.63585 .464 m .63601 .46205 L .63613 .46452 L F
.63625 .46726 m .63626 .46726 L .63626 .4674 L .604 .858 0 r
F
.63725 .46919 m .64336 .46513 L .65405 .47111 L .727 .966 0 r
F
.64336 .46513 m .64669 .46291 L .64812 .4645 L F
.64336 .46513 m .64812 .4645 L .65405 .47111 L F
.63595 .46654 m .63585 .464 L .63614 .46479 L .896 .167 0 r
F
.63593 .46674 m .63614 .46479 L .63621 .46726 L F
.63599 .46178 m .63842 .46648 L .63601 .46205 L .879 .159 0 r
F
.63573 .46127 m .63555 .45855 L .63842 .46648 L F
.63589 .46523 m .64669 .46291 L .63725 .46919 L .727 .966 0 r
F
.65302 .46136 m .65703 .46491 L .65545 .46804 L .981 1 0 r
F
.65229 .45933 m .65339 .46063 L .65302 .46136 L F
.65339 .46063 m .65703 .46491 L .65302 .46136 L F
.64812 .4645 m .65545 .46804 L .65405 .47111 L .998 1 0 r
F
.64669 .46291 m .6484 .46391 L .64812 .4645 L F
.6484 .46391 m .65545 .46804 L .64812 .4645 L F
.63626 .46726 m .64699 .4669 L .63627 .4674 L .604 .858 0 r
F
.64699 .4669 m .65025 .46679 L .64698 .46693 L F
.64699 .4669 m .64698 .46693 L .63627 .4674 L F
.64669 .46291 m .65229 .45933 L .65302 .46136 L .998 1 0 r
F
.6484 .46391 m .65302 .46136 L .65545 .46804 L F
.64669 .46291 m .65302 .46136 L .6484 .46391 L F
.76922 .46153 m .77054 .46021 L .77101 .46506 L .898 .151 0 r
F
.76393 .4511 m .76886 .45789 L .76922 .46153 L F
.76886 .45789 m .77054 .46021 L .76922 .46153 L F
.76945 .46438 m .76936 .46298 L .7695 .46438 L .604 .858 0 r
F
.64189 .4675 m .7693 .46298 L .76943 .46422 L F
.64189 .4675 m .76943 .46422 L .76944 .46438 L F
.64189 .4675 m .7695 .46438 L .76966 .46643 L F
.63637 .46754 m .64217 .46734 L .64189 .4675 L F
.76938 .46276 m .77101 .46506 L .76966 .46643 L .904 .155 0 r
F
.64217 .46734 m .76939 .4629 L .64189 .4675 L .604 .858 0 r
F
.76938 .46276 m .76922 .46153 L .77101 .46506 L .904 .155 0 r
F
.76939 .4629 m .90183 .45829 L .7694 .46298 L .604 .858 0 r
F
.76939 .4629 m .7694 .46298 L .64189 .4675 L F
.76938 .46276 m .89349 .43805 L .90183 .45829 L F
.65675 .45571 m .65874 .4617 L .65703 .46491 L .901 .796 0 r
F
.65229 .45933 m .65675 .45571 L .65703 .46491 L .981 1 0 r
F
.63621 .46726 m .76428 .45272 L .76938 .46276 L .604 .858 0 r
F
.76804 .46012 m .76393 .4511 L .76922 .46153 L .904 .155 0 r
F
.76408 .45232 m .76393 .4511 L .76804 .46012 L F
.76452 .45593 m .76922 .46153 L .76938 .46276 L F
.76239 .44154 m .76929 .45057 L .76997 .45538 L .886 .142 0 r
F
.76322 .4463 m .76997 .45538 L .77054 .46021 L .892 .147 0 r
F
.76322 .4463 m .76239 .44154 L .76997 .45538 L F
.76393 .4511 m .76322 .4463 L .77054 .46021 L .898 .151 0 r
F
.76428 .45272 m .89349 .43805 L .76938 .46276 L .604 .858 0 r
F
.63592 .46646 m .63585 .464 L .63595 .46654 L .896 .167 0 r
F
.63592 .46646 m .89349 .43805 L .63621 .46726 L .604 .858 0 r
F
.76452 .45593 m .76408 .45232 L .76804 .46012 L .904 .155 0 r
F
.65025 .46679 m .65018 .46692 L .63627 .4674 L .604 .858 0 r
F
.62522 .46764 m .63592 .46646 L .63621 .46726 L F
.63593 .46718 m .63593 .46674 L .63622 .46754 L .904 .171 0 r
F
.63593 .46674 m .63621 .46726 L .63622 .46754 L .896 .167 0 r
F
.63636 .4674 m .76952 .46283 L .63637 .46754 L .604 .858 0 r
F
.76952 .46283 m .90183 .45829 L .76952 .4629 L F
.76952 .46283 m .76952 .4629 L .63637 .46754 L F
.76999 .47134 m .77137 .46993 L .77163 .47481 L .91 .159 0 r
F
.63609 .46737 m .63622 .46754 L .76966 .46643 L .312 .268 0 r
F
.63609 .46737 m .76966 .46643 L .76957 .46634 L F
.65025 .46679 m .90183 .45829 L .65018 .46692 L .604 .858 0 r
F
.72749 .46331 m .63599 .46718 L .76943 .46625 L .312 .268 0 r
F
.76944 .46438 m .76943 .46422 L .76945 .46438 L .604 .858 0 r
F
.7693 .46298 m .76936 .46298 L .76945 .46438 L F
.765 .46078 m .76452 .45593 L .76672 .46043 L .91 .159 0 r
F
.76702 .46324 m .76672 .46043 L .76966 .46643 L F
.765 .46078 m .76672 .46043 L .76702 .46324 L F
.76704 .46377 m .76943 .46625 L .76948 .46625 L .312 .268 0 r
F
.765 .46078 m .76966 .46643 L .76708 .46377 L .91 .159 0 r
F
.76966 .46643 m .77101 .46506 L .77123 .46799 L .904 .155 0 r
F
.76936 .46298 m .90183 .45829 L .7697 .46643 L .604 .858 0 r
F
.76452 .45593 m .76938 .46276 L .76966 .46643 L .904 .155 0 r
F
.76966 .46643 m .7695 .46438 L .7697 .46643 L .604 .858 0 r
F
.7697 .46643 m .90183 .45829 L .90088 .46533 L F
.76708 .46377 m .76948 .46625 L .90088 .46533 L .312 .268 0 r
F
.76704 .46377 m .76948 .46625 L .76708 .46377 L F
.72749 .46331 m .76943 .46625 L .76704 .46377 L F
.76957 .46634 m .76966 .46643 L .90088 .46533 L F
.63626 .46726 m .63627 .4674 L .63626 .4674 L .604 .858 0 r
F
.63621 .46726 m .63625 .46726 L .63621 .46727 L F
.63599 .46718 m .63614 .46737 L .90088 .46533 L .312 .268 0 r
F
.76708 .46377 m .76966 .46643 L .76975 .46727 L .91 .159 0 r
F
.76708 .46377 m .76975 .46727 L .76927 .46691 L F
.76718 .46539 m .76978 .46765 L .76999 .47134 L F
.7671 .46417 m .76915 .46682 L .76718 .46539 L F
.72749 .46331 m .76704 .46377 L .76718 .46539 L .312 .268 0 r
F
.76704 .46377 m .76708 .46377 L .76718 .46539 L F
.76523 .46393 m .76507 .46172 L .7668 .46511 L .915 .163 0 r
F
.76516 .46393 m .72749 .46331 L .76718 .46539 L .185 .168 0 r
F
.76507 .46172 m .7658 .46248 L .76718 .46539 L .915 .163 0 r
F
.7668 .46511 m .76718 .46539 L .76999 .47134 L F
.76507 .46172 m .76718 .46539 L .7668 .46511 L F
.76618 .46464 m .76718 .46539 L .76725 .46539 L .185 .168 0 r
F
.76516 .46393 m .76718 .46539 L .76618 .46464 L F
.7653 .46393 m .76523 .46393 L .76725 .46539 L F
.76523 .46393 m .76516 .46393 L .76618 .46464 L F
.76523 .46393 m .76618 .46464 L .76725 .46539 L F
.76536 .46566 m .76523 .46393 L .76722 .46593 L .915 .163 0 r
F
.76523 .46393 m .7668 .46511 L .76722 .46593 L F
.76741 .46817 m .76722 .46593 L .76999 .47134 L F
.76536 .46566 m .76722 .46593 L .76741 .46817 L F
.76708 .46377 m .76978 .46765 L .7658 .46248 L .91 .159 0 r
F
.76718 .46539 m .76708 .46377 L .76725 .46539 L .312 .268 0 r
F
.7658 .46248 m .7671 .46417 L .76718 .46539 L .91 .159 0 r
F
.76915 .46682 m .76978 .46765 L .76718 .46539 L F
.81081 .46768 m .90088 .46533 L .89986 .47235 L .312 .268 0 r
F
.76725 .46539 m .79347 .46538 L .81081 .46768 L F
.79347 .46538 m .90088 .46533 L .81081 .46768 L F
.76708 .46377 m .90088 .46533 L .76725 .46539 L F
.79125 .46435 m .7653 .46393 L .89986 .47235 L .185 .168 0 r
F
.7653 .46393 m .76725 .46539 L .89986 .47235 L F
.79125 .46435 m .89986 .47235 L .89884 .47934 L F
.8258 .46852 m .79125 .46435 L .89883 .47934 L 0 .132 0 r
F
.89883 .47934 m .89883 .47934 L .89884 .47934 L F
.8258 .46852 m .89883 .47934 L .89883 .47934 L F
.76927 .46691 m .76975 .46727 L .76978 .46765 L .91 .159 0 r
F
.76507 .46172 m .765 .46078 L .7658 .46248 L .915 .163 0 r
F
.765 .46078 m .76708 .46377 L .7658 .46248 L .91 .159 0 r
F
.76978 .46765 m .77137 .46993 L .76999 .47134 L F
.77009 .47255 m .76999 .47134 L .77163 .47481 L .915 .163 0 r
F
.76536 .46566 m .76999 .47134 L .77009 .47255 L F
.76978 .46765 m .76966 .46643 L .77137 .46993 L .91 .159 0 r
F
.76966 .46643 m .77123 .46799 L .77137 .46993 L .904 .155 0 r
F
.63593 .46674 m .63592 .46646 L .63595 .46654 L .896 .167 0 r
F
.63048 .46741 m .63066 .46759 L .63622 .46754 L .312 .268 0 r
F
.63048 .46741 m .63622 .46754 L .63609 .46737 L F
.63599 .46718 m .63048 .46741 L .63614 .46737 L F
.63595 .46948 m .63593 .46718 L .63622 .46754 L .904 .171 0 r
F
.63595 .46948 m .63622 .46754 L .63624 .46972 L F
.63725 .46919 m .63726 .46937 L .63622 .46754 L .896 .167 0 r
F
.63669 .46814 m .63725 .46919 L .63622 .46754 L F
.63585 .464 m .63613 .46452 L .63614 .46467 L .888 .163 0 r
F
.63573 .46127 m .63599 .46178 L .63601 .46205 L .879 .159 0 r
F
.62522 .46764 m .63066 .46745 L .63066 .46759 L .604 .858 0 r
F
.63048 .46741 m .62522 .46764 L .63066 .46759 L .312 .268 0 r
F
.63055 .46453 m .63072 .46479 L .63072 .46485 L 1 .498 0 r
F
.63303 .47025 m .63389 .47075 L .63385 .47216 L F
.63045 .46876 m .62429 .46771 L .63141 .46932 L 0 .134 0 r
F
.63117 .46181 m .63176 .46288 L .63177 .46351 L .957 .259 0 r
F
.33103 .90534 m .30836 .89877 L .3137 .90124 L .441 0 0 r
F
.3358 .90752 m .33103 .90534 L .3137 .90124 L .413 0 0 r
F
.49248 .64722 m .49384 .64725 L .48822 .6487 L .373 .201 0 r
F
.86169 .69453 m .85463 .70282 L .85123 .70908 L 0 0 0 r
F
.86169 .69453 m .86523 .68804 L .85463 .70282 L F
.91212 .54496 m .90787 .55712 L .90682 .56424 L F
.91212 .54496 m .9132 .53766 L .90787 .55712 L F
.37901 .61812 m .37245 .61279 L .37461 .61433 L 0 .047 0 r
F
.3811 .61952 m .37901 .61812 L .37461 .61433 L 0 .053 0 r
F
.43605 .64268 m .42863 .64101 L .43054 .64147 L 0 .105 0 r
F
.43771 .64301 m .43605 .64268 L .43054 .64147 L 0 .111 0 r
F
.63046 .5261 m .63131 .53069 L .63043 .53328 L .858 .206 0 r
F
.63046 .5261 m .63135 .52345 L .63131 .53069 L F
.39914 .62998 m .39198 .62594 L .39424 .62711 L 0 .07 0 r
F
.40127 .63101 m .39914 .62998 L .39424 .62711 L 0 .075 0 r
F
.64229 .52638 m .64641 .5323 L .64548 .53513 L 1 .626 0 r
F
.64229 .52638 m .64304 .52351 L .64641 .5323 L F
.51442 .64134 m .51143 .64312 L .50953 .6434 L .432 .252 0 r
F
.51442 .64134 m .51657 .641 L .51143 .64312 L F
.40153 .70988 m .38829 .71149 L .39042 .7152 L .985 .165 0 r
F
.40355 .71298 m .40153 .70988 L .39042 .7152 L .983 .185 0 r
F
.67683 .69258 m .67423 .69871 L .67047 .7015 L .652 .28 0 r
F
.67683 .69258 m .68078 .68968 L .67423 .69871 L F
.51829 .92342 m .50329 .92418 L .50157 .925 L .082 0 0 r
F
.51829 .92342 m .52088 .92257 L .50329 .92418 L F
.60082 .57603 m .60054 .57963 L .59887 .58167 L .767 .263 0 r
F
.60082 .57603 m .60252 .5739 L .60054 .57963 L F
.51879 .92818 m .50361 .92865 L .50188 .92947 L .103 0 0 r
F
.51879 .92818 m .52141 .92731 L .50361 .92865 L F
.5057 .64378 m .50235 .64546 L .50071 .64558 L .422 .269 0 r
F
.5057 .64378 m .50762 .64361 L .50235 .64546 L F
.41457 .88867 m .39438 .88942 L .3976 .89114 L .428 0 0 r
F
.41704 .89024 m .41457 .88867 L .3976 .89114 L .409 0 0 r
F
.43376 .88624 m .41457 .88867 L .41704 .89024 L .357 0 0 r
F
.42863 .64101 m .42675 .64051 L .42141 .63889 L 0 .102 0 r
F
.54607 .64756 m .54392 .65089 L .54137 .65154 L .607 .644 0 r
F
.54607 .64756 m .54879 .64681 L .54392 .65089 L F
.65675 .45571 m .66069 .45201 L .65874 .4617 L .901 .796 0 r
F
.57375 .6053 m .57258 .60809 L .57051 .60961 L .639 .228 0 r
F
.57375 .6053 m .57589 .60369 L .57258 .60809 L F
.62443 .52718 m .6257 .53171 L .62479 .53421 L .886 .259 0 r
F
.62443 .52718 m .62532 .52463 L .6257 .53171 L F
.4518 .64481 m .44485 .64412 L .44624 .64428 L 0 .126 0 r
F
.45288 .64486 m .4518 .64481 L .44624 .64428 L 0 .133 0 r
F
.60469 .57888 m .60424 .58246 L .60252 .58456 L .75 .227 0 r
F
.60469 .57888 m .60644 .5767 L .60424 .58246 L F
.36266 .68993 m .35059 .68642 L .35266 .69018 L 1 .217 0 r
F
.36473 .69328 m .36266 .68993 L .35266 .69018 L 1 .24 0 r
F
.53098 .65338 m .52843 .65678 L .52602 .65705 L .643 .794 0 r
F
.53098 .65338 m .53361 .65304 L .52843 .65678 L F
.33872 .6657 m .32855 .65919 L .33041 .66278 L 1 .106 0 r
F
.34063 .66899 m .33872 .6657 L .33041 .66278 L 1 .107 0 r
F
.41518 .63685 m .40782 .63384 L .41005 .6347 L 0 .086 0 r
F
.41723 .63757 m .41518 .63685 L .41005 .6347 L 0 .092 0 r
F
.43373 .65333 m .42558 .65247 L .42756 .65315 L .338 0 0 r
F
.43545 .65385 m .43373 .65333 L .42756 .65315 L .326 0 0 r
F
.37138 .62947 m .36356 .62467 L .36589 .62638 L .489 0 0 r
F
.37362 .63103 m .37138 .62947 L .36589 .62638 L .472 0 0 r
F
.57661 .60879 m .57536 .61159 L .57322 .61314 L .628 .227 0 r
F
.57661 .60879 m .57882 .60715 L .57536 .61159 L F
.61899 .58563 m .61974 .59059 L .61787 .59293 L .887 .551 0 r
F
.61899 .58563 m .62083 .58319 L .61974 .59059 L F
.62953 .52874 m .63043 .53328 L .62949 .53585 L .862 .209 0 r
F
.62953 .52874 m .63046 .5261 L .63043 .53328 L F
.44485 .64412 m .43771 .64301 L .43937 .6433 L 0 .117 0 r
F
.44624 .64428 m .44485 .64412 L .43937 .6433 L 0 .123 0 r
F
.58968 .61995 m .58888 .62395 L .5865 .62565 L .722 .499 0 r
F
.58968 .61995 m .5921 .61812 L .58888 .62395 L F
.53684 .63311 m .53468 .63516 L .53244 .63589 L .483 .22 0 r
F
.53684 .63311 m .53925 .63229 L .53468 .63516 L F
.75792 .4229 m .76554 .43159 L .76664 .43629 L .857 .123 0 r
F
.75792 .4229 m .7565 .41835 L .76554 .43159 L F
.39348 .64167 m .38521 .63832 L .38761 .63968 L .458 0 0 r
F
.39574 .64287 m .39348 .64167 L .38761 .63968 L .444 0 0 r
F
.64149 .52926 m .64548 .53513 L .6445 .53794 L 1 .633 0 r
F
.64149 .52926 m .64229 .52638 L .64548 .53513 L F
.5021 .66392 m .49814 .66794 L .49658 .66765 L .839 1 0 r
F
.5021 .66392 m .50401 .66421 L .49814 .66794 L F
.52944 .79005 m .52408 .81232 L .52135 .81203 L 1 1 0 r
F
.52944 .79005 m .5328 .79126 L .52408 .81232 L F
.3811 .61952 m .37461 .61433 L .37681 .61583 L 0 .053 0 r
F
.38322 .62088 m .3811 .61952 L .37681 .61583 L 0 .058 0 r
F
.43545 .88766 m .43376 .88624 L .41704 .89024 L .334 0 0 r
F
.76575 .53869 m .76681 .54734 L .76565 .55213 L .827 .188 0 r
F
.76575 .53869 m .76681 .5338 L .76681 .54734 L F
.38408 .70462 m .37107 .70403 L .37322 .7079 L 1 .236 0 r
F
.38618 .70798 m .38408 .70462 L .37322 .7079 L 1 .257 0 r
F
.36979 .88665 m .34836 .88426 L .35286 .88645 L .512 0 0 r
F
.37366 .88864 m .36979 .88665 L .35286 .88645 L .494 0 0 r
F
.41072 .9163 m .38983 .91357 L .39332 .91491 L .335 0 0 r
F
.41343 .91741 m .41072 .9163 L .39332 .91491 L .304 0 0 r
F
.4308 .91813 m .41072 .9163 L .41343 .91741 L .292 0 0 r
F
.59909 .57813 m .59887 .58167 L .59717 .58368 L .768 .292 0 r
F
.59909 .57813 m .60082 .57603 L .59887 .58167 L F
.4236 .65177 m .41532 .65032 L .41752 .65118 L .389 0 0 r
F
.42558 .65247 m .4236 .65177 L .41752 .65118 L .379 0 0 r
F
.45069 .65409 m .44322 .65416 L .44466 .6545 L .177 0 0 r
F
.45181 .65429 m .45069 .65409 L .44466 .6545 L .155 0 0 r
F
.52328 .63828 m .5208 .64017 L .51869 .64061 L .46 .27 0 r
F
.52328 .63828 m .5256 .63776 L .5208 .64017 L F
.62349 .52973 m .62479 .53421 L .62384 .53669 L .888 .286 0 r
F
.62349 .52973 m .62443 .52718 L .62479 .53421 L F
.51871 .65738 m .51581 .66095 L .51363 .66092 L .727 .922 0 r
F
.51871 .65738 m .52116 .65735 L .51581 .66095 L F
.57046 .74359 m .56947 .7592 L .56526 .75853 L 1 1 0 r
F
.57046 .74359 m .57516 .7447 L .56947 .7592 L F
.40976 .92315 m .38859 .92017 L .39214 .92148 L .326 0 0 r
F
.41252 .92424 m .40976 .92315 L .39214 .92148 L .294 0 0 r
F
.43013 .92529 m .40976 .92315 L .41252 .92424 L .291 0 0 r
F
.40127 .63101 m .39424 .62711 L .39652 .62824 L 0 .075 0 r
F
.40343 .63199 m .40127 .63101 L .39652 .62824 L 0 .081 0 r
F
.51858 .81149 m .51075 .83192 L .50864 .83219 L 1 1 0 r
F
.51858 .81149 m .52135 .81203 L .51075 .83192 L F
.62369 .46777 m .63198 .47135 L .63271 .47408 L .911 1 0 r
F
.63271 .47408 m .63385 .47216 L .63376 .47481 L F
.63198 .47135 m .63385 .47216 L .63271 .47408 L F
.6283 .46999 m .62369 .46777 L .63376 .47481 L 0 .091 0 r
F
.62867 .47259 m .6283 .46999 L .6336 .47741 L 1 .228 0 r
F
.63361 .47743 m .6336 .47741 L .63363 .47745 L F
.62867 .47259 m .6336 .47741 L .63361 .47743 L F
.72625 .63734 m .72427 .64398 L .72144 .64793 L .708 .215 0 r
F
.72625 .63734 m .72914 .63324 L .72427 .64398 L F
.20883 .81389 m .18817 .80188 L .19321 .80648 L .666 .03 0 r
F
.2136 .81819 m .20883 .81389 L .19321 .80648 L .649 .025 0 r
F
.41097 .64851 m .40265 .64629 L .405 .64737 L .425 0 0 r
F
.41314 .64943 m .41097 .64851 L .405 .64737 L .414 0 0 r
F
.57157 .60687 m .57051 .60961 L .56841 .61108 L .641 .257 0 r
F
.57157 .60687 m .57375 .6053 L .57051 .60961 L F
.60289 .58103 m .60252 .58456 L .60076 .58663 L .751 .244 0 r
F
.60289 .58103 m .60469 .57888 L .60252 .58456 L F
.44322 .65416 m .43545 .65385 L .43719 .65435 L .262 0 0 r
F
.44466 .6545 m .44322 .65416 L .43719 .65435 L .247 0 0 r
F
.44323 .70413 m .43217 .70995 L .43377 .71228 L .458 .021 0 r
F
.4445 .7058 m .44323 .70413 L .43377 .71228 L .45 .023 0 r
F
.4532 .69806 m .44323 .70413 L .4445 .7058 L .268 0 0 r
F
.5943 .73449 m .59325 .74598 L .58884 .7461 L .952 1 0 r
F
.5943 .73449 m .59912 .73459 L .59325 .74598 L F
.62854 .53136 m .62949 .53585 L .62851 .53842 L .865 .213 0 r
F
.62854 .53136 m .62953 .52874 L .62949 .53585 L F
.50924 .66063 m .5059 .66443 L .50401 .66421 L .802 .999 0 r
F
.50924 .66063 m .51144 .66082 L .5059 .66443 L F
.57477 .90074 m .56355 .90359 L .55951 .90477 L 0 0 0 r
F
.5608 .90434 m .55951 .90477 L .55542 .90581 L .211 .175 0 r
F
.56996 .90183 m .56402 .9035 L .5608 .90434 L F
.56402 .9035 m .55951 .90477 L .5608 .90434 L F
.57477 .90074 m .57953 .89949 L .57213 .90139 L 0 0 0 r
F
.56926 .90214 m .57213 .90139 L .56355 .90359 L F
.57477 .90074 m .57213 .90139 L .56926 .90214 L F
.89036 .5489 m .89316 .56161 L .89185 .56846 L .847 .181 0 r
F
.89036 .5489 m .89135 .54192 L .89316 .56161 L F
.9013 .37944 m .90072 .39476 L .90175 .40175 L 0 0 0 r
F
.9013 .37944 m .9001 .37239 L .90072 .39476 L F
.41836 .71242 m .40557 .71628 L .40761 .71979 L .851 .074 0 r
F
.42021 .71526 m .41836 .71242 L .40761 .71979 L .847 .084 0 r
F
.3644 .9082 m .34255 .90331 L .34735 .9053 L .405 0 0 r
F
.36856 .90991 m .3644 .9082 L .34735 .9053 L .376 0 0 r
F
.61712 .58805 m .61787 .59293 L .61597 .59523 L .888 .571 0 r
F
.61712 .58805 m .61899 .58563 L .61787 .59293 L F
.64063 .53212 m .6445 .53794 L .64348 .54075 L 1 .641 0 r
F
.64063 .53212 m .64149 .52926 L .6445 .53794 L F
.57436 .6104 m .57322 .61314 L .57106 .61465 L .63 .234 0 r
F
.57436 .6104 m .57661 .60879 L .57322 .61314 L F
.90532 .37849 m .90616 .39368 L .90778 .40064 L 0 0 0 r
F
.90532 .37849 m .90367 .37149 L .90616 .39368 L F
.49738 .64564 m .49384 .64725 L .49248 .64722 L .428 .315 0 r
F
.49738 .64564 m .49905 .64564 L .49384 .64725 L F
.84544 .6938 m .84068 .70273 L .83722 .70874 L .626 .191 0 r
F
.84544 .6938 m .84896 .68756 L .84068 .70273 L F
.3078 .86989 m .28595 .86383 L .29123 .86688 L .572 0 0 r
F
.31261 .87268 m .3078 .86989 L .29123 .86688 L .553 0 0 r
F
.43771 .64301 m .43054 .64147 L .43245 .64189 L 0 .111 0 r
F
.43937 .6433 m .43771 .64301 L .43245 .64189 L 0 .116 0 r
F
.19897 .8264 m .17868 .81265 L .18387 .81742 L .62 .019 0 r
F
.20393 .83084 m .19897 .8264 L .18387 .81742 L .6 .013 0 r
F
.57758 .91214 m .56583 .91403 L .56172 .91543 L 0 0 0 r
F
.57758 .91214 m .58241 .91064 L .56583 .91403 L F
.36279 .91463 m .34064 .90959 L .34553 .91154 L .39 0 0 r
F
.36702 .91631 m .36279 .91463 L .34553 .91154 L .36 0 0 r
F
.43268 .91902 m .4308 .91813 L .41343 .91741 L .26 0 0 r
F
.5523 .75448 m .55074 .77407 L .54691 .77303 L 1 1 0 r
F
.5523 .75448 m .55667 .75619 L .55074 .77407 L F
.58722 .62173 m .5865 .62565 L .58409 .6273 L .72 .527 0 r
F
.58722 .62173 m .58968 .61995 L .5865 .62565 L F
.37362 .63103 m .36589 .62638 L .36825 .62807 L .472 0 0 r
F
.37588 .63255 m .37362 .63103 L .36825 .62807 L .456 0 0 r
F
.51227 .64161 m .50953 .6434 L .50762 .64361 L .454 .331 0 r
F
.51227 .64161 m .51442 .64134 L .50953 .6434 L F
.54333 .64824 m .54137 .65154 L .53881 .65211 L .612 .697 0 r
F
.54333 .64824 m .54607 .64756 L .54137 .65154 L F
.39438 .88942 m .37366 .88864 L .37757 .89054 L .472 0 0 r
F
.3976 .89114 m .39438 .88942 L .37757 .89054 L .453 0 0 r
F
.67278 .69537 m .67047 .7015 L .66662 .70417 L .658 .346 0 r
F
.67278 .69537 m .67683 .69258 L .67047 .7015 L F
.59731 .5802 m .59717 .58368 L .59542 .58566 L .768 .32 0 r
F
.59731 .5802 m .59909 .57813 L .59717 .58368 L F
.62251 .53226 m .62384 .53669 L .62284 .53917 L .89 .314 0 r
F
.62251 .53226 m .62349 .52973 L .62384 .53669 L F
.9109 .55225 m .90682 .56424 L .90563 .57134 L 0 0 0 r
F
.9109 .55225 m .91212 .54496 L .90682 .56424 L F
.57893 .91765 m .56696 .91924 L .56281 .92067 L F
.57893 .91765 m .58382 .9161 L .56696 .91924 L F
.1941 .83258 m .17329 .81875 L .17865 .82354 L .611 .016 0 r
F
.1992 .83704 m .1941 .83258 L .17865 .82354 L .589 .01 0 r
F
.43205 .92618 m .43013 .92529 L .41252 .92424 L .257 0 0 r
F
.38322 .62088 m .37681 .61583 L .37903 .6173 L 0 .058 0 r
F
.38536 .62221 m .38322 .62088 L .37903 .6173 L 0 .064 0 r
F
.42863 .64101 m .42141 .63889 L .42352 .63949 L 0 .102 0 r
F
.43054 .64147 m .42863 .64101 L .42352 .63949 L 0 .108 0 r
F
.6283 .46999 m .63376 .47481 L .63363 .47745 L 0 .091 0 r
F
.77708 .78589 m .77019 .79204 L .76542 .79682 L 0 0 0 r
F
.77708 .78589 m .78209 .78087 L .77019 .79204 L F
.41723 .63757 m .41005 .6347 L .4123 .63553 L 0 .092 0 r
F
.41931 .63825 m .41723 .63757 L .4123 .63553 L 0 .097 0 r
F
.85801 .70097 m .85123 .70908 L .84771 .71529 L 0 0 0 r
F
.85801 .70097 m .86169 .69453 L .85123 .70908 L F
.53441 .63387 m .53244 .63589 L .53018 .63657 L .493 .272 0 r
F
.53441 .63387 m .53684 .63311 L .53244 .63589 L F
.34063 .66899 m .33041 .66278 L .33229 .66642 L 1 .107 0 r
F
.34257 .67233 m .34063 .66899 L .33229 .66642 L 1 .119 0 r
F
.53911 .7699 m .53613 .79214 L .5328 .79126 L 1 1 0 r
F
.53911 .7699 m .54303 .77165 L .53613 .79214 L F
.39574 .64287 m .38761 .63968 L .39004 .64102 L .444 0 0 r
F
.39802 .64404 m .39574 .64287 L .39004 .64102 L .431 0 0 r
F
.75922 .42749 m .76664 .43629 L .76763 .44102 L .864 .128 0 r
F
.75922 .42749 m .75792 .4229 L .76664 .43629 L F
.5991 .89342 m .6044 .8918 L .5889 .89657 L .21 .174 0 r
F
.5991 .89342 m .5889 .89657 L .58424 .8981 L F
.60105 .58316 m .60076 .58663 L .59896 .58866 L .752 .273 0 r
F
.60105 .58316 m .60289 .58103 L .60076 .58663 L F
.6275 .53397 m .62851 .53842 L .62748 .54096 L .868 .241 0 r
F
.6275 .53397 m .62854 .53136 L .62851 .53842 L F
.43217 .70995 m .42021 .71526 L .42206 .71831 L .68 .053 0 r
F
.43377 .71228 m .43217 .70995 L .42206 .71831 L .675 .055 0 r
F
.50376 .64388 m .50071 .64558 L .49905 .64564 L .449 .357 0 r
F
.50376 .64388 m .5057 .64378 L .50071 .64558 L F
.62931 .88264 m .61994 .88608 L .61482 .88812 L 0 0 0 r
F
.62931 .88264 m .63499 .88047 L .61994 .88608 L F
.52833 .65365 m .52602 .65705 L .5236 .65724 L .673 .849 0 r
F
.52833 .65365 m .53098 .65338 L .52602 .65705 L F
.30052 .88721 m .27854 .87913 L .2841 .88216 L .486 0 0 r
F
.30562 .88993 m .30052 .88721 L .2841 .88216 L .461 0 0 r
F
.56936 .6084 m .56841 .61108 L .56627 .61252 L .641 .288 0 r
F
.56936 .6084 m .57157 .60687 L .56841 .61108 L F
.76459 .54357 m .76565 .55213 L .7644 .5569 L .83 .191 0 r
F
.76459 .54357 m .76575 .53869 L .76565 .55213 L F
.78615 .79495 m .7782 .80039 L .77334 .80534 L 0 0 0 r
F
.78615 .79495 m .79128 .78976 L .7782 .80039 L F
.26556 .85071 m .24404 .84219 L .24941 .84589 L .607 .009 0 r
F
.27054 .85412 m .26556 .85071 L .24941 .84589 L .589 .004 0 r
F
.36473 .69328 m .35266 .69018 L .35474 .69406 L 1 .24 0 r
F
.36682 .69674 m .36473 .69328 L .35474 .69406 L 1 .264 0 r
F
.29788 .89349 m .27555 .88532 L .28123 .88832 L .471 0 0 r
F
.30308 .89619 m .29788 .89349 L .28123 .88832 L .445 0 0 r
F
.63972 .53497 m .64348 .54075 L .64242 .54354 L 1 .651 0 r
F
.63972 .53497 m .64063 .53212 L .64348 .54075 L F
.60269 .90502 m .59191 .90725 L .58719 .90901 L 0 0 0 r
F
.60269 .90502 m .60806 .90313 L .59191 .90725 L F
.61519 .59044 m .61597 .59523 L .61401 .5975 L .889 .59 0 r
F
.61519 .59044 m .61712 .58805 L .61597 .59523 L F
.40343 .63199 m .39652 .62824 L .39883 .62933 L 0 .081 0 r
F
.40561 .63294 m .40343 .63199 L .39883 .62933 L 0 .086 0 r
F
.55017 .62628 m .54864 .62853 L .54633 .62954 L .544 .259 0 r
F
.55017 .62628 m .55261 .62517 L .54864 .62853 L F
.43545 .65385 m .42756 .65315 L .42957 .6538 L .326 0 0 r
F
.43719 .65435 m .43545 .65385 L .42957 .6538 L .318 0 0 r
F
.38983 .91357 m .36856 .90991 L .37277 .91151 L .363 0 0 r
F
.39332 .91491 m .38983 .91357 L .37277 .91151 L .333 0 0 r
F
.63381 .89409 m .62382 .89669 L .61863 .89896 L 0 0 0 r
F
.63381 .89409 m .63957 .89166 L .62382 .89669 L F
.62148 .53478 m .62284 .53917 L .6218 .54162 L .891 .341 0 r
F
.62148 .53478 m .62251 .53226 L .62284 .53917 L F
.40355 .71298 m .39042 .7152 L .39256 .71912 L .983 .185 0 r
F
.40557 .71628 m .40355 .71298 L .39256 .71912 L .981 .206 0 r
F
.45288 .64486 m .44624 .64428 L .44763 .6444 L 0 .133 0 r
F
.45396 .64487 m .45288 .64486 L .44763 .6444 L .007 .139 0 r
F
.57208 .61196 m .57106 .61465 L .56886 .61612 L .631 .266 0 r
F
.57208 .61196 m .57436 .6104 L .57106 .61465 L F
.60443 .91065 m .59342 .9126 L .58865 .91441 L 0 0 0 r
F
.60443 .91065 m .60986 .90869 L .59342 .9126 L F
.59549 .58224 m .59542 .58566 L .59363 .58761 L .768 .349 0 r
F
.59549 .58224 m .59731 .5802 L .59542 .58566 L F
.52094 .63874 m .51869 .64061 L .51657 .641 L .476 .339 0 r
F
.52094 .63874 m .52328 .63828 L .51869 .64061 L F
.44624 .64428 m .43937 .6433 L .44105 .64355 L 0 .123 0 r
F
.44763 .6444 m .44624 .64428 L .44105 .64355 L 0 .129 0 r
F
.63599 .89967 m .62579 .90206 L .62054 .90439 L 0 0 0 r
F
.63599 .89967 m .64181 .89716 L .62579 .90206 L F
.38859 .92017 m .36702 .91631 L .37131 .91787 L .35 0 0 r
F
.39214 .92148 m .38859 .92017 L .37131 .91787 L .318 0 0 r
F
.62867 .47259 m .63363 .47745 L .63349 .4801 L 1 .228 0 r
F
.72327 .64139 m .72144 .64793 L .71853 .65181 L .711 .217 0 r
F
.72327 .64139 m .72625 .63734 L .72144 .64793 L F
.42558 .65247 m .41752 .65118 L .41974 .65203 L .379 0 0 r
F
.42756 .65315 m .42558 .65247 L .41974 .65203 L .371 0 0 r
F
.25708 .86594 m .23564 .85555 L .24124 .85932 L .539 0 0 r
F
.26233 .8694 m .25708 .86594 L .24124 .85932 L .515 0 0 r
F
.58472 .62346 m .58409 .6273 L .58164 .6289 L .717 .554 0 r
F
.58472 .62346 m .58722 .62173 L .58409 .6273 L F
.41314 .64943 m .405 .64737 L .40738 .64842 L .414 0 0 r
F
.41532 .65032 m .41314 .64943 L .40738 .64842 L .405 0 0 r
F
.62642 .53656 m .62748 .54096 L .6264 .54349 L .871 .27 0 r
F
.62642 .53656 m .6275 .53397 L .62748 .54096 L F
.37588 .63255 m .36825 .62807 L .37064 .62972 L .456 0 0 r
F
.37817 .63404 m .37588 .63255 L .37064 .62972 L .441 0 0 r
F
.59917 .58525 m .59896 .58866 L .59711 .59066 L .753 .302 0 r
F
.59917 .58525 m .60105 .58316 L .59896 .58866 L F
.38536 .62221 m .37903 .6173 L .38129 .61872 L 0 .064 0 r
F
.38754 .62349 m .38536 .62221 L .38129 .61872 L 0 .069 0 r
F
.2536 .8722 m .23175 .86174 L .23749 .86549 L .526 0 0 r
F
.25897 .87565 m .2536 .8722 L .23749 .86549 L .502 0 0 r
F
.51625 .65732 m .51363 .66092 L .51144 .66082 L .765 .972 0 r
F
.51625 .65732 m .51871 .65738 L .51363 .66092 L F
.50019 .66355 m .49658 .66765 L .49501 .66728 L .891 1 0 r
F
.50019 .66355 m .5021 .66392 L .49658 .66765 L F
.63592 .47223 m .6388 .47735 L .63877 .48008 L .912 .174 0 r
F
.38618 .70798 m .37322 .7079 L .37538 .71197 L 1 .257 0 r
F
.38829 .71149 m .38618 .70798 L .37538 .71197 L 1 .279 0 r
F
.56712 .6099 m .56627 .61252 L .5641 .61391 L .642 .319 0 r
F
.56712 .6099 m .56936 .6084 L .56627 .61252 L F
.63875 .53782 m .64242 .54354 L .64132 .54632 L 1 .662 0 r
F
.63875 .53782 m .63972 .53497 L .64242 .54354 L F
.66546 .8666 m .65699 .87043 L .6516 .87313 L 0 0 0 r
F
.66546 .8666 m .67132 .86372 L .65699 .87043 L F
.6204 .53728 m .6218 .54162 L .62071 .54406 L .899 .369 0 r
F
.6204 .53728 m .62148 .53478 L .6218 .54162 L F
.45181 .65429 m .44466 .6545 L .44612 .65482 L .155 0 0 r
F
.45294 .65447 m .45181 .65429 L .44612 .65482 L .137 0 0 r
F
.54056 .64884 m .53881 .65211 L .53622 .65261 L .628 .747 0 r
F
.54056 .64884 m .54333 .64824 L .53881 .65211 L F
.34392 .88197 m .32242 .878 L .32742 .88051 L .533 0 0 r
F
.34836 .88426 m .34392 .88197 L .32742 .88051 L .515 0 0 r
F
.61322 .59279 m .61401 .5975 L .61202 .59973 L .889 .61 0 r
F
.61322 .59279 m .61519 .59044 L .61401 .5975 L F
.53196 .63457 m .53018 .63657 L .5279 .63719 L .503 .328 0 r
F
.53196 .63457 m .53441 .63387 L .53018 .63657 L F
.59363 .58425 m .59363 .58761 L .59181 .58953 L .767 .378 0 r
F
.59363 .58425 m .59549 .58224 L .59363 .58761 L F
.44466 .6545 m .43719 .65435 L .43895 .65482 L .247 0 0 r
F
.44612 .65482 m .44466 .6545 L .43895 .65482 L .236 0 0 r
F
.41931 .63825 m .4123 .63553 L .41457 .63631 L 0 .097 0 r
F
.42141 .63889 m .41931 .63825 L .41457 .63631 L 0 .103 0 r
F
.39802 .64404 m .39004 .64102 L .3925 .64232 L .431 0 0 r
F
.40032 .64518 m .39802 .64404 L .3925 .64232 L .419 0 0 r
F
.88926 .55587 m .89185 .56846 L .89044 .5753 L .845 .183 0 r
F
.88926 .55587 m .89036 .5489 L .89185 .56846 L F
.62885 .47522 m .63349 .4801 L .63331 .48274 L 1 .295 0 r
F
.62885 .47522 m .62867 .47259 L .63349 .4801 L F
.51009 .64183 m .50762 .64361 L .5057 .64378 L .475 .411 0 r
F
.51009 .64183 m .51227 .64161 L .50762 .64361 L F
.66865 .69804 m .66662 .70417 L .66268 .70673 L .663 .414 0 r
F
.66865 .69804 m .67278 .69537 L .66662 .70417 L F
.7604 .43213 m .76763 .44102 L .76851 .44578 L .872 .133 0 r
F
.7604 .43213 m .75922 .42749 L .76763 .44102 L F
.43937 .6433 m .43245 .64189 L .43438 .64227 L 0 .116 0 r
F
.44105 .64355 m .43937 .6433 L .43438 .64227 L 0 .122 0 r
F
.50702 .66037 m .50401 .66421 L .5021 .66392 L .846 1 0 r
F
.50702 .66037 m .50924 .66063 L .50401 .66421 L F
.56977 .61349 m .56886 .61612 L .56663 .61754 L .632 .299 0 r
F
.56977 .61349 m .57208 .61196 L .56886 .61612 L F
.90229 .38654 m .90175 .40175 L .90257 .40876 L 0 0 0 r
F
.90229 .38654 m .9013 .37944 L .90175 .40175 L F
.67101 .87764 m .66189 .88072 L .65642 .88364 L F
.67101 .87764 m .67696 .87454 L .66189 .88072 L F
.43054 .64147 m .42352 .63949 L .42565 .64005 L 0 .108 0 r
F
.43245 .64189 m .43054 .64147 L .42565 .64005 L 0 .113 0 r
F
.34257 .67233 m .33229 .66642 L .3342 .67015 L 1 .119 0 r
F
.34454 .67574 m .34257 .67233 L .3342 .67015 L 1 .141 0 r
F
.54771 .62734 m .54633 .62954 L .54399 .63051 L .549 .301 0 r
F
.54771 .62734 m .55017 .62628 L .54633 .62954 L F
.62529 .53914 m .6264 .54349 L .62528 .546 L .873 .3 0 r
F
.62529 .53914 m .62642 .53656 L .6264 .54349 L F
.48362 .93092 m .46677 .93056 L .46688 .93122 L .158 0 0 r
F
.48362 .93092 m .48445 .93027 L .46677 .93056 L F
.76334 .54843 m .7644 .5569 L .76305 .56164 L .833 .194 0 r
F
.76334 .54843 m .76459 .54357 L .7644 .5569 L F
.58939 .73409 m .58884 .7461 L .58435 .74594 L .956 1 0 r
F
.58939 .73409 m .5943 .73449 L .58884 .7461 L F
.40561 .63294 m .39883 .62933 L .40117 .63038 L 0 .086 0 r
F
.40782 .63384 m .40561 .63294 L .40117 .63038 L 0 .091 0 r
F
.90684 .38554 m .90778 .40064 L .90927 .40765 L 0 0 0 r
F
.90684 .38554 m .90532 .37849 L .90778 .40064 L F
.4957 .64559 m .49248 .64722 L .49111 .64713 L .459 .412 0 r
F
.4957 .64559 m .49738 .64564 L .49248 .64722 L F
.6737 .88298 m .66438 .88595 L .65885 .88893 L 0 0 0 r
F
.6737 .88298 m .67971 .87981 L .66438 .88595 L F
.55802 .64082 m .55678 .64414 L .55414 .64509 L .638 .631 0 r
F
.55802 .64082 m .56078 .63973 L .55678 .64414 L F
.59725 .58731 m .59711 .59066 L .59523 .59264 L .753 .332 0 r
F
.59725 .58731 m .59917 .58525 L .59711 .59066 L F
.56571 .74213 m .56526 .75853 L .561 .75753 L 1 1 0 r
F
.56571 .74213 m .57046 .74359 L .56526 .75853 L F
.84179 .69999 m .83722 .70874 L .83365 .71469 L .631 .193 0 r
F
.84179 .69999 m .84544 .6938 L .83722 .70874 L F
.63585 .47498 m .63877 .48008 L .63869 .48281 L .919 .178 0 r
F
.63585 .47498 m .63592 .47223 L .63877 .48008 L F
.90955 .55953 m .90563 .57134 L .90432 .57844 L 0 0 0 r
F
.90955 .55953 m .9109 .55225 L .90563 .57134 L F
.58218 .62515 m .58164 .6289 L .57915 .63045 L .714 .581 0 r
F
.58218 .62515 m .58472 .62346 L .58164 .6289 L F
.52566 .65383 m .5236 .65724 L .52116 .65735 L .704 .899 0 r
F
.52566 .65383 m .52833 .65365 L .5236 .65724 L F
.55129 .90671 m .53946 .90925 L .53611 .91011 L 0 0 0 r
F
.53912 .90933 m .53611 .91011 L .53273 .91084 L .191 .173 0 r
F
.54712 .90745 m .54122 .90888 L .53912 .90933 L F
.54122 .90888 m .53611 .91011 L .53912 .90933 L F
.55129 .90671 m .55542 .90581 L .54695 .90763 L 0 0 0 r
F
.54509 .90804 m .54695 .90763 L .53946 .90925 L F
.55129 .90671 m .54695 .90763 L .54509 .90804 L F
.61927 .53977 m .62071 .54406 L .61958 .54648 L .907 .397 0 r
F
.61927 .53977 m .6204 .53728 L .62071 .54406 L F
.33781 .90121 m .31602 .89505 L .32132 .89744 L .429 0 0 r
F
.34255 .90331 m .33781 .90121 L .32132 .89744 L .402 0 0 r
F
.2136 .81819 m .19321 .80648 L .19834 .811 L .649 .025 0 r
F
.21846 .8224 m .2136 .81819 L .19834 .811 L .631 .019 0 r
F
.63773 .54065 m .64132 .54632 L .64017 .54908 L 1 .674 0 r
F
.63773 .54065 m .63875 .53782 L .64132 .54632 L F
.38754 .62349 m .38129 .61872 L .38357 .62011 L 0 .069 0 r
F
.38975 .62474 m .38754 .62349 L .38357 .62011 L 0 .074 0 r
F
.37817 .63404 m .37064 .62972 L .37306 .63133 L .441 0 0 r
F
.38049 .6355 m .37817 .63404 L .37306 .63133 L .427 0 0 r
F
.53423 .92136 m .52088 .92257 L .51829 .92342 L .015 0 0 r
F
.53423 .92136 m .53767 .92044 L .52088 .92257 L F
.50181 .64393 m .49905 .64564 L .49738 .64564 L .475 .446 0 r
F
.50181 .64393 m .50376 .64388 L .49905 .64564 L F
.50013 .93015 m .48445 .93027 L .48362 .93092 L .119 0 0 r
F
.50013 .93015 m .50188 .92947 L .48445 .93027 L F
.63656 .47219 m .65178 .4771 L .65092 .48005 L 1 .288 0 r
F
.56484 .61136 m .56712 .6099 L .5641 .61391 L .642 .35 0 r
F
.51858 .63914 m .51657 .641 L .51442 .64134 L .491 .409 0 r
F
.51858 .63914 m .52094 .63874 L .51657 .641 L F
.62891 .47785 m .63331 .48274 L .63312 .48538 L 1 .325 0 r
F
.62891 .47785 m .62885 .47522 L .63331 .48274 L F
.59174 .58623 m .59181 .58953 L .58994 .59142 L .766 .405 0 r
F
.59174 .58623 m .59363 .58425 L .59181 .58953 L F
.3358 .90752 m .3137 .90124 L .31911 .9036 L .413 0 0 r
F
.34064 .90959 m .3358 .90752 L .31911 .9036 L .384 0 0 r
F
.7202 .64537 m .71853 .65181 L .71553 .65563 L .714 .22 0 r
F
.7202 .64537 m .72327 .64139 L .71853 .65181 L F
.53495 .92641 m .52141 .92731 L .51879 .92818 L .044 0 0 r
F
.53495 .92641 m .53842 .92547 L .52141 .92731 L F
.42021 .71526 m .40761 .71979 L .40965 .72358 L .847 .084 0 r
F
.42206 .71831 m .42021 .71526 L .40965 .72358 L .843 .104 0 r
F
.85422 .70735 m .84771 .71529 L .84407 .72143 L 0 0 0 r
F
.85422 .70735 m .85801 .70097 L .84771 .71529 L F
.55337 .91782 m .54107 .91939 L .53767 .92044 L F
.55337 .91782 m .55757 .91669 L .54107 .91939 L F
.61119 .59511 m .61202 .59973 L .60998 .60193 L .889 .629 0 r
F
.61119 .59511 m .61322 .59279 L .61202 .59973 L F
.4445 .7058 m .43377 .71228 L .43537 .71483 L .45 .023 0 r
F
.44578 .70761 m .4445 .7058 L .43537 .71483 L .444 .027 0 r
F
.36682 .69674 m .35474 .69406 L .35684 .69808 L 1 .264 0 r
F
.36894 .70031 m .36682 .69674 L .35684 .69808 L 1 .289 0 r
F
.62411 .5417 m .62528 .546 L .6241 .5485 L .875 .33 0 r
F
.62411 .5417 m .62529 .53914 L .62528 .546 L F
.55437 .92315 m .54186 .9244 L .53842 .92547 L .005 0 0 r
F
.55437 .92315 m .55861 .92197 L .54186 .9244 L F
.43719 .65435 m .42957 .6538 L .43159 .65444 L .318 0 0 r
F
.43895 .65482 m .43719 .65435 L .43159 .65444 L .312 0 0 r
F
.41532 .65032 m .40738 .64842 L .40977 .64945 L .405 0 0 r
F
.41752 .65118 m .41532 .65032 L .40977 .64945 L .399 0 0 r
F
.56742 .61497 m .56663 .61754 L .56437 .61893 L .633 .332 0 r
F
.56742 .61497 m .56977 .61349 L .56663 .61754 L F
.77198 .79081 m .76542 .79682 L .76055 .8015 L 0 0 0 r
F
.77198 .79081 m .77708 .78589 L .76542 .79682 L F
.20393 .83084 m .18387 .81742 L .18916 .8221 L .6 .013 0 r
F
.20899 .8352 m .20393 .83084 L .18916 .8221 L .578 .007 0 r
F
.42756 .65315 m .41974 .65203 L .42198 .65285 L .371 0 0 r
F
.42957 .6538 m .42756 .65315 L .42198 .65285 L .367 0 0 r
F
.59529 .58934 m .59523 .59264 L .59331 .59457 L .753 .361 0 r
F
.59529 .58934 m .59725 .58731 L .59523 .59264 L F
.44763 .6444 m .44105 .64355 L .44274 .64375 L 0 .129 0 r
F
.44904 .64449 m .44763 .6444 L .44274 .64375 L 0 .134 0 r
F
.45396 .64487 m .44763 .6444 L .44904 .64449 L .007 .139 0 r
F
.63572 .47773 m .63869 .48281 L .63855 .48555 L .927 .184 0 r
F
.63572 .47773 m .63585 .47498 L .63869 .48281 L F
.6181 .54224 m .61958 .54648 L .6184 .54888 L .915 .424 0 r
F
.6181 .54224 m .61927 .53977 L .61958 .54648 L F
.52948 .63522 m .5279 .63719 L .5256 .63776 L .513 .385 0 r
F
.52948 .63522 m .53196 .63457 L .5279 .63719 L F
.53777 .64936 m .53622 .65261 L .53361 .65304 L .648 .794 0 r
F
.53777 .64936 m .54056 .64884 L .53622 .65261 L F
.54522 .62835 m .54399 .63051 L .54163 .63143 L .553 .344 0 r
F
.54522 .62835 m .54771 .62734 L .54399 .63051 L F
.1992 .83704 m .17865 .82354 L .1841 .82823 L .589 .01 0 r
F
.20439 .84141 m .1992 .83704 L .1841 .82823 L .568 .004 0 r
F
.40032 .64518 m .3925 .64232 L .39497 .64359 L .419 0 0 r
F
.40265 .64629 m .40032 .64518 L .39497 .64359 L .41 0 0 r
F
.54789 .7524 m .54691 .77303 L .54303 .77165 L 1 1 0 r
F
.54789 .7524 m .5523 .75448 L .54691 .77303 L F
.63666 .54347 m .64017 .54908 L .63897 .55183 L 1 .686 0 r
F
.63666 .54347 m .63773 .54065 L .64017 .54908 L F
.63756 .47492 m .65092 .48005 L .6502 .48297 L 1 .46 0 r
F
.63756 .47492 m .63656 .47219 L .65092 .48005 L F
.42141 .63889 m .41457 .63631 L .41686 .63706 L 0 .103 0 r
F
.42352 .63949 m .42141 .63889 L .41686 .63706 L 0 .108 0 r
F
.52604 .7885 m .52135 .81203 L .51858 .81149 L 1 1 0 r
F
.52604 .7885 m .52944 .79005 L .52135 .81203 L F
.62888 .4805 m .63312 .48538 L .63289 .48803 L 1 .347 0 r
F
.62888 .4805 m .62891 .47785 L .63312 .48538 L F
.78092 .80004 m .77334 .80534 L .76838 .8102 L 0 0 0 r
F
.78092 .80004 m .78615 .79495 L .77334 .80534 L F
.51377 .65718 m .51144 .66082 L .50924 .66063 L .802 1 0 r
F
.51377 .65718 m .51625 .65732 L .51144 .66082 L F
.76145 .43681 m .76851 .44578 L .76929 .45057 L .879 .137 0 r
F
.76145 .43681 m .7604 .43213 L .76851 .44578 L F
.4869 .67038 m .48231 .67528 L .48151 .67491 L .957 1 0 r
F
.5796 .62678 m .57915 .63045 L .57663 .63194 L .711 .607 0 r
F
.5796 .62678 m .58218 .62515 L .57915 .63045 L F
.40782 .63384 m .40117 .63038 L .40353 .6314 L 0 .091 0 r
F
.41005 .6347 m .40782 .63384 L .40353 .6314 L 0 .096 0 r
F
.58981 .58818 m .58994 .59142 L .58804 .59328 L .765 .433 0 r
F
.58981 .58818 m .59174 .58623 L .58994 .59142 L F
.55524 .64183 m .55414 .64509 L .55148 .64599 L .638 .669 0 r
F
.55524 .64183 m .55802 .64082 L .55414 .64509 L F
.76198 .55327 m .76305 .56164 L .76162 .56636 L .836 .197 0 r
F
.76198 .55327 m .76334 .54843 L .76305 .56164 L F
.43377 .71228 m .42206 .71831 L .42393 .72163 L .675 .055 0 r
F
.43537 .71483 m .43377 .71228 L .42393 .72163 L .671 .058 0 r
F
.40557 .71628 m .39256 .71912 L .39472 .72331 L .981 .206 0 r
F
.40761 .71979 m .40557 .71628 L .39472 .72331 L .978 .227 0 r
F
.38975 .62474 m .38357 .62011 L .38589 .62147 L 0 .074 0 r
F
.39198 .62594 m .38975 .62474 L .38589 .62147 L 0 .08 0 r
F
.62288 .54424 m .6241 .5485 L .62288 .55097 L .876 .36 0 r
F
.62288 .54424 m .62411 .5417 L .6241 .5485 L F
.60913 .5974 m .60998 .60193 L .60789 .6041 L .889 .648 0 r
F
.60913 .5974 m .61119 .59511 L .60998 .60193 L F
.34454 .67574 m .3342 .67015 L .33614 .67395 L 1 .141 0 r
F
.34653 .67922 m .34454 .67574 L .33614 .67395 L 1 .166 0 r
F
.38049 .6355 m .37306 .63133 L .37551 .63292 L .427 0 0 r
F
.38284 .63693 m .38049 .6355 L .37551 .63292 L .413 0 0 r
F
.66443 .70059 m .66268 .70673 L .65866 .70916 L .666 .482 0 r
F
.66443 .70059 m .66865 .69804 L .66268 .70673 L F
.43245 .64189 m .42565 .64005 L .4278 .64057 L 0 .113 0 r
F
.43438 .64227 m .43245 .64189 L .4278 .64057 L 0 .118 0 r
F
.50791 .642 m .5057 .64378 L .50376 .64388 L .496 .49 0 r
F
.50791 .642 m .51009 .64183 L .5057 .64378 L F
.44105 .64355 m .43438 .64227 L .43633 .64261 L 0 .122 0 r
F
.44274 .64375 m .44105 .64355 L .43633 .64261 L 0 .127 0 r
F
.49828 .6631 m .49501 .66728 L .49344 .66683 L .94 1 0 r
F
.49828 .6631 m .50019 .66355 L .49501 .66728 L F
.61689 .54469 m .6184 .54888 L .61717 .55127 L .923 .452 0 r
F
.61689 .54469 m .6181 .54224 L .6184 .54888 L F
.59329 .59134 m .59331 .59457 L .59136 .59648 L .752 .39 0 r
F
.59329 .59134 m .59529 .58934 L .59331 .59457 L F
.63554 .48049 m .63855 .48555 L .63837 .48828 L .944 .213 0 r
F
.63554 .48049 m .63572 .47773 L .63855 .48555 L F
.88805 .56285 m .89044 .5753 L .88892 .58212 L .843 .185 0 r
F
.88805 .56285 m .88926 .55587 L .89044 .5753 L F
.31261 .87268 m .29123 .86688 L .29658 .86984 L .553 0 0 r
F
.31748 .87539 m .31261 .87268 L .29658 .86984 L .535 0 0 r
F
.56504 .61641 m .56742 .61497 L .56437 .61893 L .633 .365 0 r
F
.38829 .71149 m .37538 .71197 L .37756 .71625 L 1 .279 0 r
F
.39042 .7152 m .38829 .71149 L .37756 .71625 L 1 .301 0 r
F
.45294 .65447 m .44612 .65482 L .44758 .65512 L .137 0 0 r
F
.45407 .65462 m .45294 .65447 L .44758 .65512 L .122 0 0 r
F
.41704 .89024 m .3976 .89114 L .40086 .89277 L .409 0 0 r
F
.41954 .89171 m .41704 .89024 L .40086 .89277 L .389 0 0 r
F
.43545 .88766 m .41704 .89024 L .41954 .89171 L .334 0 0 r
F
.44612 .65482 m .43895 .65482 L .44071 .65528 L .236 0 0 r
F
.44758 .65512 m .44612 .65482 L .44071 .65528 L .229 0 0 r
F
.27054 .85412 m .24941 .84589 L .25485 .84949 L .589 .004 0 r
F
.2756 .85745 m .27054 .85412 L .25485 .84949 L .57 0 0 r
F
.37366 .88864 m .35286 .88645 L .35741 .88855 L .494 0 0 r
F
.37757 .89054 m .37366 .88864 L .35741 .88855 L .475 0 0 r
F
.52298 .65393 m .52116 .65735 L .51871 .65738 L .733 .942 0 r
F
.52298 .65393 m .52566 .65383 L .52116 .65735 L F
.90305 .39368 m .90257 .40876 L .90318 .41581 L 0 0 0 r
F
.90305 .39368 m .90229 .38654 L .90257 .40876 L F
.53516 .76778 m .5328 .79126 L .52944 .79005 L 1 1 0 r
F
.53516 .76778 m .53911 .7699 L .5328 .79126 L F
.5048 .66002 m .5021 .66392 L .50019 .66355 L .887 1 0 r
F
.5048 .66002 m .50702 .66037 L .5021 .66392 L F
.62879 .48315 m .63289 .48803 L .63263 .49067 L 1 .367 0 r
F
.62879 .48315 m .62888 .4805 L .63289 .48803 L F
.63828 .47769 m .6502 .48297 L .6496 .48588 L 1 .536 0 r
F
.63828 .47769 m .63756 .47492 L .6502 .48297 L F
.63553 .54628 m .63897 .55183 L .63773 .55456 L 1 .699 0 r
F
.63553 .54628 m .63666 .54347 L .63897 .55183 L F
.51621 .63948 m .51442 .64134 L .51227 .64161 L .506 .478 0 r
F
.51621 .63948 m .51858 .63914 L .51442 .64134 L F
.71704 .64929 m .71553 .65563 L .71245 .65938 L .717 .222 0 r
F
.71704 .64929 m .7202 .64537 L .71553 .65563 L F
.58783 .59009 m .58804 .59328 L .58611 .5951 L .764 .46 0 r
F
.58783 .59009 m .58981 .58818 L .58804 .59328 L F
.51579 .81067 m .50864 .83219 L .50651 .83226 L 1 1 0 r
F
.51579 .81067 m .51858 .81149 L .50864 .83219 L F
.49402 .64548 m .49111 .64713 L .48974 .64699 L .49 .509 0 r
F
.49402 .64548 m .4957 .64559 L .49111 .64713 L F
.90822 .39264 m .90927 .40765 L .91062 .41469 L 0 0 0 r
F
.90822 .39264 m .90684 .38554 L .90927 .40765 L F
.6216 .54677 m .62288 .55097 L .62161 .55342 L .881 .39 0 r
F
.6216 .54677 m .62288 .54424 L .62288 .55097 L F
.90805 .5668 m .90432 .57844 L .90286 .58551 L 0 0 0 r
F
.90805 .5668 m .90955 .55953 L .90432 .57844 L F
.5427 .62931 m .54163 .63143 L .53925 .63229 L .557 .388 0 r
F
.5427 .62931 m .54522 .62835 L .54163 .63143 L F
.58441 .73337 m .58435 .74594 L .57979 .74548 L .955 1 0 r
F
.58441 .73337 m .58939 .73409 L .58435 .74594 L F
.49985 .64393 m .49738 .64564 L .4957 .64559 L .501 .533 0 r
F
.49985 .64393 m .50181 .64393 L .49738 .64564 L F
.57698 .62836 m .5796 .62678 L .57663 .63194 L .711 .633 0 r
F
.83803 .70613 m .83365 .71469 L .82997 .72058 L .635 .196 0 r
F
.83803 .70613 m .84179 .69999 L .83365 .71469 L F
.41752 .65118 m .40977 .64945 L .41218 .65047 L .399 0 0 r
F
.41974 .65203 m .41752 .65118 L .41218 .65047 L .396 0 0 r
F
.51567 .92414 m .50157 .925 L .49984 .92568 L .047 0 0 r
F
.51567 .92414 m .51829 .92342 L .50157 .925 L F
.60701 .59964 m .60789 .6041 L .60576 .60622 L .889 .666 0 r
F
.60701 .59964 m .60913 .5974 L .60789 .6041 L F
.52699 .63582 m .5256 .63776 L .52328 .63828 L .522 .443 0 r
F
.52699 .63582 m .52948 .63522 L .5256 .63776 L F
.61562 .54713 m .61717 .55127 L .6159 .55363 L .93 .479 0 r
F
.61562 .54713 m .61689 .54469 L .61717 .55127 L F
.30562 .88993 m .2841 .88216 L .28973 .88508 L .461 0 0 r
F
.31079 .89255 m .30562 .88993 L .28973 .88508 L .434 0 0 r
F
.39198 .62594 m .38589 .62147 L .38823 .62278 L 0 .08 0 r
F
.39424 .62711 m .39198 .62594 L .38823 .62278 L 0 .084 0 r
F
.63531 .48325 m .63837 .48828 L .63813 .49101 L .961 .244 0 r
F
.63531 .48325 m .63554 .48049 L .63837 .48828 L F
.26233 .8694 m .24124 .85932 L .24693 .86299 L .515 0 0 r
F
.26765 .87275 m .26233 .8694 L .24693 .86299 L .491 0 0 r
F
.40265 .64629 m .39497 .64359 L .39747 .64484 L .41 0 0 r
F
.405 .64737 m .40265 .64629 L .39747 .64484 L .402 0 0 r
F
.59125 .5933 m .59136 .59648 L .58936 .59835 L .751 .419 0 r
F
.59125 .5933 m .59329 .59134 L .59136 .59648 L F
.53495 .6498 m .53361 .65304 L .53098 .65338 L .668 .838 0 r
F
.53495 .6498 m .53777 .64936 L .53361 .65304 L F
.62357 .88467 m .61482 .88812 L .60964 .89003 L .265 .182 0 r
F
.62357 .88467 m .62931 .88264 L .61482 .88812 L F
.51615 .92891 m .50188 .92947 L .50013 .93015 L .071 0 0 r
F
.51615 .92891 m .51879 .92818 L .50188 .92947 L F
.41005 .6347 m .40353 .6314 L .40591 .63237 L 0 .096 0 r
F
.4123 .63553 m .41005 .6347 L .40591 .63237 L 0 .101 0 r
F
.55242 .64278 m .55148 .64599 L .54879 .64681 L .641 .706 0 r
F
.55242 .64278 m .55524 .64183 L .55148 .64599 L F
.43717 .88899 m .43545 .88766 L .41954 .89171 L .311 0 0 r
F
.36894 .70031 m .35684 .69808 L .35896 .70227 L 1 .289 0 r
F
.37107 .70403 m .36894 .70031 L .35896 .70227 L 1 .314 0 r
F
.30308 .89619 m .28123 .88832 L .28698 .89121 L .445 0 0 r
F
.30836 .89877 m .30308 .89619 L .28698 .89121 L .417 0 0 r
F
.42352 .63949 m .41686 .63706 L .41917 .63777 L 0 .108 0 r
F
.42565 .64005 m .42352 .63949 L .41917 .63777 L 0 .112 0 r
F
.76239 .44154 m .76145 .43681 L .76929 .45057 L .886 .142 0 r
F
.42957 .6538 m .42198 .65285 L .42423 .65366 L .367 0 0 r
F
.43159 .65444 m .42957 .6538 L .42423 .65366 L F
.62862 .4858 m .63263 .49067 L .63233 .49331 L 1 .388 0 r
F
.62862 .4858 m .62879 .48315 L .63263 .49067 L F
.38284 .63693 m .37551 .63292 L .37799 .63448 L .413 0 0 r
F
.38521 .63832 m .38284 .63693 L .37799 .63448 L .4 0 0 r
F
.56996 .90183 m .57477 .90074 L .55951 .90477 L .211 .175 0 r
F
.36856 .90991 m .34735 .9053 L .35221 .90717 L .376 0 0 r
F
.37277 .91151 m .36856 .90991 L .35221 .90717 L .347 0 0 r
F
.43895 .65482 m .43159 .65444 L .43363 .65507 L .312 0 0 r
F
.44071 .65528 m .43895 .65482 L .43363 .65507 L F
.76053 .5581 m .76162 .56636 L .76009 .57106 L .838 .2 0 r
F
.76053 .5581 m .76198 .55327 L .76162 .56636 L F
.63881 .48049 m .6496 .48588 L .64909 .48877 L 1 .577 0 r
F
.63881 .48049 m .63828 .47769 L .6496 .48588 L F
.56091 .7403 m .561 .75753 L .55667 .75619 L 1 1 0 r
F
.56091 .7403 m .56571 .74213 L .561 .75753 L F
.25897 .87565 m .23749 .86549 L .24331 .86914 L .502 0 0 r
F
.26441 .87898 m .25897 .87565 L .24331 .86914 L .477 0 0 r
F
.63435 .54907 m .63773 .55456 L .63644 .55727 L 1 .713 0 r
F
.63435 .54907 m .63553 .54628 L .63773 .55456 L F
.85029 .71368 m .84407 .72143 L .84031 .72751 L 0 0 0 r
F
.85029 .71368 m .85422 .70735 L .84407 .72143 L F
.41343 .91741 m .39332 .91491 L .39685 .91614 L .304 0 0 r
F
.41618 .91839 m .41343 .91741 L .39685 .91614 L .272 0 0 r
F
.43268 .91902 m .41343 .91741 L .41618 .91839 L .26 0 0 r
F
.58583 .59198 m .58611 .5951 L .58413 .59689 L .762 .486 0 r
F
.58583 .59198 m .58783 .59009 L .58611 .5951 L F
.62028 .54928 m .62161 .55342 L .6203 .55586 L .889 .419 0 r
F
.62028 .54928 m .6216 .54677 L .62161 .55342 L F
.44904 .64449 m .44274 .64375 L .44444 .64392 L 0 .134 0 r
F
.45045 .64453 m .44904 .64449 L .44444 .64392 L .012 .139 0 r
F
.36702 .91631 m .34553 .91154 L .35048 .91337 L .36 0 0 r
F
.37131 .91787 m .36702 .91631 L .35048 .91337 L .328 0 0 r
F
.59374 .89489 m .58424 .8981 L .57953 .89949 L .243 .18 0 r
F
.59374 .89489 m .5991 .89342 L .58424 .8981 L F
.62798 .89639 m .61863 .89896 L .61338 .90111 L 0 0 0 r
F
.62798 .89639 m .63381 .89409 L .61863 .89896 L F
.3976 .89114 m .37757 .89054 L .38153 .89234 L .453 0 0 r
F
.40086 .89277 m .3976 .89114 L .38153 .89234 L .435 0 0 r
F
.21846 .8224 m .19834 .811 L .20356 .81543 L .631 .019 0 r
F
.22341 .82653 m .21846 .8224 L .20356 .81543 L .613 .014 0 r
F
.65953 .86935 m .6516 .87313 L .64613 .87571 L .304 .185 0 r
F
.65953 .86935 m .66546 .8666 L .6516 .87313 L F
.41252 .92424 m .39214 .92148 L .39574 .92267 L .294 0 0 r
F
.41532 .9252 m .41252 .92424 L .39574 .92267 L .26 0 0 r
F
.43205 .92618 m .41252 .92424 L .41532 .9252 L .257 0 0 r
F
.57269 .91351 m .56172 .91543 L .55757 .91669 L 0 0 0 r
F
.57269 .91351 m .57758 .91214 L .56172 .91543 L F
.61432 .54954 m .6159 .55363 L .61459 .55598 L .936 .505 0 r
F
.61432 .54954 m .61562 .54713 L .6159 .55363 L F
.51128 .65696 m .50924 .66063 L .50702 .66037 L .836 1 0 r
F
.51128 .65696 m .51377 .65718 L .50924 .66063 L F
.34653 .67922 m .33614 .67395 L .33809 .67786 L 1 .166 0 r
F
.34855 .68277 m .34653 .67922 L .33809 .67786 L 1 .194 0 r
F
.6301 .90205 m .62054 .90439 L .61523 .9066 L 0 0 0 r
F
.6301 .90205 m .63599 .89967 L .62054 .90439 L F
.43438 .64227 m .4278 .64057 L .42997 .64106 L 0 .118 0 r
F
.43633 .64261 m .43438 .64227 L .42997 .64106 L 0 .122 0 r
F
.63503 .48602 m .63813 .49101 L .63784 .49374 L .977 .276 0 r
F
.63503 .48602 m .63531 .48325 L .63813 .49101 L F
.66012 .703 m .65866 .70916 L .65455 .71146 L .669 .549 0 r
F
.66012 .703 m .66443 .70059 L .65866 .70916 L F
.60485 .60186 m .60576 .60622 L .60359 .60831 L .888 .685 0 r
F
.60485 .60186 m .60701 .59964 L .60576 .60622 L F
.50571 .64211 m .50376 .64388 L .50181 .64393 L .516 .567 0 r
F
.50571 .64211 m .50791 .642 L .50376 .64388 L F
.574 .91908 m .56281 .92067 L .55861 .92197 L 0 0 0 r
F
.574 .91908 m .57893 .91765 L .56281 .92067 L F
.58917 .59523 m .58936 .59835 L .58732 .60018 L .75 .446 0 r
F
.58917 .59523 m .59125 .5933 L .58936 .59835 L F
.54016 .63021 m .53925 .63229 L .53684 .63311 L .56 .431 0 r
F
.54016 .63021 m .5427 .62931 L .53925 .63229 L F
.42206 .71831 m .40965 .72358 L .41171 .72769 L .843 .104 0 r
F
.42393 .72163 m .42206 .71831 L .41171 .72769 L .839 .125 0 r
F
.76677 .79565 m .76055 .8015 L .75558 .8061 L .484 .196 0 r
F
.76677 .79565 m .77198 .79081 L .76055 .8015 L F
.59725 .90678 m .58719 .90901 L .58241 .91064 L 0 0 0 r
F
.59725 .90678 m .60269 .90502 L .58719 .90901 L F
.6284 .48846 m .63233 .49331 L .63199 .49594 L 1 .409 0 r
F
.6284 .48846 m .62862 .4858 L .63233 .49331 L F
.44274 .64375 m .43633 .64261 L .43829 .64292 L 0 .127 0 r
F
.44444 .64392 m .44274 .64375 L .43829 .64292 L 0 .131 0 r
F
.6392 .48332 m .64909 .48877 L .64864 .49167 L 1 .604 0 r
F
.6392 .48332 m .63881 .48049 L .64909 .48877 L F
.71379 .65314 m .71245 .65938 L .70928 .66307 L .719 .224 0 r
F
.71379 .65314 m .71704 .64929 L .71245 .65938 L F
.39424 .62711 m .38823 .62278 L .3906 .62406 L 0 .084 0 r
F
.39652 .62824 m .39424 .62711 L .3906 .62406 L 0 .089 0 r
F
.66498 .88062 m .65642 .88364 L .65087 .88643 L 0 0 0 r
F
.66498 .88062 m .67101 .87764 L .65642 .88364 L F
.51382 .63977 m .51227 .64161 L .51009 .64183 L .521 .546 0 r
F
.51382 .63977 m .51621 .63948 L .51227 .64161 L F
.52028 .65394 m .51871 .65738 L .51625 .65732 L .761 .979 0 r
F
.52028 .65394 m .52298 .65393 L .51871 .65738 L F
.63311 .55184 m .63644 .55727 L .6351 .55997 L 1 .727 0 r
F
.63311 .55184 m .63435 .54907 L .63644 .55727 L F
.59893 .91248 m .58865 .91441 L .58382 .9161 L 0 0 0 r
F
.59893 .91248 m .60443 .91065 L .58865 .91441 L F
.44578 .70761 m .43537 .71483 L .43698 .71764 L .444 .027 0 r
F
.44706 .70961 m .44578 .70761 L .43698 .71764 L .44 .03 0 r
F
.61892 .55177 m .6203 .55586 L .61894 .55827 L .897 .448 0 r
F
.61892 .55177 m .62028 .54928 L .6203 .55586 L F
.58378 .59383 m .58413 .59689 L .58212 .59864 L .76 .511 0 r
F
.58378 .59383 m .58583 .59198 L .58413 .59689 L F
.88672 .56982 m .88892 .58212 L .8873 .58892 L .841 .187 0 r
F
.88672 .56982 m .88805 .56285 L .88892 .58212 L F
.20899 .8352 m .18916 .8221 L .19455 .82669 L .578 .007 0 r
F
.21414 .83947 m .20899 .8352 L .19455 .82669 L .557 .001 0 r
F
.52447 .63636 m .52328 .63828 L .52094 .63874 L .531 .5 0 r
F
.52447 .63636 m .52699 .63582 L .52328 .63828 L F
.6676 .88604 m .65885 .88893 L .65324 .89179 L 0 0 0 r
F
.6676 .88604 m .6737 .88298 L .65885 .88893 L F
.4123 .63553 m .40591 .63237 L .40832 .63331 L 0 .101 0 r
F
.41457 .63631 m .4123 .63553 L .40832 .63331 L 0 .106 0 r
F
.61296 .55194 m .61459 .55598 L .61323 .5583 L .943 .531 0 r
F
.61296 .55194 m .61432 .54954 L .61459 .55598 L F
.38521 .63832 m .37799 .63448 L .38049 .63601 L .4 0 0 r
F
.38761 .63968 m .38521 .63832 L .38049 .63601 L .389 0 0 r
F
.54957 .64365 m .54879 .64681 L .54607 .64756 L .649 .741 0 r
F
.54957 .64365 m .55242 .64278 L .54879 .64681 L F
.43458 .91979 m .43268 .91902 L .41618 .91839 L .226 0 0 r
F
.77558 .80505 m .76838 .8102 L .76332 .81497 L 0 0 0 r
F
.77558 .80505 m .78092 .80004 L .76838 .8102 L F
.48569 .66983 m .4869 .67038 L .48151 .67491 L 1 1 0 r
F
.405 .64737 m .39747 .64484 L .4 .64607 L .402 0 0 r
F
.40738 .64842 m .405 .64737 L .4 .64607 L .397 0 0 r
F
.34836 .88426 m .32742 .88051 L .33249 .88294 L .515 0 0 r
F
.35286 .88645 m .34836 .88426 L .33249 .88294 L .496 0 0 r
F
.41974 .65203 m .41218 .65047 L .41462 .65146 L .396 0 0 r
F
.42198 .65285 m .41974 .65203 L .41462 .65146 L F
.90354 .40087 m .90318 .41581 L .90356 .42287 L 0 0 0 r
F
.90354 .40087 m .90305 .39368 L .90318 .41581 L F
.49635 .66257 m .49828 .6631 L .49344 .66683 L .985 1 0 r
F
.44758 .65512 m .44071 .65528 L .44249 .65573 L .229 0 0 r
F
.44906 .65541 m .44758 .65512 L .44249 .65573 L .228 0 0 r
F
.45407 .65462 m .44758 .65512 L .44906 .65541 L .122 0 0 r
F
.6347 .48878 m .63784 .49374 L .63751 .49647 L .993 .308 0 r
F
.6347 .48878 m .63503 .48602 L .63784 .49374 L F
.53212 .65016 m .53098 .65338 L .52833 .65365 L .687 .878 0 r
F
.53212 .65016 m .53495 .6498 L .53098 .65338 L F
.20439 .84141 m .1841 .82823 L .18965 .83282 L .568 .004 0 r
F
.20968 .84568 m .20439 .84141 L .18965 .83282 L .545 0 0 r
F
.50257 .65959 m .50019 .66355 L .49828 .6631 L .925 1 0 r
F
.50257 .65959 m .5048 .66002 L .50019 .66355 L F
.39332 .91491 m .37277 .91151 L .37703 .91299 L .333 0 0 r
F
.39685 .91614 m .39332 .91491 L .37703 .91299 L .302 0 0 r
F
.40761 .71979 m .39472 .72331 L .39688 .72781 L .978 .227 0 r
F
.40965 .72358 m .40761 .71979 L .39688 .72781 L .974 .248 0 r
F
.75898 .5629 m .76009 .57106 L .75847 .57573 L .841 .202 0 r
F
.75898 .5629 m .76053 .5581 L .76009 .57106 L F
.62811 .49112 m .63199 .49594 L .63161 .49858 L 1 .432 0 r
F
.62811 .49112 m .6284 .48846 L .63199 .49594 L F
.58706 .59713 m .58732 .60018 L .58525 .60198 L .748 .473 0 r
F
.58706 .59713 m .58917 .59523 L .58732 .60018 L F
.42565 .64005 m .41917 .63777 L .4215 .63844 L 0 .112 0 r
F
.4278 .64057 m .42565 .64005 L .4215 .63844 L 0 .117 0 r
F
.39042 .7152 m .37756 .71625 L .37975 .72078 L 1 .301 0 r
F
.39256 .71912 m .39042 .7152 L .37975 .72078 L 1 .323 0 r
F
.49232 .64532 m .48974 .64699 L .48836 .64679 L .52 .602 0 r
F
.49232 .64532 m .49402 .64548 L .48974 .64699 L F
.54345 .74994 m .54303 .77165 L .53911 .7699 L 1 1 0 r
F
.54345 .74994 m .54789 .7524 L .54303 .77165 L F
.60264 .60403 m .60359 .60831 L .60138 .61036 L .887 .702 0 r
F
.60264 .60403 m .60485 .60186 L .60359 .60831 L F
.49788 .64387 m .4957 .64559 L .49402 .64548 L .525 .616 0 r
F
.49788 .64387 m .49985 .64393 L .4957 .64559 L F
.90948 .39978 m .91062 .41469 L .91185 .42176 L 0 0 0 r
F
.90948 .39978 m .90822 .39264 L .91062 .41469 L F
.90642 .57405 m .90286 .58551 L .90128 .59257 L F
.90642 .57405 m .90805 .5668 L .90286 .58551 L F
.63947 .48616 m .64864 .49167 L .64822 .49456 L 1 .622 0 r
F
.63947 .48616 m .6392 .48332 L .64864 .49167 L F
.39214 .92148 m .37131 .91787 L .37565 .91931 L .318 0 0 r
F
.39574 .92267 m .39214 .92148 L .37565 .91931 L .285 0 0 r
F
.6175 .55423 m .61894 .55827 L .61753 .56066 L .905 .476 0 r
F
.6175 .55423 m .61892 .55177 L .61894 .55827 L F
.43537 .71483 m .42393 .72163 L .4258 .72529 L .671 .058 0 r
F
.43698 .71764 m .43537 .71483 L .4258 .72529 L .667 .061 0 r
F
.63181 .5546 m .6351 .55997 L .63371 .56264 L 1 .741 0 r
F
.63181 .5546 m .63311 .55184 L .6351 .55997 L F
.5817 .59564 m .58212 .59864 L .58008 .60036 L .757 .536 0 r
F
.5817 .59564 m .58378 .59383 L .58212 .59864 L F
.43159 .65444 m .42423 .65366 L .4265 .65446 L .367 0 0 r
F
.43363 .65507 m .43159 .65444 L .4265 .65446 L .372 0 0 r
F
.61157 .55432 m .61323 .5583 L .61183 .5606 L .948 .556 0 r
F
.61157 .55432 m .61296 .55194 L .61323 .5583 L F
.57936 .73231 m .57979 .74548 L .57516 .7447 L .953 1 0 r
F
.57936 .73231 m .58441 .73337 L .57979 .74548 L F
.5376 .63107 m .53684 .63311 L .53441 .63387 L .563 .474 0 r
F
.5376 .63107 m .54016 .63021 L .53684 .63311 L F
.83415 .71221 m .82997 .72058 L .82617 .72642 L .639 .199 0 r
F
.83415 .71221 m .83803 .70613 L .82997 .72058 L F
.39652 .62824 m .3906 .62406 L .393 .6253 L 0 .089 0 r
F
.39883 .62933 m .39652 .62824 L .393 .6253 L 0 .094 0 r
F
.37107 .70403 m .35896 .70227 L .3611 .70663 L 1 .314 0 r
F
.37322 .7079 m .37107 .70403 L .3611 .70663 L 1 .34 0 r
F
.44071 .65528 m .43363 .65507 L .43568 .65569 L .312 0 0 r
F
.44249 .65573 m .44071 .65528 L .43568 .65569 L .317 0 0 r
F
.34255 .90331 m .32132 .89744 L .32669 .89972 L .402 0 0 r
F
.34735 .9053 m .34255 .90331 L .32669 .89972 L .374 0 0 r
F
.63432 .49154 m .63751 .49647 L .63712 .4992 L 1 .34 0 r
F
.63432 .49154 m .6347 .48878 L .63751 .49647 L F
.34855 .68277 m .33809 .67786 L .34007 .68187 L 1 .194 0 r
F
.35059 .68642 m .34855 .68277 L .34007 .68187 L 1 .224 0 r
F
.62777 .49378 m .63161 .49858 L .63119 .50121 L 1 .456 0 r
F
.62777 .49378 m .62811 .49112 L .63161 .49858 L F
.43633 .64261 m .42997 .64106 L .43215 .64151 L 0 .122 0 r
F
.43829 .64292 m .43633 .64261 L .43215 .64151 L 0 .126 0 r
F
.45045 .64453 m .44444 .64392 L .44616 .64406 L .012 .139 0 r
F
.45187 .64454 m .45045 .64453 L .44616 .64406 L .034 .144 0 r
F
.58491 .59899 m .58525 .60198 L .58315 .60374 L .746 .5 0 r
F
.58491 .59899 m .58706 .59713 L .58525 .60198 L F
.65572 .70527 m .65455 .71146 L .65035 .71362 L .67 .614 0 r
F
.65572 .70527 m .66012 .703 L .65455 .71146 L F
.34064 .90959 m .31911 .9036 L .32458 .90583 L .384 0 0 r
F
.34553 .91154 m .34064 .90959 L .32458 .90583 L .354 0 0 r
F
.38761 .63968 m .38049 .63601 L .38302 .63751 L .389 0 0 r
F
.39004 .64102 m .38761 .63968 L .38302 .63751 L .379 0 0 r
F
.71045 .65693 m .70928 .66307 L .70602 .66669 L .721 .226 0 r
F
.71045 .65693 m .71379 .65314 L .70928 .66307 L F
.50879 .65665 m .50702 .66037 L .5048 .66002 L .869 1 0 r
F
.50879 .65665 m .51128 .65696 L .50702 .66037 L F
.50349 .64216 m .50181 .64393 L .49985 .64393 L .535 .64 0 r
F
.50349 .64216 m .50571 .64211 L .50181 .64393 L F
.84625 .71993 m .84031 .72751 L .83643 .73353 L 0 0 0 r
F
.84625 .71993 m .85029 .71368 L .84031 .72751 L F
.60039 .60617 m .60138 .61036 L .59912 .61236 L .885 .719 0 r
F
.60039 .60617 m .60264 .60403 L .60138 .61036 L F
.41457 .63631 m .40832 .63331 L .41074 .63421 L 0 .106 0 r
F
.41686 .63706 m .41457 .63631 L .41074 .63421 L 0 .11 0 r
F
.61604 .55668 m .61753 .56066 L .61608 .56302 L .912 .504 0 r
F
.61604 .55668 m .6175 .55423 L .61753 .56066 L F
.63964 .48903 m .64822 .49456 L .64782 .49746 L 1 .637 0 r
F
.63964 .48903 m .63947 .48616 L .64822 .49456 L F
.5467 .64445 m .54607 .64756 L .54333 .64824 L .658 .774 0 r
F
.5467 .64445 m .54957 .64365 L .54607 .64756 L F
.52194 .63684 m .52094 .63874 L .51858 .63914 L .539 .556 0 r
F
.52194 .63684 m .52447 .63636 L .52094 .63874 L F
.51142 .64 m .51009 .64183 L .50791 .642 L .535 .611 0 r
F
.51142 .64 m .51382 .63977 L .51009 .64183 L F
.2756 .85745 m .25485 .84949 L .26037 .85301 L .57 0 0 r
F
.28074 .86068 m .2756 .85745 L .26037 .85301 L .551 0 0 r
F
.63047 .55734 m .63371 .56264 L .63227 .56529 L 1 .756 0 r
F
.63047 .55734 m .63181 .5546 L .63371 .56264 L F
.57959 .59742 m .58008 .60036 L .578 .60204 L .754 .559 0 r
F
.57959 .59742 m .5817 .59564 L .58008 .60036 L F
.61013 .55668 m .61183 .5606 L .61038 .56288 L .953 .581 0 r
F
.61013 .55668 m .61157 .55432 L .61183 .5606 L F
.51757 .65386 m .51625 .65732 L .51377 .65718 L .789 1 0 r
F
.51757 .65386 m .52028 .65394 L .51625 .65732 L F
.40738 .64842 m .4 .64607 L .40254 .64727 L .397 0 0 r
F
.40977 .64945 m .40738 .64842 L .40254 .64727 L .395 0 0 r
F
.52261 .7866 m .51858 .81149 L .51579 .81067 L 1 1 0 r
F
.52261 .7866 m .52604 .7885 L .51858 .81149 L F
.55607 .73809 m .55667 .75619 L .5523 .75448 L 1 .989 0 r
F
.55607 .73809 m .56091 .7403 L .55667 .75619 L F
.44444 .64392 m .43829 .64292 L .44026 .6432 L 0 .131 0 r
F
.44616 .64406 m .44444 .64392 L .44026 .6432 L 0 .135 0 r
F
.52926 .65043 m .52833 .65365 L .52566 .65383 L .707 .914 0 r
F
.52926 .65043 m .53212 .65016 L .52833 .65365 L F
.75733 .56768 m .75847 .57573 L .75676 .58038 L .843 .205 0 r
F
.75733 .56768 m .75898 .5629 L .75847 .57573 L F
.53119 .76527 m .52944 .79005 L .52604 .7885 L 1 1 0 r
F
.53119 .76527 m .53516 .76778 L .52944 .79005 L F
.63388 .4943 m .63712 .4992 L .63668 .50192 L 1 .372 0 r
F
.63388 .4943 m .63432 .49154 L .63712 .4992 L F
.31748 .87539 m .29658 .86984 L .30201 .8727 L .535 0 0 r
F
.32242 .878 m .31748 .87539 L .30201 .8727 L .516 0 0 r
F
.62737 .49644 m .63119 .50121 L .63073 .50384 L 1 .48 0 r
F
.62737 .49644 m .62777 .49378 L .63119 .50121 L F
.42198 .65285 m .41462 .65146 L .41707 .65245 L .396 0 0 r
F
.42423 .65366 m .42198 .65285 L .41707 .65245 L .401 0 0 r
F
.55523 .62171 m .55502 .62402 L .55261 .62517 L .631 .491 0 r
F
.55523 .62171 m .55773 .62045 L .55502 .62402 L F
.54712 .90745 m .55129 .90671 L .53611 .91011 L .191 .173 0 r
F
.4278 .64057 m .4215 .63844 L .42385 .63908 L 0 .117 0 r
F
.42997 .64106 m .4278 .64057 L .42385 .63908 L 0 .12 0 r
F
.39883 .62933 m .393 .6253 L .39542 .6265 L 0 .094 0 r
F
.40117 .63038 m .39883 .62933 L .39542 .6265 L 0 .098 0 r
F
.53501 .63186 m .53441 .63387 L .53196 .63457 L .566 .516 0 r
F
.53501 .63186 m .5376 .63107 L .53441 .63387 L F
.88526 .57678 m .8873 .58892 L .88556 .59571 L .84 .189 0 r
F
.88526 .57678 m .88672 .56982 L .8873 .58892 L F
.58272 .60081 m .58315 .60374 L .581 .60546 L .743 .525 0 r
F
.58272 .60081 m .58491 .59899 L .58315 .60374 L F
.61454 .5591 m .61608 .56302 L .61458 .56537 L .918 .531 0 r
F
.61454 .5591 m .61604 .55668 L .61608 .56302 L F
.22341 .82653 m .20356 .81543 L .20887 .81978 L .613 .014 0 r
F
.22844 .83057 m .22341 .82653 L .20887 .81978 L .595 .009 0 r
F
.63971 .4919 m .64782 .49746 L .64741 .50035 L 1 .65 0 r
F
.63971 .4919 m .63964 .48903 L .64782 .49746 L F
.26765 .87275 m .24693 .86299 L .2527 .86655 L .491 0 0 r
F
.27306 .87599 m .26765 .87275 L .2527 .86655 L .467 0 0 r
F
.60864 .55901 m .61038 .56288 L .6089 .56513 L .957 .605 0 r
F
.60864 .55901 m .61013 .55668 L .61038 .56288 L F
.5981 .60826 m .59912 .61236 L .59682 .61432 L .883 .735 0 r
F
.5981 .60826 m .60039 .60617 L .59912 .61236 L F
.57744 .59917 m .578 .60204 L .57589 .60369 L .755 .582 0 r
F
.57744 .59917 m .57959 .59742 L .578 .60204 L F
.76146 .8004 m .75558 .8061 L .75051 .81061 L .49 .199 0 r
F
.76146 .8004 m .76677 .79565 L .75558 .8061 L F
.62907 .56006 m .63227 .56529 L .63078 .56792 L 1 .771 0 r
F
.62907 .56006 m .63047 .55734 L .63227 .56529 L F
.9037 .40811 m .90356 .42287 L .9037 .42995 L 0 0 0 r
F
.9037 .40811 m .90354 .40087 L .90356 .42287 L F
.54913 .91882 m .53767 .92044 L .53423 .92136 L F
.54913 .91882 m .55337 .91782 L .53767 .92044 L F
.50034 .65908 m .49828 .6631 L .49635 .66257 L .961 1 0 r
F
.50034 .65908 m .50257 .65959 L .49828 .6631 L F
.44906 .65541 m .44249 .65573 L .44428 .65618 L .228 0 0 r
F
.45054 .65569 m .44906 .65541 L .44428 .65618 L .233 0 0 r
F
.4959 .64375 m .49402 .64548 L .49232 .64532 L .548 .695 0 r
F
.4959 .64375 m .49788 .64387 L .49402 .64548 L F
.39004 .64102 m .38302 .63751 L .38558 .63898 L .379 0 0 r
F
.3925 .64232 m .39004 .64102 L .38558 .63898 L .371 0 0 r
F
.48278 .93145 m .46688 .93122 L .46698 .93174 L .123 0 0 r
F
.48278 .93145 m .48362 .93092 L .46688 .93122 L F
.53075 .92214 m .51829 .92342 L .51567 .92414 L 0 0 0 r
F
.53075 .92214 m .53423 .92136 L .51829 .92342 L F
.26441 .87898 m .24331 .86914 L .24922 .87268 L .477 0 0 r
F
.26994 .8822 m .26441 .87898 L .24922 .87268 L .451 0 0 r
F
.6334 .49706 m .63668 .50192 L .63619 .50464 L 1 .403 0 r
F
.6334 .49706 m .63388 .4943 L .63668 .50192 L F
.49062 .6451 m .48836 .64679 L .48696 .64654 L .549 .691 0 r
F
.49062 .6451 m .49232 .64532 L .48836 .64679 L F
.62692 .4991 m .63073 .50384 L .63022 .50646 L 1 .505 0 r
F
.62692 .4991 m .62737 .49644 L .63073 .50384 L F
.55009 .92418 m .53842 .92547 L .53495 .92641 L 0 0 0 r
F
.55009 .92418 m .55437 .92315 L .53842 .92547 L F
.43363 .65507 m .4265 .65446 L .42879 .65526 L .372 0 0 r
F
.43568 .65569 m .43363 .65507 L .42879 .65526 L .382 0 0 r
F
.42393 .72163 m .41171 .72769 L .41377 .73219 L .839 .125 0 r
F
.4258 .72529 m .42393 .72163 L .41377 .73219 L .835 .146 0 r
F
.90466 .58129 m .90128 .59257 L .89956 .5996 L 0 0 0 r
F
.90466 .58129 m .90642 .57405 L .90128 .59257 L F
.54379 .64517 m .54333 .64824 L .54056 .64884 L .666 .806 0 r
F
.54379 .64517 m .5467 .64445 L .54333 .64824 L F
.41686 .63706 m .41074 .63421 L .41319 .63507 L 0 .11 0 r
F
.41917 .63777 m .41686 .63706 L .41319 .63507 L 0 .114 0 r
F
.31079 .89255 m .28973 .88508 L .29544 .88789 L .434 0 0 r
F
.31602 .89505 m .31079 .89255 L .29544 .88789 L .408 0 0 r
F
.91059 .40695 m .91185 .42176 L .91295 .42887 L 0 0 0 r
F
.91059 .40695 m .90948 .39978 L .91185 .42176 L F
.53144 .92721 m .51879 .92818 L .51615 .92891 L .013 0 0 r
F
.53144 .92721 m .53495 .92641 L .51879 .92818 L F
.51939 .63726 m .51858 .63914 L .51621 .63948 L .548 .61 0 r
F
.51939 .63726 m .52194 .63684 L .51858 .63914 L F
.70702 .66064 m .70602 .66669 L .70268 .67023 L .722 .228 0 r
F
.70702 .66064 m .71045 .65693 L .70602 .66669 L F
.61299 .5615 m .61458 .56537 L .61304 .56769 L .924 .557 0 r
F
.61299 .5615 m .61454 .5591 L .61458 .56537 L F
.77013 .80996 m .76332 .81497 L .75816 .81966 L 0 0 0 r
F
.77013 .80996 m .77558 .80505 L .76332 .81497 L F
.5805 .60259 m .581 .60546 L .57882 .60715 L .741 .549 0 r
F
.5805 .60259 m .58272 .60081 L .581 .60546 L F
.35059 .68642 m .34007 .68187 L .34207 .68601 L 1 .224 0 r
F
.35266 .69018 m .35059 .68642 L .34207 .68601 L 1 .255 0 r
F
.55271 .62292 m .55261 .62517 L .55017 .62628 L .629 .52 0 r
F
.55271 .62292 m .55523 .62171 L .55261 .62517 L F
.43829 .64292 m .43215 .64151 L .43435 .64193 L 0 .126 0 r
F
.44026 .6432 m .43829 .64292 L .43435 .64193 L 0 .13 0 r
F
.37757 .89054 m .35741 .88855 L .36203 .89056 L .475 0 0 r
F
.38153 .89234 m .37757 .89054 L .36203 .89056 L .457 0 0 r
F
.49836 .9307 m .48362 .93092 L .48278 .93145 L .084 0 0 r
F
.49836 .9307 m .50013 .93015 L .48362 .93092 L F
.60711 .56132 m .6089 .56513 L .60737 .56736 L .961 .629 0 r
F
.60711 .56132 m .60864 .55901 L .6089 .56513 L F
.21414 .83947 m .19455 .82669 L .20004 .83118 L .557 .001 0 r
F
.21938 .84363 m .21414 .83947 L .20004 .83118 L .534 0 0 r
F
.39256 .71912 m .37975 .72078 L .38196 .7256 L 1 .323 0 r
F
.39472 .72331 m .39256 .71912 L .38196 .7256 L 1 .345 0 r
F
.61775 .88656 m .60964 .89003 L .6044 .8918 L .29 .187 0 r
F
.61775 .88656 m .62357 .88467 L .60964 .89003 L F
.65123 .70739 m .65035 .71362 L .64607 .71564 L .674 .675 0 r
F
.65123 .70739 m .65572 .70527 L .65035 .71362 L F
.30836 .89877 m .28698 .89121 L .29281 .89398 L .417 0 0 r
F
.3137 .90124 m .30836 .89877 L .29281 .89398 L .389 0 0 r
F
.40977 .64945 m .40254 .64727 L .40511 .64846 L .395 0 0 r
F
.41218 .65047 m .40977 .64945 L .40511 .64846 L .396 0 0 r
F
.65352 .87197 m .64613 .87571 L .64059 .87815 L .321 .189 0 r
F
.65352 .87197 m .65953 .86935 L .64613 .87571 L F
.509 .64017 m .50791 .642 L .50571 .64211 L .549 .673 0 r
F
.509 .64017 m .51142 .64 L .50791 .642 L F
.6397 .49479 m .64741 .50035 L .64699 .50325 L 1 .663 0 r
F
.6397 .49479 m .63971 .4919 L .64741 .50035 L F
.51296 .80956 m .51579 .81067 L .50651 .83226 L 1 1 0 r
F
.40117 .63038 m .39542 .6265 L .39787 .62767 L 0 .098 0 r
F
.40353 .6314 m .40117 .63038 L .39787 .62767 L 0 .103 0 r
F
.44706 .70961 m .43698 .71764 L .4386 .72078 L .44 .03 0 r
F
.44836 .71186 m .44706 .70961 L .4386 .72078 L .436 .034 0 r
F
.83015 .71822 m .82617 .72642 L .82226 .73218 L .643 .202 0 r
F
.83015 .71822 m .83415 .71221 L .82617 .72642 L F
.57425 .7309 m .57516 .7447 L .57046 .74359 L .948 1 0 r
F
.57425 .7309 m .57936 .73231 L .57516 .7447 L F
.44249 .65573 m .43568 .65569 L .43774 .65632 L .317 0 0 r
F
.44428 .65618 m .44249 .65573 L .43774 .65632 L .328 0 0 r
F
.57526 .60088 m .57589 .60369 L .57375 .6053 L .756 .603 0 r
F
.57526 .60088 m .57744 .59917 L .57589 .60369 L F
.37322 .7079 m .3611 .70663 L .36325 .71121 L 1 .34 0 r
F
.37538 .71197 m .37322 .7079 L .36325 .71121 L 1 .366 0 r
F
.62761 .56277 m .63078 .56792 L .62924 .57053 L 1 .785 0 r
F
.62761 .56277 m .62907 .56006 L .63078 .56792 L F
.50127 .64215 m .49985 .64393 L .49788 .64387 L .553 .708 0 r
F
.50127 .64215 m .50349 .64216 L .49985 .64393 L F
.5324 .6326 m .53196 .63457 L .52948 .63522 L .569 .558 0 r
F
.5324 .6326 m .53501 .63186 L .53196 .63457 L F
.40965 .72358 m .39688 .72781 L .39905 .73267 L .974 .248 0 r
F
.41171 .72769 m .40965 .72358 L .39905 .73267 L .97 .268 0 r
F
.59576 .61031 m .59682 .61432 L .59448 .61624 L .88 .751 0 r
F
.59576 .61031 m .5981 .60826 L .59682 .61432 L F
.75558 .57244 m .75676 .58038 L .75496 .58499 L .845 .208 0 r
F
.75558 .57244 m .75733 .56768 L .75676 .58038 L F
.50629 .65626 m .5048 .66002 L .50257 .65959 L .899 1 0 r
F
.50629 .65626 m .50879 .65665 L .5048 .66002 L F
.52638 .6506 m .52566 .65383 L .52298 .65393 L .726 .945 0 r
F
.52638 .6506 m .52926 .65043 L .52566 .65383 L F
.45187 .64454 m .44616 .64406 L .44788 .64417 L .034 .144 0 r
F
.4533 .64451 m .45187 .64454 L .44788 .64417 L .052 .147 0 r
F
.51485 .65369 m .51377 .65718 L .51128 .65696 L .815 1 0 r
F
.51485 .65369 m .51757 .65386 L .51377 .65718 L F
.20968 .84568 m .18965 .83282 L .1953 .83731 L .545 0 0 r
F
.21506 .84984 m .20968 .84568 L .1953 .83731 L .522 0 0 r
F
.63287 .49981 m .63619 .50464 L .63565 .50735 L 1 .434 0 r
F
.63287 .49981 m .6334 .49706 L .63619 .50464 L F
.62642 .50176 m .63022 .50646 L .62966 .50908 L 1 .53 0 r
F
.62642 .50176 m .62692 .4991 L .63022 .50646 L F
.42997 .64106 m .42385 .63908 L .42621 .63968 L 0 .12 0 r
F
.43215 .64151 m .42997 .64106 L .42621 .63968 L 0 .124 0 r
F
.41954 .89171 m .40086 .89277 L .40416 .89431 L .389 0 0 r
F
.42208 .8931 m .41954 .89171 L .40416 .89431 L .369 0 0 r
F
.43717 .88899 m .41954 .89171 L .42208 .8931 L .311 0 0 r
F
.53899 .74709 m .53911 .7699 L .53516 .76778 L 1 .989 0 r
F
.53899 .74709 m .54345 .74994 L .53911 .7699 L F
.62208 .89857 m .61338 .90111 L .60806 .90313 L 0 0 0 r
F
.62208 .89857 m .62798 .89639 L .61338 .90111 L F
.42423 .65366 m .41707 .65245 L .41954 .65343 L .401 0 0 r
F
.4265 .65446 m .42423 .65366 L .41954 .65343 L .41 0 0 r
F
.44616 .64406 m .44026 .6432 L .44224 .64344 L 0 .135 0 r
F
.44788 .64417 m .44616 .64406 L .44224 .64344 L .009 .138 0 r
F
.6114 .56387 m .61304 .56769 L .61146 .56998 L .929 .582 0 r
F
.6114 .56387 m .61299 .5615 L .61304 .56769 L F
.65888 .88347 m .65087 .88643 L .64526 .88911 L 0 0 0 r
F
.65888 .88347 m .66498 .88062 L .65087 .88643 L F
.60554 .56361 m .60737 .56736 L .60579 .56957 L .964 .651 0 r
F
.60554 .56361 m .60711 .56132 L .60737 .56736 L F
.57824 .60434 m .57882 .60715 L .57661 .60879 L .738 .573 0 r
F
.57824 .60434 m .5805 .60259 L .57882 .60715 L F
.84208 .72613 m .83643 .73353 L .83244 .73948 L 0 0 0 r
F
.84208 .72613 m .84625 .71993 L .83643 .73353 L F
.3925 .64232 m .38558 .63898 L .38817 .64042 L .371 0 0 r
F
.39497 .64359 m .3925 .64232 L .38817 .64042 L .365 0 0 r
F
.62415 .9043 m .61523 .9066 L .60986 .90869 L 0 0 0 r
F
.62415 .9043 m .6301 .90205 L .61523 .9066 L F
.43698 .71764 m .4258 .72529 L .42768 .72937 L .667 .061 0 r
F
.4386 .72078 m .43698 .71764 L .42768 .72937 L .664 .064 0 r
F
.63961 .49769 m .64699 .50325 L .64655 .50615 L 1 .677 0 r
F
.63961 .49769 m .6397 .49479 L .64699 .50325 L F
.57304 .60255 m .57375 .6053 L .57157 .60687 L .757 .624 0 r
F
.57304 .60255 m .57526 .60088 L .57375 .6053 L F
.55015 .62408 m .55017 .62628 L .54771 .62734 L .628 .549 0 r
F
.55015 .62408 m .55271 .62292 L .55017 .62628 L F
.66144 .88898 m .65324 .89179 L .64756 .89454 L 0 0 0 r
F
.66144 .88898 m .6676 .88604 L .65324 .89179 L F
.58832 .8962 m .57953 .89949 L .57477 .90074 L .277 .187 0 r
F
.58832 .8962 m .59374 .89489 L .57953 .89949 L F
.54086 .6458 m .54056 .64884 L .53777 .64936 L .674 .836 0 r
F
.54086 .6458 m .54379 .64517 L .54056 .64884 L F
.6261 .56545 m .62924 .57053 L .62766 .57311 L 1 .8 0 r
F
.6261 .56545 m .62761 .56277 L .62924 .57053 L F
.56335 .6354 m .5635 .63859 L .56078 .63973 L .712 .746 0 r
F
.56335 .6354 m .56615 .63411 L .5635 .63859 L F
.41917 .63777 m .41319 .63507 L .41566 .6359 L 0 .114 0 r
F
.4215 .63844 m .41917 .63777 L .41566 .6359 L 0 .118 0 r
F
.37277 .91151 m .35221 .90717 L .35713 .90892 L .347 0 0 r
F
.37703 .91299 m .37277 .91151 L .35713 .90892 L .317 0 0 r
F
.60354 .72509 m .60387 .73441 L .59912 .73459 L .841 1 0 r
F
.60354 .72509 m .60862 .72498 L .60387 .73441 L F
.88367 .58373 m .88556 .59571 L .88372 .60247 L .839 .191 0 r
F
.88367 .58373 m .88526 .57678 L .88556 .59571 L F
.62587 .50441 m .62966 .50908 L .62905 .51169 L 1 .555 0 r
F
.62587 .50441 m .62642 .50176 L .62966 .50908 L F
.63229 .50256 m .63565 .50735 L .63506 .51005 L 1 .465 0 r
F
.63229 .50256 m .63287 .49981 L .63565 .50735 L F
.5651 .90276 m .55542 .90581 L .55129 .90671 L .251 .183 0 r
F
.5651 .90276 m .56996 .90183 L .55542 .90581 L F
.59337 .61232 m .59448 .61624 L .5921 .61812 L .877 .766 0 r
F
.59337 .61232 m .59576 .61031 L .59448 .61624 L F
.40353 .6314 m .39787 .62767 L .40034 .62879 L 0 .103 0 r
F
.40591 .63237 m .40353 .6314 L .40034 .62879 L 0 .107 0 r
F
.51682 .63762 m .51621 .63948 L .51382 .63977 L .557 .663 0 r
F
.51682 .63762 m .51939 .63726 L .51621 .63948 L F
.5512 .73549 m .5523 .75448 L .54789 .7524 L 1 .958 0 r
F
.5512 .73549 m .55607 .73809 L .5523 .75448 L F
.60976 .56623 m .61146 .56998 L .60983 .57224 L .933 .607 0 r
F
.60976 .56623 m .6114 .56387 L .61146 .56998 L F
.37131 .91787 m .35048 .91337 L .35549 .91507 L .328 0 0 r
F
.37565 .91931 m .37131 .91787 L .35549 .91507 L .296 0 0 r
F
.52977 .63329 m .52948 .63522 L .52699 .63582 L .571 .599 0 r
F
.52977 .63329 m .5324 .6326 L .52948 .63522 L F
.60393 .56587 m .60579 .56957 L .60418 .57175 L .967 .673 0 r
F
.60393 .56587 m .60554 .56361 L .60579 .56957 L F
.7035 .66427 m .70268 .67023 L .69925 .67369 L .723 .259 0 r
F
.7035 .66427 m .70702 .66064 L .70268 .67023 L F
.90341 .4154 m .9037 .42995 L .90359 .43704 L .736 .149 0 r
F
.90341 .4154 m .9037 .40811 L .9037 .42995 L F
.49391 .64358 m .49232 .64532 L .49062 .6451 L .581 .769 0 r
F
.49391 .64358 m .4959 .64375 L .49232 .64532 L F
.41218 .65047 m .40511 .64846 L .4077 .64963 L .396 0 0 r
F
.41462 .65146 m .41218 .65047 L .4077 .64963 L .401 0 0 r
F
.57595 .60605 m .57661 .60879 L .57436 .6104 L .737 .595 0 r
F
.57595 .60605 m .57824 .60434 L .57661 .60879 L F
.43891 .89024 m .43717 .88899 L .42208 .8931 L .288 0 0 r
F
.59175 .90841 m .58241 .91064 L .57758 .91214 L 0 0 0 r
F
.59175 .90841 m .59725 .90678 L .58241 .91064 L F
.40086 .89277 m .38153 .89234 L .38555 .89406 L .435 0 0 r
F
.40416 .89431 m .40086 .89277 L .38555 .89406 L .416 0 0 r
F
.43568 .65569 m .42879 .65526 L .43109 .65607 L .382 0 0 r
F
.43774 .65632 m .43568 .65569 L .43109 .65607 L .398 0 0 r
F
.35286 .88645 m .33249 .88294 L .33762 .88526 L .496 0 0 r
F
.35741 .88855 m .35286 .88645 L .33762 .88526 L .477 0 0 r
F
.49811 .65849 m .49635 .66257 L .49443 .66196 L .995 1 0 r
F
.49811 .65849 m .50034 .65908 L .49635 .66257 L F
.50657 .64029 m .50571 .64211 L .50349 .64216 L .562 .731 0 r
F
.50657 .64029 m .509 .64017 L .50571 .64211 L F
.75374 .57717 m .75496 .58499 L .75307 .58958 L .846 .21 0 r
F
.75374 .57717 m .75558 .57244 L .75496 .58499 L F
.44026 .6432 m .43435 .64193 L .43656 .64232 L 0 .13 0 r
F
.44224 .64344 m .44026 .6432 L .43656 .64232 L 0 .132 0 r
F
.57079 .60419 m .57157 .60687 L .56936 .6084 L .757 .644 0 r
F
.57079 .60419 m .57304 .60255 L .57157 .60687 L F
.56776 .91475 m .55757 .91669 L .55337 .91782 L 0 0 0 r
F
.56776 .91475 m .57269 .91351 L .55757 .91669 L F
.63943 .50059 m .64655 .50615 L .64607 .50905 L 1 .691 0 r
F
.63943 .50059 m .63961 .49769 L .64655 .50615 L F
.35266 .69018 m .34207 .68601 L .34409 .69029 L 1 .255 0 r
F
.35474 .69406 m .35266 .69018 L .34409 .69029 L 1 .287 0 r
F
.45054 .65569 m .44428 .65618 L .44608 .65665 L .233 0 0 r
F
.45203 .65598 m .45054 .65569 L .44608 .65665 L .246 0 0 r
F
.48891 .64482 m .49062 .6451 L .48696 .64654 L .59 .775 0 r
F
.64665 .70935 m .64607 .71564 L .6417 .71749 L .687 .732 0 r
F
.64665 .70935 m .65123 .70739 L .64607 .71564 L F
.52349 .65068 m .52298 .65393 L .52028 .65394 L .745 .972 0 r
F
.52349 .65068 m .52638 .6506 L .52298 .65393 L F
.62454 .5681 m .62766 .57311 L .62602 .57567 L 1 .814 0 r
F
.62454 .5681 m .6261 .56545 L .62766 .57311 L F
.59337 .91418 m .58382 .9161 L .57893 .91765 L 0 0 0 r
F
.59337 .91418 m .59893 .91248 L .58382 .9161 L F
.62526 .50706 m .62905 .51169 L .6284 .51429 L 1 .581 0 r
F
.62526 .50706 m .62587 .50441 L .62905 .51169 L F
.90275 .5885 m .89956 .5996 L .89771 .60661 L 0 0 0 r
F
.90275 .5885 m .90466 .58129 L .89956 .5996 L F
.28074 .86068 m .26037 .85301 L .26597 .85643 L .551 0 0 r
F
.28595 .86383 m .28074 .86068 L .26597 .85643 L .532 0 0 r
F
.51303 .92473 m .49984 .92568 L .49809 .92622 L .011 0 0 r
F
.51303 .92473 m .51567 .92414 L .49984 .92568 L F
.63165 .50531 m .63506 .51005 L .63442 .51275 L 1 .495 0 r
F
.63165 .50531 m .63229 .50256 L .63506 .51005 L F
.54757 .62519 m .54771 .62734 L .54522 .62835 L .626 .577 0 r
F
.54757 .62519 m .55015 .62408 L .54771 .62734 L F
.41618 .91839 m .39685 .91614 L .40043 .91724 L .272 0 0 r
F
.41895 .91926 m .41618 .91839 L .40043 .91724 L .239 0 0 r
F
.43458 .91979 m .41618 .91839 L .41895 .91926 L .226 0 0 r
F
.39497 .64359 m .38817 .64042 L .39078 .64185 L .365 0 0 r
F
.39747 .64484 m .39497 .64359 L .39078 .64185 L .361 0 0 r
F
.91158 .41417 m .91295 .42887 L .91391 .436 L 0 0 0 r
F
.91158 .41417 m .91059 .40695 L .91295 .42887 L F
.56901 .92037 m .55861 .92197 L .55437 .92315 L F
.56901 .92037 m .574 .91908 L .55861 .92197 L F
.49904 .64209 m .49788 .64387 L .4959 .64375 L .581 .772 0 r
F
.49904 .64209 m .50127 .64215 L .49788 .64387 L F
.75605 .80505 m .75051 .81061 L .74534 .81502 L .495 .202 0 r
F
.75605 .80505 m .76146 .8004 L .75051 .81061 L F
.51212 .65343 m .51128 .65696 L .50879 .65665 L .841 1 0 r
F
.51212 .65343 m .51485 .65369 L .51128 .65696 L F
.43215 .64151 m .42621 .63968 L .42859 .64025 L 0 .124 0 r
F
.43435 .64193 m .43215 .64151 L .42859 .64025 L 0 .127 0 r
F
.59095 .61429 m .5921 .61812 L .58968 .61995 L .874 .781 0 r
F
.59095 .61429 m .59337 .61232 L .5921 .61812 L F
.56052 .63662 m .56078 .63973 L .55802 .64082 L .711 .766 0 r
F
.56052 .63662 m .56335 .6354 L .56078 .63973 L F
.60808 .56855 m .60983 .57224 L .60816 .57448 L .937 .63 0 r
F
.60808 .56855 m .60976 .56623 L .60983 .57224 L F
.60227 .56811 m .60418 .57175 L .60252 .5739 L .969 .694 0 r
F
.60227 .56811 m .60393 .56587 L .60418 .57175 L F
.51347 .9295 m .50013 .93015 L .49836 .9307 L .037 0 0 r
F
.51347 .9295 m .51615 .92891 L .50013 .93015 L F
.22844 .83057 m .20887 .81978 L .21427 .82405 L .595 .009 0 r
F
.23356 .83453 m .22844 .83057 L .21427 .82405 L .576 .003 0 r
F
.44428 .65618 m .43774 .65632 L .43982 .65697 L .328 0 0 r
F
.44608 .65665 m .44428 .65618 L .43982 .65697 L .346 0 0 r
F
.50379 .65579 m .50257 .65959 L .50034 .65908 L .929 1 0 r
F
.50379 .65579 m .50629 .65626 L .50257 .65959 L F
.53791 .64635 m .53777 .64936 L .53495 .6498 L .682 .863 0 r
F
.53791 .64635 m .54086 .6458 L .53777 .64936 L F
.40591 .63237 m .40034 .62879 L .40284 .62989 L 0 .107 0 r
F
.40832 .63331 m .40591 .63237 L .40284 .62989 L 0 .111 0 r
F
.41532 .9252 m .39574 .92267 L .39937 .92373 L .26 0 0 r
F
.41814 .92603 m .41532 .9252 L .39937 .92373 L .225 0 0 r
F
.4265 .65446 m .41954 .65343 L .42202 .65442 L .41 0 0 r
F
.42879 .65526 m .4265 .65446 L .42202 .65442 L .425 0 0 r
F
.57362 .60771 m .57436 .6104 L .57208 .61196 L .737 .617 0 r
F
.57362 .60771 m .57595 .60605 L .57436 .6104 L F
.56909 .72911 m .57046 .74359 L .56571 .74213 L .943 .974 0 r
F
.56909 .72911 m .57425 .7309 L .57046 .74359 L F
.4215 .63844 m .41566 .6359 L .41815 .63669 L 0 .118 0 r
F
.42385 .63908 m .4215 .63844 L .41815 .63669 L 0 .121 0 r
F
.4533 .64451 m .44788 .64417 L .44961 .64424 L .052 .147 0 r
F
.45474 .64446 m .4533 .64451 L .44961 .64424 L .066 .15 0 r
F
.82602 .72417 m .82226 .73218 L .81824 .73788 L .646 .204 0 r
F
.82602 .72417 m .83015 .71822 L .82226 .73218 L F
.37538 .71197 m .36325 .71121 L .36541 .71603 L 1 .366 0 r
F
.37756 .71625 m .37538 .71197 L .36541 .71603 L 1 .39 0 r
F
.5272 .76238 m .52604 .7885 L .52261 .7866 L 1 1 0 r
F
.5272 .76238 m .53119 .76527 L .52604 .7885 L F
.56851 .60579 m .56936 .6084 L .56712 .6099 L .757 .663 0 r
F
.56851 .60579 m .57079 .60419 L .56936 .6084 L F
.44788 .64417 m .44224 .64344 L .44424 .64366 L .009 .138 0 r
F
.44961 .64424 m .44788 .64417 L .44424 .64366 L .019 .14 0 r
F
.52712 .63391 m .52699 .63582 L .52447 .63636 L .574 .639 0 r
F
.52712 .63391 m .52977 .63329 L .52699 .63582 L F
.63919 .5035 m .64607 .50905 L .64555 .51194 L 1 .706 0 r
F
.63919 .5035 m .63943 .50059 L .64607 .50905 L F
.6246 .5097 m .6284 .51429 L .6277 .51689 L 1 .606 0 r
F
.6246 .5097 m .62526 .50706 L .6284 .51429 L F
.51424 .63792 m .51382 .63977 L .51142 .64 L .565 .713 0 r
F
.51424 .63792 m .51682 .63762 L .51382 .63977 L F
.62292 .57074 m .62602 .57567 L .62434 .5782 L 1 .828 0 r
F
.62292 .57074 m .62454 .5681 L .62602 .57567 L F
.63097 .50804 m .63442 .51275 L .63373 .51544 L 1 .525 0 r
F
.63097 .50804 m .63165 .50531 L .63442 .51275 L F
.39472 .72331 m .38196 .7256 L .38417 .73076 L 1 .345 0 r
F
.39688 .72781 m .39472 .72331 L .38417 .73076 L 1 .365 0 r
F
.76458 .81478 m .75816 .81966 L .7529 .82424 L 0 0 0 r
F
.76458 .81478 m .77013 .80996 L .75816 .81966 L F
.34735 .9053 m .32669 .89972 L .33212 .90188 L .374 0 0 r
F
.35221 .90717 m .34735 .9053 L .33212 .90188 L .345 0 0 r
F
.60057 .57033 m .60252 .5739 L .60082 .57603 L .971 .714 0 r
F
.60057 .57033 m .60227 .56811 L .60252 .5739 L F
.60636 .57085 m .60816 .57448 L .60644 .5767 L .94 .653 0 r
F
.60636 .57085 m .60808 .56855 L .60816 .57448 L F
.27306 .87599 m .2527 .86655 L .25855 .87001 L .467 0 0 r
F
.27854 .87913 m .27306 .87599 L .25855 .87001 L .441 0 0 r
F
.32242 .878 m .30201 .8727 L .3075 .87547 L .516 0 0 r
F
.32742 .88051 m .32242 .878 L .3075 .87547 L .496 0 0 r
F
.54497 .62625 m .54522 .62835 L .5427 .62931 L .623 .603 0 r
F
.54497 .62625 m .54757 .62519 L .54522 .62835 L F
.39685 .91614 m .37703 .91299 L .38133 .91435 L .302 0 0 r
F
.40043 .91724 m .39685 .91614 L .38133 .91435 L .271 0 0 r
F
.4258 .72529 m .41377 .73219 L .41583 .73716 L .835 .146 0 r
F
.42768 .72937 m .4258 .72529 L .41583 .73716 L .832 .168 0 r
F
.51916 .78433 m .51579 .81067 L .51296 .80956 L 1 1 0 r
F
.51916 .78433 m .52261 .7866 L .51579 .81067 L F
.58848 .61621 m .58968 .61995 L .58722 .62173 L .87 .794 0 r
F
.58848 .61621 m .59095 .61429 L .58968 .61995 L F
.69989 .66782 m .69925 .67369 L .69573 .67707 L .723 .296 0 r
F
.69989 .66782 m .7035 .66427 L .69925 .67369 L F
.41462 .65146 m .4077 .64963 L .4103 .6508 L .401 0 0 r
F
.41707 .65245 m .41462 .65146 L .4103 .6508 L .41 0 0 r
F
.21938 .84363 m .20004 .83118 L .20563 .83558 L .534 0 0 r
F
.22471 .8477 m .21938 .84363 L .20563 .83558 L .512 0 0 r
F
.59838 .72489 m .59912 .73459 L .5943 .73449 L .84 1 0 r
F
.59838 .72489 m .60354 .72509 L .59912 .73459 L F
.34553 .91154 m .32458 .90583 L .33012 .90795 L .354 0 0 r
F
.35048 .91337 m .34553 .91154 L .33012 .90795 L .323 0 0 r
F
.83779 .73226 m .83244 .73948 L .82832 .74537 L 0 0 0 r
F
.83779 .73226 m .84208 .72613 L .83244 .73948 L F
.7518 .58187 m .75307 .58958 L .75108 .59413 L .848 .213 0 r
F
.7518 .58187 m .75374 .57717 L .75307 .58958 L F
.55766 .63777 m .55802 .64082 L .55524 .64183 L .709 .785 0 r
F
.55766 .63777 m .56052 .63662 L .55802 .64082 L F
.57126 .60934 m .57208 .61196 L .56977 .61349 L .737 .637 0 r
F
.57126 .60934 m .57362 .60771 L .57208 .61196 L F
.88194 .59067 m .88372 .60247 L .88176 .60921 L .838 .193 0 r
F
.88194 .59067 m .88367 .58373 L .88372 .60247 L F
.39747 .64484 m .39078 .64185 L .39341 .64325 L .361 0 0 r
F
.4 .64607 m .39747 .64484 L .39341 .64325 L .359 0 0 r
F
.26994 .8822 m .24922 .87268 L .25521 .87612 L .451 0 0 r
F
.27555 .88532 m .26994 .8822 L .25521 .87612 L .425 0 0 r
F
.41171 .72769 m .39905 .73267 L .40123 .73795 L .97 .268 0 r
F
.41377 .73219 m .41171 .72769 L .40123 .73795 L .967 .288 0 r
F
.4871 .66426 m .48448 .66921 L .48326 .66851 L 1 1 0 r
F
.39574 .92267 m .37565 .91931 L .38003 .92062 L .285 0 0 r
F
.39937 .92373 m .39574 .92267 L .38003 .92062 L .251 0 0 r
F
.5662 .60735 m .56712 .6099 L .56484 .61136 L .756 .68 0 r
F
.5662 .60735 m .56851 .60579 L .56712 .6099 L F
.43651 .92044 m .43458 .91979 L .41895 .91926 L .192 0 0 r
F
.52059 .65067 m .52028 .65394 L .51757 .65386 L .764 .993 0 r
F
.52059 .65067 m .52349 .65068 L .52028 .65394 L F
.50413 .64035 m .50349 .64216 L .50127 .64215 L .591 .785 0 r
F
.50413 .64035 m .50657 .64029 L .50349 .64216 L F
.62389 .51234 m .6277 .51689 L .62696 .51948 L 1 .63 0 r
F
.62389 .51234 m .6246 .5097 L .6277 .51689 L F
.76536 .46566 m .77163 .47481 L .77179 .4797 L .915 .163 0 r
F
.40832 .63331 m .40284 .62989 L .40536 .63094 L 0 .111 0 r
F
.41074 .63421 m .40832 .63331 L .40536 .63094 L 0 .114 0 r
F
.63887 .50642 m .64555 .51194 L .645 .51484 L 1 .721 0 r
F
.63887 .50642 m .63919 .5035 L .64555 .51194 L F
.63024 .51078 m .63373 .51544 L .63299 .51812 L 1 .554 0 r
F
.63024 .51078 m .63097 .50804 L .63373 .51544 L F
.21506 .84984 m .1953 .83731 L .20104 .84171 L .522 0 0 r
F
.22054 .85391 m .21506 .84984 L .20104 .84171 L .499 0 0 r
F
.62126 .57334 m .62434 .5782 L .62261 .58071 L 1 .842 0 r
F
.62126 .57334 m .62292 .57074 L .62434 .5782 L F
.44836 .71186 m .4386 .72078 L .44022 .72437 L .436 .034 0 r
F
.44965 .71444 m .44836 .71186 L .44022 .72437 L .435 .038 0 r
F
.44224 .64344 m .43656 .64232 L .43878 .64268 L 0 .132 0 r
F
.44424 .64366 m .44224 .64344 L .43878 .64268 L 0 .134 0 r
F
.59884 .57251 m .60082 .57603 L .59909 .57813 L .972 .734 0 r
F
.59884 .57251 m .60057 .57033 L .60082 .57603 L F
.6046 .57312 m .60644 .5767 L .60469 .57888 L .943 .675 0 r
F
.6046 .57312 m .60636 .57085 L .60644 .5767 L F
.64198 .71113 m .6417 .71749 L .63723 .71917 L .699 .785 0 r
F
.64198 .71113 m .64665 .70935 L .6417 .71749 L F
.49192 .64335 m .49062 .6451 L .48891 .64482 L .63 .837 0 r
F
.49192 .64335 m .49391 .64358 L .49062 .6451 L F
.53493 .64681 m .53495 .6498 L .53212 .65016 L .69 .889 0 r
F
.53493 .64681 m .53791 .64635 L .53495 .6498 L F
.43774 .65632 m .43109 .65607 L .43341 .65691 L .398 0 0 r
F
.43982 .65697 m .43774 .65632 L .43341 .65691 L .42 0 0 r
F
.43435 .64193 m .42859 .64025 L .43099 .6408 L 0 .127 0 r
F
.43656 .64232 m .43435 .64193 L .43099 .6408 L 0 .129 0 r
F
.35474 .69406 m .34409 .69029 L .34613 .69473 L 1 .287 0 r
F
.35684 .69808 m .35474 .69406 L .34613 .69473 L 1 .32 0 r
F
.90241 .42276 m .90359 .43704 L .90322 .44413 L .801 .173 0 r
F
.90241 .42276 m .90341 .4154 L .90359 .43704 L F
.53454 .74387 m .53516 .76778 L .53119 .76527 L 1 .963 0 r
F
.53454 .74387 m .53899 .74709 L .53516 .76778 L F
.42385 .63908 m .41815 .63669 L .42065 .63745 L 0 .121 0 r
F
.42621 .63968 m .42385 .63908 L .42065 .63745 L 0 .124 0 r
F
.52444 .63447 m .52447 .63636 L .52194 .63684 L .576 .678 0 r
F
.52444 .63447 m .52712 .63391 L .52447 .63636 L F
.50938 .65308 m .50879 .65665 L .50629 .65626 L .865 1 0 r
F
.50938 .65308 m .51212 .65343 L .50879 .65665 L F
.64744 .87444 m .64059 .87815 L .63499 .88047 L .337 .193 0 r
F
.64744 .87444 m .65352 .87197 L .64059 .87815 L F
.4968 .64198 m .4959 .64375 L .49391 .64358 L .621 .83 0 r
F
.4968 .64198 m .49904 .64209 L .4959 .64375 L F
.49588 .65783 m .49443 .66196 L .4925 .66126 L 1 1 0 r
F
.49588 .65783 m .49811 .65849 L .49443 .66196 L F
.54234 .62726 m .5427 .62931 L .54016 .63021 L .621 .629 0 r
F
.54234 .62726 m .54497 .62625 L .5427 .62931 L F
.58597 .61808 m .58722 .62173 L .58472 .62346 L .865 .807 0 r
F
.58597 .61808 m .58848 .61621 L .58722 .62173 L F
.54633 .73252 m .54789 .7524 L .54345 .74994 L 1 .928 0 r
F
.54633 .73252 m .5512 .73549 L .54789 .7524 L F
.31602 .89505 m .29544 .88789 L .30122 .89059 L .408 0 0 r
F
.32132 .89744 m .31602 .89505 L .30122 .89059 L .38 0 0 r
F
.56887 .61093 m .56977 .61349 L .56742 .61497 L .737 .656 0 r
F
.56887 .61093 m .57126 .60934 L .56977 .61349 L F
.51164 .63816 m .51142 .64 L .509 .64017 L .581 .761 0 r
F
.51164 .63816 m .51424 .63792 L .51142 .64 L F
.62313 .51497 m .62696 .51948 L .62616 .52206 L 1 .655 0 r
F
.62313 .51497 m .62389 .51234 L .62696 .51948 L F
.90071 .5957 m .89771 .60661 L .89573 .61359 L .684 .172 0 r
F
.90071 .5957 m .90275 .5885 L .89771 .60661 L F
.56386 .60887 m .56484 .61136 L .56254 .61277 L .755 .697 0 r
F
.56386 .60887 m .5662 .60735 L .56484 .61136 L F
.42879 .65526 m .42202 .65442 L .42452 .65542 L .425 0 0 r
F
.43109 .65607 m .42879 .65526 L .42452 .65542 L .445 0 0 r
F
.45203 .65598 m .44608 .65665 L .44789 .65715 L .246 0 0 r
F
.45354 .6563 m .45203 .65598 L .44789 .65715 L .268 0 0 r
F
.62946 .5135 m .63299 .51812 L .63219 .52079 L 1 .582 0 r
F
.62946 .5135 m .63024 .51078 L .63299 .51812 L F
.59706 .57467 m .59909 .57813 L .59731 .5802 L .972 .753 0 r
F
.59706 .57467 m .59884 .57251 L .59909 .57813 L F
.50128 .65524 m .50034 .65908 L .49811 .65849 L .956 1 0 r
F
.50128 .65524 m .50379 .65579 L .50034 .65908 L F
.55476 .63886 m .55524 .64183 L .55242 .64278 L .707 .803 0 r
F
.55476 .63886 m .55766 .63777 L .55524 .64183 L F
.63848 .50934 m .645 .51484 L .64439 .51773 L 1 .737 0 r
F
.63848 .50934 m .63887 .50642 L .645 .51484 L F
.60279 .57537 m .60469 .57888 L .60289 .58103 L .945 .696 0 r
F
.60279 .57537 m .6046 .57312 L .60469 .57888 L F
.91243 .42142 m .91391 .436 L .91474 .44316 L 0 0 0 r
F
.91243 .42142 m .91158 .41417 L .91391 .436 L F
.4386 .72078 m .42768 .72937 L .42955 .73396 L .664 .064 0 r
F
.44022 .72437 m .4386 .72078 L .42955 .73396 L .661 .067 0 r
F
.61954 .57593 m .62261 .58071 L .62083 .58319 L 1 .855 0 r
F
.61954 .57593 m .62126 .57334 L .62261 .58071 L F
.3137 .90124 m .29281 .89398 L .29871 .89664 L .389 0 0 r
F
.31911 .9036 m .3137 .90124 L .29871 .89664 L .36 0 0 r
F
.61188 .88829 m .6044 .8918 L .5991 .89342 L .316 .192 0 r
F
.61188 .88829 m .61775 .88656 L .6044 .8918 L F
.44608 .65665 m .43982 .65697 L .44191 .65766 L .346 0 0 r
F
.44789 .65715 m .44608 .65665 L .44191 .65766 L .372 0 0 r
F
.4 .64607 m .39341 .64325 L .39607 .64463 L .359 0 0 r
F
.40254 .64727 m .4 .64607 L .39607 .64463 L .361 0 0 r
F
.41707 .65245 m .4103 .6508 L .41293 .65197 L .41 0 0 r
F
.41954 .65343 m .41707 .65245 L .41293 .65197 L .424 0 0 r
F
.41074 .63421 m .40536 .63094 L .4079 .63196 L 0 .114 0 r
F
.41319 .63507 m .41074 .63421 L .4079 .63196 L 0 .118 0 r
F
.6962 .67129 m .69573 .67707 L .69212 .68037 L .722 .333 0 r
F
.6962 .67129 m .69989 .66782 L .69573 .67707 L F
.44961 .64424 m .44424 .64366 L .44625 .64385 L .019 .14 0 r
F
.45136 .6443 m .44961 .64424 L .44625 .64385 L .022 .142 0 r
F
.45474 .64446 m .44961 .64424 L .45136 .6443 L .066 .15 0 r
F
.6527 .88621 m .64526 .88911 L .63957 .89166 L 0 0 0 r
F
.6527 .88621 m .65888 .88347 L .64526 .88911 L F
.45619 .64439 m .45474 .64446 L .45136 .6443 L .072 .152 0 r
F
.56389 .72693 m .56571 .74213 L .56091 .7403 L .938 .939 0 r
F
.56389 .72693 m .56909 .72911 L .56571 .74213 L F
.74976 .58654 m .75108 .59413 L .74901 .59864 L .848 .215 0 r
F
.74976 .58654 m .7518 .58187 L .75108 .59413 L F
.54291 .90805 m .53273 .91084 L .52931 .91142 L .237 .181 0 r
F
.54291 .90805 m .54712 .90745 L .53273 .91084 L F
.82179 .73006 m .81824 .73788 L .8141 .74352 L .65 .207 0 r
F
.82179 .73006 m .82602 .72417 L .81824 .73788 L F
.62232 .51759 m .62616 .52206 L .62532 .52463 L 1 .679 0 r
F
.62232 .51759 m .62313 .51497 L .62616 .52206 L F
.75054 .8096 m .74534 .81502 L .74008 .81933 L .5 .204 0 r
F
.75054 .8096 m .75605 .80505 L .74534 .81502 L F
.56645 .61247 m .56742 .61497 L .56504 .61641 L .736 .675 0 r
F
.56645 .61247 m .56887 .61093 L .56742 .61497 L F
.58342 .61991 m .58472 .62346 L .58218 .62515 L .86 .819 0 r
F
.58342 .61991 m .58597 .61808 L .58472 .62346 L F
.51767 .65056 m .51757 .65386 L .51485 .65369 L .783 1 0 r
F
.51767 .65056 m .52059 .65067 L .51757 .65386 L F
.37756 .71625 m .36541 .71603 L .36759 .72113 L 1 .39 0 r
F
.37975 .72078 m .37756 .71625 L .36759 .72113 L 1 .414 0 r
F
.53193 .64718 m .53212 .65016 L .52926 .65043 L .698 .912 0 r
F
.53193 .64718 m .53493 .64681 L .53212 .65016 L F
.53968 .62822 m .54016 .63021 L .5376 .63107 L .618 .654 0 r
F
.53968 .62822 m .54234 .62726 L .54016 .63021 L F
.56149 .61035 m .56386 .60887 L .56254 .61277 L .753 .713 0 r
F
.59524 .57681 m .59731 .5802 L .59549 .58224 L .972 .77 0 r
F
.59524 .57681 m .59706 .57467 L .59731 .5802 L F
.76561 .47057 m .77179 .4797 L .77185 .48461 L .92 .167 0 r
F
.76561 .47057 m .76536 .46566 L .77179 .4797 L F
.65519 .89179 m .64756 .89454 L .64181 .89716 L 0 0 0 r
F
.65519 .89179 m .66144 .88898 L .64756 .89454 L F
.62863 .51622 m .63219 .52079 L .63135 .52345 L 1 .609 0 r
F
.62863 .51622 m .62946 .5135 L .63219 .52079 L F
.52175 .63497 m .52194 .63684 L .51939 .63726 L .579 .717 0 r
F
.52175 .63497 m .52444 .63447 L .52194 .63684 L F
.50169 .64036 m .50127 .64215 L .49904 .64209 L .623 .834 0 r
F
.50169 .64036 m .50413 .64035 L .50127 .64215 L F
.60094 .57758 m .60289 .58103 L .60105 .58316 L .946 .716 0 r
F
.60094 .57758 m .60279 .57537 L .60289 .58103 L F
.38153 .89234 m .36203 .89056 L .3667 .89248 L .457 0 0 r
F
.38555 .89406 m .38153 .89234 L .3667 .89248 L .439 0 0 r
F
.59315 .72438 m .5943 .73449 L .58939 .73409 L .836 1 0 r
F
.59315 .72438 m .59838 .72489 L .5943 .73449 L F
.42621 .63968 m .42065 .63745 L .42318 .63817 L 0 .124 0 r
F
.42859 .64025 m .42621 .63968 L .42318 .63817 L 0 .127 0 r
F
.61612 .90061 m .60806 .90313 L .60269 .90502 L 0 0 0 r
F
.61612 .90061 m .62208 .89857 L .60806 .90313 L F
.63802 .51226 m .64439 .51773 L .64374 .52062 L 1 .753 0 r
F
.63802 .51226 m .63848 .50934 L .64439 .51773 L F
.61777 .57848 m .62083 .58319 L .61899 .58563 L 1 .868 0 r
F
.61777 .57848 m .61954 .57593 L .62083 .58319 L F
.23356 .83453 m .21427 .82405 L .21975 .82822 L .576 .003 0 r
F
.23876 .8384 m .23356 .83453 L .21975 .82822 L .557 0 0 r
F
.43656 .64232 m .43099 .6408 L .4334 .64131 L 0 .129 0 r
F
.43878 .64268 m .43656 .64232 L .4334 .64131 L 0 .131 0 r
F
.63723 .71273 m .63723 .71917 L .63269 .72067 L .708 .831 0 r
F
.63723 .71273 m .64198 .71113 L .63723 .71917 L F
.44424 .64366 m .43878 .64268 L .44102 .64302 L 0 .134 0 r
F
.44625 .64385 m .44424 .64366 L .44102 .64302 L 0 .135 0 r
F
.55184 .63987 m .55242 .64278 L .54957 .64365 L .704 .82 0 r
F
.55184 .63987 m .55476 .63886 L .55242 .64278 L F
.54485 .91968 m .53423 .92136 L .53075 .92214 L 0 0 0 r
F
.54485 .91968 m .54913 .91882 L .53423 .92136 L F
.88009 .59759 m .88176 .60921 L .87968 .61593 L .838 .196 0 r
F
.88009 .59759 m .88194 .59067 L .88176 .60921 L F
.28595 .86383 m .26597 .85643 L .27165 .85977 L .532 0 0 r
F
.29123 .86688 m .28595 .86383 L .27165 .85977 L .512 0 0 r
F
.61812 .90643 m .60986 .90869 L .60443 .91065 L 0 0 0 r
F
.61812 .90643 m .62415 .9043 L .60986 .90869 L F
.50904 .63834 m .509 .64017 L .50657 .64029 L .607 .806 0 r
F
.50904 .63834 m .51164 .63816 L .509 .64017 L F
.62147 .5202 m .62532 .52463 L .62443 .52718 L 1 .702 0 r
F
.62147 .5202 m .62232 .51759 L .62532 .52463 L F
.39688 .72781 m .38417 .73076 L .3864 .73631 L 1 .365 0 r
F
.39905 .73267 m .39688 .72781 L .3864 .73631 L 1 .385 0 r
F
.50665 .65266 m .50629 .65626 L .50379 .65579 L .89 1 0 r
F
.50665 .65266 m .50938 .65308 L .50629 .65626 L F
.75894 .8195 m .7529 .82424 L .74754 .82873 L 0 0 0 r
F
.75894 .8195 m .76458 .81478 L .7529 .82424 L F
.83338 .73832 m .82832 .74537 L .82409 .75118 L .574 .194 0 r
F
.83338 .73832 m .83779 .73226 L .82832 .74537 L F
.59338 .57891 m .59549 .58224 L .59363 .58425 L .971 .787 0 r
F
.59338 .57891 m .59524 .57681 L .59549 .58224 L F
.564 .61397 m .56645 .61247 L .56504 .61641 L .735 .692 0 r
F
.48991 .64307 m .48891 .64482 L .48719 .64449 L .682 .9 0 r
F
.48991 .64307 m .49192 .64335 L .48891 .64482 L F
.43982 .65697 m .43341 .65691 L .43574 .65779 L .42 0 0 r
F
.44191 .65766 m .43982 .65697 L .43574 .65779 L .448 0 0 r
F
.35684 .69808 m .34613 .69473 L .34818 .69935 L 1 .32 0 r
F
.35896 .70227 m .35684 .69808 L .34818 .69935 L 1 .353 0 r
F
.54576 .92509 m .53495 .92641 L .53144 .92721 L 0 0 0 r
F
.54576 .92509 m .55009 .92418 L .53495 .92641 L F
.41319 .63507 m .4079 .63196 L .41047 .63294 L 0 .118 0 r
F
.41566 .6359 m .41319 .63507 L .41047 .63294 L .007 .121 0 r
F
.62775 .51892 m .63135 .52345 L .63046 .5261 L 1 .636 0 r
F
.62775 .51892 m .62863 .51622 L .63135 .52345 L F
.59905 .57977 m .60105 .58316 L .59917 .58525 L .947 .736 0 r
F
.59905 .57977 m .60094 .57758 L .60105 .58316 L F
.58083 .62168 m .58218 .62515 L .5796 .62678 L .854 .83 0 r
F
.58083 .62168 m .58342 .61991 L .58218 .62515 L F
.49455 .64182 m .49391 .64358 L .49192 .64335 L .663 .883 0 r
F
.49455 .64182 m .4968 .64198 L .49391 .64358 L F
.40254 .64727 m .39607 .64463 L .39874 .646 L .361 0 0 r
F
.40511 .64846 m .40254 .64727 L .39874 .646 L .366 0 0 r
F
.52725 .92278 m .51567 .92414 L .51303 .92473 L 0 0 0 r
F
.52725 .92278 m .53075 .92214 L .51567 .92414 L F
.90006 .43023 m .90322 .44413 L .90263 .45122 L .883 .222 0 r
F
.90006 .43023 m .90241 .42276 L .90322 .44413 L F
.537 .62911 m .5376 .63107 L .53501 .63186 L .615 .679 0 r
F
.537 .62911 m .53968 .62822 L .5376 .63107 L F
.58284 .89735 m .57477 .90074 L .56996 .90183 L .312 .193 0 r
F
.58284 .89735 m .58832 .8962 L .57477 .90074 L F
.43109 .65607 m .42452 .65542 L .42703 .65645 L .445 0 0 r
F
.43341 .65691 m .43109 .65607 L .42703 .65645 L .471 0 0 r
F
.61594 .58101 m .61899 .58563 L .61712 .58805 L 1 .881 0 r
F
.61594 .58101 m .61777 .57848 L .61899 .58563 L F
.6375 .51518 m .64374 .52062 L .64304 .52351 L 1 .77 0 r
F
.6375 .51518 m .63802 .51226 L .64374 .52062 L F
.74763 .59118 m .74901 .59864 L .74684 .60312 L .849 .233 0 r
F
.74763 .59118 m .74976 .58654 L .74901 .59864 L F
.41954 .65343 m .41293 .65197 L .41557 .65314 L .424 0 0 r
F
.42202 .65442 m .41954 .65343 L .41557 .65314 L .443 0 0 r
F
.49364 .65709 m .49588 .65783 L .4925 .66126 L 1 1 0 r
F
.52789 .92788 m .51615 .92891 L .51347 .9295 L 0 0 0 r
F
.52789 .92788 m .53144 .92721 L .51615 .92891 L F
.52891 .64744 m .52926 .65043 L .52638 .6506 L .706 .932 0 r
F
.52891 .64744 m .53193 .64718 L .52926 .65043 L F
.69241 .67467 m .69212 .68037 L .68843 .68357 L .72 .371 0 r
F
.69241 .67467 m .6962 .67129 L .69212 .68037 L F
.51905 .6354 m .51939 .63726 L .51682 .63762 L .589 .755 0 r
F
.51905 .6354 m .52175 .63497 L .51939 .63726 L F
.22471 .8477 m .20563 .83558 L .21131 .83989 L .512 0 0 r
F
.23013 .85168 m .22471 .8477 L .21131 .83989 L .489 0 0 r
F
.52321 .75911 m .52261 .7866 L .51916 .78433 L 1 1 0 r
F
.52321 .75911 m .5272 .76238 L .52261 .7866 L F
.49878 .65462 m .49811 .65849 L .49588 .65783 L .983 1 0 r
F
.49878 .65462 m .50128 .65524 L .49811 .65849 L F
.62056 .5228 m .62443 .52718 L .62349 .52973 L 1 .725 0 r
F
.62056 .5228 m .62147 .5202 L .62443 .52718 L F
.48194 .93183 m .46698 .93174 L .46709 .93214 L .086 0 0 r
F
.48194 .93183 m .48278 .93145 L .46698 .93174 L F
.35741 .88855 m .33762 .88526 L .34281 .8875 L .477 0 0 r
F
.36203 .89056 m .35741 .88855 L .34281 .8875 L .458 0 0 r
F
.59149 .58098 m .59363 .58425 L .59174 .58623 L .97 .803 0 r
F
.59149 .58098 m .59338 .57891 L .59363 .58425 L F
.42208 .8931 m .40416 .89431 L .4075 .89576 L .369 0 0 r
F
.42465 .8944 m .42208 .8931 L .4075 .89576 L .35 0 0 r
F
.43891 .89024 m .42208 .8931 L .42465 .8944 L .288 0 0 r
F
.89853 .60287 m .89573 .61359 L .89361 .62055 L .693 .176 0 r
F
.89853 .60287 m .90071 .5957 L .89573 .61359 L F
.51475 .65035 m .51485 .65369 L .51212 .65343 L .802 1 0 r
F
.51475 .65035 m .51767 .65056 L .51485 .65369 L F
.42768 .72937 m .41583 .73716 L .4179 .74271 L .832 .168 0 r
F
.42955 .73396 m .42768 .72937 L .4179 .74271 L .828 .189 0 r
F
.37703 .91299 m .35713 .90892 L .3621 .91056 L .317 0 0 r
F
.38133 .91435 m .37703 .91299 L .3621 .91056 L .287 0 0 r
F
.54888 .6408 m .54957 .64365 L .5467 .64445 L .701 .835 0 r
F
.54888 .6408 m .55184 .63987 L .54957 .64365 L F
.59712 .58193 m .59917 .58525 L .59725 .58731 L .947 .754 0 r
F
.59712 .58193 m .59905 .57977 L .59917 .58525 L F
.76575 .47549 m .77185 .48461 L .7718 .48952 L .928 .171 0 r
F
.76575 .47549 m .76561 .47057 L .77185 .48461 L F
.62683 .52162 m .63046 .5261 L .62953 .52874 L 1 .662 0 r
F
.62683 .52162 m .62775 .51892 L .63046 .5261 L F
.42859 .64025 m .42318 .63817 L .42572 .63887 L 0 .127 0 r
F
.43099 .6408 m .42859 .64025 L .42572 .63887 L .008 .129 0 r
F
.41377 .73219 m .40123 .73795 L .40342 .74374 L .967 .288 0 r
F
.41583 .73716 m .41377 .73219 L .40342 .74374 L .963 .307 0 r
F
.54146 .72918 m .54345 .74994 L .53899 .74709 L 1 .901 0 r
F
.54146 .72918 m .54633 .73252 L .54345 .74994 L F
.45354 .6563 m .44789 .65715 L .44971 .65771 L .268 0 0 r
F
.27854 .87913 m .25855 .87001 L .26449 .87336 L .441 0 0 r
F
.2841 .88216 m .27854 .87913 L .26449 .87336 L .416 0 0 r
F
.56019 .90354 m .55129 .90671 L .54712 .90745 L .294 .19 0 r
F
.56019 .90354 m .5651 .90276 L .55129 .90671 L F
.91314 .4287 m .91474 .44316 L .91544 .45035 L .71 .125 0 r
F
.91314 .4287 m .91243 .42142 L .91474 .44316 L F
.45136 .6443 m .44625 .64385 L .44827 .64404 L .022 .142 0 r
F
.45311 .64435 m .45136 .6443 L .44827 .64404 L .015 .141 0 r
F
.45619 .64439 m .45136 .6443 L .45311 .64435 L .072 .152 0 r
F
.5782 .62341 m .5796 .62678 L .57698 .62836 L .848 .84 0 r
F
.5782 .62341 m .58083 .62168 L .5796 .62678 L F
.49923 .64032 m .49904 .64209 L .4968 .64198 L .657 .879 0 r
F
.49923 .64032 m .50169 .64036 L .49904 .64209 L F
.22054 .85391 m .20104 .84171 L .20688 .846 L .499 0 0 r
F
.2261 .85788 m .22054 .85391 L .20688 .846 L .475 0 0 r
F
.5862 .9099 m .57758 .91214 L .57269 .91351 L 0 0 0 r
F
.5862 .9099 m .59175 .90841 L .57758 .91214 L F
.49657 .93111 m .48278 .93145 L .48194 .93183 L .049 0 0 r
F
.49657 .93111 m .49836 .9307 L .48278 .93145 L F
.44789 .65715 m .44191 .65766 L .444 .65841 L .372 0 0 r
F
.44971 .65771 m .44789 .65715 L .444 .65841 L .403 0 0 r
F
.61407 .58351 m .61712 .58805 L .61519 .59044 L 1 .893 0 r
F
.61407 .58351 m .61594 .58101 L .61712 .58805 L F
.55865 .72436 m .56091 .7403 L .55607 .73809 L .933 .905 0 r
F
.55865 .72436 m .56389 .72693 L .56091 .7403 L F
.5301 .7403 m .53119 .76527 L .5272 .76238 L 1 .939 0 r
F
.5301 .7403 m .53454 .74387 L .53119 .76527 L F
.45764 .6443 m .45619 .64439 L .45311 .64435 L .069 .151 0 r
F
.63691 .51809 m .64304 .52351 L .64229 .52638 L 1 .787 0 r
F
.63691 .51809 m .6375 .51518 L .64304 .52351 L F
.37565 .91931 m .35549 .91507 L .36055 .91665 L .296 0 0 r
F
.38003 .92062 m .37565 .91931 L .36055 .91665 L .263 0 0 r
F
.41566 .6359 m .41047 .63294 L .41305 .63389 L .007 .121 0 r
F
.41815 .63669 m .41566 .6359 L .41305 .63389 L .02 .124 0 r
F
.5343 .62995 m .53501 .63186 L .5324 .6326 L .612 .702 0 r
F
.5343 .62995 m .537 .62911 L .53501 .63186 L F
.43878 .64268 m .4334 .64131 L .43583 .6418 L 0 .131 0 r
F
.44102 .64302 m .43878 .64268 L .43583 .6418 L 0 .132 0 r
F
.50642 .63847 m .50657 .64029 L .50413 .64035 L .633 .847 0 r
F
.50642 .63847 m .50904 .63834 L .50657 .64029 L F
.6196 .5254 m .62349 .52973 L .62251 .53226 L 1 .747 0 r
F
.6196 .5254 m .62056 .5228 L .62349 .52973 L F
.58783 .72353 m .58939 .73409 L .58441 .73337 L .829 .994 0 r
F
.58783 .72353 m .59315 .72438 L .58939 .73409 L F
.58955 .58303 m .59174 .58623 L .58981 .58818 L .969 .819 0 r
F
.58955 .58303 m .59149 .58098 L .59174 .58623 L F
.32742 .88051 m .3075 .87547 L .31306 .87815 L .496 0 0 r
F
.33249 .88294 m .32742 .88051 L .31306 .87815 L .477 0 0 r
F
.27555 .88532 m .25521 .87612 L .26128 .87944 L .425 0 0 r
F
.28123 .88832 m .27555 .88532 L .26128 .87944 L .398 0 0 r
F
.58776 .91575 m .57893 .91765 L .574 .91908 L 0 0 0 r
F
.58776 .91575 m .59337 .91418 L .57893 .91765 L F
.40511 .64846 m .39874 .646 L .40144 .64736 L .366 0 0 r
F
.4077 .64963 m .40511 .64846 L .40144 .64736 L .375 0 0 r
F
.63237 .71414 m .63723 .71273 L .63269 .72067 L .715 .87 0 r
F
.44965 .71444 m .44022 .72437 L .44184 .72852 L .435 .038 0 r
F
.45095 .71748 m .44965 .71444 L .44184 .72852 L .435 .042 0 r
F
.40416 .89431 m .38555 .89406 L .38961 .89568 L .416 0 0 r
F
.4075 .89576 m .40416 .89431 L .38961 .89568 L .398 0 0 r
F
.59516 .58405 m .59725 .58731 L .59529 .58934 L .946 .771 0 r
F
.59516 .58405 m .59712 .58193 L .59725 .58731 L F
.44625 .64385 m .44102 .64302 L .44327 .64335 L 0 .135 0 r
F
.44827 .64404 m .44625 .64385 L .44327 .64335 L 0 .134 0 r
F
.81743 .73587 m .8141 .74352 L .80986 .74908 L .652 .209 0 r
F
.81743 .73587 m .82179 .73006 L .8141 .74352 L F
.62585 .5243 m .62953 .52874 L .62854 .53136 L 1 .687 0 r
F
.62585 .5243 m .62683 .52162 L .62953 .52874 L F
.50392 .65215 m .50379 .65579 L .50128 .65524 L .914 1 0 r
F
.50392 .65215 m .50665 .65266 L .50379 .65579 L F
.5157 .78169 m .51296 .80956 L .51012 .80816 L 1 1 0 r
F
.5157 .78169 m .51916 .78433 L .51296 .80956 L F
.56277 .91584 m .55337 .91782 L .54913 .91882 L 0 0 0 r
F
.56277 .91584 m .56776 .91475 L .55337 .91782 L F
.47012 .65048 m .46666 .65221 L .46709 .65203 L .455 .212 0 r
F
.51633 .63577 m .51682 .63762 L .51424 .63792 L .605 .792 0 r
F
.51633 .63577 m .51905 .6354 L .51682 .63762 L F
.37975 .72078 m .36759 .72113 L .36978 .72653 L 1 .414 0 r
F
.38196 .7256 m .37975 .72078 L .36978 .72653 L 1 .436 0 r
F
.52587 .6476 m .52638 .6506 L .52349 .65068 L .715 .949 0 r
F
.52587 .6476 m .52891 .64744 L .52638 .6506 L F
.54589 .64165 m .5467 .64445 L .54379 .64517 L .697 .85 0 r
F
.54589 .64165 m .54888 .6408 L .5467 .64445 L F
.87809 .60449 m .87968 .61593 L .87749 .62262 L .837 .198 0 r
F
.87809 .60449 m .88009 .59759 L .87968 .61593 L F
.57553 .62508 m .57698 .62836 L .57433 .62988 L .841 .85 0 r
F
.57553 .62508 m .5782 .62341 L .57698 .62836 L F
.7454 .59578 m .74684 .60312 L .74458 .60756 L .849 .257 0 r
F
.7454 .59578 m .74763 .59118 L .74684 .60312 L F
.61215 .58598 m .61519 .59044 L .61322 .59279 L 1 .904 0 r
F
.61215 .58598 m .61407 .58351 L .61519 .59044 L F
.35221 .90717 m .33212 .90188 L .33762 .90393 L .345 0 0 r
F
.35713 .90892 m .35221 .90717 L .33762 .90393 L .316 0 0 r
F
.4923 .6416 m .49192 .64335 L .48991 .64307 L .704 .931 0 r
F
.4923 .6416 m .49455 .64182 L .49192 .64335 L F
.74493 .81406 m .74008 .81933 L .73473 .82355 L .505 .206 0 r
F
.74493 .81406 m .75054 .8096 L .74008 .81933 L F
.58758 .58504 m .58981 .58818 L .58783 .59009 L .966 .833 0 r
F
.58758 .58504 m .58955 .58303 L .58981 .58818 L F
.63625 .52101 m .64229 .52638 L .64149 .52926 L 1 .804 0 r
F
.63625 .52101 m .63691 .51809 L .64229 .52638 L F
.42202 .65442 m .41557 .65314 L .41822 .65434 L .443 0 0 r
F
.42452 .65542 m .42202 .65442 L .41822 .65434 L .468 0 0 r
F
.6186 .52797 m .62251 .53226 L .62148 .53478 L 1 .769 0 r
F
.6186 .52797 m .6196 .5254 L .62251 .53226 L F
.56397 .92153 m .55437 .92315 L .55009 .92418 L 0 0 0 r
F
.56397 .92153 m .56901 .92037 L .55437 .92315 L F
.68854 .67796 m .68843 .68357 L .68465 .68668 L .718 .409 0 r
F
.68854 .67796 m .69241 .67467 L .68843 .68357 L F
.44191 .65766 m .43574 .65779 L .43807 .65874 L .448 0 0 r
F
.444 .65841 m .44191 .65766 L .43807 .65874 L .48 0 0 r
F
.4879 .64273 m .48991 .64307 L .48719 .64449 L .735 .958 0 r
F
.35896 .70227 m .34818 .69935 L .35024 .70417 L 1 .353 0 r
F
.3611 .70663 m .35896 .70227 L .35024 .70417 L 1 .385 0 r
F
.43341 .65691 m .42703 .65645 L .42956 .65753 L .471 0 0 r
F
.43574 .65779 m .43341 .65691 L .42956 .65753 L .501 0 0 r
F
.64128 .87677 m .63499 .88047 L .62931 .88264 L .354 .197 0 r
F
.64128 .87677 m .64744 .87444 L .63499 .88047 L F
.53158 .63073 m .5324 .6326 L .52977 .63329 L .612 .725 0 r
F
.53158 .63073 m .5343 .62995 L .5324 .6326 L F
.51182 .65004 m .51212 .65343 L .50938 .65308 L .822 1 0 r
F
.51182 .65004 m .51475 .65035 L .51212 .65343 L F
.59315 .58614 m .59529 .58934 L .59329 .59134 L .945 .788 0 r
F
.59315 .58614 m .59516 .58405 L .59529 .58934 L F
.43099 .6408 m .42572 .63887 L .42828 .63954 L .008 .129 0 r
F
.4334 .64131 m .43099 .6408 L .42828 .63954 L .012 .131 0 r
F
.62483 .52698 m .62854 .53136 L .6275 .53397 L 1 .711 0 r
F
.62483 .52698 m .62585 .5243 L .62854 .53136 L F
.41815 .63669 m .41305 .63389 L .41566 .63481 L .02 .124 0 r
F
.42065 .63745 m .41815 .63669 L .41566 .63481 L .032 .127 0 r
F
.44022 .72437 m .42955 .73396 L .43143 .73922 L .661 .067 0 r
F
.44184 .72852 m .44022 .72437 L .43143 .73922 L .66 .07 0 r
F
.76578 .48044 m .7718 .48952 L .77165 .49444 L .939 .176 0 r
F
.76578 .48044 m .76575 .47549 L .7718 .48952 L F
.55646 .61821 m .55773 .62045 L .55523 .62171 L .728 .737 0 r
F
.55646 .61821 m .559 .61684 L .55773 .62045 L F
.89349 .43805 m .90263 .45122 L .90183 .45829 L 1 .922 0 r
F
.89349 .43805 m .90006 .43023 L .90263 .45122 L F
.35048 .91337 m .33012 .90795 L .33572 .90994 L .323 0 0 r
F
.35549 .91507 m .35048 .91337 L .33572 .90994 L .292 0 0 r
F
.82886 .74431 m .82409 .75118 L .81974 .75693 L .58 .197 0 r
F
.82886 .74431 m .83338 .73832 L .82409 .75118 L F
.41895 .91926 m .40043 .91724 L .40404 .91823 L .239 0 0 r
F
.42175 .92001 m .41895 .91926 L .40404 .91823 L .206 0 0 r
F
.43651 .92044 m .41895 .91926 L .42175 .92001 L .192 0 0 r
F
.23876 .8384 m .21975 .82822 L .22533 .83232 L .557 0 0 r
F
.24404 .84219 m .23876 .8384 L .22533 .83232 L .537 0 0 r
F
.49629 .65393 m .49588 .65783 L .49364 .65709 L 1 1 0 r
F
.49629 .65393 m .49878 .65462 L .49588 .65783 L F
.32132 .89744 m .30122 .89059 L .30707 .89317 L .38 0 0 r
F
.32669 .89972 m .32132 .89744 L .30707 .89317 L .353 0 0 r
F
.49677 .64023 m .4968 .64198 L .49455 .64182 L .689 .918 0 r
F
.49677 .64023 m .49923 .64032 L .4968 .64198 L F
.58557 .58702 m .58783 .59009 L .58583 .59198 L .964 .846 0 r
F
.58557 .58702 m .58758 .58504 L .58783 .59009 L F
.4077 .64963 m .40144 .64736 L .40416 .64871 L .375 0 0 r
F
.4103 .6508 m .4077 .64963 L .40416 .64871 L .389 0 0 r
F
.5038 .63855 m .50413 .64035 L .50169 .64036 L .66 .884 0 r
F
.5038 .63855 m .50642 .63847 L .50413 .64035 L F
.61755 .53054 m .62148 .53478 L .6204 .53728 L 1 .79 0 r
F
.61755 .53054 m .6186 .52797 L .62148 .53478 L F
.61018 .58842 m .61322 .59279 L .61119 .59511 L 1 .916 0 r
F
.61018 .58842 m .61215 .58598 L .61322 .59279 L F
.57282 .62669 m .57553 .62508 L .57433 .62988 L .833 .858 0 r
F
.63554 .52392 m .64149 .52926 L .64063 .53212 L 1 .82 0 r
F
.63554 .52392 m .63625 .52101 L .64149 .52926 L F
.75319 .82413 m .74754 .82873 L .74208 .83313 L .446 .195 0 r
F
.75319 .82413 m .75894 .8195 L .74754 .82873 L F
.44102 .64302 m .43583 .6418 L .43827 .64228 L 0 .132 0 r
F
.44327 .64335 m .44102 .64302 L .43827 .64228 L 0 .131 0 r
F
.51035 .92518 m .49809 .92622 L .49633 .92664 L 0 0 0 r
F
.51035 .92518 m .51303 .92473 L .49809 .92622 L F
.54287 .64242 m .54379 .64517 L .54086 .6458 L .693 .863 0 r
F
.54287 .64242 m .54589 .64165 L .54379 .64517 L F
.5911 .58821 m .59329 .59134 L .59125 .5933 L .943 .803 0 r
F
.5911 .58821 m .59315 .58614 L .59329 .59134 L F
.51359 .63608 m .51424 .63792 L .51164 .63816 L .623 .827 0 r
F
.51359 .63608 m .51633 .63577 L .51424 .63792 L F
.39905 .73267 m .3864 .73631 L .38864 .74229 L 1 .385 0 r
F
.40123 .73795 m .39905 .73267 L .38864 .74229 L 1 .403 0 r
F
.89622 .61001 m .89361 .62055 L .89136 .62747 L .701 .179 0 r
F
.89622 .61001 m .89853 .60287 L .89361 .62055 L F
.41814 .92603 m .39937 .92373 L .40305 .92467 L .225 0 0 r
F
.42099 .92673 m .41814 .92603 L .40305 .92467 L .189 0 0 r
F
.52281 .64766 m .52349 .65068 L .52059 .65067 L .725 .963 0 r
F
.52281 .64766 m .52587 .6476 L .52349 .65068 L F
.64644 .88881 m .63957 .89166 L .63381 .89409 L 0 0 0 r
F
.64644 .88881 m .6527 .88621 L .63957 .89166 L F
.62376 .52964 m .6275 .53397 L .62642 .53656 L 1 .735 0 r
F
.62376 .52964 m .62483 .52698 L .6275 .53397 L F
.45311 .64435 m .44827 .64404 L .4503 .64421 L .015 .141 0 r
F
.45487 .64439 m .45311 .64435 L .4503 .64421 L 0 .137 0 r
F
.45764 .6443 m .45311 .64435 L .45487 .64439 L .069 .151 0 r
F
.31911 .9036 m .29871 .89664 L .30468 .89918 L .36 0 0 r
F
.32458 .90583 m .31911 .9036 L .30468 .89918 L .331 0 0 r
F
.52883 .63144 m .52977 .63329 L .52712 .63391 L .615 .748 0 r
F
.52883 .63144 m .53158 .63073 L .52977 .63329 L F
.40043 .91724 m .38133 .91435 L .38569 .91559 L .271 0 0 r
F
.40404 .91823 m .40043 .91724 L .38569 .91559 L .239 0 0 r
F
.55389 .61953 m .55523 .62171 L .55271 .62292 L .724 .751 0 r
F
.55389 .61953 m .55646 .61821 L .55523 .62171 L F
.51077 .92997 m .49836 .9307 L .49657 .93111 L .003 0 0 r
F
.51077 .92997 m .51347 .9295 L .49836 .9307 L F
.58244 .72232 m .58441 .73337 L .57936 .73231 L .821 .962 0 r
F
.58244 .72232 m .58783 .72353 L .58441 .73337 L F
.60593 .88985 m .5991 .89342 L .59374 .89489 L .343 .197 0 r
F
.60593 .88985 m .61188 .88829 L .5991 .89342 L F
.55341 .7214 m .55607 .73809 L .5512 .73549 L .929 .872 0 r
F
.55341 .7214 m .55865 .72436 L .55607 .73809 L F
.91372 .43601 m .91544 .45035 L .916 .45755 L .724 .131 0 r
F
.91372 .43601 m .91314 .4287 L .91544 .45035 L F
.58353 .58897 m .58583 .59198 L .58378 .59383 L .96 .859 0 r
F
.58353 .58897 m .58557 .58702 L .58583 .59198 L F
.53663 .72551 m .53899 .74709 L .53454 .74387 L 1 .878 0 r
F
.53663 .72551 m .54146 .72918 L .53899 .74709 L F
.45505 .65667 m .44971 .65771 L .45154 .65836 L .298 0 0 r
F
.44971 .65771 m .444 .65841 L .44611 .65926 L .403 0 0 r
F
.45154 .65836 m .44971 .65771 L .44611 .65926 L .438 0 0 r
F
.4591 .64422 m .45764 .6443 L .45487 .64439 L .05 .148 0 r
F
.74308 .60034 m .74458 .60756 L .74224 .61195 L .849 .282 0 r
F
.74308 .60034 m .7454 .59578 L .74458 .60756 L F
.50119 .65159 m .50128 .65524 L .49878 .65462 L .938 1 0 r
F
.50119 .65159 m .50392 .65215 L .50128 .65524 L F
.44827 .64404 m .44353 .64339 L .44553 .64367 L 0 .134 0 r
F
.44756 .64397 m .44553 .64367 L .44319 .64323 L 0 .122 0 r
F
.4503 .64421 m .44827 .64404 L .44553 .64367 L 0 .131 0 r
F
.4503 .64421 m .44553 .64367 L .4478 .64401 L F
.4478 .64401 m .44553 .64367 L .44756 .64397 L 0 .122 0 r
F
.44353 .64339 m .44327 .64335 L .44553 .64367 L 0 .134 0 r
F
.61646 .53309 m .6204 .53728 L .61927 .53977 L 1 .81 0 r
F
.61646 .53309 m .61755 .53054 L .6204 .53728 L F
.64888 .89449 m .64181 .89716 L .63599 .89967 L 0 0 0 r
F
.64888 .89449 m .65519 .89179 L .64181 .89716 L F
.42065 .63745 m .41566 .63481 L .41828 .63569 L .032 .127 0 r
F
.42318 .63817 m .42065 .63745 L .41828 .63569 L .041 .129 0 r
F
.29123 .86688 m .27165 .85977 L .2774 .86301 L .512 0 0 r
F
.29658 .86984 m .29123 .86688 L .2774 .86301 L .492 0 0 r
F
.60816 .59082 m .61119 .59511 L .60913 .5974 L 1 .926 0 r
F
.60816 .59082 m .61018 .58842 L .61119 .59511 L F
.58902 .59023 m .59125 .5933 L .58917 .59523 L .941 .818 0 r
F
.58902 .59023 m .5911 .58821 L .59125 .5933 L F
.39937 .92373 m .38003 .92062 L .38446 .92181 L .251 0 0 r
F
.40305 .92467 m .39937 .92373 L .38446 .92181 L .216 0 0 r
F
.42452 .65542 m .41822 .65434 L .42089 .65557 L .468 0 0 r
F
.42703 .65645 m .42452 .65542 L .42089 .65557 L .499 0 0 r
F
.4334 .64131 m .42828 .63954 L .43085 .64019 L .012 .131 0 r
F
.43583 .6418 m .4334 .64131 L .43085 .64019 L .01 .131 0 r
F
.68458 .68114 m .68465 .68668 L .68078 .68968 L .715 .447 0 r
F
.68458 .68114 m .68854 .67796 L .68465 .68668 L F
.5089 .64965 m .50938 .65308 L .50665 .65266 L .843 1 0 r
F
.5089 .64965 m .51182 .65004 L .50938 .65308 L F
.63475 .52683 m .64063 .53212 L .63972 .53497 L 1 .837 0 r
F
.63475 .52683 m .63554 .52392 L .64063 .53212 L F
.23013 .85168 m .21131 .83989 L .21709 .84409 L .489 0 0 r
F
.23564 .85555 m .23013 .85168 L .21709 .84409 L .465 0 0 r
F
.62264 .53228 m .62642 .53656 L .62529 .53914 L 1 .758 0 r
F
.62264 .53228 m .62376 .52964 L .62642 .53656 L F
.47016 .65016 m .47012 .65048 L .46709 .65203 L .501 .216 0 r
F
.49004 .64133 m .48991 .64307 L .4879 .64273 L .746 .975 0 r
F
.49004 .64133 m .4923 .6416 L .48991 .64307 L F
.7657 .48539 m .77165 .49444 L .7714 .49937 L .95 .197 0 r
F
.7657 .48539 m .76578 .48044 L .77165 .49444 L F
.53983 .64309 m .54086 .6458 L .53791 .64635 L .688 .875 0 r
F
.53983 .64309 m .54287 .64242 L .54086 .6458 L F
.55129 .6208 m .55271 .62292 L .55015 .62408 L .72 .763 0 r
F
.55129 .6208 m .55389 .61953 L .55271 .62292 L F
.81296 .74162 m .80986 .74908 L .8055 .75457 L .655 .211 0 r
F
.81296 .74162 m .81743 .73587 L .80986 .74908 L F
.58145 .59088 m .58378 .59383 L .5817 .59564 L .957 .871 0 r
F
.58145 .59088 m .58353 .58897 L .58378 .59383 L F
.43574 .65779 m .42956 .65753 L .4321 .65868 L .501 0 0 r
F
.43807 .65874 m .43574 .65779 L .4321 .65868 L .535 0 0 r
F
.4103 .6508 m .40416 .64871 L .40689 .65006 L .389 0 0 r
F
.41293 .65197 m .4103 .6508 L .40689 .65006 L .408 0 0 r
F
.52606 .63209 m .52712 .63391 L .52444 .63447 L .618 .771 0 r
F
.52606 .63209 m .52883 .63144 L .52712 .63391 L F
.87596 .61137 m .87749 .62262 L .87518 .62928 L .837 .2 0 r
F
.87596 .61137 m .87809 .60449 L .87749 .62262 L F
.51085 .63633 m .51164 .63816 L .50904 .63834 L .643 .861 0 r
F
.51085 .63633 m .51359 .63608 L .51164 .63816 L F
.61531 .53563 m .61927 .53977 L .6181 .54224 L 1 .83 0 r
F
.61531 .53563 m .61646 .53309 L .61927 .53977 L F
.50117 .63858 m .50169 .64036 L .49923 .64032 L .687 .918 0 r
F
.50117 .63858 m .5038 .63855 L .50169 .64036 L F
.61009 .90251 m .60269 .90502 L .59725 .90678 L .229 .177 0 r
F
.61009 .90251 m .61612 .90061 L .60269 .90502 L F
.43845 .92097 m .43651 .92044 L .42175 .92001 L .157 0 0 r
F
.5257 .73641 m .5272 .76238 L .52321 .75911 L 1 .919 0 r
F
.5257 .73641 m .5301 .7403 L .5272 .76238 L F
.444 .65841 m .43807 .65874 L .44042 .6598 L .48 0 0 r
F
.44611 .65926 m .444 .65841 L .44042 .6598 L .526 .005 0 r
F
.51974 .6476 m .52059 .65067 L .51767 .65056 L .736 .973 0 r
F
.51974 .6476 m .52281 .64766 L .52059 .65067 L F
.3611 .70663 m .35024 .70417 L .35232 .70923 L 1 .385 0 r
F
.36325 .71121 m .3611 .70663 L .35232 .70923 L 1 .416 0 r
F
.5869 .59223 m .58917 .59523 L .58706 .59713 L .938 .831 0 r
F
.5869 .59223 m .58902 .59023 L .58917 .59523 L F
.2261 .85788 m .20688 .846 L .21281 .85019 L .475 0 0 r
F
.23175 .86174 m .2261 .85788 L .21281 .85019 L .451 0 0 r
F
.41583 .73716 m .40342 .74374 L .40562 .75012 L .963 .307 0 r
F
.4179 .74271 m .41583 .73716 L .40562 .75012 L .959 .325 0 r
F
.51924 .75548 m .51916 .78433 L .5157 .78169 L 1 .985 0 r
F
.51924 .75548 m .52321 .75911 L .51916 .78433 L F
.60609 .5932 m .60913 .5974 L .60701 .59964 L 1 .936 0 r
F
.60609 .5932 m .60816 .59082 L .60913 .5974 L F
.4943 .64009 m .49455 .64182 L .4923 .6416 L .722 .954 0 r
F
.4943 .64009 m .49677 .64023 L .49455 .64182 L F
.46752 .65188 m .46709 .65203 L .46405 .65372 L 0 0 0 r
F
.47016 .65016 m .46709 .65203 L .46752 .65188 L .501 .216 0 r
F
.38196 .7256 m .36978 .72653 L .37198 .73229 L 1 .436 0 r
F
.38417 .73076 m .38196 .7256 L .37198 .73229 L 1 .457 0 r
F
.42955 .73396 m .4179 .74271 L .41997 .74895 L .828 .189 0 r
F
.43143 .73922 m .42955 .73396 L .41997 .74895 L .826 .209 0 r
F
.62147 .53491 m .62529 .53914 L .62411 .5417 L 1 .779 0 r
F
.62147 .53491 m .62264 .53228 L .62529 .53914 L F
.63391 .52972 m .63972 .53497 L .63875 .53782 L 1 .854 0 r
F
.63391 .52972 m .63475 .52683 L .63972 .53497 L F
.44327 .64335 m .43827 .64228 L .44072 .64275 L 0 .131 0 r
F
.44553 .64367 m .44327 .64335 L .44072 .64275 L 0 .128 0 r
F
.4938 .65319 m .49364 .65709 L .49141 .65628 L 1 1 0 r
F
.4938 .65319 m .49629 .65393 L .49364 .65709 L F
.61204 .90843 m .60443 .91065 L .59893 .91248 L 0 0 0 r
F
.61204 .90843 m .61812 .90643 L .60443 .91065 L F
.42318 .63817 m .41828 .63569 L .42093 .63655 L .041 .129 0 r
F
.42572 .63887 m .42318 .63817 L .42093 .63655 L .047 .131 0 r
F
.38555 .89406 m .3667 .89248 L .37142 .8943 L .439 0 0 r
F
.38961 .89568 m .38555 .89406 L .37142 .8943 L .42 0 0 r
F
.57933 .59277 m .5817 .59564 L .57959 .59742 L .952 .882 0 r
F
.57933 .59277 m .58145 .59088 L .5817 .59564 L F
.54866 .62202 m .55015 .62408 L .54757 .62519 L .715 .774 0 r
F
.54866 .62202 m .55129 .6208 L .55015 .62408 L F
.2841 .88216 m .26449 .87336 L .2705 .8766 L .416 0 0 r
F
.28973 .88508 m .2841 .88216 L .2705 .8766 L .39 0 0 r
F
.61412 .53816 m .6181 .54224 L .61689 .54469 L 1 .848 0 r
F
.61412 .53816 m .61531 .53563 L .6181 .54224 L F
.73923 .81841 m .73473 .82355 L .72928 .82766 L .509 .208 0 r
F
.73923 .81841 m .74493 .81406 L .73473 .82355 L F
.74066 .60486 m .74224 .61195 L .7398 .61631 L .849 .307 0 r
F
.74066 .60486 m .74308 .60034 L .74224 .61195 L F
.82421 .75022 m .81974 .75693 L .81528 .7626 L .585 .2 0 r
F
.82421 .75022 m .82886 .74431 L .81974 .75693 L F
.58474 .59419 m .58706 .59713 L .58491 .59899 L .935 .844 0 r
F
.58474 .59419 m .5869 .59223 L .58706 .59713 L F
.53676 .64367 m .53791 .64635 L .53493 .64681 L .684 .885 0 r
F
.53676 .64367 m .53983 .64309 L .53791 .64635 L F
.43583 .6418 m .43085 .64019 L .43344 .64082 L .01 .131 0 r
F
.43827 .64228 m .43583 .6418 L .43344 .64082 L .002 .131 0 r
F
.52328 .63267 m .52444 .63447 L .52175 .63497 L .622 .794 0 r
F
.52328 .63267 m .52606 .63209 L .52444 .63447 L F
.577 .72073 m .57936 .73231 L .57425 .7309 L .811 .926 0 r
F
.577 .72073 m .58244 .72232 L .57936 .73231 L F
.53866 .90848 m .52931 .91142 L .52587 .91185 L .285 .189 0 r
F
.53866 .90848 m .54291 .90805 L .52931 .91142 L F
.49847 .65097 m .49878 .65462 L .49629 .65393 L .962 1 0 r
F
.49847 .65097 m .50119 .65159 L .49878 .65462 L F
.60397 .59553 m .60701 .59964 L .60485 .60186 L 1 .945 0 r
F
.60397 .59553 m .60609 .5932 L .60701 .59964 L F
.50597 .64919 m .50665 .65266 L .50392 .65215 L .865 1 0 r
F
.50597 .64919 m .5089 .64965 L .50665 .65266 L F
.45487 .64439 m .4503 .64421 L .45234 .64441 L 0 .137 0 r
F
.45664 .64445 m .45487 .64439 L .45234 .64441 L .048 0 0 r
F
.4591 .64422 m .45487 .64439 L .45664 .64445 L .05 .148 0 r
F
.62026 .53753 m .62411 .5417 L .62288 .54424 L 1 .8 0 r
F
.62026 .53753 m .62147 .53491 L .62411 .5417 L F
.68053 .68423 m .68078 .68968 L .67683 .69258 L .712 .484 0 r
F
.68053 .68423 m .68458 .68114 L .68078 .68968 L F
.89377 .61713 m .89136 .62747 L .88898 .63436 L .709 .183 0 r
F
.89377 .61713 m .89622 .61001 L .89136 .62747 L F
.42703 .65645 m .42089 .65557 L .42358 .65684 L .499 0 0 r
F
.42956 .65753 m .42703 .65645 L .42358 .65684 L .534 0 0 r
F
.28123 .88832 m .26128 .87944 L .26744 .88264 L .398 0 0 r
F
.28698 .89121 m .28123 .88832 L .26744 .88264 L .371 0 0 r
F
.57718 .59461 m .57959 .59742 L .57744 .59917 L .948 .892 0 r
F
.57718 .59461 m .57933 .59277 L .57959 .59742 L F
.50809 .63652 m .50904 .63834 L .50642 .63847 L .665 .893 0 r
F
.50809 .63652 m .51085 .63633 L .50904 .63834 L F
.45095 .71748 m .44184 .72852 L .44346 .73343 L .435 .042 0 r
F
.45225 .72113 m .45095 .71748 L .44346 .73343 L .437 .046 0 r
F
.54818 .71808 m .5512 .73549 L .54633 .73252 L .927 .843 0 r
F
.54818 .71808 m .55341 .7214 L .5512 .73549 L F
.45234 .64441 m .4503 .64421 L .4478 .64401 L .074 0 0 r
F
.63301 .53262 m .63875 .53782 L .63773 .54065 L 1 .87 0 r
F
.63301 .53262 m .63391 .52972 L .63875 .53782 L F
.41293 .65197 m .40689 .65006 L .40965 .65143 L .408 0 0 r
F
.41557 .65314 m .41293 .65197 L .40965 .65143 L .432 0 0 r
F
.57731 .89833 m .56996 .90183 L .5651 .90276 L .349 .198 0 r
F
.57731 .89833 m .58284 .89735 L .56996 .90183 L F
.46752 .65188 m .46405 .65372 L .46487 .65381 L 0 0 0 r
F
.56447 .63118 m .56615 .63411 L .56335 .6354 L .806 .877 0 r
F
.56447 .63118 m .56729 .62975 L .56615 .63411 L F
.36203 .89056 m .34281 .8875 L .34807 .88964 L .458 0 0 r
F
.3667 .89248 m .36203 .89056 L .34807 .88964 L .439 0 0 r
F
.51667 .64743 m .51767 .65056 L .51475 .65035 L .748 .98 0 r
F
.51667 .64743 m .51974 .6476 L .51767 .65056 L F
.61289 .54066 m .61689 .54469 L .61562 .54713 L 1 .866 0 r
F
.61289 .54066 m .61412 .53816 L .61689 .54469 L F
.7655 .49036 m .7714 .49937 L .77105 .50429 L .961 .221 0 r
F
.7655 .49036 m .7657 .48539 L .7714 .49937 L F
.54601 .62319 m .54757 .62519 L .54497 .62625 L .71 .784 0 r
F
.54601 .62319 m .54866 .62202 L .54757 .62519 L F
.49854 .63858 m .49923 .64032 L .49677 .64023 L .713 .947 0 r
F
.49854 .63858 m .50117 .63858 L .49923 .64032 L F
.58255 .59611 m .58491 .59899 L .58272 .60081 L .931 .856 0 r
F
.58255 .59611 m .58474 .59419 L .58491 .59899 L F
.33249 .88294 m .31306 .87815 L .31869 .88074 L .477 0 0 r
F
.33762 .88526 m .33249 .88294 L .31869 .88074 L .457 0 0 r
F
.91416 .44335 m .916 .45755 L .91643 .46478 L .738 .136 0 r
F
.91416 .44335 m .91372 .43601 L .916 .45755 L F
.24404 .84219 m .22533 .83232 L .23098 .83632 L .537 0 0 r
F
.24941 .84589 m .24404 .84219 L .23098 .83632 L .518 0 0 r
F
.42572 .63887 m .42093 .63655 L .42359 .63738 L .047 .131 0 r
F
.42828 .63954 m .42572 .63887 L .42359 .63738 L .05 .132 0 r
F
.53186 .72157 m .53454 .74387 L .5301 .7403 L 1 .858 0 r
F
.53186 .72157 m .53663 .72551 L .53454 .74387 L F
.45154 .65836 m .44611 .65926 L .44822 .66027 L .438 0 0 r
F
.45338 .65917 m .45154 .65836 L .44822 .66027 L .485 .007 0 r
F
.48777 .641 m .49004 .64133 L .4879 .64273 L .79 1 0 r
F
.74734 .82865 m .74208 .83313 L .73653 .83742 L .452 .198 0 r
F
.74734 .82865 m .75319 .82413 L .74208 .83313 L F
.575 .59643 m .57744 .59917 L .57526 .60088 L .943 .901 0 r
F
.575 .59643 m .57718 .59461 L .57744 .59917 L F
.54053 .92041 m .53075 .92214 L .52725 .92278 L .127 .161 0 r
F
.54053 .92041 m .54485 .91968 L .53075 .92214 L F
.619 .54013 m .62288 .54424 L .6216 .54677 L 1 .821 0 r
F
.619 .54013 m .62026 .53753 L .62288 .54424 L F
.60181 .59783 m .60485 .60186 L .60264 .60403 L 1 .954 0 r
F
.60181 .59783 m .60397 .59553 L .60485 .60186 L F
.43807 .65874 m .4321 .65868 L .43464 .65994 L .535 0 0 r
F
.44042 .6598 m .43807 .65874 L .43464 .65994 L .611 .016 0 r
F
.53366 .64415 m .53493 .64681 L .53193 .64718 L .679 .894 0 r
F
.53366 .64415 m .53676 .64367 L .53493 .64681 L F
.52047 .63318 m .52175 .63497 L .51905 .6354 L .628 .818 0 r
F
.52047 .63318 m .52328 .63267 L .52175 .63497 L F
.49183 .63991 m .4923 .6416 L .49004 .64133 L .754 .985 0 r
F
.49183 .63991 m .4943 .64009 L .4923 .6416 L F
.6116 .54315 m .61562 .54713 L .61432 .54954 L 1 .884 0 r
F
.6116 .54315 m .61289 .54066 L .61562 .54713 L F
.63204 .5355 m .63773 .54065 L .63666 .54347 L 1 .886 0 r
F
.63204 .5355 m .63301 .53262 L .63773 .54065 L F
.51224 .77868 m .51012 .80816 L .50725 .80645 L 1 1 0 r
F
.51224 .77868 m .5157 .78169 L .51012 .80816 L F
.40123 .73795 m .38864 .74229 L .3909 .74878 L 1 .403 0 r
F
.40342 .74374 m .40123 .73795 L .3909 .74878 L 1 .419 0 r
F
.63505 .87895 m .62931 .88264 L .62357 .88467 L .371 .2 0 r
F
.63505 .87895 m .64128 .87677 L .62931 .88264 L F
.44553 .64367 m .44128 .64286 L .44319 .64323 L 0 .128 0 r
F
.44515 .64361 m .44319 .64323 L .44129 .64272 L 0 .116 0 r
F
.4478 .64401 m .44319 .64323 L .44567 .64373 L 0 .122 0 r
F
.44567 .64373 m .44319 .64323 L .44515 .64361 L 0 .116 0 r
F
.44128 .64286 m .44072 .64275 L .44319 .64323 L 0 .128 0 r
F
.54334 .62431 m .54497 .62625 L .54234 .62726 L .704 .793 0 r
F
.54334 .62431 m .54601 .62319 L .54497 .62625 L F
.44184 .72852 m .43143 .73922 L .43331 .74529 L .66 .07 0 r
F
.44346 .73343 m .44184 .72852 L .43331 .74529 L .659 .073 0 r
F
.58032 .598 m .58272 .60081 L .5805 .60259 L .927 .867 0 r
F
.58032 .598 m .58255 .59611 L .58272 .60081 L F
.38133 .91435 m .3621 .91056 L .36712 .91208 L .287 0 0 r
F
.38569 .91559 m .38133 .91435 L .36712 .91208 L .256 0 0 r
F
.56162 .63256 m .56335 .6354 L .56052 .63662 L .795 .882 0 r
F
.56162 .63256 m .56447 .63118 L .56335 .6354 L F
.54139 .92585 m .53144 .92721 L .52789 .92788 L 0 0 0 r
F
.54139 .92585 m .54576 .92509 L .53144 .92721 L F
.87369 .61822 m .87518 .62928 L .87275 .63591 L .837 .203 0 r
F
.87369 .61822 m .87596 .61137 L .87518 .62928 L F
.58059 .91125 m .57269 .91351 L .56776 .91475 L .202 .174 0 r
F
.58059 .91125 m .5862 .9099 L .57269 .91351 L F
.73815 .60934 m .7398 .61631 L .73727 .62062 L .848 .332 0 r
F
.73815 .60934 m .74066 .60486 L .7398 .61631 L F
.80837 .74729 m .8055 .75457 L .80103 .75999 L .657 .213 0 r
F
.80837 .74729 m .81296 .74162 L .8055 .75457 L F
.44611 .65926 m .44042 .6598 L .44277 .66102 L .526 .005 0 r
F
.44822 .66027 m .44611 .65926 L .44277 .66102 L .609 .023 0 r
F
.50533 .63667 m .50642 .63847 L .5038 .63855 L .689 .922 0 r
F
.50533 .63667 m .50809 .63652 L .50642 .63847 L F
.43827 .64228 m .43344 .64082 L .43604 .64145 L .002 .131 0 r
F
.44072 .64275 m .43827 .64228 L .43604 .64145 L 0 .129 0 r
F
.57278 .5982 m .57526 .60088 L .57304 .60255 L .937 .91 0 r
F
.57278 .5982 m .575 .59643 L .57526 .60088 L F
.36325 .71121 m .35232 .70923 L .35441 .71454 L 1 .416 0 r
F
.36541 .71603 m .36325 .71121 L .35441 .71454 L 1 .445 0 r
F
.49131 .65239 m .49141 .65628 L .48919 .65539 L 1 1 0 r
F
.49131 .65239 m .4938 .65319 L .49141 .65628 L F
.55524 .90414 m .54712 .90745 L .54291 .90805 L .337 .196 0 r
F
.55524 .90414 m .56019 .90354 L .54712 .90745 L F
.47021 .64985 m .47016 .65016 L .46752 .65188 L .543 .218 0 r
F
.50306 .64867 m .50392 .65215 L .50119 .65159 L .889 1 0 r
F
.50306 .64867 m .50597 .64919 L .50392 .65215 L F
.61769 .54271 m .6216 .54677 L .62028 .54928 L 1 .84 0 r
F
.61769 .54271 m .619 .54013 L .6216 .54677 L F
.51358 .64715 m .51475 .65035 L .51182 .65004 L .764 .984 0 r
F
.51358 .64715 m .51667 .64743 L .51475 .65035 L F
.59959 .6001 m .60264 .60403 L .60039 .60617 L 1 .962 0 r
F
.59959 .6001 m .60181 .59783 L .60264 .60403 L F
.41557 .65314 m .40965 .65143 L .41241 .65282 L .432 0 0 r
F
.41822 .65434 m .41557 .65314 L .41241 .65282 L .463 0 0 r
F
.42465 .8944 m .4075 .89576 L .41088 .89712 L .35 0 0 r
F
.42725 .89562 m .42465 .8944 L .41088 .89712 L .33 0 0 r
F
.5237 .92329 m .51303 .92473 L .51035 .92518 L 0 0 0 r
F
.5237 .92329 m .52725 .92278 L .51303 .92473 L F
.67639 .6872 m .67683 .69258 L .67278 .69537 L .707 .52 0 r
F
.67639 .6872 m .68053 .68423 L .67683 .69258 L F
.58209 .91718 m .574 .91908 L .56901 .92037 L 0 0 0 r
F
.58209 .91718 m .58776 .91575 L .574 .91908 L F
.5715 .71874 m .57425 .7309 L .56909 .72911 L .802 .888 0 r
F
.5715 .71874 m .577 .72073 L .57425 .7309 L F
.38003 .92062 m .36055 .91665 L .36566 .91811 L .263 0 0 r
F
.38446 .92181 m .38003 .92062 L .36566 .91811 L .23 0 0 r
F
.61028 .54563 m .61432 .54954 L .61296 .55194 L 1 .9 0 r
F
.61028 .54563 m .6116 .54315 L .61432 .54954 L F
.49577 .65031 m .49629 .65393 L .4938 .65319 L .986 1 0 r
F
.49577 .65031 m .49847 .65097 L .49629 .65393 L F
.51765 .63362 m .51905 .6354 L .51633 .63577 L .635 .842 0 r
F
.51765 .63362 m .52047 .63318 L .51905 .6354 L F
.42828 .63954 m .42359 .63738 L .42627 .63819 L .05 .132 0 r
F
.43085 .64019 m .42828 .63954 L .42627 .63819 L .048 .133 0 r
F
.42956 .65753 m .42358 .65684 L .42627 .6582 L .534 0 0 r
F
.4321 .65868 m .42956 .65753 L .42627 .6582 L .572 .006 0 r
F
.57806 .59985 m .5805 .60259 L .57824 .60434 L .922 .877 0 r
F
.57806 .59985 m .58032 .598 L .5805 .60259 L F
.53054 .64452 m .53193 .64718 L .52891 .64744 L .674 .902 0 r
F
.53054 .64452 m .53366 .64415 L .53193 .64718 L F
.63102 .53837 m .63666 .54347 L .63553 .54628 L 1 .902 0 r
F
.63102 .53837 m .63204 .5355 L .63666 .54347 L F
.54064 .62537 m .54234 .62726 L .53968 .62822 L .698 .801 0 r
F
.54064 .62537 m .54334 .62431 L .54234 .62726 L F
.35713 .90892 m .33762 .90393 L .34317 .90586 L .316 0 0 r
F
.3621 .91056 m .35713 .90892 L .34317 .90586 L .286 0 0 r
F
.23564 .85555 m .21709 .84409 L .22295 .84819 L .465 0 0 r
F
.24124 .85932 m .23564 .85555 L .22295 .84819 L .441 0 0 r
F
.4959 .63854 m .49677 .64023 L .4943 .64009 L .738 .972 0 r
F
.4959 .63854 m .49854 .63858 L .49677 .64023 L F
.7652 .49535 m .77105 .50429 L .77059 .50922 L .971 .246 0 r
F
.7652 .49535 m .7655 .49036 L .77105 .50429 L F
.32669 .89972 m .30707 .89317 L .313 .89565 L .353 0 0 r
F
.33212 .90188 m .32669 .89972 L .313 .89565 L .325 0 0 r
F
.52431 .92842 m .51347 .9295 L .51077 .92997 L 0 0 0 r
F
.52431 .92842 m .52789 .92788 L .51347 .9295 L F
.55873 .63386 m .56052 .63662 L .55766 .63777 L .783 .885 0 r
F
.55873 .63386 m .56162 .63256 L .56052 .63662 L F
.57054 .59995 m .57304 .60255 L .57079 .60419 L .931 .918 0 r
F
.57054 .59995 m .57278 .5982 L .57304 .60255 L F
.52136 .73227 m .52321 .75911 L .51924 .75548 L 1 .902 0 r
F
.52136 .73227 m .5257 .73641 L .52321 .75911 L F
.64012 .89129 m .63381 .89409 L .62798 .89639 L .285 .184 0 r
F
.64012 .89129 m .64644 .88881 L .63381 .89409 L F
.46796 .6518 m .46752 .65188 L .46487 .65381 L 0 0 0 r
F
.47021 .64985 m .46752 .65188 L .46796 .6518 L .543 .218 0 r
F
.29658 .86984 m .2774 .86301 L .28323 .86615 L .492 0 0 r
F
.30201 .8727 m .29658 .86984 L .28323 .86615 L .472 0 0 r
F
.54299 .71441 m .54633 .73252 L .54146 .72918 L .927 .816 0 r
F
.54299 .71441 m .54818 .71808 L .54633 .73252 L F
.4075 .89576 m .38961 .89568 L .39372 .89722 L .398 0 0 r
F
.41088 .89712 m .4075 .89576 L .39372 .89722 L .38 0 0 r
F
.45234 .64441 m .4478 .64401 L .45008 .64437 L .074 0 0 r
F
.45439 .64464 m .45234 .64441 L .45008 .64437 L .14 0 0 r
F
.45664 .64445 m .45234 .64441 L .45439 .64464 L .048 0 0 r
F
.38417 .73076 m .37198 .73229 L .37421 .73843 L 1 .457 0 r
F
.3864 .73631 m .38417 .73076 L .37421 .73843 L 1 .476 0 r
F
.61634 .54527 m .62028 .54928 L .61892 .55177 L 1 .858 0 r
F
.61634 .54527 m .61769 .54271 L .62028 .54928 L F
.45842 .64457 m .45664 .64445 L .45439 .64464 L .12 0 0 r
F
.59734 .60232 m .60039 .60617 L .5981 .60826 L 1 .969 0 r
F
.59734 .60232 m .59959 .6001 L .60039 .60617 L F
.81945 .75606 m .81528 .7626 L .8107 .76819 L .589 .202 0 r
F
.81945 .75606 m .82421 .75022 L .81528 .7626 L F
.60891 .54808 m .61296 .55194 L .61157 .55432 L 1 .916 0 r
F
.60891 .54808 m .61028 .54563 L .61296 .55194 L F
.67626 .85971 m .67132 .86372 L .66546 .8666 L .418 .204 0 r
F
.67626 .85971 m .68249 .85663 L .67132 .86372 L F
.35549 .91507 m .33572 .90994 L .34138 .91181 L .292 0 0 r
F
.36055 .91665 m .35549 .91507 L .34138 .91181 L .26 0 0 r
F
.55774 .9168 m .54913 .91882 L .54485 .91968 L .173 .17 0 r
F
.55774 .9168 m .56277 .91584 L .54913 .91882 L F
.89118 .62421 m .88898 .63436 L .88647 .64122 L .716 .187 0 r
F
.89118 .62421 m .89377 .61713 L .88898 .63436 L F
.57576 .60166 m .57824 .60434 L .57595 .60605 L .916 .886 0 r
F
.57576 .60166 m .57806 .59985 L .57824 .60434 L F
.23175 .86174 m .21281 .85019 L .21884 .85428 L .451 0 0 r
F
.23749 .86549 m .23175 .86174 L .21884 .85428 L .426 0 0 r
F
.50258 .63678 m .5038 .63855 L .50117 .63858 L .713 .948 0 r
F
.50258 .63678 m .50533 .63667 L .5038 .63855 L F
.32458 .90583 m .30468 .89918 L .31072 .9016 L .331 0 0 r
F
.33012 .90795 m .32458 .90583 L .31072 .9016 L .301 0 0 r
F
.64249 .89706 m .63599 .89967 L .6301 .90205 L 0 0 0 r
F
.64249 .89706 m .64888 .89449 L .63599 .89967 L F
.48109 .93209 m .46709 .93214 L .4672 .93239 L .049 0 0 r
F
.48109 .93209 m .48194 .93183 L .46709 .93214 L F
.48936 .63968 m .49004 .64133 L .48777 .641 L .786 1 0 r
F
.48936 .63968 m .49183 .63991 L .49004 .64133 L F
.53791 .62638 m .53968 .62822 L .537 .62911 L .691 .809 0 r
F
.53791 .62638 m .54064 .62537 L .53968 .62822 L F
.56825 .60165 m .57079 .60419 L .56851 .60579 L .924 .924 0 r
F
.56825 .60165 m .57054 .59995 L .57079 .60419 L F
.62993 .54123 m .63553 .54628 L .63435 .54907 L 1 .917 0 r
F
.62993 .54123 m .63102 .53837 L .63553 .54628 L F
.73343 .82266 m .72928 .82766 L .72374 .83168 L .513 .21 0 r
F
.73343 .82266 m .73923 .81841 L .72928 .82766 L F
.51482 .63398 m .51633 .63577 L .51359 .63608 L .646 .867 0 r
F
.51482 .63398 m .51765 .63362 L .51633 .63577 L F
.5105 .64678 m .51182 .65004 L .5089 .64965 L .782 .987 0 r
F
.5105 .64678 m .51358 .64715 L .51182 .65004 L F
.73555 .61378 m .73727 .62062 L .73465 .62488 L .847 .357 0 r
F
.73555 .61378 m .73815 .60934 L .73727 .62062 L F
.59993 .89125 m .59374 .89489 L .58832 .8962 L .371 .201 0 r
F
.59993 .89125 m .60593 .88985 L .59374 .89489 L F
.44072 .64275 m .43604 .64145 L .43866 .64208 L 0 .129 0 r
F
.44319 .64323 m .44072 .64275 L .43866 .64208 L 0 .124 0 r
F
.45008 .64437 m .4478 .64401 L .44567 .64373 L .131 0 0 r
F
.5274 .64477 m .52891 .64744 L .52587 .6476 L .67 .908 0 r
F
.5274 .64477 m .53054 .64452 L .52891 .64744 L F
.44042 .6598 m .43464 .65994 L .4372 .66136 L .611 .016 0 r
F
.44277 .66102 m .44042 .6598 L .4372 .66136 L .699 .033 0 r
F
.5558 .6351 m .55766 .63777 L .55476 .63886 L .771 .887 0 r
F
.5558 .6351 m .55873 .63386 L .55766 .63777 L F
.61495 .54781 m .61892 .55177 L .6175 .55423 L 1 .876 0 r
F
.61495 .54781 m .61634 .54527 L .61892 .55177 L F
.55888 .92255 m .55009 .92418 L .54576 .92509 L 0 0 0 r
F
.55888 .92255 m .56397 .92153 L .55009 .92418 L F
.4179 .74271 m .40562 .75012 L .40784 .75717 L .959 .325 0 r
F
.41997 .74895 m .4179 .74271 L .40784 .75717 L .956 .342 0 r
F
.5153 .75152 m .5157 .78169 L .51224 .77868 L 1 .965 0 r
F
.5153 .75152 m .51924 .75548 L .5157 .78169 L F
.50017 .64812 m .50119 .65159 L .49847 .65097 L .914 1 0 r
F
.50017 .64812 m .50306 .64867 L .50119 .65159 L F
.43085 .64019 m .42627 .63819 L .42896 .63898 L .048 .133 0 r
F
.43344 .64082 m .43085 .64019 L .42896 .63898 L .041 .133 0 r
F
.41822 .65434 m .41241 .65282 L .4152 .65424 L .463 0 0 r
F
.42089 .65557 m .41822 .65434 L .4152 .65424 L .499 0 0 r
F
.91446 .45071 m .91643 .46478 L .91672 .47202 L .752 .141 0 r
F
.91446 .45071 m .91416 .44335 L .91643 .46478 L F
.49477 .93139 m .48194 .93183 L .48109 .93209 L .012 0 0 r
F
.49477 .93139 m .49657 .93111 L .48194 .93183 L F
.52716 .71741 m .5301 .7403 L .5257 .73641 L 1 .842 0 r
F
.52716 .71741 m .53186 .72157 L .5301 .7403 L F
.60749 .55051 m .61157 .55432 L .61013 .55668 L 1 .931 0 r
F
.60749 .55051 m .60891 .54808 L .61157 .55432 L F
.46796 .6518 m .46487 .65381 L .46568 .65406 L 0 0 0 r
F
.61206 .71747 m .61361 .7246 L .60862 .72498 L .708 .945 0 r
F
.61206 .71747 m .61728 .71702 L .61361 .7246 L F
.57343 .60344 m .57595 .60605 L .57362 .60771 L .911 .894 0 r
F
.57343 .60344 m .57576 .60166 L .57595 .60605 L F
.59504 .60451 m .5981 .60826 L .59576 .61031 L 1 .976 0 r
F
.59504 .60451 m .59734 .60232 L .5981 .60826 L F
.45338 .65917 m .44822 .66027 L .45034 .66153 L .485 .007 0 r
F
.45521 .66024 m .45338 .65917 L .45034 .66153 L .566 .027 0 r
F
.67216 .69006 m .67278 .69537 L .66865 .69804 L .702 .554 0 r
F
.67216 .69006 m .67639 .6872 L .67278 .69537 L F
.56594 .60332 m .56851 .60579 L .5662 .60735 L .918 .931 0 r
F
.56594 .60332 m .56825 .60165 L .56851 .60579 L F
.43143 .73922 m .41997 .74895 L .42205 .75602 L .826 .209 0 r
F
.43331 .74529 m .43143 .73922 L .42205 .75602 L .824 .229 0 r
F
.49326 .63847 m .4943 .64009 L .49183 .63991 L .762 .993 0 r
F
.49326 .63847 m .4959 .63854 L .4943 .64009 L F
.53516 .62732 m .537 .62911 L .5343 .62995 L .684 .816 0 r
F
.53516 .62732 m .53791 .62638 L .537 .62911 L F
.56596 .71633 m .56909 .72911 L .56389 .72693 L .792 .849 0 r
F
.56596 .71633 m .5715 .71874 L .56909 .72911 L F
.68248 .87123 m .67696 .87454 L .67101 .87764 L .355 .192 0 r
F
.68248 .87123 m .68883 .86793 L .67696 .87454 L F
.48884 .65152 m .49131 .65239 L .48919 .65539 L 1 1 0 r
F
.87128 .62505 m .87275 .63591 L .8702 .64251 L .837 .205 0 r
F
.87128 .62505 m .87369 .61822 L .87275 .63591 L F
.49307 .64961 m .4938 .65319 L .49131 .65239 L 1 1 0 r
F
.49307 .64961 m .49577 .65031 L .4938 .65319 L F
.62879 .54408 m .63435 .54907 L .63311 .55184 L 1 .932 0 r
F
.62879 .54408 m .62993 .54123 L .63435 .54907 L F
.76479 .50033 m .77059 .50922 L .77004 .51415 L .981 .271 0 r
F
.76479 .50033 m .7652 .49535 L .77059 .50922 L F
.4321 .65868 m .42627 .6582 L .42897 .65966 L .572 .006 0 r
F
.43464 .65994 m .4321 .65868 L .42897 .65966 L .657 .021 0 r
F
.28973 .88508 m .2705 .8766 L .27659 .87974 L .39 0 0 r
F
.29544 .88789 m .28973 .88508 L .27659 .87974 L .363 0 0 r
F
.61351 .55034 m .6175 .55423 L .61604 .55668 L 1 .893 0 r
F
.61351 .55034 m .61495 .54781 L .6175 .55423 L F
.44822 .66027 m .44277 .66102 L .44513 .66247 L .609 .023 0 r
F
.45034 .66153 m .44822 .66027 L .44513 .66247 L .689 .041 0 r
F
.51197 .63428 m .51359 .63608 L .51085 .63633 L .661 .892 0 r
F
.51197 .63428 m .51482 .63398 L .51359 .63608 L F
.60604 .55293 m .61013 .55668 L .60864 .55901 L 1 .946 0 r
F
.60604 .55293 m .60749 .55051 L .61013 .55668 L F
.49982 .63688 m .50117 .63858 L .49854 .63858 L .736 .971 0 r
F
.49982 .63688 m .50258 .63678 L .50117 .63858 L F
.55285 .63626 m .55476 .63886 L .55184 .63987 L .757 .888 0 r
F
.55285 .63626 m .5558 .6351 L .55476 .63886 L F
.57107 .60517 m .57362 .60771 L .57126 .60934 L .904 .901 0 r
F
.57107 .60517 m .57343 .60344 L .57362 .60771 L F
.7414 .83307 m .73653 .83742 L .73088 .84161 L .457 .2 0 r
F
.7414 .83307 m .74734 .82865 L .73653 .83742 L F
.52423 .64489 m .52587 .6476 L .52281 .64766 L .667 .912 0 r
F
.52423 .64489 m .5274 .64477 L .52587 .6476 L F
.80367 .75289 m .80103 .75999 L .79646 .76533 L .659 .215 0 r
F
.80367 .75289 m .80837 .74729 L .80103 .75999 L F
.24941 .84589 m .23098 .83632 L .23672 .84023 L .518 0 0 r
F
.25485 .84949 m .24941 .84589 L .23672 .84023 L .498 0 0 r
F
.36541 .71603 m .35441 .71454 L .35652 .72014 L 1 .445 0 r
F
.36759 .72113 m .36541 .71603 L .35652 .72014 L 1 .472 0 r
F
.5636 .60494 m .5662 .60735 L .56386 .60887 L .91 .936 0 r
F
.5636 .60494 m .56594 .60332 L .5662 .60735 L F
.42175 .92001 m .40404 .91823 L .40769 .91909 L .206 0 0 r
F
.42459 .92064 m .42175 .92001 L .40769 .91909 L .173 0 0 r
F
.43845 .92097 m .42175 .92001 L .42459 .92064 L .157 0 0 r
F
.59269 .60666 m .59576 .61031 L .59337 .61232 L 1 .981 0 r
F
.59269 .60666 m .59504 .60451 L .59576 .61031 L F
.604 .90428 m .59725 .90678 L .59175 .90841 L .249 .181 0 r
F
.604 .90428 m .61009 .90251 L .59725 .90678 L F
.50743 .64633 m .5089 .64965 L .50597 .64919 L .805 .99 0 r
F
.50743 .64633 m .5105 .64678 L .5089 .64965 L F
.68537 .87658 m .67971 .87981 L .6737 .88298 L .345 .19 0 r
F
.68537 .87658 m .69179 .87319 L .67971 .87981 L F
.53786 .71046 m .54146 .72918 L .53663 .72551 L .93 .795 0 r
F
.53786 .71046 m .54299 .71441 L .54146 .72918 L F
.53239 .62821 m .5343 .62995 L .53158 .63073 L .676 .822 0 r
F
.53239 .62821 m .53516 .62732 L .5343 .62995 L F
.28698 .89121 m .26744 .88264 L .27367 .88574 L .371 0 0 r
F
.29281 .89398 m .28698 .89121 L .27367 .88574 L .343 0 0 r
F
.45439 .64464 m .45008 .64437 L .45238 .64479 L .14 0 0 r
F
.45644 .64496 m .45439 .64464 L .45238 .64479 L .238 0 0 r
F
.45842 .64457 m .45439 .64464 L .45644 .64496 L .12 0 0 r
F
.40404 .91823 m .38569 .91559 L .39009 .91672 L .239 0 0 r
F
.40769 .91909 m .40404 .91823 L .39009 .91672 L .207 0 0 r
F
.43344 .64082 m .42896 .63898 L .43167 .63976 L .041 .133 0 r
F
.43604 .64145 m .43344 .64082 L .43167 .63976 L .027 .132 0 r
F
.61202 .55284 m .61604 .55668 L .61454 .5591 L 1 .909 0 r
F
.61202 .55284 m .61351 .55034 L .61604 .55668 L F
.73285 .61817 m .73465 .62488 L .73194 .62909 L .845 .382 0 r
F
.73285 .61817 m .73555 .61378 L .73465 .62488 L F
.44319 .64323 m .43866 .64208 L .44129 .64272 L 0 .124 0 r
F
.47026 .6496 m .47021 .64985 L .46796 .6518 L .575 .215 0 r
F
.60454 .55532 m .60864 .55901 L .60711 .56132 L 1 .959 0 r
F
.60454 .55532 m .60604 .55293 L .60864 .55901 L F
.62759 .54691 m .63311 .55184 L .63181 .5546 L 1 .947 0 r
F
.62759 .54691 m .62879 .54408 L .63311 .55184 L F
.48688 .63938 m .48936 .63968 L .48777 .641 L .82 1 0 r
F
.45225 .72113 m .44346 .73343 L .44507 .73932 L .437 .046 0 r
F
.56868 .60687 m .57126 .60934 L .56887 .61093 L .897 .908 0 r
F
.56868 .60687 m .57107 .60517 L .57126 .60934 L F
.42089 .65557 m .4152 .65424 L .41799 .65572 L .499 0 0 r
F
.42358 .65684 m .42089 .65557 L .41799 .65572 L .54 0 0 r
F
.49729 .64756 m .49847 .65097 L .49577 .65031 L .94 1 0 r
F
.49729 .64756 m .50017 .64812 L .49847 .65097 L F
.60589 .9103 m .59893 .91248 L .59337 .91418 L .212 .174 0 r
F
.60589 .9103 m .61204 .90843 L .59893 .91248 L F
.4602 .64479 m .45842 .64457 L .45644 .64496 L .23 0 0 r
F
.56123 .60653 m .56386 .60887 L .56149 .61035 L .902 .94 0 r
F
.56123 .60653 m .5636 .60494 L .56386 .60887 L F
.42099 .92673 m .40305 .92467 L .40676 .92548 L .189 0 0 r
F
.42388 .92731 m .42099 .92673 L .40676 .92548 L .153 0 0 r
F
.54986 .63734 m .55184 .63987 L .54888 .6408 L .743 .887 0 r
F
.54986 .63734 m .55285 .63626 L .55184 .63987 L F
.50912 .63452 m .51085 .63633 L .50809 .63652 L .681 .919 0 r
F
.50912 .63452 m .51197 .63428 L .51085 .63633 L F
.40342 .74374 m .3909 .74878 L .39318 .75583 L 1 .419 0 r
F
.40562 .75012 m .40342 .74374 L .39318 .75583 L 1 .434 0 r
F
.45008 .64437 m .44567 .64373 L .44815 .64428 L .131 0 0 r
F
.45238 .64479 m .45008 .64437 L .44815 .64428 L .219 0 0 r
F
.5903 .60876 m .59337 .61232 L .59095 .61429 L 1 .986 0 r
F
.5903 .60876 m .59269 .60666 L .59337 .61232 L F
.60676 .71763 m .60862 .72498 L .60354 .72509 L .699 .942 0 r
F
.60676 .71763 m .61206 .71747 L .60862 .72498 L F
.52105 .64489 m .52281 .64766 L .51974 .6476 L .666 .914 0 r
F
.52105 .64489 m .52423 .64489 L .52281 .64766 L F
.50765 .92549 m .49633 .92664 L .49454 .92692 L 0 0 0 r
F
.50765 .92549 m .51035 .92518 L .49633 .92664 L F
.40305 .92467 m .38446 .92181 L .38894 .92287 L .216 0 0 r
F
.40676 .92548 m .40305 .92467 L .38894 .92287 L .181 0 0 r
F
.5296 .62902 m .53158 .63073 L .52883 .63144 L .668 .828 0 r
F
.5296 .62902 m .53239 .62821 L .53158 .63073 L F
.88846 .63126 m .88647 .64122 L .88382 .64804 L .723 .19 0 r
F
.88846 .63126 m .89118 .62421 L .88647 .64122 L F
.49062 .63835 m .49183 .63991 L .48936 .63968 L .783 1 0 r
F
.49062 .63835 m .49326 .63847 L .49183 .63991 L F
.66784 .6928 m .66865 .69804 L .66443 .70059 L .696 .587 0 r
F
.66784 .6928 m .67216 .69006 L .66865 .69804 L F
.49706 .63695 m .49854 .63858 L .4959 .63854 L .757 .989 0 r
F
.49706 .63695 m .49982 .63688 L .49854 .63858 L F
.61049 .55532 m .61454 .5591 L .61299 .5615 L 1 .924 0 r
F
.61049 .55532 m .61202 .55284 L .61454 .5591 L F
.60299 .55769 m .60711 .56132 L .60554 .56361 L 1 .972 0 r
F
.60299 .55769 m .60454 .55532 L .60711 .56132 L F
.44277 .66102 m .4372 .66136 L .43975 .66302 L .699 .033 0 r
F
.44513 .66247 m .44277 .66102 L .43975 .66302 L .782 .05 0 r
F
.56625 .60852 m .56887 .61093 L .56645 .61247 L .89 .913 0 r
F
.56625 .60852 m .56868 .60687 L .56887 .61093 L F
.81457 .76183 m .8107 .76819 L .80601 .7737 L .594 .205 0 r
F
.81457 .76183 m .81945 .75606 L .8107 .76819 L F
.46839 .65186 m .46796 .6518 L .46568 .65406 L 0 0 0 r
F
.47026 .6496 m .46796 .6518 L .46839 .65186 L .575 .215 0 r
F
.33762 .88526 m .31869 .88074 L .32438 .88323 L .457 0 0 r
F
.34281 .8875 m .33762 .88526 L .32438 .88323 L .437 0 0 r
F
.5604 .71352 m .56389 .72693 L .55865 .72436 L .784 .812 0 r
F
.5604 .71352 m .56596 .71633 L .56389 .72693 L F
.5171 .72794 m .51924 .75548 L .5153 .75152 L 1 .889 0 r
F
.5171 .72794 m .52136 .73227 L .51924 .75548 L F
.38961 .89568 m .37142 .8943 L .3762 .89603 L .42 0 0 r
F
.39372 .89722 m .38961 .89568 L .3762 .89603 L .403 0 0 r
F
.50438 .64583 m .50597 .64919 L .50306 .64867 L .834 .994 0 r
F
.50438 .64583 m .50743 .64633 L .50597 .64919 L F
.62633 .54973 m .63181 .5546 L .63047 .55734 L 1 .96 0 r
F
.62633 .54973 m .62759 .54691 L .63181 .5546 L F
.76427 .50533 m .77004 .51415 L .76938 .51907 L .991 .296 0 r
F
.76427 .50533 m .76479 .50033 L .77004 .51415 L F
.50804 .93029 m .49657 .93111 L .49477 .93139 L 0 0 0 r
F
.50804 .93029 m .51077 .92997 L .49657 .93111 L F
.3864 .73631 m .37421 .73843 L .37646 .74502 L 1 .476 0 r
F
.38864 .74229 m .3864 .73631 L .37646 .74502 L 1 .492 0 r
F
.62875 .88098 m .62357 .88467 L .61775 .88656 L .389 .203 0 r
F
.62875 .88098 m .63505 .87895 L .62357 .88467 L F
.49039 .64888 m .49131 .65239 L .48884 .65152 L 1 1 0 r
F
.49039 .64888 m .49307 .64961 L .49131 .65239 L F
.24124 .85932 m .22295 .84819 L .22891 .85219 L .441 0 0 r
F
.24693 .86299 m .24124 .85932 L .22891 .85219 L .417 0 0 r
F
.52258 .71312 m .5257 .73641 L .52136 .73227 L 1 .831 0 r
F
.52258 .71312 m .52716 .71741 L .5257 .73641 L F
.54684 .63835 m .54888 .6408 L .54589 .64165 L .727 .885 0 r
F
.54684 .63835 m .54986 .63734 L .54888 .6408 L F
.43464 .65994 m .42897 .65966 L .43168 .66129 L .657 .021 0 r
F
.4372 .66136 m .43464 .65994 L .43168 .66129 L .754 .039 0 r
F
.3667 .89248 m .34807 .88964 L .35338 .89169 L .439 0 0 r
F
.37142 .8943 m .3667 .89248 L .35338 .89169 L .421 0 0 r
F
.43604 .64145 m .43167 .63976 L .43439 .64054 L .027 .132 0 r
F
.43866 .64208 m .43604 .64145 L .43439 .64054 L .001 .129 0 r
F
.58786 .61082 m .59095 .61429 L .58848 .61621 L 1 .991 0 r
F
.58786 .61082 m .5903 .60876 L .59095 .61429 L F
.50627 .63472 m .50809 .63652 L .50533 .63667 L .706 .946 0 r
F
.50627 .63472 m .50912 .63452 L .50809 .63652 L F
.91462 .4581 m .91672 .47202 L .91688 .47929 L .764 .145 0 r
F
.91462 .4581 m .91446 .45071 L .91672 .47202 L F
.44346 .73343 m .43331 .74529 L .43518 .75241 L .659 .073 0 r
F
.44507 .73932 m .44346 .73343 L .43518 .75241 L .66 .092 0 r
F
.52678 .62977 m .52883 .63144 L .52606 .63209 L .66 .834 0 r
F
.52678 .62977 m .5296 .62902 L .52883 .63144 L F
.60141 .56004 m .60554 .56361 L .60393 .56587 L 1 .984 0 r
F
.60141 .56004 m .60299 .55769 L .60554 .56361 L F
.5638 .61014 m .56645 .61247 L .564 .61397 L .882 .918 0 r
F
.5638 .61014 m .56625 .60852 L .56645 .61247 L F
.60892 .55778 m .61299 .5615 L .6114 .56387 L 1 .939 0 r
F
.60892 .55778 m .61049 .55532 L .61299 .5615 L F
.57173 .89912 m .5651 .90276 L .56019 .90354 L .387 .203 0 r
F
.57173 .89912 m .57731 .89833 L .5651 .90276 L F
.50878 .77531 m .50725 .80645 L .50438 .80443 L 1 1 0 r
F
.50878 .77531 m .51224 .77868 L .50725 .80645 L F
.51786 .64475 m .51974 .6476 L .51667 .64743 L .669 .915 0 r
F
.51786 .64475 m .52105 .64489 L .51974 .6476 L F
.72754 .82681 m .72374 .83168 L .71811 .83558 L .516 .212 0 r
F
.72754 .82681 m .73343 .82266 L .72374 .83168 L F
.53283 .70629 m .53663 .72551 L .53186 .72157 L .937 .778 0 r
F
.53283 .70629 m .53786 .71046 L .53663 .72551 L F
.73006 .62251 m .73194 .62909 L .72914 .63324 L .843 .407 0 r
F
.73006 .62251 m .73285 .61817 L .73194 .62909 L F
.86874 .63185 m .8702 .64251 L .86753 .64907 L .836 .207 0 r
F
.86874 .63185 m .87128 .62505 L .8702 .64251 L F
.44567 .64373 m .44129 .64272 L .44393 .6434 L 0 .116 0 r
F
.44815 .64428 m .44567 .64373 L .44393 .6434 L .172 0 0 r
F
.45521 .66024 m .45034 .66153 L .45246 .66319 L .566 .027 0 r
F
.49444 .647 m .49577 .65031 L .49307 .64961 L .965 1 0 r
F
.49444 .647 m .49729 .64756 L .49577 .65031 L F
.42358 .65684 m .41799 .65572 L .42079 .65727 L .54 0 0 r
F
.42627 .6582 m .42358 .65684 L .42079 .65727 L .585 .005 0 r
F
.62502 .55253 m .63047 .55734 L .62907 .56006 L 1 .974 0 r
F
.62502 .55253 m .62633 .54973 L .63047 .55734 L F
.23749 .86549 m .21884 .85428 L .22495 .85827 L .426 0 0 r
F
.24331 .86914 m .23749 .86549 L .22495 .85827 L .401 0 0 r
F
.66995 .86266 m .66546 .8666 L .65953 .86935 L .427 .206 0 r
F
.66995 .86266 m .67626 .85971 L .66546 .8666 L F
.30201 .8727 m .28323 .86615 L .28913 .8692 L .472 0 0 r
F
.3075 .87547 m .30201 .8727 L .28913 .8692 L .452 0 0 r
F
.46839 .65186 m .46568 .65406 L .4665 .65458 L 0 0 0 r
F
.4943 .63701 m .4959 .63854 L .49326 .63847 L .773 1 0 r
F
.4943 .63701 m .49706 .63695 L .4959 .63854 L F
.45034 .66153 m .44513 .66247 L .44748 .6643 L .689 .041 0 r
F
.45246 .66319 m .45034 .66153 L .44748 .6643 L .759 .058 0 r
F
.54378 .63926 m .54589 .64165 L .54287 .64242 L .71 .882 0 r
F
.54378 .63926 m .54684 .63835 L .54589 .64165 L F
.58538 .61283 m .58848 .61621 L .58597 .61808 L .998 .994 0 r
F
.58538 .61283 m .58786 .61082 L .58848 .61621 L F
.8258 .46852 m .89884 .47934 L .89786 .4863 L 0 .132 0 r
F
.56131 .61171 m .5638 .61014 L .564 .61397 L .873 .922 0 r
F
.59978 .56236 m .60393 .56587 L .60227 .56811 L 1 .996 0 r
F
.59978 .56236 m .60141 .56004 L .60393 .56587 L F
.52394 .63044 m .52606 .63209 L .52328 .63267 L .652 .841 0 r
F
.52394 .63044 m .52678 .62977 L .52606 .63209 L F
.50135 .64534 m .50306 .64867 L .50017 .64812 L .866 1 0 r
F
.50135 .64534 m .50438 .64583 L .50306 .64867 L F
.60731 .56022 m .6114 .56387 L .60976 .56623 L 1 .952 0 r
F
.60731 .56022 m .60892 .55778 L .6114 .56387 L F
.45644 .64496 m .45238 .64479 L .45467 .64534 L .238 0 0 r
F
.4585 .64543 m .45644 .64496 L .45467 .64534 L .368 0 0 r
F
.4602 .64479 m .45644 .64496 L .4585 .64543 L .23 0 0 r
F
.53437 .90876 m .52587 .91185 L .52239 .91214 L .334 .196 0 r
F
.53437 .90876 m .53866 .90848 L .52587 .91185 L F
.48797 .63817 m .48936 .63968 L .48688 .63938 L .804 1 0 r
F
.48797 .63817 m .49062 .63835 L .48936 .63968 L F
.60137 .71749 m .60354 .72509 L .59838 .72489 L .686 .93 0 r
F
.60137 .71749 m .60676 .71763 L .60354 .72509 L F
.50342 .6349 m .50533 .63667 L .50258 .63678 L .735 .972 0 r
F
.50342 .6349 m .50627 .63472 L .50533 .63667 L F
.79886 .75841 m .79646 .76533 L .79177 .77059 L .66 .217 0 r
F
.79886 .75841 m .80367 .75289 L .79646 .76533 L F
.66343 .69541 m .66443 .70059 L .66012 .703 L .689 .619 0 r
F
.66343 .69541 m .66784 .6928 L .66443 .70059 L F
.36759 .72113 m .35652 .72014 L .35865 .72606 L 1 .472 0 r
F
.36978 .72653 m .36759 .72113 L .35865 .72606 L 1 .497 0 r
F
.45238 .64479 m .44815 .64428 L .45065 .64492 L .219 0 0 r
F
.45467 .64534 m .45238 .64479 L .45065 .64492 L .341 0 0 r
F
.63372 .89363 m .62798 .89639 L .62208 .89857 L .299 .188 0 r
F
.63372 .89363 m .64012 .89129 L .62798 .89639 L F
.55484 .71029 m .55865 .72436 L .55341 .7214 L .779 .776 0 r
F
.55484 .71029 m .5604 .71352 L .55865 .72436 L F
.51466 .64447 m .51667 .64743 L .51358 .64715 L .677 .914 0 r
F
.51466 .64447 m .51786 .64475 L .51667 .64743 L F
.43866 .64208 m .43439 .64054 L .43712 .64133 L .001 .129 0 r
F
.44129 .64272 m .43866 .64208 L .43712 .64133 L 0 .123 0 r
F
.33212 .90188 m .313 .89565 L .31898 .89801 L .325 0 0 r
F
.33762 .90393 m .33212 .90188 L .31898 .89801 L .296 0 0 r
F
.51141 .74728 m .51224 .77868 L .50878 .77531 L 1 .949 0 r
F
.51141 .74728 m .5153 .75152 L .51224 .77868 L F
.62365 .55532 m .62907 .56006 L .62761 .56277 L 1 .987 0 r
F
.62365 .55532 m .62502 .55253 L .62907 .56006 L F
.76365 .51032 m .76938 .51907 L .76862 .52399 L 1 .322 0 r
F
.76365 .51032 m .76427 .50533 L .76938 .51907 L F
.59811 .56466 m .60227 .56811 L .60057 .57033 L 1 1 0 r
F
.59811 .56466 m .59978 .56236 L .60227 .56811 L F
.57492 .91246 m .56776 .91475 L .56277 .91584 L .229 .179 0 r
F
.57492 .91246 m .58059 .91125 L .56776 .91475 L F
.52109 .63103 m .52328 .63267 L .52047 .63318 L .645 .848 0 r
F
.52109 .63103 m .52394 .63044 L .52328 .63267 L F
.58287 .6148 m .58597 .61808 L .58342 .61991 L .987 .997 0 r
F
.58287 .6148 m .58538 .61283 L .58597 .61808 L F
.60565 .56263 m .60976 .56623 L .60808 .56855 L 1 .965 0 r
F
.60565 .56263 m .60731 .56022 L .60976 .56623 L F
.5407 .64008 m .54287 .64242 L .53983 .64309 L .692 .877 0 r
F
.5407 .64008 m .54378 .63926 L .54287 .64242 L F
.73536 .83739 m .73088 .84161 L .72514 .8457 L .461 .202 0 r
F
.73536 .83739 m .7414 .83307 L .73088 .84161 L F
.48772 .64807 m .48884 .65152 L .48637 .65057 L 1 1 0 r
F
.48772 .64807 m .49039 .64888 L .48884 .65152 L F
.38569 .91559 m .36712 .91208 L .3722 .91349 L .256 0 0 r
F
.39009 .91672 m .38569 .91559 L .3722 .91349 L .225 0 0 r
F
.63603 .89951 m .6301 .90205 L .62415 .9043 L .275 .183 0 r
F
.63603 .89951 m .64249 .89706 L .6301 .90205 L F
.41997 .74895 m .40784 .75717 L .41009 .76499 L .956 .342 0 r
F
.42205 .75602 m .41997 .74895 L .41009 .76499 L .953 .357 0 r
F
.25485 .84949 m .23672 .84023 L .24255 .84405 L .498 0 0 r
F
.26037 .85301 m .25485 .84949 L .24255 .84405 L .478 0 0 r
F
.67606 .87441 m .67101 .87764 L .66498 .88062 L .363 .195 0 r
F
.67606 .87441 m .68248 .87123 L .67101 .87764 L F
.44513 .66247 m .43975 .66302 L .4423 .66503 L .782 .05 0 r
F
.44748 .6643 m .44513 .66247 L .4423 .66503 L .854 .067 0 r
F
.3621 .91056 m .34317 .90586 L .34879 .90768 L .286 0 0 r
F
.36712 .91208 m .3621 .91056 L .34879 .90768 L .257 0 0 r
F
.88561 .63827 m .88382 .64804 L .88105 .65482 L .729 .194 0 r
F
.88561 .63827 m .88846 .63126 L .88382 .64804 L F
.50059 .6351 m .50258 .63678 L .49982 .63688 L .763 .995 0 r
F
.50059 .6351 m .50342 .6349 L .50258 .63678 L F
.4703 .64946 m .47026 .6496 L .46839 .65186 L .58 .201 0 r
F
.4372 .66136 m .43168 .66129 L .43438 .66314 L .754 .039 0 r
F
.43975 .66302 m .4372 .66136 L .43438 .66314 L .846 .056 0 r
F
.49154 .63703 m .49326 .63847 L .49062 .63835 L .785 1 0 r
F
.49154 .63703 m .4943 .63701 L .49326 .63847 L F
.72717 .6268 m .72914 .63324 L .72625 .63734 L .841 .431 0 r
F
.72717 .6268 m .73006 .62251 L .72914 .63324 L F
.33012 .90795 m .31072 .9016 L .31683 .9039 L .301 0 0 r
F
.33572 .90994 m .33012 .90795 L .31683 .9039 L .271 0 0 r
F
.4916 .64644 m .49307 .64961 L .49039 .64888 L .986 1 0 r
F
.4916 .64644 m .49444 .647 L .49307 .64961 L F
.55625 .61471 m .559 .61684 L .55646 .61821 L .854 .927 0 r
F
.55625 .61471 m .5588 .61323 L .559 .61684 L F
.53617 .92099 m .52725 .92278 L .5237 .92329 L .161 .168 0 r
F
.53617 .92099 m .54053 .92041 L .52725 .92278 L F
.57637 .91849 m .56901 .92037 L .56397 .92153 L .179 .17 0 r
F
.57637 .91849 m .58209 .91718 L .56901 .92037 L F
.44815 .64428 m .44393 .6434 L .44658 .64415 L .172 0 0 r
F
.45065 .64492 m .44815 .64428 L .44658 .64415 L .282 0 0 r
F
.5964 .56694 m .60057 .57033 L .59884 .57251 L 1 1 0 r
F
.5964 .56694 m .59811 .56466 L .60057 .57033 L F
.42627 .6582 m .42079 .65727 L .42361 .65894 L .585 .005 0 r
F
.42897 .65966 m .42627 .6582 L .42361 .65894 L .655 .021 0 r
F
.49836 .64489 m .50017 .64812 L .49729 .64756 L .901 1 0 r
F
.49836 .64489 m .50135 .64534 L .50017 .64812 L F
.51146 .64406 m .51358 .64715 L .5105 .64678 L .692 .914 0 r
F
.51146 .64406 m .51466 .64447 L .51358 .64715 L F
.52792 .70201 m .53186 .72157 L .52716 .71741 L .948 .766 0 r
F
.52792 .70201 m .53283 .70629 L .53186 .72157 L F
.55024 .90457 m .54291 .90805 L .53866 .90848 L .382 .202 0 r
F
.55024 .90457 m .55524 .90414 L .54291 .90805 L F
.51813 .70881 m .52136 .73227 L .5171 .72794 L 1 .823 0 r
F
.51813 .70881 m .52258 .71312 L .52136 .73227 L F
.51821 .63153 m .52047 .63318 L .51765 .63362 L .64 .857 0 r
F
.51821 .63153 m .52109 .63103 L .52047 .63318 L F
.62222 .55809 m .62761 .56277 L .6261 .56545 L 1 .999 0 r
F
.62222 .55809 m .62365 .55532 L .62761 .56277 L F
.60395 .56502 m .60808 .56855 L .60636 .57085 L 1 .977 0 r
F
.60395 .56502 m .60565 .56263 L .60808 .56855 L F
.5803 .61672 m .58342 .61991 L .58083 .62168 L .976 .998 0 r
F
.5803 .61672 m .58287 .6148 L .58342 .61991 L F
.53759 .64081 m .53983 .64309 L .53676 .64367 L .673 .871 0 r
F
.53759 .64081 m .5407 .64008 L .53983 .64309 L F
.38446 .92181 m .36566 .91811 L .37083 .91945 L .23 0 0 r
F
.38894 .92287 m .38446 .92181 L .37083 .91945 L .196 0 0 r
F
.29544 .88789 m .27659 .87974 L .28277 .88276 L .363 0 0 r
F
.30122 .89059 m .29544 .88789 L .28277 .88276 L .337 0 0 r
F
.80958 .76751 m .80601 .7737 L .80121 .77914 L .597 .207 0 r
F
.80958 .76751 m .81457 .76183 L .80601 .7737 L F
.59386 .89246 m .58832 .8962 L .58284 .89735 L .4 .205 0 r
F
.59386 .89246 m .59993 .89125 L .58832 .8962 L F
.67888 .87985 m .6737 .88298 L .6676 .88604 L .353 .192 0 r
F
.67888 .87985 m .68537 .87658 L .6737 .88298 L F
.43331 .74529 m .42205 .75602 L .42415 .76407 L .824 .229 0 r
F
.43518 .75241 m .43331 .74529 L .42415 .76407 L .823 .247 0 r
F
.36055 .91665 m .34138 .91181 L .3471 .91356 L .26 0 0 r
F
.36566 .91811 m .36055 .91665 L .3471 .91356 L .228 0 0 r
F
.59589 .71701 m .59838 .72489 L .59315 .72438 L .67 .909 0 r
F
.59589 .71701 m .60137 .71749 L .59838 .72489 L F
.44129 .64272 m .43712 .64133 L .43987 .64215 L 0 .123 0 r
F
.44393 .6434 m .44129 .64272 L .43987 .64215 L 0 .113 0 r
F
.53697 .92649 m .52789 .92788 L .52431 .92842 L .111 .159 0 r
F
.53697 .92649 m .54139 .92585 L .52789 .92788 L F
.55368 .61615 m .55646 .61821 L .55389 .61953 L .844 .928 0 r
F
.55368 .61615 m .55625 .61471 L .55646 .61821 L F
.51294 .7235 m .5153 .75152 L .51141 .74728 L 1 .878 0 r
F
.51294 .7235 m .5171 .72794 L .5153 .75152 L F
.5493 .70668 m .55341 .7214 L .54818 .71808 L .776 .744 0 r
F
.5493 .70668 m .55484 .71029 L .55341 .7214 L F
.65893 .69787 m .66012 .703 L .65572 .70527 L .681 .648 0 r
F
.65893 .69787 m .66343 .69541 L .66012 .703 L F
.59465 .56919 m .59884 .57251 L .59706 .57467 L 1 1 0 r
F
.59465 .56919 m .5964 .56694 L .59884 .57251 L F
.91465 .46551 m .91688 .47929 L .9169 .48656 L .777 .15 0 r
F
.91465 .46551 m .91462 .4581 L .91688 .47929 L F
.46883 .65222 m .46839 .65186 L .4665 .65458 L 0 0 0 r
F
.4703 .64946 m .46839 .65186 L .46883 .65222 L .58 .201 0 r
F
.42725 .89562 m .41088 .89712 L .4143 .89841 L .33 0 0 r
F
.42989 .89676 m .42725 .89562 L .4143 .89841 L .312 0 0 r
F
.51531 .63193 m .51765 .63362 L .51482 .63398 L .638 .869 0 r
F
.51531 .63193 m .51821 .63153 L .51765 .63362 L F
.86606 .63861 m .86753 .64907 L .86474 .65559 L .836 .209 0 r
F
.86606 .63861 m .86874 .63185 L .86753 .64907 L F
.49776 .63531 m .49982 .63688 L .49706 .63695 L .784 1 0 r
F
.49776 .63531 m .50059 .6351 L .49982 .63688 L F
.60221 .56738 m .60636 .57085 L .6046 .57312 L 1 .988 0 r
F
.60221 .56738 m .60395 .56502 L .60636 .57085 L F
.50827 .64356 m .5105 .64678 L .50743 .64633 L .719 .917 0 r
F
.50827 .64356 m .51146 .64406 L .5105 .64678 L F
.41088 .89712 m .39372 .89722 L .39788 .89867 L .38 0 0 r
F
.4143 .89841 m .41088 .89712 L .39788 .89867 L .363 0 0 r
F
.5777 .61859 m .58083 .62168 L .5782 .62341 L .964 .999 0 r
F
.5777 .61859 m .5803 .61672 L .58083 .62168 L F
.62074 .56083 m .6261 .56545 L .62454 .5681 L 1 1 0 r
F
.62074 .56083 m .62222 .55809 L .6261 .56545 L F
.29281 .89398 m .27367 .88574 L .27997 .88872 L .343 0 0 r
F
.29871 .89664 m .29281 .89398 L .27997 .88872 L .315 0 0 r
F
.45467 .64534 m .45065 .64492 L .45315 .64573 L .341 0 0 r
F
.45698 .64611 m .45467 .64534 L .45315 .64573 L .481 0 0 r
F
.4585 .64543 m .45467 .64534 L .45698 .64611 L .368 0 0 r
F
.53445 .64142 m .53676 .64367 L .53366 .64415 L .652 .863 0 r
F
.53445 .64142 m .53759 .64081 L .53676 .64367 L F
.76292 .51532 m .76862 .52399 L .76776 .5289 L 1 .348 0 r
F
.76292 .51532 m .76365 .51032 L .76862 .52399 L F
.40562 .75012 m .39318 .75583 L .39551 .7635 L 1 .434 0 r
F
.40784 .75717 m .40562 .75012 L .39551 .7635 L 1 .447 0 r
F
.46057 .64621 m .4585 .64543 L .45698 .64611 L .505 .002 0 r
F
.55109 .61753 m .55389 .61953 L .55129 .6208 L .833 .928 0 r
F
.55109 .61753 m .55368 .61615 L .55389 .61953 L F
.48877 .63698 m .49062 .63835 L .48797 .63817 L .792 1 0 r
F
.48877 .63698 m .49154 .63703 L .49062 .63835 L F
.84426 .47414 m .89786 .4863 L .89695 .49325 L .321 0 0 r
F
.84426 .47414 m .8258 .46852 L .89786 .4863 L F
.49539 .64449 m .49729 .64756 L .49444 .647 L .932 1 0 r
F
.49539 .64449 m .49836 .64489 L .49729 .64756 L F
.59287 .57141 m .59706 .57467 L .59524 .57681 L 1 1 0 r
F
.59287 .57141 m .59465 .56919 L .59706 .57467 L F
.38864 .74229 m .37646 .74502 L .37874 .75208 L 1 .492 0 r
F
.3909 .74878 m .38864 .74229 L .37874 .75208 L 1 .507 0 r
F
.52013 .92366 m .51035 .92518 L .50765 .92549 L .128 .162 0 r
F
.52013 .92366 m .5237 .92329 L .51035 .92518 L F
.55266 .91762 m .54485 .91968 L .54053 .92041 L .204 .175 0 r
F
.55266 .91762 m .55774 .9168 L .54485 .91968 L F
.45705 .66172 m .45246 .66319 L .45456 .6655 L .64 .047 0 r
F
.5124 .63224 m .51482 .63398 L .51197 .63428 L .644 .885 0 r
F
.5124 .63224 m .51531 .63193 L .51482 .63398 L F
.45246 .66319 m .44748 .6643 L .44983 .66673 L .759 .058 0 r
F
.45456 .6655 m .45246 .66319 L .44983 .66673 L .816 .074 0 r
F
.60042 .56972 m .6046 .57312 L .60279 .57537 L 1 .999 0 r
F
.60042 .56972 m .60221 .56738 L .6046 .57312 L F
.24693 .86299 m .22891 .85219 L .23496 .85609 L .417 0 0 r
F
.2527 .86655 m .24693 .86299 L .23496 .85609 L .393 0 0 r
F
.48877 .64582 m .49039 .64888 L .48772 .64807 L .999 1 0 r
F
.48877 .64582 m .4916 .64644 L .49039 .64888 L F
.72155 .83084 m .72754 .82681 L .71811 .83558 L .519 .214 0 r
F
.7242 .63103 m .72625 .63734 L .72327 .64139 L .84 .455 0 r
F
.7242 .63103 m .72717 .6268 L .72625 .63734 L F
.42897 .65966 m .42361 .65894 L .42642 .66076 L .655 .021 0 r
F
.43168 .66129 m .42897 .65966 L .42642 .66076 L .765 .039 0 r
F
.54846 .61887 m .55129 .6208 L .54866 .62202 L .821 .927 0 r
F
.54846 .61887 m .55109 .61753 L .55129 .6208 L F
.57506 .62042 m .5782 .62341 L .57553 .62508 L .951 .999 0 r
F
.57506 .62042 m .5777 .61859 L .5782 .62341 L F
.52318 .69773 m .52716 .71741 L .52258 .71312 L .962 .76 0 r
F
.52318 .69773 m .52792 .70201 L .52716 .71741 L F
.59785 .9059 m .59175 .90841 L .5862 .9099 L .27 .185 0 r
F
.59785 .9059 m .604 .90428 L .59175 .90841 L F
.45065 .64492 m .44658 .64415 L .44923 .64503 L .282 0 0 r
F
.45315 .64573 m .45065 .64492 L .44923 .64503 L .423 0 0 r
F
.79393 .76385 m .79177 .77059 L .78698 .77578 L .661 .219 0 r
F
.79393 .76385 m .79886 .75841 L .79177 .77059 L F
.49493 .63553 m .49706 .63695 L .4943 .63701 L .794 1 0 r
F
.49493 .63553 m .49776 .63531 L .49706 .63695 L F
.50511 .64303 m .50743 .64633 L .50438 .64583 L .759 .929 0 r
F
.50511 .64303 m .50827 .64356 L .50743 .64633 L F
.6192 .56356 m .62454 .5681 L .62292 .57074 L 1 1 0 r
F
.6192 .56356 m .62074 .56083 L .62454 .5681 L F
.53128 .64191 m .53366 .64415 L .53054 .64452 L .631 .854 0 r
F
.53128 .64191 m .53445 .64142 L .53366 .64415 L F
.59104 .57361 m .59524 .57681 L .59338 .57891 L 1 1 0 r
F
.59104 .57361 m .59287 .57141 L .59524 .57681 L F
.52069 .92881 m .52431 .92842 L .51077 .92997 L .084 .154 0 r
F
.52069 .92881 m .51077 .92997 L .50804 .93029 L F
.44393 .6434 m .43987 .64215 L .44263 .64303 L 0 .113 0 r
F
.44658 .64415 m .44393 .6434 L .44263 .64303 L 0 .096 0 r
F
.36978 .72653 m .35865 .72606 L .3608 .73233 L 1 .497 0 r
F
.37198 .73229 m .36978 .72653 L .3608 .73233 L 1 .519 0 r
F
.46732 .65569 m .4665 .65458 L .46459 .65792 L .18 0 0 r
F
.46883 .65222 m .4665 .65458 L .46732 .65569 L 0 0 0 r
F
.55374 .92344 m .54576 .92509 L .54139 .92585 L .15 .166 0 r
F
.55374 .92344 m .55888 .92255 L .54576 .92509 L F
.54383 .70274 m .54818 .71808 L .54299 .71441 L .778 .717 0 r
F
.54383 .70274 m .5493 .70668 L .54818 .71808 L F
.43975 .66302 m .43438 .66314 L .43708 .66533 L .846 .056 0 r
F
.4423 .66503 m .43975 .66302 L .43708 .66533 L .925 .073 0 r
F
.59034 .71617 m .59315 .72438 L .58783 .72353 L .653 .882 0 r
F
.59034 .71617 m .59589 .71701 L .59315 .72438 L F
.50948 .63247 m .51197 .63428 L .50912 .63452 L .662 .909 0 r
F
.50948 .63247 m .5124 .63224 L .51197 .63428 L F
.5986 .57203 m .60279 .57537 L .60094 .57758 L 1 1 0 r
F
.5986 .57203 m .60042 .56972 L .60279 .57537 L F
.54581 .62016 m .54866 .62202 L .54601 .62319 L .809 .925 0 r
F
.54581 .62016 m .54846 .61887 L .54866 .62202 L F
.65435 .7002 m .65572 .70527 L .65123 .70739 L .675 .675 0 r
F
.65435 .7002 m .65893 .69787 L .65572 .70527 L F
.24331 .86914 m .22495 .85827 L .23115 .86214 L .401 0 0 r
F
.24922 .87268 m .24331 .86914 L .23115 .86214 L .376 0 0 r
F
.62238 .88283 m .61775 .88656 L .61188 .88829 L .407 .206 0 r
F
.62238 .88283 m .62875 .88098 L .61775 .88656 L F
.51383 .70457 m .5171 .72794 L .51294 .7235 L 1 .819 0 r
F
.51383 .70457 m .51813 .70881 L .5171 .72794 L F
.59967 .91203 m .59337 .91418 L .58776 .91575 L .228 .178 0 r
F
.59967 .91203 m .60589 .9103 L .59337 .91418 L F
.44748 .6643 m .4423 .66503 L .44483 .66759 L .854 .067 0 r
F
.44983 .66673 m .44748 .6643 L .44483 .66759 L .911 .128 0 r
F
.58918 .57577 m .59338 .57891 L .59149 .58098 L 1 1 0 r
F
.58918 .57577 m .59104 .57361 L .59338 .57891 L F
.57238 .62218 m .57553 .62508 L .57282 .62669 L .938 .997 0 r
F
.57238 .62218 m .57506 .62042 L .57553 .62508 L F
.34281 .8875 m .32438 .88323 L .33014 .88562 L .437 0 0 r
F
.34807 .88964 m .34281 .8875 L .33014 .88562 L .418 0 0 r
F
.49245 .64414 m .49444 .647 L .4916 .64644 L .955 1 0 r
F
.49245 .64414 m .49539 .64449 L .49444 .647 L F
.66356 .86547 m .65953 .86935 L .65352 .87197 L .435 .208 0 r
F
.66356 .86547 m .66995 .86266 L .65953 .86935 L F
.88262 .64524 m .88105 .65482 L .87814 .66155 L .735 .197 0 r
F
.88262 .64524 m .88561 .63827 L .88105 .65482 L F
.52809 .64228 m .53054 .64452 L .5274 .64477 L .608 .843 0 r
F
.52809 .64228 m .53128 .64191 L .53054 .64452 L F
.61761 .56627 m .62292 .57074 L .62126 .57334 L 1 1 0 r
F
.61761 .56627 m .6192 .56356 L .62292 .57074 L F
.50199 .64255 m .50438 .64583 L .50135 .64534 L .812 .952 0 r
F
.50199 .64255 m .50511 .64303 L .50438 .64583 L F
.50658 .63266 m .50912 .63452 L .50627 .63472 L .699 .943 0 r
F
.50658 .63266 m .50948 .63247 L .50912 .63452 L F
.4921 .63571 m .4943 .63701 L .49154 .63703 L .795 1 0 r
F
.4921 .63571 m .49493 .63553 L .4943 .63701 L F
.59674 .57431 m .60094 .57758 L .59905 .57977 L 1 1 0 r
F
.59674 .57431 m .5986 .57203 L .60094 .57758 L F
.54314 .6214 m .54601 .62319 L .54334 .62431 L .795 .921 0 r
F
.54314 .6214 m .54581 .62016 L .54601 .62319 L F
.3075 .87547 m .28913 .8692 L .2951 .87216 L .452 0 0 r
F
.31306 .87815 m .3075 .87547 L .2951 .87216 L .431 0 0 r
F
.76208 .52031 m .76776 .5289 L .76681 .5338 L 1 .374 0 r
F
.76208 .52031 m .76292 .51532 L .76776 .5289 L F
.72923 .8416 m .72514 .8457 L .71931 .84968 L .466 .204 0 r
F
.72923 .8416 m .73536 .83739 L .72514 .8457 L F
.58727 .57791 m .59149 .58098 L .58955 .58303 L 1 1 0 r
F
.58727 .57791 m .58918 .57577 L .59149 .58098 L F
.48023 .93221 m .4672 .93239 L .46731 .93252 L .011 0 0 r
F
.48023 .93221 m .48109 .93209 L .4672 .93239 L F
.48595 .64507 m .48877 .64582 L .48772 .64807 L 1 1 0 r
F
.47035 .64964 m .4703 .64946 L .46883 .65222 L 0 0 0 r
F
.47139 .64683 m .4703 .64946 L .47035 .64964 L .872 .467 0 r
F
.44507 .73932 m .43518 .75241 L .43705 .76084 L .66 .092 0 r
F
.44667 .74654 m .44507 .73932 L .43705 .76084 L .663 .113 0 r
F
.50534 .77157 m .50878 .77531 L .50438 .80443 L 1 1 0 r
F
.72113 .63521 m .72327 .64139 L .7202 .64537 L .841 .478 0 r
F
.72113 .63521 m .7242 .63103 L .72327 .64139 L F
.52487 .6425 m .5274 .64477 L .52423 .64489 L .586 .83 0 r
F
.52487 .6425 m .52809 .64228 L .5274 .64477 L F
.45698 .64611 m .45315 .64573 L .45565 .64684 L .481 0 0 r
F
.45928 .64731 m .45698 .64611 L .45565 .64684 L .698 .032 0 r
F
.46057 .64621 m .45698 .64611 L .45928 .64731 L .505 .002 0 r
F
.53844 .69852 m .54299 .71441 L .53786 .71046 L .784 .696 0 r
F
.53844 .69852 m .54383 .70274 L .54299 .71441 L F
.80447 .77311 m .80121 .77914 L .7963 .78449 L .601 .209 0 r
F
.80447 .77311 m .80958 .76751 L .80121 .77914 L F
.51862 .69356 m .52258 .71312 L .51813 .70881 L .981 .76 0 r
F
.51862 .69356 m .52318 .69773 L .52258 .71312 L F
.50758 .74281 m .50878 .77531 L .50534 .77157 L 1 .934 0 r
F
.50758 .74281 m .51141 .74728 L .50878 .77531 L F
.44658 .64415 m .44263 .64303 L .44539 .644 L 0 .096 0 r
F
.44923 .64503 m .44658 .64415 L .44539 .644 L .322 0 0 r
F
.50369 .6329 m .50627 .63472 L .50342 .6349 L .752 .985 0 r
F
.50369 .6329 m .50658 .63266 L .50627 .63472 L F
.54044 .62258 m .54334 .62431 L .54064 .62537 L .781 .917 0 r
F
.54044 .62258 m .54314 .6214 L .54334 .62431 L F
.86324 .64534 m .86474 .65559 L .86183 .66207 L .836 .211 0 r
F
.86324 .64534 m .86606 .63861 L .86474 .65559 L F
.59484 .57656 m .59905 .57977 L .59712 .58193 L 1 1 0 r
F
.59484 .57656 m .59674 .57431 L .59905 .57977 L F
.91453 .47293 m .9169 .48656 L .91678 .49384 L .788 .155 0 r
F
.91453 .47293 m .91465 .46551 L .9169 .48656 L F
.61597 .56895 m .62126 .57334 L .61954 .57593 L 1 1 0 r
F
.61597 .56895 m .61761 .56627 L .62126 .57334 L F
.26037 .85301 m .24255 .84405 L .24845 .84778 L .478 0 0 r
F
.26597 .85643 m .26037 .85301 L .24845 .84778 L .457 0 0 r
F
.49296 .93152 m .48109 .93209 L .48023 .93221 L 0 0 0 r
F
.49296 .93152 m .49477 .93139 L .48109 .93209 L F
.43168 .66129 m .42642 .66076 L .42923 .6628 L .765 .039 0 r
F
.43438 .66314 m .43168 .66129 L .42923 .6628 L .873 .058 0 r
F
.49893 .64221 m .50135 .64534 L .49836 .64489 L .87 .983 0 r
F
.49893 .64221 m .50199 .64255 L .50135 .64534 L F
.37142 .8943 m .35338 .89169 L .35876 .89365 L .421 0 0 r
F
.3762 .89603 m .37142 .8943 L .35876 .89365 L .402 0 0 r
F
.40769 .91909 m .39009 .91672 L .39453 .91773 L .207 0 0 r
F
.41137 .91984 m .40769 .91909 L .39453 .91773 L .175 0 0 r
F
.42459 .92064 m .40769 .91909 L .41137 .91984 L .173 0 0 r
F
.45315 .64573 m .44923 .64503 L .45189 .64613 L .423 0 0 r
F
.45565 .64684 m .45315 .64573 L .45189 .64613 L .576 .007 0 r
F
.5847 .71495 m .58783 .72353 L .58244 .72232 L .634 .847 0 r
F
.5847 .71495 m .59034 .71617 L .58783 .72353 L F
.58534 .58002 m .58955 .58303 L .58758 .58504 L 1 1 0 r
F
.58534 .58002 m .58727 .57791 L .58955 .58303 L F
.50889 .71903 m .51141 .74728 L .50758 .74281 L 1 .871 0 r
F
.50889 .71903 m .51294 .7235 L .51141 .74728 L F
.46732 .65569 m .46459 .65792 L .46577 .66018 L .18 0 0 r
F
.46263 .64766 m .46057 .64621 L .45928 .64731 L .741 .05 0 r
F
.42745 .92115 m .42459 .92064 L .41137 .91984 L .139 0 0 r
F
.48927 .63584 m .49154 .63703 L .48877 .63698 L .786 1 0 r
F
.48927 .63584 m .4921 .63571 L .49154 .63703 L F
.48952 .64377 m .4916 .64644 L .48877 .64582 L .964 1 0 r
F
.48952 .64377 m .49245 .64414 L .4916 .64644 L F
.85526 .4804 m .89695 .49325 L .89612 .5002 L .577 0 0 r
F
.85526 .4804 m .84426 .47414 L .89695 .49325 L F
.39372 .89722 m .3762 .89603 L .38103 .89768 L .403 0 0 r
F
.39788 .89867 m .39372 .89722 L .38103 .89768 L .385 0 0 r
F
.53772 .62371 m .54064 .62537 L .53791 .62638 L .766 .912 0 r
F
.53772 .62371 m .54044 .62258 L .54064 .62537 L F
.52162 .64256 m .52423 .64489 L .52105 .64489 L .564 .817 0 r
F
.52162 .64256 m .52487 .6425 L .52423 .64489 L F
.62725 .89583 m .62208 .89857 L .61612 .90061 L .313 .191 0 r
F
.62725 .89583 m .63372 .89363 L .62208 .89857 L F
.64967 .70236 m .65123 .70739 L .64665 .70935 L .668 .699 0 r
F
.64967 .70236 m .65435 .7002 L .65123 .70739 L F
.50083 .63323 m .50342 .6349 L .50059 .6351 L .801 1 0 r
F
.50083 .63323 m .50369 .6329 L .50342 .6349 L F
.66955 .87747 m .66498 .88062 L .65888 .88347 L .371 .197 0 r
F
.66955 .87747 m .67606 .87441 L .66498 .88062 L F
.59289 .57878 m .59712 .58193 L .59516 .58405 L 1 1 0 r
F
.59289 .57878 m .59484 .57656 L .59712 .58193 L F
.56609 .89973 m .56019 .90354 L .55524 .90414 L .426 .29 0 r
F
.56609 .89973 m .57173 .89912 L .56019 .90354 L F
.58336 .5821 m .58758 .58504 L .58557 .58702 L 1 1 0 r
F
.58336 .5821 m .58534 .58002 L .58758 .58504 L F
.46926 .65328 m .46883 .65222 L .46732 .65569 L 0 0 0 r
F
.47035 .64964 m .46883 .65222 L .46926 .65328 L F
.61428 .57161 m .61954 .57593 L .61777 .57848 L 1 1 0 r
F
.61428 .57161 m .61597 .56895 L .61954 .57593 L F
.53497 .62478 m .53791 .62638 L .53516 .62732 L .75 .905 0 r
F
.53497 .62478 m .53772 .62371 L .53791 .62638 L F
.40676 .92548 m .38894 .92287 L .39346 .9238 L .181 0 0 r
F
.41051 .92616 m .40676 .92548 L .39346 .9238 L .146 0 0 r
F
.42388 .92731 m .40676 .92548 L .41051 .92616 L .153 0 0 r
F
.49592 .64203 m .49836 .64489 L .49539 .64449 L .918 1 0 r
F
.49592 .64203 m .49893 .64221 L .49836 .64489 L F
.53319 .69412 m .53786 .71046 L .53283 .70629 L .797 .682 0 r
F
.53319 .69412 m .53844 .69852 L .53786 .71046 L F
.4423 .66503 m .43708 .66533 L .43977 .66802 L .925 .073 0 r
F
.44483 .66759 m .4423 .66503 L .43977 .66802 L .987 .163 0 r
F
.51836 .64244 m .52105 .64489 L .51786 .64475 L .546 .803 0 r
F
.51836 .64244 m .52162 .64256 L .52105 .64489 L F
.42679 .92776 m .42388 .92731 L .41051 .92616 L .116 0 0 r
F
.5097 .70051 m .51294 .7235 L .50889 .71903 L 1 .819 0 r
F
.5097 .70051 m .51383 .70457 L .51294 .7235 L F
.33762 .90393 m .31898 .89801 L .32504 .90025 L .296 0 0 r
F
.34317 .90586 m .33762 .90393 L .32504 .90025 L .268 0 0 r
F
.56411 .62715 m .56729 .62975 L .56447 .63118 L .891 .987 0 r
F
.56411 .62715 m .56691 .62555 L .56729 .62975 L F
.49799 .63363 m .50059 .6351 L .49776 .63531 L .828 1 0 r
F
.49799 .63363 m .50083 .63323 L .50059 .6351 L F
.6295 .90182 m .62415 .9043 L .61812 .90643 L .286 .186 0 r
F
.6295 .90182 m .63603 .89951 L .62415 .9043 L F
.59092 .58097 m .59516 .58405 L .59315 .58614 L 1 1 0 r
F
.59092 .58097 m .59289 .57878 L .59516 .58405 L F
.7889 .76921 m .78698 .77578 L .78209 .78087 L .662 .22 0 r
F
.7889 .76921 m .79393 .76385 L .78698 .77578 L F
.42205 .75602 m .41009 .76499 L .41238 .77367 L .953 .357 0 r
F
.42415 .76407 m .42205 .75602 L .41238 .77367 L .951 .37 0 r
F
.76114 .5253 m .76681 .5338 L .76575 .53869 L 1 .399 0 r
F
.76114 .5253 m .76208 .52031 L .76681 .5338 L F
.45456 .6655 m .44983 .66673 L .45214 .67017 L .816 .074 0 r
F
.45665 .669 m .45456 .6655 L .45214 .67017 L .86 .193 0 r
F
.58135 .58415 m .58557 .58702 L .58353 .58897 L 1 1 0 r
F
.58135 .58415 m .58336 .5821 L .58557 .58702 L F
.67231 .88301 m .6676 .88604 L .66144 .88898 L .36 .195 0 r
F
.67231 .88301 m .67888 .87985 L .6676 .88604 L F
.51426 .68965 m .51813 .70881 L .51383 .70457 L 1 .765 0 r
F
.51426 .68965 m .51862 .69356 L .51813 .70881 L F
.44923 .64503 m .44539 .644 L .44816 .64514 L .322 0 0 r
F
.45189 .64613 m .44923 .64503 L .44816 .64514 L .485 0 0 r
F
.5322 .62578 m .53516 .62732 L .53239 .62821 L .732 .897 0 r
F
.5322 .62578 m .53497 .62478 L .53516 .62732 L F
.71797 .63932 m .7202 .64537 L .71704 .64929 L .841 .5 0 r
F
.71797 .63932 m .72113 .63521 L .7202 .64537 L F
.30122 .89059 m .28277 .88276 L .28901 .88567 L .337 0 0 r
F
.30707 .89317 m .30122 .89059 L .28901 .88567 L .31 0 0 r
F
.4866 .64325 m .48877 .64582 L .48595 .64507 L .955 1 0 r
F
.4866 .64325 m .48952 .64377 L .48877 .64582 L F
.579 .71331 m .58244 .72232 L .577 .72073 L .614 .808 0 r
F
.579 .71331 m .5847 .71495 L .58244 .72232 L F
.51507 .64213 m .51786 .64475 L .51466 .64447 L .534 .79 0 r
F
.51507 .64213 m .51836 .64244 L .51786 .64475 L F
.61253 .57424 m .61777 .57848 L .61594 .58101 L 1 1 0 r
F
.61253 .57424 m .61428 .57161 L .61777 .57848 L F
.37198 .73229 m .3608 .73233 L .36298 .73899 L 1 .519 0 r
F
.37421 .73843 m .37198 .73229 L .36298 .73899 L 1 .539 0 r
F
.3909 .74878 m .37874 .75208 L .38107 .75965 L 1 .507 0 r
F
.39318 .75583 m .3909 .74878 L .38107 .75965 L 1 .519 0 r
F
.49515 .63404 m .49776 .63531 L .49493 .63553 L .83 1 0 r
F
.49515 .63404 m .49799 .63363 L .49776 .63531 L F
.87951 .65217 m .87814 .66155 L .87511 .66825 L .741 .2 0 r
F
.87951 .65217 m .88262 .64524 L .87814 .66155 L F
.5889 .58314 m .59315 .58614 L .5911 .58821 L 1 1 0 r
F
.5889 .58314 m .59092 .58097 L .59315 .58614 L F
.5793 .58616 m .58353 .58897 L .58145 .59088 L F
.5793 .58616 m .58135 .58415 L .58353 .58897 L F
.56128 .62868 m .56447 .63118 L .56162 .63256 L .874 .98 0 r
F
.56128 .62868 m .56411 .62715 L .56447 .63118 L F
.50493 .92567 m .49454 .92692 L .49274 .92706 L .104 .158 0 r
F
.50493 .92567 m .50765 .92549 L .49454 .92692 L F
.49293 .64196 m .49539 .64449 L .49245 .64414 L .946 1 0 r
F
.49293 .64196 m .49592 .64203 L .49539 .64449 L F
.52941 .62672 m .53239 .62821 L .5296 .62902 L .713 .887 0 r
F
.52941 .62672 m .5322 .62578 L .53239 .62821 L F
.33572 .90994 m .31683 .9039 L .323 .90608 L .271 0 0 r
F
.34138 .91181 m .33572 .90994 L .323 .90608 L .24 0 0 r
F
.44983 .66673 m .44483 .66759 L .44734 .67104 L .911 .128 0 r
F
.45214 .67017 m .44983 .66673 L .44734 .67104 L .953 .251 0 r
F
.2527 .86655 m .23496 .85609 L .2411 .85989 L .393 0 0 r
F
.25668 .86892 m .2527 .86655 L .2411 .85989 L .368 0 0 r
F
.26449 .87336 m .2491 .86459 L .25362 .86716 L 0 .053 0 r
F
.25855 .87001 m .2411 .85989 L .24732 .86358 L .368 0 0 r
F
.2491 .86459 m .24732 .86358 L .24814 .86404 L 0 .053 0 r
F
.2491 .86459 m .24814 .86404 L .25362 .86716 L F
.25855 .87001 m .25774 .86953 L .25668 .86892 L .368 0 0 r
F
.25774 .86953 m .2527 .86655 L .25668 .86892 L F
.52811 .68967 m .53283 .70629 L .52792 .70201 L .815 .675 0 r
F
.52811 .68967 m .53319 .69412 L .53283 .70629 L F
.43438 .66314 m .42923 .6628 L .43203 .66516 L .873 .058 0 r
F
.43708 .66533 m .43438 .66314 L .43203 .66516 L .968 .075 0 r
F
.51178 .64162 m .51466 .64447 L .51146 .64406 L .535 .78 0 r
F
.51178 .64162 m .51507 .64213 L .51466 .64447 L F
.6449 .70435 m .64665 .70935 L .64198 .71113 L .659 .72 0 r
F
.6449 .70435 m .64967 .70236 L .64665 .70935 L F
.45565 .64684 m .45189 .64613 L .45455 .64763 L .576 .007 0 r
F
.45815 .64853 m .45565 .64684 L .45455 .64763 L .855 .057 0 r
F
.45928 .64731 m .45565 .64684 L .45815 .64853 L .698 .032 0 r
F
.46158 .64945 m .45928 .64731 L .45815 .64853 L .908 .076 0 r
F
.46263 .64766 m .45928 .64731 L .46158 .64945 L .741 .05 0 r
F
.46813 .6582 m .46732 .65569 L .46577 .66018 L .251 .01 0 r
F
.46926 .65328 m .46732 .65569 L .46813 .6582 L 0 0 0 r
F
.29871 .89664 m .27997 .88872 L .28635 .89158 L .315 0 0 r
F
.30358 .89872 m .29871 .89664 L .28635 .89158 L .287 0 0 r
F
.31072 .9016 m .29379 .89473 L .29933 .89696 L 0 .078 0 r
F
.30468 .89918 m .28635 .89158 L .2928 .89433 L .287 0 0 r
F
.29379 .89473 m .2928 .89433 L .29321 .89449 L 0 .078 0 r
F
.29379 .89473 m .29321 .89449 L .29933 .89696 L F
.30468 .89918 m .30427 .899 L .30358 .89872 L .287 0 0 r
F
.30427 .899 m .29871 .89664 L .30358 .89872 L F
.5266 .62759 m .5296 .62902 L .52678 .62977 L .692 .876 0 r
F
.5266 .62759 m .52941 .62672 L .5296 .62902 L F
.40784 .75717 m .39551 .7635 L .39789 .77184 L 1 .447 0 r
F
.41009 .76499 m .40784 .75717 L .39789 .77184 L 1 .458 0 r
F
.56921 .91353 m .56277 .91584 L .55774 .9168 L .256 .184 0 r
F
.56921 .91353 m .57492 .91246 L .56277 .91584 L F
.57722 .58815 m .58145 .59088 L .57933 .59277 L 1 1 0 r
F
.57722 .58815 m .5793 .58616 L .58145 .59088 L F
.58685 .58526 m .5911 .58821 L .58902 .59023 L F
.58685 .58526 m .5889 .58314 L .5911 .58821 L F
.58773 .89348 m .58284 .89735 L .57731 .89833 L .43 .265 0 r
F
.58773 .89348 m .59386 .89246 L .58284 .89735 L F
.50529 .93048 m .49477 .93139 L .49296 .93152 L .068 .151 0 r
F
.50529 .93048 m .50804 .93029 L .49477 .93139 L F
.4923 .63443 m .49493 .63553 L .4921 .63571 L .815 1 0 r
F
.4923 .63443 m .49515 .63404 L .49493 .63553 L F
.61073 .57684 m .61594 .58101 L .61407 .58351 L 1 1 0 r
F
.61073 .57684 m .61253 .57424 L .61594 .58101 L F
.36712 .91208 m .34879 .90768 L .35446 .90938 L .257 0 0 r
F
.3722 .91349 m .36712 .91208 L .35446 .90938 L .227 0 0 r
F
.55842 .63015 m .56162 .63256 L .55873 .63386 L .855 .972 0 r
F
.55842 .63015 m .56128 .62868 L .56162 .63256 L F
.43518 .75241 m .42415 .76407 L .42627 .77328 L .823 .247 0 r
F
.43705 .76084 m .43518 .75241 L .42627 .77328 L .823 .263 0 r
F
.50849 .64093 m .51146 .64406 L .50827 .64356 L .56 .781 0 r
F
.50849 .64093 m .51178 .64162 L .51146 .64406 L F
.86029 .65202 m .86183 .66207 L .85879 .66851 L .835 .214 0 r
F
.86029 .65202 m .86324 .64534 L .86183 .66207 L F
.53004 .90886 m .52239 .91214 L .51888 .91227 L .384 .213 0 r
F
.53004 .90886 m .53437 .90876 L .52239 .91214 L F
.52376 .62837 m .52678 .62977 L .52394 .63044 L .669 .863 0 r
F
.52376 .62837 m .5266 .62759 L .52678 .62977 L F
.48996 .64188 m .49245 .64414 L .48952 .64377 L .947 1 0 r
F
.48996 .64188 m .49293 .64196 L .49245 .64414 L F
.57511 .5901 m .57933 .59277 L .57718 .59461 L 1 1 0 r
F
.57511 .5901 m .57722 .58815 L .57933 .59277 L F
.5101 .68609 m .51383 .70457 L .5097 .70051 L 1 .773 0 r
F
.5101 .68609 m .51426 .68965 L .51383 .70457 L F
.91428 .48037 m .91678 .49384 L .91653 .50114 L .799 .159 0 r
F
.91428 .48037 m .91453 .47293 L .91678 .49384 L F
.79926 .77863 m .7963 .78449 L .79128 .78976 L .604 .212 0 r
F
.79926 .77863 m .80447 .77311 L .7963 .78449 L F
.24922 .87268 m .23115 .86214 L .23744 .86591 L .376 0 0 r
F
.25521 .87612 m .24922 .87268 L .23744 .86591 L 0 .052 0 r
F
.57324 .71125 m .577 .72073 L .5715 .71874 L .595 .765 0 r
F
.57324 .71125 m .579 .71331 L .577 .72073 L F
.52323 .68532 m .52792 .70201 L .52318 .69773 L .841 .677 0 r
F
.52323 .68532 m .52811 .68967 L .52792 .70201 L F
.39009 .91672 m .3722 .91349 L .37733 .91477 L .225 0 0 r
F
.39453 .91773 m .39009 .91672 L .37733 .91477 L .194 0 0 r
F
.58476 .58736 m .58902 .59023 L .5869 .59223 L 1 1 0 r
F
.58476 .58736 m .58685 .58526 L .58902 .59023 L F
.86239 .48698 m .89612 .5002 L .89534 .50714 L .777 .053 0 r
F
.86239 .48698 m .85526 .4804 L .89612 .5002 L F
.50523 .64019 m .50827 .64356 L .50511 .64303 L .624 .808 0 r
F
.50523 .64019 m .50849 .64093 L .50827 .64356 L F
.45189 .64613 m .44816 .64514 L .45093 .64656 L .485 0 0 r
F
.45455 .64763 m .45189 .64613 L .45093 .64656 L .686 .026 0 r
F
.48945 .63474 m .4921 .63571 L .48927 .63584 L .788 1 0 r
F
.48945 .63474 m .4923 .63443 L .4921 .63571 L F
.57059 .91965 m .56397 .92153 L .55888 .92255 L .201 .174 0 r
F
.57059 .91965 m .57637 .91849 L .56397 .92153 L F
.76009 .53029 m .76575 .53869 L .76459 .54357 L 1 .425 0 r
F
.76009 .53029 m .76114 .5253 L .76575 .53869 L F
.5209 .62906 m .52394 .63044 L .52109 .63103 L .643 .848 0 r
F
.5209 .62906 m .52376 .62837 L .52394 .63044 L F
.55552 .63155 m .55873 .63386 L .5558 .6351 L .835 .963 0 r
F
.55552 .63155 m .55842 .63015 L .55873 .63386 L F
.71473 .64338 m .71704 .64929 L .71379 .65314 L .841 .522 0 r
F
.71473 .64338 m .71797 .63932 L .71704 .64929 L F
.72301 .8457 m .71931 .84968 L .71339 .85355 L .47 .206 0 r
F
.72301 .8457 m .72923 .8416 L .71931 .84968 L F
.50383 .73815 m .50758 .74281 L .50534 .77157 L 1 .921 0 r
F
.50497 .71461 m .50758 .74281 L .50383 .73815 L 1 .865 0 r
F
.50497 .71461 m .50889 .71903 L .50758 .74281 L F
.60888 .57942 m .61407 .58351 L .61215 .58598 L 1 1 0 r
F
.60888 .57942 m .61073 .57684 L .61407 .58351 L F
.65709 .86813 m .65352 .87197 L .64744 .87444 L .444 .21 0 r
F
.65709 .86813 m .66356 .86547 L .65352 .87197 L F
.50572 .69669 m .50889 .71903 L .50497 .71461 L 1 .82 0 r
F
.50572 .69669 m .5097 .70051 L .50889 .71903 L F
.36566 .91811 m .3471 .91356 L .35288 .91519 L .228 0 0 r
F
.37083 .91945 m .36566 .91811 L .35288 .91519 L .195 0 0 r
F
.57296 .59201 m .57718 .59461 L .575 .59643 L 1 1 0 r
F
.57296 .59201 m .57511 .5901 L .57718 .59461 L F
.50206 .63962 m .50511 .64303 L .50199 .64255 L .734 .873 0 r
F
.50206 .63962 m .50523 .64019 L .50511 .64303 L F
.51801 .62964 m .52109 .63103 L .51821 .63153 L .616 .833 0 r
F
.51801 .62964 m .5209 .62906 L .52109 .63103 L F
.5452 .90482 m .53866 .90848 L .53437 .90876 L .428 .318 0 r
F
.5452 .90482 m .55024 .90457 L .53866 .90848 L F
.58263 .58942 m .5869 .59223 L .58474 .59419 L 1 1 0 r
F
.58263 .58942 m .58476 .58736 L .5869 .59223 L F
.44483 .66759 m .43977 .66802 L .44242 .67151 L .987 .163 0 r
F
.44734 .67104 m .44483 .66759 L .44242 .67151 L 1 .293 0 r
F
.48658 .63493 m .48945 .63474 L .48927 .63584 L .748 .98 0 r
F
.48698 .64165 m .48952 .64377 L .4866 .64325 L .92 1 0 r
F
.48698 .64165 m .48996 .64188 L .48952 .64377 L F
.55259 .63288 m .5558 .6351 L .55285 .63626 L .813 .951 0 r
F
.55259 .63288 m .55552 .63155 L .5558 .6351 L F
.38894 .92287 m .37083 .91945 L .37605 .92066 L .196 0 0 r
F
.39346 .9238 m .38894 .92287 L .37605 .92066 L .161 0 0 r
F
.51859 .68123 m .52318 .69773 L .51862 .69356 L .873 .687 0 r
F
.51859 .68123 m .52323 .68532 L .52318 .69773 L F
.5151 .63008 m .51821 .63153 L .51531 .63193 L .587 .817 0 r
F
.5151 .63008 m .51801 .62964 L .51821 .63153 L F
.57078 .59389 m .575 .59643 L .57278 .5982 L 1 1 0 r
F
.57078 .59389 m .57296 .59201 L .575 .59643 L F
.64004 .70617 m .64198 .71113 L .63723 .71273 L .647 .737 0 r
F
.64004 .70617 m .6449 .70435 L .64198 .71113 L F
.61593 .88451 m .61188 .88829 L .60593 .88985 L .426 .209 0 r
F
.61593 .88451 m .62238 .88283 L .61188 .88829 L F
.49899 .63942 m .50199 .64255 L .49893 .64221 L .856 .954 0 r
F
.49899 .63942 m .50206 .63962 L .50199 .64255 L F
.48072 .64104 m .48313 .64405 L .48031 .64257 L .881 .843 0 r
F
.48072 .64104 m .48366 .64242 L .48313 .64405 L F
.26597 .85643 m .24845 .84778 L .25443 .85142 L .457 0 0 r
F
.27165 .85977 m .26597 .85643 L .25443 .85142 L .437 0 0 r
F
.50383 .73815 m .50534 .77157 L .50193 .76748 L 1 .921 0 r
F
.60698 .58197 m .61215 .58598 L .61018 .58842 L 1 1 0 r
F
.60698 .58197 m .60888 .57942 L .61215 .58598 L F
.51216 .63036 m .51531 .63193 L .5124 .63224 L .558 .803 0 r
F
.51216 .63036 m .5151 .63008 L .51531 .63193 L F
.31306 .87815 m .2951 .87216 L .30114 .87502 L .431 0 0 r
F
.31869 .88074 m .31306 .87815 L .30114 .87502 L .411 0 0 r
F
.58047 .59145 m .58474 .59419 L .58255 .59611 L 1 1 0 r
F
.58047 .59145 m .58263 .58942 L .58474 .59419 L F
.56744 .70873 m .5715 .71874 L .56596 .71633 L .577 .72 0 r
F
.56744 .70873 m .57324 .71125 L .5715 .71874 L F
.43708 .66533 m .43203 .66516 L .43482 .66799 L .968 .075 0 r
F
.43977 .66802 m .43708 .66533 L .43482 .66799 L 1 .17 0 r
F
.59164 .90739 m .5862 .9099 L .58059 .91125 L .291 .189 0 r
F
.59164 .90739 m .59785 .9059 L .5862 .9099 L F
.53176 .92143 m .5237 .92329 L .52013 .92366 L .197 .174 0 r
F
.53176 .92143 m .53617 .92099 L .5237 .92329 L F
.78376 .77449 m .78209 .78087 L .77708 .78589 L .662 .222 0 r
F
.78376 .77449 m .7889 .76921 L .78209 .78087 L F
.56857 .59574 m .57278 .5982 L .57054 .59995 L 1 1 0 r
F
.56857 .59574 m .57078 .59389 L .57278 .5982 L F
.50919 .63043 m .5124 .63224 L .50948 .63247 L .544 .8 0 r
F
.50919 .63043 m .51216 .63036 L .5124 .63224 L F
.50614 .68294 m .5097 .70051 L .50572 .69669 L 1 .785 0 r
F
.50614 .68294 m .5101 .68609 L .5097 .70051 L F
.54962 .63413 m .55285 .63626 L .54986 .63734 L .789 .938 0 r
F
.54962 .63413 m .55259 .63288 L .55285 .63626 L F
.496 .63956 m .49893 .64221 L .49592 .64203 L .938 1 0 r
F
.496 .63956 m .49899 .63942 L .49893 .64221 L F
.34807 .88964 m .33014 .88562 L .33597 .88792 L .418 0 0 r
F
.35338 .89169 m .34807 .88964 L .33597 .88792 L .398 0 0 r
F
.46692 .66517 m .46577 .66018 L .46416 .66622 L .464 .055 0 r
F
.46813 .6582 m .46577 .66018 L .46692 .66517 L .251 .01 0 r
F
.50622 .63041 m .50948 .63247 L .50658 .63266 L .594 .846 0 r
F
.50622 .63041 m .50919 .63043 L .50948 .63247 L F
.45815 .64853 m .45455 .64763 L .4572 .64992 L .855 .057 0 r
F
.46063 .65156 m .45815 .64853 L .4572 .64992 L 1 .227 0 r
F
.46158 .64945 m .45815 .64853 L .46063 .65156 L .908 .076 0 r
F
.51421 .67756 m .51862 .69356 L .51426 .68965 L .912 .706 0 r
F
.51421 .67756 m .51859 .68123 L .51862 .69356 L F
.57828 .59345 m .58255 .59611 L .58032 .598 L 1 1 0 r
F
.57828 .59345 m .58047 .59145 L .58255 .59611 L F
.87625 .65906 m .87511 .66825 L .87194 .67489 L .746 .203 0 r
F
.87625 .65906 m .87951 .65217 L .87511 .66825 L F
.4143 .89841 m .39788 .89867 L .40209 .90004 L .363 0 0 r
F
.41777 .89961 m .4143 .89841 L .40209 .90004 L .347 0 0 r
F
.42989 .89676 m .4143 .89841 L .41777 .89961 L .312 0 0 r
F
.50333 .63065 m .50658 .63266 L .50369 .6329 L .764 .98 0 r
F
.50333 .63065 m .50622 .63041 L .50658 .63266 L F
.56633 .59755 m .57054 .59995 L .56825 .60165 L 1 1 0 r
F
.56633 .59755 m .56857 .59574 L .57054 .59995 L F
.60503 .58449 m .61018 .58842 L .60816 .59082 L F
.60503 .58449 m .60698 .58197 L .61018 .58842 L F
.43255 .89784 m .42989 .89676 L .41777 .89961 L .295 0 0 r
F
.71139 .64737 m .71379 .65314 L .71045 .65693 L .84 .542 0 r
F
.71139 .64737 m .71473 .64338 L .71379 .65314 L F
.49304 .63987 m .49592 .64203 L .49293 .64196 L .967 1 0 r
F
.49304 .63987 m .496 .63956 L .49592 .64203 L F
.53252 .92698 m .52431 .92842 L .52069 .92881 L .141 .165 0 r
F
.53252 .92698 m .53697 .92649 L .52431 .92842 L F
.54662 .63531 m .54986 .63734 L .54684 .63835 L .763 .922 0 r
F
.54662 .63531 m .54962 .63413 L .54986 .63734 L F
.45455 .64763 m .45093 .64656 L .45369 .6485 L .686 .026 0 r
F
.4572 .64992 m .45455 .64763 L .45369 .6485 L .977 .076 0 r
F
.50053 .63123 m .50369 .6329 L .50083 .63323 L .887 1 0 r
F
.50053 .63123 m .50333 .63065 L .50369 .6329 L F
.75894 .53527 m .76459 .54357 L .76334 .54843 L 1 .45 0 r
F
.75894 .53527 m .76009 .53029 L .76459 .54357 L F
.5934 .91363 m .58776 .91575 L .58209 .91718 L .245 .181 0 r
F
.5934 .91363 m .59967 .91203 L .58776 .91575 L F
.66296 .8804 m .65888 .88347 L .6527 .88621 L .379 .199 0 r
F
.66296 .8804 m .66955 .87747 L .65888 .88347 L F
.45665 .669 m .45214 .67017 L .45441 .67551 L .86 .193 0 r
F
.57605 .5954 m .58032 .598 L .57806 .59985 L 1 1 0 r
F
.57605 .5954 m .57828 .59345 L .58032 .598 L F
.54754 .9183 m .54053 .92041 L .53617 .92099 L .236 .181 0 r
F
.54754 .9183 m .55266 .91762 L .54053 .92041 L F
.46383 .65427 m .46158 .64945 L .46063 .65156 L 1 .36 0 r
F
.49774 .63191 m .50083 .63323 L .49799 .63363 L .903 1 0 r
F
.49774 .63191 m .50053 .63123 L .50083 .63323 L F
.56406 .59933 m .56825 .60165 L .56594 .60332 L 1 1 0 r
F
.56406 .59933 m .56633 .59755 L .56825 .60165 L F
.56161 .70575 m .56596 .71633 L .5604 .71352 L .562 .676 0 r
F
.56161 .70575 m .56744 .70873 L .56596 .71633 L F
.37421 .73843 m .36298 .73899 L .36519 .74606 L 1 .539 0 r
F
.37646 .74502 m .37421 .73843 L .36519 .74606 L 1 .555 0 r
F
.48096 .63971 m .48366 .64242 L .48072 .64104 L .76 .783 0 r
F
.48096 .63971 m .48398 .64103 L .48366 .64242 L F
.50118 .71025 m .50497 .71461 L .50383 .73815 L 1 .86 0 r
F
.5019 .69312 m .50497 .71461 L .50118 .71025 L 1 .822 0 r
F
.5019 .69312 m .50572 .69669 L .50497 .71461 L F
.51008 .67446 m .51426 .68965 L .5101 .68609 L .954 .73 0 r
F
.51008 .67446 m .51421 .67756 L .51426 .68965 L F
.45214 .67017 m .44734 .67104 L .44979 .67603 L .953 .251 0 r
F
.45441 .67551 m .45214 .67017 L .44979 .67603 L .985 .36 0 r
F
.8572 .65867 m .85879 .66851 L .85564 .67491 L .835 .216 0 r
F
.8572 .65867 m .86029 .65202 L .85879 .66851 L F
.54359 .6364 m .54684 .63835 L .54378 .63926 L .734 .903 0 r
F
.54359 .6364 m .54662 .63531 L .54684 .63835 L F
.49495 .63258 m .49799 .63363 L .49515 .63404 L .878 1 0 r
F
.49495 .63258 m .49774 .63191 L .49799 .63363 L F
.49008 .64016 m .49293 .64196 L .48996 .64188 L .953 1 0 r
F
.49008 .64016 m .49304 .63987 L .49293 .64196 L F
.63509 .70779 m .63723 .71273 L .63237 .71414 L .632 .751 0 r
F
.63509 .70779 m .64004 .70617 L .63723 .71273 L F
.60303 .58698 m .60816 .59082 L .60609 .5932 L 1 1 0 r
F
.60303 .58698 m .60503 .58449 L .60816 .59082 L F
.56176 .60106 m .56594 .60332 L .5636 .60494 L F
.56176 .60106 m .56406 .59933 L .56594 .60332 L F
.57379 .59732 m .57806 .59985 L .57576 .60166 L F
.57379 .59732 m .57605 .5954 L .57806 .59985 L F
.62072 .8979 m .61612 .90061 L .61009 .90251 L .327 .194 0 r
F
.62072 .8979 m .62725 .89583 L .61612 .90061 L F
.49214 .6332 m .49515 .63404 L .4923 .63443 L .841 1 0 r
F
.49214 .6332 m .49495 .63258 L .49515 .63404 L F
.50235 .68021 m .50572 .69669 L .5019 .69312 L 1 .795 0 r
F
.50235 .68021 m .50614 .68294 L .50572 .69669 L F
.86728 .49376 m .89534 .50714 L .8946 .51408 L .961 .091 0 r
F
.86728 .49376 m .86239 .48698 L .89534 .50714 L F
.47797 .63785 m .48096 .63971 L .48072 .64104 L .753 .691 0 r
F
.66566 .88604 m .66144 .88898 L .65519 .89179 L .366 .197 0 r
F
.66566 .88604 m .67231 .88301 L .66144 .88898 L F
.91389 .48783 m .91653 .50114 L .91614 .50844 L .81 .163 0 r
F
.91389 .48783 m .91428 .48037 L .91653 .50114 L F
.54856 .92419 m .54139 .92585 L .53697 .92649 L .177 .171 0 r
F
.54856 .92419 m .55374 .92344 L .54139 .92585 L F
.54052 .63739 m .54378 .63926 L .5407 .64008 L .703 .88 0 r
F
.54052 .63739 m .54359 .6364 L .54378 .63926 L F
.44667 .74654 m .43705 .76084 L .43894 .77087 L .663 .113 0 r
F
.44826 .75556 m .44667 .74654 L .43894 .77087 L .668 .134 0 r
F
.55943 .60276 m .5636 .60494 L .56123 .60653 L 1 1 0 r
F
.55943 .60276 m .56176 .60106 L .5636 .60494 L F
.48931 .63372 m .4923 .63443 L .48945 .63474 L .797 1 0 r
F
.48931 .63372 m .49214 .6332 L .4923 .63443 L F
.4871 .64027 m .48996 .64188 L .48698 .64165 L .901 1 0 r
F
.4871 .64027 m .49008 .64016 L .48996 .64188 L F
.79393 .78406 m .79128 .78976 L .78615 .79495 L .606 .214 0 r
F
.79393 .78406 m .79926 .77863 L .79128 .78976 L F
.5715 .59921 m .57576 .60166 L .57343 .60344 L 1 1 0 r
F
.5715 .59921 m .57379 .59732 L .57576 .60166 L F
.55578 .70231 m .5604 .71352 L .55484 .71029 L .552 .634 0 r
F
.55578 .70231 m .56161 .70575 L .5604 .71352 L F
.50016 .73333 m .50383 .73815 L .50193 .76748 L 1 .91 0 r
F
.50118 .71025 m .50383 .73815 L .50016 .73333 L 1 .86 0 r
F
.26449 .87336 m .25855 .87001 L .24732 .86358 L 0 .053 0 r
F
.51652 .92389 m .50765 .92549 L .50493 .92567 L .166 .169 0 r
F
.51652 .92389 m .52013 .92366 L .50765 .92549 L F
.39318 .75583 m .38107 .75965 L .38348 .76777 L 1 .519 0 r
F
.39551 .7635 m .39318 .75583 L .38348 .76777 L 1 .529 0 r
F
.50618 .67197 m .5101 .68609 L .50614 .68294 L .995 .756 0 r
F
.50618 .67197 m .51008 .67446 L .5101 .68609 L F
.48647 .63411 m .48945 .63474 L .48658 .63493 L .738 .974 0 r
F
.48647 .63411 m .48931 .63372 L .48945 .63474 L F
.60099 .58944 m .60609 .5932 L .60397 .59553 L 1 1 0 r
F
.60099 .58944 m .60303 .58698 L .60609 .5932 L F
.3762 .89603 m .35876 .89365 L .36419 .89552 L .402 0 0 r
F
.38103 .89768 m .3762 .89603 L .36419 .89552 L .385 0 0 r
F
.55707 .60442 m .56123 .60653 L .55883 .60808 L .998 1 0 r
F
.55707 .60442 m .55943 .60276 L .56123 .60653 L F
.30707 .89317 m .28901 .88567 L .29533 .88847 L .31 0 0 r
F
.313 .89565 m .30707 .89317 L .29533 .88847 L .283 0 0 r
F
.53743 .63828 m .5407 .64008 L .53759 .64081 L .668 .854 0 r
F
.53743 .63828 m .54052 .63739 L .5407 .64008 L F
.43977 .66802 m .43482 .66799 L .43757 .67152 L 1 .17 0 r
F
.44242 .67151 m .43977 .66802 L .43757 .67152 L 1 .31 0 r
F
.56917 .60105 m .57343 .60344 L .57107 .60517 L 1 1 0 r
F
.56917 .60105 m .5715 .59921 L .57343 .60344 L F
.62291 .90401 m .61812 .90643 L .61204 .90843 L .297 .189 0 r
F
.62291 .90401 m .6295 .90182 L .61812 .90643 L F
.70796 .65129 m .71045 .65693 L .70702 .66064 L .838 .562 0 r
F
.70796 .65129 m .71139 .64737 L .71045 .65693 L F
.44734 .67104 m .44242 .67151 L .44501 .67629 L 1 .293 0 r
F
.44979 .67603 m .44734 .67104 L .44501 .67629 L 1 .406 0 r
F
.47801 .63656 m .48096 .63971 L .47797 .63785 L .536 .541 0 r
F
.51705 .92907 m .50804 .93029 L .50529 .93048 L .117 .16 0 r
F
.51705 .92907 m .52069 .92881 L .50804 .93029 L F
.54997 .69843 m .55484 .71029 L .5493 .70668 L .547 .597 0 r
F
.54997 .69843 m .55578 .70231 L .55484 .71029 L F
.53431 .63907 m .53759 .64081 L .53445 .64142 L .629 .824 0 r
F
.53431 .63907 m .53743 .63828 L .53759 .64081 L F
.75768 .54023 m .76334 .54843 L .76198 .55327 L 1 .475 0 r
F
.75768 .54023 m .75894 .53527 L .76334 .54843 L F
.34317 .90586 m .32504 .90025 L .33116 .90238 L .268 0 0 r
F
.34879 .90768 m .34317 .90586 L .33116 .90238 L .239 0 0 r
F
.46891 .66575 m .46813 .6582 L .46692 .66517 L .335 .041 0 r
F
.48104 .63863 m .48398 .64103 L .48096 .63971 L .581 .686 0 r
F
.48104 .63863 m .48409 .63992 L .48398 .64103 L F
.47801 .63656 m .48104 .63863 L .48096 .63971 L .536 .541 0 r
F
.7167 .8497 m .72301 .8457 L .71339 .85355 L .473 .208 0 r
F
.56682 .60286 m .57107 .60517 L .56868 .60687 L 1 1 0 r
F
.56682 .60286 m .56917 .60105 L .57107 .60517 L F
.59889 .59186 m .60397 .59553 L .60181 .59783 L F
.59889 .59186 m .60099 .58944 L .60397 .59553 L F
.63005 .7092 m .63509 .70779 L .63237 .71414 L .614 .759 0 r
F
.42415 .76407 m .41238 .77367 L .41474 .78327 L .951 .37 0 r
F
.42627 .77328 m .42415 .76407 L .41474 .78327 L .949 .381 0 r
F
.4572 .64992 m .45369 .6485 L .45643 .65149 L .977 .076 0 r
F
.4598 .65407 m .4572 .64992 L .45643 .65149 L 1 .364 0 r
F
.46063 .65156 m .4572 .64992 L .4598 .65407 L 1 .227 0 r
F
.25521 .87612 m .23744 .86591 L .24381 .86956 L 0 .052 0 r
F
.26128 .87944 m .25521 .87612 L .24381 .86956 L 0 .058 0 r
F
.50248 .67006 m .50614 .68294 L .50235 .68021 L 1 .781 0 r
F
.50248 .67006 m .50618 .67197 L .50614 .68294 L F
.49821 .68976 m .5019 .69312 L .50118 .71025 L 1 .822 0 r
F
.49869 .6778 m .5019 .69312 L .49821 .68976 L 1 .802 0 r
F
.49869 .6778 m .50235 .68021 L .5019 .69312 L F
.53115 .63973 m .53445 .64142 L .53128 .64191 L .587 .788 0 r
F
.53115 .63973 m .53431 .63907 L .53445 .64142 L F
.39788 .89867 m .38103 .89768 L .38592 .89924 L .385 0 0 r
F
.40209 .90004 m .39788 .89867 L .38592 .89924 L .369 0 0 r
F
.56041 .90013 m .55524 .90414 L .55024 .90457 L .466 .422 0 r
F
.56041 .90013 m .56609 .89973 L .55524 .90414 L F
.31072 .9016 m .30468 .89918 L .2928 .89433 L 0 .078 0 r
F
.4975 .70594 m .50118 .71025 L .50016 .73333 L 1 .854 0 r
F
.49821 .68976 m .50118 .71025 L .4975 .70594 L 1 .822 0 r
F
.7785 .77968 m .77708 .78589 L .77198 .79081 L .662 .223 0 r
F
.7785 .77968 m .78376 .77449 L .77708 .78589 L F
.46692 .66517 m .46416 .66622 L .46559 .67563 L .464 .055 0 r
F
.56443 .60463 m .56868 .60687 L .56625 .60852 L 1 1 0 r
F
.56443 .60463 m .56682 .60286 L .56868 .60687 L F
.54422 .69416 m .5493 .70668 L .54383 .70274 L .549 .566 0 r
F
.54422 .69416 m .54997 .69843 L .5493 .70668 L F
.46303 .65861 m .46063 .65156 L .4598 .65407 L 1 .504 0 r
F
.46383 .65427 m .46063 .65156 L .46303 .65861 L 1 .36 0 r
F
.47792 .63517 m .48104 .63863 L .47801 .63656 L .14 .091 0 r
F
.87287 .6659 m .87194 .67489 L .86865 .68149 L .75 .206 0 r
F
.87287 .6659 m .87625 .65906 L .87194 .67489 L F
.52797 .64026 m .53128 .64191 L .52809 .64228 L .541 .747 0 r
F
.52797 .64026 m .53115 .63973 L .53128 .64191 L F
.41009 .76499 m .39789 .77184 L .40036 .78087 L 1 .458 0 r
F
.41238 .77367 m .41009 .76499 L .40036 .78087 L 1 .466 0 r
F
.65054 .87065 m .64744 .87444 L .64128 .87677 L .452 .212 0 r
F
.65054 .87065 m .65709 .86813 L .64744 .87444 L F
.59675 .59425 m .60181 .59783 L .59959 .6001 L 1 1 0 r
F
.59675 .59425 m .59889 .59186 L .60181 .59783 L F
.34138 .91181 m .323 .90608 L .32924 .90814 L .24 0 0 r
F
.3471 .91356 m .34138 .91181 L .32924 .90814 L .209 0 0 r
F
.50149 .63621 m .50523 .64019 L .50206 .63962 L .546 .678 0 r
F
.49851 .63636 m .50206 .63962 L .49899 .63942 L .907 .943 0 r
F
.49851 .63636 m .50149 .63621 L .50206 .63962 L F
.56202 .60636 m .56625 .60852 L .5638 .61014 L .991 1 0 r
F
.56202 .60636 m .56443 .60463 L .56625 .60852 L F
.49564 .6371 m .49899 .63942 L .496 .63956 L 1 1 0 r
F
.49564 .6371 m .49851 .63636 L .49899 .63942 L F
.53858 .68957 m .54383 .70274 L .53844 .69852 L .56 .545 0 r
F
.53858 .68957 m .54422 .69416 L .54383 .70274 L F
.52475 .64062 m .52809 .64228 L .52487 .6425 L .507 .7 0 r
F
.52475 .64062 m .52797 .64026 L .52809 .64228 L F
.41137 .91984 m .39453 .91773 L .39902 .91862 L .175 0 0 r
F
.41509 .92047 m .41137 .91984 L .39902 .91862 L .143 0 0 r
F
.42745 .92115 m .41137 .91984 L .41509 .92047 L .139 0 0 r
F
.50474 .63729 m .50849 .64093 L .50523 .64019 L .324 .441 0 r
F
.50149 .63621 m .50474 .63729 L .50523 .64019 L .546 .678 0 r
F
.27165 .85977 m .25443 .85142 L .26049 .85496 L .437 0 0 r
F
.2774 .86301 m .27165 .85977 L .26049 .85496 L .417 0 0 r
F
.49278 .63792 m .496 .63956 L .49304 .63987 L 1 1 0 r
F
.49278 .63792 m .49564 .6371 L .496 .63956 L F
.5215 .64081 m .52487 .6425 L .52162 .64256 L .468 .646 0 r
F
.5215 .64081 m .52475 .64062 L .52487 .6425 L F
.50016 .73333 m .50193 .76748 L .49856 .76303 L 1 .91 0 r
F
.50815 .63875 m .51178 .64162 L .50849 .64093 L .299 .421 0 r
F
.5053 .63783 m .50815 .63875 L .50849 .64093 L .324 .441 0 r
F
.50815 .63875 m .51155 .63982 L .51178 .64162 L .299 .421 0 r
F
.50766 .6387 m .51098 .63966 L .50815 .63875 L .199 0 0 r
F
.51098 .63966 m .51155 .63982 L .50815 .63875 L F
.50474 .63729 m .50815 .63875 L .5053 .63783 L .324 .441 0 r
F
.53309 .68476 m .53844 .69852 L .53319 .69412 L .582 .534 0 r
F
.53309 .68476 m .53858 .68957 L .53844 .69852 L F
.46746 .92866 m .46735 .92865 L .45455 .92884 L 0 0 0 r
F
.47929 .92805 m .48015 .92805 L .46735 .92865 L .045 .147 0 r
F
.47929 .92805 m .46735 .92865 L .46746 .92866 L F
.47792 .63517 m .48096 .63792 L .48104 .63863 L .14 .091 0 r
F
.4777 .63365 m .48096 .63792 L .47792 .63517 L .788 .075 0 r
F
.49891 .66859 m .50235 .68021 L .49869 .6778 L 1 .799 0 r
F
.49891 .66859 m .50248 .67006 L .50235 .68021 L F
.55957 .60804 m .5638 .61014 L .56131 .61171 L .978 1 0 r
F
.55957 .60804 m .56202 .60636 L .5638 .61014 L F
.85398 .66527 m .85564 .67491 L .85236 .68126 L .834 .218 0 r
F
.85398 .66527 m .8572 .65867 L .85564 .67491 L F
.51822 .64077 m .52162 .64256 L .51836 .64244 L .424 .587 0 r
F
.51822 .64077 m .5215 .64081 L .52162 .64256 L F
.48096 .63792 m .48409 .63992 L .48104 .63863 L .366 .512 0 r
F
.51155 .63982 m .51507 .64213 L .51178 .64162 L .331 .466 0 r
F
.5278 .67991 m .53319 .69412 L .52811 .68967 L .616 .536 0 r
F
.5278 .67991 m .53309 .68476 L .53319 .69412 L F
.48988 .63863 m .49304 .63987 L .49008 .64016 L .978 1 0 r
F
.48988 .63863 m .49278 .63792 L .49304 .63987 L F
.70444 .65513 m .70702 .66064 L .7035 .66427 L .835 .581 0 r
F
.70444 .65513 m .70796 .65129 L .70702 .66064 L F
.52276 .67522 m .52811 .68967 L .52323 .68532 L .663 .552 0 r
F
.52276 .67522 m .5278 .67991 L .52811 .68967 L F
.51491 .64047 m .51836 .64244 L .51507 .64213 L .377 .525 0 r
F
.51491 .64047 m .51822 .64077 L .51836 .64244 L F
.51803 .67094 m .52323 .68532 L .51859 .68123 L .725 .583 0 r
F
.51803 .67094 m .52276 .67522 L .52323 .68532 L F
.51155 .63982 m .51491 .64047 L .51507 .64213 L .331 .466 0 r
F
.58154 .89429 m .57731 .89833 L .57173 .89912 L .462 .381 0 r
F
.58154 .89429 m .58773 .89348 L .57731 .89833 L F
.51363 .66732 m .51859 .68123 L .51421 .67756 L .798 .628 0 r
F
.51363 .66732 m .51803 .67094 L .51859 .68123 L F
.59456 .5966 m .59959 .6001 L .59734 .60232 L 1 1 0 r
F
.59456 .5966 m .59675 .59425 L .59959 .6001 L F
.50957 .66456 m .51421 .67756 L .51008 .67446 L .876 .682 0 r
F
.50957 .66456 m .51363 .66732 L .51421 .67756 L F
.43034 .92154 m .42745 .92115 L .41509 .92047 L .106 0 0 r
F
.48696 .63911 m .49008 .64016 L .4871 .64027 L .9 1 0 r
F
.48696 .63911 m .48988 .63863 L .49008 .64016 L F
.87071 .50065 m .8946 .51408 L .89385 .52103 L 1 .134 0 r
F
.87071 .50065 m .86728 .49376 L .8946 .51408 L F
.48096 .63792 m .48399 .6391 L .48409 .63992 L .366 .512 0 r
F
.49462 .68645 m .49821 .68976 L .4975 .70594 L 1 .817 0 r
F
.49513 .67554 m .49821 .68976 L .49462 .68645 L 1 .802 0 r
F
.49513 .67554 m .49869 .6778 L .49821 .68976 L F
.4777 .63365 m .48075 .63799 L .48096 .63792 L .788 .075 0 r
F
.47936 .93219 m .46731 .93252 L .46743 .9325 L .028 .144 0 r
F
.47936 .93219 m .48023 .93221 L .46731 .93252 L F
.75633 .54518 m .76198 .55327 L .76053 .5581 L 1 .5 0 r
F
.75633 .54518 m .75768 .54023 L .76198 .55327 L F
.4861 .63338 m .48931 .63372 L .48647 .63411 L .74 .976 0 r
F
.5058 .66273 m .51008 .67446 L .50618 .67197 L .949 .736 0 r
F
.5058 .66273 m .50957 .66456 L .51008 .67446 L F
.41051 .92616 m .39346 .9238 L .39803 .92461 L .146 0 0 r
F
.4143 .92671 m .41051 .92616 L .39803 .92461 L .11 0 0 r
F
.42679 .92776 m .41051 .92616 L .4143 .92671 L .116 0 0 r
F
.5546 .61128 m .5588 .61323 L .55625 .61471 L .952 1 0 r
F
.5546 .61128 m .5571 .60968 L .5588 .61323 L F
.91336 .49529 m .91614 .50844 L .91561 .51574 L .819 .168 0 r
F
.91336 .49529 m .91389 .48783 L .91614 .50844 L F
.48886 .63279 m .49214 .6332 L .48931 .63372 L .807 1 0 r
F
.4861 .63338 m .48886 .63279 L .48931 .63372 L .74 .976 0 r
F
.49658 .72832 m .50016 .73333 L .49856 .76303 L 1 .899 0 r
F
.4975 .70594 m .50016 .73333 L .49658 .72832 L 1 .854 0 r
F
.31869 .88074 m .30114 .87502 L .30725 .87779 L .411 0 0 r
F
.32438 .88323 m .31869 .88074 L .30725 .87779 L .391 0 0 r
F
.43705 .76084 m .42627 .77328 L .42845 .78378 L .823 .263 0 r
F
.43894 .77087 m .43705 .76084 L .42845 .78378 L .824 .278 0 r
F
.59233 .59892 m .59734 .60232 L .59504 .60451 L 1 1 0 r
F
.59233 .59892 m .59456 .5966 L .59734 .60232 L F
.49161 .63206 m .49495 .63258 L .49214 .6332 L .859 1 0 r
F
.48886 .63279 m .49161 .63206 L .49214 .6332 L .807 1 0 r
F
.3722 .91349 m .35446 .90938 L .3602 .91096 L .227 0 0 r
F
.37733 .91477 m .3722 .91349 L .3602 .91096 L .197 0 0 r
F
.60942 .886 m .60593 .88985 L .59993 .89125 L .446 .255 0 r
F
.60942 .886 m .61593 .88451 L .60593 .88985 L F
.37646 .74502 m .36519 .74606 L .36747 .75357 L 1 .555 0 r
F
.37874 .75208 m .37646 .74502 L .36747 .75357 L 1 .569 0 r
F
.49112 .93153 m .48023 .93221 L .47936 .93219 L .062 .15 0 r
F
.49112 .93153 m .49296 .93152 L .48023 .93221 L F
.49434 .63123 m .49774 .63191 L .49495 .63258 L .911 1 0 r
F
.49161 .63206 m .49434 .63123 L .49495 .63258 L .859 1 0 r
F
.50224 .66169 m .50618 .67197 L .50248 .67006 L 1 .783 0 r
F
.50224 .66169 m .5058 .66273 L .50618 .67197 L F
.55208 .61284 m .55625 .61471 L .55368 .61615 L .938 1 0 r
F
.55208 .61284 m .5546 .61128 L .55625 .61471 L F
.49543 .66732 m .49869 .6778 L .49513 .67554 L 1 .804 0 r
F
.49543 .66732 m .49891 .66859 L .49869 .6778 L F
.49704 .63029 m .50053 .63123 L .49774 .63191 L .976 1 0 r
F
.49434 .63123 m .49704 .63029 L .49774 .63191 L .911 1 0 r
F
.56344 .91445 m .55774 .9168 L .55266 .91762 L .283 .188 0 r
F
.56344 .91445 m .56921 .91353 L .55774 .9168 L F
.44242 .67151 m .43757 .67152 L .44026 .67618 L 1 .31 0 r
F
.44501 .67629 m .44242 .67151 L .44026 .67618 L 1 .435 0 r
F
.49971 .62923 m .50333 .63065 L .50053 .63123 L 1 1 0 r
F
.49704 .63029 m .49971 .62923 L .50053 .63123 L .976 1 0 r
F
.49393 .70155 m .4975 .70594 L .49658 .72832 L 1 .846 0 r
F
.49462 .68645 m .4975 .70594 L .49393 .70155 L 1 .817 0 r
F
.78849 .78941 m .78615 .79495 L .78092 .80004 L .608 .215 0 r
F
.78849 .78941 m .79393 .78406 L .78615 .79495 L F
.50232 .62794 m .50622 .63041 L .50333 .63065 L .778 .946 0 r
F
.49971 .62923 m .50232 .62794 L .50333 .63065 L 1 1 0 r
F
.54953 .61435 m .55368 .61615 L .55109 .61753 L .923 1 0 r
F
.54953 .61435 m .55208 .61284 L .55368 .61615 L F
.6563 .8832 m .6527 .88621 L .64644 .88881 L .387 .201 0 r
F
.6563 .8832 m .66296 .8804 L .6527 .88621 L F
.50514 .62771 m .50919 .63043 L .50622 .63041 L 0 .105 0 r
F
.50232 .62794 m .50514 .62771 L .50622 .63041 L .778 .946 0 r
F
.48075 .63799 m .48399 .6391 L .48096 .63792 L .239 .296 0 r
F
.59006 .6012 m .59504 .60451 L .59269 .60666 L 1 1 0 r
F
.59006 .6012 m .59233 .59892 L .59504 .60451 L F
.45441 .67551 m .44979 .67603 L .45212 .68403 L .985 .36 0 r
F
.45654 .68491 m .45441 .67551 L .45212 .68403 L 1 .451 0 r
F
.45868 .67492 m .45441 .67551 L .45654 .68491 L .895 .302 0 r
F
.54695 .61581 m .55109 .61753 L .54846 .61887 L .907 1 0 r
F
.54695 .61581 m .54953 .61435 L .55109 .61753 L F
.49882 .66119 m .50248 .67006 L .49891 .66859 L 1 .815 0 r
F
.49882 .66119 m .50224 .66169 L .50248 .67006 L F
.46796 .68176 m .46692 .66517 L .46559 .67563 L .583 .095 0 r
F
.46891 .66575 m .46692 .66517 L .46796 .68176 L .335 .041 0 r
F
.70083 .6589 m .7035 .66427 L .69989 .66782 L .832 .598 0 r
F
.70083 .6589 m .70444 .65513 L .7035 .66427 L F
.4598 .65407 m .45643 .65149 L .4591 .65704 L 1 .364 0 r
F
.37083 .91945 m .35288 .91519 L .35871 .9167 L .195 0 0 r
F
.37388 .92016 m .37083 .91945 L .35871 .9167 L .162 0 0 r
F
.39346 .9238 m .37605 .92066 L .38132 .92174 L .161 0 0 r
F
.38132 .92174 m .36646 .91848 L .37055 .91933 L 0 .11 0 r
F
.37605 .92066 m .35871 .9167 L .3646 .91807 L .162 0 0 r
F
.36646 .91848 m .3646 .91807 L .36545 .91825 L 0 .11 0 r
F
.36646 .91848 m .36545 .91825 L .37055 .91933 L F
.37605 .92066 m .37518 .92046 L .37388 .92016 L .162 0 0 r
F
.37518 .92046 m .37083 .91945 L .37388 .92016 L F
.54435 .61722 m .54846 .61887 L .54581 .62016 L .891 1 0 r
F
.54435 .61722 m .54695 .61581 L .54846 .61887 L F
.50844 .62927 m .51216 .63036 L .50919 .63043 L .372 .444 0 r
F
.50514 .62771 m .50844 .62927 L .50919 .63043 L 0 .105 0 r
F
.4911 .68293 m .49462 .68645 L .49393 .70155 L 1 .805 0 r
F
.49163 .67309 m .49462 .68645 L .4911 .68293 L 1 .789 0 r
F
.49163 .67309 m .49513 .67554 L .49462 .68645 L F
.46056 .68689 m .45868 .67492 L .45654 .68491 L .928 .395 0 r
F
.35338 .89169 m .33597 .88792 L .34185 .89013 L .398 0 0 r
F
.35876 .89365 m .35338 .89169 L .34185 .89013 L .379 0 0 r
F
.46225 .66429 m .4598 .65407 L .4591 .65704 L 1 .623 0 r
F
.46303 .65861 m .4598 .65407 L .46225 .66429 L 1 .504 0 r
F
.56476 .92068 m .55888 .92255 L .55374 .92344 L .222 .178 0 r
F
.56476 .92068 m .57059 .91965 L .55888 .92255 L F
.47831 .64605 m .48167 .65154 L .48153 .65516 L .757 .466 0 r
F
.47829 .64318 m .48167 .65154 L .47831 .64605 L .508 .28 0 r
F
.54173 .61859 m .54581 .62016 L .54314 .6214 L .873 1 0 r
F
.54173 .61859 m .54435 .61722 L .54581 .62016 L F
.39453 .91773 m .37733 .91477 L .38251 .91594 L .194 0 0 r
F
.39902 .91862 m .39453 .91773 L .38251 .91594 L .163 0 0 r
F
.49197 .66586 m .49513 .67554 L .49163 .67309 L 1 .791 0 r
F
.49197 .66586 m .49543 .66732 L .49513 .67554 L F
.58773 .60344 m .59269 .60666 L .5903 .60876 L 1 1 0 r
F
.58773 .60344 m .59006 .6012 L .59269 .60666 L F
.51139 .62919 m .5151 .63008 L .51216 .63036 L .478 .614 0 r
F
.50844 .62927 m .51139 .62919 L .51216 .63036 L .372 .444 0 r
F
.47787 .63767 m .48154 .64755 L .47814 .64035 L 1 .39 0 r
F
.2705 .8766 m .26449 .87336 L .25362 .86716 L 0 .059 0 r
F
.58538 .90872 m .58059 .91125 L .57492 .91246 L .313 .193 0 r
F
.58538 .90872 m .59164 .90739 L .58059 .91125 L F
.53908 .6199 m .54314 .6214 L .54044 .62258 L .854 1 0 r
F
.53908 .6199 m .54173 .61859 L .54314 .6214 L F
.47787 .63767 m .48138 .64873 L .48154 .64755 L 1 .39 0 r
F
.86936 .6727 m .86865 .68149 L .86523 .68804 L .754 .208 0 r
F
.86936 .6727 m .87287 .6659 L .86865 .68149 L F
.77315 .78477 m .77198 .79081 L .76677 .79565 L .662 .225 0 r
F
.77315 .78477 m .7785 .77968 L .77198 .79081 L F
.49545 .6609 m .49891 .66859 L .49543 .66732 L 1 .829 0 r
F
.49545 .6609 m .49882 .66119 L .49891 .66859 L F
.48075 .63799 m .48368 .63862 L .48399 .6391 L .239 .296 0 r
F
.65894 .88894 m .65519 .89179 L .64888 .89449 L .373 .198 0 r
F
.65894 .88894 m .66566 .88604 L .65519 .89179 L F
.44979 .67603 m .44501 .67629 L .44748 .68343 L 1 .406 0 r
F
.45212 .68403 m .44979 .67603 L .44748 .68343 L 1 .5 0 r
F
.53641 .62116 m .54044 .62258 L .53772 .62371 L .834 .995 0 r
F
.53641 .62116 m .53908 .6199 L .54044 .62258 L F
.51428 .62876 m .51801 .62964 L .5151 .63008 L .538 .719 0 r
F
.51139 .62919 m .51428 .62876 L .5151 .63008 L .478 .614 0 r
F
.75487 .55012 m .76053 .5581 L .75898 .5629 L 1 .524 0 r
F
.75487 .55012 m .75633 .54518 L .76053 .5581 L F
.52569 .9088 m .53004 .90886 L .51888 .91227 L .435 .346 0 r
F
.53372 .62237 m .53772 .62371 L .53497 .62478 L .812 .98 0 r
F
.53372 .62237 m .53641 .62116 L .53772 .62371 L F
.51712 .62814 m .5209 .62906 L .51801 .62964 L .596 .791 0 r
F
.51428 .62876 m .51712 .62814 L .51801 .62964 L .538 .719 0 r
F
.50218 .92571 m .49274 .92706 L .49093 .92707 L .144 .165 0 r
F
.50218 .92571 m .50493 .92567 L .49274 .92706 L F
.53101 .62351 m .53497 .62478 L .5322 .62578 L .787 .962 0 r
F
.53101 .62351 m .53372 .62237 L .53497 .62478 L F
.54011 .90487 m .53437 .90876 L .53004 .90886 L .475 .46 0 r
F
.54011 .90487 m .5452 .90482 L .53437 .90876 L F
.51994 .62739 m .52376 .62837 L .5209 .62906 L .649 .843 0 r
F
.51712 .62814 m .51994 .62739 L .5209 .62906 L .596 .791 0 r
F
.52827 .62459 m .5322 .62578 L .52941 .62672 L .76 .941 0 r
F
.52827 .62459 m .53101 .62351 L .5322 .62578 L F
.58537 .60564 m .5903 .60876 L .58786 .61082 L 1 1 0 r
F
.58537 .60564 m .58773 .60344 L .5903 .60876 L F
.48656 .63819 m .48988 .63863 L .48696 .63911 L .912 1 0 r
F
.52274 .62654 m .5266 .62759 L .52376 .62837 L .692 .883 0 r
F
.51994 .62739 m .52274 .62654 L .52376 .62837 L .649 .843 0 r
F
.52552 .6256 m .52941 .62672 L .5266 .62759 L .729 .915 0 r
F
.52552 .6256 m .52827 .62459 L .52941 .62672 L F
.52274 .62654 m .52552 .6256 L .5266 .62759 L .692 .883 0 r
F
.39551 .7635 m .38348 .76777 L .38597 .77643 L 1 .529 0 r
F
.39789 .77184 m .39551 .7635 L .38597 .77643 L 1 .536 0 r
F
.85063 .67183 m .85236 .68126 L .84896 .68756 L .833 .229 0 r
F
.85063 .67183 m .85398 .66527 L .85236 .68126 L F
.48938 .63733 m .49278 .63792 L .48988 .63863 L 1 1 0 r
F
.48656 .63819 m .48938 .63733 L .48988 .63863 L .912 1 0 r
F
.49393 .70155 m .49658 .72832 L .49308 .72302 L 1 .846 0 r
F
.49217 .63622 m .49564 .6371 L .49278 .63792 L 1 1 0 r
F
.48938 .63733 m .49217 .63622 L .49278 .63792 L F
.61412 .89982 m .61009 .90251 L .604 .90428 L .342 .197 0 r
F
.61412 .89982 m .62072 .8979 L .61009 .90251 L F
.4949 .6349 m .49851 .63636 L .49564 .6371 L 1 1 0 r
F
.49217 .63622 m .4949 .6349 L .49564 .6371 L F
.39803 .92461 m .39346 .9238 L .38132 .92174 L .127 0 0 r
F
.49755 .63328 m .50149 .63621 L .49851 .63636 L 1 .959 0 r
F
.4949 .6349 m .49755 .63328 L .49851 .63636 L 1 1 0 r
F
.49208 .66041 m .49543 .66732 L .49197 .66586 L 1 .817 0 r
F
.49208 .66041 m .49545 .6609 L .49543 .66732 L F
.58707 .9151 m .58209 .91718 L .57637 .91849 L .261 .184 0 r
F
.58707 .9151 m .5934 .91363 L .58209 .91718 L F
.61437 .71199 m .61728 .71702 L .61206 .71747 L .542 .751 0 r
F
.61437 .71199 m .61969 .71132 L .61728 .71702 L F
.26128 .87944 m .24381 .86956 L .25027 .87311 L 0 .058 0 r
F
.26744 .88264 m .26128 .87944 L .25027 .87311 L 0 .064 0 r
F
.48153 .65516 m .48468 .66576 L .48126 .66002 L .897 .589 0 r
F
.48153 .65516 m .48501 .6603 L .48468 .66576 L F
.48167 .65154 m .48501 .6603 L .48153 .65516 L .74 .488 0 r
F
.313 .89565 m .29533 .88847 L .30172 .89116 L .283 0 0 r
F
.31898 .89801 m .313 .89565 L .30172 .89116 L 0 .079 0 r
F
.87314 .50764 m .89385 .52103 L .89308 .52799 L 1 .239 0 r
F
.87314 .50764 m .87071 .50065 L .89385 .52103 L F
.58296 .60779 m .58786 .61082 L .58538 .61283 L 1 1 0 r
F
.58296 .60779 m .58537 .60564 L .58786 .61082 L F
.50252 .93052 m .49296 .93152 L .49112 .93153 L .104 .158 0 r
F
.50252 .93052 m .50529 .93048 L .49296 .93152 L F
.50003 .63089 m .50474 .63729 L .50149 .63621 L 0 0 0 r
F
.49755 .63328 m .50003 .63089 L .50149 .63621 L 1 .959 0 r
F
.50847 .65552 m .51363 .66732 L .50957 .66456 L .794 .623 0 r
F
.50492 .65448 m .50957 .66456 L .5058 .66273 L .933 .731 0 r
F
.50492 .65448 m .50847 .65552 L .50957 .66456 L F
.5016 .6545 m .5058 .66273 L .50224 .66169 L 1 .807 0 r
F
.5016 .6545 m .50492 .65448 L .5058 .66273 L F
.69714 .66259 m .69989 .66782 L .6962 .67129 L .827 .614 0 r
F
.69714 .66259 m .70083 .6589 L .69989 .66782 L F
.48167 .65154 m .48518 .65643 L .48501 .6603 L .74 .488 0 r
F
.49839 .65508 m .50224 .66169 L .49882 .66119 L 1 .854 0 r
F
.49839 .65508 m .5016 .6545 L .50224 .66169 L F
.51244 .65806 m .51803 .67094 L .51363 .66732 L .623 .495 0 r
F
.50847 .65552 m .51244 .65806 L .51363 .66732 L .794 .623 0 r
F
.91268 .50277 m .91561 .51574 L .91494 .52305 L .829 .172 0 r
F
.91268 .50277 m .91336 .49529 L .91561 .51574 L F
.58052 .6099 m .58538 .61283 L .58287 .6148 L 1 1 0 r
F
.58052 .6099 m .58296 .60779 L .58538 .61283 L F
.64391 .87301 m .64128 .87677 L .63505 .87895 L .46 .213 0 r
F
.64391 .87301 m .65054 .87065 L .64128 .87677 L F
.46484 .69202 m .46303 .65861 L .46225 .66429 L 1 .718 0 r
F
.61625 .90607 m .61204 .90843 L .60589 .9103 L .309 .191 0 r
F
.61625 .90607 m .62291 .90401 L .61204 .90843 L F
.2774 .86301 m .26049 .85496 L .26663 .85841 L .417 0 0 r
F
.28323 .86615 m .2774 .86301 L .26663 .85841 L .396 0 0 r
F
.4952 .65579 m .49882 .66119 L .49545 .6609 L 1 .878 0 r
F
.4952 .65579 m .49839 .65508 L .49882 .66119 L F
.50409 .6364 m .50815 .63875 L .50474 .63729 L .458 0 0 r
F
.50003 .63089 m .50409 .6364 L .50474 .63729 L 0 0 0 r
F
.41777 .89961 m .40209 .90004 L .40634 .90133 L .347 0 0 r
F
.42127 .90075 m .41777 .89961 L .40634 .90133 L .332 0 0 r
F
.43255 .89784 m .41777 .89961 L .42127 .90075 L .295 0 0 r
F
.75331 .55504 m .75898 .5629 L .75733 .56768 L 1 .547 0 r
F
.75331 .55504 m .75487 .55012 L .75898 .5629 L F
.52732 .92174 m .52013 .92366 L .51652 .92389 L .232 .18 0 r
F
.52732 .92174 m .53176 .92143 L .52013 .92366 L F
.31683 .9039 m .31072 .9016 L .29933 .89696 L 0 .084 0 r
F
.5169 .6621 m .52276 .67522 L .51803 .67094 L .461 .38 0 r
F
.51244 .65806 m .5169 .6621 L .51803 .67094 L .623 .495 0 r
F
.57803 .61197 m .58287 .6148 L .5803 .61672 L 1 1 0 r
F
.57803 .61197 m .58052 .6099 L .58287 .6148 L F
.44501 .67629 m .44026 .67618 L .44284 .68272 L 1 .435 0 r
F
.44748 .68343 m .44501 .67629 L .44284 .68272 L 1 .537 0 r
F
.78295 .79466 m .78092 .80004 L .77558 .80505 L .61 .217 0 r
F
.78295 .79466 m .78849 .78941 L .78092 .80004 L F
.60896 .71237 m .61206 .71747 L .60676 .71763 L .517 .736 0 r
F
.60896 .71237 m .61437 .71199 L .61206 .71747 L F
.34879 .90768 m .33116 .90238 L .33734 .90439 L .239 0 0 r
F
.35446 .90938 m .34879 .90768 L .33734 .90439 L .211 0 0 r
F
.54237 .91883 m .53617 .92099 L .53176 .92143 L .268 .186 0 r
F
.54237 .91883 m .54754 .9183 L .53617 .92099 L F
.38103 .89768 m .36419 .89552 L .36968 .8973 L .385 0 0 r
F
.38592 .89924 m .38103 .89768 L .36968 .8973 L .368 0 0 r
F
.49195 .65623 m .49545 .6609 L .49208 .66041 L 1 .872 0 r
F
.49195 .65623 m .4952 .65579 L .49545 .6609 L F
.43525 .89885 m .43255 .89784 L .42127 .90075 L .28 0 0 r
F
.5755 .61399 m .5803 .61672 L .5777 .61859 L 1 1 0 r
F
.5755 .61399 m .57803 .61197 L .5803 .61672 L F
.46225 .66429 m .4591 .65704 L .46149 .67186 L 1 .623 0 r
F
.44826 .75556 m .43894 .77087 L .44086 .78283 L .668 .134 0 r
F
.44984 .76698 m .44826 .75556 L .44086 .78283 L .674 .155 0 r
F
.37874 .75208 m .36747 .75357 L .36982 .76154 L 1 .569 0 r
F
.38107 .75965 m .37874 .75208 L .36982 .76154 L 1 .579 0 r
F
.69335 .6662 m .6962 .67129 L .69241 .67467 L .82 .629 0 r
F
.69335 .6662 m .69714 .66259 L .6962 .67129 L F
.52803 .92733 m .52069 .92881 L .51705 .92907 L .172 .17 0 r
F
.52803 .92733 m .53252 .92698 L .52069 .92881 L F
.52184 .66721 m .5278 .67991 L .52276 .67522 L .36 .297 0 r
F
.5169 .6621 m .52184 .66721 L .52276 .67522 L .461 .38 0 r
F
.86572 .67944 m .86523 .68804 L .86169 .69453 L .757 .211 0 r
F
.86572 .67944 m .86936 .6727 L .86523 .68804 L F
.50409 .6364 m .50766 .6387 L .50815 .63875 L .458 0 0 r
F
.48863 .65586 m .49195 .65623 L .49208 .66041 L .974 .814 0 r
F
.41238 .77367 m .40036 .78087 L .40295 .7906 L 1 .466 0 r
F
.41474 .78327 m .41238 .77367 L .40295 .7906 L 1 .472 0 r
F
.57293 .61597 m .5777 .61859 L .57506 .62042 L 1 1 0 r
F
.57293 .61597 m .5755 .61399 L .5777 .61859 L F
.42627 .77328 m .41474 .78327 L .41721 .79382 L .949 .381 0 r
F
.42845 .78378 m .42627 .77328 L .41721 .79382 L .948 .39 0 r
F
.76769 .78978 m .76677 .79565 L .76146 .8004 L .661 .226 0 r
F
.76769 .78978 m .77315 .78477 L .76677 .79565 L F
.54334 .9248 m .53697 .92649 L .53252 .92698 L .203 .175 0 r
F
.54334 .9248 m .54856 .92419 L .53697 .92649 L F
.3471 .91356 m .32924 .90814 L .33554 .91008 L .209 0 0 r
F
.35288 .91519 m .3471 .91356 L .33554 .91008 L 0 .098 0 r
F
.60345 .71243 m .60676 .71763 L .60137 .71749 L .491 .713 0 r
F
.60345 .71243 m .60896 .71237 L .60676 .71763 L F
.84714 .67833 m .84896 .68756 L .84544 .6938 L .832 .248 0 r
F
.84714 .67833 m .85063 .67183 L .84896 .68756 L F
.32438 .88323 m .30725 .87779 L .31343 .88047 L .391 0 0 r
F
.33014 .88562 m .32438 .88323 L .31343 .88047 L .371 0 0 r
F
.57032 .61789 m .57506 .62042 L .57238 .62218 L 1 1 0 r
F
.57032 .61789 m .57293 .61597 L .57506 .62042 L F
.50354 .64683 m .50847 .65552 L .50492 .65448 L .996 .766 0 r
F
.50059 .64833 m .50492 .65448 L .5016 .6545 L 1 .858 0 r
F
.50059 .64833 m .50354 .64683 L .50492 .65448 L F
.55467 .90032 m .55024 .90457 L .5452 .90482 L .506 .56 0 r
F
.55467 .90032 m .56041 .90013 L .55024 .90457 L F
.49765 .65007 m .5016 .6545 L .49839 .65508 L 1 .914 0 r
F
.49765 .65007 m .50059 .64833 L .5016 .6545 L F
.52716 .67282 m .53309 .68476 L .5278 .67991 L .308 .247 0 r
F
.52184 .66721 m .52716 .67282 L .5278 .67991 L .36 .297 0 r
F
.64957 .88587 m .64644 .88881 L .64012 .89129 L .394 .203 0 r
F
.64957 .88587 m .6563 .8832 L .64644 .88881 L F
.50667 .64636 m .51244 .65806 L .50847 .65552 L .721 .551 0 r
F
.50354 .64683 m .50667 .64636 L .50847 .65552 L .996 .766 0 r
F
.75165 .55994 m .75733 .56768 L .75558 .57244 L 1 .57 0 r
F
.75165 .55994 m .75331 .55504 L .75733 .56768 L F
.51103 .63968 m .51491 .64047 L .51155 .63982 L .014 .138 0 r
F
.50766 .6387 m .51103 .63968 L .51155 .63982 L .199 0 0 r
F
.60284 .88729 m .59993 .89125 L .59386 .89246 L .466 .348 0 r
F
.60284 .88729 m .60942 .886 L .59993 .89125 L F
.87483 .51468 m .89308 .52799 L .89225 .53495 L 1 .312 0 r
F
.87483 .51468 m .87314 .50764 L .89308 .52799 L F
.57529 .89488 m .57173 .89912 L .56609 .89973 L .494 .506 0 r
F
.57529 .89488 m .58154 .89429 L .57173 .89912 L F
.56767 .61976 m .57032 .61789 L .57238 .62218 L 1 1 0 r
F
.40209 .90004 m .38592 .89924 L .39086 .90071 L .369 0 0 r
F
.40634 .90133 m .40209 .90004 L .39086 .90071 L .354 0 0 r
F
.49465 .65175 m .49839 .65508 L .4952 .65579 L 1 .948 0 r
F
.49465 .65175 m .49765 .65007 L .49839 .65508 L F
.46796 .68176 m .46559 .67563 L .46663 .71314 L .583 .095 0 r
F
.47824 .64698 m .48536 .71077 L .47881 .6565 L 1 .711 0 r
F
.47881 .6565 m .48603 .72101 L .47939 .66946 L 0 0 0 r
F
.47939 .66946 m .48603 .72101 L .4874 .74758 L .425 .071 0 r
F
.47824 .64698 m .48603 .72745 L .48536 .71077 L 1 .711 0 r
F
.2705 .8766 m .25362 .86716 L .26001 .87063 L 0 .059 0 r
F
.27659 .87974 m .2705 .8766 L .26001 .87063 L 0 .065 0 r
F
.68948 .66972 m .69241 .67467 L .68854 .67796 L .813 .642 0 r
F
.68948 .66972 m .69335 .6662 L .69241 .67467 L F
.59786 .71215 m .60137 .71749 L .59589 .71701 L .463 .682 0 r
F
.59786 .71215 m .60345 .71243 L .60137 .71749 L F
.51288 .92398 m .50493 .92567 L .50218 .92571 L .204 .176 0 r
F
.51288 .92398 m .51652 .92389 L .50493 .92567 L F
.49157 .65307 m .4952 .65579 L .49195 .65623 L 1 .955 0 r
F
.49157 .65307 m .49465 .65175 L .4952 .65579 L F
.91187 .51025 m .91494 .52305 L .91414 .53036 L .837 .176 0 r
F
.91187 .51025 m .91268 .50277 L .91494 .52305 L F
.51432 .64008 m .51822 .64077 L .51491 .64047 L .181 .168 0 r
F
.51103 .63968 m .51432 .64008 L .51491 .64047 L .014 .138 0 r
F
.56227 .62334 m .56691 .62555 L .56411 .62715 L .968 1 0 r
F
.56227 .62334 m .56499 .62158 L .56691 .62555 L F
.51047 .64876 m .5169 .6621 L .51244 .65806 L .277 .127 0 r
F
.50667 .64636 m .51047 .64876 L .51244 .65806 L .721 .551 0 r
F
.53276 .67852 m .53858 .68957 L .53309 .68476 L .273 .225 0 r
F
.52716 .67282 m .53276 .67852 L .53309 .68476 L .308 .247 0 r
F
.48837 .65359 m .49195 .65623 L .48863 .65586 L .996 .914 0 r
F
.48837 .65359 m .49157 .65307 L .49195 .65623 L F
.65214 .89173 m .64888 .89449 L .64249 .89706 L .379 .2 0 r
F
.65214 .89173 m .65894 .88894 L .64888 .89449 L F
.55952 .62504 m .56411 .62715 L .56128 .62868 L .947 1 0 r
F
.55952 .62504 m .56227 .62334 L .56411 .62715 L F
.51755 .64011 m .5215 .64081 L .51822 .64077 L .307 .218 0 r
F
.51432 .64008 m .51755 .64011 L .51822 .64077 L .181 .168 0 r
F
.45212 .68403 m .44748 .68343 L .44973 .69528 L 1 .5 0 r
F
.45417 .69882 m .45212 .68403 L .44973 .69528 L 1 .575 0 r
F
.45654 .68491 m .45212 .68403 L .45417 .69882 L 1 .451 0 r
F
.4634 .72486 m .46225 .66429 L .46149 .67186 L 1 .803 0 r
F
.46484 .69202 m .46225 .66429 L .4634 .72486 L 1 .718 0 r
F
.51337 .92919 m .50529 .93048 L .50252 .93052 L .151 .167 0 r
F
.51337 .92919 m .51705 .92907 L .50529 .93048 L F
.45831 .70526 m .45654 .68491 L .45417 .69882 L 1 .525 0 r
F
.46056 .68689 m .45654 .68491 L .45831 .70526 L .928 .395 0 r
F
.55673 .62668 m .56128 .62868 L .55842 .63015 L .925 1 0 r
F
.55673 .62668 m .55952 .62504 L .56128 .62868 L F
.26744 .88264 m .25027 .87311 L .2568 .87654 L 0 .064 0 r
F
.27367 .88574 m .26744 .88264 L .2568 .87654 L 0 .07 0 r
F
.37733 .91477 m .3602 .91096 L .36598 .91242 L .197 0 0 r
F
.38251 .91594 m .37733 .91477 L .36598 .91242 L .167 0 0 r
F
.77731 .79982 m .77558 .80505 L .77013 .80996 L .611 .219 0 r
F
.77731 .79982 m .78295 .79466 L .77558 .80505 L F
.59218 .7115 m .59589 .71701 L .59034 .71617 L .433 .644 0 r
F
.59218 .7115 m .59786 .71215 L .59589 .71701 L F
.35876 .89365 m .34185 .89013 L .3478 .89225 L .379 0 0 r
F
.36419 .89552 m .35876 .89365 L .3478 .89225 L .361 0 0 r
F
.41509 .92047 m .39902 .91862 L .40355 .91939 L .143 0 0 r
F
.41885 .92099 m .41509 .92047 L .40355 .91939 L .111 0 0 r
F
.43034 .92154 m .41509 .92047 L .41885 .92099 L .106 0 0 r
F
.52075 .63987 m .52475 .64062 L .5215 .64081 L .4 .388 0 r
F
.51755 .64011 m .52075 .63987 L .5215 .64081 L .307 .218 0 r
F
.5539 .62826 m .55842 .63015 L .55552 .63155 L .9 1 0 r
F
.5539 .62826 m .55673 .62668 L .55842 .63015 L F
.74989 .56482 m .75558 .57244 L .75374 .57717 L 1 .593 0 r
F
.74989 .56482 m .75165 .55994 L .75558 .57244 L F
.53856 .68402 m .54422 .69416 L .53858 .68957 L .252 .226 0 r
F
.53276 .67852 m .53856 .68402 L .53858 .68957 L .273 .225 0 r
F
.39789 .77184 m .38597 .77643 L .3886 .78563 L 1 .536 0 r
F
.40036 .78087 m .39789 .77184 L .3886 .78563 L 1 .541 0 r
F
.55104 .62977 m .55552 .63155 L .55259 .63288 L .873 1 0 r
F
.55104 .62977 m .5539 .62826 L .55552 .63155 L F
.28323 .86615 m .26663 .85841 L .27284 .86177 L .396 0 0 r
F
.28913 .8692 m .28323 .86615 L .27284 .86177 L .376 0 0 r
F
.50187 .64061 m .50667 .64636 L .50354 .64683 L 1 .847 0 r
F
.49931 .64359 m .50354 .64683 L .50059 .64833 L 1 .944 0 r
F
.49931 .64359 m .50187 .64061 L .50354 .64683 L F
.52392 .63943 m .52797 .64026 L .52475 .64062 L .471 .528 0 r
F
.52075 .63987 m .52392 .63943 L .52475 .64062 L .4 .388 0 r
F
.55763 .91523 m .55266 .91762 L .54754 .9183 L .311 .193 0 r
F
.55763 .91523 m .56344 .91445 L .55266 .91762 L F
.86195 .68613 m .86169 .69453 L .85801 .70097 L .76 .213 0 r
F
.86195 .68613 m .86572 .67944 L .86169 .69453 L F
.69029 .84927 m .68864 .85342 L .68249 .85663 L .529 .219 0 r
F
.69029 .84927 m .69671 .84583 L .68864 .85342 L F
.43894 .77087 m .42845 .78378 L .43072 .79565 L .824 .278 0 r
F
.44086 .78283 m .43894 .77087 L .43072 .79565 L .827 .291 0 r
F
.68552 .67315 m .68854 .67796 L .68458 .68114 L .804 .654 0 r
F
.68552 .67315 m .68948 .66972 L .68854 .67796 L F
.54815 .63121 m .55259 .63288 L .54962 .63413 L .844 .994 0 r
F
.54815 .63121 m .55104 .62977 L .55259 .63288 L F
.5042 .63695 m .51047 .64876 L .50667 .64636 L .706 .514 0 r
F
.50187 .64061 m .5042 .63695 L .50667 .64636 L 1 .847 0 r
F
.52705 .63881 m .53115 .63973 L .52797 .64026 L .526 .64 0 r
F
.52392 .63943 m .52705 .63881 L .52797 .64026 L .471 .528 0 r
F
.49662 .64627 m .50059 .64833 L .49765 .65007 L 1 1 0 r
F
.49662 .64627 m .49931 .64359 L .50059 .64833 L F
.31898 .89801 m .30172 .89116 L .30818 .89373 L 0 .079 0 r
F
.32504 .90025 m .31898 .89801 L .30818 .89373 L 0 .085 0 r
F
.63721 .8752 m .63505 .87895 L .62875 .88098 L .469 .219 0 r
F
.63721 .8752 m .64391 .87301 L .63505 .87895 L F
.60746 .90159 m .604 .90428 L .59785 .9059 L .357 .199 0 r
F
.60746 .90159 m .61412 .89982 L .604 .90428 L F
.58641 .71044 m .59034 .71617 L .5847 .71495 L .402 .599 0 r
F
.58641 .71044 m .59218 .7115 L .59034 .71617 L F
.54523 .63258 m .54962 .63413 L .54662 .63531 L .811 .968 0 r
F
.54523 .63258 m .54815 .63121 L .54962 .63413 L F
.84352 .68479 m .84544 .6938 L .84179 .69999 L .831 .268 0 r
F
.84352 .68479 m .84714 .67833 L .84544 .6938 L F
.57906 .90991 m .57492 .91246 L .56921 .91353 L .335 .196 0 r
F
.57906 .90991 m .58538 .90872 L .57492 .91246 L F
.53016 .63805 m .53431 .63907 L .53115 .63973 L .57 .728 0 r
F
.52705 .63881 m .53016 .63805 L .53115 .63973 L .526 .64 0 r
F
.51533 .65484 m .52184 .66721 L .5169 .6621 L .01 .054 0 r
F
.51047 .64876 m .51533 .65484 L .5169 .6621 L .277 .127 0 r
F
.76212 .7947 m .76146 .8004 L .75605 .80505 L .66 .227 0 r
F
.76212 .7947 m .76769 .78978 L .76146 .8004 L F
.54228 .63386 m .54662 .63531 L .54359 .6364 L .774 .937 0 r
F
.54228 .63386 m .54523 .63258 L .54662 .63531 L F
.38132 .92174 m .37605 .92066 L .3646 .91807 L 0 .11 0 r
F
.44748 .68343 m .44284 .68272 L .44522 .69277 L 1 .537 0 r
F
.44973 .69528 m .44748 .68343 L .44522 .69277 L 1 .619 0 r
F
.53323 .63717 m .53743 .63828 L .53431 .63907 L .629 .798 0 r
F
.53016 .63805 m .53323 .63717 L .53431 .63907 L .57 .728 0 r
F
.53929 .63506 m .54359 .6364 L .54052 .63739 L .732 .899 0 r
F
.53929 .63506 m .54228 .63386 L .54359 .6364 L F
.53628 .63616 m .54052 .63739 L .53743 .63828 L .684 .854 0 r
F
.53323 .63717 m .53628 .63616 L .53743 .63828 L .629 .798 0 r
F
.53628 .63616 m .53929 .63506 L .54052 .63739 L .684 .854 0 r
F
.5445 .68914 m .54997 .69843 L .54422 .69416 L .245 .245 0 r
F
.53856 .68402 m .5445 .68914 L .54422 .69416 L .252 .226 0 r
F
.49383 .64869 m .49765 .65007 L .49465 .65175 L 1 1 0 r
F
.49383 .64869 m .49662 .64627 L .49765 .65007 L F
.4143 .92671 m .39803 .92461 L .40264 .92529 L .11 0 0 r
F
.41812 .92713 m .4143 .92671 L .40264 .92529 L 0 .123 0 r
F
.87593 .52176 m .89225 .53495 L .89135 .54192 L 1 .362 0 r
F
.87593 .52176 m .87483 .51468 L .89225 .53495 L F
.49092 .65077 m .49465 .65175 L .49157 .65307 L 1 1 0 r
F
.49092 .65077 m .49383 .64869 L .49465 .65175 L F
.4879 .65221 m .49157 .65307 L .48837 .65359 L F
.58056 .70894 m .5847 .71495 L .579 .71331 L .37 .548 0 r
F
.58056 .70894 m .58641 .71044 L .5847 .71495 L F
.55888 .92156 m .55374 .92344 L .54856 .92419 L .244 .182 0 r
F
.55888 .92156 m .56476 .92068 L .55374 .92344 L F
.4879 .65221 m .49092 .65077 L .49157 .65307 L 1 1 0 r
F
.55052 .69379 m .55578 .70231 L .54997 .69843 L .25 .279 0 r
F
.5445 .68914 m .55052 .69379 L .54997 .69843 L .245 .245 0 r
F
.46758 .92853 m .46746 .92866 L .45563 .92889 L .048 .148 0 r
F
.47843 .92791 m .46746 .92866 L .46758 .92853 L .085 .155 0 r
F
.47843 .92791 m .47929 .92805 L .46746 .92866 L F
.38107 .75965 m .36982 .76154 L .37226 .76996 L 1 .579 0 r
F
.38348 .76777 m .38107 .75965 L .37226 .76996 L 1 .587 0 r
F
.31683 .9039 m .29933 .89696 L .30592 .89946 L 0 .084 0 r
F
.323 .90608 m .31683 .9039 L .30592 .89946 L 0 .09 0 r
F
.39902 .91862 m .38251 .91594 L .38774 .91699 L .163 0 0 r
F
.40355 .91939 m .39902 .91862 L .38774 .91699 L .133 0 0 r
F
.60952 .90799 m .60589 .9103 L .59967 .91203 L .319 .193 0 r
F
.60952 .90799 m .61625 .90607 L .60589 .9103 L F
.58069 .91642 m .57637 .91849 L .57059 .91965 L .278 .187 0 r
F
.58069 .91642 m .58707 .9151 L .57637 .91849 L F
.57464 .70697 m .579 .71331 L .57324 .71125 L .34 .492 0 r
F
.57464 .70697 m .58056 .70894 L .579 .71331 L F
.74803 .56968 m .75374 .57717 L .7518 .58187 L 1 .615 0 r
F
.74803 .56968 m .74989 .56482 L .75374 .57717 L F
.68147 .67648 m .68458 .68114 L .68053 .68423 L .793 .664 0 r
F
.68147 .67648 m .68552 .67315 L .68458 .68114 L F
.5042 .63695 m .50767 .63875 L .51047 .64876 L .706 .514 0 r
F
.55657 .69791 m .56161 .70575 L .55578 .70231 L .263 .324 0 r
F
.55052 .69379 m .55657 .69791 L .55578 .70231 L .25 .279 0 r
F
.50767 .63875 m .51533 .65484 L .51047 .64876 L .868 .115 0 r
F
.91092 .51773 m .91414 .53036 L .9132 .53766 L .845 .179 0 r
F
.91092 .51773 m .91187 .51025 L .91414 .53036 L F
.56866 .70449 m .57324 .71125 L .56744 .70873 L .31 .434 0 r
F
.56866 .70449 m .57464 .70697 L .57324 .71125 L F
.46754 .93235 m .46743 .9325 L .4555 .93247 L .04 .146 0 r
F
.47849 .93203 m .46743 .9325 L .46754 .93235 L .067 .151 0 r
F
.47849 .93203 m .47936 .93219 L .46743 .9325 L F
.56263 .70147 m .56744 .70873 L .56161 .70575 L .284 .377 0 r
F
.55657 .69791 m .56263 .70147 L .56161 .70575 L .263 .324 0 r
F
.4327 .92826 m .42973 .92808 L .41812 .92713 L 0 .13 0 r
F
.56263 .70147 m .56866 .70449 L .56744 .70873 L .284 .377 0 r
F
.53499 .90473 m .53004 .90886 L .52569 .9088 L .521 .605 0 r
F
.53499 .90473 m .54011 .90487 L .53004 .90886 L F
.48927 .93139 m .47936 .93219 L .47849 .93203 L .1 .157 0 r
F
.48927 .93139 m .49112 .93153 L .47936 .93219 L F
.69724 .86099 m .6951 .86451 L .68883 .86793 L .482 .212 0 r
F
.69724 .86099 m .70381 .85734 L .6951 .86451 L F
.52088 .66245 m .52716 .67282 L .52184 .66721 L 0 .034 0 r
F
.51568 .65549 m .52088 .66245 L .52184 .66721 L .01 .054 0 r
F
.52088 .66245 m .52677 .67004 L .52716 .67282 L 0 .034 0 r
F
.52203 .66878 m .5265 .66997 L .52088 .66245 L 1 .165 0 r
F
.5265 .66997 m .52677 .67004 L .52088 .66245 L F
.51533 .65484 m .52088 .66245 L .51568 .65549 L .01 .054 0 r
F
.35446 .90938 m .33734 .90439 L .34359 .90628 L .211 0 0 r
F
.3602 .91096 m .35446 .90938 L .34359 .90628 L 0 .098 0 r
F
.39803 .92461 m .38132 .92174 L .38664 .9227 L .127 0 0 r
F
.40264 .92529 m .39803 .92461 L .38664 .9227 L 0 .119 0 r
F
.33014 .88562 m .31343 .88047 L .31967 .88305 L .371 0 0 r
F
.33597 .88792 m .33014 .88562 L .31967 .88305 L .351 0 0 r
F
.64276 .8884 m .64012 .89129 L .63372 .89363 L .401 .205 0 r
F
.64276 .8884 m .64957 .88587 L .64012 .89129 L F
.46758 .92853 m .45563 .92889 L .45672 .9288 L .048 .148 0 r
F
.27659 .87974 m .26001 .87063 L .26648 .87399 L 0 .065 0 r
F
.28277 .88276 m .27659 .87974 L .26648 .87399 L 0 .071 0 r
F
.77156 .80489 m .77013 .80996 L .76458 .81478 L .612 .22 0 r
F
.77156 .80489 m .77731 .79982 L .77013 .80996 L F
.85805 .69276 m .85801 .70097 L .85422 .70735 L .763 .215 0 r
F
.85805 .69276 m .86195 .68613 L .85801 .70097 L F
.67734 .6797 m .68053 .68423 L .67639 .6872 L .781 .671 0 r
F
.67734 .6797 m .68147 .67648 L .68053 .68423 L F
.38592 .89924 m .36968 .8973 L .37523 .89899 L .368 0 0 r
F
.39086 .90071 m .38592 .89924 L .37523 .89899 L .352 0 0 r
F
.83978 .69119 m .84179 .69999 L .83803 .70613 L .83 .288 0 r
F
.83978 .69119 m .84352 .68479 L .84179 .69999 L F
.45661 .93235 m .4555 .93247 L .44378 .93209 L .021 .142 0 r
F
.46754 .93235 m .4555 .93247 L .45661 .93235 L .04 .146 0 r
F
.59619 .88834 m .59386 .89246 L .58773 .89348 L .488 .45 0 r
F
.59619 .88834 m .60284 .88729 L .59386 .89246 L F
.70034 .8662 m .69812 .86969 L .69179 .87319 L .478 .211 0 r
F
.70034 .8662 m .70697 .86247 L .69812 .86969 L F
.74607 .57451 m .7518 .58187 L .74976 .58654 L 1 .636 0 r
F
.74607 .57451 m .74803 .56968 L .7518 .58187 L F
.50767 .63875 m .51553 .65778 L .51533 .65484 L .868 .115 0 r
F
.41474 .78327 m .40295 .7906 L .4057 .80097 L 1 .472 0 r
F
.41721 .79382 m .41474 .78327 L .4057 .80097 L 1 .475 0 r
F
.35288 .91519 m .33554 .91008 L .3419 .9119 L 0 .098 0 r
F
.35871 .9167 m .35288 .91519 L .3419 .9119 L 0 .104 0 r
F
.75645 .79951 m .75605 .80505 L .75054 .8096 L .658 .228 0 r
F
.75645 .79951 m .76212 .7947 L .75605 .80505 L F
.49941 .92561 m .50218 .92571 L .49093 .92707 L .185 .172 0 r
F
.64527 .89438 m .64249 .89706 L .63603 .89951 L .384 .202 0 r
F
.64527 .89438 m .65214 .89173 L .64249 .89706 L F
.68378 .85258 m .68249 .85663 L .67626 .85971 L .53 .22 0 r
F
.68378 .85258 m .69029 .84927 L .68249 .85663 L F
.87657 .52887 m .89135 .54192 L .89036 .5489 L 1 .396 0 r
F
.87657 .52887 m .87593 .52176 L .89135 .54192 L F
.27367 .88574 m .2568 .87654 L .26342 .87986 L 0 .07 0 r
F
.27997 .88872 m .27367 .88574 L .26342 .87986 L 0 .075 0 r
F
.4634 .72486 m .46149 .67186 L .46139 .77493 L 1 .803 0 r
F
.42127 .90075 m .40634 .90133 L .41064 .90255 L .332 0 0 r
F
.42481 .90183 m .42127 .90075 L .41064 .90255 L .319 0 0 r
F
.43525 .89885 m .42127 .90075 L .42481 .90183 L .28 0 0 r
F
.56899 .89521 m .56609 .89973 L .56041 .90013 L .526 .633 0 r
F
.56899 .89521 m .57529 .89488 L .56609 .89973 L F
.28913 .8692 m .27284 .86177 L .27913 .86503 L .376 0 0 r
F
.2951 .87216 m .28913 .8692 L .27913 .86503 L .356 0 0 r
F
.53716 .91921 m .53176 .92143 L .52732 .92174 L .301 .191 0 r
F
.53716 .91921 m .54237 .91883 L .53176 .92143 L F
.42845 .78378 m .41721 .79382 L .41984 .80527 L .948 .39 0 r
F
.43072 .79565 m .42845 .78378 L .41984 .80527 L .947 .395 0 r
F
.49972 .93043 m .49112 .93153 L .48927 .93139 L .14 .165 0 r
F
.49972 .93043 m .50252 .93052 L .49112 .93153 L F
.52285 .9219 m .51652 .92389 L .51288 .92398 L .269 .186 0 r
F
.52285 .9219 m .52732 .92174 L .51652 .92389 L F
.67311 .68282 m .67639 .6872 L .67216 .69006 L .767 .677 0 r
F
.67311 .68282 m .67734 .6797 L .67639 .6872 L F
.54889 .90028 m .5452 .90482 L .54011 .90487 L .546 .696 0 r
F
.54889 .90028 m .55467 .90032 L .5452 .90482 L F
.52677 .67004 m .53276 .67852 L .52716 .67282 L 0 .025 0 r
F
.90983 .52521 m .9132 .53766 L .91212 .54496 L .853 .183 0 r
F
.90983 .52521 m .91092 .51773 L .9132 .53766 L F
.63044 .87721 m .62875 .88098 L .62238 .88283 L .478 .277 0 r
F
.63044 .87721 m .63721 .8752 L .62875 .88098 L F
.51553 .65778 m .52088 .66245 L .51533 .65484 L 1 .155 0 r
F
.43797 .89982 m .43525 .89885 L .42481 .90183 L .267 0 0 r
F
.74401 .57931 m .74976 .58654 L .74763 .59118 L 1 .656 0 r
F
.74401 .57931 m .74607 .57451 L .74976 .58654 L F
.47939 .66946 m .4874 .74758 L .48001 .68721 L .425 .071 0 r
F
.44984 .76698 m .44086 .78283 L .44286 .79694 L .674 .155 0 r
F
.53807 .92527 m .53252 .92698 L .52803 .92733 L .229 .18 0 r
F
.53807 .92527 m .54334 .9248 L .53252 .92698 L F
.32504 .90025 m .30818 .89373 L .31472 .89618 L 0 .085 0 r
F
.33116 .90238 m .32504 .90025 L .31472 .89618 L 0 .09 0 r
F
.36419 .89552 m .3478 .89225 L .35381 .89427 L .361 0 0 r
F
.36968 .8973 m .36419 .89552 L .35381 .89427 L .343 0 0 r
F
.40634 .90133 m .39086 .90071 L .39585 .90211 L .354 0 0 r
F
.41064 .90255 m .40634 .90133 L .39585 .90211 L .341 0 0 r
F
.52351 .92754 m .51705 .92907 L .51337 .92919 L .202 .175 0 r
F
.52351 .92754 m .52803 .92733 L .51705 .92907 L F
.40036 .78087 m .3886 .78563 L .39139 .79532 L 1 .541 0 r
F
.40295 .7906 m .40036 .78087 L .39139 .79532 L 1 .542 0 r
F
.85403 .69934 m .85422 .70735 L .85029 .71368 L .765 .218 0 r
F
.85403 .69934 m .85805 .69276 L .85422 .70735 L F
.60074 .90322 m .59785 .9059 L .59164 .90739 L .372 .202 0 r
F
.60074 .90322 m .60746 .90159 L .59785 .9059 L F
.7657 .80987 m .76458 .81478 L .75894 .8195 L .612 .221 0 r
F
.7657 .80987 m .77156 .80489 L .76458 .81478 L F
.38348 .76777 m .37226 .76996 L .37484 .77881 L 1 .587 0 r
F
.38597 .77643 m .38348 .76777 L .37484 .77881 L 1 .591 0 r
F
.8359 .69753 m .83803 .70613 L .83415 .71221 L .828 .309 0 r
F
.8359 .69753 m .83978 .69119 L .83803 .70613 L F
.6688 .68582 m .67216 .69006 L .66784 .6928 L .751 .68 0 r
F
.6688 .68582 m .67311 .68282 L .67216 .69006 L F
.69059 .86452 m .68883 .86793 L .68248 .87123 L .484 .213 0 r
F
.69059 .86452 m .69724 .86099 L .68883 .86793 L F
.38251 .91594 m .36598 .91242 L .37183 .91377 L .167 0 0 r
F
.40355 .91939 m .38774 .91699 L .39301 .91793 L .133 0 0 r
F
.39301 .91793 m .38172 .91577 L .38367 .91612 L 0 .115 0 r
F
.38315 .91606 m .38251 .91594 L .37183 .91377 L 0 .109 0 r
F
.38774 .91699 m .38416 .91627 L .38315 .91606 L F
.38416 .91627 m .38251 .91594 L .38315 .91606 L F
.38774 .91699 m .37183 .91377 L .37772 .915 L F
.38172 .91577 m .37772 .915 L .38098 .91561 L 0 .115 0 r
F
.38172 .91577 m .38098 .91561 L .38367 .91612 L F
.45661 .93235 m .44378 .93209 L .44585 .93203 L .021 .142 0 r
F
.323 .90608 m .30592 .89946 L .31258 .90185 L 0 .09 0 r
F
.32924 .90814 m .323 .90608 L .31258 .90185 L 0 .096 0 r
F
.87682 .53601 m .89036 .5489 L .88926 .55587 L 1 .42 0 r
F
.87682 .53601 m .87657 .52887 L .89036 .5489 L F
.75069 .80423 m .75054 .8096 L .74493 .81406 L .656 .232 0 r
F
.75069 .80423 m .75645 .79951 L .75054 .8096 L F
.44973 .69528 m .44522 .69277 L .44719 .71001 L 1 .619 0 r
F
.45145 .71814 m .44973 .69528 L .44719 .71001 L 1 .68 0 r
F
.45417 .69882 m .44973 .69528 L .45145 .71814 L 1 .575 0 r
F
.57268 .91094 m .56921 .91353 L .56344 .91445 L .358 .199 0 r
F
.57268 .91094 m .57906 .90991 L .56921 .91353 L F
.53284 .67709 m .53856 .68402 L .53276 .67852 L 0 .023 0 r
F
.52677 .67004 m .53284 .67709 L .53276 .67852 L 0 .025 0 r
F
.74186 .58408 m .74763 .59118 L .7454 .59578 L 1 .676 0 r
F
.74186 .58408 m .74401 .57931 L .74763 .59118 L F
.28277 .88276 m .26648 .87399 L .27302 .87724 L 0 .071 0 r
F
.28901 .88567 m .28277 .88276 L .27302 .87724 L 0 .076 0 r
F
.60274 .90977 m .59967 .91203 L .5934 .91363 L .33 .195 0 r
F
.60274 .90977 m .60952 .90799 L .59967 .91203 L F
.4555 .73251 m .45417 .69882 L .45145 .71814 L 1 .63 0 r
F
.45831 .70526 m .45417 .69882 L .4555 .73251 L 1 .525 0 r
F
.55177 .91586 m .54754 .9183 L .54237 .91883 L .34 .196 0 r
F
.55177 .91586 m .55763 .91523 L .54754 .9183 L F
.69362 .86983 m .69179 .87319 L .68537 .87658 L .48 .212 0 r
F
.69362 .86983 m .70034 .8662 L .69179 .87319 L F
.63588 .89079 m .63372 .89363 L .62725 .89583 L .409 .206 0 r
F
.63588 .89079 m .64276 .8884 L .63372 .89363 L F
.66441 .6887 m .66784 .6928 L .66343 .69541 L .733 .68 0 r
F
.66441 .6887 m .6688 .68582 L .66784 .6928 L F
.38664 .9227 m .38132 .92174 L .37055 .91933 L 0 .116 0 r
F
.67719 .85576 m .67626 .85971 L .66995 .86266 L .531 .221 0 r
F
.67719 .85576 m .68378 .85258 L .67626 .85971 L F
.50922 .92393 m .50218 .92571 L .49941 .92561 L .244 .182 0 r
F
.50922 .92393 m .51288 .92398 L .50218 .92571 L F
.33597 .88792 m .31967 .88305 L .32598 .88553 L .351 0 0 r
F
.34185 .89013 m .33597 .88792 L .32598 .88553 L .332 0 0 r
F
.9086 .53269 m .91212 .54496 L .9109 .55225 L .86 .187 0 r
F
.9086 .53269 m .90983 .52521 L .91212 .54496 L F
.41885 .92099 m .40355 .91939 L .40812 .92005 L .111 0 0 r
F
.57425 .9176 m .57059 .91965 L .56476 .92068 L .294 .19 0 r
F
.57425 .9176 m .58069 .91642 L .57059 .91965 L F
.27997 .88872 m .26342 .87986 L .27011 .88306 L 0 .075 0 r
F
.28635 .89158 m .27997 .88872 L .27011 .88306 L 0 .081 0 r
F
.55296 .92231 m .54856 .92419 L .54334 .9248 L .266 .186 0 r
F
.55296 .92231 m .55888 .92156 L .54856 .92419 L F
.2951 .87216 m .27913 .86503 L .28549 .86819 L .356 0 0 r
F
.30114 .87502 m .2951 .87216 L .28549 .86819 L .336 0 0 r
F
.44086 .78283 m .43072 .79565 L .43315 .80886 L .827 .291 0 r
F
.44286 .79694 m .44086 .78283 L .43315 .80886 L .829 .301 0 r
F
.50966 .92917 m .50252 .93052 L .49972 .93043 L .185 .172 0 r
F
.50966 .92917 m .51337 .92919 L .50252 .93052 L F
.50417 .65273 m .54297 .81729 L .52482 .75717 L .871 .136 0 r
F
.53505 .79536 m .54297 .81729 L .54941 .84899 L 0 .002 0 r
F
.52482 .75717 m .54297 .81729 L .53505 .79536 L F
.54297 .81729 m .55942 .86153 L .54941 .84899 L 0 0 0 r
F
.54388 .82645 m .55137 .84055 L .54297 .81729 L 1 .123 0 r
F
.55193 .8414 m .55775 .85257 L .55942 .86153 L 0 0 0 r
F
.54297 .81729 m .55775 .85257 L .55193 .8414 L F
.55942 .86153 m .56809 .87558 L .55984 .87192 L .302 .314 0 r
F
.55942 .86153 m .56863 .86872 L .56809 .87558 L F
.54941 .84899 m .55942 .86153 L .55984 .87192 L .29 .166 0 r
F
.55775 .85257 m .56863 .86872 L .55942 .86153 L 0 .036 0 r
F
.55873 .8618 m .56335 .86333 L .55775 .85257 L .726 .039 0 r
F
.56293 .86026 m .56822 .86493 L .56863 .86872 L 0 .036 0 r
F
.55775 .85257 m .56822 .86493 L .56293 .86026 L F
.56863 .86872 m .57615 .87778 L .56809 .87558 L .348 .49 0 r
F
.56863 .86872 m .57725 .87248 L .57615 .87778 L F
.56822 .86493 m .57725 .87248 L .56863 .86872 L .001 .107 0 r
F
.56801 .86881 m .57319 .86931 L .56822 .86493 L .321 0 0 r
F
.57197 .86807 m .57719 .8697 L .57725 .87248 L .001 .107 0 r
F
.56822 .86493 m .57719 .8697 L .57197 .86807 L F
.57719 .8697 m .58551 .87422 L .57725 .87248 L .19 .187 0 r
F
.57719 .8697 m .58555 .87144 L .58551 .87422 L F
.57633 .87087 m .58206 .87122 L .57719 .8697 L .03 .144 0 r
F
.58206 .87122 m .58555 .87144 L .57719 .8697 L F
.57319 .86931 m .57719 .8697 L .56822 .86493 L .321 0 0 r
F
.56335 .86333 m .56822 .86493 L .55775 .85257 L .726 .039 0 r
F
.55137 .84055 m .55775 .85257 L .54297 .81729 L 1 .123 0 r
F
.50417 .65273 m .54388 .82645 L .54297 .81729 L .871 .136 0 r
F
.50514 .67768 m .50417 .65273 L .52482 .75717 L 1 .601 0 r
F
.3602 .91096 m .34359 .90628 L .34989 .90806 L 0 .098 0 r
F
.36598 .91242 m .3602 .91096 L .34989 .90806 L 0 .104 0 r
F
.63833 .89691 m .63603 .89951 L .6295 .90182 L .39 .203 0 r
F
.63833 .89691 m .64527 .89438 L .63603 .89951 L F
.58947 .88915 m .58773 .89348 L .58154 .89429 L .51 .558 0 r
F
.58947 .88915 m .59619 .88834 L .58773 .89348 L F
.73961 .58882 m .7454 .59578 L .74308 .60034 L 1 .695 0 r
F
.73961 .58882 m .74186 .58408 L .7454 .59578 L F
.65992 .69145 m .66343 .69541 L .65893 .69787 L .712 .677 0 r
F
.65992 .69145 m .66441 .6887 L .66343 .69541 L F
.84988 .70585 m .85029 .71368 L .84625 .71993 L .766 .22 0 r
F
.84988 .70585 m .85403 .69934 L .85029 .71368 L F
.8319 .70381 m .83415 .71221 L .83015 .71822 L .826 .33 0 r
F
.8319 .70381 m .8359 .69753 L .83415 .71221 L F
.51553 .65778 m .52203 .66878 L .52088 .66245 L 1 .155 0 r
F
.53901 .68346 m .5445 .68914 L .53856 .68402 L 0 .029 0 r
F
.53284 .67709 m .53901 .68346 L .53856 .68402 L 0 .023 0 r
F
.40812 .92005 m .40355 .91939 L .39301 .91793 L .103 0 0 r
F
.41812 .92713 m .40264 .92529 L .40729 .92585 L 0 .123 0 r
F
.42197 .92743 m .41812 .92713 L .40729 .92585 L 0 .13 0 r
F
.4327 .92826 m .41812 .92713 L .42197 .92743 L F
.75975 .81474 m .75894 .8195 L .75319 .82413 L .612 .222 0 r
F
.75975 .81474 m .7657 .80987 L .75894 .8195 L F
.62359 .87903 m .62238 .88283 L .61593 .88451 L .487 .343 0 r
F
.62359 .87903 m .63044 .87721 L .62238 .88283 L F
.87673 .54316 m .88926 .55587 L .88805 .56285 L 1 .439 0 r
F
.87673 .54316 m .87682 .53601 L .88926 .55587 L F
.35871 .9167 m .3419 .9119 L .34832 .91359 L 0 .104 0 r
F
.3646 .91807 m .35871 .9167 L .34832 .91359 L 0 .111 0 r
F
.52983 .90437 m .52569 .9088 L .52129 .90855 L .567 .744 0 r
F
.52983 .90437 m .53499 .90473 L .52569 .9088 L F
.74482 .80885 m .74493 .81406 L .73923 .81841 L .654 .253 0 r
F
.74482 .80885 m .75069 .80423 L .74493 .81406 L F
.39086 .90071 m .37523 .89899 L .38083 .9006 L .352 0 0 r
F
.39585 .90211 m .39086 .90071 L .38083 .9006 L .337 0 0 r
F
.65535 .69407 m .65893 .69787 L .65435 .7002 L .689 .671 0 r
F
.65535 .69407 m .65992 .69145 L .65893 .69787 L F
.68385 .86792 m .68248 .87123 L .67606 .87441 L .486 .214 0 r
F
.68385 .86792 m .69059 .86452 L .68248 .87123 L F
.40264 .92529 m .38664 .9227 L .39201 .92353 L 0 .119 0 r
F
.40729 .92585 m .40264 .92529 L .39201 .92353 L 0 .125 0 r
F
.56263 .89529 m .56041 .90013 L .55467 .90032 L .562 .755 0 r
F
.56263 .89529 m .56899 .89521 L .56041 .90013 L F
.73727 .59352 m .74308 .60034 L .74066 .60486 L 1 .713 0 r
F
.73727 .59352 m .73961 .58882 L .74308 .60034 L F
.41721 .79382 m .4057 .80097 L .40867 .81187 L 1 .475 0 r
F
.41984 .80527 m .41721 .79382 L .40867 .81187 L F
.33116 .90238 m .31472 .89618 L .32131 .89852 L 0 .09 0 r
F
.33734 .90439 m .33116 .90238 L .32131 .89852 L 0 .096 0 r
F
.90723 .54017 m .9109 .55225 L .90955 .55953 L .866 .19 0 r
F
.90723 .54017 m .9086 .53269 L .9109 .55225 L F
.46769 .92827 m .46758 .92853 L .45672 .9288 L .088 .155 0 r
F
.54524 .68907 m .55052 .69379 L .5445 .68914 L 0 .04 0 r
F
.53901 .68346 m .54524 .68907 L .5445 .68914 L 0 .029 0 r
F
.38597 .77643 m .37484 .77881 L .37759 .78807 L 1 .591 0 r
F
.3886 .78563 m .38597 .77643 L .37759 .78807 L 1 .592 0 r
F
.65069 .69653 m .65435 .7002 L .64967 .70236 L .664 .661 0 r
F
.65069 .69653 m .65535 .69407 L .65435 .7002 L F
.48001 .68721 m .4874 .74758 L .4891 .7863 L .628 .217 0 r
F
.67051 .8588 m .66995 .86266 L .66356 .86547 L .531 .245 0 r
F
.67051 .8588 m .67719 .85576 L .66995 .86266 L F
.68682 .87333 m .68537 .87658 L .67888 .87985 L .481 .213 0 r
F
.68682 .87333 m .69362 .86983 L .68537 .87658 L F
.28901 .88567 m .27302 .87724 L .27964 .88038 L 0 .076 0 r
F
.29533 .88847 m .28901 .88567 L .27964 .88038 L 0 .082 0 r
F
.36968 .8973 m .35381 .89427 L .35988 .89621 L .343 0 0 r
F
.37523 .89899 m .36968 .8973 L .35988 .89621 L .327 0 0 r
F
.59395 .90468 m .59164 .90739 L .58538 .90872 L .389 .204 0 r
F
.59395 .90468 m .60074 .90322 L .59164 .90739 L F
.54307 .9 m .54011 .90487 L .53499 .90473 L .614 .822 0 r
F
.54307 .9 m .54889 .90028 L .54011 .90487 L F
.46766 .93206 m .46754 .93235 L .45661 .93235 L .079 .153 0 r
F
.47761 .93173 m .46754 .93235 L .46766 .93206 L .106 .158 0 r
F
.47761 .93173 m .47849 .93203 L .46754 .93235 L F
.82777 .71003 m .83015 .71822 L .82602 .72417 L .824 .351 0 r
F
.82777 .71003 m .8319 .70381 L .83015 .71822 L F
.8456 .7123 m .84625 .71993 L .84208 .72613 L .767 .222 0 r
F
.8456 .7123 m .84988 .70585 L .84625 .71993 L F
.40295 .7906 m .39139 .79532 L .3944 .80542 L 1 .542 0 r
F
.4057 .80097 m .40295 .7906 L .3944 .80542 L 1 .54 0 r
F
.32924 .90814 m .31258 .90185 L .3193 .90412 L 0 .096 0 r
F
.33554 .91008 m .32924 .90814 L .3193 .90412 L 0 .102 0 r
F
.48741 .93111 m .47849 .93203 L .47761 .93173 L .138 .164 0 r
F
.48741 .93111 m .48927 .93139 L .47849 .93203 L F
.73483 .59818 m .74066 .60486 L .73815 .60934 L 1 .73 0 r
F
.73483 .59818 m .73727 .59352 L .74066 .60486 L F
.42481 .90183 m .41064 .90255 L .41499 .9037 L .319 0 0 r
F
.42839 .90285 m .42481 .90183 L .41499 .9037 L .309 0 0 r
F
.43797 .89982 m .42481 .90183 L .42839 .90285 L .267 0 0 r
F
.62894 .89303 m .62725 .89583 L .62072 .8979 L .416 .207 0 r
F
.62894 .89303 m .63588 .89079 L .62725 .89583 L F
.46769 .92827 m .45672 .9288 L .45783 .92858 L .088 .155 0 r
F
.64594 .69883 m .64967 .70236 L .6449 .70435 L .644 .647 0 r
F
.64594 .69883 m .65069 .69653 L .64967 .70236 L F
.53191 .91945 m .52732 .92174 L .52285 .9219 L .335 .195 0 r
F
.53191 .91945 m .53716 .91921 L .52732 .92174 L F
.7537 .81951 m .75319 .82413 L .74734 .82865 L .612 .223 0 r
F
.7537 .81951 m .75975 .81474 L .75319 .82413 L F
.87634 .55032 m .88805 .56285 L .88672 .56982 L 1 .455 0 r
F
.87634 .55032 m .87673 .54316 L .88805 .56285 L F
.43072 .79565 m .41984 .80527 L .4227 .81747 L .947 .395 0 r
F
.43315 .80886 m .43072 .79565 L .4227 .81747 L .946 .398 0 r
F
.28635 .89158 m .27011 .88306 L .27688 .88615 L 0 .081 0 r
F
.2928 .89433 m .28635 .89158 L .27688 .88615 L 0 .087 0 r
F
.30114 .87502 m .28549 .86819 L .29192 .87126 L .336 0 0 r
F
.30725 .87779 m .30114 .87502 L .29192 .87126 L .316 0 0 r
F
.34185 .89013 m .32598 .88553 L .33235 .88792 L .332 0 0 r
F
.3478 .89225 m .34185 .89013 L .33235 .88792 L .313 0 0 r
F
.5959 .91141 m .5934 .91363 L .58707 .9151 L .341 .197 0 r
F
.5959 .91141 m .60274 .90977 L .5934 .91363 L F
.55147 .69392 m .55657 .69791 L .55052 .69379 L 0 .054 0 r
F
.54524 .68907 m .55147 .69392 L .55052 .69379 L 0 .04 0 r
F
.45772 .93209 m .45661 .93235 L .44585 .93203 L .06 .149 0 r
F
.46766 .93206 m .45661 .93235 L .45772 .93209 L .079 .153 0 r
F
.73886 .81336 m .73923 .81841 L .73343 .82266 L .652 .275 0 r
F
.73886 .81336 m .74482 .80885 L .73923 .81841 L F
.41064 .90255 m .39585 .90211 L .40089 .90344 L .341 0 0 r
F
.41499 .9037 m .41064 .90255 L .40089 .90344 L .329 0 0 r
F
.5284 .67765 m .53284 .67709 L .52677 .67004 L 1 .121 0 r
F
.52203 .66878 m .5284 .67765 L .52677 .67004 L 1 .165 0 r
F
.51834 .92191 m .51288 .92398 L .50922 .92393 L .306 .191 0 r
F
.51834 .92191 m .52285 .9219 L .51288 .92398 L F
.56626 .91182 m .56344 .91445 L .55763 .91523 L .382 .202 0 r
F
.56626 .91182 m .57268 .91094 L .56344 .91445 L F
.39301 .91793 m .38774 .91699 L .37772 .915 L 0 .115 0 r
F
.63133 .8993 m .6295 .90182 L .62291 .90401 L .395 .204 0 r
F
.63133 .8993 m .63833 .89691 L .6295 .90182 L F
.64111 .70097 m .6449 .70435 L .64004 .70617 L .62 .627 0 r
F
.64111 .70097 m .64594 .69883 L .6449 .70435 L F
.53276 .92559 m .52803 .92733 L .52351 .92754 L .256 .184 0 r
F
.53276 .92559 m .53807 .92527 L .52803 .92733 L F
.73229 .60281 m .73815 .60934 L .73555 .61378 L 1 .746 0 r
F
.73229 .60281 m .73483 .59818 L .73815 .60934 L F
.61666 .88063 m .61593 .88451 L .60942 .886 L .497 .415 0 r
F
.61666 .88063 m .62359 .87903 L .61593 .88451 L F
.90572 .54764 m .90955 .55953 L .90805 .5668 L .872 .193 0 r
F
.90572 .54764 m .90723 .54017 L .90955 .55953 L F
.58268 .88968 m .58154 .89429 L .57529 .89488 L .534 .668 0 r
F
.58268 .88968 m .58947 .88915 L .58154 .89429 L F
.4969 .93019 m .48927 .93139 L .48741 .93111 L .176 .171 0 r
F
.4969 .93019 m .49972 .93043 L .48927 .93139 L F
.67704 .8712 m .67606 .87441 L .66955 .87747 L .487 .215 0 r
F
.67704 .8712 m .68385 .86792 L .67606 .87441 L F
.51894 .92761 m .51337 .92919 L .50966 .92917 L .233 .18 0 r
F
.51894 .92761 m .52351 .92754 L .51337 .92919 L F
.55769 .69804 m .56263 .70147 L .55657 .69791 L 0 .071 0 r
F
.55147 .69392 m .55769 .69804 L .55657 .69791 L 0 .054 0 r
F
.82352 .71619 m .82602 .72417 L .82179 .73006 L .822 .372 0 r
F
.82352 .71619 m .82777 .71003 L .82602 .72417 L F
.63618 .70292 m .64004 .70617 L .63509 .70779 L .595 .602 0 r
F
.63618 .70292 m .64111 .70097 L .64004 .70617 L F
.38664 .9227 m .37055 .91933 L .37654 .92046 L 0 .116 0 r
F
.39201 .92353 m .38664 .9227 L .37654 .92046 L 0 .123 0 r
F
.54586 .91634 m .54237 .91883 L .53716 .91921 L .369 .2 0 r
F
.54586 .91634 m .55177 .91586 L .54237 .91883 L F
.56776 .91864 m .56476 .92068 L .55888 .92156 L .311 .193 0 r
F
.56776 .91864 m .57425 .9176 L .56476 .92068 L F
.84121 .71869 m .84208 .72613 L .83779 .73226 L .768 .223 0 r
F
.84121 .71869 m .8456 .7123 L .84208 .72613 L F
.36598 .91242 m .34989 .90806 L .35626 .90972 L 0 .104 0 r
F
.37183 .91377 m .36598 .91242 L .35626 .90972 L 0 .109 0 r
F
.66376 .86169 m .66356 .86547 L .65709 .86813 L .531 .278 0 r
F
.66376 .86169 m .67051 .8588 L .66356 .86547 L F
.72966 .6074 m .73555 .61378 L .73285 .61817 L 1 .761 0 r
F
.72966 .6074 m .73229 .60281 L .73555 .61378 L F
.67994 .87671 m .67888 .87985 L .67231 .88301 L .482 .214 0 r
F
.67994 .87671 m .68682 .87333 L .67888 .87985 L F
.63117 .70468 m .63509 .70779 L .63005 .7092 L .566 .571 0 r
F
.63117 .70468 m .63618 .70292 L .63509 .70779 L F
.87568 .55748 m .88672 .56982 L .88526 .57678 L 1 .47 0 r
F
.87568 .55748 m .87634 .55032 L .88672 .56982 L F
.56385 .70145 m .56866 .70449 L .56263 .70147 L 0 .09 0 r
F
.55769 .69804 m .56385 .70145 L .56263 .70147 L 0 .071 0 r
F
.29533 .88847 m .27964 .88038 L .28634 .88341 L 0 .082 0 r
F
.30172 .89116 m .29533 .88847 L .28634 .88341 L 0 .087 0 r
F
.54699 .92291 m .54334 .9248 L .53807 .92527 L .288 .189 0 r
F
.54699 .92291 m .55296 .92231 L .54334 .9248 L F
.74755 .82418 m .74734 .82865 L .7414 .83307 L .611 .224 0 r
F
.74755 .82418 m .7537 .81951 L .74734 .82865 L F
.3646 .91807 m .34832 .91359 L .3548 .91516 L 0 .111 0 r
F
.37055 .91933 m .3646 .91807 L .3548 .91516 L 0 .117 0 r
F
.45772 .93209 m .44585 .93203 L .44795 .93184 L .06 .149 0 r
F
.33734 .90439 m .32131 .89852 L .32797 .90075 L 0 .096 0 r
F
.34359 .90628 m .33734 .90439 L .32797 .90075 L 0 .102 0 r
F
.7328 .81777 m .73343 .82266 L .72754 .82681 L .649 .298 0 r
F
.7328 .81777 m .73886 .81336 L .73343 .82266 L F
.62607 .70622 m .63117 .70468 L .63005 .7092 L .533 .533 0 r
F
.45145 .71814 m .44719 .71001 L .44834 .74351 L 1 .68 0 r
F
.3886 .78563 m .37759 .78807 L .38055 .79765 L 1 .592 0 r
F
.39139 .79532 m .3886 .78563 L .38055 .79765 L 1 .589 0 r
F
.55622 .89506 m .55467 .90032 L .54889 .90028 L .639 .865 0 r
F
.55622 .89506 m .56263 .89529 L .55467 .90032 L F
.50552 .92373 m .49941 .92561 L .49662 .92537 L .284 .188 0 r
F
.50552 .92373 m .50922 .92393 L .49941 .92561 L F
.56995 .7042 m .57464 .70697 L .56866 .70449 L 0 .109 0 r
F
.56385 .70145 m .56995 .7042 L .56866 .70449 L 0 .09 0 r
F
.39585 .90211 m .38083 .9006 L .38649 .90213 L .337 0 0 r
F
.40089 .90344 m .39585 .90211 L .38649 .90213 L .325 0 0 r
F
.40812 .92005 m .39301 .91793 L .39834 .91875 L .103 0 0 r
F
.41274 .92059 m .40812 .92005 L .39834 .91875 L 0 .123 0 r
F
.62192 .89512 m .62072 .8979 L .61412 .89982 L .424 .209 0 r
F
.62192 .89512 m .62894 .89303 L .62072 .8979 L F
.72694 .61194 m .73285 .61817 L .73006 .62251 L 1 .775 0 r
F
.72694 .61194 m .72966 .6074 L .73285 .61817 L F
.90407 .5551 m .90805 .5668 L .90642 .57405 L .877 .196 0 r
F
.90407 .5551 m .90572 .54764 L .90805 .5668 L F
.30725 .87779 m .29192 .87126 L .29842 .87424 L .316 0 0 r
F
.31343 .88047 m .30725 .87779 L .29842 .87424 L .297 0 0 r
F
.53474 .68506 m .53901 .68346 L .53284 .67709 L 1 .085 0 r
F
.5284 .67765 m .53474 .68506 L .53284 .67709 L 1 .121 0 r
F
.2928 .89433 m .27688 .88615 L .28372 .88912 L 0 .087 0 r
F
.29933 .89696 m .2928 .89433 L .28372 .88912 L 0 .092 0 r
F
.58711 .90598 m .58538 .90872 L .57906 .90991 L .406 .209 0 r
F
.58711 .90598 m .59395 .90468 L .58538 .90872 L F
.33554 .91008 m .3193 .90412 L .32609 .90626 L 0 .102 0 r
F
.3419 .9119 m .33554 .91008 L .32609 .90626 L 0 .108 0 r
F
.81914 .72228 m .82179 .73006 L .81743 .73587 L .819 .392 0 r
F
.81914 .72228 m .82352 .71619 L .82179 .73006 L F
.37523 .89899 m .35988 .89621 L .36601 .89806 L .327 0 0 r
F
.38083 .9006 m .37523 .89899 L .36601 .89806 L .311 0 0 r
F
.52465 .90379 m .52129 .90855 L .51687 .90811 L .663 .872 0 r
F
.52465 .90379 m .52983 .90437 L .52129 .90855 L F
.83669 .72501 m .83779 .73226 L .83338 .73832 L .768 .225 0 r
F
.83669 .72501 m .84121 .71869 L .83779 .73226 L F
.42197 .92743 m .40729 .92585 L .41198 .92628 L 0 .13 0 r
F
.42587 .9276 m .42197 .92743 L .41198 .92628 L 0 .136 0 r
F
.61558 .70858 m .61969 .71132 L .61437 .71199 L .454 .432 0 r
F
.61558 .70858 m .62087 .70752 L .61969 .71132 L F
.57597 .70636 m .58056 .70894 L .57464 .70697 L 0 .127 0 r
F
.56995 .7042 m .57597 .70636 L .57464 .70697 L 0 .109 0 r
F
.45212 .76835 m .45145 .71814 L .44834 .74351 L 1 .71 0 r
F
.4555 .73251 m .45145 .71814 L .45212 .76835 L 1 .63 0 r
F
.50592 .929 m .49972 .93043 L .4969 .93019 L .219 .178 0 r
F
.50592 .929 m .50966 .92917 L .49972 .93043 L F
.3478 .89225 m .33235 .88792 L .33879 .89022 L .313 0 0 r
F
.35381 .89427 m .3478 .89225 L .33879 .89022 L .296 0 0 r
F
.67015 .87435 m .66955 .87747 L .66296 .8804 L .488 .216 0 r
F
.67015 .87435 m .67704 .8712 L .66955 .87747 L F
.40729 .92585 m .39201 .92353 L .39742 .92424 L 0 .125 0 r
F
.41198 .92628 m .40729 .92585 L .39742 .92424 L 0 .132 0 r
F
.44286 .79694 m .43315 .80886 L .43581 .8232 L .829 .301 0 r
F
.44501 .81321 m .44286 .79694 L .43581 .8232 L .83 .306 0 r
F
.41984 .80527 m .40867 .81187 L .41192 .82316 L 1 .475 0 r
F
.4227 .81747 m .41984 .80527 L .41192 .82316 L 1 .471 0 r
F
.61021 .70935 m .61437 .71199 L .60896 .71237 L .407 .368 0 r
F
.61021 .70935 m .61558 .70858 L .61437 .71199 L F
.58191 .70796 m .58641 .71044 L .58056 .70894 L .073 .144 0 r
F
.57597 .70636 m .58191 .70796 L .58056 .70894 L 0 .127 0 r
F
.62426 .90156 m .62291 .90401 L .61625 .90607 L .4 .205 0 r
F
.62426 .90156 m .63133 .8993 L .62291 .90401 L F
.4057 .80097 m .3944 .80542 L .39767 .81581 L 1 .54 0 r
F
.40867 .81187 m .4057 .80097 L .39767 .81581 L 1 .534 0 r
F
.60966 .882 m .60942 .886 L .60284 .88729 L .507 .493 0 r
F
.60966 .882 m .61666 .88063 L .60942 .886 L F
.87477 .56464 m .88526 .57678 L .88367 .58373 L 1 .485 0 r
F
.87477 .56464 m .87568 .55748 L .88526 .57678 L F
.72413 .61643 m .73006 .62251 L .72717 .6268 L 1 .789 0 r
F
.72413 .61643 m .72694 .61194 L .73006 .62251 L F
.60473 .70982 m .60896 .71237 L .60345 .71243 L .353 .296 0 r
F
.60473 .70982 m .61021 .70935 L .60896 .71237 L F
.589 .91291 m .58707 .9151 L .58069 .91642 L .352 .199 0 r
F
.589 .91291 m .5959 .91141 L .58707 .9151 L F
.53722 .89945 m .53499 .90473 L .52983 .90437 L .704 .93 0 r
F
.53722 .89945 m .54307 .9 L .53499 .90473 L F
.58775 .70906 m .59218 .7115 L .58641 .71044 L .152 .159 0 r
F
.58191 .70796 m .58775 .70906 L .58641 .71044 L .073 .144 0 r
F
.59917 .70995 m .60345 .71243 L .59786 .71215 L .293 .218 0 r
F
.59917 .70995 m .60473 .70982 L .60345 .71243 L F
.65692 .86442 m .65709 .86813 L .65054 .87065 L .531 .314 0 r
F
.65692 .86442 m .66376 .86169 L .65709 .86813 L F
.59351 .70971 m .59786 .71215 L .59218 .7115 L .225 .173 0 r
F
.58775 .70906 m .59351 .70971 L .59218 .7115 L .152 .159 0 r
F
.59351 .70971 m .59917 .70995 L .59786 .71215 L .225 .173 0 r
F
.74131 .82875 m .7414 .83307 L .73536 .83739 L .61 .225 0 r
F
.74131 .82875 m .74755 .82418 L .7414 .83307 L F
.57583 .88989 m .57529 .89488 L .56899 .89521 L .567 .774 0 r
F
.57583 .88989 m .58268 .88968 L .57529 .89488 L F
.72665 .82207 m .72754 .82681 L .72155 .83084 L .646 .32 0 r
F
.72665 .82207 m .7328 .81777 L .72754 .82681 L F
.67299 .87998 m .67231 .88301 L .66566 .88604 L .483 .215 0 r
F
.67299 .87998 m .67994 .87671 L .67231 .88301 L F
.55979 .91254 m .55763 .91523 L .55177 .91586 L .406 .27 0 r
F
.55979 .91254 m .56626 .91182 L .55763 .91523 L F
.50514 .67768 m .52482 .75717 L .51651 .74001 L 1 .601 0 r
F
.50526 .70315 m .50514 .67768 L .51651 .74001 L 1 .655 0 r
F
.90228 .56254 m .90642 .57405 L .90466 .58129 L .882 .199 0 r
F
.90228 .56254 m .90407 .5551 L .90642 .57405 L F
.72123 .62087 m .72717 .6268 L .7242 .63103 L 1 .801 0 r
F
.72123 .62087 m .72413 .61643 L .72717 .6268 L F
.81465 .7283 m .81743 .73587 L .81296 .74162 L .816 .412 0 r
F
.81465 .7283 m .81914 .72228 L .81743 .73587 L F
.30172 .89116 m .28634 .88341 L .29311 .88632 L 0 .087 0 r
F
.30818 .89373 m .30172 .89116 L .29311 .88632 L 0 .093 0 r
F
.39834 .91875 m .39301 .91793 L .38367 .91612 L 0 .12 0 r
F
.42839 .90285 m .41499 .9037 L .41938 .9048 L .309 0 0 r
F
.43201 .90383 m .42839 .90285 L .41938 .9048 L .302 0 0 r
F
.83205 .73126 m .83338 .73832 L .82886 .74431 L .768 .231 0 r
F
.83205 .73126 m .83669 .72501 L .83338 .73832 L F
.52663 .91955 m .52285 .9219 L .51834 .92191 L .369 .226 0 r
F
.52663 .91955 m .53191 .91945 L .52285 .9219 L F
.54104 .69128 m .54524 .68907 L .53901 .68346 L .956 .072 0 r
F
.53474 .68506 m .54104 .69128 L .53901 .68346 L 1 .085 0 r
F
.41499 .9037 m .40089 .90344 L .40598 .90469 L .329 0 0 r
F
.41938 .9048 m .41499 .9037 L .40598 .90469 L .321 0 0 r
F
.46781 .92788 m .46769 .92827 L .45783 .92858 L .128 .162 0 r
F
.37183 .91377 m .35626 .90972 L .36268 .91127 L 0 .109 0 r
F
.37772 .915 m .37183 .91377 L .36268 .91127 L 0 .115 0 r
F
.31343 .88047 m .29842 .87424 L .30499 .87711 L .297 0 0 r
F
.31967 .88305 m .31343 .88047 L .30499 .87711 L .278 0 0 r
F
.87363 .57179 m .88367 .58373 L .88194 .59067 L 1 .5 0 r
F
.87363 .57179 m .87477 .56464 L .88367 .58373 L F
.34359 .90628 m .32797 .90075 L .3347 .90285 L 0 .102 0 r
F
.34989 .90806 m .34359 .90628 L .3347 .90285 L 0 .107 0 r
F
.56122 .91954 m .55888 .92156 L .55296 .92231 L .328 .195 0 r
F
.56122 .91954 m .56776 .91864 L .55888 .92156 L F
.71823 .62527 m .7242 .63103 L .72113 .63521 L 1 .812 0 r
F
.71823 .62527 m .72123 .62087 L .7242 .63103 L F
.29933 .89696 m .28372 .88912 L .29063 .89197 L 0 .092 0 r
F
.30592 .89946 m .29933 .89696 L .29063 .89197 L 0 .098 0 r
F
.46778 .93163 m .46766 .93206 L .45772 .93209 L .118 .16 0 r
F
.47672 .9313 m .46766 .93206 L .46778 .93163 L .144 .165 0 r
F
.47672 .9313 m .47761 .93173 L .46766 .93206 L F
.43315 .80886 m .4227 .81747 L .42584 .83019 L .946 .398 0 r
F
.43581 .8232 m .43315 .80886 L .42584 .83019 L .943 .395 0 r
F
.39201 .92353 m .37654 .92046 L .38259 .92146 L 0 .123 0 r
F
.39742 .92424 m .39201 .92353 L .38259 .92146 L 0 .129 0 r
F
.61484 .89706 m .61412 .89982 L .60746 .90159 L .432 .21 0 r
F
.61484 .89706 m .62192 .89512 L .61412 .89982 L F
.52741 .92577 m .52351 .92754 L .51894 .92761 L .283 .188 0 r
F
.52741 .92577 m .53276 .92559 L .52351 .92754 L F
.48553 .93069 m .47761 .93173 L .47672 .9313 L .176 .17 0 r
F
.48553 .93069 m .48741 .93111 L .47761 .93173 L F
.53992 .91666 m .53716 .91921 L .53191 .91945 L .398 .283 0 r
F
.53992 .91666 m .54586 .91634 L .53716 .91921 L F
.66318 .87737 m .66296 .8804 L .6563 .8832 L .489 .216 0 r
F
.66318 .87737 m .67015 .87435 L .66296 .8804 L F
.51379 .92177 m .50922 .92393 L .50552 .92373 L .344 .196 0 r
F
.51379 .92177 m .51834 .92191 L .50922 .92393 L F
.46781 .92788 m .45783 .92858 L .45894 .92824 L .128 .162 0 r
F
.37055 .91933 m .3548 .91516 L .36133 .9166 L 0 .117 0 r
F
.37654 .92046 m .37055 .91933 L .36133 .9166 L 0 .122 0 r
F
.39139 .79532 m .38055 .79765 L .38376 .80748 L 1 .589 0 r
F
.3944 .80542 m .39139 .79532 L .38376 .80748 L 1 .581 0 r
F
.73497 .83321 m .73536 .83739 L .72923 .8416 L .608 .226 0 r
F
.73497 .83321 m .74131 .82875 L .73536 .83739 L F
.7204 .82625 m .72155 .83084 L .71547 .83476 L .642 .341 0 r
F
.7204 .82625 m .72665 .82207 L .72155 .83084 L F
.65001 .86699 m .65054 .87065 L .64391 .87301 L .531 .352 0 r
F
.65001 .86699 m .65692 .86442 L .65054 .87065 L F
.3419 .9119 m .32609 .90626 L .33294 .90828 L 0 .108 0 r
F
.34832 .91359 m .3419 .9119 L .33294 .90828 L 0 .114 0 r
F
.54976 .89453 m .54889 .90028 L .54307 .9 L .718 .955 0 r
F
.54976 .89453 m .55622 .89506 L .54889 .90028 L F
.81003 .73425 m .81296 .74162 L .80837 .74729 L .813 .432 0 r
F
.81003 .73425 m .81465 .7283 L .81296 .74162 L F
.45884 .9317 m .45772 .93209 L .44795 .93184 L .098 .156 0 r
F
.46778 .93163 m .45772 .93209 L .45884 .9317 L .118 .16 0 r
F
.58022 .90712 m .57906 .90991 L .57268 .91094 L .424 .278 0 r
F
.58022 .90712 m .58711 .90598 L .57906 .90991 L F
.60258 .8831 m .60284 .88729 L .59619 .88834 L .518 .576 0 r
F
.60258 .8831 m .60966 .882 L .60284 .88729 L F
.90036 .56997 m .90466 .58129 L .90275 .5885 L .886 .202 0 r
F
.90036 .56997 m .90228 .56254 L .90466 .58129 L F
.71515 .6296 m .72113 .63521 L .71797 .63932 L 1 .822 0 r
F
.71515 .6296 m .71823 .62527 L .72113 .63521 L F
.51435 .92753 m .50966 .92917 L .50592 .929 L .264 .185 0 r
F
.51435 .92753 m .51894 .92761 L .50966 .92917 L F
.61712 .90368 m .61625 .90607 L .60952 .90799 L .404 .206 0 r
F
.61712 .90368 m .62426 .90156 L .61625 .90607 L F
.45579 .81145 m .4555 .73251 L .45212 .76835 L 1 .629 0 r
F
.45902 .7639 m .4555 .73251 L .45579 .81145 L 1 .571 0 r
F
.35381 .89427 m .33879 .89022 L .34529 .89242 L .296 0 0 r
F
.35988 .89621 m .35381 .89427 L .34529 .89242 L .279 0 0 r
F
.8273 .73743 m .82886 .74431 L .82421 .75022 L .768 .254 0 r
F
.8273 .73743 m .83205 .73126 L .82886 .74431 L F
.54097 .92336 m .53807 .92527 L .53276 .92559 L .311 .192 0 r
F
.54097 .92336 m .54699 .92291 L .53807 .92527 L F
.66595 .88311 m .66566 .88604 L .65894 .88894 L .483 .215 0 r
F
.66595 .88311 m .67299 .87998 L .66566 .88604 L F
.50091 .91052 m .496 .91429 L .49324 .91371 L .558 .671 0 r
F
.38083 .9006 m .36601 .89806 L .3722 .89982 L .311 0 0 r
F
.38649 .90213 m .38083 .9006 L .3722 .89982 L .297 0 0 r
F
.40089 .90344 m .38649 .90213 L .3922 .90358 L .325 0 0 r
F
.40598 .90469 m .40089 .90344 L .3922 .90358 L .314 0 0 r
F
.49405 .92982 m .48741 .93111 L .48553 .93069 L .213 .176 0 r
F
.49405 .92982 m .4969 .93019 L .48741 .93111 L F
.54729 .69643 m .55147 .69392 L .54524 .68907 L .872 .058 0 r
F
.54104 .69128 m .54729 .69643 L .54524 .68907 L .956 .072 0 r
F
.87228 .57894 m .88194 .59067 L .88009 .59759 L 1 .515 0 r
F
.87228 .57894 m .87363 .57179 L .88194 .59067 L F
.58204 .91427 m .58069 .91642 L .57425 .9176 L .363 .2 0 r
F
.58204 .91427 m .589 .91291 L .58069 .91642 L F
.71197 .63388 m .71797 .63932 L .71473 .64338 L 1 .83 0 r
F
.71197 .63388 m .71515 .6296 L .71797 .63932 L F
.30818 .89373 m .29311 .88632 L .29995 .88912 L 0 .093 0 r
F
.31472 .89618 m .30818 .89373 L .29995 .88912 L 0 .098 0 r
F
.56891 .88975 m .56899 .89521 L .56263 .89529 L .631 .868 0 r
F
.56891 .88975 m .57583 .88989 L .56899 .89521 L F
.41274 .92059 m .39834 .91875 L .4037 .91946 L 0 .123 0 r
F
.41739 .92103 m .41274 .92059 L .4037 .91946 L 0 .128 0 r
F
.51943 .90297 m .52465 .90379 L .51687 .90811 L .763 .981 0 r
F
.40867 .81187 m .39767 .81581 L .40124 .82634 L 1 .534 0 r
F
.41192 .82316 m .40867 .81187 L .40124 .82634 L 1 .524 0 r
F
.71407 .83032 m .7204 .82625 L .71547 .83476 L .639 .363 0 r
F
.72855 .83756 m .72923 .8416 L .72301 .8457 L .606 .226 0 r
F
.72855 .83756 m .73497 .83321 L .72923 .8416 L F
.8053 .74013 m .80837 .74729 L .80367 .75289 L .81 .452 0 r
F
.8053 .74013 m .81003 .73425 L .80837 .74729 L F
.31967 .88305 m .30499 .87711 L .31163 .87989 L .278 0 0 r
F
.32598 .88553 m .31967 .88305 L .31163 .87989 L .26 0 0 r
F
.45006 .93151 m .44795 .93184 L .4385 .9313 L .085 .153 0 r
F
.45884 .9317 m .44795 .93184 L .45006 .93151 L .098 .156 0 r
F
.53133 .89863 m .52983 .90437 L .52465 .90379 L .792 1 0 r
F
.53133 .89863 m .53722 .89945 L .52983 .90437 L F
.70871 .63811 m .71473 .64338 L .71139 .64737 L 1 .837 0 r
F
.70871 .63811 m .71197 .63388 L .71473 .64338 L F
.48603 .72101 m .49521 .7802 L .49662 .80308 L .26 .048 0 r
F
.48603 .72745 m .49418 .76804 L .48536 .71077 L 1 .187 0 r
F
.65614 .88025 m .6563 .8832 L .64957 .88587 L .49 .216 0 r
F
.65614 .88025 m .66318 .87737 L .6563 .8832 L F
.89829 .57739 m .90275 .5885 L .90071 .5957 L .89 .215 0 r
F
.89829 .57739 m .90036 .56997 L .90275 .5885 L F
.30592 .89946 m .29063 .89197 L .29761 .8947 L 0 .098 0 r
F
.31258 .90185 m .30592 .89946 L .29761 .8947 L 0 .103 0 r
F
.41198 .92628 m .39742 .92424 L .40288 .92482 L 0 .132 0 r
F
.41671 .92658 m .41198 .92628 L .40288 .92482 L .006 .138 0 r
F
.42587 .9276 m .41198 .92628 L .41671 .92658 L 0 .136 0 r
F
.82242 .74353 m .82421 .75022 L .81945 .75606 L .767 .277 0 r
F
.82242 .74353 m .8273 .73743 L .82421 .75022 L F
.42979 .92765 m .42587 .9276 L .41671 .92658 L .028 .143 0 r
F
.64302 .86939 m .64391 .87301 L .63721 .8752 L .53 .391 0 r
F
.64302 .86939 m .65001 .86699 L .64391 .87301 L F
.4227 .81747 m .41192 .82316 L .41549 .83461 L 1 .471 0 r
F
.42584 .83019 m .4227 .81747 L .41549 .83461 L 1 .462 0 r
F
.55328 .91311 m .55177 .91586 L .54586 .91634 L .431 .356 0 r
F
.55328 .91311 m .55979 .91254 L .55177 .91586 L F
.6077 .89882 m .60746 .90159 L .60074 .90322 L .441 .246 0 r
F
.6077 .89882 m .61484 .89706 L .60746 .90159 L F
.34989 .90806 m .3347 .90285 L .34148 .90484 L 0 .107 0 r
F
.35626 .90972 m .34989 .90806 L .34148 .90484 L 0 .112 0 r
F
.46468 .90989 m .4634 .72486 L .46139 .77493 L 1 .576 0 r
F
.55348 .70063 m .55769 .69804 L .55147 .69392 L .77 .04 0 r
F
.54729 .69643 m .55348 .70063 L .55147 .69392 L .872 .058 0 r
F
.87073 .58607 m .88009 .59759 L .87809 .60449 L 1 .53 0 r
F
.87073 .58607 m .87228 .57894 L .88009 .59759 L F
.37772 .915 m .36268 .91127 L .36915 .91269 L 0 .115 0 r
F
.38367 .91612 m .37772 .915 L .36915 .91269 L 0 .12 0 r
F
.70536 .64226 m .71139 .64737 L .70796 .65129 L 1 .843 0 r
F
.70536 .64226 m .70871 .63811 L .71139 .64737 L F
.50216 .92869 m .4969 .93019 L .49405 .92982 L .253 .183 0 r
F
.50216 .92869 m .50592 .929 L .4969 .93019 L F
.59542 .88389 m .59619 .88834 L .58947 .88915 L .531 .662 0 r
F
.59542 .88389 m .60258 .8831 L .59619 .88834 L F
.65885 .88612 m .65894 .88894 L .65214 .89173 L .483 .215 0 r
F
.65885 .88612 m .66595 .88311 L .65894 .88894 L F
.39834 .91875 m .38367 .91612 L .38966 .91712 L 0 .12 0 r
F
.4037 .91946 m .39834 .91875 L .38966 .91712 L 0 .125 0 r
F
.50795 .90663 m .50456 .91121 L .50091 .91052 L .714 .915 0 r
F
.34832 .91359 m .33294 .90828 L .33985 .91018 L 0 .114 0 r
F
.3548 .91516 m .34832 .91359 L .33985 .91018 L 0 .119 0 r
F
.55464 .92028 m .55296 .92231 L .54699 .92291 L .345 .197 0 r
F
.55464 .92028 m .56122 .91954 L .55296 .92231 L F
.60993 .90567 m .60952 .90799 L .60274 .90977 L .409 .207 0 r
F
.60993 .90567 m .61712 .90368 L .60952 .90799 L F
.80044 .74592 m .80367 .75289 L .79886 .75841 L .806 .471 0 r
F
.80044 .74592 m .8053 .74013 L .80367 .75289 L F
.3944 .80542 m .38376 .80748 L .38726 .81743 L 1 .581 0 r
F
.39767 .81581 m .3944 .80542 L .38726 .81743 L 1 .57 0 r
F
.35988 .89621 m .34529 .89242 L .35185 .89453 L .279 0 0 r
F
.36601 .89806 m .35988 .89621 L .35185 .89453 L .263 0 0 r
F
.70192 .64636 m .70796 .65129 L .70444 .65513 L 1 .848 0 r
F
.70192 .64636 m .70536 .64226 L .70796 .65129 L F
.37654 .92046 m .36133 .9166 L .36791 .91792 L 0 .122 0 r
F
.38259 .92146 m .37654 .92046 L .36791 .91792 L 0 .128 0 r
F
.41938 .9048 m .40598 .90469 L .41113 .90589 L .321 0 0 r
F
.42382 .90585 m .41938 .9048 L .41113 .90589 L .316 0 0 r
F
.43201 .90383 m .41938 .9048 L .42382 .90585 L .302 0 0 r
F
.57328 .90808 m .57268 .91094 L .56626 .91182 L .443 .356 0 r
F
.57328 .90808 m .58022 .90712 L .57268 .91094 L F
.5213 .91949 m .51834 .92191 L .51379 .92177 L .403 .323 0 r
F
.5213 .91949 m .52663 .91955 L .51834 .92191 L F
.72203 .8418 m .72301 .8457 L .7167 .8497 L .604 .244 0 r
F
.72203 .8418 m .72855 .83756 L .72301 .8457 L F
.54327 .89365 m .54307 .9 L .53722 .89945 L .796 1 0 r
F
.54327 .89365 m .54976 .89453 L .54307 .9 L F
.43567 .90479 m .43201 .90383 L .42382 .90585 L .299 0 0 r
F
.39742 .92424 m .38259 .92146 L .38868 .92234 L 0 .129 0 r
F
.40288 .92482 m .39742 .92424 L .38868 .92234 L 0 .135 0 r
F
.89609 .58478 m .90071 .5957 L .89853 .60287 L .893 .243 0 r
F
.89609 .58478 m .89829 .57739 L .90071 .5957 L F
.81743 .74956 m .81945 .75606 L .81457 .76183 L .766 .3 0 r
F
.81743 .74956 m .82242 .74353 L .81945 .75606 L F
.31472 .89618 m .29995 .88912 L .30686 .8918 L 0 .098 0 r
F
.32131 .89852 m .31472 .89618 L .30686 .8918 L 0 .103 0 r
F
.44501 .81321 m .43581 .8232 L .43878 .83824 L .83 .306 0 r
F
.53394 .91684 m .53191 .91945 L .52663 .91955 L .428 .376 0 r
F
.53394 .91684 m .53992 .91666 L .53191 .91945 L F
.55959 .70398 m .56385 .70145 L .55769 .69804 L .648 .02 0 r
F
.55348 .70063 m .55959 .70398 L .55769 .69804 L .77 .04 0 r
F
.6984 .65038 m .70444 .65513 L .70083 .6589 L .999 .85 0 r
F
.6984 .65038 m .70192 .64636 L .70444 .65513 L F
.64902 .88299 m .64957 .88587 L .64276 .8884 L .49 .222 0 r
F
.64902 .88299 m .65614 .88025 L .64957 .88587 L F
.38649 .90213 m .3722 .89982 L .37844 .9015 L .297 0 0 r
F
.3922 .90358 m .38649 .90213 L .37844 .9015 L .286 0 0 r
F
.56193 .88919 m .56263 .89529 L .55622 .89506 L .699 .942 0 r
F
.56193 .88919 m .56891 .88975 L .56263 .89529 L F
.86899 .59319 m .87809 .60449 L .87596 .61137 L 1 .546 0 r
F
.86899 .59319 m .87073 .58607 L .87809 .60449 L F
.32598 .88553 m .31163 .87989 L .31833 .88258 L .26 0 0 r
F
.33235 .88792 m .32598 .88553 L .31833 .88258 L 0 .082 0 r
F
.45006 .93151 m .4385 .9313 L .44157 .93105 L .085 .153 0 r
F
.63595 .87159 m .63721 .8752 L .63044 .87721 L .529 .432 0 r
F
.63595 .87159 m .64302 .86939 L .63721 .8752 L F
.52202 .9258 m .51894 .92761 L .51435 .92753 L .31 .191 0 r
F
.52202 .9258 m .52741 .92577 L .51894 .92761 L F
.57504 .91547 m .57425 .9176 L .56776 .91864 L .374 .201 0 r
F
.57504 .91547 m .58204 .91427 L .57425 .9176 L F
.31258 .90185 m .29761 .8947 L .30466 .89731 L 0 .103 0 r
F
.3193 .90412 m .31258 .90185 L .30466 .89731 L 0 .108 0 r
F
.40598 .90469 m .3922 .90358 L .39797 .90496 L .314 0 0 r
F
.41113 .90589 m .40598 .90469 L .39797 .90496 L .307 0 0 r
F
.50922 .92149 m .51379 .92177 L .50552 .92373 L .384 .286 0 r
F
.53491 .92367 m .53276 .92559 L .52741 .92577 L .333 .195 0 r
F
.53491 .92367 m .54097 .92336 L .53276 .92559 L F
.79548 .75164 m .79886 .75841 L .79393 .76385 L .802 .489 0 r
F
.79548 .75164 m .80044 .74592 L .79886 .75841 L F
.69479 .65433 m .70083 .6589 L .69714 .66259 L .986 .851 0 r
F
.69479 .65433 m .6984 .65038 L .70083 .6589 L F
.6005 .90041 m .60074 .90322 L .59395 .90468 L .451 .303 0 r
F
.6005 .90041 m .6077 .89882 L .60074 .90322 L F
.65168 .88901 m .65214 .89173 L .64527 .89438 L .483 .216 0 r
F
.65168 .88901 m .65885 .88612 L .65214 .89173 L F
.50526 .70315 m .51651 .74001 L .51303 .74964 L 1 .655 0 r
F
.50463 .72991 m .50526 .70315 L .51303 .74964 L 1 .695 0 r
F
.43581 .8232 m .42584 .83019 L .42933 .8431 L .943 .395 0 r
F
.43878 .83824 m .43581 .8232 L .42933 .8431 L .939 .387 0 r
F
.4679 .93107 m .46778 .93163 L .45884 .9317 L .156 .166 0 r
F
.47583 .93072 m .46778 .93163 L .4679 .93107 L .183 .171 0 r
F
.47583 .93072 m .47672 .9313 L .46778 .93163 L F
.58818 .88433 m .58947 .88915 L .58268 .88968 L .543 .748 0 r
F
.58818 .88433 m .59542 .88389 L .58947 .88915 L F
.81232 .75551 m .81457 .76183 L .80958 .76751 L .764 .324 0 r
F
.81232 .75551 m .81743 .74956 L .81457 .76183 L F
.45212 .76835 m .44834 .74351 L .44876 .80466 L 1 .71 0 r
F
.89375 .59215 m .89853 .60287 L .89622 .61001 L .896 .271 0 r
F
.89375 .59215 m .89609 .58478 L .89853 .60287 L F
.71542 .84592 m .72203 .8418 L .7167 .8497 L .601 .264 0 r
F
.46007 .92776 m .45894 .92824 L .45021 .9283 L .135 .163 0 r
F
.48363 .93013 m .47672 .9313 L .47583 .93072 L .215 .176 0 r
F
.48363 .93013 m .48553 .93069 L .47672 .9313 L F
.35626 .90972 m .34148 .90484 L .34833 .90671 L 0 .112 0 r
F
.36268 .91127 m .35626 .90972 L .34833 .90671 L 0 .117 0 r
F
.56561 .70657 m .56995 .7042 L .56385 .70145 L .542 0 0 r
F
.55959 .70398 m .56561 .70657 L .56385 .70145 L .648 .02 0 r
F
.50972 .9273 m .50592 .929 L .50216 .92869 L .296 .189 0 r
F
.50972 .9273 m .51435 .92753 L .50592 .929 L F
.69109 .6582 m .69714 .66259 L .69335 .6662 L .971 .85 0 r
F
.69109 .6582 m .69479 .65433 L .69714 .66259 L F
.49725 .90965 m .50091 .91052 L .49324 .91371 L .649 .82 0 r
F
.52541 .89752 m .52465 .90379 L .51943 .90297 L .875 1 0 r
F
.52541 .89752 m .53133 .89863 L .52465 .90379 L F
.41739 .92103 m .4037 .91946 L .40912 .92005 L 0 .128 0 r
F
.42208 .92135 m .41739 .92103 L .40912 .92005 L 0 .133 0 r
F
.86706 .60028 m .87596 .61137 L .87369 .61822 L 1 .562 0 r
F
.86706 .60028 m .86899 .59319 L .87596 .61137 L F
.45998 .93118 m .45884 .9317 L .45006 .93151 L .136 .162 0 r
F
.4679 .93107 m .45884 .9317 L .45998 .93118 L .156 .166 0 r
F
.41192 .82316 m .40124 .82634 L .40517 .83686 L 1 .524 0 r
F
.41549 .83461 m .41192 .82316 L .40517 .83686 L 1 .51 0 r
F
.60267 .9075 m .60274 .90977 L .5959 .91141 L .414 .207 0 r
F
.60267 .9075 m .60993 .90567 L .60274 .90977 L F
.54673 .91352 m .54586 .91634 L .53992 .91666 L .457 .446 0 r
F
.54673 .91352 m .55328 .91311 L .54586 .91634 L F
.68731 .662 m .69335 .6662 L .68948 .66972 L .955 .847 0 r
F
.68731 .662 m .69109 .6582 L .69335 .6662 L F
.3548 .91516 m .33985 .91018 L .34682 .91196 L 0 .119 0 r
F
.36133 .9166 m .3548 .91516 L .34682 .91196 L 0 .124 0 r
F
.32131 .89852 m .30686 .8918 L .31384 .89437 L 0 .103 0 r
F
.32797 .90075 m .32131 .89852 L .31384 .89437 L 0 .108 0 r
F
.38367 .91612 m .36915 .91269 L .37568 .91401 L 0 .12 0 r
F
.38966 .91712 m .38367 .91612 L .37568 .91401 L 0 .125 0 r
F
.7904 .75728 m .79393 .76385 L .7889 .76921 L .798 .507 0 r
F
.7904 .75728 m .79548 .75164 L .79393 .76385 L F
.6288 .87359 m .63044 .87721 L .62359 .87903 L .528 .476 0 r
F
.6288 .87359 m .63595 .87159 L .63044 .87721 L F
.49119 .92929 m .48553 .93069 L .48363 .93013 L .25 .182 0 r
F
.49119 .92929 m .49405 .92982 L .48553 .93069 L F
.64184 .88558 m .64276 .8884 L .63588 .89079 L .49 .252 0 r
F
.64184 .88558 m .64902 .88299 L .64276 .8884 L F
.36601 .89806 m .35185 .89453 L .35847 .89656 L .263 0 0 r
F
.3722 .89982 m .36601 .89806 L .35847 .89656 L .249 0 0 r
F
.41671 .92658 m .40288 .92482 L .40837 .92528 L .006 .138 0 r
F
.42147 .92676 m .41671 .92658 L .40837 .92528 L .037 .143 0 r
F
.42979 .92765 m .41671 .92658 L .42147 .92676 L .028 .143 0 r
F
.57153 .70849 m .57597 .70636 L .56995 .7042 L .451 0 0 r
F
.56561 .70657 m .57153 .70849 L .56995 .7042 L .542 0 0 r
F
.33235 .88792 m .31833 .88258 L .32509 .88517 L 0 .082 0 r
F
.33879 .89022 m .33235 .88792 L .32509 .88517 L 0 .086 0 r
F
.56629 .90888 m .56626 .91182 L .55979 .91254 L .464 .439 0 r
F
.56629 .90888 m .57328 .90808 L .56626 .91182 L F
.68345 .66571 m .68948 .66972 L .68552 .67315 L .936 .842 0 r
F
.68345 .66571 m .68731 .662 L .68948 .66972 L F
.46007 .92776 m .45021 .9283 L .45233 .92789 L .135 .163 0 r
F
.80711 .76137 m .80958 .76751 L .80447 .77311 L .762 .346 0 r
F
.80711 .76137 m .81232 .75551 L .80958 .76751 L F
.69454 .84181 m .69671 .84583 L .69029 .84927 L .625 .423 0 r
F
.69454 .84181 m .70113 .8381 L .69671 .84583 L F
.4037 .91946 m .38966 .91712 L .39571 .91801 L 0 .125 0 r
F
.40912 .92005 m .4037 .91946 L .39571 .91801 L 0 .13 0 r
F
.39767 .81581 m .38726 .81743 L .39109 .8274 L 1 .57 0 r
F
.40124 .82634 m .39767 .81581 L .39109 .8274 L 1 .554 0 r
F
.548 .92088 m .54699 .92291 L .54097 .92336 L .363 .202 0 r
F
.548 .92088 m .55464 .92028 L .54699 .92291 L F
.89127 .5995 m .89622 .61001 L .89377 .61713 L .898 .3 0 r
F
.89127 .5995 m .89375 .59215 L .89622 .61001 L F
.38259 .92146 m .36791 .91792 L .37455 .91912 L 0 .128 0 r
F
.38868 .92234 m .38259 .92146 L .37455 .91912 L 0 .133 0 r
F
.53675 .89241 m .53722 .89945 L .53133 .89863 L .867 1 0 r
F
.53675 .89241 m .54327 .89365 L .53722 .89945 L F
.3193 .90412 m .30466 .89731 L .31177 .8998 L 0 .108 0 r
F
.32609 .90626 m .3193 .90412 L .31177 .8998 L 0 .113 0 r
F
.43375 .92757 m .42979 .92765 L .42147 .92676 L .06 .148 0 r
F
.55489 .88818 m .55622 .89506 L .54976 .89453 L .764 .988 0 r
F
.55489 .88818 m .56193 .88919 L .55622 .89506 L F
.42584 .83019 m .41549 .83461 L .41943 .84601 L 1 .462 0 r
F
.42933 .8431 m .42584 .83019 L .41943 .84601 L 1 .449 0 r
F
.45219 .93105 m .45006 .93151 L .44157 .93105 L .122 .16 0 r
F
.45998 .93118 m .45006 .93151 L .45219 .93105 L .136 .162 0 r
F
.64443 .89176 m .64527 .89438 L .63833 .89691 L .482 .216 0 r
F
.64443 .89176 m .65168 .88901 L .64527 .89438 L F
.6795 .66933 m .68552 .67315 L .68147 .67648 L .916 .834 0 r
F
.6795 .66933 m .68345 .66571 L .68552 .67315 L F
.86495 .60735 m .87369 .61822 L .87128 .62505 L 1 .579 0 r
F
.86495 .60735 m .86706 .60028 L .87369 .61822 L F
.57736 .70982 m .58191 .70796 L .57597 .70636 L .347 0 0 r
F
.57153 .70849 m .57736 .70982 L .57597 .70636 L .451 0 0 r
F
.59323 .90182 m .59395 .90468 L .58711 .90598 L .462 .368 0 r
F
.59323 .90182 m .6005 .90041 L .59395 .90468 L F
.3922 .90358 m .37844 .9015 L .38474 .90311 L .286 0 0 r
F
.39797 .90496 m .3922 .90358 L .38474 .90311 L .276 0 0 r
F
.56798 .91652 m .56776 .91864 L .56122 .91954 L .386 .21 0 r
F
.56798 .91652 m .57504 .91547 L .56776 .91864 L F
.58084 .88433 m .58268 .88968 L .57583 .88989 L .587 .827 0 r
F
.58084 .88433 m .58818 .88433 L .58268 .88968 L F
.40288 .92482 m .38868 .92234 L .39482 .9231 L 0 .135 0 r
F
.40837 .92528 m .40288 .92482 L .39482 .9231 L .026 .14 0 r
F
.7852 .76283 m .7889 .76921 L .78376 .77449 L .797 .524 0 r
F
.7852 .76283 m .7904 .75728 L .7889 .76921 L F
.50345 .90556 m .50795 .90663 L .50091 .91052 L .827 1 0 r
F
.67547 .67286 m .68147 .67648 L .67734 .6797 L .894 .823 0 r
F
.67547 .67286 m .6795 .66933 L .68147 .67648 L F
.48603 .72745 m .4938 .76942 L .49418 .76804 L 1 .187 0 r
F
.42382 .90585 m .41113 .90589 L .41632 .90703 L .316 0 0 r
F
.4283 .90687 m .42382 .90585 L .41632 .90703 L .314 0 0 r
F
.43567 .90479 m .42382 .90585 L .4283 .90687 L .299 0 0 r
F
.4874 .74758 m .49777 .82965 L .4891 .7863 L .459 .097 0 r
F
.49837 .92823 m .49405 .92982 L .49119 .92929 L .289 .187 0 r
F
.49837 .92823 m .50216 .92869 L .49405 .92982 L F
.52792 .91687 m .52663 .91955 L .5213 .91949 L .459 .474 0 r
F
.52792 .91687 m .53394 .91684 L .52663 .91955 L F
.51595 .91928 m .51379 .92177 L .50922 .92149 L .44 .429 0 r
F
.51595 .91928 m .5213 .91949 L .51379 .92177 L F
.62157 .87535 m .62359 .87903 L .61666 .88063 L .527 .522 0 r
F
.62157 .87535 m .6288 .87359 L .62359 .87903 L F
.67135 .6763 m .67734 .6797 L .67311 .68282 L .87 .809 0 r
F
.67135 .6763 m .67547 .67286 L .67734 .6797 L F
.80178 .76715 m .80447 .77311 L .79926 .77863 L .76 .368 0 r
F
.80178 .76715 m .80711 .76137 L .80447 .77311 L F
.36268 .91127 m .34833 .90671 L .35523 .90847 L 0 .117 0 r
F
.36915 .91269 m .36268 .91127 L .35523 .90847 L 0 .122 0 r
F
.5831 .71061 m .58775 .70906 L .58191 .70796 L .232 0 0 r
F
.57736 .70982 m .5831 .71061 L .58191 .70796 L .347 0 0 r
F
.43936 .90574 m .43567 .90479 L .4283 .90687 L .3 0 0 r
F
.63458 .88802 m .63588 .89079 L .62894 .89303 L .491 .285 0 r
F
.63458 .88802 m .64184 .88558 L .63588 .89079 L F
.68786 .84538 m .69029 .84927 L .68378 .85258 L .619 .441 0 r
F
.68786 .84538 m .69454 .84181 L .69029 .84927 L F
.88866 .60682 m .89377 .61713 L .89118 .62421 L .902 .329 0 r
F
.88866 .60682 m .89127 .5995 L .89377 .61713 L F
.59536 .90919 m .5959 .91141 L .589 .91291 L .419 .212 0 r
F
.59536 .90919 m .60267 .9075 L .5959 .91141 L F
.32797 .90075 m .31384 .89437 L .32088 .89682 L 0 .108 0 r
F
.3347 .90285 m .32797 .90075 L .32088 .89682 L 0 .112 0 r
F
.41113 .90589 m .39797 .90496 L .40379 .90628 L .307 0 0 r
F
.41632 .90703 m .41113 .90589 L .40379 .90628 L .303 0 0 r
F
.66715 .67963 m .67311 .68282 L .6688 .68582 L .842 .791 0 r
F
.66715 .67963 m .67135 .6763 L .67311 .68282 L F
.70196 .85383 m .70381 .85734 L .69724 .86099 L .595 .306 0 r
F
.70196 .85383 m .70873 .84993 L .70381 .85734 L F
.86268 .6144 m .87128 .62505 L .86874 .63185 L 1 .595 0 r
F
.86268 .6144 m .86495 .60735 L .87128 .62505 L F
.5166 .92569 m .51435 .92753 L .50972 .9273 L .338 .204 0 r
F
.5166 .92569 m .52202 .9258 L .51435 .92753 L F
.52882 .92383 m .52741 .92577 L .52202 .9258 L .356 .224 0 r
F
.52882 .92383 m .53491 .92367 L .52741 .92577 L F
.33879 .89022 m .32509 .88517 L .33192 .88767 L 0 .086 0 r
F
.34529 .89242 m .33879 .89022 L .33192 .88767 L 0 .09 0 r
F
.58874 .71094 m .59351 .70971 L .58775 .70906 L .112 0 0 r
F
.5831 .71061 m .58874 .71094 L .58775 .70906 L .232 0 0 r
F
.36133 .9166 m .34682 .91196 L .35384 .91361 L 0 .124 0 r
F
.36791 .91792 m .36133 .9166 L .35384 .91361 L 0 .129 0 r
F
.7799 .7683 m .78376 .77449 L .7785 .77968 L .794 .541 0 r
F
.7799 .7683 m .7852 .76283 L .78376 .77449 L F
.66288 .68285 m .6688 .68582 L .66441 .6887 L .812 .769 0 r
F
.66288 .68285 m .66715 .67963 L .6688 .68582 L F
.3722 .89982 m .35847 .89656 L .36514 .8985 L .249 0 0 r
F
.37844 .9015 m .3722 .89982 L .36514 .8985 L .236 0 0 r
F
.45219 .93105 m .44157 .93105 L .44467 .93068 L .122 .16 0 r
F
.63713 .89438 m .63833 .89691 L .63133 .8993 L .482 .233 0 r
F
.63713 .89438 m .64443 .89176 L .63833 .89691 L F
.32609 .90626 m .31177 .8998 L .31894 .90216 L 0 .113 0 r
F
.33294 .90828 m .32609 .90626 L .31894 .90216 L 0 .118 0 r
F
.65852 .68595 m .66441 .6887 L .65992 .69145 L .779 .741 0 r
F
.65852 .68595 m .66288 .68285 L .66441 .6887 L F
.51948 .89608 m .51943 .90297 L .51418 .9019 L .951 1 0 r
F
.51948 .89608 m .52541 .89752 L .51943 .90297 L F
.54014 .91379 m .53992 .91666 L .53394 .91684 L .483 .536 0 r
F
.54014 .91379 m .54673 .91352 L .53992 .91666 L F
.59429 .71085 m .59917 .70995 L .59351 .70971 L 0 0 0 r
F
.58874 .71094 m .59429 .71085 L .59351 .70971 L .112 0 0 r
F
.38966 .91712 m .37568 .91401 L .38226 .9152 L 0 .125 0 r
F
.39571 .91801 m .38966 .91712 L .38226 .9152 L 0 .13 0 r
F
.70512 .85895 m .70697 .86247 L .70034 .8662 L .596 .299 0 r
F
.70512 .85895 m .71196 .85496 L .70697 .86247 L F
.55926 .90952 m .55979 .91254 L .55328 .91311 L .485 .524 0 r
F
.55926 .90952 m .56629 .90888 L .55979 .91254 L F
.79634 .77285 m .79926 .77863 L .79393 .78406 L .757 .39 0 r
F
.79634 .77285 m .80178 .76715 L .79926 .77863 L F
.54781 .88668 m .54976 .89453 L .54327 .89365 L .824 1 0 r
F
.54781 .88668 m .55489 .88818 L .54976 .89453 L F
.65407 .68893 m .65992 .69145 L .65535 .69407 L .741 .708 0 r
F
.65407 .68893 m .65852 .68595 L .65992 .69145 L F
.57342 .88381 m .57583 .88989 L .56891 .88975 L .636 .887 0 r
F
.57342 .88381 m .58084 .88433 L .57583 .88989 L F
.68109 .84882 m .68378 .85258 L .67719 .85576 L .614 .459 0 r
F
.68109 .84882 m .68786 .84538 L .68378 .85258 L F
.88591 .6141 m .89118 .62421 L .88846 .63126 L .911 .357 0 r
F
.88591 .6141 m .88866 .60682 L .89118 .62421 L F
.59975 .71039 m .60473 .70982 L .59917 .70995 L .12 .161 0 r
F
.59429 .71085 m .59975 .71039 L .59917 .70995 L 0 0 0 r
F
.42208 .92135 m .40912 .92005 L .41457 .92055 L 0 .133 0 r
F
.42681 .92158 m .42208 .92135 L .41457 .92055 L 0 .137 0 r
F
.58591 .90304 m .58711 .90598 L .58022 .90712 L .475 .439 0 r
F
.58591 .90304 m .59323 .90182 L .58711 .90598 L F
.41549 .83461 m .40517 .83686 L .40947 .8472 L 1 .51 0 r
F
.41943 .84601 m .41549 .83461 L .40947 .8472 L 1 .49 0 r
F
.61426 .87684 m .61666 .88063 L .60966 .882 L .526 .572 0 r
F
.61426 .87684 m .62157 .87535 L .61666 .88063 L F
.45317 .84561 m .45212 .76835 L .44876 .80466 L 1 .673 0 r
F
.45579 .81145 m .45212 .76835 L .45317 .84561 L 1 .629 0 r
F
.64955 .69178 m .65535 .69407 L .65069 .69653 L .7 .668 0 r
F
.64955 .69178 m .65407 .68893 L .65535 .69407 L F
.5302 .89079 m .53133 .89863 L .52541 .89752 L .93 1 0 r
F
.5302 .89079 m .53675 .89241 L .53133 .89863 L F
.50892 .90052 m .50795 .90663 L .50345 .90556 L .953 1 0 r
F
.86023 .62141 m .86874 .63185 L .86606 .63861 L 1 .612 0 r
F
.86023 .62141 m .86268 .6144 L .86874 .63185 L F
.50505 .92693 m .50216 .92869 L .49837 .92823 L .328 .2 0 r
F
.50505 .92693 m .50972 .9273 L .50216 .92869 L F
.38868 .92234 m .37455 .91912 L .38124 .92019 L 0 .133 0 r
F
.39482 .9231 m .38868 .92234 L .38124 .92019 L .027 .138 0 r
F
.60511 .7096 m .61021 .70935 L .60473 .70982 L .222 .178 0 r
F
.59975 .71039 m .60511 .7096 L .60473 .70982 L .12 .161 0 r
F
.6951 .8576 m .69724 .86099 L .69059 .86452 L .592 .326 0 r
F
.6951 .8576 m .70196 .85383 L .69724 .86099 L F
.40124 .82634 m .39109 .8274 L .39529 .83724 L 1 .554 0 r
F
.40517 .83686 m .40124 .82634 L .39529 .83724 L 1 .532 0 r
F
.64494 .69449 m .65069 .69653 L .64594 .69883 L .665 .619 0 r
F
.64494 .69449 m .64955 .69178 L .65069 .69653 L F
.62726 .8903 m .62894 .89303 L .62192 .89512 L .491 .32 0 r
F
.62726 .8903 m .63458 .88802 L .62894 .89303 L F
.77449 .77368 m .7785 .77968 L .77315 .78477 L .792 .556 0 r
F
.77449 .77368 m .7799 .7683 L .7785 .77968 L F
.54133 .92133 m .54097 .92336 L .53491 .92367 L .381 .262 0 r
F
.54133 .92133 m .548 .92088 L .54097 .92336 L F
.64026 .69705 m .64594 .69883 L .64111 .70097 L .635 .562 0 r
F
.64026 .69705 m .64494 .69449 L .64594 .69883 L F
.61039 .70851 m .61558 .70858 L .61021 .70935 L .312 .193 0 r
F
.60511 .7096 m .61039 .70851 L .61021 .70935 L .222 .178 0 r
F
.56088 .91742 m .56122 .91954 L .55464 .92028 L .399 .262 0 r
F
.56088 .91742 m .56798 .91652 L .56122 .91954 L F
.46802 .93037 m .4679 .93107 L .45998 .93118 L .194 .172 0 r
F
.47493 .93001 m .4679 .93107 L .46802 .93037 L .222 .177 0 r
F
.47493 .93001 m .47583 .93072 L .4679 .93107 L F
.40912 .92005 m .39571 .91801 L .4018 .91879 L 0 .13 0 r
F
.41457 .92055 m .40912 .92005 L .4018 .91879 L 0 .135 0 r
F
.4612 .92717 m .46007 .92776 L .45233 .92789 L .171 .169 0 r
F
.63549 .69945 m .64111 .70097 L .63618 .70292 L .6 .493 0 r
F
.63549 .69945 m .64026 .69705 L .64111 .70097 L F
.48173 .92943 m .47583 .93072 L .47493 .93001 L .253 .182 0 r
F
.48173 .92943 m .48363 .93013 L .47583 .93072 L F
.61558 .70715 m .62087 .70752 L .61558 .70858 L .389 .204 0 r
F
.61039 .70851 m .61558 .70715 L .61558 .70858 L .312 .193 0 r
F
.42147 .92676 m .40837 .92528 L .41392 .92562 L .037 .143 0 r
F
.42628 .92682 m .42147 .92676 L .41392 .92562 L .066 .148 0 r
F
.43375 .92757 m .42147 .92676 L .42628 .92682 L .06 .148 0 r
F
.3347 .90285 m .32088 .89682 L .32798 .89915 L 0 .112 0 r
F
.34148 .90484 m .3347 .90285 L .32798 .89915 L 0 .117 0 r
F
.43878 .83824 m .42933 .8431 L .43323 .85585 L .939 .387 0 r
F
.44216 .85341 m .43878 .83824 L .43323 .85585 L .933 .373 0 r
F
.39797 .90496 m .38474 .90311 L .3911 .90464 L .276 0 0 r
F
.40379 .90628 m .39797 .90496 L .3911 .90464 L .269 0 0 r
F
.63064 .70167 m .63618 .70292 L .63117 .70468 L .559 .413 0 r
F
.63064 .70167 m .63549 .69945 L .63618 .70292 L F
.61558 .70715 m .62068 .70554 L .62087 .70752 L .389 .204 0 r
F
.6257 .70371 m .63117 .70468 L .62607 .70622 L .511 .32 0 r
F
.6257 .70371 m .63064 .70167 L .63117 .70468 L F
.588 .91072 m .589 .91291 L .58204 .91427 L .424 .25 0 r
F
.588 .91072 m .59536 .90919 L .589 .91291 L F
.36915 .91269 m .35523 .90847 L .36219 .91011 L 0 .122 0 r
F
.37568 .91401 m .36915 .91269 L .36219 .91011 L 0 .127 0 r
F
.79079 .77846 m .79393 .78406 L .78849 .78941 L .754 .411 0 r
F
.79079 .77846 m .79634 .77285 L .79393 .78406 L F
.34529 .89242 m .33192 .88767 L .3388 .89007 L 0 .09 0 r
F
.35185 .89453 m .34529 .89242 L .3388 .89007 L 0 .093 0 r
F
.46112 .93052 m .45998 .93118 L .45219 .93105 L .172 .168 0 r
F
.46802 .93037 m .45998 .93118 L .46112 .93052 L .194 .172 0 r
F
.6982 .86282 m .70034 .8662 L .69362 .86983 L .593 .318 0 r
F
.6982 .86282 m .70512 .85895 L .70034 .8662 L F
.51651 .74001 m .53894 .83132 L .52949 .81542 L .738 .362 0 r
F
.51651 .74001 m .52482 .75717 L .53894 .83132 L F
.51303 .74964 m .51651 .74001 L .52949 .81542 L 1 .601 0 r
F
.62975 .89686 m .63133 .8993 L .62426 .90156 L .48 .257 0 r
F
.62975 .89686 m .63713 .89438 L .63133 .8993 L F
.40837 .92528 m .39482 .9231 L .40101 .92373 L .026 .14 0 r
F
.41392 .92562 m .40837 .92528 L .40101 .92373 L .054 .145 0 r
F
.50463 .72991 m .51303 .74964 L .50997 .76481 L 1 .695 0 r
F
.50273 .754 m .50463 .72991 L .50997 .76481 L 1 .72 0 r
F
.88302 .62136 m .88846 .63126 L .88561 .63827 L .92 .385 0 r
F
.88302 .62136 m .88591 .6141 L .88846 .63126 L F
.67425 .85211 m .67719 .85576 L .67051 .8588 L .607 .476 0 r
F
.67425 .85211 m .68109 .84882 L .67719 .85576 L F
.4883 .92863 m .48363 .93013 L .48173 .92943 L .288 .187 0 r
F
.4883 .92863 m .49119 .92929 L .48363 .93013 L F
.43773 .92737 m .43375 .92757 L .42628 .92682 L .09 .154 0 r
F
.85763 .6284 m .86606 .63861 L .86324 .64534 L 1 .629 0 r
F
.85763 .6284 m .86023 .62141 L .86606 .63861 L F
.33294 .90828 m .31894 .90216 L .32618 .90441 L 0 .118 0 r
F
.33985 .91018 m .33294 .90828 L .32618 .90441 L 0 .123 0 r
F
.76897 .77897 m .77315 .78477 L .76769 .78978 L .789 .572 0 r
F
.76897 .77897 m .77449 .77368 L .77315 .78477 L F
.36791 .91792 m .35384 .91361 L .36091 .91513 L 0 .129 0 r
F
.37455 .91912 m .36791 .91792 L .36091 .91513 L .017 .134 0 r
F
.60686 .87802 m .60966 .882 L .60258 .8831 L .525 .626 0 r
F
.60686 .87802 m .61426 .87684 L .60966 .882 L F
.4612 .92717 m .45233 .92789 L .45446 .92737 L .171 .169 0 r
F
.52186 .91674 m .5213 .91949 L .51595 .91928 L .491 .575 0 r
F
.52186 .91674 m .52792 .91687 L .5213 .91949 L F
.37844 .9015 m .36514 .8985 L .37188 .90035 L .236 0 0 r
F
.38474 .90311 m .37844 .9015 L .37188 .90035 L .225 0 0 r
F
.68817 .86125 m .69059 .86452 L .68385 .86792 L .588 .346 0 r
F
.68817 .86125 m .6951 .8576 L .69059 .86452 L F
.4283 .90687 m .41632 .90703 L .42156 .90814 L .314 0 0 r
F
.43283 .90788 m .4283 .90687 L .42156 .90814 L .318 0 0 r
F
.43936 .90574 m .4283 .90687 L .43283 .90788 L .3 0 0 r
F
.56591 .88266 m .56891 .88975 L .56193 .88919 L .685 .919 0 r
F
.56591 .88266 m .57342 .88381 L .56891 .88975 L F
.42933 .8431 m .41943 .84601 L .42378 .85714 L 1 .449 0 r
F
.43323 .85585 m .42933 .8431 L .42378 .85714 L 1 .429 0 r
F
.5407 .88468 m .54327 .89365 L .53675 .89241 L .879 .995 0 r
F
.5407 .88468 m .54781 .88668 L .54327 .89365 L F
.41632 .90703 m .40379 .90628 L .40966 .90754 L .303 0 0 r
F
.42156 .90814 m .41632 .90703 L .40966 .90754 L F
.45434 .93045 m .45219 .93105 L .44467 .93068 L .157 .165 0 r
F
.46112 .93052 m .45219 .93105 L .45434 .93045 L .172 .168 0 r
F
.61987 .89241 m .62192 .89512 L .61484 .89706 L .492 .359 0 r
F
.61987 .89241 m .62726 .8903 L .62192 .89512 L F
.57854 .90406 m .58022 .90712 L .57328 .90808 L .49 .516 0 r
F
.57854 .90406 m .58591 .90304 L .58022 .90712 L F
.78514 .78398 m .78849 .78941 L .78295 .79466 L .751 .431 0 r
F
.78514 .78398 m .79079 .77846 L .78849 .78941 L F
.5522 .91001 m .55328 .91311 L .54673 .91352 L .508 .608 0 r
F
.5522 .91001 m .55926 .90952 L .55328 .91311 L F
.39571 .91801 m .38226 .9152 L .38889 .91629 L 0 .13 0 r
F
.4018 .91879 m .39571 .91801 L .38889 .91629 L 0 .134 0 r
F
.6912 .86657 m .69362 .86983 L .68682 .87333 L .589 .336 0 r
F
.6912 .86657 m .6982 .86282 L .69362 .86983 L F
.52268 .92384 m .52202 .9258 L .5166 .92569 L .38 .297 0 r
F
.52268 .92384 m .52882 .92383 L .52202 .9258 L F
.88 .62858 m .88561 .63827 L .88262 .64524 L .928 .413 0 r
F
.88 .62858 m .88302 .62136 L .88561 .63827 L F
.66733 .85526 m .67051 .8588 L .66376 .86169 L .601 .493 0 r
F
.66733 .85526 m .67425 .85211 L .67051 .8588 L F
.53351 .91391 m .53394 .91684 L .52792 .91687 L .509 .625 0 r
F
.53351 .91391 m .54014 .91379 L .53394 .91684 L F
.49455 .92762 m .49119 .92929 L .4883 .92863 L .325 .209 0 r
F
.49455 .92762 m .49837 .92823 L .49119 .92929 L F
.85486 .63534 m .86324 .64534 L .86029 .65202 L 1 .646 0 r
F
.85486 .63534 m .85763 .6284 L .86324 .64534 L F
.76335 .78416 m .76769 .78978 L .76212 .7947 L .785 .586 0 r
F
.76335 .78416 m .76897 .77897 L .76769 .78978 L F
.51352 .89425 m .51948 .89608 L .51418 .9019 L 1 1 0 r
F
.34148 .90484 m .32798 .89915 L .33514 .90136 L 0 .117 0 r
F
.34833 .90671 m .34148 .90484 L .33514 .90136 L 0 .121 0 r
F
.51114 .92542 m .50972 .9273 L .50505 .92693 L .367 .284 0 r
F
.51114 .92542 m .5166 .92569 L .50972 .9273 L F
.52365 .88878 m .52541 .89752 L .51948 .89608 L .984 1 0 r
F
.52365 .88878 m .5302 .89079 L .52541 .89752 L F
.62232 .8992 m .62426 .90156 L .61712 .90368 L .479 .282 0 r
F
.62232 .8992 m .62975 .89686 L .62426 .90156 L F
.51303 .74964 m .52949 .81542 L .52197 .80785 L 1 .601 0 r
F
.50997 .76481 m .51303 .74964 L .52197 .80785 L 1 .655 0 r
F
.35185 .89453 m .3388 .89007 L .34575 .89238 L 0 .093 0 r
F
.35847 .89656 m .35185 .89453 L .34575 .89238 L 0 .097 0 r
F
.68116 .86477 m .68385 .86792 L .67704 .8712 L .583 .364 0 r
F
.68116 .86477 m .68817 .86125 L .68385 .86792 L F
.58058 .9121 m .58204 .91427 L .57504 .91547 L .43 .293 0 r
F
.58058 .9121 m .588 .91072 L .58204 .91427 L F
.39482 .9231 m .38124 .92019 L .38797 .92113 L .027 .138 0 r
F
.40101 .92373 m .39482 .9231 L .38797 .92113 L .053 .143 0 r
F
.59936 .87882 m .60258 .8831 L .59542 .88389 L .523 .683 0 r
F
.59936 .87882 m .60686 .87802 L .60258 .8831 L F
.55373 .91817 m .55464 .92028 L .548 .92088 L .412 .32 0 r
F
.55373 .91817 m .56088 .91742 L .55464 .92028 L F
.77938 .7894 m .78295 .79466 L .77731 .79982 L .747 .45 0 r
F
.77938 .7894 m .78514 .78398 L .78295 .79466 L F
.37568 .91401 m .36219 .91011 L .3692 .91163 L 0 .127 0 r
F
.38226 .9152 m .37568 .91401 L .3692 .91163 L 0 .131 0 r
F
.40517 .83686 m .39529 .83724 L .39985 .84685 L 1 .532 0 r
F
.40947 .8472 m .40517 .83686 L .39985 .84685 L 1 .505 0 r
F
.33985 .91018 m .32618 .90441 L .33347 .90652 L 0 .123 0 r
F
.34682 .91196 m .33985 .91018 L .33347 .90652 L .001 .127 0 r
F
.53462 .92164 m .53491 .92367 L .52882 .92383 L .4 .329 0 r
F
.53462 .92164 m .54133 .92133 L .53491 .92367 L F
.5583 .88076 m .56193 .88919 L .55489 .88818 L .731 .915 0 r
F
.5583 .88076 m .56591 .88266 L .56193 .88919 L F
.40379 .90628 m .3911 .90464 L .3975 .9061 L .269 0 0 r
F
.40966 .90754 m .40379 .90628 L .3975 .9061 L .266 0 0 r
F
.45434 .93045 m .44467 .93068 L .44779 .93018 L .157 .165 0 r
F
.42681 .92158 m .41457 .92055 L .42007 .92094 L 0 .137 0 r
F
.43158 .92171 m .42681 .92158 L .42007 .92094 L .017 .141 0 r
F
.41943 .84601 m .40947 .8472 L .41417 .85722 L 1 .49 0 r
F
.42378 .85714 m .41943 .84601 L .41417 .85722 L 1 .465 0 r
F
.61241 .89433 m .61484 .89706 L .6077 .89882 L .493 .401 0 r
F
.61241 .89433 m .61987 .89241 L .61484 .89706 L F
.87685 .63576 m .88262 .64524 L .87951 .65217 L .936 .439 0 r
F
.87685 .63576 m .88 .62858 L .88262 .64524 L F
.75762 .78926 m .76212 .7947 L .75645 .79951 L .781 .599 0 r
F
.75762 .78926 m .76335 .78416 L .76212 .7947 L F
.66032 .85825 m .66376 .86169 L .65692 .86442 L .593 .508 0 r
F
.66032 .85825 m .66733 .85526 L .66376 .86169 L F
.85194 .64225 m .86029 .65202 L .8572 .65867 L 1 .663 0 r
F
.85194 .64225 m .85486 .63534 L .86029 .65202 L F
.41457 .92055 m .4018 .91879 L .40793 .91946 L 0 .135 0 r
F
.42007 .92094 m .41457 .92055 L .40793 .91946 L .009 .138 0 r
F
.68412 .8702 m .68682 .87333 L .67994 .87671 L .585 .354 0 r
F
.68412 .8702 m .6912 .86657 L .68682 .87333 L F
.37455 .91912 m .36091 .91513 L .36804 .91653 L .017 .134 0 r
F
.38124 .92019 m .37455 .91912 L .36804 .91653 L .041 .139 0 r
F
.38474 .90311 m .37188 .90035 L .37866 .90213 L .225 0 0 r
F
.3911 .90464 m .38474 .90311 L .37866 .90213 L .217 0 0 r
F
.53359 .88219 m .53675 .89241 L .5302 .89079 L .927 .971 0 r
F
.53359 .88219 m .5407 .88468 L .53675 .89241 L F
.57113 .90489 m .57328 .90808 L .56629 .90888 L .507 .596 0 r
F
.57113 .90489 m .57854 .90406 L .57328 .90808 L F
.46468 .90989 m .46139 .77493 L .46443 .91333 L 1 .576 0 r
F
.42628 .92682 m .41392 .92562 L .4195 .92583 L .066 .148 0 r
F
.43112 .92676 m .42628 .92682 L .4195 .92583 L .093 .153 0 r
F
.43773 .92737 m .42628 .92682 L .43112 .92676 L .09 .154 0 r
F
.50036 .9264 m .49837 .92823 L .49455 .92762 L .363 .287 0 r
F
.50036 .9264 m .50505 .92693 L .49837 .92823 L F
.67407 .86816 m .67704 .8712 L .67015 .87435 L .579 .383 0 r
F
.67407 .86816 m .68116 .86477 L .67704 .8712 L F
.41392 .92562 m .40101 .92373 L .40724 .92424 L .054 .145 0 r
F
.4195 .92583 m .41392 .92562 L .40724 .92424 L .08 .15 0 r
F
.77351 .79474 m .77731 .79982 L .77156 .80489 L .743 .468 0 r
F
.77351 .79474 m .77938 .7894 L .77731 .79982 L F
.59176 .87915 m .59542 .88389 L .58818 .88433 L .522 .739 0 r
F
.59176 .87915 m .59936 .87882 L .59542 .88389 L F
.34833 .90671 m .33514 .90136 L .34237 .90346 L 0 .121 0 r
F
.35523 .90847 m .34833 .90671 L .34237 .90346 L 0 .126 0 r
F
.61482 .9014 m .61712 .90368 L .60993 .90567 L .478 .307 0 r
F
.61482 .9014 m .62232 .8992 L .61712 .90368 L F
.5451 .91035 m .54673 .91352 L .54014 .91379 L .53 .689 0 r
F
.5451 .91035 m .5522 .91001 L .54673 .91352 L F
.75179 .79426 m .75645 .79951 L .75069 .80423 L .777 .612 0 r
F
.75179 .79426 m .75762 .78926 L .75645 .79951 L F
.35847 .89656 m .34575 .89238 L .35275 .8946 L 0 .097 0 r
F
.36514 .8985 m .35847 .89656 L .35275 .8946 L 0 .1 0 r
F
.84887 .64912 m .8572 .65867 L .85398 .66527 L 1 .68 0 r
F
.84887 .64912 m .85194 .64225 L .8572 .65867 L F
.87357 .6429 m .87951 .65217 L .87625 .65906 L .943 .466 0 r
F
.87357 .6429 m .87685 .63576 L .87951 .65217 L F
.65324 .86108 m .65692 .86442 L .65001 .86699 L .585 .523 0 r
F
.65324 .86108 m .66032 .85825 L .65692 .86442 L F
.51578 .91645 m .52186 .91674 L .51595 .91928 L .524 .68 0 r
F
.46815 .92954 m .46802 .93037 L .46112 .93052 L .232 .178 0 r
F
.47402 .92916 m .46802 .93037 L .46815 .92954 L .26 .182 0 r
F
.47402 .92916 m .47493 .93001 L .46802 .93037 L F
.52482 .75717 m .54941 .84899 L .53894 .83132 L 0 .002 0 r
F
.55063 .87803 m .55489 .88818 L .54781 .88668 L .775 .884 0 r
F
.55063 .87803 m .5583 .88076 L .55489 .88818 L F
.67697 .87371 m .67994 .87671 L .67299 .87998 L .58 .371 0 r
F
.67697 .87371 m .68412 .8702 L .67994 .87671 L F
.57311 .91331 m .57504 .91547 L .56798 .91652 L .436 .339 0 r
F
.57311 .91331 m .58058 .9121 L .57504 .91547 L F
.4798 .92858 m .47493 .93001 L .47402 .92916 L .293 .187 0 r
F
.4798 .92858 m .48173 .92943 L .47493 .93001 L F
.42156 .90814 m .40966 .90754 L .41558 .90877 L .303 0 0 r
F
.42685 .90923 m .42156 .90814 L .41558 .90877 L .308 0 0 r
F
.43283 .90788 m .42156 .90814 L .42685 .90923 L .318 0 0 r
F
.4018 .91879 m .38889 .91629 L .39556 .91727 L 0 .134 0 r
F
.40793 .91946 m .4018 .91879 L .39556 .91727 L .014 .138 0 r
F
.4374 .9089 m .43283 .90788 L .42685 .90923 L .327 0 0 r
F
.34682 .91196 m .33347 .90652 L .34082 .90852 L .001 .127 0 r
F
.35384 .91361 m .34682 .91196 L .34082 .90852 L .024 .132 0 r
F
.60489 .89604 m .6077 .89882 L .6005 .90041 L .495 .448 0 r
F
.60489 .89604 m .61241 .89433 L .6077 .89882 L F
.5171 .88628 m .51948 .89608 L .51352 .89425 L 1 1 0 r
F
.5171 .88628 m .52365 .88878 L .51948 .89608 L F
.52686 .91388 m .52792 .91687 L .52186 .91674 L .536 .712 0 r
F
.52686 .91388 m .53351 .91391 L .52792 .91687 L F
.46228 .92973 m .46112 .93052 L .45434 .93045 L .208 .174 0 r
F
.46815 .92954 m .46112 .93052 L .46228 .92973 L .232 .178 0 r
F
.76755 .79997 m .77156 .80489 L .7657 .80987 L .739 .486 0 r
F
.76755 .79997 m .77351 .79474 L .77156 .80489 L F
.6669 .87141 m .67015 .87435 L .66318 .87737 L .574 .4 0 r
F
.6669 .87141 m .67407 .86816 L .67015 .87435 L F
.38226 .9152 m .3692 .91163 L .37626 .91305 L 0 .131 0 r
F
.38889 .91629 m .38226 .9152 L .37626 .91305 L .013 .135 0 r
F
.54655 .91877 m .548 .92088 L .54133 .92133 L .426 .379 0 r
F
.54655 .91877 m .55373 .91817 L .548 .92088 L F
.4854 .92781 m .48173 .92943 L .4798 .92858 L .328 .226 0 r
F
.4854 .92781 m .4883 .92863 L .48173 .92943 L F
.44216 .85341 m .43323 .85585 L .43755 .86814 L .933 .373 0 r
F
.44597 .86813 m .44216 .85341 L .43755 .86814 L .924 .352 0 r
F
.50997 .76481 m .52197 .80785 L .51564 .80673 L 1 .655 0 r
F
.50606 .77737 m .50997 .76481 L .51564 .80673 L 1 .67 0 r
F
.50273 .754 m .50997 .76481 L .50606 .77737 L 1 .72 0 r
F
.49917 .76985 m .50273 .754 L .50606 .77737 L 1 .727 0 r
F
.51652 .9237 m .5166 .92569 L .51114 .92542 L .405 .376 0 r
F
.51652 .9237 m .52268 .92384 L .5166 .92569 L F
.74586 .79916 m .75069 .80423 L .74482 .80885 L .772 .624 0 r
F
.74586 .79916 m .75179 .79426 L .75069 .80423 L F
.40101 .92373 m .38797 .92113 L .39475 .92196 L .053 .143 0 r
F
.40724 .92424 m .40101 .92373 L .39475 .92196 L .078 .148 0 r
F
.58403 .87887 m .58818 .88433 L .58084 .88433 L .533 .785 0 r
F
.58403 .87887 m .59176 .87915 L .58818 .88433 L F
.84565 .65594 m .85398 .66527 L .85063 .67183 L 1 .696 0 r
F
.84565 .65594 m .84887 .64912 L .85398 .66527 L F
.43323 .85585 m .42378 .85714 L .42853 .8678 L 1 .429 0 r
F
.43755 .86814 m .43323 .85585 L .42853 .8678 L 1 .405 0 r
F
.87015 .64999 m .87625 .65906 L .87287 .6659 L .949 .491 0 r
F
.87015 .64999 m .87357 .6429 L .87625 .65906 L F
.64608 .86373 m .65001 .86699 L .64302 .86939 L .577 .538 0 r
F
.64608 .86373 m .65324 .86108 L .65001 .86699 L F
.56368 .90553 m .56629 .90888 L .55926 .90952 L .527 .677 0 r
F
.56368 .90553 m .57113 .90489 L .56629 .90888 L F
.5265 .87923 m .5302 .89079 L .52365 .88878 L .969 .939 0 r
F
.5265 .87923 m .53359 .88219 L .5302 .89079 L F
.60727 .90344 m .60993 .90567 L .60267 .9075 L .476 .334 0 r
F
.60727 .90344 m .61482 .9014 L .60993 .90567 L F
.38124 .92019 m .36804 .91653 L .37521 .91781 L .041 .139 0 r
F
.38797 .92113 m .38124 .92019 L .37521 .91781 L .065 .143 0 r
F
.40966 .90754 m .3975 .9061 L .40397 .90751 L .266 0 0 r
F
.41558 .90877 m .40966 .90754 L .40397 .90751 L .268 0 0 r
F
.52787 .92179 m .52882 .92383 L .52268 .92384 L .419 .398 0 r
F
.52787 .92179 m .53462 .92164 L .52882 .92383 L F
.3911 .90464 m .37866 .90213 L .38551 .90383 L .217 0 0 r
F
.3975 .9061 m .3911 .90464 L .38551 .90383 L .211 0 0 r
F
.45651 .92974 m .45434 .93045 L .44779 .93018 L .19 .17 0 r
F
.46228 .92973 m .45434 .93045 L .45651 .92974 L .208 .174 0 r
F
.40947 .8472 m .39985 .84685 L .40481 .85612 L 1 .505 0 r
F
.41417 .85722 m .40947 .8472 L .40481 .85612 L 1 .473 0 r
F
.66974 .87709 m .67299 .87998 L .66595 .88311 L .576 .388 0 r
F
.66974 .87709 m .67697 .87371 L .67299 .87998 L F
.50565 .92499 m .50505 .92693 L .50036 .9264 L .398 .374 0 r
F
.50565 .92499 m .51114 .92542 L .50505 .92693 L F
.35523 .90847 m .34237 .90346 L .34964 .90544 L 0 .126 0 r
F
.36219 .91011 m .35523 .90847 L .34964 .90544 L .007 .13 0 r
F
.76149 .80511 m .7657 .80987 L .75975 .81474 L .734 .502 0 r
F
.76149 .80511 m .76755 .79997 L .7657 .80987 L F
.36514 .8985 m .35275 .8946 L .35981 .89673 L 0 .1 0 r
F
.37188 .90035 m .36514 .8985 L .35981 .89673 L 0 .102 0 r
F
.54292 .87449 m .54781 .88668 L .5407 .88468 L .82 .843 0 r
F
.54292 .87449 m .55063 .87803 L .54781 .88668 L F
.49071 .92685 m .4883 .92863 L .4854 .92781 L .365 .303 0 r
F
.49071 .92685 m .49455 .92762 L .4883 .92863 L F
.73984 .80395 m .74482 .80885 L .73886 .81336 L .766 .635 0 r
F
.73984 .80395 m .74586 .79916 L .74482 .80885 L F
.65967 .87453 m .66318 .87737 L .65614 .88025 L .568 .417 0 r
F
.65967 .87453 m .6669 .87141 L .66318 .87737 L F
.5973 .89754 m .6005 .90041 L .59323 .90182 L .499 .502 0 r
F
.5973 .89754 m .60489 .89604 L .6005 .90041 L F
.42007 .92094 m .40793 .91946 L .41411 .92004 L .009 .138 0 r
F
.4256 .92124 m .42007 .92094 L .41411 .92004 L .025 .141 0 r
F
.43158 .92171 m .42007 .92094 L .4256 .92124 L .017 .141 0 r
F
.53798 .91057 m .54014 .91379 L .53351 .91391 L .559 .764 0 r
F
.53798 .91057 m .5451 .91035 L .54014 .91379 L F
.84229 .66272 m .85063 .67183 L .84714 .67833 L 1 .712 0 r
F
.84229 .66272 m .84565 .65594 L .85063 .67183 L F
.43638 .92176 m .43158 .92171 L .4256 .92124 L .03 .144 0 r
F
.35384 .91361 m .34082 .90852 L .34822 .91039 L .024 .132 0 r
F
.36091 .91513 m .35384 .91361 L .34822 .91039 L .046 .136 0 r
F
.57615 .87778 m .58084 .88433 L .57342 .88381 L .552 .806 0 r
F
.57615 .87778 m .58403 .87887 L .58084 .88433 L F
.5656 .91436 m .56798 .91652 L .56088 .91742 L .444 .389 0 r
F
.5656 .91436 m .57311 .91331 L .56798 .91652 L F
.42378 .85714 m .41417 .85722 L .41926 .8668 L 1 .465 0 r
F
.42853 .8678 m .42378 .85714 L .41926 .8668 L 1 .435 0 r
F
.86661 .65704 m .87287 .6659 L .86936 .6727 L .954 .516 0 r
F
.86661 .65704 m .87015 .64999 L .87287 .6659 L F
.63884 .86618 m .64302 .86939 L .63595 .87159 L .567 .552 0 r
F
.63884 .86618 m .64608 .86373 L .64302 .86939 L F
.4195 .92583 m .40724 .92424 L .41351 .92463 L .08 .15 0 r
F
.42512 .92593 m .4195 .92583 L .41351 .92463 L .104 .154 0 r
F
.43112 .92676 m .4195 .92583 L .42512 .92593 L .093 .153 0 r
F
.45093 .92956 m .44779 .93018 L .44157 .92971 L .178 .168 0 r
F
.45651 .92974 m .44779 .93018 L .45093 .92956 L .19 .17 0 r
F
.75533 .81015 m .75975 .81474 L .7537 .81951 L .729 .518 0 r
F
.75533 .81015 m .76149 .80511 L .75975 .81474 L F
.66245 .88035 m .66595 .88311 L .65885 .88612 L .571 .403 0 r
F
.66245 .88035 m .66974 .87709 L .66595 .88311 L F
.43599 .92659 m .43112 .92676 L .42512 .92593 L .117 .157 0 r
F
.51053 .88304 m .51352 .89425 L .50755 .89189 L 1 .973 0 r
F
.51053 .88304 m .5171 .88628 L .51352 .89425 L F
.73372 .80864 m .73886 .81336 L .7328 .81777 L .76 .644 0 r
F
.73372 .80864 m .73984 .80395 L .73886 .81336 L F
.59966 .90533 m .60267 .9075 L .59536 .90919 L .475 .362 0 r
F
.59966 .90533 m .60727 .90344 L .60267 .9075 L F
.38889 .91629 m .37626 .91305 L .38337 .91434 L .013 .135 0 r
F
.39556 .91727 m .38889 .91629 L .38337 .91434 L .032 .138 0 r
F
.40793 .91946 m .39556 .91727 L .40229 .91814 L .014 .138 0 r
F
.41411 .92004 m .40793 .91946 L .40229 .91814 L .031 .141 0 r
F
.50606 .77737 m .51564 .80673 L .5095 .80667 L 1 .67 0 r
F
.5009 .78176 m .50606 .77737 L .5095 .80667 L 1 .624 0 r
F
.49917 .76985 m .50606 .77737 L .5009 .78176 L 1 .727 0 r
F
.65236 .87751 m .65614 .88025 L .64902 .88299 L .563 .434 0 r
F
.65236 .87751 m .65967 .87453 L .65614 .88025 L F
.53932 .91922 m .54133 .92133 L .53462 .92164 L .441 .44 0 r
F
.53932 .91922 m .54655 .91877 L .54133 .92133 L F
.55621 .90603 m .55926 .90952 L .5522 .91001 L .551 .755 0 r
F
.55621 .90603 m .56368 .90553 L .55926 .90952 L F
.51945 .87575 m .52365 .88878 L .5171 .88628 L 1 .899 0 r
F
.51945 .87575 m .5265 .87923 L .52365 .88878 L F
.53526 .87033 m .5407 .88468 L .53359 .88219 L .87 .808 0 r
F
.53526 .87033 m .54292 .87449 L .5407 .88468 L F
.83878 .66944 m .84714 .67833 L .84352 .68479 L 1 .728 0 r
F
.83878 .66944 m .84229 .66272 L .84714 .67833 L F
.49564 .92571 m .49455 .92762 L .49071 .92685 L .4 .389 0 r
F
.49564 .92571 m .50036 .9264 L .49455 .92762 L F
.52018 .91368 m .52186 .91674 L .51578 .91645 L .582 .799 0 r
F
.52018 .91368 m .52686 .91388 L .52186 .91674 L F
.4588 .88487 m .45579 .81145 L .45317 .84561 L 1 .551 0 r
F
.36219 .91011 m .34964 .90544 L .35698 .9073 L .007 .13 0 r
F
.3692 .91163 m .36219 .91011 L .35698 .9073 L .026 .134 0 r
F
.86293 .66404 m .86936 .6727 L .86572 .67944 L .959 .54 0 r
F
.86293 .66404 m .86661 .65704 L .86936 .6727 L F
.42685 .90923 m .41558 .90877 L .42156 .90996 L .308 0 0 r
F
.4322 .91033 m .42685 .90923 L .42156 .90996 L .32 0 0 r
F
.4374 .9089 m .42685 .90923 L .4322 .91033 L .327 0 0 r
F
.63152 .86841 m .63595 .87159 L .6288 .87359 L .556 .566 0 r
F
.63152 .86841 m .63884 .86618 L .63595 .87159 L F
.45317 .84561 m .44876 .80466 L .45136 .86612 L 1 .673 0 r
F
.56809 .87558 m .57342 .88381 L .56591 .88266 L .568 .785 0 r
F
.56809 .87558 m .57615 .87778 L .57342 .88381 L F
.58965 .89879 m .59323 .90182 L .58591 .90304 L .505 .564 0 r
F
.58965 .89879 m .5973 .89754 L .59323 .90182 L F
.37188 .90035 m .35981 .89673 L .36693 .89878 L 0 .102 0 r
F
.37866 .90213 m .37188 .90035 L .36693 .89878 L 0 .105 0 r
F
.5009 .78176 m .5095 .80667 L .50289 .80155 L 1 .624 0 r
F
.40724 .92424 m .39475 .92196 L .40157 .92266 L .078 .148 0 r
F
.41351 .92463 m .40724 .92424 L .40157 .92266 L .101 .152 0 r
F
.38797 .92113 m .37521 .91781 L .38243 .91897 L .065 .143 0 r
F
.39475 .92196 m .38797 .92113 L .38243 .91897 L .088 .147 0 r
F
.3975 .9061 m .38551 .90383 L .39241 .90546 L .211 0 0 r
F
.40397 .90751 m .3975 .9061 L .39241 .90546 L .209 0 0 r
F
.74908 .81508 m .7537 .81951 L .74755 .82418 L .724 .533 0 r
F
.74908 .81508 m .75533 .81015 L .7537 .81951 L F
.44202 .90999 m .4374 .9089 L .4322 .91033 L .344 0 0 r
F
.72751 .81322 m .7328 .81777 L .72665 .82207 L .753 .653 0 r
F
.72751 .81322 m .73372 .80864 L .7328 .81777 L F
.65508 .88347 m .65885 .88612 L .65168 .88901 L .565 .418 0 r
F
.65508 .88347 m .66245 .88035 L .65885 .88612 L F
.36091 .91513 m .34822 .91039 L .35568 .91214 L .046 .136 0 r
F
.36804 .91653 m .36091 .91513 L .35568 .91214 L .068 .14 0 r
F
.41558 .90877 m .40397 .90751 L .41049 .90887 L .268 0 0 r
F
.42156 .90996 m .41558 .90877 L .41049 .90887 L .274 0 0 r
F
.51031 .9234 m .51114 .92542 L .50565 .92499 L .432 .462 0 r
F
.51031 .9234 m .51652 .9237 L .51114 .92542 L F
.52109 .9218 m .52268 .92384 L .51652 .9237 L .44 .47 0 r
F
.52109 .9218 m .52787 .92179 L .52268 .92384 L F
.83513 .67612 m .84352 .68479 L .83978 .69119 L 1 .743 0 r
F
.83513 .67612 m .83878 .66944 L .84352 .68479 L F
.55804 .91525 m .56088 .91742 L .55373 .91817 L .454 .443 0 r
F
.55804 .91525 m .5656 .91436 L .56088 .91742 L F
.64499 .88033 m .64902 .88299 L .64184 .88558 L .557 .45 0 r
F
.64499 .88033 m .65236 .87751 L .64902 .88299 L F
.41417 .85722 m .40481 .85612 L .41014 .865 L 1 .473 0 r
F
.41926 .8668 m .41417 .85722 L .41014 .865 L 1 .435 0 r
F
.62412 .8704 m .6288 .87359 L .62157 .87535 L .544 .58 0 r
F
.62412 .8704 m .63152 .86841 L .6288 .87359 L F
.45093 .92956 m .44157 .92971 L .44564 .92921 L .178 .168 0 r
F
.85913 .67099 m .86572 .67944 L .86195 .68613 L .964 .564 0 r
F
.85913 .67099 m .86293 .66404 L .86572 .67944 L F
.53084 .91066 m .53351 .91391 L .52686 .91388 L .608 .833 0 r
F
.53084 .91066 m .53798 .91057 L .53351 .91391 L F
.59199 .90705 m .59536 .90919 L .588 .91072 L .474 .391 0 r
F
.59199 .90705 m .59966 .90533 L .59536 .90919 L F
.55984 .87192 m .56591 .88266 L .5583 .88076 L .583 .719 0 r
F
.55984 .87192 m .56809 .87558 L .56591 .88266 L F
.46827 .92858 m .46815 .92954 L .46228 .92973 L .268 .183 0 r
F
.47311 .92817 m .46815 .92954 L .46827 .92858 L .3 .188 0 r
F
.47311 .92817 m .47402 .92916 L .46815 .92954 L F
.52771 .86584 m .53359 .88219 L .5265 .87923 L .922 .786 0 r
F
.52771 .86584 m .53526 .87033 L .53359 .88219 L F
.47787 .92759 m .47402 .92916 L .47311 .92817 L .335 .246 0 r
F
.47787 .92759 m .4798 .92858 L .47402 .92916 L F
.7212 .81769 m .72665 .82207 L .7204 .82625 L .746 .661 0 r
F
.7212 .81769 m .72751 .81322 L .72665 .82207 L F
.74273 .81991 m .74755 .82418 L .74131 .82875 L .719 .547 0 r
F
.74273 .81991 m .74908 .81508 L .74755 .82418 L F
.46344 .92882 m .46228 .92973 L .45651 .92974 L .241 .179 0 r
F
.46827 .92858 m .46228 .92973 L .46344 .92882 L .268 .183 0 r
F
.58195 .89978 m .58591 .90304 L .57854 .90406 L .515 .634 0 r
F
.58195 .89978 m .58965 .89879 L .58591 .90304 L F
.50289 .80155 m .512 .8341 L .50465 .82506 L .94 .569 0 r
F
.50289 .80155 m .5095 .80667 L .512 .8341 L F
.51241 .87136 m .5171 .88628 L .51053 .88304 L 1 .844 0 r
F
.51241 .87136 m .51945 .87575 L .5171 .88628 L F
.48247 .92684 m .4798 .92858 L .47787 .92759 L .372 .326 0 r
F
.48247 .92684 m .4854 .92781 L .4798 .92858 L F
.4256 .92124 m .41411 .92004 L .42034 .92052 L .025 .141 0 r
F
.43118 .92145 m .4256 .92124 L .42034 .92052 L .035 .144 0 r
F
.43638 .92176 m .4256 .92124 L .43118 .92145 L .03 .144 0 r
F
.54872 .90643 m .5522 .91001 L .5451 .91035 L .601 .826 0 r
F
.54872 .90643 m .55621 .90603 L .5522 .91001 L F
.50013 .92439 m .50036 .9264 L .49564 .92571 L .433 .476 0 r
F
.50013 .92439 m .50565 .92499 L .50036 .9264 L F
.3692 .91163 m .35698 .9073 L .36436 .90905 L .026 .134 0 r
F
.37626 .91305 m .3692 .91163 L .36436 .90905 L .044 .137 0 r
F
.50393 .87843 m .51053 .88304 L .50755 .89189 L 1 .895 0 r
F
.39556 .91727 m .38337 .91434 L .39053 .91553 L .032 .138 0 r
F
.40229 .91814 m .39556 .91727 L .39053 .91553 L .048 .142 0 r
F
.64765 .88647 m .65168 .88901 L .64443 .89176 L .56 .431 0 r
F
.64765 .88647 m .65508 .88347 L .65168 .88901 L F
.83135 .68274 m .83978 .69119 L .8359 .69753 L 1 .758 0 r
F
.83135 .68274 m .83513 .67612 L .83978 .69119 L F
.43755 .86814 m .42853 .8678 L .43369 .87789 L 1 .405 0 r
F
.44231 .87973 m .43755 .86814 L .43369 .87789 L 1 .375 0 r
F
.44597 .86813 m .43755 .86814 L .44231 .87973 L .924 .352 0 r
F
.37866 .90213 m .36693 .89878 L .3741 .90074 L 0 .105 0 r
F
.38551 .90383 m .37866 .90213 L .3741 .90074 L 0 .107 0 r
F
.55139 .86649 m .5583 .88076 L .55063 .87803 L .609 .637 0 r
F
.55139 .86649 m .55984 .87192 L .5583 .88076 L F
.61663 .8721 m .62157 .87535 L .61426 .87684 L .53 .593 0 r
F
.61663 .8721 m .62412 .8704 L .62157 .87535 L F
.63754 .88299 m .64184 .88558 L .63458 .88802 L .55 .466 0 r
F
.63754 .88299 m .64499 .88033 L .64184 .88558 L F
.85519 .67788 m .86195 .68613 L .85805 .69276 L .967 .586 0 r
F
.85519 .67788 m .85913 .67099 L .86195 .68613 L F
.53207 .91954 m .53462 .92164 L .52787 .92179 L .456 .501 0 r
F
.53207 .91954 m .53932 .91922 L .53462 .92164 L F
.45869 .9289 m .45651 .92974 L .45093 .92956 L .22 .175 0 r
F
.46344 .92882 m .45651 .92974 L .45869 .9289 L .241 .179 0 r
F
.41411 .92004 m .40229 .91814 L .40906 .91891 L .031 .141 0 r
F
.42034 .92052 m .41411 .92004 L .40906 .91891 L .044 .144 0 r
F
.71481 .82204 m .7204 .82625 L .71407 .83032 L .738 .668 0 r
F
.71481 .82204 m .7212 .81769 L .7204 .82625 L F
.42512 .92593 m .41351 .92463 L .41983 .92491 L .104 .154 0 r
F
.43077 .92592 m .42512 .92593 L .41983 .92491 L .125 .158 0 r
F
.43599 .92659 m .42512 .92593 L .43077 .92592 L .117 .157 0 r
F
.51564 .80673 m .52664 .84486 L .51921 .83945 L 1 .628 0 r
F
.51564 .80673 m .52197 .80785 L .52664 .84486 L F
.5095 .80667 m .51564 .80673 L .51921 .83945 L 1 .64 0 r
F
.73629 .82463 m .74131 .82875 L .73497 .83321 L .713 .559 0 r
F
.73629 .82463 m .74273 .81991 L .74131 .82875 L F
.42853 .8678 m .41926 .8668 L .42474 .87589 L 1 .435 0 r
F
.43369 .87789 m .42853 .8678 L .42474 .87589 L 1 .4 0 r
F
.5203 .86111 m .5265 .87923 L .51945 .87575 L .963 .765 0 r
F
.5203 .86111 m .52771 .86584 L .5265 .87923 L F
.52197 .80785 m .53453 .8517 L .52664 .84486 L .886 .541 0 r
F
.52197 .80785 m .52949 .81542 L .53453 .8517 L F
.5095 .80667 m .51921 .83945 L .512 .8341 L 1 .64 0 r
F
.36804 .91653 m .35568 .91214 L .36318 .91376 L .068 .14 0 r
F
.37521 .91781 m .36804 .91653 L .36318 .91376 L .088 .144 0 r
F
.39475 .92196 m .38243 .91897 L .3897 .92 L .088 .147 0 r
F
.40157 .92266 m .39475 .92196 L .3897 .92 L .109 .151 0 r
F
.40397 .90751 m .39241 .90546 L .39936 .90703 L .209 0 0 r
F
.41049 .90887 m .40397 .90751 L .39936 .90703 L .211 0 0 r
F
.58427 .9086 m .588 .91072 L .58058 .9121 L .474 .424 0 r
F
.58427 .9086 m .59199 .90705 L .588 .91072 L F
.55045 .91599 m .55373 .91817 L .54655 .91877 L .465 .498 0 r
F
.55045 .91599 m .55804 .91525 L .55373 .91817 L F
.4409 .92632 m .43599 .92659 L .43077 .92592 L .136 .161 0 r
F
.54287 .85941 m .55063 .87803 L .54292 .87449 L .666 .585 0 r
F
.54287 .85941 m .55139 .86649 L .55063 .87803 L F
.82743 .6893 m .8359 .69753 L .8319 .70381 L 1 .772 0 r
F
.82743 .6893 m .83135 .68274 L .8359 .69753 L F
.41351 .92463 m .40157 .92266 L .40844 .92325 L .101 .152 0 r
F
.41983 .92491 m .41351 .92463 L .40844 .92325 L .122 .156 0 r
F
.57419 .9005 m .57854 .90406 L .57113 .90489 L .529 .712 0 r
F
.57419 .9005 m .58195 .89978 L .57854 .90406 L F
.60904 .87346 m .61426 .87684 L .60686 .87802 L .514 .608 0 r
F
.60904 .87346 m .61663 .8721 L .61426 .87684 L F
.64015 .88933 m .64443 .89176 L .63713 .89438 L .554 .444 0 r
F
.64015 .88933 m .64765 .88647 L .64443 .89176 L F
.4322 .91033 m .42156 .90996 L .4276 .91116 L .32 0 0 r
F
.43759 .91146 m .4322 .91033 L .4276 .91116 L .34 0 0 r
F
.44202 .90999 m .4322 .91033 L .43759 .91146 L .344 0 0 r
F
.70832 .82628 m .71481 .82204 L .71407 .83032 L .729 .674 0 r
F
.85114 .68472 m .85805 .69276 L .85403 .69934 L .97 .608 0 r
F
.85114 .68472 m .85519 .67788 L .85805 .69276 L F
.63003 .88549 m .63458 .88802 L .62726 .8903 L .543 .483 0 r
F
.63003 .88549 m .63754 .88299 L .63458 .88802 L F
.50532 .86489 m .51053 .88304 L .50393 .87843 L .997 .761 0 r
F
.50532 .86489 m .51241 .87136 L .51053 .88304 L F
.4541 .92882 m .45093 .92956 L .44564 .92921 L .205 .172 0 r
F
.45869 .9289 m .45093 .92956 L .4541 .92882 L .22 .175 0 r
F
.72976 .82924 m .73497 .83321 L .72855 .83756 L .707 .571 0 r
F
.72976 .82924 m .73629 .82463 L .73497 .83321 L F
.42156 .90996 m .41049 .90887 L .41706 .9102 L .274 0 0 r
F
.4276 .91116 m .42156 .90996 L .41706 .9102 L .288 0 0 r
F
.50465 .82506 m .51297 .85556 L .50556 .84708 L .911 .575 0 r
F
.50465 .82506 m .512 .8341 L .51297 .85556 L F
.52368 .91059 m .52686 .91388 L .52018 .91368 L .66 .895 0 r
F
.52368 .91059 m .53084 .91066 L .52686 .91388 L F
.53453 .8517 m .54292 .87449 L .53526 .87033 L .761 .589 0 r
F
.53453 .8517 m .54287 .85941 L .54292 .87449 L F
.51297 .85556 m .51945 .87575 L .51241 .87136 L .975 .726 0 r
F
.51297 .85556 m .5203 .86111 L .51945 .87575 L F
.54122 .90675 m .5451 .91035 L .53798 .91057 L .652 .886 0 r
F
.54122 .90675 m .54872 .90643 L .5451 .91035 L F
.37626 .91305 m .36436 .90905 L .37179 .91069 L .044 .137 0 r
F
.38337 .91434 m .37626 .91305 L .37179 .91069 L .061 .141 0 r
F
.51428 .92164 m .51652 .9237 L .51031 .9234 L .462 .547 0 r
F
.51428 .92164 m .52109 .9218 L .51652 .9237 L F
.52949 .81542 m .54287 .85941 L .53453 .8517 L .621 .351 0 r
F
.52949 .81542 m .53894 .83132 L .54287 .85941 L F
.38551 .90383 m .3741 .90074 L .38132 .90263 L 0 .107 0 r
F
.39241 .90546 m .38551 .90383 L .38132 .90263 L 0 .108 0 r
F
.82338 .6958 m .8319 .70381 L .82777 .71003 L 1 .786 0 r
F
.82338 .6958 m .82743 .6893 L .8319 .70381 L F
.50408 .92291 m .50565 .92499 L .50013 .92439 L .462 .559 0 r
F
.50408 .92291 m .51031 .9234 L .50565 .92499 L F
.41926 .8668 m .41014 .865 L .41584 .87342 L 1 .435 0 r
F
.42474 .87589 m .41926 .8668 L .41584 .87342 L 1 .392 0 r
F
.60134 .87438 m .60686 .87802 L .59936 .87882 L .494 .622 0 r
F
.60134 .87438 m .60904 .87346 L .60686 .87802 L F
.52664 .84486 m .53526 .87033 L .52771 .86584 L .87 .628 0 r
F
.52664 .84486 m .53453 .8517 L .53526 .87033 L F
.40229 .91814 m .39053 .91553 L .39774 .91662 L .048 .142 0 r
F
.40906 .91891 m .40229 .91814 L .39774 .91662 L .062 .145 0 r
F
.57651 .90997 m .58058 .9121 L .57311 .91331 L .476 .461 0 r
F
.57651 .90997 m .58427 .9086 L .58058 .9121 L F
.84695 .6915 m .85403 .69934 L .84988 .70585 L .972 .629 0 r
F
.84695 .6915 m .85114 .68472 L .85403 .69934 L F
.6326 .89205 m .63713 .89438 L .62975 .89686 L .548 .456 0 r
F
.6326 .89205 m .64015 .88933 L .63713 .89438 L F
.37521 .91781 m .36318 .91376 L .37073 .91526 L .088 .144 0 r
F
.38243 .91897 m .37521 .91781 L .37073 .91526 L .108 .148 0 r
F
.72315 .83374 m .72855 .83756 L .72203 .8418 L .701 .582 0 r
F
.72315 .83374 m .72976 .82924 L .72855 .83756 L F
.62245 .88779 m .62726 .8903 L .61987 .89241 L .536 .501 0 r
F
.62245 .88779 m .63003 .88549 L .62726 .8903 L F
.512 .8341 m .5203 .86111 L .51297 .85556 L .969 .651 0 r
F
.512 .8341 m .51921 .83945 L .5203 .86111 L F
.5664 .90101 m .57113 .90489 L .56368 .90553 L .565 .793 0 r
F
.5664 .90101 m .57419 .9005 L .57113 .90489 L F
.51921 .83945 m .52771 .86584 L .5203 .86111 L .948 .659 0 r
F
.51921 .83945 m .52664 .84486 L .52771 .86584 L F
.50556 .84708 m .51241 .87136 L .50532 .86489 L .939 .646 0 r
F
.50556 .84708 m .51297 .85556 L .51241 .87136 L F
.52479 .91971 m .52787 .92179 L .52109 .9218 L .472 .562 0 r
F
.52479 .91971 m .53207 .91954 L .52787 .92179 L F
.40157 .92266 m .3897 .92 L .39701 .92091 L .109 .151 0 r
F
.40844 .92325 m .40157 .92266 L .39701 .92091 L .129 .155 0 r
F
.43118 .92145 m .42034 .92052 L .4266 .92092 L .035 .144 0 r
F
.4368 .92161 m .43118 .92145 L .4266 .92092 L .038 .145 0 r
F
.54283 .91659 m .54655 .91877 L .53932 .91922 L .478 .553 0 r
F
.54283 .91659 m .55045 .91599 L .54655 .91877 L F
.41049 .90887 m .39936 .90703 L .40636 .90856 L .211 0 0 r
F
.41706 .9102 m .41049 .90887 L .40636 .90856 L .218 0 0 r
F
.4541 .92882 m .44564 .92921 L .44975 .92859 L .205 .172 0 r
F
.59351 .87471 m .59936 .87882 L .59176 .87915 L .47 .633 0 r
F
.59351 .87471 m .60134 .87438 L .59936 .87882 L F
.81919 .70224 m .82777 .71003 L .82352 .71619 L 1 .799 0 r
F
.81919 .70224 m .82338 .6958 L .82777 .71003 L F
.6951 .83438 m .70113 .8381 L .69454 .84181 L .709 .682 0 r
F
.6951 .83438 m .70176 .83039 L .70113 .8381 L F
.42034 .92052 m .40906 .91891 L .41587 .91959 L .044 .144 0 r
F
.4266 .92092 m .42034 .92052 L .41587 .91959 L .052 .146 0 r
F
.49457 .92359 m .50013 .92439 L .49564 .92571 L .475 .596 0 r
F
.71645 .83813 m .72203 .8418 L .71542 .84592 L .694 .592 0 r
F
.71645 .83813 m .72315 .83374 L .72203 .8418 L F
.84265 .69822 m .84988 .70585 L .8456 .7123 L .973 .649 0 r
F
.84265 .69822 m .84695 .6915 L .84988 .70585 L F
.38337 .91434 m .37179 .91069 L .37927 .91221 L .061 .141 0 r
F
.39053 .91553 m .38337 .91434 L .37927 .91221 L .076 .144 0 r
F
.43077 .92592 m .41983 .92491 L .42618 .92508 L .125 .158 0 r
F
.43647 .92581 m .43077 .92592 L .42618 .92508 L .141 .161 0 r
F
.4409 .92632 m .43077 .92592 L .43647 .92581 L .136 .161 0 r
F
.62498 .89462 m .62975 .89686 L .62232 .8992 L .542 .468 0 r
F
.62498 .89462 m .6326 .89205 L .62975 .89686 L F
.53372 .907 m .53798 .91057 L .53084 .91066 L .698 .935 0 r
F
.53372 .907 m .54122 .90675 L .53798 .91057 L F
.4684 .9275 m .46827 .92858 L .46344 .92882 L .306 .192 0 r
F
.4722 .92705 m .46827 .92858 L .4684 .9275 L .343 .26 0 r
F
.4722 .92705 m .47311 .92817 L .46827 .92858 L F
.6148 .88989 m .61987 .89241 L .61241 .89433 L .529 .521 0 r
F
.6148 .88989 m .62245 .88779 L .61987 .89241 L F
.41983 .92491 m .40844 .92325 L .41534 .92372 L .122 .156 0 r
F
.42618 .92508 m .41983 .92491 L .41534 .92372 L .14 .159 0 r
F
.39241 .90546 m .38132 .90263 L .38859 .90445 L 0 .108 0 r
F
.39936 .90703 m .39241 .90546 L .38859 .90445 L 0 .109 0 r
F
.58551 .87422 m .59176 .87915 L .58403 .87887 L .438 .631 0 r
F
.58551 .87422 m .59351 .87471 L .59176 .87915 L F
.56869 .91114 m .57311 .91331 L .5656 .91436 L .479 .505 0 r
F
.56869 .91114 m .57651 .90997 L .57311 .91331 L F
.51649 .9103 m .52368 .91059 L .52018 .91368 L .713 .952 0 r
F
.68837 .83824 m .69454 .84181 L .68786 .84538 L .698 .685 0 r
F
.68837 .83824 m .6951 .83438 L .69454 .84181 L F
.81488 .70861 m .82352 .71619 L .81914 .72228 L 1 .811 0 r
F
.81488 .70861 m .81919 .70224 L .82352 .71619 L F
.46461 .9278 m .46344 .92882 L .45869 .9289 L .273 .184 0 r
F
.4684 .9275 m .46344 .92882 L .46461 .9278 L .306 .192 0 r
F
.55862 .90138 m .56368 .90553 L .55621 .90603 L .627 .87 0 r
F
.55862 .90138 m .5664 .90101 L .56368 .90553 L F
.43369 .87789 m .42474 .87589 L .43059 .88443 L 1 .4 0 r
F
.43923 .88733 m .43369 .87789 L .43059 .88443 L 1 .36 0 r
F
.44231 .87973 m .43369 .87789 L .43923 .88733 L 1 .375 0 r
F
.38243 .91897 m .37073 .91526 L .37833 .91663 L .108 .148 0 r
F
.3897 .92 m .38243 .91897 L .37833 .91663 L .127 .151 0 r
F
.44747 .89052 m .44231 .87973 L .43923 .88733 L .992 .341 0 r
F
.4276 .91116 m .41706 .9102 L .42368 .91152 L .288 0 0 r
F
.43368 .91238 m .4276 .91116 L .42368 .91152 L .31 0 0 r
F
.43759 .91146 m .4276 .91116 L .43368 .91238 L .34 0 0 r
F
.83822 .70487 m .8456 .7123 L .84121 .71869 L .974 .668 0 r
F
.83822 .70487 m .84265 .69822 L .8456 .7123 L F
.57725 .87248 m .58403 .87887 L .57615 .87778 L .398 .595 0 r
F
.57725 .87248 m .58551 .87422 L .58403 .87887 L F
.44304 .91269 m .43759 .91146 L .43368 .91238 L .369 0 0 r
F
.40906 .91891 m .39774 .91662 L .40499 .9176 L .062 .145 0 r
F
.41587 .91959 m .40906 .91891 L .40499 .9176 L .073 .147 0 r
F
.46088 .92796 m .45869 .9289 L .4541 .92882 L .247 .179 0 r
F
.46461 .9278 m .45869 .9289 L .46088 .92796 L .273 .184 0 r
F
.53894 .83132 m .55139 .86649 L .54287 .85941 L .358 .168 0 r
F
.50743 .92128 m .51031 .9234 L .50408 .92291 L .487 .632 0 r
F
.50743 .92128 m .51428 .92164 L .51031 .9234 L F
.60708 .89175 m .61241 .89433 L .60489 .89604 L .521 .545 0 r
F
.60708 .89175 m .6148 .88989 L .61241 .89433 L F
.6173 .89705 m .62232 .8992 L .61482 .9014 L .535 .479 0 r
F
.6173 .89705 m .62498 .89462 L .62232 .8992 L F
.68155 .84196 m .68786 .84538 L .68109 .84882 L .686 .686 0 r
F
.68155 .84196 m .68837 .83824 L .68786 .84538 L F
.53894 .83132 m .54941 .84899 L .55139 .86649 L .358 .168 0 r
F
.81045 .71491 m .81914 .72228 L .81465 .7283 L 1 .823 0 r
F
.81045 .71491 m .81488 .70861 L .81914 .72228 L F
.53519 .91708 m .53932 .91922 L .53207 .91954 L .491 .606 0 r
F
.53519 .91708 m .54283 .91659 L .53932 .91922 L F
.42474 .87589 m .41584 .87342 L .42189 .88137 L 1 .392 0 r
F
.43059 .88443 m .42474 .87589 L .42189 .88137 L 1 .345 0 r
F
.40844 .92325 m .39701 .92091 L .40436 .92171 L .129 .155 0 r
F
.41534 .92372 m .40844 .92325 L .40436 .92171 L .146 .158 0 r
F
.54941 .84899 m .55984 .87192 L .55139 .86649 L .29 .166 0 r
F
.51747 .91972 m .52109 .9218 L .51428 .92164 L .489 .625 0 r
F
.51747 .91972 m .52479 .91971 L .52109 .9218 L F
.7028 .84656 m .70873 .84993 L .70196 .85383 L .68 .609 0 r
F
.7028 .84656 m .70966 .8424 L .70873 .84993 L F
.41706 .9102 m .40636 .90856 L .41342 .91004 L .218 0 0 r
F
.42368 .91152 m .41706 .9102 L .41342 .91004 L .233 0 0 r
F
.39053 .91553 m .37927 .91221 L .3868 .91362 L .076 .144 0 r
F
.39774 .91662 m .39053 .91553 L .3868 .91362 L .09 .147 0 r
F
.4578 .89461 m .45317 .84561 L .45136 .86612 L 1 .61 0 r
F
.4588 .88487 m .45317 .84561 L .4578 .89461 L 1 .551 0 r
F
.56084 .91213 m .5656 .91436 L .55804 .91525 L .486 .555 0 r
F
.56084 .91213 m .56869 .91114 L .5656 .91436 L F
.83367 .71146 m .84121 .71869 L .83669 .72501 L .974 .686 0 r
F
.83367 .71146 m .83822 .70487 L .84121 .71869 L F
.55085 .90176 m .55621 .90603 L .54872 .90643 L .696 .938 0 r
F
.55085 .90176 m .55862 .90138 L .55621 .90603 L F
.52621 .90714 m .53084 .91066 L .52368 .91059 L .736 .972 0 r
F
.52621 .90714 m .53372 .907 L .53084 .91066 L F
.45728 .92798 m .4541 .92882 L .44975 .92859 L .227 .176 0 r
F
.46088 .92796 m .4541 .92882 L .45728 .92798 L .247 .179 0 r
F
.67466 .84555 m .68109 .84882 L .67425 .85211 L .673 .685 0 r
F
.67466 .84555 m .68155 .84196 L .68109 .84882 L F
.39936 .90703 m .38859 .90445 L .39592 .9062 L 0 .109 0 r
F
.40636 .90856 m .39936 .90703 L .39592 .9062 L 0 .108 0 r
F
.80588 .72115 m .81465 .7283 L .81003 .73425 L 1 .834 0 r
F
.80588 .72115 m .81045 .71491 L .81465 .7283 L F
.59928 .89333 m .60489 .89604 L .5973 .89754 L .514 .576 0 r
F
.59928 .89333 m .60708 .89175 L .60489 .89604 L F
.4266 .92092 m .41587 .91959 L .42272 .92019 L .052 .146 0 r
F
.43291 .92126 m .4266 .92092 L .42272 .92019 L .053 .146 0 r
F
.4368 .92161 m .4266 .92092 L .43291 .92126 L .038 .145 0 r
F
.60957 .89932 m .61482 .9014 L .60727 .90344 L .528 .49 0 r
F
.60957 .89932 m .6173 .89705 L .61482 .9014 L F
.3897 .92 m .37833 .91663 L .38597 .91789 L .127 .151 0 r
F
.39701 .92091 m .3897 .92 L .38597 .91789 L .145 .155 0 r
F
.44245 .92173 m .4368 .92161 L .43291 .92126 L .029 .143 0 r
F
.69586 .85059 m .70196 .85383 L .6951 .8576 L .673 .615 0 r
F
.69586 .85059 m .7028 .84656 L .70196 .85383 L F
.70595 .85154 m .71196 .85496 L .70512 .85895 L .684 .612 0 r
F
.70595 .85154 m .71288 .84729 L .71196 .85496 L F
.66769 .84899 m .67425 .85211 L .66733 .85526 L .659 .683 0 r
F
.66769 .84899 m .67466 .84555 L .67425 .85211 L F
.829 .71798 m .83669 .72501 L .83205 .73126 L .974 .703 0 r
F
.829 .71798 m .83367 .71146 L .83669 .72501 L F
.42618 .92508 m .41534 .92372 L .42229 .92409 L .14 .159 0 r
F
.43257 .92516 m .42618 .92508 L .42229 .92409 L .154 .161 0 r
F
.43647 .92581 m .42618 .92508 L .43257 .92516 L .141 .161 0 r
F
.44219 .92562 m .43647 .92581 L .43257 .92516 L .152 .163 0 r
F
.8012 .72731 m .81003 .73425 L .8053 .74013 L 1 .844 0 r
F
.8012 .72731 m .80588 .72115 L .81003 .73425 L F
.41587 .91959 m .40499 .9176 L .41228 .91849 L .073 .147 0 r
F
.42272 .92019 m .41587 .91959 L .41228 .91849 L .079 .149 0 r
F
.45387 .92788 m .44975 .92859 L .44571 .92822 L .214 .173 0 r
F
.45728 .92798 m .44975 .92859 L .45387 .92788 L .227 .176 0 r
F
.5914 .89455 m .5973 .89754 L .58965 .89879 L .507 .617 0 r
F
.5914 .89455 m .59928 .89333 L .5973 .89754 L F
.54312 .90223 m .54872 .90643 L .54122 .90675 L .756 .99 0 r
F
.54312 .90223 m .55085 .90176 L .54872 .90643 L F
.52753 .91745 m .53207 .91954 L .52479 .91971 L .503 .654 0 r
F
.52753 .91745 m .53519 .91708 L .53207 .91954 L F
.55296 .91297 m .55804 .91525 L .55045 .91599 L .497 .611 0 r
F
.55296 .91297 m .56084 .91213 L .55804 .91525 L F
.68884 .8545 m .6951 .8576 L .68817 .86125 L .665 .621 0 r
F
.68884 .8545 m .69586 .85059 L .6951 .8576 L F
.60179 .90143 m .60727 .90344 L .59966 .90533 L .521 .501 0 r
F
.60179 .90143 m .60957 .89932 L .60727 .90344 L F
.66064 .85228 m .66733 .85526 L .66032 .85825 L .644 .679 0 r
F
.66064 .85228 m .66769 .84899 L .66733 .85526 L F
.69894 .85567 m .70512 .85895 L .6982 .86282 L .677 .619 0 r
F
.69894 .85567 m .70595 .85154 L .70512 .85895 L F
.43368 .91238 m .42368 .91152 L .43036 .91286 L .31 0 0 r
F
.43983 .91368 m .43368 .91238 L .43036 .91286 L .343 0 0 r
F
.44304 .91269 m .43368 .91238 L .43983 .91368 L .369 0 0 r
F
.39774 .91662 m .3868 .91362 L .39437 .91493 L .09 .147 0 r
F
.40499 .9176 m .39774 .91662 L .39437 .91493 L .101 .149 0 r
F
.51867 .90706 m .52368 .91059 L .51649 .9103 L .767 .997 0 r
F
.51867 .90706 m .52621 .90714 L .52368 .91059 L F
.82421 .72443 m .83205 .73126 L .8273 .73743 L .973 .719 0 r
F
.82421 .72443 m .829 .71798 L .83205 .73126 L F
.41534 .92372 m .40436 .92171 L .41175 .92239 L .146 .158 0 r
F
.42229 .92409 m .41534 .92372 L .41175 .92239 L .161 .161 0 r
F
.40636 .90856 m .39592 .9062 L .4033 .9079 L 0 .108 0 r
F
.41342 .91004 m .40636 .90856 L .4033 .9079 L 0 .107 0 r
F
.51013 .91953 m .51428 .92164 L .50743 .92128 L .507 .694 0 r
F
.51013 .91953 m .51747 .91972 L .51428 .92164 L F
.7964 .73339 m .8053 .74013 L .80044 .74592 L 1 .854 0 r
F
.7964 .73339 m .8012 .72731 L .8053 .74013 L F
.42368 .91152 m .41342 .91004 L .42053 .91151 L .233 0 0 r
F
.43036 .91286 m .42368 .91152 L .42053 .91151 L .256 0 0 r
F
.44855 .9141 m .44304 .91269 L .43983 .91368 L .409 0 0 r
F
.43923 .88733 m .43059 .88443 L .43677 .89244 L 1 .36 0 r
F
.44514 .89616 m .43923 .88733 L .43677 .89244 L 1 .319 0 r
F
.44747 .89052 m .43923 .88733 L .44514 .89616 L .992 .341 0 r
F
.65352 .8554 m .66032 .85825 L .65324 .86108 L .631 .673 0 r
F
.65352 .8554 m .66064 .85228 L .66032 .85825 L F
.58342 .89535 m .58965 .89879 L .58195 .89978 L .504 .67 0 r
F
.58342 .89535 m .5914 .89455 L .58965 .89879 L F
.39701 .92091 m .38597 .91789 L .39365 .91902 L .145 .155 0 r
F
.40436 .92171 m .39701 .92091 L .39365 .91902 L .161 .158 0 r
F
.68175 .85828 m .68817 .86125 L .68116 .86477 L .657 .626 0 r
F
.68175 .85828 m .68884 .8545 L .68817 .86125 L F
.69186 .85968 m .6982 .86282 L .6912 .86657 L .67 .625 0 r
F
.69186 .85968 m .69894 .85567 L .6982 .86282 L F
.43059 .88443 m .42189 .88137 L .42827 .88886 L 1 .345 0 r
F
.43677 .89244 m .43059 .88443 L .42827 .88886 L 1 .296 0 r
F
.47127 .92581 m .4722 .92705 L .4684 .9275 L .392 .348 0 r
F
.59395 .90335 m .59966 .90533 L .59199 .90705 L .513 .514 0 r
F
.59395 .90335 m .60179 .90143 L .59966 .90533 L F
.53542 .90278 m .54122 .90675 L .53372 .907 L .798 1 0 r
F
.53542 .90278 m .54312 .90223 L .54122 .90675 L F
.81931 .7308 m .8273 .73743 L .82242 .74353 L .971 .735 0 r
F
.81931 .7308 m .82421 .72443 L .8273 .73743 L F
.45387 .92788 m .44571 .92822 L .45071 .92766 L .214 .173 0 r
F
.54507 .91371 m .55045 .91599 L .54283 .91659 L .512 .666 0 r
F
.54507 .91371 m .55296 .91297 L .55045 .91599 L F
.79147 .7394 m .80044 .74592 L .79548 .75164 L 1 .863 0 r
F
.79147 .7394 m .7964 .73339 L .80044 .74592 L F
.64632 .85836 m .65324 .86108 L .64608 .86373 L .617 .664 0 r
F
.64632 .85836 m .65352 .8554 L .65324 .86108 L F
.43291 .92126 m .42272 .92019 L .42961 .92073 L .053 .146 0 r
F
.43925 .92156 m .43291 .92126 L .42961 .92073 L .043 .145 0 r
F
.44245 .92173 m .43291 .92126 L .43925 .92156 L .029 .143 0 r
F
.67458 .86193 m .68116 .86477 L .67407 .86816 L .649 .629 0 r
F
.67458 .86193 m .68175 .85828 L .68116 .86477 L F
.57537 .89564 m .58195 .89978 L .57419 .9005 L .508 .738 0 r
F
.57537 .89564 m .58342 .89535 L .58195 .89978 L F
.51984 .91767 m .52479 .91971 L .51747 .91972 L .514 .698 0 r
F
.51984 .91767 m .52753 .91745 L .52479 .91971 L F
.68469 .86357 m .6912 .86657 L .68412 .8702 L .662 .631 0 r
F
.68469 .86357 m .69186 .85968 L .6912 .86657 L F
.46309 .92695 m .46088 .92796 L .45728 .92798 L .266 .183 0 r
F
.40499 .9176 m .39437 .91493 L .40198 .91613 L .101 .149 0 r
F
.41228 .91849 m .40499 .9176 L .40198 .91613 L .109 .151 0 r
F
.42272 .92019 m .41228 .91849 L .41961 .9193 L .079 .149 0 r
F
.42961 .92073 m .42272 .92019 L .41961 .9193 L F
.63905 .86112 m .64608 .86373 L .63884 .86618 L .601 .652 0 r
F
.63905 .86112 m .64632 .85836 L .64608 .86373 L F
.51109 .90652 m .51867 .90706 L .51649 .9103 L .791 1 0 r
F
.43257 .92516 m .42229 .92409 L .42927 .92436 L .154 .161 0 r
F
.43899 .92515 m .43257 .92516 L .42927 .92436 L .161 .163 0 r
F
.44219 .92562 m .43257 .92516 L .43899 .92515 L .152 .163 0 r
F
.58605 .90508 m .59199 .90705 L .58427 .9086 L .506 .53 0 r
F
.58605 .90508 m .59395 .90335 L .59199 .90705 L F
.44814 .92187 m .44245 .92173 L .43925 .92156 L .002 .139 0 r
F
.81429 .7371 m .82242 .74353 L .81743 .74956 L .968 .749 0 r
F
.81429 .7371 m .81931 .7308 L .82242 .74353 L F
.78644 .74532 m .79548 .75164 L .7904 .75728 L 1 .871 0 r
F
.78644 .74532 m .79147 .7394 L .79548 .75164 L F
.41342 .91004 m .4033 .9079 L .41072 .90956 L 0 .107 0 r
F
.42053 .91151 m .41342 .91004 L .41072 .90956 L .159 0 0 r
F
.66734 .86545 m .67407 .86816 L .6669 .87141 L .64 .631 0 r
F
.66734 .86545 m .67458 .86193 L .67407 .86816 L F
.52771 .9033 m .53372 .907 L .52621 .90714 L .819 1 0 r
F
.52771 .9033 m .53542 .90278 L .53372 .907 L F
.40436 .92171 m .39365 .91902 L .40136 .92004 L .161 .158 0 r
F
.41175 .92239 m .40436 .92171 L .40136 .92004 L .175 .161 0 r
F
.56726 .89551 m .57419 .9005 L .5664 .90101 L .561 .817 0 r
F
.56726 .89551 m .57537 .89564 L .57419 .9005 L F
.46049 .92709 m .45728 .92798 L .45387 .92788 L .239 .178 0 r
F
.46309 .92695 m .45728 .92798 L .46049 .92709 L .266 .183 0 r
F
.42229 .92409 m .41175 .92239 L .41918 .92297 L .161 .161 0 r
F
.42927 .92436 m .42229 .92409 L .41918 .92297 L .172 .163 0 r
F
.67746 .86734 m .68412 .8702 L .67697 .87371 L .655 .635 0 r
F
.67746 .86734 m .68469 .86357 L .68412 .8702 L F
.6317 .86367 m .63884 .86618 L .63152 .86841 L .583 .636 0 r
F
.6317 .86367 m .63905 .86112 L .63884 .86618 L F
.44796 .92538 m .44219 .92562 L .43899 .92515 L .151 .163 0 r
F
.53717 .91439 m .54283 .91659 L .53519 .91708 L .527 .714 0 r
F
.53717 .91439 m .54507 .91371 L .54283 .91659 L F
.43983 .91368 m .43036 .91286 L .4371 .91426 L .343 0 0 r
F
.44603 .91514 m .43983 .91368 L .4371 .91426 L .389 0 0 r
F
.44855 .9141 m .43983 .91368 L .44603 .91514 L .409 0 0 r
F
.43036 .91286 m .42053 .91151 L .42769 .91299 L .256 0 0 r
F
.4371 .91426 m .43036 .91286 L .42769 .91299 L .291 0 0 r
F
.78129 .75117 m .7904 .75728 L .7852 .76283 L 1 .879 0 r
F
.78129 .75117 m .78644 .74532 L .7904 .75728 L F
.80916 .74332 m .81743 .74956 L .81232 .75551 L .965 .763 0 r
F
.80916 .74332 m .81429 .7371 L .81743 .74956 L F
.5781 .90657 m .58427 .9086 L .57651 .90997 L .5 .552 0 r
F
.5781 .90657 m .58605 .90508 L .58427 .9086 L F
.66004 .86883 m .6669 .87141 L .65967 .87453 L .63 .632 0 r
F
.66004 .86883 m .66734 .86545 L .6669 .87141 L F
.62428 .86599 m .63152 .86841 L .62412 .8704 L .561 .616 0 r
F
.62428 .86599 m .6317 .86367 L .63152 .86841 L F
.55921 .89534 m .5664 .90101 L .55862 .90138 L .67 .911 0 r
F
.55921 .89534 m .56726 .89551 L .5664 .90101 L F
.67016 .87098 m .67697 .87371 L .66974 .87709 L .647 .638 0 r
F
.67016 .87098 m .67746 .86734 L .67697 .87371 L F
.4578 .89461 m .45136 .86612 L .45709 .9006 L 1 .61 0 r
F
.45803 .92712 m .45387 .92788 L .45071 .92766 L .219 .175 0 r
F
.46049 .92709 m .45387 .92788 L .45803 .92712 L .239 .178 0 r
F
.41228 .91849 m .40198 .91613 L .40964 .91725 L .109 .151 0 r
F
.41961 .9193 m .41228 .91849 L .40964 .91725 L .114 .152 0 r
F
.51213 .91768 m .51747 .91972 L .51013 .91953 L .522 .743 0 r
F
.51213 .91768 m .51984 .91767 L .51747 .91972 L F
.61677 .86802 m .62412 .8704 L .61663 .8721 L .536 .589 0 r
F
.61677 .86802 m .62428 .86599 L .62412 .8704 L F
.48728 .85725 m .49627 .89613 L .48798 .87962 L .079 .027 0 r
F
.77602 .75692 m .7852 .76283 L .7799 .7683 L 1 .886 0 r
F
.77602 .75692 m .78129 .75117 L .7852 .76283 L F
.51997 .90359 m .52621 .90714 L .51867 .90706 L .82 1 0 r
F
.51997 .90359 m .52771 .9033 L .52621 .90714 L F
.43677 .89244 m .42827 .88886 L .43495 .89591 L 1 .296 0 r
F
.44328 .89998 m .43677 .89244 L .43495 .89591 L 1 .247 0 r
F
.44514 .89616 m .43677 .89244 L .44328 .89998 L 1 .319 0 r
F
.65267 .87206 m .65967 .87453 L .65236 .87751 L .621 .632 0 r
F
.65267 .87206 m .66004 .86883 L .65967 .87453 L F
.80392 .74946 m .81232 .75551 L .80711 .76137 L .962 .775 0 r
F
.80392 .74946 m .80916 .74332 L .81232 .75551 L F
.48349 .92463 m .48622 .92668 L .48139 .92549 L .508 .708 0 r
F
.48349 .92463 m .48912 .92578 L .48622 .92668 L F
.42053 .91151 m .41072 .90956 L .4182 .9112 L .159 0 0 r
F
.42769 .91299 m .42053 .91151 L .4182 .9112 L .182 0 0 r
F
.5701 .90781 m .57651 .90997 L .56869 .91114 L .496 .584 0 r
F
.5701 .90781 m .5781 .90657 L .57651 .90997 L F
.55131 .89565 m .55862 .90138 L .55085 .90176 L .8 1 0 r
F
.55131 .89565 m .55921 .89534 L .55862 .90138 L F
.43925 .92156 m .42961 .92073 L .43655 .92123 L .043 .145 0 r
F
.44814 .92187 m .43925 .92156 L .44564 .92188 L .002 .139 0 r
F
.44564 .92188 m .43925 .92156 L .43655 .92123 L .015 .141 0 r
F
.52927 .91501 m .53519 .91708 L .52753 .91745 L .537 .749 0 r
F
.52927 .91501 m .53717 .91439 L .53519 .91708 L F
.66279 .87449 m .66974 .87709 L .66245 .88035 L .638 .641 0 r
F
.66279 .87449 m .67016 .87098 L .66974 .87709 L F
.42961 .92073 m .41961 .9193 L .42698 .92005 L .079 .149 0 r
F
.43655 .92123 m .42961 .92073 L .42698 .92005 L .068 .148 0 r
F
.60916 .86972 m .61663 .8721 L .60904 .87346 L .504 .553 0 r
F
.60916 .86972 m .61677 .86802 L .61663 .8721 L F
.45138 .90447 m .44514 .89616 L .44328 .89998 L 1 .28 0 r
F
.41175 .92239 m .40136 .92004 L .40911 .92095 L .175 .161 0 r
F
.41918 .92297 m .41175 .92239 L .40911 .92095 L .187 .163 0 r
F
.77065 .76259 m .7799 .7683 L .77449 .77368 L .999 .892 0 r
F
.77065 .76259 m .77602 .75692 L .7799 .7683 L F
.64523 .87515 m .65236 .87751 L .64499 .88033 L .61 .63 0 r
F
.64523 .87515 m .65267 .87206 L .65236 .87751 L F
.60145 .87099 m .60904 .87346 L .60134 .87438 L .462 .504 0 r
F
.60145 .87099 m .60916 .86972 L .60904 .87346 L F
.79857 .75552 m .80711 .76137 L .80178 .76715 L .958 .787 0 r
F
.79857 .75552 m .80392 .74946 L .80711 .76137 L F
.45803 .92712 m .45071 .92766 L .45574 .92705 L .219 .175 0 r
F
.43899 .92515 m .42927 .92436 L .43629 .92456 L .161 .163 0 r
F
.44545 .92509 m .43899 .92515 L .43629 .92456 L .158 .163 0 r
F
.44796 .92538 m .43899 .92515 L .44545 .92509 L .151 .163 0 r
F
.42927 .92436 m .41918 .92297 L .42664 .92346 L .172 .163 0 r
F
.43629 .92456 m .42927 .92436 L .42664 .92346 L .178 .164 0 r
F
.5936 .87166 m .60134 .87438 L .59351 .87471 L .404 .435 0 r
F
.5936 .87166 m .60145 .87099 L .60134 .87438 L F
.65536 .87787 m .66245 .88035 L .65508 .88347 L .63 .642 0 r
F
.65536 .87787 m .66279 .87449 L .66245 .88035 L F
.54355 .89655 m .55085 .90176 L .54312 .90223 L .893 1 0 r
F
.54355 .89655 m .55131 .89565 L .55085 .90176 L F
.56206 .90878 m .56869 .91114 L .56084 .91213 L .499 .634 0 r
F
.56206 .90878 m .5701 .90781 L .56869 .91114 L F
.51219 .90331 m .51867 .90706 L .51109 .90652 L .802 1 0 r
F
.51219 .90331 m .51997 .90359 L .51867 .90706 L F
.48533 .92368 m .48912 .92578 L .48349 .92463 L .529 .764 0 r
F
.48533 .92368 m .49168 .92477 L .48912 .92578 L F
.58555 .87144 m .59351 .87471 L .58551 .87422 L .319 .336 0 r
F
.58555 .87144 m .5936 .87166 L .59351 .87471 L F
.4371 .91426 m .42769 .91299 L .43491 .91452 L .291 0 0 r
F
.4439 .9158 m .4371 .91426 L .43491 .91452 L .342 0 0 r
F
.44603 .91514 m .4371 .91426 L .4439 .9158 L .389 0 0 r
F
.76518 .76817 m .77449 .77368 L .76897 .77897 L .99 .897 0 r
F
.76518 .76817 m .77065 .76259 L .77449 .77368 L F
.63773 .87807 m .64499 .88033 L .63754 .88299 L .598 .627 0 r
F
.63773 .87807 m .64523 .87515 L .64499 .88033 L F
.41961 .9193 m .40964 .91725 L .41733 .91828 L .114 .152 0 r
F
.42698 .92005 m .41961 .9193 L .41733 .91828 L .112 .153 0 r
F
.49572 .90108 m .50199 .90826 L .49466 .9054 L .775 .81 0 r
F
.49572 .90108 m .50345 .90498 L .50199 .90826 L F
.79311 .76149 m .80178 .76715 L .79634 .77285 L .953 .798 0 r
F
.79311 .76149 m .79857 .75552 L .80178 .76715 L F
.52134 .91551 m .52753 .91745 L .51984 .91767 L .546 .769 0 r
F
.52134 .91551 m .52927 .91501 L .52753 .91745 L F
.64786 .88112 m .65508 .88347 L .64765 .88647 L .621 .642 0 r
F
.64786 .88112 m .65536 .87787 L .65508 .88347 L F
.4523 .91688 m .44603 .91514 L .4439 .9158 L .451 0 0 r
F
.53586 .8978 m .54312 .90223 L .53542 .90278 L .929 1 0 r
F
.53586 .8978 m .54355 .89655 L .54312 .90223 L F
.47361 .92542 m .47398 .92741 L .472 .92599 L .502 .641 0 r
F
.47361 .92542 m .4766 .92688 L .47398 .92741 L F
.42769 .91299 m .4182 .9112 L .42573 .91285 L .182 0 0 r
F
.43491 .91452 m .42769 .91299 L .42573 .91285 L .217 0 0 r
F
.63016 .88082 m .63754 .88299 L .63003 .88549 L .586 .622 0 r
F
.63016 .88082 m .63773 .87807 L .63754 .88299 L F
.75959 .77365 m .76897 .77897 L .76335 .78416 L .981 .901 0 r
F
.75959 .77365 m .76518 .76817 L .76897 .77897 L F
.41918 .92297 m .40911 .92095 L .4169 .92175 L .187 .163 0 r
F
.42664 .92346 m .41918 .92297 L .4169 .92175 L .196 .165 0 r
F
.55399 .90958 m .56084 .91213 L .55296 .91297 L .516 .704 0 r
F
.55399 .90958 m .56206 .90878 L .56084 .91213 L F
.47514 .92474 m .4766 .92688 L .47361 .92542 L .541 .753 0 r
F
.47514 .92474 m .47909 .92624 L .4766 .92688 L F
.78754 .76737 m .79634 .77285 L .79079 .77846 L .948 .808 0 r
F
.78754 .76737 m .79311 .76149 L .79634 .77285 L F
.64031 .88424 m .64765 .88647 L .64015 .88933 L .612 .642 0 r
F
.64031 .88424 m .64786 .88112 L .64765 .88647 L F
.43655 .92123 m .42698 .92005 L .43439 .92076 L .068 .148 0 r
F
.44564 .92188 m .43655 .92123 L .44352 .92174 L .015 .141 0 r
F
.44352 .92174 m .43655 .92123 L .43439 .92076 L .041 .144 0 r
F
.48688 .92262 m .49168 .92477 L .48533 .92368 L .554 .802 0 r
F
.48688 .92262 m .49385 .92367 L .49168 .92477 L F
.62253 .88339 m .63003 .88549 L .62245 .88779 L .572 .615 0 r
F
.62253 .88339 m .63016 .88082 L .63003 .88549 L F
.52815 .89905 m .53542 .90278 L .52771 .9033 L .921 1 0 r
F
.52815 .89905 m .53586 .8978 L .53542 .90278 L F
.48798 .87962 m .49627 .89613 L .49572 .90108 L .448 .233 0 r
F
.75391 .77904 m .76335 .78416 L .75762 .78926 L .971 .905 0 r
F
.75391 .77904 m .75959 .77365 L .76335 .78416 L F
.44328 .89998 m .43495 .89591 L .44191 .9026 L 1 .247 0 r
F
.45008 .90717 m .44328 .89998 L .44191 .9026 L 1 .204 0 r
F
.45138 .90447 m .44328 .89998 L .45008 .90717 L 1 .28 0 r
F
.47655 .92395 m .47909 .92624 L .47514 .92474 L .61 .846 0 r
F
.47655 .92395 m .48139 .92549 L .47909 .92624 L F
.45206 .9223 m .44564 .92188 L .44352 .92174 L 0 .129 0 r
F
.54596 .91042 m .55296 .91297 L .54507 .91371 L .559 .786 0 r
F
.54596 .91042 m .55399 .90958 L .55296 .91297 L F
.51339 .91579 m .51984 .91767 L .51213 .91768 L .547 .782 0 r
F
.51339 .91579 m .52134 .91551 L .51984 .91767 L F
.43629 .92456 m .42664 .92346 L .43413 .92386 L .178 .164 0 r
F
.44334 .9247 m .43629 .92456 L .43413 .92386 L .173 .164 0 r
F
.44545 .92509 m .43629 .92456 L .44334 .9247 L .158 .163 0 r
F
.63269 .88721 m .64015 .88933 L .6326 .89205 L .602 .64 0 r
F
.63269 .88721 m .64031 .88424 L .64015 .88933 L F
.78187 .77316 m .79079 .77846 L .78514 .78398 L .942 .817 0 r
F
.78187 .77316 m .78754 .76737 L .79079 .77846 L F
.42698 .92005 m .41733 .91828 L .42505 .91925 L .112 .153 0 r
F
.43439 .92076 m .42698 .92005 L .42505 .91925 L .102 .152 0 r
F
.61483 .88573 m .62245 .88779 L .6148 .88989 L .556 .606 0 r
F
.61483 .88573 m .62253 .88339 L .62245 .88779 L F
.4966 .91625 m .50276 .91903 L .49535 .91801 L .599 .853 0 r
F
.74812 .78433 m .75762 .78926 L .75179 .79426 L .961 .907 0 r
F
.74812 .78433 m .75391 .77904 L .75762 .78926 L F
.49627 .89613 m .50345 .90498 L .49572 .90108 L .597 .611 0 r
F
.49627 .89613 m .50431 .90167 L .50345 .90498 L F
.45194 .92504 m .44545 .92509 L .44334 .9247 L .134 .16 0 r
F
.52039 .9 m .52771 .9033 L .51997 .90359 L .883 1 0 r
F
.52039 .9 m .52815 .89905 L .52771 .9033 L F
.47783 .92305 m .48139 .92549 L .47655 .92395 L .668 .913 0 r
F
.4439 .9158 m .43491 .91452 L .44219 .91617 L .342 0 0 r
F
.45076 .9176 m .4439 .9158 L .44219 .91617 L .413 0 0 r
F
.4523 .91688 m .4439 .9158 L .45076 .9176 L .451 0 0 r
F
.60705 .88782 m .6148 .88989 L .60708 .89175 L .536 .595 0 r
F
.60705 .88782 m .61483 .88573 L .6148 .88989 L F
.42664 .92346 m .4169 .92175 L .42471 .92246 L .196 .165 0 r
F
.43413 .92386 m .42664 .92346 L .42471 .92246 L .199 .166 0 r
F
.43491 .91452 m .42573 .91285 L .43331 .91453 L .217 0 0 r
F
.44219 .91617 m .43491 .91452 L .43331 .91453 L .269 0 0 r
F
.62502 .89004 m .6326 .89205 L .62498 .89462 L .592 .637 0 r
F
.62502 .89004 m .63269 .88721 L .6326 .89205 L F
.53795 .91138 m .54507 .91371 L .53717 .91439 L .611 .843 0 r
F
.53795 .91138 m .54596 .91042 L .54507 .91371 L F
.7761 .77887 m .78514 .78398 L .77938 .7894 L .936 .825 0 r
F
.7761 .77887 m .78187 .77316 L .78514 .78398 L F
.74224 .78952 m .75179 .79426 L .74586 .79916 L .95 .909 0 r
F
.74224 .78952 m .74812 .78433 L .75179 .79426 L F
.49689 .92125 m .50305 .92306 L .4956 .92249 L .487 .7 0 r
F
.49689 .92125 m .50471 .92172 L .50305 .92306 L F
.48813 .92146 m .49385 .92367 L .48688 .92262 L .564 .818 0 r
F
.48813 .92146 m .4956 .92249 L .49385 .92367 L F
.54388 .82645 m .55873 .8618 L .55775 .85257 L 1 .123 0 r
F
.59919 .88957 m .60708 .89175 L .59928 .89333 L .513 .583 0 r
F
.59919 .88957 m .60705 .88782 L .60708 .89175 L F
.51256 .90023 m .51997 .90359 L .51219 .90331 L .814 1 0 r
F
.51256 .90023 m .52039 .9 L .51997 .90359 L F
.6173 .89272 m .62498 .89462 L .6173 .89705 L .582 .633 0 r
F
.6173 .89272 m .62502 .89004 L .62498 .89462 L F
.73625 .79461 m .74586 .79916 L .73984 .80395 L .938 .91 0 r
F
.73625 .79461 m .74224 .78952 L .74586 .79916 L F
.77023 .78447 m .77938 .7894 L .77351 .79474 L .929 .832 0 r
F
.77023 .78447 m .7761 .77887 L .77938 .7894 L F
.59122 .89084 m .59928 .89333 L .5914 .89455 L .481 .569 0 r
F
.59122 .89084 m .59919 .88957 L .59928 .89333 L F
.52996 .91238 m .53717 .91439 L .52927 .91501 L .626 .859 0 r
F
.52996 .91238 m .53795 .91138 L .53717 .91439 L F
.44352 .92174 m .43439 .92076 L .44184 .92147 L .041 .144 0 r
F
.45054 .92234 m .44352 .92174 L .44184 .92147 L 0 .134 0 r
F
.45206 .9223 m .44352 .92174 L .45054 .92234 L 0 .129 0 r
F
.43439 .92076 m .42505 .91925 L .43281 .92017 L .102 .152 0 r
F
.44184 .92147 m .43439 .92076 L .43281 .92017 L .077 .149 0 r
F
.46454 .91841 m .4578 .89461 L .45709 .9006 L 1 .542 0 r
F
.60953 .89524 m .6173 .89705 L .60957 .89932 L .57 .627 0 r
F
.60953 .89524 m .6173 .89272 L .6173 .89705 L F
.58307 .89132 m .5914 .89455 L .58342 .89535 L .434 .552 0 r
F
.58307 .89132 m .59122 .89084 L .5914 .89455 L F
.73018 .79959 m .73984 .80395 L .73372 .80864 L .926 .91 0 r
F
.73018 .79959 m .73625 .79461 L .73984 .80395 L F
.44334 .9247 m .43413 .92386 L .44165 .92422 L .173 .164 0 r
F
.45042 .92485 m .44334 .9247 L .44165 .92422 L .149 .162 0 r
F
.45194 .92504 m .44334 .9247 L .45042 .92485 L .134 .16 0 r
F
.45008 .90717 m .44191 .9026 L .44912 .90905 L 1 .204 0 r
F
.76426 .78998 m .77351 .79474 L .76755 .79997 L .921 .839 0 r
F
.76426 .78998 m .77023 .78447 L .77351 .79474 L F
.57462 .89034 m .58342 .89535 L .57537 .89564 L .365 .509 0 r
F
.57462 .89034 m .58307 .89132 L .58342 .89535 L F
.43413 .92386 m .42471 .92246 L .43256 .92309 L .199 .166 0 r
F
.44165 .92422 m .43413 .92386 L .43256 .92309 L .193 .166 0 r
F
.56578 .88718 m .57537 .89564 L .56726 .89551 L .319 .45 0 r
F
.56578 .88718 m .57462 .89034 L .57537 .89564 L F
.52194 .91328 m .52927 .91501 L .52134 .91551 L .61 .845 0 r
F
.52194 .91328 m .52996 .91238 L .52927 .91501 L F
.49737 .91442 m .50438 .91732 L .4966 .91625 L .54 .794 0 r
F
.49737 .91442 m .5054 .91561 L .50438 .91732 L F
.6017 .8976 m .60957 .89932 L .60179 .90143 L .558 .621 0 r
F
.6017 .8976 m .60953 .89524 L .60957 .89932 L F
.55726 .88458 m .56726 .89551 L .55921 .89534 L .572 .702 0 r
F
.55726 .88458 m .56578 .88718 L .56726 .89551 L F
.44219 .91617 m .43331 .91453 L .44095 .91632 L .269 0 0 r
F
.44953 .91806 m .44219 .91617 L .44095 .91632 L .345 0 0 r
F
.45076 .9176 m .44219 .91617 L .44953 .91806 L .413 0 0 r
F
.72401 .80447 m .73372 .80864 L .72751 .81322 L .914 .909 0 r
F
.72401 .80447 m .73018 .79959 L .73372 .80864 L F
.4691 .92582 m .47034 .92647 L .46865 .92685 L .491 .489 0 r
F
.46976 .92562 m .47035 .92449 L .4691 .92582 L .087 0 0 r
F
.4694 .92511 m .46976 .92562 L .4691 .92582 L .491 .489 0 r
F
.46976 .92562 m .47034 .92647 L .46925 .9259 L F
.47001 .92585 m .47012 .92543 L .4694 .92631 L 0 0 0 r
F
.47015 .92528 m .47035 .92449 L .46976 .92562 L F
.4691 .92582 m .47035 .92449 L .46866 .9251 L .087 0 0 r
F
.47002 .92443 m .47015 .92528 L .4694 .92511 L .577 .734 0 r
F
.47015 .92528 m .47034 .92647 L .46976 .92562 L F
.47015 .92528 m .46976 .92562 L .4694 .92511 L F
.47012 .92543 m .47015 .92528 L .46976 .92562 L 0 0 0 r
F
.47012 .92543 m .46976 .92562 L .4694 .92631 L F
.46976 .92562 m .46925 .9259 L .4691 .92582 L .491 .489 0 r
F
.4694 .92631 m .46976 .92562 L .4691 .92582 L .087 0 0 r
F
.54965 .88583 m .55921 .89534 L .55131 .89565 L .982 .971 0 r
F
.54965 .88583 m .55726 .88458 L .55921 .89534 L F
.48904 .92019 m .4956 .92249 L .48813 .92146 L .552 .809 0 r
F
.48904 .92019 m .49689 .92125 L .4956 .92249 L F
.4691 .92582 m .46866 .9251 L .46873 .92611 L .087 0 0 r
F
.4694 .92511 m .4691 .92582 L .46878 .92567 L .491 .489 0 r
F
.4691 .92582 m .46865 .92685 L .46873 .92611 L F
.4691 .92582 m .46873 .92611 L .46878 .92567 L F
.4694 .92631 m .4691 .92582 L .46877 .9267 L .087 0 0 r
F
.4691 .92582 m .46873 .92611 L .46877 .9267 L F
.75819 .79539 m .76755 .79997 L .76149 .80511 L .913 .844 0 r
F
.75819 .79539 m .76426 .78998 L .76755 .79997 L F
.54235 .88882 m .55131 .89565 L .54355 .89655 L 1 1 0 r
F
.54235 .88882 m .54965 .88583 L .55131 .89565 L F
.59382 .89976 m .60179 .90143 L .59395 .90335 L .544 .612 0 r
F
.59382 .89976 m .6017 .8976 L .60179 .90143 L F
.71776 .80923 m .72751 .81322 L .7212 .81769 L .901 .907 0 r
F
.71776 .80923 m .72401 .80447 L .72751 .81322 L F
.535 .89188 m .54355 .89655 L .53586 .8978 L 1 1 0 r
F
.535 .89188 m .54235 .88882 L .54355 .89655 L F
.47117 .92594 m .47514 .92474 L .47361 .92542 L .391 .202 0 r
F
.4977 .91998 m .50471 .92172 L .49689 .92125 L .471 .679 0 r
F
.4977 .91998 m .50577 .92038 L .50471 .92172 L F
.5139 .91391 m .52134 .91551 L .51339 .91579 L .576 .816 0 r
F
.5139 .91391 m .52194 .91328 L .52134 .91551 L F
.54607 .83691 m .56578 .88718 L .55726 .88458 L .056 .04 0 r
F
.54607 .83691 m .55882 .86216 L .56578 .88718 L F
.54497 .86742 m .54607 .83691 L .55726 .88458 L 1 .778 0 r
F
.75203 .8007 m .76149 .80511 L .75533 .81015 L .905 .849 0 r
F
.75203 .8007 m .75819 .79539 L .76149 .80511 L F
.47169 .92539 m .47514 .92474 L .47117 .92594 L .532 .249 0 r
F
.47169 .92539 m .47655 .92395 L .47514 .92474 L F
.44184 .92147 m .43281 .92017 L .44061 .9211 L .077 .149 0 r
F
.45054 .92234 m .44184 .92147 L .44932 .92227 L 0 .134 0 r
F
.44932 .92227 m .44184 .92147 L .44061 .9211 L .026 .141 0 r
F
.58589 .9017 m .59395 .90335 L .58605 .90508 L .528 .603 0 r
F
.58589 .9017 m .59382 .89976 L .59395 .90335 L F
.52754 .8945 m .53586 .8978 L .52815 .89905 L 1 1 0 r
F
.52754 .8945 m .535 .89188 L .53586 .8978 L F
.48929 .91125 m .49737 .91442 L .4966 .91625 L .575 .739 0 r
F
.71142 .81388 m .7212 .81769 L .71481 .82204 L .887 .905 0 r
F
.71142 .81388 m .71776 .80923 L .7212 .81769 L F
.46454 .91841 m .45709 .9006 L .46433 .91967 L 1 .542 0 r
F
.47216 .92475 m .47655 .92395 L .47169 .92539 L .657 .602 0 r
F
.47216 .92475 m .47783 .92305 L .47655 .92395 L F
.45759 .92325 m .45054 .92234 L .44932 .92227 L .134 0 0 r
F
.51994 .8965 m .52815 .89905 L .52039 .9 L .959 1 0 r
F
.51994 .8965 m .52754 .8945 L .52815 .89905 L F
.44165 .92422 m .43256 .92309 L .44043 .92367 L .193 .166 0 r
F
.44921 .92459 m .44165 .92422 L .44043 .92367 L .171 .163 0 r
F
.45042 .92485 m .44165 .92422 L .44921 .92459 L .149 .162 0 r
F
.57789 .90335 m .58605 .90508 L .5781 .90657 L .509 .594 0 r
F
.57789 .90335 m .58589 .9017 L .58605 .90508 L F
.55873 .8618 m .56801 .86881 L .56822 .86493 L .726 .039 0 r
F
.74578 .80591 m .75533 .81015 L .74908 .81508 L .896 .853 0 r
F
.74578 .80591 m .75203 .8007 L .75533 .81015 L F
.70499 .81842 m .71481 .82204 L .70832 .82628 L .872 .9 0 r
F
.70499 .81842 m .71142 .81388 L .71481 .82204 L F
.51222 .89758 m .52039 .9 L .51256 .90023 L .839 1 0 r
F
.51222 .89758 m .51994 .8965 L .52039 .9 L F
.47258 .924 m .47783 .92305 L .47216 .92475 L .858 .919 0 r
F
.45715 .91426 m .44912 .90905 L .45659 .91549 L 1 .178 0 r
F
.56981 .90457 m .5781 .90657 L .5701 .90781 L .484 .589 0 r
F
.56981 .90457 m .57789 .90335 L .5781 .90657 L F
.4896 .91877 m .49689 .92125 L .48904 .92019 L .507 .764 0 r
F
.4896 .91877 m .4977 .91998 L .49689 .92125 L F
.44953 .91806 m .44095 .91632 L .44864 .91832 L .345 0 0 r
F
.45695 .92043 m .44953 .91806 L .44864 .91832 L .455 0 0 r
F
.73944 .81101 m .74908 .81508 L .74273 .81991 L .886 .856 0 r
F
.73944 .81101 m .74578 .80591 L .74908 .81508 L F
.49765 .91266 m .5054 .91561 L .49737 .91442 L .442 .675 0 r
F
.49765 .91266 m .50581 .91401 L .5054 .91561 L F
.56162 .90512 m .5701 .90781 L .56206 .90878 L .454 .599 0 r
F
.56162 .90512 m .56981 .90457 L .5701 .90781 L F
.69189 .82712 m .70176 .83039 L .6951 .83438 L .841 .888 0 r
F
.69189 .82712 m .69848 .82283 L .70176 .83039 L F
.48799 .88599 m .49747 .91136 L .48905 .90143 L .873 .122 0 r
F
.4965 .91115 m .49747 .91136 L .49765 .91266 L 0 .042 0 r
F
.48905 .90143 m .49747 .91136 L .4965 .91115 L F
.49747 .91136 m .50581 .91401 L .49765 .91266 L .344 .483 0 r
F
.49688 .91133 m .4984 .91156 L .49747 .91136 L .299 .325 0 r
F
.49747 .91136 m .50561 .91266 L .50581 .91401 L .344 .483 0 r
F
.4984 .91156 m .50561 .91266 L .49747 .91136 L .299 .325 0 r
F
.48799 .88599 m .49688 .91133 L .49747 .91136 L .873 .122 0 r
F
.55339 .90522 m .56206 .90878 L .55399 .90958 L .478 .706 0 r
F
.55339 .90522 m .56162 .90512 L .56206 .90878 L F
.73301 .81601 m .74273 .81991 L .73629 .82463 L .876 .858 0 r
F
.73301 .81601 m .73944 .81101 L .74273 .81991 L F
.44932 .92227 m .44061 .9211 L .44844 .92211 L .026 .141 0 r
F
.45759 .92325 m .44932 .92227 L .45685 .92336 L .134 0 0 r
F
.45685 .92336 m .44932 .92227 L .44844 .92211 L 0 .121 0 r
F
.4894 .9077 m .49737 .91442 L .48929 .91125 L .352 .441 0 r
F
.4894 .9077 m .49765 .91266 L .49737 .91442 L F
.68522 .83129 m .6951 .83438 L .68837 .83824 L .824 .88 0 r
F
.68522 .83129 m .69189 .82712 L .6951 .83438 L F
.54538 .90625 m .55399 .90958 L .54596 .91042 L .704 .946 0 r
F
.54538 .90625 m .55339 .90522 L .55399 .90958 L F
.56801 .86881 m .57633 .87087 L .57719 .8697 L .321 0 0 r
F
.49802 .91873 m .50577 .92038 L .4977 .91998 L .437 .616 0 r
F
.49802 .91873 m .50621 .91908 L .50577 .92038 L F
.44921 .92459 m .44043 .92367 L .44833 .92426 L .171 .163 0 r
F
.45679 .92511 m .44921 .92459 L .44833 .92426 L .108 .154 0 r
F
.67848 .83532 m .68837 .83824 L .68155 .84196 L .805 .871 0 r
F
.67848 .83532 m .68522 .83129 L .68837 .83824 L F
.53749 .90793 m .54596 .91042 L .53795 .91138 L .798 1 0 r
F
.53749 .90793 m .54538 .90625 L .54596 .91042 L F
.7265 .82089 m .73629 .82463 L .72976 .82924 L .866 .859 0 r
F
.7265 .82089 m .73301 .81601 L .73629 .82463 L F
.45695 .92043 m .44864 .91832 L .4564 .92077 L .455 0 0 r
F
.67166 .83922 m .68155 .84196 L .67466 .84555 L .786 .859 0 r
F
.67166 .83922 m .67848 .83532 L .68155 .84196 L F
.52958 .90961 m .53795 .91138 L .52996 .91238 L .759 .989 0 r
F
.52958 .90961 m .53749 .90793 L .53795 .91138 L F
.58428 .87104 m .5936 .87166 L .58555 .87144 L .251 .182 0 r
F
.57633 .87087 m .58428 .87104 L .58555 .87144 L .03 .144 0 r
F
.48905 .90143 m .49765 .91266 L .4894 .9077 L 0 .042 0 r
F
.7199 .82566 m .72976 .82924 L .72315 .83374 L .854 .859 0 r
F
.7199 .82566 m .7265 .82089 L .72976 .82924 L F
.4898 .91708 m .4977 .91998 L .4896 .91877 L .422 .64 0 r
F
.4898 .91708 m .49802 .91873 L .4977 .91998 L F
.66476 .84298 m .67466 .84555 L .66769 .84899 L .764 .845 0 r
F
.66476 .84298 m .67166 .83922 L .67466 .84555 L F
.52164 .91106 m .52996 .91238 L .52194 .91328 L .687 .924 0 r
F
.52164 .91106 m .52958 .90961 L .52996 .91238 L F
.46448 .92207 m .45659 .91549 L .46428 .92268 L 1 .202 0 r
F
.49568 .89092 m .50361 .89619 L .50435 .89677 L 0 .043 0 r
F
.6578 .8466 m .66769 .84899 L .66064 .85228 L .741 .829 0 r
F
.6578 .8466 m .66476 .84298 L .66769 .84899 L F
.45685 .92336 m .44844 .92211 L .45632 .92339 L 0 .121 0 r
F
.51365 .91216 m .52194 .91328 L .5139 .91391 L .607 .847 0 r
F
.51365 .91216 m .52164 .91106 L .52194 .91328 L F
.59203 .87021 m .60145 .87099 L .5936 .87166 L .382 .264 0 r
F
.58428 .87104 m .59203 .87021 L .5936 .87166 L .251 .182 0 r
F
.71322 .83032 m .72315 .83374 L .71645 .83813 L .843 .858 0 r
F
.71322 .83032 m .7199 .82566 L .72315 .83374 L F
.65077 .85006 m .66064 .85228 L .65352 .8554 L .716 .809 0 r
F
.65077 .85006 m .6578 .8466 L .66064 .85228 L F
.54497 .86742 m .55726 .88458 L .54965 .88583 L 1 .778 0 r
F
.53949 .87873 m .54965 .88583 L .54235 .88882 L 1 .924 0 r
F
.53949 .87873 m .54497 .86742 L .54965 .88583 L F
.64367 .85336 m .65352 .8554 L .64632 .85836 L .688 .785 0 r
F
.64367 .85336 m .65077 .85006 L .65352 .8554 L F
.46443 .92542 m .45685 .92336 L .45632 .92339 L .333 0 0 r
F
.59965 .86876 m .60916 .86972 L .60145 .87099 L .464 .422 0 r
F
.59203 .87021 m .59965 .86876 L .60145 .87099 L .382 .264 0 r
F
.45679 .92511 m .44833 .92426 L .45626 .925 L .108 .154 0 r
F
.51122 .89562 m .51994 .8965 L .51222 .89758 L .882 1 0 r
F
.53294 .88541 m .54235 .88882 L .535 .89188 L 1 1 0 r
F
.53294 .88541 m .53949 .87873 L .54235 .88882 L F
.63651 .85648 m .64632 .85836 L .63905 .86112 L .656 .756 0 r
F
.63651 .85648 m .64367 .85336 L .64632 .85836 L F
.60717 .86687 m .61677 .86802 L .60916 .86972 L .52 .534 0 r
F
.59965 .86876 m .60717 .86687 L .60916 .86972 L .464 .422 0 r
F
.62928 .85942 m .63905 .86112 L .6317 .86367 L .62 .72 0 r
F
.62928 .85942 m .63651 .85648 L .63905 .86112 L F
.52593 .89004 m .535 .89188 L .52754 .8945 L 1 1 0 r
F
.52593 .89004 m .53294 .88541 L .535 .89188 L F
.61461 .86465 m .62428 .86599 L .61677 .86802 L .56 .615 0 r
F
.60717 .86687 m .61461 .86465 L .61677 .86802 L .52 .534 0 r
F
.62198 .86215 m .6317 .86367 L .62428 .86599 L .591 .674 0 r
F
.62198 .86215 m .62928 .85942 L .6317 .86367 L F
.51866 .8934 m .52754 .8945 L .51994 .8965 L 1 1 0 r
F
.51122 .89562 m .51866 .8934 L .51994 .8965 L .882 1 0 r
F
.61461 .86465 m .62198 .86215 L .62428 .86599 L .56 .615 0 r
F
.51866 .8934 m .52593 .89004 L .52754 .8945 L 1 1 0 r
F
.69963 .83929 m .70966 .8424 L .7028 .84656 L .818 .854 0 r
F
.69963 .83929 m .70646 .83487 L .70966 .8424 L F
.46443 .92542 m .45632 .92339 L .46423 .9256 L .333 0 0 r
F
.48961 .91472 m .49802 .91873 L .4898 .91708 L .203 .253 0 r
F
.69272 .8436 m .7028 .84656 L .69586 .85059 L .804 .85 0 r
F
.69272 .8436 m .69963 .83929 L .7028 .84656 L F
.49785 .91768 m .50621 .91908 L .49802 .91873 L .388 .509 0 r
F
.49785 .91768 m .50602 .91791 L .50621 .91908 L F
.55882 .86216 m .57462 .89034 L .56578 .88718 L .723 .075 0 r
F
.48961 .91472 m .49785 .91768 L .49802 .91873 L .203 .253 0 r
F
.68574 .84778 m .69586 .85059 L .68884 .8545 L .79 .845 0 r
F
.68574 .84778 m .69272 .8436 L .69586 .85059 L F
.70269 .84411 m .71288 .84729 L .70595 .85154 L .826 .862 0 r
F
.70269 .84411 m .7096 .83959 L .71288 .84729 L F
.6787 .85183 m .68884 .8545 L .68175 .85828 L .775 .84 0 r
F
.6787 .85183 m .68574 .84778 L .68884 .8545 L F
.67158 .85576 m .68175 .85828 L .67458 .86193 L .759 .832 0 r
F
.67158 .85576 m .6787 .85183 L .68175 .85828 L F
.48901 .91104 m .49785 .91768 L .48961 .91472 L .431 0 0 r
F
.69572 .84851 m .70595 .85154 L .69894 .85567 L .813 .86 0 r
F
.69572 .84851 m .70269 .84411 L .70595 .85154 L F
.55882 .86216 m .57307 .88914 L .57462 .89034 L .723 .075 0 r
F
.57307 .88914 m .58307 .89132 L .57462 .89034 L .148 .161 0 r
F
.6644 .85956 m .67458 .86193 L .66734 .86545 L .743 .824 0 r
F
.6644 .85956 m .67158 .85576 L .67458 .86193 L F
.68867 .85279 m .69894 .85567 L .69186 .85968 L .8 .856 0 r
F
.68867 .85279 m .69572 .84851 L .69894 .85567 L F
.49688 .91133 m .5048 .91167 L .50561 .91266 L .299 .325 0 r
F
.65716 .86322 m .66734 .86545 L .66004 .86883 L .725 .813 0 r
F
.65716 .86322 m .6644 .85956 L .66734 .86545 L F
.58137 .88963 m .59122 .89084 L .58307 .89132 L .379 .317 0 r
F
.57307 .88914 m .58137 .88963 L .58307 .89132 L .148 .161 0 r
F
.64986 .86674 m .66004 .86883 L .65267 .87206 L .706 .801 0 r
F
.64986 .86674 m .65716 .86322 L .66004 .86883 L F
.48901 .91104 m .49723 .91723 L .49785 .91768 L .431 0 0 r
F
.68155 .85694 m .69186 .85968 L .68469 .86357 L .787 .852 0 r
F
.68155 .85694 m .68867 .85279 L .69186 .85968 L F
.51265 .9106 m .52164 .91106 L .51365 .91216 L .634 .869 0 r
F
.64249 .87011 m .65267 .87206 L .64523 .87515 L .685 .787 0 r
F
.64249 .87011 m .64986 .86674 L .65267 .87206 L F
.49723 .91723 m .50602 .91791 L .49785 .91768 L .371 .429 0 r
F
.52044 .90896 m .52958 .90961 L .52164 .91106 L .753 .982 0 r
F
.51265 .9106 m .52044 .90896 L .52164 .91106 L .634 .869 0 r
F
.58931 .88847 m .59919 .88957 L .59122 .89084 L .474 .483 0 r
F
.58137 .88963 m .58931 .88847 L .59122 .89084 L .379 .317 0 r
F
.63507 .87334 m .64523 .87515 L .63773 .87807 L .663 .769 0 r
F
.63507 .87334 m .64249 .87011 L .64523 .87515 L F
.67436 .86097 m .68469 .86357 L .67746 .86734 L .773 .847 0 r
F
.67436 .86097 m .68155 .85694 L .68469 .86357 L F
.52817 .90685 m .53749 .90793 L .52958 .90961 L .89 1 0 r
F
.52044 .90896 m .52817 .90685 L .52958 .90961 L .753 .982 0 r
F
.6276 .8764 m .63773 .87807 L .63016 .88082 L .638 .749 0 r
F
.6276 .8764 m .63507 .87334 L .63773 .87807 L F
.59712 .88665 m .60705 .88782 L .59919 .88957 L .527 .581 0 r
F
.58931 .88847 m .59712 .88665 L .59919 .88957 L .474 .483 0 r
F
.53579 .90417 m .54538 .90625 L .53749 .90793 L 1 1 0 r
F
.52817 .90685 m .53579 .90417 L .53749 .90793 L .89 1 0 r
F
.62007 .87929 m .63016 .88082 L .62253 .88339 L .61 .722 0 r
F
.62007 .87929 m .6276 .8764 L .63016 .88082 L F
.60483 .88446 m .61483 .88573 L .60705 .88782 L .561 .644 0 r
F
.59712 .88665 m .60483 .88446 L .60705 .88782 L .527 .581 0 r
F
.61248 .88198 m .62253 .88339 L .61483 .88573 L .587 .689 0 r
F
.61248 .88198 m .62007 .87929 L .62253 .88339 L F
.66711 .86488 m .67746 .86734 L .67016 .87098 L .758 .841 0 r
F
.66711 .86488 m .67436 .86097 L .67746 .86734 L F
.60483 .88446 m .61248 .88198 L .61483 .88573 L .561 .644 0 r
F
.54319 .9004 m .55339 .90522 L .54538 .90625 L 1 1 0 r
F
.53579 .90417 m .54319 .9004 L .54538 .90625 L F
.49723 .91723 m .50521 .91691 L .50602 .91791 L .371 .429 0 r
F
.54955 .8915 m .56162 .90512 L .55339 .90522 L 0 0 0 r
F
.54319 .9004 m .54955 .8915 L .55339 .90522 L 1 1 0 r
F
.6598 .86866 m .67016 .87098 L .66279 .87449 L .743 .834 0 r
F
.6598 .86866 m .66711 .86488 L .67016 .87098 L F
.65243 .8723 m .66279 .87449 L .65536 .87787 L .728 .826 0 r
F
.65243 .8723 m .6598 .86866 L .66279 .87449 L F
.55986 .90278 m .56981 .90457 L .56162 .90512 L .348 .34 0 r
F
.54955 .8915 m .55986 .90278 L .56162 .90512 L 0 0 0 r
F
.645 .87582 m .65536 .87787 L .64786 .88112 L .711 .817 0 r
F
.645 .87582 m .65243 .8723 L .65536 .87787 L F
.63752 .8792 m .64786 .88112 L .64031 .88424 L .694 .806 0 r
F
.63752 .8792 m .645 .87582 L .64786 .88112 L F
.568 .90227 m .57789 .90335 L .56981 .90457 L .476 .535 0 r
F
.55986 .90278 m .568 .90227 L .56981 .90457 L .348 .34 0 r
F
.62998 .88244 m .64031 .88424 L .63269 .88721 L .676 .795 0 r
F
.62998 .88244 m .63752 .8792 L .64031 .88424 L F
.6224 .88554 m .63269 .88721 L .62502 .89004 L .657 .781 0 r
F
.6224 .88554 m .62998 .88244 L .63269 .88721 L F
.57593 .90066 m .58589 .9017 L .57789 .90335 L .524 .617 0 r
F
.568 .90227 m .57593 .90066 L .57789 .90335 L .476 .535 0 r
F
.61476 .88849 m .62502 .89004 L .6173 .89272 L .637 .766 0 r
F
.61476 .88849 m .6224 .88554 L .62502 .89004 L F
.58379 .89866 m .59382 .89976 L .58589 .9017 L .553 .666 0 r
F
.57593 .90066 m .58379 .89866 L .58589 .9017 L .524 .617 0 r
F
.60709 .89129 m .6173 .89272 L .60953 .89524 L .616 .748 0 r
F
.60709 .89129 m .61476 .88849 L .6173 .89272 L F
.5916 .89639 m .6017 .8976 L .59382 .89976 L .574 .701 0 r
F
.58379 .89866 m .5916 .89639 L .59382 .89976 L .553 .666 0 r
F
.59937 .89393 m .60953 .89524 L .6017 .8976 L .592 .727 0 r
F
.59937 .89393 m .60709 .89129 L .60953 .89524 L F
.5916 .89639 m .59937 .89393 L .6017 .8976 L .574 .701 0 r
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{273.938, 287.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004A00017b000`400?l00000o`00003oo`3ooolB
0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB
0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB
0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB
0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB0?ooo`00o`3ooolB
0?ooo`00PP3oool206X008d0oooo001n0?ooo`0405X0003=B000g_l00=Gj0080gUd00P3fB02;0?oo
o`00O03oool20;@T0080cDP000H0g_l00=Gb003NG@00eEd00?oF003fC0020<dD0080iQ000P1k0002
06Xd000303U800003000oooo00@0oooo00@00000059a001BL@0021@0N03oool007X0oooo0P35>002
0;@T0080cDP000@0i_l00=ko003NG@00eEd00P3oeP020?mm000:0?n5003oU@00L``007<<002LfP00
00000684001kZP0021`00?HX0080oooo00H000000;A<003^T@00kY40000D001RS@1g0?ooo`00M@3o
ool01@3^o`00cC@00<dd003^hP00_B`00080aCP00P2d90001P1R2000cED00>Ko003No`00gUd00=EM
0080omH00P3oO@001`3o_P00oiD007<<001c3000>@000?lh000Y00000`1ZV@001P3=6000mRP00008
00002000kY4007>Z0080FX400P1JQ@001P1ZX@00HXd006:=000Y;000JYd006:906l0oooo001b0?oo
o`040?oo00089000k_l009`@008001`00P2m;0020<Dh00080;@T003=D000cED00<eE003oo`00eO80
0=iM003EG@020?oF000@0=iQ003oO@00okh00?nE001c3000iTP00688000Y0000ohT007<<002;/P00
HXd00?HX00000000@@0008^n0080RkX00P1ZX@0205Z50080FX4000<0BVd002T/003oL@000P1RR@00
0`0iB000oooo0?ooo`060?ooo`030?oo001RS@00oooo0680oooo001^0?ooo`<0]9T000L0oooo0?oo
000a:000aLh009`@00007000cC@00080_B`00P35>0001P2d9000cE000<eE003=E@00eNH00?oo0080
eEd00P3oeP020=iQ00050?nn003oU@00L``00:`X001R20000P3oR@00101c300000000:cB003f:002
04400080RkX00`23]P0206ZM0080JYD000<0BVd003U4003oL@000P1BK@000`0iB000ol800?ooo`05
0?ooo`80ool00P1RS@0205Z9000305Z1003oool0oooo05d0oooo001]0?ooo`80[>800P2dV@001`3o
o`00DP@0034X0035cP00ool0000L0035C0000P2m;0020<Dh0080cE000P3=E@00103EiP00ool00=EM
003EG@020?oF0080gV4000D0okh00?nE001c3000[2P0068800020?n9000807<<003oK@00W0`00?HX
00110000HP`00?m4003oT@0209c20080Pjh00`1ZU@000`1RS@00>D@00?ma00020?ma0003045<003o
`P00oooo00@0oooo0`3oo`0206:=0080FXT00P1JP@000`1JN@00oooo0?ooo`1K0?ooo`00I@3oool3
0?oo0080aOl000<0PjX00;Cb002dlP000`1kQ@000`2T2000DP@0058400030;dX00030=EI0035C000
00000080[2P000<0W1000<e@003=D0000P3=E@020?oo0080eEd00P3oeP020=iQ00050?nQ003oU@00
[2P00>h/001B20000P3oR@001`3oH@00ofd00000003f:000@@00068<003oA0000P3oT@000`2L`P00
U;X009Bj000207^Z0080HXd000@0FX400?ma003oL@00og400P3o`P00100Y:000oooo0?ooo`3oool3
0?oo000308/d001RT@00HY400080FXT00P1JP@00101JN@00DW40059a001:H@1J0?ooo`00I@3oool0
0`3N`P00ool00?oo000207<40003058`0035nP00aOX000<0eOl00`3No`002@35<000_BP00;dX0000
0000aD`00000002/:000kWd00=D/00020<e@0080cED00P3oo`020=EM0080omH00P3NH@001@3oX@00
oiD00:`X003^;000DPP00080ohT000L0of400?m]00000000mRP00=D/002;T@00od@00080oi4000@0
kR0009Bj002D]P00U;H00`1kY@00101cW@00og400?ma000000030?o2000303T/00000000BVD00080
ool00P2;=00206:A0080HXd00P1JP@000`1JN@00aHd0059a000204YQ000303U4003oool0oooo05H0
oooo001P0?ooo`80k/h00P3fcP020=k20080ool00P1c1000101B<000ool00=ko003No`050>Ko0080
gUd000L0_BP000000035C00000000:`X003^O@00eB`00080cE000P3=E@020?oo0080eEd00P3oeP02
0=iQ00030?nQ003oU@00[2P00080DPP00P3oR@00103oH@00ofd00=D/003E;002068<00050?m4003o
]P00oi400>hP003oT@000P2D]P0208^b0080Lid00P3oL@0010000000ol800?o2003o`P0300000004
0?oo003ohP00BVT007>Q0080HY400P1RS@0206:500030<F=001BL@00DW400080BV400P0iA00204YU
000304YQ003oool0oooo0580oooo001O0?ooo`<0k/h00P3fcP030=k200030?oo001c1000L`@000P0
ool000X0cOX00=iM003NG@00okh000000035C000eET00:`X003^O@00eB`00P3=D0020<eE0080ool0
0P3EG@020?oF0080gV4000<0oj400?nE002/:0000P1B20020?n900080?mQ003oK@00eB`00=D/001R
3000eC000?m4003o]P030?nA00040:C2002;/P00Rk8008^b0080Rjh000@0og400000001cU@00JY40
0P3o`P001@000000BV4002Th000P9000on800080BVT00P1:G@0404Y]00030?oo001JM@00FWD00080
BV400P0iA00204YU0080BV40D`3oool005h0oooo0P35^P030>k>00030?K>003N`P00cOl000800000
00<0ool00=kB003NdP000P3oo`000`3NfP00ool003T0000207/8000:03T0002T4000gUd00=iM0000
0000aD`00=EI002/:000kWd00=D/0080cE000P3=E@00103oo`00ohd00=EM003EG@020?oF0080gV40
00D0oj400?nE002/:000DPP00>h/00020?n900070?mQ003oK@00eB`00=D/002LT@00eC000?nf0004
0?nA00<0Y;h00P2;[P00102;ZP00og4008^Z001ZT@020?o200030000001:H@00FWD00080DW4000<0
on800000000Y;0000P1:G@000`11B000<BP004Y]00020?oo0080f000307=8001B;000DR`00080
DR`00`3oW@000`2;2000610001P@000201P@008000P000<0000006X4001Z1000101R100704X00080
:@001@3fjP001035W@00aIT00>kJ003^fP020>kF00040;ee002mL@00W3@009`d03X0oooo000Y0?oo
o`060;@8002m3000gQ000;@8002d3000gQ000`3V40020;@800040=h@003V4000iQ000>H@00D0oa@0
203o80080?l`00X0oc`02P3o>0060>h`00<0oiD0103oR@040?mi00030?IQ003fI@00mVD00080eDP0
00T0eD`00?nf003o]P00okH00?nQ003oT@00kWD00;@h000P00000P0000001`1:3000aED00?ld002T
A000LaP00100002/C0000P3oW@00103oZP00ojD00?nU003oV@030;eM00040000003oo`00ool00?oo
0080olh000<0_Gd00?o:003obP000P3obP000`2TK@00ol800?o200030?o2000308]M003o]P00okH0
00<0okH000<0LdP0058/001B;0000P1B;0040?nM000303TD000H400061000080610000<000P00000
00000000101R100804X00080:@0000@0k^X00?KZ003fjP00m^X00P35W@030>kJ00050>kF002mO@00
_GD00;ea002L=000>`3oool002T0oooo0`2d20001@3N4000[0P00;@<003E4000gQ000080iQ0000<0
[0P00;@8003N40000P3N40060?lD00P0oaP0203o;00D0?ld00H0kR`00`3oU@030?n900@0ogT000D0
mV400?IU003fI@00mVD00=E800020=E<0080okH000D0oj400?nA003^M@00]3P00200000200000080
BP`000D000000?ld001c600000000:a<00020?nM00030?nZ003oY@00ojD00080oiT00P2mG@030?oo
00040?KZ003ocP00olh00;em0080olX000@0_A000?o:003obP00Y6d01@3o`P000`2;G@00okH00?nf
00030?nf000307=8001B;000DR`00080DR`00`3oW@000`232000610001P@000201P@008000P00P00
0003068000L0BP000P0Y00020>kZ0080m^X00P35W@020>KJ0080k]X00P2mO@000`2mM@00W3@00?oo
o`0k0?ooo`00:`3oool20;@800030=h@002/2000[0P00080eA0000@0gQ000?lD002/1000[0P00P3E
30000`3N4000oa000?l@00040?l@00L0oa@0203o900:0?l`00X0ob`01@3^;000103^:000oiD00?nE
003oU@040?n900<0ogT0103fI@002P3EB000eD`00=E<003o]P00ojh00?nQ003oT@00kWD00;@h000P
000200000080BP`000P000000?ld001c600040000:a<003fT@00oid00?nZ0080ojD00P3oV@020;eM
00030000003N8000m^X000<0olh00P2mO@040?o:00030:A]003o`P00ol8000<0ol8000<0Red00?nf
003o]P000`3o]P000`1cB000DR`0058/0002058/00@0oid000<0>A@001P@000H40000P0H40020008
00040000001R0000HP00068000H0BP0000<080000>kZ003^jP000P3^jP020<FQ00040<FM003VfP00
i]X00>KJ0080_H4000<0_Gd009`h002L>000?@3oool002`0oooo00H0[0P00;@8003E4000[0@00:`8
003=30020=D@0080[0@000@0[0P00<d<003=3000e@`01P3f40070?lD00P0ob004`3o;0060>hX00<0
oiD000@0oi400?n9003oR@00ohT0103oN@030?IU00<0eD`000h0okH00000003oX@00oi400>ie002d
>00080000000000Y1000oc`004X<00000000oc@007<H008000000P3fT@000`3oZP00ojD00?nU0002
0?nI0080_Ed000<000000=hP003ocP00103ocP000`2mO@00olX00?o:00020?o:00030:A]003o`P00
ol8000@0ol8000<0Red00?nf003o]P000`3o]P05058/00@0oid0100H400200080080000000@0HP00
04X0001:0000BP000`1100030>KZ0080k^X000<0aJD00<FQ0035X@00103VfP020;f10080W3P0?P3o
ool002d0oooo00H0Y0@00;@8003=3000Y0@00:`4003530020<d<00030?H@002T1000[0@000@0c@`0
0P3^40030?H@00L0oa@0203o60090?lT00T0mRP01`3^80000`3oU@00oi400?nA00030?n900@0ogT0
0`3fI@030=E<00090?nf00000000oj400?mm003^M@00]3P0020000000000ojX00080BP`000D00000
0?ld003o/P00_F400:a<00020?JA00@0oj4000<0oiT00;eM002mG@000P0000000`3=S@00olh00?o>
00020?o>00030;em003obP00olX000<0olX000<0Y6d00?o2003o`P000`3o`P000`2;G@00okH00?nf
00030?nf000307=8001B;000DR`00080DR`0103oW@000`1R0000610001P@000201P@008000P00P00
0006044000040>KV003VjP00i^X00>kZ0080aJD01@3VfP00102mQ@00_H4009`h002L>00o0?ooo`00
;@3oool20:@40080c@`000H0W0@00:`4002m3000a@`00<d<003^40020:@400@0a@`00P3V40020>h@
00L0oa@0203o60090?lP00X0mR001P3V70000`3oU@00oi400?nA00030?n900040?n5003oN@00ogT0
0?mi00<0mVD00`3EC0002@3o]P0000000?nQ003oS@00kWD00;@h000P000000000?nZ000204X<0003
0000003o=000ok800080_F400P3fT@040?nQ00060>J9002mG@00_Ed00;eM003=4000cHd0103ocP00
0`2mO@00olX00?o:00030?o:00030:A]003o`P00ol8000@0ol801P3o]P05058/00@0oid01@0H4002
00080003000000110000@@0000<0@@000P3ViP020>KZ0080aJD0103VfP020;f900030;f5002L>000
oooo0400oooo000_0?ooo`80Y0@000<0a@`009`4002m30000P2m30030>h@00030:@4002m2000_@P0
0080_@P00P3V30020>H@00L0oa00203o50090?lH00T0mQ`01P3V50030?nA00040?n=003oR@00ohD0
0?n500<0ogT00`3fI@040=E<00080000003oX@00ohd007/@002d>00080000000003oZP0204X<0003
0000003o=000ok800080_F400P3fT@040?nQ0080iXT00P2mG@000`000000cHd00?o>00040?o>0003
0;em003obP00]0`000<0olX01P3o`P000`2;G@00okH00?nf00030?nf000307=8001B;000DR`00080
DR`0103oW@000`1J0000610001P@000201P@008000P00P000002044000<0g^H000D0i^H00;fZ002m
ZP00aJD00=kJ00020>KJ0080_Hd000<0_HT009`h002L>000@P3oool00300oooo00H0W0@00:@4002m
3000W00009`4002d20020;d<0080iQ0000<0W0000;@8002d20000P2m20020=h<0080iP`01`3f400@
0?lD00X0kQP01P3V4000103oT@00ohd00?n=003oR@020?n500<0ogT000<0ogD00?IU003fI@00103E
C0003@000000oj400?n=001k4000]3P0020000000000ojX00;@P001:300000000?ld002TA0000P2m
H@020?JA00@0oj400P3VR@00102LF@00_Ed00000003o70050?o>00030;em003obP00olX000<0olX0
00<0Y6d00?o2003o`P000`3o`P000`2;G@00okH00?nf00040?nf00D0DR`0103oW@0501P@008000P0
00@0000003T0000i0000aA`00P3NiP030;fZ0080g]X000H0i]X00;B=002mS@00_Hd00;f9002L>013
0?ooo`00<@3oool01@2D0000Y0@00;@8002m3000W00000<0]0P00P3N3000102D0000W0000;@8002d
20050=h<00H0mQ002@3o40070?H@00X0kQ001P3N40030?n=00<0ohD000@0oh400?mi003oM@00ogD0
0P3fI@004@3fH@00eD`00=E<003EC00000000?nQ003oS@00Na000;@h000P000000000?nZ001J4000
BP`00000003o=000Y4@00080_F400P3fT@040?nQ0080iXT00P2LF@000`000000oa`00?o>00040?o>
00030;em003obP00olX000<0olX000<0Y6d00?o2003o`P00103o`P000`2;G@00okH00?nf00030?nf
000307=8001B;000DR`00080DR`01@3oW@0401P@00060008003EhP00eN800=GR000i000060000P2m
[P000`2mZP00g]X00=kJ00020=kJ0080]8d00P2mS@000`2L>000oooo0?ooo`120?ooo`00<P3oool0
1@2D0000]0P00;@8002d2000R`000080[0P000<0]0P00=D<002D00000P2D00000`2/1000]0P00=D<
00040=D<00H0kQ00403f40090>h@00L0gQ000P3oS@001@3oR@00ohD00?n1003oP@00ogT00080ogD0
0P3fI@003P3fH@00eD`00=E<003EC00000000?nQ003oS@00Na000;@h000P000000000?nZ00000000
BP`00P0000001@2TA000_F400<dT003^T@00mY4000@0oj400P3VR@0209aI0080000000<0oa`00?o>
003ocP000`3ocP000`2mO@00olX00?o:00030?o:00H0ol8000<0Red00?nf003o]P00103o]P05058/
00@0oid000@0>A@001P@000H40006100103EhP02010000040<DL003EfP00eMX00=GJ0080g]X000D0
]9400;B=002dS@00W3P007<`00150?ooo`00<`3oool209@00080]0P000@0R`000:`4002/2000[0P0
0P3=300208/00080[0@01@3=30060>H<00P0mQ00203^40090>H@00H0eA0000@0ohd00?n9003oR@00
ohD00P3oP@030?me00030?ma003fI@00mV4000<0eD`000X000000?nQ003oS@00Na000;@h000P0000
00000?nZ00000000iWd00P0000000`2TA000eGd00<dT00020>jA00@0oj400P3VR@0309aI00030000
003o7000olh000@0olh000<0_Gd00?o:003obP000`3obP000`2TK@00ol800?o200040?o200H0okH0
00<0LdP0058/001B;0000P1B;0050?nM0080610000<0cMh00=GR003EhP000P2d[P000`0@00002000
0=GJ00030=GJ0080]9D000<0]94009`h002L>000A`3oool003D0oooo00@0U0000:`4002d2000R`00
0P2/1000102/2000a@`00<D<003=300208/000030:@4002/1000a@P000<0a@P01P3N300?0>h@00T0
iQ001P3E30030?n900<0oh4000H0ogd00?me003oL@00og400?IU003fH@030=E<000:0000003oX@00
ohd007/@003=D00080000000003oZP00oc`005X@0080000000<0Y4@00=Em000000000`3^T@030?nQ
0080iXT00`2LF@02000000030?lL003ocP00olh00080olh000<0_Gd00?o:003obP000`3obP000`2T
K@00ol800?o200040?o2000308]M003o]P00okH000@0okH01@1B;0040?nM00030340003=gP00cMh0
00@0]:h0103EfP030;BE0080W3P000<0Lc000?ooo`3oool0AP3oool003H0oooo00@0P`000:`4002/
1000P`000P2T1000102/1000a@`00<D<0035300208<0000309`0002T1000_@P000@0_@P01@3N300@
0>H@00P0gQ001P3=30020?n90080oh400P3oO@001P3oM@00og400?ma003fI@00mV400>iM0080eD`0
00l000000?nQ003oS@00Na000<e@000P000000000?nZ00000000FQ0004X<00000000ok800=Em003f
;0000`3^T@000`3oY@00oj400?nQ00020>J900<0W5T000<0FRP00?o6003o70001@3ocP060?o:00L0
ol801P3o]P000`1cB000DR`0058/0002058/00<0oid00`3=fP00102/[P00]:h00;B^002LK@030=GJ
00060<DL002/V@00]9D00;BE002L?000W3P0BP3oool003P0oooo00@0P`000:@4002/1000P`000P2T
1000102m2000a@`00<D<0035300207/0000309`0002d2000]0P000<0]0P01@3E30070>H<0100gP`0
1`3=30000`3oR@00oh400?n100020?mm00<0og400P3fH@00103^G@00eD`00?n^000000020?n=000:
07/@003=D00080000000003oZP00000005X@001:300000000?ld0080eGd00`3^T@020?nU00030?JZ
003VR@00iXT000<0W5T000@0FRP00?o6003o7000oa`0103ocP000`2mO@00olX00?o:00030?o:0003
0:A]003o`P00ol8000@0ol8000<0Red00?nf003o]P00103o]P05058/00<0aMX00`2/[P0209aa0080
cMX00`3EgP00102/V@00W40009`l001k=01;0?ooo`00>@3oool01P1k0000W0000:@4001c0000W000
0:@40080]0P000H0_@P00=h<001k0000N`0009@0002L00040;@400D0c@P03`3N30080=D<00H0a@`0
0P3oP@030?mm000@0?me003oL@00og400?m]003fH@00kUd00=E<003o[P0000000?nM003oS@00Na00
0<e@000P000000000?nZ0080FQ0000<0BP`00000003o=0000P3EO@030>jA0080ojD00P3fZP00203V
R@00W5T009aI002LF@00FRP00?o600082000oa`0103ocP000`2mO@00olX00?o:00030?o:00030:A]
003o`P00ol8000D0ol801P3o]P000`1cB000DR`0058/00030;gF00<0[:h00P2LM@020<gJ00D0eMh0
00<0W4P007/d003oool0C03oool003X0oooo00H0N`0009`0002L0000]0P007<0002D00020:`40080
]0P000@0e@`007<0001c0000U000102/10050<D800h0e@`0203=30070;d<00060?n1003oN@00ogd0
0?mm003oM@00og400P3oK@00303fH@00kUd00=E<003o[P00FP`00?nM003oS@00Na000<e@000P0000
00000?nZ0080FQ0000D0BP`00000003o=000eGd0000000020?JU00030>jA003oY@00ojD00080mZX0
00P0gZ4009aI002LF@00W5T005XX003oaP0020P00?lL00D0olh01P3obP070?o200L0okH00`2dcP02
0:B^0080[:h000<0W7T00<GF0035eP000`3=fP020=GN0080[9d000<0Nc@00?ooo`3oool0C03oool0
03/0oooo00<0L`0009`0002L00000P2d20000`2;0000U0000:`400020:`40080c@P000<0JP0008/0
002;00000`2T10050;d800L0c@`01`3E30080<d<00H0]0P00`3oN@000`3oO@00ogD00?ma00020?m]
0080kUd00P3o[P0020000000oid00?n=003ofP00cE00020000000000ojX00`1J400010000000oc@0
0>jQ003=90030?JU0080ojD00P3fZP020=jQ00030<FE002LF@00FRP00080olH000<020P00;d8003o
cP000`3ocP060?o:00030:A]003o`P00ol8000@0ol8000<0Red00?nf003o]P000`2T`P020;C:00@0
Y:h000@0W7d00<GF0035eP00aMH0103=fP040:bM04l0oooo000m0?ooo`0607<0002L0000[0@00:`4
001R0000R`000P2T10000`2/1000a@P00<D8000206X00080R`000P2L00060;@400d0c@P0202m2006
0:`80080ogT00P3oM@030?m]000<0?mU003^G@00kUT00?n^00000000oid00?n=003ofP00cE000200
00000000ojX00`1J400010000000oc@00?nb003EO@030?JU00040?nj003oY@00mZX00?JZ0080gZ40
0P35U@00101J:000olH00?o6000820020;d800<0olh000<0_Gd00?o:003obP00103obP070?o200<0
W;X00P2T`P0209bZ0080Y:h000H0U8400;gB002mdP00_M800<GF0035fP020<gJ00@0[9d000<0W4`0
0?ooo`3oool0CP3oool003l0oooo00D0R`000:@4002T1000Y0@008<0000209`000050:@4002m2000
_@P00;d8001R00000`23000309@000@0[0@01P2m20070<D800L0_@P01P2T1000103oN@00ofd00?m]
003oM@020?m]0080ofD000`0kUd00>iI003o[P0000000?nM003oS@00kWD00<e@000P000000000?nZ
002D?00205X@0080000000<0ok800000003fY@000P3fY@020?nj0080mZX00P3NX@020<FE00040:bE
003oaP00olH000P800<0_@P00`3ocP060?o:00D0ol800`2D[P0209bj0080W:D00P2LZP000`2DQ@00
_M800;gB00030;gB0080aMX00P2/X@020:bM0080U500D@3oool00400oooo00<0HP0008/0002T1000
0P0030000`230000W00009`000040;@400030680001k0000N`0000<0U000102T10070;@400d0]0P0
1@2L10050?m]00<0ofD000H0kUd00>iI003o[P0000000?nM003oS@020<e@0004020000000000ojh0
00000080FQ000P0000000`3o/P0040000?JU00020?JU0080okX00P3f`P020=jQ0080aID00`3oaP02
00P8000304Y@002m2000olh00080olh01P3obP000`2TK@00ol800?o2000508^M0080U:400P2DS@00
102DR@00]<h00;C>002dcP020;gB0080aMH00P2TX@020:bQ0080U5D000<0U5000?ooo`3oool0D03o
ool00480oooo00D0HP0009`0002L0000W000000<000209@0000509`0002T1000Y0@00:@4001J0000
0P1k000408/000@0W0001@2/10070;@400L0Y0@01@2D00020?m]00030?mU003oK@00ofD00080ofD0
0P3^F@00303o[P00000005X<003oS@00W2P00<e@000P000000000?n^00000000ojh005X@00800000
00@0ok800100003o`P00ol800`3o^P020?K20080k/X00P35U@001`3okP00olH00?o6003oaP0020P0
0;d@001:D0000P1B00000`3ocP00_Gd00?o:00030?o:00<0Lfd00P23S@0208^E0080Rid000<0Ri40
09B=002DS@000`2/bP020;C>0080_MH0102TX@0209AI000309AE001k=000oooo0580oooo00140?oo
o`0507/0002D0000U00009@0001c00000`2;00040:@40080DP000`2;000509@000@0Y0@01`2/1007
09`400D0P`000P3oI@001`3oK@00ofD00?mU003oI@00oed00>iI003^D0000P0000003@3oS@00kVd0
0<e@000P000000000?n^000Y1000U3`005X@000@100000000?nb000@00000P3o`P000`3ofP00okX0
0?nj00020?K20080k/X00P3NcP001`3okP00olH00?o6003oaP0020P00;d@001:D0000P1JO@02034/
0080DUD00`1RK@0207>10080Phd000<0PiD008^E002;U@000P23N@030:c60080[<X00P2mdP020:BU
0080Y:400P2DG@000`2DF@00Nc@00?ooo`1D0?ooo`00A@3oool01P003000L`0007<0002D00000100
06X00080R`00102L00020:`40080JP000`23000809@000H0W0001`2;000507/000@0ofD00P3oG@00
4@3^F@00kU00000000000000ohd00>i]003=D00080000000003o[P00000009@l001J400040@00000
003o/P0040000080ol800P3ofP030?K20080k/X000@0g/h00?o^003okP00onh00P3oaP0200P80003
0;d@001JO@00FWd00080HYT00P1cX@0207^Q0080Nid00P23V@0208>A0080PhD00`2T_P0209bQ0080
]=80102TY@0209AQ000309AM001k=000Nc@005H0oooo00170?ooo`06000@001Z0000P`0008<00000
4000HP000P23000209@0000509`0002T1000Y0@00:@4001R00000`1k000408/000X0U0001P230006
07<000030?mI003oI@00ofD00080oed00P3^D002000000060?n=003^K@00cE00020000000000ojh0
0P2D?0001`3o[P0040@00000003o/P0040000?me003o`P000P3ofP020?oV0080k/X000<0g/h00?oo
003oo`000P3okP020?o6008020P000<0_A0009C:002DbP000P2;cP0208_:0080Pkh00P23[P001023
X@00Pi4008>A0023Q@0209bj00<0U9d00P2dcP0209bU0080Y:D00P2DI@000`2DH@00Nc@007/d001H
0?ooo`00B@3oool01`004000HP0007/000230000010005X0001c0000102;000309`000030440001J
0000FP000080L`003@23000607/000D0HP0000l0oeT00?mM003oG@00oed00?mE003^D000oid00000
003oS@00kVd00<e@000P000000000?oB000Y10000P2D?000101c>00040@00?nb003o/P020?oV0080
omX00P3oiP020?ob00<0ool00P3okP020?o6008020P00P2m400208_>0080RlX00P23_P0208>^0003
08>A002;Y@00RjD00080U;800`2/aP020:c:00@0W:D000<0U6T009AU002DI@000P1k=01J0?ooo`00
C03oool010005000N`0009@0002D0002000D000306X000230000P`0000<0U00000<0W0000:@4001B
0000101Z000207/000<0P`001P1k000607<000040680001J0000FP0005X00080odP00140oed00?mE
003oE@00oeD00?nM00000000ohd00?mm003=D00080000000003odP00:@@00<em002D?000gQ`00104
00020?nb0080onH00P3onP000`3oo`00oo800?ob00060?oo0080ooX00P2D/P020;d@00040:CR002D
dP00U=8008^n0080PjX00`23U@0208^I00<0Y<H00P2/aP0209bQ0080W:D000@0Rfd007/d001k=000
FS00G@3oool004h0oooo00H001@007<0001c0000R`00000D001Z000207/0000308<0002;0000R`00
0080R`0000<0W000000D000050000P1R000407<000<0N`001@1c000506X000040580001:0000BP00
04X00080odP001<0oe000?mE003oE@00oid000P0003oS@00ogd00<e@000P000000000?oB000Y1000
cGd009@l003N7000LcP00008003o/P00onH000<0ooX02@3oo`020?oj0080U;800P1BL@03020X0080
HU000P1kT@0208>E00<0W;h00P2TaP0209BQ0080RgD000@0Rg4007/d001k=000HS00G`3oool004l0
oooo0P0050001@1Z0000N`0007/000006000FP0000<0L`000`23000408/00003000H00110000FP00
00<0HP000`1c000506X000D0FP0000<0@@0003T0000i00000P3o?000103oD000od`00?m<00000002
0?mm00050<e@000P000000000?oV001c70000P3=O@00103N7000LcP00598000030020?oo0080i_l0
2@3oo`020?oj0080U;800`1BL@0205Z10080JXd00P23W@0309Bj00@0U:400`2;M@00101k>000Nc@0
07/d001R<01P0?ooo`00DP3oool00`00400001P0000H000207/0008001P000<0JP0007/0001k0000
0`1k000408/0008001P000@0DP0005X0001J0000FP000`1R000505X000D0BP0000l0:@000?ll003o
A000od@00?m<00000000ohT00?mm003=D00080000000003odP00La`00?Jb003o`P000P3N7000102L
W@00DTP00?oo003oo`030=Go0080m_l00P3oo`020>ko0080ool000@000000<go002/jP00[>X00P2;
dP0208>n000408>Z002;ZP00RjX008^Z0080U;800P2;W@0208=m000508]i001kB000NdP007]0001R
=000I03oool005@0oooo00<001@0000H000060000P1c0000101k000001P0000H001J000407<000<0
N`000`230002000H00<0DP000P1J0005058000@0@@0000h0P`000?ld003oA000od@00?n9000Y0000
ogd00<e@0011200000000=DH001c7000m[800?o20080gQ`00P2LW@00103oo`00m_l00=Go003Eo`03
0>Ko0080k_l01@3oo`0010000000[>X00:cZ002DbP0207^90080Pid00`23V@0208^M000408>10023
O@00Pgd007]<0080NdP000<0HS@00?ooo`3oool0I03oool005P0oooo00<001P0000L000070000P1k
0002000L00040580001R0000HP00068000<0L`001@1k0002000H00030440001B0000DP000080DP00
101:00004@0i0000@@000448003o=000od000?n9000a0000ogd00<e@00112000omH00000001c7000
m[800?o200002000gQ`00080aLh000@0m_l00=ko003=o`00cOl00`3Eo`020>Ko00D0ool00P000002
07>I0080NiD00P23V@0208>50080Ph4000<0Ned007]E001kE@000P1R=0000`1:<000oooo0?ooo`1V
0?ooo`00F`3oool00`0060000200000P000206X000@0020000@0FP000680001R0000HP001P1c0002
000H00040440001:0000BP0004X000D0DP0001<0FP`00?l/003o@000Na`00?n9003=D000@@P00?oF
00000000La`00?oN003o`P00FW400008003Eo`00]>X009c:003o^P00cOl00080aOl00P35nP020<Go
00<0cOl00P2dlP0207^f0080Nj400P1kU@0207^=000307]]001kI@00NfD00080JS@000<0DS0004X`
001:<000JP3oool005h0oooo00H001P0000L00088000220005X000006002000P008022@00`1B0003
068000D0JP0000<0HP000440001:00000P1J00020680000=05X<001k7000ohT009`X003V@000@@P0
0?mU000Y4000ool00?o2003ofP00JP0009Bn000305Yi0080PkH00P2LfP020:c^0080Y=X00P2LeP02
08_:00<0PkH000<0Nhd007^1001kP@000P1kM@0206Xl00<0DS00KP3oool00640oooo00<001`0000P
000080000P0@900201PT008001`000@0220000PT000H900062@00P1:000905800080L`0000X0Na`0
0?l`003o<000iT0003T0003okP00ool00000003o`P00onX00P0a@00208_:00040?nj0023aP00PlH0
08_:0080RlH00`2;_P0208>f0080PjX000<0Lgd007=a001cL@000P1cH@0305X`0080>B`0L@3oool0
06D0oooo00<001`0000P000080000P0@9002020T0080:BP000<00200000T000090000`0@900201PT
00030340000H0000@@P00080FP`000X0Na`008/0002D=000a@`003T0003oV@00ool0069M003ojP00
]>800P23`P0306ZM000307=]0023_P00Pkh00080Pk800P23Y@0207=a0080JV400P1ZD00206900080
BS00MP3oool006X0oooo00<0020000PT000890000P0@9002020X00<0:BP00P0a:0020?l/000<0?l@
001RE@00HT`008=Q002T1000U3@006X0000i0000ool00=kZ003=Q@00]?800P2;cP0207^^00@0Lhd0
0P1cN@0206YU0005069E001R@000HT0004X`0011;0000P0i;01j0?ooo`00L@3oool01@0070000200
010T000@9000:@00008062P000/082P0069E001RE@00:BP0034/0011;0000200069I0011;000PjD0
06Ya000206YY0003069Q001JB000FTP000<0FTP000<0DS@004X`001:<0000P11;0000`0i;000oooo
0?ooo`1n0?ooo`00M`3oool2020H00<0:BP000<0<B`003T/000i;0000P0i;004034/00<0:BP000<0
:B`00?ooo`3oool0QP3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo
4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo
4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo
4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo
4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo
4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo
4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00?l0oooo4P3oool00001\
\>"],
  ImageRangeCache->{{{0, 272.938}, {286.938, 0}} -> {0.0291031, -8.36256*^-5, \
0.00332481, 0.00332481}}],

Cell[CellGroupData[{

oX00P3oo`060684000405X0003oS@00og400?ma00<0oed0
0`3oD000103o;000omh00?oN003ogP050?ob000307=e001cL@00Lg4000@0Lg400P1JF@0205YE00<0
FU0000<0DT`0044d0011;0000`0i:0000`0i900061@001PD0004010@008000`000<000P00?ooo`3o
ool0;03oool00300oooo8`3oo`0209@80080W0`000D0Y0`00684001J1000FP@00584000205800003
0688003^4000m]h00080W7d000h0FS@004X@001:4000BQ0006XP003VA000[4P00:@D003=G@00eF40
03T/0035E@00oc@00=EE0080gUT000H0:@@00?mm003oY@00JQ0004X<003^J@020<E<00@0cE0000H0
cED0000000000000gVD00>IY003oeP020?nQ000;0:@X003^;000L``007/@003ojP00ok800?nn003o
L@00cC@00?nf003oaP000P2/40001@3okP00ooH00?ob003olP00omh00080ojD000D0<@000000003o
hP00olX0044000030?nQ000500PP003oW@00cId00<fM002/R@000P3onP020?oo00D0HP@00P1J0002
0?ma00<0oed00`3oD0000`3oB000ob`00?oo00020?oN0080oo800`3oo`0607=a0080JVd00`1JE@02
05Y@0080DT`00P11;00303TX000403TT000i800061@001PD00<041000P003002000802d0oooo000`
0?ooob80ool00`1B100306880080HP@000<0FP@00584001B00000`1R20000`3fgP00oaP00?lH0002
05Xd000404X@003N=000BQ0006XP0080[4P000D0cEd00=EQ000i;000aED00?ld00020=EE00030=iI
00113000U1@00080JQ0000D0BP`00>iY0035C000aD`00=EI00030<e@00060<eE0000000000000=iU
003VJ@00omH00P3oX@002`2T:000omh007<<003oO@00onX00?nb003o_P00og400<dd001R2000FPP0
0080[10000D0onh00?I8003olP00oo800?oN00020?nU00050?nf003ohP00olX00440003E90000P3o
X@000`0@0000oid00<fM00020<FI0080ooX00P3oo`05068400@0FP000`3oG@020?m@0080odP000<0
od000?oo003oo`001`3oo`000`2;P@00Lg4007=a000207=a0080JVd00P1ZJ@000`1JE@00FU0005Y@
0003059<00040598000i:000>BP003TX0080>B@000@0>B0001PD000H500061000P0@40000`084000
00`000080002000802`0oooo000_0?ooob80ool00P0Y0002058400<0HPP00P1R10000`1J1000DP@0
05800003068800050?oo003fgP00m]h00?lH001J=0000`1:400206XP00030:a8003=G@00eF400080
>B`000d0aED00?ld003EE@00gUT00?m]002D5000ogd006X@003oD000kVT005X<0035C000eET000<0
cE0000H0cED0000000000000gVD00>IY003oeP020?nQ000508/D003ogP00L``00?mm003ojP000P3o
_P00103oL@00cC@006XL003o_P020:`@00030?of003fB000oo800080omh000L0ojD0034000000000
on800?o:00110000eB@00080oj4000@022000?nM0035V@00aIT00P3onP020?oo00D0HP@01P1J0003
0?m@0080odP000<0od000?oo003oo`00203oo`00103V:000Rh4007=a001cL@0206Y]00<0JVT00P1J
D003059<0080DTP000@0DT@003TX000i:000>B@00P0i800203TL000301P@000@4000410000802100
0`00200/0?ooo`00;@3ooolI0?oo00L0]3000P2m<00402T00080DP@00`1R200206840080FP@0101R
20020?oo00040?KN002LO@00ob`005Xd0080BQ0001@0JR000>I4002/B000kU000<eM003EH@00>B`0
0<EE003o=000eED00=iI003oK@00U1@00?mm001Z4000oe000>iY001J3000aD`00=EI00<0cE0000H0
cED0000000000000gVD00>IY003oeP020?nQ000508/D001c3000FPP00?mm003ohP000P3o_P020<dd
000?06XL002/4000[1000?oN003omP00mTP00?ob003ogP00mU000?nU003o]P00on800?o:00110000
eB@00080oj4000<040000?nM0035V@000P35V@020?oj0080ool0101R100805X000<0odP000<0od00
0?oo003oo`002@3oo`000`3V:000Rh4006Y]000206Y]00<0JVT00P1ZI@04059<00040598001BA000
DT@005940080>B@00P0i800203TL0003034H000@40004100008021001000200[0?ooo`00;@3ooolH
0?oo0080[3001`2d<0020;d`00030<Dd000Y0000:@0000<0DP@00`1R20020684000305X4001Z3000
HPP00080HPP01@3oo`001@3o;000BQ0004X@001:4000JR000080[4P000H0cEd00=EQ000i;000aED0
0?ld003EE@020=iI000802T4003oO@00ojD00?m@003^J@00FP`00<E<003EF@030<e@00060<eE0000
000000000=iU003VJ@00ogd00P3oX@001@3oO@00kR`005X8003oO@00on800080okh00P3==0003`1Z
7000[1000:`@003ogP00ooH00?I8003olP00omh00?I@000a000000000?oR003obP00@@000=DT0002
0?nQ000400PP003oW@00aIT00<FE0080ooX00P3oo`05068400T0FP000P3o@00<0?oo00040?m<0023
O@00Pgd008=m00<0JVT00P1ZI@0206YQ0080DT`00P1BB00205940004058l001B@000>B0003TP0080
>A`00P0a6003010@000300P@0000300000`0008000P000<000@00?ooo`3oool0:03oool002`0oooo
5`3oo`030:`/0080[3001`2d<0020;d`0080aC@00`1B100306880080HP@000<0FP@006X<001R2000
0P1R20000`3oaP00ool00?oo00030?oo00030?l/001:4000BQ000080JR0000<0kU000<eM003EH@00
0P0i;000303o=000eED00=iI003NF@00:@@009@D003oY@00JQ000>iY001J3000aD`00=EI00<0cE00
0180cED0000000000000gVD00>IY003oO@00oj400:@X003oO@00kR`005X8003ojP00on800?nn003o
L@00cC@006XL003o_P020:`@00070?of003fB000oo800?of003ogP00ojD003400002000000060?o:
003E9000oj400?nQ000@0000oid00`35U@000`3onP00ool00?oo0005068400T0FP000P1R000=0?oo
0080od`000@0Pgd008=i0023N@00JVT00P1ZI@0406YQ0080DTP00P1BA0001@1B?000DT000590001B
?000>B000080>A`00P0a6000100a50004100010@0008400200P<008000P000<000@00?ooo`3oool0
:03oool002/0oooo5`3oo`050:`/0080[3001`2d<0020;d`0080aC@000<0cC000584001R20000`1R
2000101R1000Na0007/@001Z3002068800030?o6003oo`00ool000@0ool000H0od000=hd001:4000
iT@00:a8003^D0020=EQ000=03T/0035E@00eED00=EE003NF@0080@009@D003oY@00JQ000>iY003E
B000aD`00=EI00030<e@000B0<eE0000000000000=iU003VJ@00ogd00?nQ002T:000ogd00>h/003o
gP00onX00?nb003o_P00og400<dd001Z7000okh00P2/40002`3omP00mTP00?ob003ogP00onh00?nU
003o]P00on800?o:00110000eB@00080oj4000D022000?nM003NY@00aI400?oj00030?oo00@0HP@0
201J0003068000h0ool00P3oC00308=i0080JVD0101ZH@0206YM0080DT@000<0DS`00590001B@000
0P1B?00203TL00<0<AP00P0a50000`0@4000210000P<000200P<000300080000100000@002T0oooo
000Z0?oooa80ool000@0eAP00?oo003oo`00ool0202/;0020:``00H0]3000P2m<0030<Dd00030<d`
001R2000HPP00080HPP000@0HP@009@@001k4000JP`00P1R20000`3oaP00ool00?oo00040?oo0004
0?m0001:4000BQ0006XP0080[4P000l0cEd00=EQ000i;000aED00?ld003EE@00gUT00204002D5000
ogd006X@003^J@00ojD00<E<003EF@000`3=D0004@3=E@0000000000003NI@00iVT00?mm003oX@00
Y2P00?mm001c3000omh00?oZ003o/P00okh00?n9003==000JQ`00080[10000/0FS`00?of003fB000
oo800?oN003fD000<@000000003ohP00olX00=DT00020?nQ00060100003oW@00gZ400=jQ0035T@00
ooX00P3oo`04068400L0FP00101R000=0?oo0080ooX00P3oN@0208=i0080PgD0101ZH@0206YM0080
HUT000<0DS`00590001B@0000`1B?000101B>000<AP0034H000a6003034D008021000`0830001000
300000@000040000100X0?ooo`00:@3ooolG0?oo00T0[2`00P2/<0060;@`0080_C000`35=000103=
<000aB`00<D/001R200209@@0080Na0000<0JP`00688003^:0001`3o6000503o@000BQ0006XP001Z
8000_BP00<eM003EH@00>B`00<EE003o=000eED00=iI003oK@00U1@00?mm001Z4000BP`00?nU0035
C000ogD00`3=D0004@3=E@0000000000003NI@00iVT00?mm003oX@00Y2P00?mm001c3000Na000?oR
003E<000okh00?n9003==000JQ`00080[10000/0ofd00?of003fB000ooH00?o^003fD000okH00?oR
003obP00@@000=DT00020?nQ0080oid00P3NX@000`3onP00ool00?oo0004068400H0FP000`1R0002
06X000D0L`001`3oo`040?oj0080ogT00`23M@0208=a0080JV400P1ZG@03069I0080DT000`1B?002
058h000304X`000a6000<AP000<0<A@00P0Y500300P<008000`00P00100X0?ooo`00:03ooolE0?oo
00030=DH003oo`00[2`000X0[2`00P2/<0060;@`0080_C000P35=0020<d`0080aB`000L0[1`009@@
002D4000Na0006X<001R2000kRP000P0oaP000H0od0004X@003VA000[4P00?mI003EH@0203T/000;
0<EE003EE@00gUT00=iI002D5000Y20006X@003oD000ojD00<E<003oP@000`3=D000303=E@000000
0000003NI@00iVT00?mm003oX@00Ra@00?oN001J2000omh00?oZ0080okh000<0cC@006XL003o_P00
0P2/40002P3oK@00omh00?I8003omP00onh00?I@00000000on800?o:003E90020?nQ000300PP003o
W@00gZ400080gYd00`3oo`03068400D0FP0000@0Y6d00:AU002TI@00Y6D00P23B000101k?000ool0
0?oo003oo`0307<000@0ool01@3onP00103oeP00oiT00?nI003oV@0408=a00<0JUd00`1RF@02069E
00@0DS`000@0DSP004X`001:<000BS00100a500202TD000302T@0008300020`0008000`00P001000
0`000000oooo0?ooo`0U0?ooo`00:03ooolI0?oo00X0[2`00P2/<0060;@`0080_C000P35=0020<d`
0080aB`000H0[1`009@@001k4000Na0006X<003^:0080?lH000:0?m0003oE@00JR0006XP002/B000
cEd00=EQ000i;000aED00=EE0080gUT00P2D50001@3oY@00oe000>iY0035C000oh4000<0cE0001H0
cED0000000000000gVD00>IY003oO@00oj4008/D003ogP00FPP00?oN003ohP00eC000?oN003==000
JQ`00?nn002/4000FS`00?of003N<000ooH00P3okP001@3o]P00on80000000110000eB@00080oj40
00D0oid00=jM003NW@00gYd00?oj00020?oo00@0HP@00P1J00020:A]00D0Y6D00P1k?0060?oo0080
L`0000<0ob@00?oj003onP000`3onP030?oF00<0oiT01@23L@04069I00<0HUD000<0HU00058l001B
?0000P1B>00304X`000304X/000a5000<A@00080:A@00P0Y400200P<00<000`000<000@00000003o
ool09P3oool002L0oooo6`3oo`0:0:`/0080[3001@2d<0020;d`00<0aC@000@0cC000<D/0035;000
[1`00P2D4000101k4000JP`00=DP001130070?lH000<02T4003oE@00BQ0006XP003oF@00cEd00=EQ
000i;000aED00?ld003EE@00gUT00P2D50001@3oY@00JQ000>iY003o^P00oh4000<0cE000100cED0
000000000000gVD00>IY003oO@00oj400?mm003ogP00FPP00000003ohP0000000?oN003==000JQ`0
0P2/40002P1J?000ooH00=h`003omP00onh00?mi00000000on800?o:003E90020?nQ000300PP003o
W@00gYd00080gYd00P3oo`040684000305X00035P@00aH4000D0Y6D00`2TG@070?oo000408<8001Z
0000ooX00?lL0080ooX00`3oeP020?nb00<0ojX01023L@0208=]0080HUT00`1RE@03069@0080DSP0
0`1:<00204X/000404XX000a5000:A@002TD00<0:A00100030000`00100000000000000V0?ooo`00
9P3ooolM0?oo00X0[2`000<0[3000;@`002d<000102d<0020;d`0080aC@00P3=<0020<D/00060:`L
002D4000Na0007/@001Z3000@@`0203o60020?mE00040>i@002/B000_BP00=EQ0080>B`000/0oc@0
0=EE003NF@00oh4009@D003oY@00JQ000>iY001J3000aD`00=EI00020<e@000@0<eE000000000000
0=iU003VJ@00ogd00?nQ003oO@00omh005X800000000on800?nn003ogP00cC@006XL0080[10000H0
ofd00?oN003N<000ooH00?o^003o]P02000000050440003E9000oj400?nQ003oW@000P3NW@00103N
V@00ool00?oo003oo`030684000305X00035P@00aGd00080aGd00P2TI@040:AM00L0ool000D0P`P0
0?oo003onP0000@00?lL00030?oF00@0ok800`3oZP0308=a00<0Pfd0101RE@03069@0080HT`00`1:
<00204X/0080BRP00P0Y500502T@00<000`000@000P000000000000000009@3oool002H0oooo7P3o
o`0:0:`/00030:``002d<000]30000@0]3000P2m<0020<Dd0080cC000P35;00209@@000407/@001Z
3000@@`0044<00L0oaP000L0:@@00?mE003oH@00JR000:a8003=G@00eF400080aED000X0eED00=iI
003^F@00U1@00:@P001Z4000kVT005X<0035C000eET00P3=D000203=E@0000000000003NI@00iVT0
0?mm003oX@00ogd00P3ogP0010000000on800?nn003ogP0206XL000;0:`@001J?000ofd00?oN003N
<000onH00?o^003o]P00on800?o:003E90000P3oX@0010088000oid00=jI003NV@030?oo00<0HP@0
00<0aH400<Em0035O@000`35O@050:AM00L0ool000<0P`P00?oj003onP000P3onP000`001000oa`0
0?nb00030?nb0080oi40103o/P001023L@00Pfd008=]0023K@0207]Y0080HUD00`1RD004069<0003
04X`001:;000BR`000<0BRP000<0BR@002T@000Y4000100Y4003000<008000P00P00000U0?ooo`00
9@3ooolP0?oo00X0[2`000<0[3000;@`002d<000102d<0020;d`0080aC@000D0cC000<D/0035;000
[1`009@@000207/@00<0@@`01P3o600202T40080JR0000l0oeT00<eM003EH@00>B`00<EE003EE@00
gUT00>iI003fG@00Y20006X@003^J@00ojD00<E<003EF@000P3=D0005`3=E@0000000000003NI@00
iVT00?mm003oX@00ogd005X8003ogP00onX00=D`003o_P00omh006XL003o_P00[10005Xl003oK@00
omh00?of003oiP00omh00080000000D0olX00=DT003oX@00oj400?nM00030=jE0080ool00`1R1005
0<Em0080aGD00`2TG@000`2TF@00ool00?oo00050?oo000408<8002D2000ooX00?oj00<0omH000<0
00@00?nb003o/P00103oT@040?nb00<0Pfd0101kJ@03069@00D0HT`00P1:;00304XX0080BR@01P0Y
40000`0P400000`0000<0002000800<00000903oool002@0oooo7`3oo`0308/D00X0[2`000<0[300
0;@`002d<0000`2d<0020;d`0080aC@00P3=<0020<D/00040:`L002D4000Na000<DL0080@@`01`3o
60001P0Y1000oeD00?mQ002/B000oeT00=EQ0080>B`000X0oc@00=EE003NF@00mUd00:@P001Z4000
kVT00?nU001:2000eET00P3=D000503=E@0000000000003NI@00iVT00?mm002;5000ogd005X8003o
gP00onX00=D`000i1000ohT006XL003o_P00[10005Xl003ogP00gS000P3oiP00103ogP00on800000
003E90020?nQ000300PP003oW@00gYD00080gYD00P3oo`02068400040=jA0035O@00aGd00<Em00@0
aGD0102TF@060?oo000408<8002D2000U0P00?oj00<0omH00P3o/P050?nA00030?mi003o/P00ok80
0080ok800P23K@0407]Y0080NfD01P1RC002069800<0BRP00P1:900204XP00@0:A000P0P4002000<
00<000P00P00000T0?ooo`008`3ooolP0?oo000508/D003oo`00Ra@008/D003oo`00202/;0020:``
00D0]3000P2m<0020<Dd0080cC0000<0aB`00:`L002D40000P1k4003044<00H0oaP00P0Y1000103o
E@00JR000:a8003=G@0203T/00080<EE003EE@00gUT00?IM002T8000ojD004X<003oY@0204X80080
cE0001X0cED0000000000000gVD00>IY003oO@00Ra@00?mm001J2000omh00?oZ003o_P00omh00<dd
001Z7000[10005Xl003oaP00omh00=h`003oiP00ojD00000003ohP00olX00=DT0080oj4000@0oid0
0?JU003NT@00gY400P3oo`0206840080gY401@35M@030<Ea0080Y5T01P3oo`000`232000U0P009@8
00040?oF0080ok800P3oT@000`3oN@00oi400?mi00020?mi00@0ojX0101kJ@0507]U00@0HT`00P1R
B00205Y4000304XX001:9000BR@000<0BR0000@0@A`002T@000Y4000:A000`0P4004000800<00000
8`3oool00280oooo803oo`0308/D00030?oo002;5000Ra@000T0[2`00P2/<0050;@`0080_C000P35
=0001P3=<000aB`00<D/002/7000U10007/@00@0@@`01@3o600302T400040?mQ003oG@00cEd00=EQ
0080aED000T0eED00=iI003fG@00mUd00?nU001:3000ojD006X@001:20000P3=D0003@3=E@000000
0000003NI@00iVT00?mm002;5000ogd00?nU003ogP00]2P00?nn003ogP000P1Z7000102/4000FS`0
0?o6003o/P020?oV00040?nU003ohP0000000=DT0080oj4000H022000?nM003fX@00mZ400=jA003o
o`02068400@0gXT00P35M@050<Ea000309a@003oo`00ool000@0ool000@0P`P009@8002D2000U0P0
0P3oeP020?nb00<0oi4000@000000?mi003oN@00ogT00P3oJ@040?nZ000309Ai001kJ@00NfT000H0
NfD00`1RC002069800<0FT@00`1:900204XP0080@A`00P0Y4004020@0005020<0000200000P00008
000010000`00000R0?ooo`008P3ooolO0?oo00<0Ra001@2;50090:`/0080[3001@2d<0020;d`0003
0<Dd003=<000cC000080aB`000<0U10007/@001130000`1130060?lH0080:@@000@0of4006XP003o
E@00eF400P35E@002@3EE@00gUT00>iI003fG@00_C@004X<003oY@00JQ0004X800020<e@00050<eE
0000000000000=iU003VJ@000P3oO@004P3oW@00ojD00?oN002d:000okh00?oN001Z7000okh00:`@
001J?000olH00?nb003oiP00okX00000003ohP00olX00=DT0080oj4000@0oid00?JQ003fX@00mZ40
0P3oo`000`1R1000gXT00=j900030=j900@0aG400`2mJ@050?oo0080P`P0102D20020?nb00@0oi40
00L0ogT0000000000000ofT005XL003oJ@00oeT000D0oj401`1kI@0207]Q00<0HTP00`1JA00205Y0
000304XT001:8000BR0000<0@A`000<0@AP002T@000P40000P0P4002020<00<000P00P0010020000
0280oooo000Q0?ooob00ool000@0Ra000?oo002;4000Ra001@2;50090:`/0080[300102d<0020;d`
0080aC@00P3=<0001035;000[1`009@@001k4004044<00D0oaP00`0Y10000`3oH@00[4P00<eM0002
03T/00090?ld003NF@00kUT00?IM002m=000BP`00?nU001Z4000okH00080cE0000D0cED000000000
0000gVD00>IY00020?mm000A0?nM003oY@00omh00;@X003oL@00omh006XL003o_P00FS`00?n^003o
/P00ojh00?oV003o^P00oc000?H`003E90000P3oX@000`088000mZ400?JQ00020?JM00040?oo001R
1000gXT00=j900@0gXD01P2mJ@050?oo000308<8002D2000U0P000@0U0P0103oT@030?mi00030?mY
00000000FQ`000<0oeT01@3oX@000`2DN@00NfD007]U000207]U00<0Nf400P1kG@00101RB000FT@0
05Y4001JA00305Y00080BR000`117002044H00@081000P0P30000`0H300000P000080002000400<0
00008@3oool00240oooo7`3oo`0308/@00030?oo002;4000Ra0000D0Ra@000<000P00:`/002/;000
1P2/;0000`2/<000]3000;@`00030;@`0080_C000P35=0001@3=<000aB`00<D/002/7000Na0000D0
@@`01@3o600202T4000;0?mQ002/B000cEd00=EQ000i;000aED00=EE003^F@00mUd00;dd001:3000
0P3oY@00103o]P00cE000<e@003=E@020000000@0=iU003oO@00ogd00=E8001:2000olH00?oN003E
<000Y1@00?oN001Z7000[10005Xl003o[P00P``00?n^0080okX000H0on800?H`003E9000oj4000PP
003oW@030?JM00030?oo003NQ@00gXD000@0gXD00P3NP@040;eY00030;eU003oo`00ool000<0ool0
00<0P`P009@8002D20001@2D20020?nA00<0ogT00`3oJ@000`000000oeT00?mI00020?m<00D0oiT0
0P2DM@0207]U00<0Nf400`1kG@0305Y400<0FT000P1J?003044L00<0@AP000<0@A@0020@000P4000
0P0P300201P<008000P00`00100200000240oooo000P0?oooal0ool01@2;40000`3oo`00Ra0008/@
000508/D00030?oo002/;000[2`000H0[2`000<0[3000;@`002d<0000`2d<0020;d`0080aC@000D0
cC000<D/0035;000U1000=h<0004044<00D0oaP00`0Y10000`3oG@00od`00=EQ00020<EE00050=EE
003^F@00mUd00?mM002m=0000P3oY@00103o]P00cE000<e@003=E@020000000D0=iU003oO@00eDP0
0=E800000000olH00?oN002d:000Y1@00?nZ001Z7000[10005Xl003oaP00P``00?n^003o^P00ohD0
0?nM003f<0020?nQ000600PP003fW@00mYd00?JM003fV@00ool00`3NQ@050=j100D0_FD0103oo`00
0`232000U0P009@8000609@800<0ogT00P3oJ@030?mI0080000000@0od`00?m0003o@000od00103o
S@0209Ae00@0Nf400`1kG@0207]I000405Y4001J@000FT0005Y00080FS`00P1J>00010117000@AP0
044H00116003044D0003020@000P300080`000<060`01000100300000200oooo000O0?ooob00ool0
1P2;4000103oo`00Ra0008/@002;400408/D0080ool01`2/;0000`2/<000]3000;@`00030;@`0080
_C0000H0aC@00<d`003=<000aB`00:`L003N7005044<00@0oaP00`0Y10020?mM00080=EQ0035E@00
>B`00=EE003^F@00mUd00?mM003fE@020?nU00040?nf003=D000cE000<eE0080000000T0gVD00?mm
003EB000eDP00?nZ003oaP00omh00<d`002T50000P1Z700205Xl00070?o6003o[P00ojh00?n5003o
hP00oid00=DT00020?nQ00060?nM003fV@00mYT00?JI003oo`00mYT01P3NP@020=ii00@0_FD0103o
o`000`232000U0P009@8000609@80080U0@000<0ofT00?mI003oF@000P3oF@020?m<00800000103o
@0040?n=00<0U7400P1kH@0207]M00@0NeT00`1J@00205Xl00<0FSP00`116004044D008080`01@0H
3003000400<00000803oool001l0oooo7`3oo`0<08/@00@0Ra@000<0ool00;@8002/;0001P2/;000
0`2/<000]3000;@`00030;@`00040;d`0035=000aC@00<d`0080aB`000<0gQ`004X<001130001011
30040?lH0080:@@00P3oG@003P3oC000aED003T/003EE@00oeD00?IM003oG@00mUD00?n9003oY@00
okH00<e@002/>000cED00P0000004`3VJ@00ogd00=E8003EB000ojX00?o6003ogP00oiD00?nZ001Z
7000okh005Xl003o[P00P``00?n^003oH@00L`@00?m@003oF@000P3oX@000`088000mYT00?JI0002
0?JI0080mYD00`3NP@050=ii00<0_Ed0103oo`000`232000U0P009@8000509@800@0U0@00P2;1003
0?m<0080od000P000000103o@000ocP00?lh003o>0050?n10080U7400P1kG@0507]I0080LeD00`1J
?00305Xh0080FS@000<0@AP0044D001150000`1150000`0i400080`001P<000401P<00<000@00`00
000P0?ooo`007P3ooolO0?oo00h0Ra001@2;50000`2d2000[2`00:`/00050:`/00030:``002d<000
]3000080]3000P2m<0020<Dd00030<d`0035;000gQ`00080BP`0101130040?lH00<0:@@000l0oed0
0?m<003o<000>B`00=EE003oE@00odP00?mM003fE@00ohT00?nQ003oP@00Pa@00000003=E@000P00
00004@3VJ@00kV400=E800000000ojX00?o6003oO@00olH00?nZ001Z7000[10005Xl003o[P00N`@0
06X0001:0000HP000080oa@000@0mQ`00?nQ003oW@00mYT01@3fU@060=ii00<0gWD000<0_Ed00?oo
003oo`000P3oo`000`232000U0P009@8000409@800@0U0@01@2;10040?m00080000000<0ocP00?l`
003o<0000P3o<0040?ma0080U6d01@1kF@0307=E0080Le0000@0FS`005Xh001J>000FSP00`1J=005
044D0080>A001P0H30000`0@300000@000040004000001l0oooo000N0?oooal0ool03`2;400508/D
00P0[2`000<0[3000;@`002d<0000P2d<0020;d`00040<Dd003=<000cC000?lP0080BP`000<0<@P0
044<001130000P1130040?lH00<0:@@000h0od`00?l`000i;000oc`00?mE003oB000ocP00?IE003o
R@00oj400?n1003NO@00[3000<eE0080000000X0iVT00>iQ002T400000000?nZ003oT@00ogd00?nE
003oG@00JQ`00P1J?0020?n^000707<4001R0000ool0000L000Y0000mQ`00?nM00050?JE00<0mY40
0`3NN@050=ie00<0ool000<0P`P009@8002D20001@2D200309@400D0R`@00`2;00030?lh00800000
1@3o<0040?ma00<0U6d00P1kF@0407=E00<0Le000`1J>00305Xd0080FS000`11500403T@00@060`0
0P0@3002000400@000007`3oool001d0oooo5P3oo`020<d@00L0ool04P2;400408/D00P0[2`000<0
[3000;@`002d<0000P2d<0020;d`00040<Dd003=<000ob000?lP0080BP`000<0<@P0044<00113000
0P1130030?lH00H0:@@000D0gXD00000003oB000ocP00>i40002034400040?n1002m=000[3000<eE
0080000000l0gV400>iQ002T4000oid00=h`003oJ@00cC00068<001R0000iQ0005Xl003o[P00R``0
0?n^0011C0000P3oo`00101B000041@00200002d=0020?JE00H0mY401P3NM@001@3NL@00ool00?oo
003oo`00P`P000H0U0P00`2D100408/400<0R`00102D00020?l`008000001@3o:0040?mU00<0U6d0
101cE@0607=@000405Xh001J=000FS@005Xd0080FS000P1J;0000`115000>A0003T@000403T@00<0
60`00P0@3002000400D000007P3oool001`0oooo5P3oo`040<d@00H0ool04`2;400408/D00L0[2`0
0P2/<0040;@`00080;d`0035=000aC@00<d`003o8000BP`00348001:3004044<00<0oaP0100Y1002
0>JE000:0=j500000000oa`00<D8002mI@00<@@0068<003oP@00_C@00:``00<0000001L0okX00?o6
003oY@00ojD00?n^003o=000ohd00>iU000a30000000000<003o[P00DUT007<<000iB000ool00348
001B00000000000<000000008200020L00030?JA00<0mXT00`3NM@030=ia00<0ool000<0P`P009@8
002D20000`2D200309@400@0R`@00P2;000909@0008000001P3o80030?mI0080U6d00P2DJ@0207=E
00L0Le000`1J=00205X`00<0FR`01`0i400201P<008040`000<040P00004000010001@00000N0?oo
o`00703ooolH0?oo00<0cA00103oo`0E08/@00@0Ra@000<0[2`00;@8002/;000102/;0020:``00<0
]3000P2m<0001`35=000cC000?m8003o8000BP`00348001:3000101130030?lH00<0:@@000P0iZ40
0>JE003NQ@0000000?H@002;9000c@P0034400<0of4000L000000?m<0000000000000?o6003odP00
ojD00080ojh00P3oS@00203^L@00BQ@004XD0000400001@0059I0011C000ool00P3oU@001`1BL@00
>E0000000000100000P0000@000H50001@3fR@060=ia0080ool000<0P`P009@8002D20000P2D2003
09@400<0R`@00P2;000<09@0008000001P3o70040?m800<0U6T0201cD00207=<00<0FS000`1J;002
058X00L0>A000`0@3002010800H000007P3oool001/0oooo5P3oo`000`1RT@00ool00?oo00020?oo
0080cA000P3oo`0G08/@00@0Ra@000<0[2`00;@8002/;000102/;0000`2/<000]3000;@`00020;@`
0080_C000P3oU@001@3oB000BP`004X<001:3000<@P000@0@@`00P3o600202T4000701P0003N/P00
iZ400=j500000000[50008/T000300000080of40100000020?oB0080ojh00180okX00?n=003oV@00
oiT008]Q001J?000:A@001PH000H8000@E00069m003oU@00DP0003U@003odP0000@00?Hh00002002
000@0003010D003fR@00mXD00080mXD00`3NL@020=iY0080ool000@0P`P009@8002D2000U0P00P2d
B0020;A000<0Ra`0102;5004058<00030588002L0000W00000D0W00000<000000?lL003o7000103o
70040?m80080U6T00P2DI@0507=@00<0Ld`00P1cB000101J<000FR`005X/001J;003058X00L0>A00
0P0@30030108000300P800000000000000<000007P3oool001`0oooo703oo`00103=4000ool00?oo
003oo`0F08/@00@0Ra@000<000P00;@8002/;000102/;0000`2/<000]3000;@`00020;@`00050;d`
003ocP00oiD00?nE003oB0000`1:3000100a2000@@`0044<001130020?lH000902T4003EkP00eNh0
0=jb003VX@00gXD00?l`002/D000ojh000<000000P3oH@03000000030?of003odP00om8000<0okX0
00d0oiT00?nU003oY@00kWd00>j9001cL@00DUT0045<000iB000>D@003U8000iE@00om8000808100
00H0mSP001P@000H40000100010D000840030?J500D0gVT000<0ool008<8003EI@000`2dB0040;A0
00D0Ra@00P234002058<00<0DPP00P0H000709`000H0oaP00`3o>00209AU00<0RfD00P1cD00407=<
00<0LdP00`1J;003058X0080DR@01`0i40030108008020P01P00000M0?ooo`007@3ooolL0?oo0080
onX00`3oo`0F08/@00<0Ra@000<000P00;@8002/;000102/;0000`2/<000]3000;@`00020;@`0080
olh00P3oU@0204X<00030348001:3000@@`000<0@@`000D0ool00<Go002dlP00eNh00<G:000207]e
000407<d003oT@0020@000P4008000000P3oH@0200000080ooX00P3ofP000`3ohP00ol800?o20003
0?nU0080kXT000L0cFd007^1001JL@00BV40059]0011F@00BV400080BQ`000H0:A0000P@003o<000
810000P@000@4002000<0080mX400`3NJ@000`3EI@00ool00=EU00020=EU00D0]4000P2d?00308/D
00@0Pa00101B2000101:2000600001P0000@000200000080Y0@000<0000009`0003o50001@3o5003
0?l/00D0RfD0101cC00407=8000307=4001J;000FR`000<0DRP00P1B9002058P00H0>A000`0@2003
00P800H00000703oool001X0oooo0P3oo`040?o:01`0ool000@0onX00?oo003oo`00ool05@2;4003
08/D00030?oo002/;000[2`000@0[2`000@0[3000;@`002d<000]3000`3ocP00203oU@00BP`004X<
001:3000<@P004X<00113000g_l00P3oo`002P3^o`00g_l00;gV002miP00W9D00<f5003o]P00omX0
0?m<00081003000000030?mQ0000000000000080ool000D0omX00?oF003oiP00ol800?o:00030?n^
00<0iY400P3=N@020:AQ00<0NdP000@0DS00034H000a600041@00P0040001@0@400000`0000<0000
2000mX4000H0eFD00P3EH@030;A000@0]3`01`234002058800<0BPP00`0@0003000000040:@40000
0000Y0@00:@400H0oa@000<0ob000?l/002;I@000P2;I@0308]Q0080Ld`0101cB00207=400@0DRP0
0P1B9003058P00D0>A0000<0<A000108000@200010082006000001`0oooo000I0?ooo`@0ool000@0
olX00?oo003oo`00_D007P3oo`020?oZ01D0Ra00102;50060:`/00040:``002d<000on800?oF00<0
olh000<0kQ0004X<001:30000P1:3000103No`00ool00?oo003oo`020>ko00050=GZ003EdP00m/h0
0?nf003ofP000P3oC0001@0@100020@0000000000000of40008000000P3oo`030?oV00030?o:003o
cP00okH00080okH00`3VW@020<f500<0Y6d00P1kE@0205Xl0080@C0000L081@000PD0000500001P0
000<00002000mWd000<0eFD01@3EH@050;@l0080]3@01`23400504X800<040001@0000020:`40003
0:@4003o5000oa@000<0oa@00P3o70000`2;I@00Rf4008]Q000308]Q00@0LdP00`1cA00206Y00080
DRP00P1B9003058P0003058L000i4000>A000080>A000P0a40000`0a300040P000P8000300P800H0
0000703oool001T0oooo203oo`030;e001@0ool00`2;40080?oo01@0Ra00102;50060:`/0080oo80
00D0on800?oF003ocP00olh00>h@000204X<00030=kj003oo`00ool00080ool00P3fo`001@3^o`00
m_X00?oZ003ojP00ool000<0od`000D040@000P40000000000000?mQ000200000080ool00`3okP03
0?oB0080okX00`3VX@030<f=0080[7D00P23H@001`1JB000HU00069@001:>000:A`0034P000@5000
0`0060000`3fO@00eF400=EQ00020=EQ00@0eET00`2d?0040;@d00D0Pa000P1k400404X800<04000
00<020000000000000000`000000101k:000[0P00:`8002/10040?lD00<0oa`00`2;H@0308]M0080
LdP00P1cA00406Y000<0DR@00`1B8002058L00<0>A000P0a4002034<00@020P000<000@000000000
00001000000L0?ooo`006@3oool90?oo00D0_D001`3oo`040:@X00H0ool00`23400208/@00P0ool0
502;400308/D00D0[2`000L0ooX00?ob003olP00on800?oF003ocP00kQ000080g_X01P3oo`000`3f
o`00ool00?oo00030?oo00<0od`00P0@100500000080ool00`3okP030?oF00<0m[h00P3VZP030<FA
00<0[7d00P23K@02069I000404Xl001:A000<B@0034T008061P000<021@00?mm003EF@001`3EF@05
0;@d0080[2`00`23400407/@00<0BPP000@0BP@00100000@000020001@00000207/X000404X<002d
2000]0P00:`800@0mQ@000<0kQ`00?lL002;H@001@2;G@0207=400D0JT000P1Z?004058P0080DQ`0
0P1B60000`0i4000<A00034@0004034<00<020P00P001006000001/0oooo000H0?ooo`/0ool01`2m
@0040?oo00L0Y2P00P3oo`0608<@0080Ra000P3oiP050?oo0003000@002;4000Ra000140Ra000`2;
50030:`/0080ool000@0ooX00?ob003olP00on800P3^o`0=0?oo0080DQ000P3oC0020104000300P4
000000000000008000000`3oo`020?o^00<0omH00`3f`P030=j^0080aIT000<0[8400:b9002/R@00
0`2;L@02069Q0080DTP000H0<BP003T/000H600081P00?lh000040030=EI00@0eED00`2d=0040:`/
00@0Na000`1k3000101:2000BP@004X4001:100300P000D000000P1k:00204X<00<0]0P00`3^5000
0`3N7000kQ`008]M000308]M0080ReT01@1Z@00306Xl0080JSP00P1B8002058L00<0DQP00P0a4005
034<008020P010001005000001/0oooo000H0?ooo``0ool02@2m@0020?oo00P0Y2P02023400208/@
0003000@003oo`00ool000@0ool04`2;400308/D00030:`/003oo`00ool00080ool000@0ooX00?oo
003oo`00m_l00`3oo`020=GN00030?Ko003oo`00ool000H0ool00`1B40020?m<008040@00P000005
0?oo0080onh00`3oeP030?K200<0g[800`35W@030:b9000308]e002;N@00RgT00080JV400P1BC002
03T`008081P000<001@0000<003EE@001@3EE@040:`/00<0[2P01P1k300304X40080@@@00`080005
000000<0Nb@00`1:30000`2m3000kQ@00>hD00020>hD00030=hL002;G@00Red000D0ReT00P1Z@004
06Xl00<0JSP00`1B7003058H0080DQ@01`0a3005000400D000006`3oool001L0oooo3@3oo`0<0;e0
0080ool0202T:00708<@0080Ra0000<001000?oo003oo`00103oo`0B08/@0080Ra@0303oo`020>ko
00T0ool000<0FQ@0058@001B40000P3oC0020104000300P400000000ool000@0ool00`3okP030?oF
00<0k/H00`3N/P030<FQ0080[8d00`2;N@0306YU0080DT`00P0i<0001@0P600081@0000D00003000
00P000@0eE001@2/:0020:`T00<0N``00`1c30050444000300P000000000000000D000000P1k9000
101k8000BP`004X<001:30020;d<00050>HD003^5000kQ@00=DH003N70001P2;F@0406Xl00H0JSP0
00@0DQ`0058H001B6000DQP00P1B500204X@00H0<@`01@001005000001/0oooo000G0?ooo``0ool0
202m@0000`3oo`00_D000;e000050;e00080ool0202T:00608<@0080Ra0000<001000?oo003oo`00
0`3oo`000`004000Ra0008/@000?08/@01L0ool00P1J7000101J5000DQ00058@003oC003010400<0
ool00`3onP030?oZ00<0omH00`3^aP030=Fb00<0aJ400`2TS@0208]i000308]m001ZI@00JVD000<0
DT`00P0i;002020D0004000@00002000eE000=E@0080eD`00`2/:0040:`T00H0L``0101110080000
000407/T001k8000Nb0007/P00@0BP`000@0aA000;d<003N5000iQ@00P3E600408]I00<0ReD00P1Z
?00706Xh00<0DQP00P1B500304X@00D0<@`000<0:@`00004000010000`001006000001X0oooo000F
0?ooo`l0ool000<0420004YQ002m@0001P2m@0020?oo00H0_D0000<0ool001PP002T:0001P2T:006
08<@0080Ra000P0040001@3oo`00N`0007/0001k0000010000h0Ra005@3oo`040?ld0080FQ`000<0
FQ@0058@001B40000`0@10030?oo00<0ooH00`3oiP030?KF00<0i/H0103E/P030;fQ00<0Y8d00`2;
N@0206YU0003059<001BB000DTP00080>BP000@081@001PD0000400000@00`3EC0050:`T0080Y1`0
1P1c300304440003044000000000000000H00000101k800504X<00050<D@002m3000eA@00=hD003E
60000P2;F@0508]E00L0JSP00P1Z=002058H0080DQ@0101:4004034<00<0:@`010001006000001X0
oooo000F0?oooa00ool00`0@80000`1:H@00_D000;e000060;e00080ool01@2m@0000`3oo`006200
0:@X00060:@X00D0Pa000P2;4002000@00@0N`00302;400F0?oo0080U5T00P3o=0001@1J8000FQ`0
05XL001J5000DQ0000<040@00`3oo`030?of00<0onH00`3fdP040>K200<0eK800`2mX@030:B=00<0
RgT00P1ZI@00101ZH@00DTP00598001BA00203TT008061@000@000P00004003=B000cDP00P2/9005
0:@L00@0L``00P1Z300010111000@@00044000110008000000<0Nb0000<0Na`004X<001:3000101:
300010354000eA@00=DD0035600508]E00<0Re00101Z>00406Xd00<0DQ@01@1:4003034<00@0:@`0
0`001007000001X0oooo000E0?oooa<0ool0100@800204YQ00L0_D000`3oo`040;e000030?oo000H
8000Y2P000D0Y2P01@23400308/@0005000@001k0000N`0007/0000040002P2;400E0?oo00<0W5d0
00@0U5T00?ld003o=000FR000P1J70000`1J5000ool00?oo00040?oo00<0oo800`3oiP040?KB00<0
i/800`3E/P040;fQ00<0Y8d00`2;N@0306YQ0080DT@000<0DT0003TP000i80000P0H40000`002000
00000:@L00050:@L0080Y1P00P1c300306X<00@0@@0000<0>@000000000000001@00000207/P00<0
Na`01P1:30001@3=5000aA000=DD003E5000aAP00080ReD01@2;D00206Xh00D0JS@00P1R<00804X@
0003034<000Y3000:@`000@0:@`00P001007000001X0oooo000E0?oooa@0ool01P0@800204YQ00L0
_D00103oo`040;e0000301PP002T:000Y2P000@0Y2P01@23400208/@008001000P1k00000`004000
Ra0008/@000508/@01H0ool00P2TH@0209aM000409AI003o=000FR0005XP0080FQ`00`3oo`030?oj
00<0onh0103ohP030>k>00@0i/800`3=/P030;fM00@0Y8d000<0RgT008]e002;M@000`1ZG@001P1B
@000DS`003TP000i7000>AP0000@008000P000<000000:@L002T7000102T600606X<0080@@000`0i
0007000000H0Na`0101:30001P113000cA@00<dD003=6000eA@00<DH00D0Re000P23C00506Xd00<0
HS000P1R;00704X@00L0:@`000<000@00000000000001`00000I0?ooo`005@3ooolE0?oo00P04200
0`1:H@060;e000D0ool00`2m@0000`0H8000Y2P00:@X00040:@X00@0Pa000P2;4002000@000307/0
003olP00010000@0Ra005P3oo`030:AU00040:AQ002LG@00W5d009AI00<0FR00103oo`030?of00<0
onX0103ogP030>k>00@0g[h00`3=[P040;fM00<0Y8T00`2;M@000`1ZG@00JUT006YI0002058l0003
058h000i6000<A@00080410000<000P00000002T60000P2T60030:@D00H0JP`0100i0008000000H0
Na`00P1:3003044<00050000003=5000cA@00<dH002m60000`2;D00508=<0080JS@0101R<003068/
00P0BQ001@0Y30000`0Y200000@000000008000001T0oooo000D0?oooaP0ool00P007007010P00<0
BV401`2m@0050?oo0080_D0000<062000:@X002T:0000`2T:00408<@0080Ra000P0040000`1k0000
010008/@000208/@0180ool00`3=R@020?lD00<0Y6D000<0Y64009aQ002LG@001P3oo`040?ob00<0
onX0103ofP030>k>00@0g[h0103=[P030;fI00040:B9002TQ@00Y8D00:B500<0Rg400P1ZF@000`1Z
E@00DSP0058d0003034D008020`000<000@00:@D002T50000P2T500209`@00H0JP`0100i00070000
00D0Na`00P1k6005044<008000000P3=50000`3=6000Re0008=<000608=<00@0HS00101R;0000`1R
:000BQ0004X@000604X@00@0:@`00P0Y200:000001T0oooo000D0?oooaX0ool010007006010P00@0
BV401P2m@0050?oo0080_D0000<062000:@X002T:0000`2T:00308<@0080Ra001000400C0?oo00@0
cHT000<0oa@00:AU002TI@000P2TI@000`2TH@00W6400?oo00020?oo00<0ooX0103olP040?oV00<0
omX0103^bP040=jj00<0cJX0102mV@030:B5000408]a0023K@00Pfd006YE0080HUD000<0DS@0058`
001:<0000P0a50001@0a400020`0000<00000000Y1@000@0W100101Z3002068800@0>@001P000000
102/A000Na`007/L001k700407/H00D0@@`00P000000103E6000cA@00<dH002d600508=<00<0PdP0
0P1R<003068/00<0HRP0201:400302T<0080:@P00P0P2009000001T0oooo000C0?oooad0ool01@00
7006010P00@0BV401P2m@0040?oo00<0_D0000<062000:@X002T:0000`2T:00208<@0080Ra0000<0
01000?oo003oo`003P3oo`030>h@00<0cHd00`3=R@000`3o5000Y6D00:AU00020:AU00@0ool00`3o
nP040?o^00@0on800`3feP040>k600@0g[X0103=Y@030;fE00<0Y8D000@0Y84008=]0023K@00PfT0
0P1RD000101RC000BS0004X/001::002034@000400P<000030000000000000@0W1000P1Z30030688
00@0>@001`0000000`2/A000NaP007/H000507/H00H0@@`00P0000000`3E6000cAP00;@H000308=<
00D0PdP0101R;003068X0080HR@0201:40000`0Y3000:@P002T80003020800T000006@3oool001<0
oooo7`3oo`07000L00D042001@1:H@050;e000@0ool00`2m@0000`0H8000Y2P00:@X00020:@X0080
Pa0000<0Ra000?oo003oo`003@3oo`030>JU0080kQ00103=S@020<f900@0Y6D00`3oo`040?of00@0
onh0103ohP030?oF00@0k/H0103N]P040<fU00@0]9D00`2TO@0408=Y00<0HTP000<0BRP004XT001:
90000P0Y40001000300000P000000000000309`@00D0HPP0100i0007000000030:a0001k6000NaP0
00<0NaP00P1k5006044<008000000P3E60000`3=6000Pd`008=8000408=80080Pd@00P1R;004068X
00<0HR@0201:400202T800@080P02@00000I0?ooo`004`3ooolR0?oo000301PP0000700001`000@0
01`01@0@800504YQ00H0_D000P3oo`040;e0000401PP002T:000Y2P00:@X00d0ool000<0]0P00?oo
003oo`000P3^Y@030>JU00030>h@003=S@00cHd000<0cHd01`3oo`040?of00@0onX0103ogP030?oB
00030?KB003^`P00k/800080k/80103N/P030<fU00@0]9400`2LO@00102LN@00PfD008=U0023H@02
069800040694001:9000BR0004XL0080:A000P00200200000080W1001P1R200403T000H000000P2/
@00307/H00@0Na@01P113003000000030=DH00356000PdP000<0PdP01023A004068X00<0HR@00P1R
800704X@0003044@000Y200080P000D080P02@00000H0?ooo`004`3ooolT0?oo0080620000<0]4P0
000L0000700010007004010P00H0BV401@2m@0020?oo00050:a0002m@000_D000;e0000H8000303o
o`020?nf00030;@8003^Y@00kZD000<0kZD00`3VY@030<f=00P0ool0103olP040?oZ00@0omh0103o
cP040>jn00@0g[80103=X@040;B=00<0W7T01023H@0206900008068l001:7000BQ`004XH000Y4000
80`00008000010020000000309`@001R2000HPP000@0HPP00P0i0002034000D000000`2/@00707/D
00H0@@`00P0000000`080000eA`00<DH000208=800@0Pd@00`23@002068X0080HR@0101R800604X@
0080@A001`0P2009000001P0oooo000B0?ooobL0ool0100H80000`2dB00001`0000L0003000L00@0
42001P1:H@050;e000040?oo002/@000[4000:@X00@0ool000<0[4000?oo003oo`00103oo`050?nf
00030;@8003^Y@00kZD000<0kZD0203oo`040?oj00@0onh0103oiP040?oJ00<0m/h000<0okh00>jn
003^_P000P3^_P040=j^00@0cId0102dR@0409ae0080Ped00P23F@03068l000604XH0011500080`0
020<0000200000@00P0000000`2L4000HPP006880003068800D0<@001@0000030:a000D0Na@00P1c
5006044<000600000008000020000=hL003E700000000`23A00508=00080HR@01@1R8002068L00@0
BQ000P114002044<00H080P02@00000H0?ooo`004P3ooolY0?oo00D0620000<0]4P0000L00007000
10007003010P00L0BV40102m@0000`2/@000ool00?oo00090?oo008001`01@3o]P040>jU00P0ool0
103onP040?o^00@0on80103ofP040?K:00@0k[X0103N[P000`3=W@00aIT00<FI00020<FI00@0]8T0
0`2LL@0308=I000407]I001J>000FSP005Xh0080@A@000<0@A00020<000H30000P0010000`000000
U10006880004068800@0<@001P0000030:a000<0Na@00`1c50000`1c4000@@`0044<0004044<00<0
20000P3N70000`356000Pd@008=0000608=000D0HR000`1R700205XL0080BQ000P114003044<00D0
80P000<060P00000000000001`00000H0?ooo`004P3ooolY0?oo00D0U2P000<0ooX001PP000H8000
0P2dB005000L00<042001`1:H@020?oo008020001011F@020?oo008000000`3o]P00103oo`00okH0
0?nf003o]P0<0?oo00@0ooH01@3ojP040?oR00@0omH0103fbP050>Jj00@0gZX01035V@040;B500@0
W7400P1kE@000`1kD000FS@005Xd000205X`0080@A000P0H3002000400030000002d6000HPP000@0
HPP0100a0005000000040:a0002/?000[3`00:`l00@0La@00`1c4006044<00@0200000<0gQ`00<DL
0023@0001@23@00308<l0080HR000`1R700405XL00<0@A00101130040208000301P8000H100060@0
00P00000603oool00180oooo:@3oo`0909@X0080ooX000<062000;A8002dB0001@007002010P00@0
BV401P3oo`0300000080ool01P3o]P0>0?oo00@0oo80103ojP050?oN00@0om80103faP050>Jf00@0
gZD01035U@040;B100<0W6d000<0W6T007]@001kD0000P1kC00205X`000605X/00114000@A00044@
000H300060P00P0000000`2d6000HPP006880003068800@0<@00100000050:`l0080La@01P1c4005
044<00@0200000<0gR000<DL0023@0000`23@00508<l00@0HQ`0101J70000`1J6000@A00044@0005
044<00<080P000@060P001P4000H100060@010000000103V>000000000000000000H0?ooo`004@3o
oolY0?oo00l0U2P000@0onh00;A8002dB000]4P010007002010P00@0ool00`0P00050?oo00P0okH0
203oo`040?oj00@0oo80103oiP050?oN00@0om80103faP000`3f`P00i[800>Jb00020>Jb00@0eJ40
1@35T@040;Am00@0W6T00`1kC00205XX000405XT00114000@A0003T@008060P00P0000000`2m7000
aA`00688000205X800@0<@00100000000`35<000[3`00:`l00030:`l00P0La00101130000`112000
200000P0000200P00080gR000P23@00508<l0080NcP00P1R700405XL00<0FQP0201130000`0P2000
60P001P4000301P400<000000P3okP03000001P0oooo000A0?ooobT0ool04`2D:0000`3onP00]4P0
0;A80003000L00L0ool000@0:C000?oo003oo`00ool0203o]P080?oo00D0ooX0103okP040?oV00D0
omX0103ocP040?K200030?Jn003V/P00i[800080i[801@3EX@040<FA00@0]7T00P2LI@0209AQ0080
NdP00P1kA00305XT00<0>A000P0@2002000000040<DL001J2000FPP005X800@0<@00100000000`35
<000[3`00:`l00030:`l00P0La000P113003044800@0200000<0iR000=hP003570001023?00407/h
00D0FQ`00`1J600205XD00L0@@`000<060P001P4000H10000`0H1002000000<0onh00`00000H0?oo
o`004@3ooolY0?oo01L0U2P000<0]4P00?oo003oo`002P3oo`080?nf00P0ool0103omP050?o^00@0
on801@3ofP040?o>00D0m[h0103V[P050=FM00@0aHd0102dN@0409AQ000407]4001c@000Ld0007=0
0080FR0000H0FQ`003T@000i4000>A00010800082002000000040<dL001J2000FPP005X800@0<@00
0`0000000`3NE@00[3`00:`l00040:`l00P0La001@11200400P000030000003V8000aA`00080Pc`0
101k>00307/d0080FQ`00`1J600405XD00L0@@`02@2LfP020?o^00<0000000<0_B000?ooo`3oool0
5@3oool00100oooo7`3oo`040?oj00L0ool0602D:00:0?oo0003000H003oo`00okH000H0okH02@3o
o`040?of00D0onX0103ohP050?oF00@0olX0103f_P000`3f^P00iZX00>JZ00030>JZ00@0eIT01@35
R@040:ae0080U5d00P2DF@0207=0000307<l001J7000FQ`00080DQP00P0i300200P800<000000`1J
200403400080000000<0]3P00<dd002/?0001@2/?00807<@00D0@@P0100800000`000000iR@00<DL
000407/h00D0Nc@0101J600305XD0180W=X00P3okP03000000030;dP003oool0oooo01D0oooo000@
0?ooo`80ooX07@3oo`070?oj00<0ool0602D:00<0?oo0003000D001BL@00DW4000D0okH02@3oo`04
0?ob00@0onX01@3ogP050?oB00@0olH01@3f^P050>JZ00@0eIT01@35Q@040:aa00@0U5T00P1c?002
07<h0080DQ@000H0DQ0003T<000a3000<@`000P400001002000000<0FPP00`0a0002000000030;e<
003fS@00000000@0[3`00P2/>00807<@00D0@@P0100800000`000000iR@00<DP000207/h00D0Nc@0
702LfP001@3okP000000000000000000aB@001L0oooo000@0?ooo`<0ooX00P3oo`020?oj01P0ool0
2P3onP0H09@X00l0ool00P3oX@030?nf00@0ool0103onP050?ob00@0onH01@3ofP050?oB00@0olH0
103f^P000`3f]P00iZD00>JU00030>JU00D0eID01035P@040:a]000509AI002DE@00U5D009AE001c
>0000P1c=000101c<000DQ00058@001B4003034<008000@00P00000205X800@0<@0000H000000<f=
003o`P00gS@00000002/?0050:`h00P0La001@11200400P000030000002LfP00W=X002<0W=X000D0
onh000000000000000000<DT000G0?ooo`00403oool50?oj00030?of003onP00ooX001L0ool00`3o
mP070?oj01P0U2P04@3oo`020?nQ00@0ool01@3omP040?o^00D0onH01@3ofP050?o>00D0ol800`3f
]P000`3f/P00iZD00>JU00030>JU00D0eI401035P@000`2/K@00[6T00:aY00020:aY00@0U5000`1c
<004058@0080<@`000H000@0000000000000iRP00=hT001J2004034000040>K:003=S@00omH00=hd
00L0[3P0201c4002044800P0W=X000<0iR@009cJ002LfP008`2LfP03000000030<DT003oool0oooo
01D0oooo000@0?ooo`@0ooX00`3omP020?oj00`0ool00P3onP070?oo00H0ooH01@3onP0G09@X0080
ool000<0ooH00?oo003oo`000P3oo`000`3onP00ool00?oo000>0?oo00D0ooH0103ojP050?oR00D0
omH01@3ocP050?o200<0m[H000<0m[800>JQ003VX@000`3VX@050=FA00D0aGd0102/J@0409A<0080
Lc000P1Z;003058@0003034<000Y200000000080000000<0kR`00=hT001J20000`0a00001@3oo`00
i/X00?oV003oeP00gS@000L0[3P000<0La0009cJ002LfP003`2LfP000`3^:000W=X009cJ000S09cJ
00<0000000<0aB@00?ooo`3oool05@3oool00100oooo0P3omP00103onP00ooH00?ob003olP020?of
0080ooX02P3oo`050?oj00D0ool00`3olP050?of00<0ooX05`2D:000103onP00oo800?ob003omP03
0?oo00030?of003onP00ool000d0ool000<0ojX00?ob003olP000P3omP050?oZ00D0omh01@3oeP05
0?o:00D0okh00`3f/P020?J^00@0iZ401@3ES@050<Ei0080[6D00P2/H@0408]800<0JRP000@0JR@0
058@001B4000BQ000`0Y2002000000040?I000000000FPP0034000<0ool00P3olP000`3VC000W=X0
09cJ000H09cJ00030>hX003V9000W=X002<0W=X00`0000000`359000oooo0?ooo`0E0?ooo`003`3o
ool50?of00<0oo800P3omP020?oj00T0ool01`3onP030?oo00D0oo801@3omP0H09@X00040?of003o
kP00onh00?ob0080ool000<0onh00?ob003omP003P3oo`000`3oZP00oo800?ob00020?ob00D0onH0
1@3ogP050?oB00D0olX01@3o^P050?J^00D0iYd0103ER@050<Ei00D0[640102;A00206XT000406XP
001:4000BQ0004X@00<0:@P00`3^o`0S04Y400030>hX000Y:000:BP000`0:BP00P00800D04Y40005
0<DX0000000000000000003590005`3oool000l0oooo0P3olP020?of00030?ob003okP00onh000<0
oo8000@0ooH00?oj003onP00ooX01`3oo`090?oj00T0oo800P3omP0>045I00T0U2P00P3okP020?oZ
00060?o^003onP00ooX00?oZ003okP00oo802P3oo`040?oj00030?nZ003okP00onh00080onh01@3o
iP050?oJ00D0om801@3oaP050?nj00<0mZh00P3fZP050>JI00D0eHT0102mL@050:aM00@0Rd000`1Z
700204X@0080BP`000@0:@P0020800000000k_l01P2mmP020?oo00030?oj003^E@00[3P00080[3P0
1P2/=00707<@00H0@@P0100@00020>hX00030<DP001k<000Nc0000<0Nb`01@1k:00605X@000302TX
001B00000200008002000`0Y:00:04Y400050<DX0000000000000000003=90005`3oool000l0oooo
1@3olP030?o^00<0oo8000<0ooH00?oj003onP000P3onP050?oo00<0ooH01P3onP030?o^00P0oo80
5`11F@001@3ojP00onh00?oR003oiP00onX00080ooH000<0onH00?oZ003oo`002P3oo`020?of0080
ooX01@3ojP050?oR00D0omX01@3ocP050?o200D0okX00`3fZP020?JU00D0iYD01@3EQ@040;ea00D0
Y5T00P2;?00208/h0080HQ`00P1R600304X<00070208000P100000000?lh003=:000kR`00?me0003
000P0080ool000<0mV400>iE002/=000202/=00707<@00H0@@P0100@00000`000000kRP00<DT0003
07//00D0NbP00P1c900905X@00<0DP001P00800602TX00050<DX0000000000000000003=90005`3o
ool000l0oooo0P3okP000`3olP00onh00?o^00020?oZ0080onh00`3olP020?of00@0ooX00P3oo`06
0?of00@0ooX01@3okP050?ob00D0onH04`11F@001@3oiP00onX00?oN003ogP00onH00080oo8000@0
omh00?oV003onP00ooX0203oo`040?of00030?nZ003ojP00onX000<0onX0103ogP000`3ohP00omH0
0?oF00020?oF00D0olh01P3o`P050?nf00D0mZD01@3VU@050=F100D0_Fd0102TE@0408/h0080HQP0
0P1R500304X<008080@000@000000?m@003=:000kR`00P3oR@001P3oB000ooH00?of003oo`00ofD0
0:`X00H0[3@00`2T=00707<@00H0@@P0100@00000`000000mR`00<dT000507/X00D0Lb@0201J4000
101B4000>@`003T<002D0004058000P00200100000000`3=:000oooo0?ooo`0E0?ooo`003`3oool4
0?o^00@0onX00P3okP040?ob0080ooH0103onP030?ob00D0ooH00P3onP080?o^0080oo80203oiP0@
045I00050?oR003oiP00omX00?oJ003ogP000P3okP001@3ofP00omh00?of003omP00ooX000<0ool0
103onP050?ob00D0onH0103ogP050?oB00D0olX01P3o_P050?nb0080mZD00`3fX@050>JA00D0eH40
1@2mJ@040:A@00@0Pc@0101R400204X<0007044<000P100060@00000003oF@00cBP00?Hd00020?nA
00060?n9003okP00ooH00?of003oJ@00eET00`2/=0060:@d00L0La001P112004010000030000003f
;000cB@000<0NbP01@1c900207<P00H0FQ000`1B400303T800<0U0001@1B0004000P00@0000000<0
cBP00?ooo`3oool05@3oool000l0oooo0P3ojP00103okP00onX00?oV003oiP030?oZ0080onh01@3o
lP020?of0080ooX01@3olP050?of00X0onh02`3oiP0=0?oJ00030?oN003ohP00omH00080omX00P3o
jP000`3ocP00omX00?ob00020?ob0080ooX000<0ool00?of003omP000P3onP040?ob00D0onH01@3o
fP050?oB00D0olX01P3o_P050?nb0080mZ400`3fW@050>J=00D0eGT01@2mI@020:A@00<0Y4`00P23
<00208</00<0HQ000`11300201P400040000003oH@00eBP00?m40080oiT000<0oi400?oF003okP00
0P3oJ@000`3EF@00Y3@00:@d00070:@d00L0La001P11200401000080mS0000<0cB@007<T001c9000
101c900407<P00D0FQ00101B400503T800040<D<002D0000U00009@000H0DP00100000000`3=:000
oooo0?ooo`0E0?ooo`003P3oool50?oZ00<0onH00`3ojP000`3okP00oo800?ob00040?ob00<0ooH0
1`3olP030?of00<0onX01`3okP040?oR00L0onH0301c40001@3odP00omH00?oN003obP00omH00080
onH00P3obP000`3ocP00onh00?ob00080?of00@0onh0103oiP000`3oV@00omH00?oF00030?oF00D0
olh01@3oaP060?nj00D0ojh00P3fX@030?JM00D0iXd01@3EN@050;eU00D0Y4P01023;003068@0080
@@`000l0@@P001P4000H000060000?mY003E:000od`00?nQ003oW@00oiT00?o:003oeP00ofD00;@/
003EF@001@2T=0040:@`00L0La001P112004010000040?Hh003f<000cB@009@l00<0Lb@0101c8003
07<L0080FQ001P1B400303T800<0<@P000<0mQ@00<D<002D00000`2D0003058000@0000000<0cBP0
0?ooo`3oool05@3oool000h0oooo0P3oiP020?oZ00030?oV003ohP00on8000<0onH00P3ojP080?ob
00040?of003okP00onh00?o^00H0oo801P3ojP050?o^00P0on800`3oiP0<07<@00050?o>003odP00
omH00?o6003obP000P3ohP001@3o`P00olX00?oV003oiP00onh00080oo800P3omP040?ob00@0onh0
103ohP000`3oV@00omH00?oF00030?oF00D0olX01@3o`P060?nj00D0ojh00P3fW@030?JI00D0iXT0
1@3=M@000`2mH@00_Ed00;eM00020;eM00D0Y4@00P23:00208<T00<0FQ000`11200201P0000<0100
003oK@00eBP00?mE003oY@00oj400?nM003o`P00olX00?mU002d;000cET02@2T<00707<@00H0@@P0
100@0000103o?000mS000<dX002D?00507<P00D0La`01P1B4002058<0080>@P0100a20020?HD0080
a@`0102D00000`3N;000000000000002000000030=DX003oool0oooo01D0oooo000>0?ooo`<0onH0
00D0onX00?oV003ogP00omh00?oR00030?oV00030?oZ003okP00onh000L0oo801@3okP040?ob00@0
onH01@3ojP020?o^00@0omh01`3ohP0<07<@00050?o:003ocP00oo800?o2003oaP000P3ogP001@3o
]P00ol800?oR003ohP00onH00080onh00P3olP020?o^0080oo800P3oiP020?oZ00@0omh000<0oiT0
0?oB003odP000`3odP050?o:00D0ol801P3o]P050?nZ00030?JI003fU@00mYD00080mYD01P3VQ@05
0<ea00@0_Ed01@2T@00208<T0080Pb000`1J40020448000903T8000@000040000100003oN@00ofD0
0?mE003oZP00ojD00080okX000@0olX00?mU003=F@00cET02@2T<00707<@00H0@@P0100@0000103o
?000mSP00<dX002D?00307<P00L0La`0101B4004058<00L0<@P000<0ob000?HD003f50000P353002
09@000030=h/0000000000000080000000<0eBP00?ooo`3oool05@3oool000h0oooo0P3ohP000`3o
iP00on800?oR00030?oN0080on800P3oiP040?o^00D0oo801`3okP020?ob00L0onH0103ojP080?oN
00<0on80301c40001@3o`P00olX00?o^003o_P00ol800080omH000D0ok800?nf003ogP00omh00?oR
00070?oZ00030?o^003oiP00onH00080onH00`3ogP000`2LfP00oiT00?o>00040?o>00D0olH01@3o
_P060?nf00D0ojD000<0mYT00?JE003fU@000P3fU@060>J100D0cG401@2mF@0409`l00@0Na`0101J
300203T80080400000D020000?n1003oK@00cB`00?nb00020?nZ00030?nj003oF@00]2`00080cET0
2@2T<00707<@00H0@@P0100@0000103oA000oc`00<dX002D?00807<L0080LaP00P1B4007058<00H0
<@P00P3o80020?HD00<0a@`000<0gR`00000000000000P0000000`3E:000oooo0?ooo`0E0?ooo`00
3P3oool30?oR0080omh00P3ofP030?oN00040?oR003oiP00onX00?oZ00@0onh00P3olP0:0?o^00X0
onH0303ogP0<07<@00050?nn003o`P00onH00?nb003o_P000P3odP001@3oY@00ok800?oB003odP00
omX00080onH000D0onX00?oV003oiP00onH00?oZ00050?oR00D0omX00`3odP020?o>00D0ol801@3o
_P060?nb00D0ojD000<0mYD00?JA003fT@000P3fT@060>J100D0cFd01@2mE@0209`l0080W3P00P1k
700207/H00@0FP`00P0i200200P00080ohD000P0ogD00000003o]P00ok800?nU003oZP00mUD00;@/
0080cET01@2T<0040:@/00L0La001P112003010000050000003oB000oc`00<dX002D>0001P1c7004
07<H00T0DP`01`0a20020?lP00<0mQ@000<0a@`00=h/000000000`0000000`3E:000oooo0?ooo`0E
0?ooo`003P3oool20?oN00030?oR003ogP00omh000<0omX00`3ogP000`3ohP00onX00?oZ00020?oZ
00@0onh00`3ojP070?o^00<0on801`3oiP030?oJ00T0omh0301c40001@3o^P00okh00?oR003oZP00
ok800080olh000D0oid00?nU003ocP00olh00?oB00020?oN00<0on800P3oiP050?oN00@0omH0103o
cP020?J900D0ol801@3o^P060?n^00D0oj401@3fS@060=im00D0cFT01@2dD00409`d0080NaP00P1k
500405X<0080>@@00P0800002@3oU@00ohD00?mm00000000okX00?nf003oX@00ojD00?I@00030<eE
00T0Y2`01`1c4006044800<0400000D000000?m8003oA000000009@h000407<L00@0LaP00P1c5009
058<00H0<@P000<0<@@00?ll003o80000P3o80020?HD00030=h/0000000000000080000000<0eBP0
0?ooo`3oool05@3oool000h0oooo00<0omX00?oN003ogP000P3ofP020?oF0080omX00`3ogP020?oV
00@0onX00P3okP020?oV00<0onX01@3okP050?oR00D0onH01P3ofP050?oN00d0La0000D0ojh00?nj
003ogP00ojD00?nZ00020?o600050?nE003oW@00olH00?o6003ocP000P3ofP050?oN00D0omX00P3o
dP020?oF00@0olX00P3fR@050?nn00D0okX01@3o[P060?nQ00D0mXd01P3NN@050<eU00D0]4`0102L
<00407/@0080FP`00P1B30003@0i1000<@@000P000000000oiT00=h`003oQ@00:@000?nn003o^P00
oj400?nU003fD0000`3=E@090:@/00D0La000P1Z4005044800<0400000D020000000003oD000odP0
0000000209@d00D0LaP0101c5009058<00D0<@P00P0a10000`3oC000oc`00?lP00020?lP00030?HD
003N;00000000080000000<0eB`00=DX003oool05P3oool000h0oooo0P3ofP000`3ogP00omX00?oJ
00030?oF0080omX00P3ogP020?oR0080onH0103ojP040?oV00<0onX00`3okP080?oR0080onH0103o
eP050?oJ0080omh02@1c400405Z900030?nZ003o[P00omX00080oiT00P3o`P001@3oaP00ohT00?nn
003o_P00olH00080omH00`3ofP020?oN0080omH00P3ofP050?oB00@0olX00P3fR@050?nj00D0okH0
1@3oZP050?nM00030?nI003^Q@00kXD000<0kXD01P3NM@050<eQ00D0]4P00P2L<00209`/0080Na00
0P1c4004058<0080<@@00P0000000`3oY@00oiD00?n500020?o600040?nn003oW@00kTP00?I@00<0
cED02@2T;00207<@00D0JQ001@11200201000080200000@000000?mI003oB000U3@00P2D<00307<H
00@0La@00`1Z4008058<00<0<@P00`0a1000100Y1000od`00?m<003o?0030?lP00060=h/00000000
00000000003N;00000005`3oool000h0oooo0P3oeP000`3ofP00omH00?oF00020?oB0080omH00P3o
fP050?oR0080onH00P3ojP060?oV00<0onX02`3ohP080?oF00<0omX03@1JR@000`3oX@00ojX00?oF
00020?nA00070?nI003o_P00ol800?n1003oR@00okX00?nn00020?o>00030?oB003oeP00omH000H0
omH01@3ocP020?o600@0ohD01@3o/P050?nf00D0ojX01P3oV@050>j500H0gW401@3=G@050;A400@0
W2P0101c4002058<0080DPP00P0a10001`000000ojh00?nU003oX@00eC000?o:003oaP000P3oW@00
0`3^B000]2`00<eE00020<eE00D0Y2`00`2T:00406X@00@0JP`01@1120001`0@0000200000P00008
000000000?mM003=;0000`2D<00507<D00D0JQ00201B3002034800<0<@@00P0Y100010000000od`0
0?m<003o?0020?lP00050=h/0000000000000000003N;000603oool000h0oooo1@3oeP030?oB0080
omH000<0omX00?oR003ohP00103ohP0;0?oV00030?oZ003ogP00omh00080omh01`3ohP040?oB00L0
omH03@1JR@000`3oW@00oj400?oB00020?n=00070?nA003o/P00ok800?ma003oP@00ojh00?nf0002
0?o:00030?o>003odP00om800080om800P3ocP020?oB00D0olX01@3o`P040?nf0080ojh01@3o/P05
0?nU00@0oiT00P3oT@060>j100D0gW401@3=G@050;A00080U2@00P2D800407<@00@0DPP000T0<@@0
02T000000000ok800>Hd003oZP00eC000?o>003obP000P3oW@000`3^B000cE000<e@00020<e@00P0
Y2P0201Z3005044800@0200000@000000?mM003E;000U3000P2;<00307<D00L0JQ00201B30030344
00@0:@@000D000000?mM003oC000od`00?ll00020=h/00<0000000<0gR`00?ooo`3oool05P3oool0
00h0oooo0P3ocP000`3oeP00om800?oB00020?o>0080om800P3oeP080?oR00040?oV003ohP00on80
0?oR00H0onH0203ogP030?oR00P0om800`3oeP040?o200T0FXT000<0oiD00?nM003obP000P3oQ@00
1`3oS@00ojh00?n^003oJ@00og400?nZ003o[P000P3o`P000`3oaP00olh00?o>00020?o>00@0olX0
1@3oaP050?nn00@0okH00P3fM@050?nb00D0ojD0103oU@020?nA00H0kWd01@3NK@050<eE00D0]3`0
102D800407<@00<0DPP00`0Y00002P000000okh00?n^003oZP0000000?oB003ocP00oj400?nM003^
B0040<e@00H0Y2P00P2T900806X<00<0@@P00P11100400P00080ofD000@0eB`008/`002;<000Rc00
2P1Z4006058<0080BP`00P0a100502T400030000003oI@00oed00080od`00P3N;003000000030=h/
003oool0oooo01H0oooo000=0?ooo`@0olh00P3odP030?o>0080om8000<0omH00?oN003ogP00303o
hP040?oV00@0omX01`3ogP0;0?oB00P0ol801@1JR@001P3oS@00oiD00?o2003o`P00ogT00?mm0080
ojX000@0of400?mY003oW@00ojD00P3o_P000`3o`P00olH00?o600020?o:0080olH00P3obP030?o2
0080olH01@3o^P040?nb0080mW401@3o/P050?nQ00<0oi400`3oR@060>im00D0gVT01@35E@050:`h
0080U1`00P2D600406X<0080DPP000D0BPP002T0000Y0000:@000?o600020?nn00070=hd000Y0000
omX00?oB003oX@00iT@00;@/00040<e@00<0Y2P01@2T900806X<0003044800111000@@@00080@@@0
10080000103oK@00ofD00=D/002;<00208//00X0JQ00101B300404X<00L0:@@000D000000?mU003o
I@00oed00?m<00020=h/00<0000000<0gR`00?ooo`3oool05P3oool000d0oooo0P3obP020?o>00@0
olX00P3ocP020?oB00@0omh01@3ohP030?oN00@0on800P3oiP080?oJ00<0omh0103ocP070?oB00@0
okh0203o`P000`1J3000ohD00?n=00020?nn00060?ma003oN@00oid00?nM003oD000oeT00P3oU@02
0?nf00030?nj003o`P00ol800080olH0103o`P050?nn00D0okX00P3o[P0404X000D0okH01@3oW@02
0?nA00@0ohT01P3^M@050=iU00D0aD`01@2/=00409@D00@0JP`00`1:200202T000050200003ocP00
ol800?nn003N=0000P3ogP000`3oY@00oj400>I400050<e@00@0Y2@0102L900706X<00H0@@@01008
00000`3oL@00ofD00=D/000308//00X0JQ000P1B300604X<00L0:@@000H000000?mY003oI@00ofD0
0?mM003N;00300000080gR`0603oool000d0oooo0`3obP000`3ocP00olX00?o:00020?o200040?o:
003ocP00olh00?oB0080omX0103ogP020?oR00H0omh0103ohP0;0?oJ00P0olh00`3odP080?nn00@0
ol8000<0FP`00?n1003oQ@000P3o^P020?mY0080oiT000H0oid00?m8003oR@00ohT00?nA003o[P02
0?nf00030?nj003o_P00okh000@0okh00`3o^P020?nn00D0ok80103oZP000`3EjP00olh00?o>0004
0?o>00D0oid01P3oQ@060>ie00D0gV401@35B0050:`/00@0Ra@0101Z300204X8000304X4000P0000
80000080omH000P0olH00=i400000000on800?oN003oY@00oj400>I400D0cD`0102L900409`P00L0
JP`01P11100400P000030?ma003oK@00000000<0RbP02P1Z400804X<00L0:@@000<000000?mY003o
J@000P3oI@001P3N;0000000000000000000gS000=h/01P0oooo000=0?ooo`80olH00P3obP020?o6
00<0ol800P3obP000`3ocP00omX00?oJ00020?oJ00@0omh00`3ofP050?oN0080on800`3oeP080?oJ
00@0olX01`3ocP060?nj00H0okh000<0DP`00?mi003oP@000P3o]P002@3o^P00oed00?mQ003oT@00
oiT00?lh003o@000oh400?n900020?nU00030?nZ003o]P00okH000@0okX000<0okh00?nf003o]P00
0`3o]P050?nb00D0ojD01P3oZP050?nI00H0oh401P3^L@050=iM00D0aD@01@2/;00408/@0080JP`0
0P1R300304X40080800000X0omh00?oB003odP00gT@00200003oiP00on800?n^003VA000]2`01@35
C00809`P00L0JP`01P11100300P00080ogT000<0ofd008/X002;:0000P2;:00:06X@00P0BP`01P0Y
10000`0P000000000?ma00020?mY00030?mU003N;00000000080000000<0gS000=h/003oool05`3o
ool000d0oooo0`3oaP000`3obP00olH00?o600020?nn0080ol800P3obP020?oF00@0omX00P3ogP05
0?oJ00D0omh01@3oeP050?oJ00T0olX00`3ocP040?nf00P0okX000<0DP`00?me003oN@000P3o/P00
0`3o]P00oeD00?mM00020?n900040?l`003o>000ogD00?mm0080oid000@0ojD00?n^003o[P00ok80
1@3o]P040?nb00D0ojX01@3oY@000`3oV@00ojD00?nU00030?nU00<0oiD00P3oS@060?mm00H0kVd0
1@3NF@050<E000D0[2@0102;4004068<0080BP@000T0@@@00200003ohP00on800?oF003odP00[2`0
0?o^003ojP000P3o[P000`3VA000aD`00<E800040<E800P0W2001@1Z3002068<00@0@@@00P0i1003
00P000040?mm003oN@00eC0008/X00@0Rb@02@1Z400704X<000304X8000Y1000:@@000<0:@@00P0P
00000`000000og400?ma00020?mY00060=h/0000000000000000003N<0000000603oool000h0oooo
00<0ol800?o6003oaP000P3o`P030?nn0080ol8000<0olX00?oB003odP000P3oeP0<0?oJ0080omh0
103odP040?oF0080omX0103oaP080?o:00P0okH0103o^P00201B3000ofd00?me003oY@00ojX00?nb
003oC000oeD00P3oP@00103oR@00obP00?m]003oM@020?nE00030?nI003oZP00ojX000@0ojh00P3o
/P040?n^00D0ojX01@3oW@060?nE00030?nA003oR@00ohT00080ohT01P3oN@060>iY00D0eED01@35
?0050:`P00@0Ra000P1R300206880080@@@00P0H00002P3oiP00on800?oJ003VH@0080000?ob003o
kP00ok800?n^002d<0060<E800@0W200102L700306X<00@0HP`00P11100303T400<0200000@00000
0?n5003oN@00eC001@2;900706X@0080HQ001@1:300304X800<0:@@0100P00000`000000ogD00?ma
00020?mY00060=h/0000000000000000003N<0000000603oool000h0oooo0P3o`P000`3oaP00okh0
0?nn00020?nj0080okh00P3o`P040?oB0080omH00P3ofP030?oF00L0omX01`3odP030?oF00P0olH0
103obP040?n^00P0okH000<0DP`00?mY003oK@000P3oX@000`3oZP00okh00?ll00020?mm00040?n1
003o8000oed00?mM0080ohd000<0oiD00?nQ003oX@000P3oY@080?nZ00D0oj401@3oW@060?nA00D0
ohD01P3oM@050>iU00H0eE001@35>0040:@L00D0Pa000`1R2002044400070440000H0000onh00?oZ
003oiP00omX00>IQ00020?of00040?nj003o]P00iT`00;@`00H0aDP0202L7007068<00D0>@@00P08
0002000000030?n5003oN@00000000D0Rb@01@1Z4004068@00@0BP`0101:200202T400D0800000H0
00000?me003oM@00og400?mY003N;003000000030=h`003oool0oooo01L0oooo000>0?ooo`80okX0
00<0ol800?nn003o_P000`3o^P020?nn00030?o2003ocP00olh000<0om80203oeP050?oJ00@0olh0
1P3odP060?o200H0olH0203o[P040?nf0003058<003oG@00ofT00080oid000`0oj400?nj003o=000
oc`00?m]003oM@00mQ`00?lL003oE@00oed00?n1003oR@020?nI00@0oj400P3oY@040?nQ00D0oid0
1@3oU@060?n=00D0oh401P3oL@050>IM00H0eD`01@2m<0040:@H00D0P``000<0HPP005X8001J2000
0`1100002`0@0000ooH00?o^003ojP00iW400;@`003oo`00ooH00?nn003o]P00iT`000L0aD@0102L
700409`H00L0HP`01@0i10000`0800000000000000020?n=00030=D`002;9000Rb@00080Rb@00P2;
800306X@00H0HQ000P1:300604X800L0800000@000000?mi003oM@00og400P3N;002000000030>H`
003N<000oooo01P0oooo000>0?ooo`<0okX00P3o]P020?nb0080okX00P3o_P040?o>00<0om8000@0
omH00?oB003odP00om801@3oeP020?oJ00L0olh00`3odP0<0?o200H0ojX01P3o[P02058<00070?mE
003oU@00oiD00?nM003o/P00obP00?l`00020?mY00040?m]003^7000od@00?m<0080ogT000@0oh40
0?nA003oU@00oiD0203oW@050?nI00D0oi401P3oR@050?mm00H0mVd01@3VG@060=E400D0_C00102T
400408<<00@0FPP00P0i00001P0@0000ooX00?of003olP00onX00;@d0080ool000@0ooX00?nn003V
F@00]3001`35A00409`H00@0U1P01`1R300503T400<0000000@0oi400?n=003E<000Rb@01@2;8009
068@00P0BPP01`0P00001P000000ogT00?mi003oM@00eB`00=h/0080000000<0iS000=h`003oool0
603oool000h0oooo0P3o]P000`3o^P00okH00?nf00030?nb0080okX000<0okh00?o:003obP00103o
cP070?oB00D0omH02P3ocP0<0?o200@0ojD0203oZP0207>f00040?m@003oE@00oi400?nE0080ojh0
00L0ob000?mI003oF@00of400>HH003V7000oc`00080ofd000@0ogD00?n=003oS@00ohd0103oU@05
0?nI00@0oiD01P3oS@050?n500D0ogT01P3fJ@050>IE00H0eD@01@2m:0040:@@00@0N``00`1J2003
03T000060?oo003onP00ooH00?ob003^Q@00@@000P3oo`000`3obP00gV400>IE00030<E400D0aD00
202D6007068<00D0>@@00`0000000`3oU@00ohd00=D`000408/P0080Ra`02@1R400804X800L08000
00D000000?mm003oN@00ogD00=D/0003000000030>H`003N<000oooo01P0oooo000>0?ooo`<0okH0
0P3o/P020?n^00<0ok8000<0okX00?o:003obP000P3obP080?o>00@0om800P3oeP040?o:00H0olh0
103o_P080?o200P0ojD0103oZP0207>f00040?m8003oD000ohD00?nA0080ojX000X0oa`00?lP003o
E@00oeT00?me003V6000ob`00?ld003oI@00ofd00P3oP@00103oQ@00ohd00?n=003oS@060?nA00@0
ohd01P3oQ@050?mm00D0og401P3fI@050>IE00H0eC`0102m900509`@00@0N``00`1J100303T00005
0?oo003onP00ooH00>jE002m=0000P3oo`00103ocP00olX00=iQ002d<0030<E000D0_D00102D6004
09@D00L0HP`00`0i100203T0008000000P3oU@000`3oS@00000008/P000508/L00T0HQ00201:2007
02000080ogd00P3oN@001P3E;0000000000000000000iS00000001T0oooo000>0?ooo`80ok8000<0
okH00?nb003o/P00103o[P020?nb0080olH0103obP020?o>00<0olX0103ocP030?oB00L0olX00`3o
cP080?nn00@0ol801P3oW@060?nU0080LkH000@0od@00?m8003oP@00oh400P3oY@000`3oZP00oa`0
0?m<00020?m<00030=DD003o9000ob@00080oeT000@0of400?mi003oN@00ogT0103oR@040?n=00D0
ohT01@3oQ@050?mi00D0og401P3fH@050>I<00D0cCP01@2d700509`@00@0N``00`1B1002034000<0
ool000<0kZ400>jE001100000P3oo`000`3odP00olX00=iQ00090;e000@0U1@0102D4006068<0080
>@@0100i0002000000030?nM003oU@00eC@000@0Ra`00`236006068@00<0HP`0201:200602000006
01P0003oO@00ogd00?mm003oN@00eB`00P0000020>H`00030000003oool0oooo01L0oooo000>0?oo
o`<0ok80103oZP040?n^00040?nb003o`P00olH00?o600T0olX01@3ocP040?o600H0olX01P3o^P06
0?nn00`0oid00P3oA0004@3o@000od@00?mm003oO@00oh400?nM003oY@00mQP00?lL003o?000od@0
0?mU003=5000oa`00?lP003oB000oe000080ofd000<0ogD00?mm003oO@000P3oP@090?n500D0ogd0
1@3oM@050?mY00H0mUT01@3VB0050<dd00D0]1`0102L400407<800<0DP@00P0a00040?oo00080>jQ
002m=000ool00?oo003oeP00om800>I]002m=0080;dl00P0U100101R300305X800D0>@000P000002
0?nQ00030?nE003E=000PaP000H0PaP00`1R4006068<00H0BPP00P11200402000080600000H00000
0?mm003oO@00ogd00?mi003E;002000000030>Hd003V<000oooo01T0oooo000>0?ooo`80ojX000D0
ok800?nZ003oZP00ojX00?nQ00020?nZ00<0ojh00`3o`P020?o60080olX00`3oaP050?o:0080olh0
0`3o`P040?o600<0olX0103o]P080?nj00H0oiT01P3oW@030?lT00040?ld003oM@00ogD00?mm0080
oiD000<0oid00>hH003o>0000P3o>0000`354000cA@00?lH00020?m00080of4000<0ofT00?mi003o
N@000P3oN@090?mm00D0ogT01@3oL@050?mU00H0mUT01@3NA0050<d/00D0]1@0102D300207<80080
JPP00P1B10000`1B0000<@000?oo00030?oo00030?Jb002m>000ool00080ool000<0omH00>Ii002m
=0002@2m?00809@@00L0FPP0100i00001`0a000000000000003oY@00oj400=hd003E=00010236003
08<D00T0HP`0101:2004044800808000100H00001P000000oh400?mm003oO@00eC000=D/00800000
00<0iS@00>H`003oool06@3oool000h0oooo0`3oZP020?nU00030?nZ003oX@00oj4000<0ojX000<0
ojh00?nn003o_P000`3o`P070?o600D0olX01@3o`P050?o600P0okH0103o^P060?nE00H0oiT00`3o
9000103o<000oc@00?ma003oM@020?nA00070?nE003V6000iQP00?lX003o<000oe000;d@00020?HH
00030?l`003o>000oed00080oed00`3oK@040?me00D0ogT01@3oL@050?mY00D0of401P3fD0050=hl
00D0cB@01@2d400409@<00@0JPP00`1B00040?oo00030?Jn003f/P00>@000080ool000@0omh00>J1
003VN@00gV402@2m>00409@@00@0Ra001`1J200203T000<0<@000P000000103oY@00oj400=hd0000
000708<D00T0HP`00P1:2006044800H0600000D000000?n1003oO@00ogd00=D`0003000000030>Hd
00000000oooo01T0oooo000>0?ooo`80ojD000@0ojX00?nU003oY@00ojD00P3oW@020?nQ0080ojX0
103o_P030?o200P0olH00P3obP080?o20080olH0103o/P080?nf00`0oiD00`3V4000103o;000oc00
0?mY003oL@020?n=0080oi4000L0eA@00?lH003o6000ob000?m<002d3000iQ@00080ob000`3oC004
0?mQ00@0ofd0103oL@050?mY00D0of401@3oF@060>i800D0gSP01@3580040:`@00D0R``00`1Z1003
04X000@0ool000<0m/H00?Jn000000000P3oo`001@3oiP00omh00>J1002m=000gV4000D0_CP0102m
=00808/@00L0FPP0100a000200000080ojh000<0oj400=hd002350001`235009068<00L0@@P000<0
@@@001P0000H0000100H00001@000000ohD00?n1003oO@00eC000080000000<0iS`00>Hd003oool0
6P3oool000h0oooo103oY@000`3oW@00ojD00?nM00020?nM0080oj4000<0ojX00?nj003o^P00103o
_P020?o200T0olH02P3o`P080?nb00@0okH01P3oT@060?nE00@0e@`000<0ob`00?mQ003oH@000P3o
Q@020?n=0080eA@00P3o60020?ll00060;@<003V5000oa`00?lL003o@000odP00P3oE@020?mM00@0
of40103oI@050?mQ00D0oed01@3oD0060>i000D0gS001@3560040:`@00@0R``0101R100304X000<0
ool000<0m/X00?K6002D<0000`3oo`000`3oiP00iXd00;dh00020=iQ00D0_C@0102d=00808/@00H0
FPP01@0a000010000000ok800?nb003o[P020=hd00H0Pa@00P234009068<00D0@@P00`11100601P0
0080ohD000<0oh400?mm003E<0000P0000000`3VA000iS@00?ooo`0J0?ooo`003P3oool20?nM0080
ojD00P3oW@020?nE0080oid00P3oX@040?nj00@0okh00`3o`P060?o600@0okh01P3o`P0<0?nb00`0
oi40103E30001@3o9000oeT00?mI003oH@00oh400080ohD000<0oi400<d@003=40000P3o60000`3o
<000Y0P00<d@00020?lH0080oc0000@0ocP00?m@003oD000oe003@3oG@050?mE00D0odP01P3^?005
0=DX00@0aA001@2T300408<800<0HP@00P1100040?oo00030?KB0035H@00U3@00080ool000D0onh0
0?oZ003VU@00iXd00;dh00020=iM00T0]3@0202;400605X800D0<@0000D000000?nf003o/P00ojh0
0=hd000408<D00D0Pa002@1R3004044800@0@@@01P0H00000`3oR@00ohD00?n500020=D`00040000
003VA000iT@00>Hd01/0oooo000?0?ooo`030?nI003oW@00oid00080oiT00`3oU@020?nM00030?nQ
003o]P00okH000@0okX01@3o_P030?o200<0olH01`3o_P030?o200@0ojh0203o/P0<0?n=00@0a@`0
00@0ob000?lT003oE@00oeT00P3oM@00103oO@00ohd00?n=003540020?lD0080obP000H0W0@00<D<
003o5000oa@00?lP003o:0040?m400P0oe00103oE@050?m<00D0od@01P3^=0040=DP00D0_A001@2T
300408<800040684001J0000FP00044000@0ool000<0k]X00?KB002L=0000P3oo`001@3olP00onh0
0>JQ003VU@00_CP000<0eET02@2d<00808/@00H0FPP01@0a00001P000000okH00?nb003N@000Y2`0
08<D00P0Pa001`1R300205X<0080@@P01P11100501P000050100003oS@00ohD00?n5003E<0000P00
00000`3VC000iT@00:`/000K0?ooo`003`3oool20?nI00030?nM003oT@00oi400080oi400`3oU@00
0`3oW@00okH00?nf00020?nf00@0okX01@3o_P040?o200@0okX01P3o_P080?n^00@0ok801P3oR@06
0?n=00D0a@`000<0ob000?m@003oD0000P3oL@020?me0080oh4000<0_@`00>hD003^50000P3o7000
1P2D0000_@`00>h@003^4000oa@00?lH00<0oc@0103oA0090?m<00@0od@01@3f?0050>H/00D0eAP0
1@2m400409`<00@0N`P00`1J00000`0i0000ool00?oo00020?oo00030>kN003^fP00W3@000<0ool0
00@0ooH00?o^003VX@00_CP0103EF@090;@/00@0Ra001023400605X800<0<@0000L0:@000000003o
^P00okX00=i8003N@000Y2`000T0Pa001@1R300405X<00P0@@@00`0H000201000080ohd000<0ohT0
0?n5003E<0000P0000000`3VC000iT@00:`/000K0?ooo`003`3oool20?nA00030?nI003oT@00oi40
00@0oi400P3oU@030?nb00<0okH01@3o^P040?nn0080ol80103o]P030?nj00<0okh01P3oZP060?n^
00`0ohT01@3530001@3o7000ob000?m<003oD000ofd00080og400P3oO@000`3oP@00]0`00=h@0002
0?lD00030?lH00230000[0P00080gQ000P3o50030?lX00<0ocP02@3o@0050?ll00@0mS@01@3V9005
0<dD00D0]100102L300307/400<0DP0000<0<@000?oo003oo`000P3oo`00103^hP00k]h009`h001B
00020?oo0080ooH000<0iZD00;dl003EE@00103EE@090;@X00L0Pa001@1J2002058800040340000Y
0000:@0002T00080okh000<0okX00=i8002/<0002P234003068<00H0FP`0201110000`0H00004000
01000002010000050?nE003oS@00ohd00?n5003E<0000P0000000`3VC000iT@00:`/000K0?ooo`00
3`3oool30?nA0080ohd000<0oi400?n9003oT@000`3oT@000`3oU@00ojX00?nb00030?nb0080okH0
1@3o^P040?nn00P0okH00P3o^P0<0?nZ00d0ohT0103=40020?lL0080od000P3oJ@000`3oK@00ogT0
0?mi00020?mm00030:`8003E4000oa@00080oa@000<0N`000:@4003=30000P3f40030?lH00@0ob`0
103o>0040?ld00D0oc00103^;0050=hL00D0cA00102d300409@800@0JP@00`1B00001`3oo`00k^h0
0?oo003ViP00k^H00;f=002L>0000`3oo`00103onP00i[X00>Jb002mA0060=E@00D0]2P0102/:007
08<<00<0FPP00`1B200502T000050?o2003o_P00okX00=i8002/<0002P23400905X<00H0@@@000<0
>@@00100000@0000100@00000`3oU@00ohd00?n=00020=D`00040000003VE@00iT`00>I401`0oooo
000?0?ooo`80ohT000@0oi400?n=003oS@00ohd00P3oQ@00103oR@00oi400?nA003oT@030?nZ00@0
ok800`3o]P040?nj0080okh02`3o]P0;0?nZ00L0ohD01P3oR@050<d@00050?lL003o?000oc`00?m0
003oG@000P3oH@030?me00030?mi002T1000c@`00080mQ@000@0oaP00004002L0000_@`00P3V4003
0?lD00<0oa`0203o;0050?lX00@0kR001@3N50050<D@00@0[0`0102;200306X000<0BP0000L0:@00
0?oo003oo`00i^X00;fQ002mV@00W3P000<0ool00P3onP000`3V^P00_E000=E@00060=E@00D0[2P0
102/900708<<00<0DPP00`1B100302T00080800000@0olH00?nn003NE@00gTP02023400307/@00T0
FP`01011100303T400H0400000@0oiT00?nE003oS@00eC000P0000000`3^F@00iT`00;@/000L0?oo
o`003`3oool30?n900030?nA003oQ@00ohd000<0ohD00P3oR@000`3oT@00ojD00?nU00030?nZ00D0
ok800`3o]P030?nj00/0okH0103oY@070?nZ00d0ohD01@3=80020?lL00050?lh003o?000oeT00?mI
003oG@000P3oJ@001@3oK@00og400?ma002T1000_@`00080kQ000P3o500010002000[0@00=D<003E
30020?H@00@0oa@00`3o60040?lP00D0mQ`0103V60050=D@00D0_@`0102T300408<400<0HP000P1:
00030?Ko00040>KZ002mY@00_J400:@h00@0ool000<0i/H00>Jn002mH@00203=C0090:`T00<0P``0
101k30060584000402T0000P0000800002000080olH000<0gUT00=iE002L90001023400707/@00T0
FP`00P11100503T400D040000P3oV@00103oU@00ohd00=D`000000020>iI00030>I<003oool0oooo
01/0oooo000@0?ooo`030?n5003oR@00ohT00080ohD000<0ohd00?mm003oQ@000P3oQ@000`3oR@00
ojD00?nU00020?nU00<0ojX01@3o/P040?nf00@0ok801`3o]P080?nU00<0ojX03@3oQ@050=Dh0080
mQ`00P3o=0020?m@00030?mI003oI@00ofD00080ofT00P3oK@00102D0000]0P00=h@003N40020?l@
0004000<002T1000a@`00<D<0080iQ000`3f40040?l@00@0mQ@0103^50040=h@00D0eA00102m3004
09`800@0N`@00`1R000203T00080k_l00P3NkP000`000000Y4`0044000040?oo00030=k:003VaP00
_F4000T0cD`0202/800807/<00D0DP@0100P00020?o:00040?o6003NF@00[30009`T00/0Na002@1J
300703T400D0400000<0oid00?nI003oU@000P3E<00010000000kV400>iI002d;00M0?ooo`00403o
ool20?n500040?n9003oO@00ogd00?n500<0ogd00P3oQ@020?nQ00@0ojD00P3oZP020?n^00D0ok80
0P3o]P030?n^00@0ok800`3o]P060?nQ00D0ojD03@3oQ@060=Dh0080mQ`00P3o<0030?m<00<0of40
0`3oJ@00102;0000[0@00<d<003=30030>h@0003000@002D0000[0@00080e@`00`3^40030?H@00@0
kQ00103V40040=h@00D0a@`0102d300409@400<0L`000`1J00000`0i0000g_l00<g^00020=G^0003
0;fn0000000000000080ool00P3fo`001@3oo`00g/h00;em002L>000kW4000T0cDP0202/700707/<
00@0DP@00P1:100302000080olh000D0olX00=EY003NF@00[30009`P000;07/@00L0FP`00P1J2007
03T400@040000P3oW@00203oV@00oiD00=D`003E<00000000>iQ003^F@00]2`07@3oool00100oooo
0P3oO@00103oQ@00ogd00?mm003oO@020?mi00<0ogd000@0ohD00?nM003oX@00oj40103oY@040?n^
00D0ok801`3o[P030?nb00/0oj403@3oQ@070=i<00030?HL003o:000obP00080od@000<0odP00?mE
003oE@000P3oF@020?mM00050?mQ00230000Y0@00:@4002m20000P3V3000103^400001@008<0002L
00020;d800<0e@`00`3V30030>H@00@0gQ00103E30050<D<00@0Y0P00`2;100406X0000804X0003=
mP00cOH00=Go0035jP00cNX00;C6002TO@0200P800080?Ko000i000000000?Ko003NeP00g]800;B=
002L>0020>I]00T0cD@0202T600407/<00<0L``00P1B100404X400<080000P3ocP000`3obP00eFT0
0;@d000209`P00X0Na001@1J300405X800H0>@@00P0i00030100000600P0003oX@00oid00?nM003E
=000eC000P0000000`3^H@00kUT00;@/000M0?ooo`00403oool30?mm0080ogD000@0ogd00?mi003o
N@00ogT00`3oO@030?nM0080oj400P3oY@030?nZ00@0ojh00P3o/P040?nZ00H0ojh0303oX@0<0?n5
00L0gUT000H0mQP00?lT003o9000obP00?m0003oA0020?m@0080oeD0103oF@0207/0000409`0002/
1000c@`00<d<0080iP`000@001P006X0002T1000Y0@00`2m20020<d<00@0e@`00`3=30040<D<00D0
]0P00`2L100407/000<0HP0000@0]>800;gZ002dhP00_NH00P2dcP000`2TT@00Y8d0034@00020>ko
00070>Ko000i000000000=GJ003NeP00]8d009`h00030>IY00T0aD00102T60040:@D00L0L``01P1:
10000`0P000060000?oB00020?o>00030=E]002d=000W1`00080W1`02P1k400305X<00H0FPP0100i
100303T000<040000P080000103oX@00oid00?nM003E=002000000030>iY003^H@00kUT001h0oooo
000A0?ooo`030?me003oO@00ogD00080ogD000<0ogd00?ma003oN@000P3oN@000`3oO@00oiD00?nE
00030?nM0080oj401P3oZP030?n^00L0ojX00`3o[P060?nM00H0oj403@3oQ@050=iI00030>IU003f
6000mQP00080ob@00`3o?0030?m<00H0oe0000D0L`0008/0002T1000Y0@00;d800020=D<0004000@
00006000N`0009@00080Y0@00`2m20030<D800@0_@P00`2d20040:@400@0R`000P3oo`003035lP00
FW4007^M002DdP00W=H00:CJ002/eP00[=8009bb002LY@00ReT006Xd0080g_l000P0i_l00=kj003N
nP00<@00000800000000]9T007<`00@0iVD02@35@0040:@D00@0Y1001`1c300504X400<0600000D0
om800?o>003EM@00eFd00;@d000309`H00X0Na002@1J200203T400D0>@000P0@000300P000040?nU
003oX@00oid00=Dd0080000000<0kVT00>iQ002m<0007P3oool00140oooo0`3oM@000`3oL@00ogD0
0?me00020?mY00<0ogT0103oU@030?nM00<0ojD0403oZP0<0?nM00d0ohD01`3VI@00103f6000ob00
0?lP003o80020?lh0080od000P3oA0040?m800<0od`000<0JP0008<0002L00000P2T10020<D80005
0=D<0000600001`007/0002D00000`2L00030:@400<0[0@0102L100308/0000E07/0002mnP00cOl0
0=Go003oo`0000000<Go002/jP00Y>800:CN002TdP00W<X009BI002DS@00Nc@007<d001Z=000aNh0
0<gf003ElP00eOH00080cN8000@0000001P@0000200000001@3VI@090<Dl00P0Y1001P1c300304X4
00<0BP000P0H00001@3oeP00om800=Ei003EM@00eFd000@0W1P01`1k400307/<00T0FPP01`0i0004
00P00080ojD000L0oj400?nM003E=00000000>ia003^J@00kV4001l0oooo000A0?ooo`80ofd000@0
ogD00?mY003oJ@00og400`3oJ@00103oL@00ogT00?nA003oT@040?nE0080oid00`3oX@020?nU00<0
ojX0103oY@060?nZ00`0oid03@3oQ@070>I]0080mQP00P3o70020?l`00040?ld003o?000oc`00?ll
00@0od@0103o@0000`1R0000N`0008/0000209`00080[0@00P2m200010006000220000PP001c0004
08<000<0R`00102300001@2/A000N`0008^9001Z0000cOl000<0ool00P3ofP00302TgP00W=8009c:
002;S@00Pg40068`002D^P00Y<h00:cJ002dhP00_NH00<G^0080aN8000<0]<H001P0000H40000P0H
4002000000@0gV402035>00809`@00@0L``00`1Z200304X000<0@@0000H060000?oF003oeP00eGd0
0=Ei003EM@0509`H00@0Na000`1k300307<<00L0FPP00P1B200703T000@0200000<0ojX00?nU003o
X@000P3E=00010000000mWD00>iY002m<00O0?ooo`004P3oool00`3oJ@00ofd00?mY00020?mY0003
0?ma003oI@00ofT00080ofT0103oT@040?nE00H0oj402P3oY@030?nZ00D0oiT01P3oW@0=0?n500D0
iVd00`3^M@020?HH0080oa`00`3o;0070?lh00@0oc`000D0oc@005X0001c0000N`0008/0000209@0
0080Y0@00P2/1000100060000200000P001J000206X000<0L`000`1Z00001@3omP00eHD000080035
bP00i_l000<0m_l00140oo800?oJ002dP@00DWD006:5001ZU@00LjD008>b002;_P00Y=h00:cN002d
hP00]=X00;CF002dcP00Y:X000P0000203TD0080610000<000P00000003NG@000`3NG@080;dd00P0
W1001`1Z2005044000070100003oeP00omH00?oF003EO@00eGT00000000509`H00@0N``01P1c3005
05X800@0DPP01@0i0002034000<020000P3oZP00103oY@00oj400=Dd000000020?Ie00030>iY002m
<000oooo01h0oooo000B0?ooo`80ofT000@0ofd00?mQ003oJ@00ofT00P3oI@030?mY0080ohd00`3o
T@020?nE00<0oid02`3oX@050?nU00/0oiT03@3oQ@080>ie00@0oaP00`3o:0020?l/00D0oc@01`3o
<0001@1J0000L`0007<0001k0000P`0000T0R`0000<0BP000200000H00000`0Y0000103okP00kY40
08=4003omP020?Ko000:0>ko003oo`00oo800?oJ002dP@00]>X00:cZ002;cP00U=800:cZ0080[>H0
0P2dgP000`2/cP00Y;H00:BZ0002058/00<0>A@00P0H40000`00200000000=iI00020=iI00P0_C00
202D400406X80080HPP01P1100020?oJ00040?oF003ER@00eGd00;@h00<0W1P00`2D500:07<<00<0
FPP01@1B200403T000<0<@000`08000010000000ojh00?nZ003oY@020=Dd00040000003fO@00mWD0
0;d`0200oooo000B0?ooo`80of4000@0ofT00?mQ003oH@00ofT00P3oG@020?mU00030?mY003oQ@00
ohD000<0ohd00P3oT@060?nM00<0oj40103oW@060?nQ00/0oiT03@3oQ@080>ii00030?Im003o6000
oaP00080oaP00P3o90040?lX00@0oc00103o;0040?lT000405X0001Z0000JP0006X000P0L`0000@0
JP000?l@003N3000omX00P3o[P00103onP00okh00?nf002D10040?oo00040?oJ003oaP00_Hd00=hL
0080_OX000P0]?800;C^002djP00]>800:cF002/cP00W9D009Ai0080LdP00P1B;00203TD00<06100
00@000000=EE003EE@00eED0202m;00809@@00H0HPP0101100001`0i0000omX00?oJ003ofP00eHd0
0=F9002d>0000`2D500409@@00X0L``0201B200203T000D0<@000P0800001`000000ojh00?n^003o
ZP00ojD00=Dd000000000P3fO@000`3fM@00_C000?ooo`0O0?ooo`004P3oool30?mQ0080oeT000@0
of400?mM003oG@00oed00P3oI@040?n500<0ohd00`3oV@0=0?nM00<0oj401P3oU@050?nI00d0ohD0
2@3fO@040?lH00<0ob001`3o90050?lP00@0oa`000<0mQ0006X0001R00000P1R00000`1J0000DP00
0580000205800080BP0000<0<@000?oB003oP@000P000000103onP00kS@00?nf002mO@020?oo000?
0?of003olP00omX00?o6002mS@00@B000<go0035o`00_O800;CZ002/eP00Y<X00:Bn002;H@00JS@0
00<0LdP00P1B;00303TD0080610000@000P00000003ED000eE00202m;00409@@00<0U0`01`1R2002
04400080>@000`3ofP00103EU@00eHd00;dh002d>00709@@00T0L``02@1B2007034000<0000000<0
ok800?n^003oZP000P3E=00010000000mXD00?Im003fM@0Q0?ooo`004`3oool00`3oF@00of400?mI
00020?mI00030?mQ003oE@00oed00080oed000<0ofD00?n1003oP@000`3oQ@020?n=00<0oiD00P3o
V@030?nM00@0oiT01P3oW@0<0?nE00`0ohD0203fO@020?J100@0oaP00`3o70070?lP00@0oa`01@3o
50020>h@0080N`0000@0L`000680001B0000DP000P0i0000600H000080000?oB003oW@00:@000?nA
003o?000kS@00?nf003VU@00ool00?oZ003omP00on800?oJ003oV@00k[X0044P003o9000_O800:cJ
002TbP00W:X009BI00<0Red0101cB002058/0080>A@00`0H4002000000030=E@002d9000]2@000H0
]2@0102D300308/<00L0HPP00`0i00030?oJ00040=FI003EU@00_CP00;dh00P0U1002@1c30090588
00H0<@000`0000020?nb00040?n^003E=000eC@00=Dd0080mXD000<0mWd00;d`003oool0803oool0
01<0oooo0`3oF@000`3oD000oeT00?mI00020?m<00030?mE003oG@00oed000D0oh400P3oQ@060?nE
00T0oiT00`3oW@060?nA00H0oiD0303oQ@0:0?J100D0oaP01P3o70040?lH00@0oa@0103f40040>H@
00060:@4002/1000W0@009`400230000L`000P2D10001@0a1000oid00688003oT@00]20000800000
00d0iYD00?oo00000000omh00?oR003ofP00oiT00>jj003=W@00W7d00?lT002DY@00RgT00080Y6d0
0`2;G@00103o]P00LdP007=8001cB002058/00030?nM000i5000>A@00080610000<000P00000003E
B000202d800708/<00@0HPP00P1J100203T000060340003ffP00m]X00?oJ003EW@00eIT00P2m>008
09@@00X0L``02@1B20060340008000000P3o]P020?nb0080eC@000@000000?J9003fQ@00mWd08P3o
ool001<0oooo0P3oD000103oF@00oe000?m@003oF@030?m<0080oeD00`3oO@040?n100<0oi401P3o
U@090?nI00`0oi40303oQ@0;0?J10080oaP00P3o70030?lH00L0oa@0103f40050>h@00L0gP`00P3N
40001`353000Y0`00;@@003oW@00L``00?nA002d80000P0000020?oo000;0<dT003odP00omH00?oB
003oV@00m[h00<fM002LO@00Lf400?lX002mO@000P2TK@0408]M00@0LdP00P1B;00203TD00<06100
00<000P00000002/70001`2/700708/<00H0FP@00P0a00020>kF00050?KJ003EX@00eId00=FI002m
>0002@2D400:07<<00H0DPP00`1B100603400080000000@0okX00?nf003o/P00ok800P3E=0020?J9
00030?J5002m=000oooo0240oooo000C0?ooo`<0oe0000D0oeT00?m8003oD000oe000?m800030?m<
00030?mE003oM@00ogd000<0ogd00P3oP@020?n=00<0oi401`3oU@060?nI00/0oi403@3oQ@070?J1
00@0oh40103o70020?lH00P0oa@0103f40040>H@00D0e@`00`3o:000203^8000eA000=h`003ofP00
oid00:`X003oT@00]2000P0000020?oo000;0<dT003obP00omH00?oB003oV@00m[h00>J^002LO@00
Lf400?lX002mO@000`2TK@0308]M00040?nf001cB000LdP007=80080DR`000<0oid003TD000i5000
0`0H40000`000000[1P00:`H00050:`H00P0P``01P1J1000200a0000k]H00>kF003^eP00eJD00=FQ
003EW@00_D002P2D400:07<<00<0DPP01@1B100503400080:@0000<000000?nj003o^P000P3o]P00
1P3o/P00eC@00000003fT@00mXT00?J502<0oooo000D0?ooo`030?m8003oD000oe000080od0000@0
oe000?m8003oB000odP00P3oC0030?me00@0ogd01@3oS@030?nA00L0oiD00`3oV@060?n=00D0oi40
3@3oQ@070?n100@0ohD00P3o90020?lP00<0oaP0103o50030?l@00@0kQ00103N30050<D<000=0:`4
003oC000odP00?m8003f@000oed00?oJ003ocP00[2P00?nA002d800000000?n^00020?oo00040100
003obP00olh00?o>0080oiT000H0iZh00<fQ001cH@00FT`00?lX003obP020:A]00@0Red0101cB002
058/00<0>A@00P0H40001000200000000:`H002/60040:`@00L0P``0101J1002058400080340003V
dP00i]800>kF003=Y@00eJD00=FQ002m@00;09@@00L0L``00P1Z3009058400<0<@000`0Y00020000
00060?nn003o^P00okX00?nf003E>000eC@00P3fT@000`3fR@00aC@00?ooo`0R0?ooo`00503oool3
0?m800<0od0000<0odP00?m0003oB0000P3oB0000`3oC000og400?ma00020?me0080ogd00`3oR@05
0?n=00D0oi401@3oU@0;0?n=01P0ohD01@3o90030?lH00<0oa@0103f40040>H@00@0e@`01@2d2000
0`2D1000ofd00?mU00020?mM00040>I<003ocP00[2P00?nA0080000000D0ojh00<gV003o`P004000
0?o:00020?o>0080oiT000<0iZh00<fQ002mU@000P1JC000103o7000Y6d00:A]003o`P0308]M0004
0?nf001cB000LdP007=80080DR`000<0oid003TD000i50000`0H4002000000030:`@002T4000Y100
0080Y1001023300307/<00<0DP@00`1B0000203NcP00i]800>KB003=ZP00cJD00;eM002L=000[200
2`2D400407<<00D0JP`02@1B10000`0a0000:@0002T0000302T000030000003o_P00okh00080okX0
00L0okH00=Dh00000000mYD00?JA003fR@00aC@002<0oooo000E0?ooo`040?m0003oB000odP00?ll
00<0od0000@0ocP00?m0003oB000odP01@3oL@000`3oM@00ohT00?n900040?n900H0ohd01P3oT@0;
0?n=01T0ohD01@3o:0020?lL00@0oa@0103f40030=h<00D0a@P0102/10002@1k0000ofd00?n9003o
O@00oed00>I<003ocP00[2P00?nA0002000000050?n^003^X@00ol800100003obP000P3ocP020?nI
00030?Jj003=X@00_ID00080[8d000@0oa`00?lD002TK@00Y6d00`2;G@00103o]P00LdP007=8001c
B003058/00030?nM000i5000>A@00080610000<000P00000002T4000102T400407/<00<0L`P01@1B
00001`3EbP00g/h00<FZ0035ZP00cJD00;AY002L>0000P2/700;09@@00T0JP`0201B100702T00007
0000003o`P00okh00?nn003o^P00eC`00=Dh00020?JE00030?JA0035=000aC@002<0oooo000E0?oo
o`80ocP000<0odP00?ll003o?0000P3o@0020?lh0080od000`3oJ@040?ma0080ohD01P3oR@070?n=
00<0oi401@3oR@060?n=00`0oh401`3oQ@050?n100<0oc000P3o;0030?lP00<0oa@0103^40040=D<
00@0_@P01@2D00020?n900060?mm003oL@00iT`00?o>002/:000oi400P0000001@3o[P00okH00?o2
000@0000olX00080olh000D0ojD00?nI003f^P00k[H00;fE00020:b=000509b9003o5000oa@00:A]
003o`P000`2;G@00103o]P00LdP007=8001cB002058/00030?nM000i5000>A@000<0610000<000P0
0000002T40000`2T400607<800<0DP0000T0BP000<g6003=aP00eLX00<F^0035ZP00]7T00;Aa002T
>0000`2/700509@@00D0Ra001`1Z300306X800D0DP@00`1:100602T000030000003o`P00ol800080
okh000L0eD@00=Dl003oV@00oiT00?JE003fT@00aC@002@0oooo000E0?ooo`<0ocP000@0od000?ld
003o?000oc`00P3o<0020?lh00030?m0003oI@00ofD00080ofT00P3oL@030?mm0080ohD0203oR@05
0?n=00/0ohT06@3oP@020?lh00<0oc000`3o80030?lD00@0kQ00103=30040:`400@0N`0000P0FP00
0?n9003oO@00og400>iU003ocP00[2P00?nA0080000000@0ojh00?nf003o`P0040000`3ocP001@3o
Y@00oiT00=hP003^]P00gZh00080[8d000D0W8T00?lD003o5000mQ000?o2000308]M00040?nf001c
B000LdP007=800<0DR`000<0oid003TD000i50000`0H400010000000W10009`@002L400407<800<0
JPP00`1:00020<Fn00060<g60035[P00aJh00;B5002dN@00Y3P00`2/700;08/@00@0JP`01P1Z2002
058400H0BP@01P0Y000030000000olH00?o2003o`P00okh00=E400000000oj400?nI003fU@00aC@0
000002@0oooo000F0?ooo`030?l`003o>000ocP00080oc@000<0oc`00?l`003o<0000P3o<0000`3o
>000ofD00?mU00030?mU00030?mY003oO@00ogd000@0ogd00P3oQ@0:0?n900/0ohD06@3oP@030?m0
0080oc@0103o90030?lD00@0iQ001035200409`400@0JP0000L0ohT00?mm003oL@00ohD00?o>002/
:000oi400080000000@0ojh006X@003obP0040000`3ocP001@3oY@00oiT00?nI003^]P00gZh00080
eJh000H0W8T009B9002DR@00mQ000:A]003o`P0308]M00040?nf001cB000LdP007=80080DR`000<0
oid003TD000i50000`0H400010002000000009@<002D300706X80080BP000P2m]P001@35_P00_Jh0
0<F^002dS@00]8D00080Y3P00`2/600;08/@00T0JPP0201:100702T00080olH00P3o`P001`3EB000
eD@00?nQ003oX@00oiT00?JE0035=0009@3oool001H0oooo0`3o<0020?l/0080oc@000<0ob`00?l`
003o<0000P3o<0020?mM00@0ofD00P3oN@060?mm00@0ohD01@3oR@0;0?n501T0oh4000<0kXd00?m8
003oB0000`3o?0030?lX00@0oa@0103V40040;d800@0U0@00`1J00001`3oW@00oi400?ma003oQ@00
olh00<e<003oT@000P000000203o[P00JQ000?oB000@0000olh00?oB003obP00ojD00P3oV@000`3o
`P00gZh00=F^00020=F^0080U8T000<0RhT00?H@003N30000`2;G@00103o]P00LdP007=8001cB003
058/00030?nM000i5000>A@000<061000P0000000`2D3000JPP006X8000206X80080HP@000<0@@00
0:bM002dZP000P2dZP001P2d[P00_Jh00;BE002dQ@00Y4@00:@h00@0[1P0202;400308/<00H0JPP0
0`1R200804X400D0:@0000<080000?o:003obP000P3oaP000`3o`P00eDP00?nU00020?nQ00030?nI
0035=000oooo02D0oooo000G0?ooo`040?lX003o<000oc000?lT0080ob`000<0oc@00?lT003o;000
0P3o<0030?mI00030?mM003oI@00ofD000<0ogD00P3oN@030?mm00D0oh403`3oQ@0I0?n10080kXT0
0P3oD0030?m000<0oc000`3o50040>H@00D0_@P0102300020580000704X0003o[P00ohD00?n5003o
cP0000000?nA0002000000050?n^002T=000om800100003ocP000P3odP000`3oY@00oiT00?nI0002
0?o200<0eJh000@0cJh008^9002;R@00Ri400P3N300010352000Red00?nf003o]P0307=80080DR`0
0P3oW@0203TD0080610000<000P00000002;30001@1R10020:B=00030:bM002/ZP00]:X00080[:D0
00@0]9d00:aY002TA000Pc@01@2/500408/@00L0R``00`1Z2006068800P0BP@00P0Y000402000005
0?o>003obP00olH00?o6003EC0000P3oY@020?nQ0080aC@09P3oool001L0oooo0P3o:0000`3o<000
ob@00?lT00020?l/0080ob@00P3o;0050?mI00030?mM003oM@00ogD000@0ogD00P3oN@0E0?n101T0
ogd000<0mXD00?mI003oF@000`3oB0040?ld00<0oa`0103N4000102m2000]0P00;@8002d200308<0
000:07/0001:0000@@000440003o[P00oj400?n5003ocP00cD`00?nA0080000000@0ojh00:@d003o
dP0040000`3odP020?nU00030?nI003N8000ol800080m/8000@0eJh00<f^003=/P00cK800P2;T@00
1@2;V@00a@P00:@4002;G@00okH000<0LdP00`1B;0000`3oW@00>A@003TD000301P@000300080000
0000HP@00080HP@000/0RfT009am002LX@00W:400:BU002/ZP00[:h00:bU002dW@00[6T009@h0007
0:`D00X0R``02P1R200504X40080BP001P0P00020?o>0080olX000L0olH00=E<003oZP00ojD00?nQ
0035>000aC@002L0oooo000H0?ooo`040?lP003o:000obP00?lL0080ob@000D0ob`00?lL003o9000
ob@00?l/00020?m@00@0oeT00P3oL@060?me00@0ogd01@3oP@060?mm00D0oh406@3oO@00103fQ@00
of400?mQ003oH@030?m@00<0oc`0103o80040=h@00<0]0P000D0]0`007/0001k1000N`@007<40002
044000060?n^003oX@00ohD00?o>003=C000oi400P0000001@3o[P00Y3@00?oB000@0000omX00080
om8000D0ok800?nU003oV@00gR000?o200020?K200050?K6003=[P00cK800<fb0035]P000P2;V@00
1@2;X@00Y0@00:@4002;0000okH000<0LdP00P1B;0020?nM0080>A@00`0H40001P000000HP@008=@
0023D000U94009bI0080W:4000H0[;X00:bb002/W@00[9d00:aY002D>0020:`D00H0Y1002P2;3009
068800<0BP@01@1:000602000080olh00P3obP00103EE@00ojX00?nZ003oY@020<Dh00030<Dd003o
ool0oooo02D0oooo000I0?ooo`040?lL003o8000oa`00?lL0080ob@000@0oeD00?lL003o7000ob@0
1@3oD0020?mI0080ofT00P3oL@030?me00D0ogT0:03oO@020?J500<0ofT00P3oE@040?m000@0ob@0
103N40030;@<00030:`<001c1000L`@00080L`@000L0>@000?n^003oX@00ohD00?o>003=C000oi40
0080000000@0ojh00?n1003odP0040000P3ofP000`3odP00ok800?nU00020?nI00050?o2003f`P00
m/800?K6003^aP000P3=/P000`35]P00aKh00<Fn000208^Q000608^^001:K@00L`0007<0001J0000
LdP00`1B;0000`3oW@00>A@003TD000301P@0003068d00000000RhT00080U94000P0Y<800:Bn002T
_P00[;800:b^002/W@00Y50009@h00T0Y1002P2;3009068800P0BP001@0P00030?o>0080eET000@0
eED00?n^003oZP00ojD00P35>00X0?ooo`006@3oool20?lL00050?lP003o7000oa`00?lL003o9000
103o70020?m800@0oe001@3oJ@020?ma00X0ogT02P3oO@0I0?mi0080mX400`3oJ@030?mM00<0od@0
0`3o:0020?l/00@0gQ00102/300307<4000=06X8003o[P00oj400?n5003ocP00cD`00?nA003oE@00
00000?n^003oP@00>@P0010000020?oJ00030?oN003o/P00ojD00080oiT000P0om800?K2003f`P00
m/H00>k6003^bP00cK800<Ff0080aKh000<0aLH008^^002;[P000P2D^P02059m000605Z=000i0000
600001P0000i;000BS@00P1JB0000`1ZG@00Lfd007=]00020000000909c2002T`P00Y;h00:Bn002d
bP00[;X00:bM002TK@00U3P000T0Y1001P2;300508<<00T0HPP01@1:0003044000D0800000<0om80
0?o>003ocP000P3EF@020?n^00030?nZ0035>000aCP002T0oooo000J0?ooo`H0oa`000<0od`00?lH
003o70000P3o70020?m400030?m8003oD000oe0000<0ofD01@3oJ@040?me02P0ogT00P3fP@030?ma
00@0of400`3oC0030?l/00050?ld003N4000gQ000=h@003N5000102/300207<40080JPP000`0ojh0
0?nQ003oQ@00olh00<e<003oT@00oeD00000003o]P00oh400?l/000@00020?oJ00030?oN003o/P00
ojD00080oiT000D0gR000?oF003faP00m/H00>k600020>k:00040<Ff0035_P00aKh00<G60080cLh0
0P2D^P0209c2000409c>001RV@00HYT006ZU0080Ljh000H0NkH008>n0023_P00Rl8009C200002002
000000070;CN002deP00]<X00:bj002/X@00Y6d007/d000:0:@@00/0P``0201R200304X000D0@@00
1@0P00020?oB00090?o>003EG@00eET00=EI003o/P00ojh00?nZ0035>000000002T0oooo000J0?oo
o`L0oa`00`3o60000`3o7000od@00?m400020?m400030?m8003oI@00ofD000@0ofD00P3oJ@050?ma
00@0ogD02`3oN@0;0?me00d0ogT00`3fO@030?mi00<0ofT0103oD0020?ld0080ocP00P3N50020=DH
00@0[0`00`1Z2000303o[P00oj400?n5003ocP00cD`00?nA003oE@0000000?nf003oP@00ob`00100
0080omX000<0omh00?nb003o/P000P3oV@001@3N8000omH00?oF003faP00k/H00080k/X000@0k]80
0<Fn0035_P00aLH00P3=cP000`3=fP00W<8009c2000209c>0080Y=X000@0Y>800:cZ002/jP00[>h0
0`2dlP0201P@0003000800000000]=H00080_Lh000<0[:400:A]001c<0002`2T400:08<<00T0HPP0
1`110004020000<0omH000@0om800?o>003EG@00eET00P3o/P000`3o[P00aCP00000000Z0?ooo`00
6P3oool20?lH0080oa`000<0oaP00?lL003o7000103o60030?ll00<0od@0103oG@030?mU00X0og40
8P3oM@030?Ii0080ogT000<0ogd00?mY003oJ@000P3oK@020?m@00050?mI003o>000ocP00?lh003o
?0000`3E6000103E7000[0`00:`<002/30020:`@0080JPP000`0ojh00?nQ003oQ@00olh00<e<003o
T@00oeD00?oF003o]P00oh400?l/000@00020?oJ00040?oN003o/P00ok800?nU0080oiT00`3oeP00
103^aP00k/X00>k:003^dP020>kF00040>kN003=cP00cLh00<gJ0080cN8000@0cNh00:CJ002TfP00
Y>800P2/jP00102/kP00]?800;Cb002dlP0401P@0080000000@0_Lh00:bQ002L>000_B00302T400:
08<<00H0HPP00`1R10070440008080000P0H00001@3ofP00omH00?oF003odP00eFD000<0okX000<0
ok800<Dh0035>000:`3oool001/0oooo1@3o60000`3o7000oc`00?lH00030?lH0080oc@00P3o?002
0?m400<0oeT0103oG@090?m]00X0og40603oM@030?Ii00<0ogd0103oK@020?mI0080oed00P3o?002
0?m40080eA`00P3E9000102/3000[1000:`@002/400206X800080?n^003oX@00ohD00?o>003=C000
oi400?mE003oeP020?n100050?l/000@0000mR`00?oJ003ogP000P3o/P000`3oY@00oiT00?nI0003
0?oF00040?oJ003^bP00k/X00>kB0080k]H000@0k]h00>kV003=fP00cMX00P3=hP000`3=kP00eOH0
0=Gf00070=Go000503TD000H4000610001P@000020000P0000000`2D>000_A`00;dL000;0:@@00/0
P``00`1R2005068400P0@@000`0H00020?oJ0080omH000<0eFT00=EU003o_P000P3o^P000`3o/P00
aCP00?ooo`0[0?ooo`006`3oool40?lH00030?HH003o6000oa`000@0oaP0103o=0020?ll00L0oeT0
1@3oJ@0:0?m]0100og40303oM@040?Ie00<0ohD00`3oM@030?mM00050?mQ003o?000od@00?m4003f
B0000`3E90000`3E:000[1000:`@00030:`@000@06X8003o[P00oj400?n5003ocP00cD`00?nA0000
0000omH00?o2003oP@00Y3@00100003f;000onH00?oN0080ok8000@0ojD00?nI003oV@00gR000P3o
eP00103ofP00on800>kB003^dP020>kF00050>kN003^iP00m_800?Kb003=hP000P3=kP020=Gf00H0
eOl000<0oid00=Go000i50000`0H40000`00200000000;dL00020;dL00H0Y1001@2L400:08<<00H0
HP@00`1J1007044000@060000`3ofP00103oeP00eFT00?nn003o_P020?nj00030<Dh00000000oooo
02/0oooo000L0?ooo`080?HH003o6000oaP00?lH003^6000mQP00?ld003f60030?lH00<0oc000P3o
=0040?mE00@0oeT0103oI@050?mY00X0ofd0703oL@00103oQ@00ohT00?n9003oM@020?mi00030?mM
003oH@00of400080od@00P3fB0001@3fC000eB@00=DX003E:000eC0000@0[1000140JPP00?n^003o
X@00oi400?o>003=C000oi400000003oeP00ol800?n1002T=000ok800?H/003oiP00omh00?nj0002
0?nb0080oiT000D0gR000?oF003oeP00omX00?oR00020?oV00040>kF003^gP00k]h00>kV0080m_80
00@0m_X00?Ko003fo`00m_l01P3Eo`030?nM00050=ko000H4000610001P@000020000P0000020;dH
00/0W1001@23300507/<00<0HP@01P1J1007044000<06000103ofP001`3EK@00eFT00?Jn003o_P00
okX00<E00035>000;@3oool001`0oooo0P3f60020?lH0080kQP000@0mQP00?l/003^5000mQP00P3o
60020?lX00<0oc00103oC0030?mE00T0ofD02P3oJ@0G0?m]00D0og400`3oR@030?mi0080of400P3o
I@020?I80080mT`00P3E:0020=D`00@0[1000140ol800?n^003oX@00oi400?o>003=C000oi400000
003oeP00ol800?n1002T=000ok800?H/003oiP00onX00?nj00020?nb0080oiT000D0gR000?oF003o
eP00omX00?oR00020?oV00040?o^003omP00k^H00>kV0080m_8000<0m_X00?Ko003fo`001P3fo`02
058/0080oid000<0eO8003TD000H40000P0H40001000200000000000002m500;09`@00X0N``0201J
1007044000<060000P3ogP020?oJ00050<ea003EK@00m[h00?Jn003o_P000P35@00^0?ooo`007@3o
ool01`3^6000mQP00?HH003o6000iQ@00>hH003f60000`3^50000`3f6000obP00?lX00020?lX0080
oc000P3oB0050?m<00@0oed03`3oI@0;0?mY0100ofd00P3oR@000`3oS@00ogT00?mi00020?mm0080
ofD00P3oJ@00103fB000mT`00?I@003fD0020=D`000<0=Dd003E>000[1000:`@002/5000ol800?n^
003oX@00oi400?o>003=C000oi400P000000203o`P00oh400:@d003o;000mR`00?oV003ojP00okX0
0P3o/P030?nI00040?oZ003ofP00omX00?oR0080onH000D0onh00?of003oo`00ool00?Kb00020?Kj
00P0m_l00`1B;0020?nM000309@h000H400061000080610000<000P00000002m50001@2L400609`<
00D0N``0101k200905X400D0@@000P0i000201P000<0omh000<0omX00<ea003f`P000P3f`P00103f
_P00okh00<E00035@00^0?ooo`007P3oool0203V5000kQP00?HH003o;000gQ@00>HD003o9000iQ@0
0`3^50030?lP0080obP01@3oB0020?m<00D0oeT0103oG@0:0?mU01/0ofT00`3oS@030?mm00030?n1
003oI@00ofT00080ofT000D0mT`00?I@003fD000mU000=D`00020=Dd000E0=Dh002/4000[1000:`D
003o`P00okH00?nQ003oT@00olh00<e<003oT@0000000>HX003o`P00oh400:@d003o;000mR`00?oV
003ojP00okX00080ok800`3oV@00103N8000oo800?oR003ohP020?oV00030?o^003omP00ool000<0
ool0203fo`04058/0080oid000<0]1@003TD000H40000P0H40000`00200000000000000:09`<00X0
N`P02@1J1002044000D0>@0000<060000?oN003ogP000P3ogP000`3=N@00cG400?K600020?K20003
0?Jn0035A000aD0002l0oooo000N0?ooo`80iQ@00P3^60020=hD00040>HD003o8000iQ@00>HD0080
kQ@00P3o70030?lP00<0od000`3oB0090?mI00X0of402`3oJ@0A0?mU00040?n=003oT@00oi400?mm
0080oh400`3oJ@001@3oK@00mU000?I@003fD000mUD00080eC@00P3E>0004`2/4000[1@00:`L002/
8000okH00?nQ003oT@00olh00<e<003oT@0000000:@X003o`P00oh400:@d003o;00040000?oV003o
jP000P3o^P001P3o/P00oiT00;eM003oV@00gR000?ob0080ooH000@0ool00?o^003okP00ooH02`3o
o`0207=800@0DR`00P3oW@000`2d4000610001P@000201P@0003000800000000W0`000T0W0`02P1k
200805X400L0>@000P0@00001@3ohP00omh00?oN003ogP00cGT00080m/H00P3f`P000`35C000U300
0?ooo`0_0?ooo`007`3oool0103N5000iQ@00>HD003^60020=hD00030>HD003o6000iQ@00080iQ@0
103o70020?lP00<0oc`00`3o@0090?mE00T0oed02`3oI@0<0?mQ00D0ofD00`3oT@030?n100060?n5
003oJ@00ofd00?m]003oL@00mU000P3fE@00103fF@00eC@00=Dh003E?0020:`D000A0:`L002/8000
okH00?nQ003oT@00olh00<e<003oT@0000000:@X003o`P00oh400?ld001c600040000?oV003ojP00
0P3o^P001P3o/P00ojD00;eM002mG@00gR000?ob0080ooH00P3oo`020?of00T0ool00`3o]P000`1c
B000DR`0058/0002058/00<0oid000@0>A@001P@000H400061000P0020000`000000W0`009`<0007
09`<00T0N`P0201J100703T0008040000P3ohP020?oN00070<em003fbP00m/X00?K6003f`P00aE00
0<E<000a0?ooo`00803oool20=hD00040>HD003N5000gQ@00=hD0080oaP00P3N4000103V5000oaP0
0?lH003o60020?lL00L0oc`0103oC0040?mE00X0oeT06`3oH@020?nA0080oiD000<0oh400?n5003o
Q@000P3oK@020?ma0080mUD00P3fF@020=Dh000=0=Dl003E@000[1@00:`L002/8000okH00?nQ003o
T@00olh00<e<003oQ@0000000?ll00020?n100050?ld001c600040000?oV003ojP000P3o^P001P3o
/P00ojD00;eM002mG@00gR000?ob0080ooH03P3oo`030?nf000307=8001B;000DR`00080DR`00P3o
W@000`2d4000610001P@000201P@0003000800000000000000L0W0`01@1k200507<800D0FP@00`1J
000703T000@0on800P3=P@030?K:00030?K60035D000aE000380oooo000Q0?ooo`040=DD003N5000
gQ@00=DD0080gQ@00P3o60000`3E4000gQ000=h@00050?lH00<0oc@0103o?0040?m800<0od`02P3o
F@0K0?mM00@0oiD00`3oQ@001@3oK@00og400?ma003oL@00mUD000<0mUT000D0eCP00=Dl003E?000
eD000:`L00020:`P00080?nf003oX@00oi400?o>00080000ohD00000003o?0020?n100050?ld001c
600040000?oV003ojP000P3o^P000`3o/P00ojD00;eM00020;eM00030=hP003omP00ooH000d0ool0
103o]P000`1cB000DR`0058/0002058/00<0oid000<0]10001P@000H40000P0H4000100020000000
09`<002L300509@<00X0L`P00P1J100605X000H0>@0000<040000?oV003ohP000P3ohP000`3=P@00
m/h00?K>00020?K:00030<EI0035D000aE000380oooo000R0?ooo`070<d@003E5000gQ@00<d@003E
5000gQ@00?lH00030=D@00030=h@003o5000oaP00080oaP0103o;0030?ld00P0odP02@3oE@0;0?mM
00/0oeT01P3oG@030?nE00<0ohD00`3oL@001@3oM@00mUT00?II003fF@00mUd00080eC`00P3E@000
4P2/7000[2000:`P003o]P00oj400?nA003ocP0040000?n500000000ojX00?o2003oP@00oc@007<H
0011300000000?oZ0080okX00P3oY@00103oV@00_Ed00;eM003N80020?of00`0ool00P2;G@040?nf
000307=8001B;000DR`00080DR`00P3oW@000`2d4000>A@001P@000201P@008000P000<0000009@<
002D3000102D300907<800D0FP000`1B000503T00004034000080000onH00?oV0080on8000P0cHD0
0?K>003fcP00m/h00?K:0035G@00aET00<E@03<0oooo000R0?ooo`H0cA000P3o60020<d@00040=D@
003o5000oa@00?lD0080oaP00`3o:0030?l/00T0od@02@3oD00K0?mI00<0oiD00`3oQ@000`3oR@00
og400?me00020?me0080mUT000<0mUd00?IQ003E?0000P3E@000202/7000[2000:`P003o]P00oj40
0?nA003ocP00DP`00P000000203oZP00ol800?n1003o=000LaP0044<00000000onX00P3o^P000`3o
ZP00ojD00?nI00020;eM00030=hP003oo`00ool000/0ool00P3o`P000`2;G@00okH00?nf00020?nf
000307=8001B;000DR`00080DR`00`3oW@000`2d4000610001P@000201P@00030008000000000000
00@0U0`02P1c200805800080>@000`0a00040?oV0080cHT0103fcP020<EM000309`d003oool0oooo
0380oooo000S0?ooo`<0cA0000H0aA000<d@003=4000oa@00?lH003540020<d@00@0oa@01`3o:004
0?ll00@0od@02@3oC00F0?mE00D0mU00103oU@000`3oQ@00ohT00?n900040?me00070?II003fG@00
mUd00?IQ003E?000eD000=E400020:`P00060:`T003o]P00oj400?nA003ocP00[3@00P0000001`3o
ZP00ol800?n1003o=000LaP0044<000000000`3o^P000`3oZP00ojD00?nI00020;eM00d0ool00`3o
`P0208]M00@0okH000<0LdP0058/001B;0000P1B;0030?nM000403TD000H4000610001P@008000P0
00<0000009@<002D30000P2D300:07<800L0DP001P0a00040?oV0080cHT000@0m]800?K>003fcP00
m/h00P35G@0e0?ooo`00903oool00`354000cA000<d@00020<D@00060<d@003f5000oa@00<D<0035
4000cA000P3f50020?lD00<0ob00103o:0040?lh00<0oc`02P3oC00E0?m@00H0mT`00`3oU@00103o
Q@00ohT00?n9003oR@030?me0080mUd00P3fH@020=E000060=E4003EB000[2000:`T003o]P00oj40
0P3oT@002P2d>00000000000003oZP00ol800?n1003o=000LaP0044<003f;0030?nj00030?nZ003o
Y@00oiT00080_Ed000<000000=hP003oo`002@3oo`050?o2000308]M003o]P00okH00080okH000<0
LdP0058/001B;0000P1B;0030?nM000309@<000H400061000080610000<000P00000000000000P2D
300:07<800L0DP001P0a00040?oV00040<f=003=R@00m]800?KB0080m/h000<0aF400<EM003oool0
=@3oool002@0oooo1P3540020?HD00<0a@`01@3f50030?lL00<0ob00203o>0090?m400X0oe002`3o
C0060?I800<0oiD0103oR@030?me00050?mi003fG@00mV400?IQ003E@0000P3EA000203EB000[200
0:`T003o]P00oj400?nA003^M@00]3P00P000000103oZP00BP`00?n1003o=00207<H00030<dT003o
^P00okX00080ojX000<0ojD00?nI002mG@000P2mG@000`3N8000ool00?oo00070?oo0080Y6d0103o
`P000`2;G@00okH00?nf00030?nf000307=8001B;000DR`00080DR`00`3oW@000`0i5000610001P@
000201P@0004000800000000000008/<00D0L`P0101Z1008058000@0<@00103oiP020<fA00<0k]80
00D0m]800<EY0035J@00aF4009`d000f0?ooo`009@3oool010353000aA000<D@002m30020<D@0005
0>hD003f5000mQ@00;d<003530001@3f50030?lD00<0oa`0203o<0080?m001D0odP01P3fB000103f
A000oiD00?nE003oU@030?n90080ogD00P3oN@030?IQ00050=E0003EA000eD@00=E8002/90000P3o
]P00103oX@00oi400>ie002d>002000000040?nZ001:3000[3`00?ld0080LaP000D0[5000?nM003o
W@00oid00?nZ00020?nU00040?nI002mG@00_Ed0000000T0ool000<0olX00:A]003o`P00103o`P00
0`2;G@00okH00?nf00020?nf000307=8001B;000DR`00080DR`00`3oW@000`2;3000610001P@0002
01P@008000P000<0000008/<001Z1000201Z1008058000@0<@0000@0m^X00?oV003oiP00onH00P3=
T@00103^eP00k]800>kB003fdP020<EY000309`d003oool0oooo03D0oooo000V0?ooo`030;d<0035
3000aA000080_@`000@0aA000>hD003^5000mQ@00P2m30020>h@0080mQ@01`3o50070?l/00T0oc`0
2P3oA00:0?m800L0mT@00`3oU@030?n900040?me003oN@00ogT00?mi00<0mV400P3EA0020=E80007
0:`T003o]P00okH00?nQ003oT@00kWD00;@h0002000000060>HX001:3000[3`00?ld001c60004000
0P2/D0020?nM00040?nZ003oY@00ojD00?nI0080_Ed0203oo`030?o:00030:A]003o`P00ol8000<0
ol8000<0Red00?nf003o]P000`3o]P000`1cB000DR`0058/0002058/00<0oid000<0R``001P@000H
40000P0H40000`00200000000000000906X400L0DP000P0a000202T00080m^X00P3oiP00103=U@00
cI400>kF003^eP020>kB00030<E]0035J@00W3@003P0oooo000W0?ooo`80_@`000<0kQ@00;d<002m
30000`3^50030;d<0080iQ000P3^40060?lD00@0ob@0103o;0090?ld00T0od002`3oA0060?Hl00<0
oiD00`3oR@040?mi00<0mV4000D0mVD00=E4003EB000eDP00:`T00020?nf00050?nQ003oT@00kWD0
0;@h000P00000P0000001`1:3000[3`00?ld002TA00040000?H/002/D0000P3oW@00103oZP00ojD0
0?nU003oV@020;eM00030000003N8000ool000@0ool01@3obP000`2TK@00ol800?o200030?o20003
08]M003o]P00okH00080okH000<0LdP0058/001B;0000P1B;0040?nM00@061000P002002000000L0
JP@0101B000304X000<0:@00103fjP020<FI00@0k]H00P2mL@000`35K@00W3@00?ooo`0h0?ooo`00
:03oool20;d<00030>H@002d3000_@`00080iQ0000@0kQ@00;@8002d2000_@`0103V40050?lD00P0
ob@02@3o=00D0?ll00H0mSP00`3oU@040?n900<0ogT00`3fH@001@3fI@00eD@00=E8003EB000[2@0
0080okH000D0oj400?nA003^M@00]3P0020000020000000704X<002/?000oc@00:A4001c6000[4`0
0:a@00020?nM00040?nZ003oY@00ojD00?nI0080_Ed000<000000=hP003oo`000`3oo`020;em00@0
olX000<0Y6d00?o2003o`P000`3o`P000`2;G@00okH00?nf00030?nf000307=8001B;000DR`00080
DR`00`3oW@000`2;2000610001P@000201P@008000P000<0000006X4001Z1000101R100704X00080
:@001@3fjP001035W@00aIT00>kJ003^fP020>kF00040;ee002mL@00W3@009`d03X0oooo000Y0?oo
o`060;@8002m3000gQ000;@8002d3000gQ000`3V40020;@800040=h@003V4000iQ000>H@00D0oa@0
203o80080?l`00X0oc`02P3o>0060>h`00<0oiD0103oR@040?mi00030?IQ003fI@00mVD00080eDP0
00T0eD`00?nf003o]P00okH00?nQ003oT@00kWD00;@h000P00000P0000001`1:3000aED00?ld002T
A000LaP00100002/C0000P3oW@00103oZP00ojD00?nU003oV@030;eM00040000003oo`00ool00?oo
0080olh000<0_Gd00?o:003obP000P3obP000`2TK@00ol800?o200030?o2000308]M003o]P00okH0
00<0okH000<0LdP0058/001B;0000P1B;0040?nM000303TD000H400061000080610000<000P00000
00000000101R100804X00080:@0000@0k^X00?KZ003fjP00m^X00P35W@030>kJ00050>kF002mO@00
_GD00;ea002L=000>`3oool002T0oooo0`2d20001@3N4000[0P00;@<003E4000gQ000080iQ0000<0
[0P00;@8003N40000P3N40060?lD00P0oaP0203o;00D0?ld00H0kR`00`3oU@030?n900@0ogT000D0
mV400?IU003fI@00mVD00=E800020=E<0080okH000D0oj400?nA003^M@00]3P00200000200000080
BP`000D000000?ld001c600000000:a<00020?nM00030?nZ003oY@00ojD00080oiT00P2mG@030?oo
00040?KZ003ocP00olh00;em0080olX000@0_A000?o:003obP00Y6d01@3o`P000`2;G@00okH00?nf
00030?nf000307=8001B;000DR`00080DR`00`3oW@000`232000610001P@000201P@008000P00P00
0003068000L0BP000P0Y00020>kZ0080m^X00P35W@020>KJ0080k]X00P2mO@000`2mM@00W3@00?oo
o`0k0?ooo`00:`3oool20;@800030=h@002/2000[0P00080eA0000@0gQ000?lD002/1000[0P00P3E
30000`3N4000oa000?l@00040?l@00L0oa@0203o900:0?l`00X0ob`01@3^;000103^:000oiD00?nE
003oU@040?n900<0ogT0103fI@002P3EB000eD`00=E<003o]P00ojh00?nQ003oT@00kWD00;@h000P
000200000080BP`000P000000?ld001c600040000:a<003fT@00oid00?nZ0080ojD00P3oV@020;eM
00030000003N8000m^X000<0olh00P2mO@040?o:00030:A]003o`P00ol8000<0ol8000<0Red00?nf
003o]P000`3o]P000`1cB000DR`0058/0002058/00@0oid000<0>A@001P@000H40000P0H40020008
00040000001R0000HP00068000H0BP0000<080000>kZ003^jP000P3^jP020<FQ00040<FM003VfP00
i]X00>KJ0080_H4000<0_Gd009`h002L>000?@3oool002`0oooo00H0[0P00;@8003E4000[0@00:`8
003=30020=D@0080[0@000@0[0P00<d<003=3000e@`01P3f40070?lD00P0ob004`3o;0060>hX00<0
oiD000@0oi400?n9003oR@00ohT0103oN@030?IU00<0eD`000h0okH00000003oX@00oi400>ie002d
>00080000000000Y1000oc`004X<00000000oc@007<H008000000P3fT@000`3oZP00ojD00?nU0002
0?nI0080_Ed000<000000=hP003ocP00103ocP000`2mO@00olX00?o:00020?o:00030:A]003o`P00
ol8000@0ol8000<0Red00?nf003o]P000`3o]P05058/00@0oid0100H400200080080000000@0HP00
04X0001:0000BP000`1100030>KZ0080k^X000<0aJD00<FQ0035X@00103VfP020;f10080W3P0?P3o
ool002d0oooo00H0Y0@00;@8003=3000Y0@00:`4003530020<d<00030?H@002T1000[0@000@0c@`0
0P3^40030?H@00L0oa@0203o60090?lT00T0mRP01`3^80000`3oU@00oi400?nA00030?n900@0ogT0
0`3fI@030=E<00090?nf00000000oj400?mm003^M@00]3P0020000000000ojX00080BP`000D00000
0?ld003o/P00_F400:a<00020?JA00@0oj4000<0oiT00;eM002mG@000P0000000`3=S@00olh00?o>
00020?o>00030;em003obP00olX000<0olX000<0Y6d00?o2003o`P000`3o`P000`2;G@00okH00?nf
00030?nf000307=8001B;000DR`00080DR`0103oW@000`1R0000610001P@000201P@008000P00P00
0006044000040>KV003VjP00i^X00>kZ0080aJD01@3VfP00102mQ@00_H4009`h002L>00o0?ooo`00
;@3oool20:@40080c@`000H0W0@00:`4002m3000a@`00<d<003^40020:@400@0a@`00P3V40020>h@
00L0oa@0203o60090?lP00X0mR001P3V70000`3oU@00oi400?nA00030?n900040?n5003oN@00ogT0
0?mi00<0mVD00`3EC0002@3o]P0000000?nQ003oS@00kWD00;@h000P000000000?nZ000204X<0003
0000003o=000ok800080_F400P3fT@040?nQ00060>J9002mG@00_Ed00;eM003=4000cHd0103ocP00
0`2mO@00olX00?o:00030?o:00030:A]003o`P00ol8000@0ol801P3o]P05058/00@0oid01@0H4002
00080003000000110000@@0000<0@@000P3ViP020>KZ0080aJD0103VfP020;f900030;f5002L>000
oooo0400oooo000_0?ooo`80Y0@000<0a@`009`4002m30000P2m30030>h@00030:@4002m2000_@P0
0080_@P00P3V30020>H@00L0oa00203o50090?lH00T0mQ`01P3V50030?nA00040?n=003oR@00ohD0
0?n500<0ogT00`3fI@040=E<00080000003oX@00ohd007/@002d>00080000000003oZP0204X<0003
0000003o=000ok800080_F400P3fT@040?nQ0080iXT00P2mG@000`000000cHd00?o>00040?o>0003
0;em003obP00]0`000<0olX01P3o`P000`2;G@00okH00?nf00030?nf000307=8001B;000DR`00080
DR`0103oW@000`1J0000610001P@000201P@008000P00P000002044000<0g^H000D0i^H00;fZ002m
ZP00aJD00=kJ00020>KJ0080_Hd000<0_HT009`h002L>000@P3oool00300oooo00H0W0@00:@4002m
3000W00009`4002d20020;d<0080iQ0000<0W0000;@8002d20000P2m20020=h<0080iP`01`3f400@
0?lD00X0kQP01P3V4000103oT@00ohd00?n=003oR@020?n500<0ogT000<0ogD00?IU003fI@00103E
C0003@000000oj400?n=001k4000]3P0020000000000ojX00;@P001:300000000?ld002TA0000P2m
H@020?JA00@0oj400P3VR@00102LF@00_Ed00000003o70050?o>00030;em003obP00olX000<0olX0
00<0Y6d00?o2003o`P000`3o`P000`2;G@00okH00?nf00040?nf00D0DR`0103oW@0501P@008000P0
00@0000003T0000i0000aA`00P3NiP030;fZ0080g]X000H0i]X00;B=002mS@00_Hd00;f9002L>013
0?ooo`00<@3oool01@2D0000Y0@00;@8002m3000W00000<0]0P00P3N3000102D0000W0000;@8002d
20050=h<00H0mQ002@3o40070?H@00X0kQ001P3N40030?n=00<0ohD000@0oh400?mi003oM@00ogD0
0P3fI@004@3fH@00eD`00=E<003EC00000000?nQ003oS@00Na000;@h000P000000000?nZ001J4000
BP`00000003o=000Y4@00080_F400P3fT@040?nQ0080iXT00P2LF@000`000000oa`00?o>00040?o>
00030;em003obP00olX000<0olX000<0Y6d00?o2003o`P00103o`P000`2;G@00okH00?nf00030?nf
000307=8001B;000DR`00080DR`01@3oW@0401P@00060008003EhP00eN800=GR000i000060000P2m
[P000`2mZP00g]X00=kJ00020=kJ0080]8d00P2mS@000`2L>000oooo0?ooo`120?ooo`00<P3oool0
1@2D0000]0P00;@8002d2000R`000080[0P000<0]0P00=D<002D00000P2D00000`2/1000]0P00=D<
00040=D<00H0kQ00403f40090>h@00L0gQ000P3oS@001@3oR@00ohD00?n1003oP@00ogT00080ogD0
0P3fI@003P3fH@00eD`00=E<003EC00000000?nQ003oS@00Na000;@h000P000000000?nZ00000000
BP`00P0000001@2TA000_F400<dT003^T@00mY4000@0oj400P3VR@0209aI0080000000<0oa`00?o>
003ocP000`3ocP000`2mO@00olX00?o:00030?o:00H0ol8000<0Red00?nf003o]P00103o]P05058/
00@0oid000@0>A@001P@000H40006100103EhP02010000040<DL003EfP00eMX00=GJ0080g]X000D0
]9400;B=002dS@00W3P007<`00150?ooo`00<`3oool209@00080]0P000@0R`000:`4002/2000[0P0
0P3=300208/00080[0@01@3=30060>H<00P0mQ00203^40090>H@00H0eA0000@0ohd00?n9003oR@00
ohD00P3oP@030?me00030?ma003fI@00mV4000<0eD`000X000000?nQ003oS@00Na000;@h000P0000
00000?nZ00000000iWd00P0000000`2TA000eGd00<dT00020>jA00@0oj400P3VR@0309aI00030000
003o7000olh000@0olh000<0_Gd00?o:003obP000`3obP000`2TK@00ol800?o200040?o200H0okH0
00<0LdP0058/001B;0000P1B;0050?nM0080610000<0cMh00=GR003EhP000P2d[P000`0@00002000
0=GJ00030=GJ0080]9D000<0]94009`h002L>000A`3oool003D0oooo00@0U0000:`4002d2000R`00
0P2/1000102/2000a@`00<D<003=300208/000030:@4002/1000a@P000<0a@P01P3N300?0>h@00T0
iQ001P3E30030?n900<0oh4000H0ogd00?me003oL@00og400?IU003fH@030=E<000:0000003oX@00
ohd007/@003=D00080000000003oZP00oc`005X@0080000000<0Y4@00=Em000000000`3^T@030?nQ
0080iXT00`2LF@02000000030?lL003ocP00olh00080olh000<0_Gd00?o:003obP000`3obP000`2T
K@00ol800?o200040?o2000308]M003o]P00okH000@0okH01@1B;0040?nM00030340003=gP00cMh0
00@0]:h0103EfP030;BE0080W3P000<0Lc000?ooo`3oool0AP3oool003H0oooo00@0P`000:`4002/
1000P`000P2T1000102/1000a@`00<D<0035300208<0000309`0002T1000_@P000@0_@P01@3N300@
0>H@00P0gQ001P3=30020?n90080oh400P3oO@001P3oM@00og400?ma003fI@00mV400>iM0080eD`0
00l000000?nQ003oS@00Na000<e@000P000000000?nZ00000000FQ0004X<00000000ok800=Em003f
;0000`3^T@000`3oY@00oj400?nQ00020>J900<0W5T000<0FRP00?o6003o70001@3ocP060?o:00L0
ol801P3o]P000`1cB000DR`0058/0002058/00<0oid00`3=fP00102/[P00]:h00;B^002LK@030=GJ
00060<DL002/V@00]9D00;BE002L?000W3P0BP3oool003P0oooo00@0P`000:@4002/1000P`000P2T
1000102m2000a@`00<D<0035300207/0000309`0002d2000]0P000<0]0P01@3E30070>H<0100gP`0
1`3=30000`3oR@00oh400?n100020?mm00<0og400P3fH@00103^G@00eD`00?n^000000020?n=000:
07/@003=D00080000000003oZP00000005X@001:300000000?ld0080eGd00`3^T@020?nU00030?JZ
003VR@00iXT000<0W5T000@0FRP00?o6003o7000oa`0103ocP000`2mO@00olX00?o:00030?o:0003
0:A]003o`P00ol8000@0ol8000<0Red00?nf003o]P00103o]P05058/00<0aMX00`2/[P0209aa0080
cMX00`3EgP00102/V@00W40009`l001k=01;0?ooo`00>@3oool01P1k0000W0000:@4001c0000W000
0:@40080]0P000H0_@P00=h<001k0000N`0009@0002L00040;@400D0c@P03`3N30080=D<00H0a@`0
0P3oP@030?mm000@0?me003oL@00og400?m]003fH@00kUd00=E<003o[P0000000?nM003oS@00Na00
0<e@000P000000000?nZ0080FQ0000<0BP`00000003o=0000P3EO@030>jA0080ojD00P3fZP00203V
R@00W5T009aI002LF@00FRP00?o600082000oa`0103ocP000`2mO@00olX00?o:00030?o:00030:A]
003o`P00ol8000D0ol801P3o]P000`1cB000DR`0058/00030;gF00<0[:h00P2LM@020<gJ00D0eMh0
00<0W4P007/d003oool0C03oool003X0oooo00H0N`0009`0002L0000]0P007<0002D00020:`40080
]0P000@0e@`007<0001c0000U000102/10050<D800h0e@`0203=30070;d<00060?n1003oN@00ogd0
0?mm003oM@00og400P3oK@00303fH@00kUd00=E<003o[P00FP`00?nM003oS@00Na000<e@000P0000
00000?nZ0080FQ0000D0BP`00000003o=000eGd0000000020?JU00030>jA003oY@00ojD00080mZX0
00P0gZ4009aI002LF@00W5T005XX003oaP0020P00?lL00D0olh01P3obP070?o200L0okH00`2dcP02
0:B^0080[:h000<0W7T00<GF0035eP000`3=fP020=GN0080[9d000<0Nc@00?ooo`3oool0C03oool0
03/0oooo00<0L`0009`0002L00000P2d20000`2;0000U0000:`400020:`40080c@P000<0JP0008/0
002;00000`2T10050;d800L0c@`01`3E30080<d<00H0]0P00`3oN@000`3oO@00ogD00?ma00020?m]
0080kUd00P3o[P0020000000oid00?n=003ofP00cE00020000000000ojX00`1J400010000000oc@0
0>jQ003=90030?JU0080ojD00P3fZP020=jQ00030<FE002LF@00FRP00080olH000<020P00;d8003o
cP000`3ocP060?o:00030:A]003o`P00ol8000@0ol8000<0Red00?nf003o]P000`2T`P020;C:00@0
Y:h000@0W7d00<GF0035eP00aMH0103=fP040:bM04l0oooo000m0?ooo`0607<0002L0000[0@00:`4
001R0000R`000P2T10000`2/1000a@P00<D8000206X00080R`000P2L00060;@400d0c@P0202m2006
0:`80080ogT00P3oM@030?m]000<0?mU003^G@00kUT00?n^00000000oid00?n=003ofP00cE000200
00000000ojX00`1J400010000000oc@00?nb003EO@030?JU00040?nj003oY@00mZX00?JZ0080gZ40
0P35U@00101J:000olH00?o6000820020;d800<0olh000<0_Gd00?o:003obP00103obP070?o200<0
W;X00P2T`P0209bZ0080Y:h000H0U8400;gB002mdP00_M800<GF0035fP020<gJ00@0[9d000<0W4`0
0?ooo`3oool0CP3oool003l0oooo00D0R`000:@4002T1000Y0@008<0000209`000050:@4002m2000
_@P00;d8001R00000`23000309@000@0[0@01P2m20070<D800L0_@P01P2T1000103oN@00ofd00?m]
003oM@020?m]0080ofD000`0kUd00>iI003o[P0000000?nM003oS@00kWD00<e@000P000000000?nZ
002D?00205X@0080000000<0ok800000003fY@000P3fY@020?nj0080mZX00P3NX@020<FE00040:bE
003oaP00olH000P800<0_@P00`3ocP060?o:00D0ol800`2D[P0209bj0080W:D00P2LZP000`2DQ@00
_M800;gB00030;gB0080aMX00P2/X@020:bM0080U500D@3oool00400oooo00<0HP0008/0002T1000
0P0030000`230000W00009`000040;@400030680001k0000N`0000<0U000102T10070;@400d0]0P0
1@2L10050?m]00<0ofD000H0kUd00>iI003o[P0000000?nM003oS@020<e@0004020000000000ojh0
00000080FQ000P0000000`3o/P0040000?JU00020?JU0080okX00P3f`P020=jQ0080aID00`3oaP02
00P8000304Y@002m2000olh00080olh01P3obP000`2TK@00ol800?o2000508^M0080U:400P2DS@00
102DR@00]<h00;C>002dcP020;gB0080aMH00P2TX@020:bQ0080U5D000<0U5000?ooo`3oool0D03o
ool00480oooo00D0HP0009`0002L0000W000000<000209@0000509`0002T1000Y0@00:@4001J0000
0P1k000408/000@0W0001@2/10070;@400L0Y0@01@2D00020?m]00030?mU003oK@00ofD00080ofD0
0P3^F@00303o[P00000005X<003oS@00W2P00<e@000P000000000?n^00000000ojh005X@00800000
00@0ok800100003o`P00ol800`3o^P020?K20080k/X00P35U@001`3okP00olH00?o6003oaP0020P0
0;d@001:D0000P1B00000`3ocP00_Gd00?o:00030?o:00<0Lfd00P23S@0208^E0080Rid000<0Ri40
09B=002DS@000`2/bP020;C>0080_MH0102TX@0209AI000309AE001k=000oooo0580oooo00140?oo
o`0507/0002D0000U00009@0001c00000`2;00040:@40080DP000`2;000509@000@0Y0@01`2/1007
09`400D0P`000P3oI@001`3oK@00ofD00?mU003oI@00oed00>iI003^D0000P0000003@3oS@00kVd0
0<e@000P000000000?n^000Y1000U3`005X@000@100000000?nb000@00000P3o`P000`3ofP00okX0
0?nj00020?K20080k/X00P3NcP001`3okP00olH00?o6003oaP0020P00;d@001:D0000P1JO@02034/
0080DUD00`1RK@0207>10080Phd000<0PiD008^E002;U@000P23N@030:c60080[<X00P2mdP020:BU
0080Y:400P2DG@000`2DF@00Nc@00?ooo`1D0?ooo`00A@3oool01P003000L`0007<0002D00000100
06X00080R`00102L00020:`40080JP000`23000809@000H0W0001`2;000507/000@0ofD00P3oG@00
4@3^F@00kU00000000000000ohd00>i]003=D00080000000003o[P00000009@l001J400040@00000
003o/P0040000080ol800P3ofP030?K20080k/X000@0g/h00?o^003okP00onh00P3oaP0200P80003
0;d@001JO@00FWd00080HYT00P1cX@0207^Q0080Nid00P23V@0208>A0080PhD00`2T_P0209bQ0080
]=80102TY@0209AQ000309AM001k=000Nc@005H0oooo00170?ooo`06000@001Z0000P`0008<00000
4000HP000P23000209@0000509`0002T1000Y0@00:@4001R00000`1k000408/000X0U0001P230006
07<000030?mI003oI@00ofD00080oed00P3^D002000000060?n=003^K@00cE00020000000000ojh0
0P2D?0001`3o[P0040@00000003o/P0040000?me003o`P000P3ofP020?oV0080k/X000<0g/h00?oo
003oo`000P3okP020?o6008020P000<0_A0009C:002DbP000P2;cP0208_:0080Pkh00P23[P001023
X@00Pi4008>A0023Q@0209bj00<0U9d00P2dcP0209bU0080Y:D00P2DI@000`2DH@00Nc@007/d001H
0?ooo`00B@3oool01`004000HP0007/000230000010005X0001c0000102;000309`000030440001J
0000FP000080L`003@23000607/000D0HP0000l0oeT00?mM003oG@00oed00?mE003^D000oid00000
003oS@00kVd00<e@000P000000000?oB000Y10000P2D?000101c>00040@00?nb003o/P020?oV0080
omX00P3oiP020?ob00<0ool00P3okP020?o6008020P00P2m400208_>0080RlX00P23_P0208>^0003
08>A002;Y@00RjD00080U;800`2/aP020:c:00@0W:D000<0U6T009AU002DI@000P1k=01J0?ooo`00
C03oool010005000N`0009@0002D0002000D000306X000230000P`0000<0U00000<0W0000:@4001B
0000101Z000207/000<0P`001P1k000607<000040680001J0000FP0005X00080odP00140oed00?mE
003oE@00oeD00?nM00000000ohd00?mm003=D00080000000003odP00:@@00<em002D?000gQ`00104
00020?nb0080onH00P3onP000`3oo`00oo800?ob00060?oo0080ooX00P2D/P020;d@00040:CR002D
dP00U=8008^n0080PjX00`23U@0208^I00<0Y<H00P2/aP0209bQ0080W:D000@0Rfd007/d001k=000
FS00G@3oool004h0oooo00H001@007<0001c0000R`00000D001Z000207/0000308<0002;0000R`00
0080R`0000<0W000000D000050000P1R000407<000<0N`001@1c000506X000040580001:0000BP00
04X00080odP001<0oe000?mE003oE@00oid000P0003oS@00ogd00<e@000P000000000?oB000Y1000
cGd009@l003N7000LcP00008003o/P00onH000<0ooX02@3oo`020?oj0080U;800P1BL@03020X0080
HU000P1kT@0208>E00<0W;h00P2TaP0209BQ0080RgD000@0Rg4007/d001k=000HS00G`3oool004l0
oooo0P0050001@1Z0000N`0007/000006000FP0000<0L`000`23000408/00003000H00110000FP00
00<0HP000`1c000506X000D0FP0000<0@@0003T0000i00000P3o?000103oD000od`00?m<00000002
0?mm00050<e@000P000000000?oV001c70000P3=O@00103N7000LcP00598000030020?oo0080i_l0
2@3oo`020?oj0080U;800`1BL@0205Z10080JXd00P23W@0309Bj00@0U:400`2;M@00101k>000Nc@0
07/d001R<01P0?ooo`00DP3oool00`00400001P0000H000207/0008001P000<0JP0007/0001k0000
0`1k000408/0008001P000@0DP0005X0001J0000FP000`1R000505X000D0BP0000l0:@000?ll003o
A000od@00?m<00000000ohT00?mm003=D00080000000003odP00La`00?Jb003o`P000P3N7000102L
W@00DTP00?oo003oo`030=Go0080m_l00P3oo`020>ko0080ool000@000000<go002/jP00[>X00P2;
dP0208>n000408>Z002;ZP00RjX008^Z0080U;800P2;W@0208=m000508]i001kB000NdP007]0001R
=000I03oool005@0oooo00<001@0000H000060000P1c0000101k000001P0000H001J000407<000<0
N`000`230002000H00<0DP000P1J0005058000@0@@0000h0P`000?ld003oA000od@00?n9000Y0000
ogd00<e@0011200000000=DH001c7000m[800?o20080gQ`00P2LW@00103oo`00m_l00=Go003Eo`03
0>Ko0080k_l01@3oo`0010000000[>X00:cZ002DbP0207^90080Pid00`23V@0208^M000408>10023
O@00Pgd007]<0080NdP000<0HS@00?ooo`3oool0I03oool005P0oooo00<001P0000L000070000P1k
0002000L00040580001R0000HP00068000<0L`001@1k0002000H00030440001B0000DP000080DP00
101:00004@0i0000@@000448003o=000od000?n9000a0000ogd00<e@00112000omH00000001c7000
m[800?o200002000gQ`00080aLh000@0m_l00=ko003=o`00cOl00`3Eo`020>Ko00D0ool00P000002
07>I0080NiD00P23V@0208>50080Ph4000<0Ned007]E001kE@000P1R=0000`1:<000oooo0?ooo`1V
0?ooo`00F`3oool00`0060000200000P000206X000@0020000@0FP000680001R0000HP001P1c0002
000H00040440001:0000BP0004X000D0DP0001<0FP`00?l/003o@000Na`00?n9003=D000@@P00?oF
00000000La`00?oN003o`P00FW400008003Eo`00]>X009c:003o^P00cOl00080aOl00P35nP020<Go
00<0cOl00P2dlP0207^f0080Nj400P1kU@0207^=000307]]001kI@00NfD00080JS@000<0DS0004X`
001:<000JP3oool005h0oooo00H001P0000L00088000220005X000006002000P008022@00`1B0003
068000D0JP0000<0HP000440001:00000P1J00020680000=05X<001k7000ohT009`X003V@000@@P0
0?mU000Y4000ool00?o2003ofP00JP0009Bn000305Yi0080PkH00P2LfP020:c^0080Y=X00P2LeP02
08_:00<0PkH000<0Nhd007^1001kP@000P1kM@0206Xl00<0DS00KP3oool00640oooo00<001`0000P
000080000P0@900201PT008001`000@0220000PT000H900062@00P1:000905800080L`0000X0Na`0
0?l`003o<000iT0003T0003okP00ool00000003o`P00onX00P0a@00208_:00040?nj0023aP00PlH0
08_:0080RlH00`2;_P0208>f0080PjX000<0Lgd007=a001cL@000P1cH@0305X`0080>B`0L@3oool0
06D0oooo00<001`0000P000080000P0@9002020T0080:BP000<00200000T000090000`0@900201PT
00030340000H0000@@P00080FP`000X0Na`008/0002D=000a@`003T0003oV@00ool0069M003ojP00
]>800P23`P0306ZM000307=]0023_P00Pkh00080Pk800P23Y@0207=a0080JV400P1ZD00206900080
BS00MP3oool006X0oooo00<0020000PT000890000P0@9002020X00<0:BP00P0a:0020?l/000<0?l@
001RE@00HT`008=Q002T1000U3@006X0000i0000ool00=kZ003=Q@00]?800P2;cP0207^^00@0Lhd0
0P1cN@0206YU0005069E001R@000HT0004X`0011;0000P0i;01j0?ooo`00L@3oool01@0,

Cell[CellGroupData[{

0008062P000/082P0069E001RE@00:BP0034/0011;0000200069I,

Cell[BoxData[
    \(Off[General::spell]; 
    Off[General::spell1] $HistoryLength = 0; \)], "Input",
  FontSize->10],

Cell[BoxData[
    \(ArcTrigFunctionQ[f_] := 
      MatchQ[f, 
        ArcSin | \ ArcCos | \ ArcTan | \ ArcCot | \ ArcSec | \ 
          ArcCsc | \n\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ ArcSinh | \ 
          ArcCosh | \ ArcTanh | \ ArcCoth | \ ArcSech | \ ArcCsch]\)], "Input",\

  FontSize->10],

Cell[BoxData[
    \(canonicalizeFunction[w_] := \n
      w //. f_?ArcTrigFunctionQ[
            x_] \[RuleDelayed] \((Function @@ {TrigToExp[f[#]]})\)[
            x]\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(multiValuedTerms[w_, z_] := \n
      Union[Cases[
          canonicalizeFunction[
            w], \n\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \t\
Log[_?\((MemberQ[#, 
                      z, {0, \[Infinity]}] &)\)]\  | \ \n\t\t\ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \t\tPower[_?\((MemberQ[#, 
                      z, {0, \[Infinity]}] &)\), \n\t\t\t\t\t\ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ _Rational | _?\((MemberQ[#, 
                        z, {0, \[Infinity]}] &)\)] | \ \ \ \ \ \ \ \ \ \ \ \n\
\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ Root[_?\((MemberQ[#, 
                      z, {0, \[Infinity]}] &)\), __], {0, \[Infinity]}]]\)], \
"Input",
  FontSize->10],

Cell[BoxData[
    RowBox[{\(branchPoints[w_, z_]\), ":=", "\n", 
      RowBox[{\(If[
            TrueQ[And @@ \((NumericQ /@ 
                    DeleteCases[#, z | _DirectedInfinity])\)], 
            DeleteCases[#, z | _DirectedInfinity], $Failed] &\), "[", 
        RowBox[{"Check", "[", 
          
          RowBox[{\(Union[
              Flatten[\(branchPointsF[#, z] &\) /@ multiValuedTerms[w, z]]]\),
             ",", " ", "\n", "\t\t        ", "$Failed", ",", "\n", "\t\t\t", 
            
            StyleBox[\( (*\ 
                catch\ the\ following\ messages\ from\ Solve\ *) \),
              FontWeight->"Plain"], "\n", "\t\t\t", \(Solve::tdep\), 
            ",", \(Solve::ifun\)}], "]"}], "]"}]}]], "Input",
  FontSize->10],

Cell[BoxData[
    \(branchPointsF[Log[f_], z_] := 
      z /. Solve[f \[Equal] 0 || 1/f \[Equal] 0, z]\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(branchPointsF[Power[f_, _], z_] := 
      z /. Solve[f \[Equal] 0 || 1/f \[Equal] 0, z]\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(branchPointsF[Root[f_, _], z_] := \n
      Module[{w, p}, 
        p = f[w]; \((z /. 
            Solve[Factor[Resultant[p, \[PartialD]\_w p, w]] \[Equal] 0, 
              z])\)]\)], "Input",
  FontSize->10],

Cell[BoxData[
    RowBox[{\(sectors[branchpoints_]\), ":=", "\n", "\t", 
      RowBox[{"Module", "[", 
        RowBox[{\({\[CurlyEpsilon] = 10\^\(-5\), rMax, 
            rList, \[CurlyPhi]List\ }\), ",", "\n", "\t\t", 
          
          RowBox[{\(rMax = \(If[# \[Equal] 0. , 1, 14/10\ #] &\)[
                Max[Abs[rList = Abs /@ N[branchpoints, 25]]]]\), ";", "\t\t", 
            "\n", "\t\t", 
            StyleBox[\( (*\ the\ different\ distances\ *) \),
              FontWeight->"Plain"], "\n", 
            "\t\t", \(rList = 
              Union[Prepend[
                  Append[rList, 
                    rMax], \[CurlyEpsilon]], \n\t\t\t\t\t\ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ SameTest \[Rule] \((Abs[#1 - #2] < 
                        2  \[CurlyEpsilon] &)\)]\), ";", "\n", "\t\t", 
            StyleBox[\( (*\ the\ different\ angles\ *) \),
              FontWeight->"Plain"], "\n", 
            "\t  ", \(\[CurlyPhi]List = 
              Union[\(If[# \[Equal] 0. , 0``25, Arg[#]] &\) /@ 
                  branchpoints, \n\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ SameTest \[Rule] \((Abs[#1 - #2] < \[CurlyEpsilon] &)\)]\), ";", 
            "\n", "\t\t", \(\[CurlyPhi]List = 
              Append[\[CurlyPhi]List, First[\[CurlyPhi]List] + 2\ \[Pi]]\), 
            ";", "\n", "\t\t", 
            StyleBox[\( (*\ the\ different\ sectors\ *) \),
              FontWeight->"Plain"], "\n", 
            "\t\t", \(\(N[#, 25] &\)@
              Flatten[Table[{rList\[LeftDoubleBracket]
                        i\[RightDoubleBracket] + \[CurlyEpsilon], \
\[CurlyPhi]List\[LeftDoubleBracket]j\[RightDoubleBracket] + \[CurlyEpsilon], 
                    rList\[LeftDoubleBracket]i + 
                          1\[RightDoubleBracket] - \[CurlyEpsilon], \
\[CurlyPhi]List\[LeftDoubleBracket]j + 
                          1\[RightDoubleBracket] - \[CurlyEpsilon]}, \n\t\t\t\
\t{i, Length[rList] - 1}, {j, Length[\[CurlyPhi]List] - 1}], 1]\)}]}], 
        "]"}]}]], "Input",
  FontSize->10],

Cell[BoxData[
    RowBox[{\(numberMultiValuedTerms[w_, z_]\), ":=", "\n", 
      RowBox[{"Module", "[", 
        RowBox[{\({root, function, \[Omega]}\), ",", "\n", 
          RowBox[{"Block", "[", 
            RowBox[{\({i = 1}\), ",", "\n", 
              RowBox[{
                RowBox[{"MapAll", "[", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"Which", "[", 
                        
                        RowBox[{\(MatchQ[#, 
                            Log[_?\((MemberQ[#, z, {0, \[Infinity]}] &)\)]]\),
                           ",", "\n", "\t\t\t\t                     ", 
                          StyleBox[\( (*\ the\ Log\ terms\ *) \),
                            FontWeight->"Plain"], 
                          "    ", \(Log\_\(i++\) @@ #\), ",", "\n", 
                          "                           \t", \(MatchQ[#, 
                            Power[_?\((MemberQ[#, 
                                      z, {0, \[Infinity]}] &)\), \
_Rational]]\), ",", " ", "\n", "\t\t\t\t                      ", 
                          StyleBox[\( (*\ the\ rational\ power\ terms\ *) \),
                            FontWeight->"Plain"], 
                          "    ", \(Power\_\(i++\) @@ #\), ",", "\n", 
                          "\t\t\t\t\t                 ", \(MatchQ[#, 
                            Power[_?\((MemberQ[#, 
                                      z, {0, \[Infinity]}] &)\), \n\t\t\t\t\t\
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ _?\((MemberQ[#, z, {0, \[Infinity]}] &)\)]]\), ",", 
                          " ", "\n", "\t\t\t\t                          ", 
                          StyleBox[\( (*\ the\ f[z]^g[z]\ terms\ *) \),
                            FontWeight->"Plain"], 
                          StyleBox[" ",
                            FontWeight->"Plain"], \(Exp[
                            Log\_\(i++\)[#\[LeftDoubleBracket]1\
\[RightDoubleBracket]]\ #\[LeftDoubleBracket]2\[RightDoubleBracket]]\), ",", 
                          "\n", "\t\t\t\t                    ", \(MatchQ[#, 
                            root[_?\((MemberQ[#, 
                                      z, {0, \[Infinity]}] &)\), _]]\), ",", 
                          " ", "\n", "\t\t\t\t                         ", 
                          StyleBox[\( (*\ the\ Root\ terms\ *) \),
                            FontWeight->"Plain"], 
                          StyleBox[
                            RowBox[{
                              StyleBox[" ",
                                FontWeight->"Plain"], 
                              " "}]], \(root\_\(i++\) @@ #\), ",", "\n", 
                          "                           \t", "True", ",", "#"}],
                         "]"}], "&"}], ",", "\n", "\t\t\t\t", 
                    
                    StyleBox[\( (*\ 
                        some\ preprocessing\ for\ Root\ objects\ *) \),
                      FontWeight->"Plain"], "\n", 
                    "\t\t\t\t", \(\(w //. 
                        Root[f_, __] \[RuleDelayed] 
                          root[f, 
                            Exponent[
                              f[\[Omega]], \[Omega]]]\) //. \ \ \ Function \
\[Rule] function\)}], "]"}], 
                "//.", \({function \[Rule] Function, root \[Rule] Root}\)}]}],
             "\n", "\t", "]"}]}], "]"}]}]], "Input",
  FontSize->10],

Cell[BoxData[
    \(powerAndLogTerms[w_, z_] := \n\t
      Module[{powerTerms, logTerms, 
          sortedPowerAndLogTerms}, \n\t\tpowerTerms = 
          Cases[w, Power\__[__], {0, \[Infinity]}]; \n\t\ logTerms = 
          Cases[w, Log\__[_], {0, \[Infinity]}]; \n\ \trootTerms = 
          Cases[w, Root\__[__], {0, \[Infinity]}]; \n\t\ \ Sort[
          Join[powerTerms, \ logTerms, \ 
            rootTerms], #1\[LeftDoubleBracket]0, 
                2\[RightDoubleBracket] < #2\[LeftDoubleBracket]0, 
                2\[RightDoubleBracket] &]]\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(substitutions[powerAndLogTerms_, wFunc_, w_, z_] := \n\t
      Module[{ws = \(\((# \[Rule] 
                    w\_\(#\[LeftDoubleBracket]0, 2\[RightDoubleBracket]\)[
                      z])\) &\) /@ powerAndLogTerms}, \n\t\t{Last /@ 
            FoldList[Append[#1, #2 //. #1] &, {First[ws]}, Rest[ws]], ws, \ 
          wFunc //. ws}]\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(toODE[\[Omega] : \((Log\__[\[Xi]_] \[Rule] w_)\), 
        z_] := {\[Omega], \[PartialD]\_z w \[Equal] 
          Together[\[PartialD]\_z \[Xi]\/\[Xi]]}\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(toODE[\[Omega] : \((Power\__[\[Xi]_, Rational[p_, q_]] \[Rule] w_)\), 
        z_] := {\[Omega], \[PartialD]\_z w \[Equal] 
          Together[\(p\/q\) \(\[Xi]\^\(p - 1\)\/\(\(\ \)\(w\^\(q - 
                        1\)\)\)\) \[PartialD]\_z \[Xi]]}\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(toODE[\[Omega] : \((Root\__[\[Xi]_, d_] \[Rule] w_)\), 
        z_] := \n\t{\[Omega], \[PartialD]\_z w \[Equal] 
          Together[\(-\(\((\[PartialD]\_z \[Xi])\)[
                    w]\/\[PartialD]\_w \[Xi][w]\)\)]}\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(derivativeFreeRhs[odes_] := 
      Apply[Equal, 
        Last /@ Transpose[{First /@ 
                odes, \(Last /@ 
                    FoldList[Append[#1, #2 //. #1] &, {First[#]}, 
                      Rest[#]] &\)[
                Apply[Rule, Last /@ odes, {1}]]}], {1}]\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(sheets[\[Omega] : Power\_i_[\[Xi]_, r : Rational[p_, q_]], ___] := 
      Table[\[Omega] \[Rule] \[ExponentialE]\^\(\(2  \[Pi]\ \[ImaginaryI]\ \
j\)\/q\)\ \[Xi]\^r, {j, 0, q - 1}]; \)], "Input",
  FontSize->10],

Cell[BoxData[
    \(sheets[\[Omega] : Log\_i_[\[Xi]_], k1_: - 1, k2_:  1] := 
      Table[\[Omega] \[Rule] Log[\[Xi]] + 2\ k\ \[ImaginaryI]\ \[Pi], {k, k1, 
          k2}]\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(sheets[\[Omega] : Root\__[\[Xi]_, d_], ___] := 
      Table[\[Omega] \[Rule] Root[\[Xi], j], {j, 1, d}]\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(allSheets[sheetRealizations_] := 
      Flatten[\(Outer[List, ##] &\) @@ sheetRealizations, 
        Length[sheetRealizations] - 1]; \)], "Input",
  FontSize->10],

Cell[BoxData[
    RowBox[{
      RowBox[{"odeAzimuthal", "[", 
        RowBox[{
          RowBox[{
            RowBox[{
              SubsuperscriptBox["w_", "i_", "\[Prime]",
                MultilineFunction->None], "[", "z_", "]"}], "==", "rhs_"}], 
          ",", \({w_\_i_, z_}\), ",", \({\[Psi]_, \[CurlyPhi]_}\), ",", 
          "r_"}], "]"}], ":=", "\n", 
      "               ", \(\(\(\[Psi]\_i'\)[\[CurlyPhi]]\  \[Equal] 
            rhs\ \[PartialD]\_\[CurlyPhi]\((r\ \[ExponentialE]\^\(\
\[ImaginaryI]\ \[CurlyPhi]\))\)\  /. 
          w\_j_[z] \[Rule] \[Psi]\_j[\[CurlyPhi]]\) /. 
        z \[Rule] 
          r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]\)\)}]], "Input",
  FontSize->10],

Cell[BoxData[
    RowBox[{
      RowBox[{"odeRadial", "[", 
        RowBox[{
          RowBox[{
            RowBox[{
              SubsuperscriptBox["w_", "i_", "\[Prime]",
                MultilineFunction->None], "[", "z_", "]"}], "==", "rhs_"}], 
          ",", \({w_\_i_, z_}\), ",", \({\[Psi]_, \[Rho]_}\), ",", 
          "\[ScriptD]_"}], "]"}], ":=", "\n", 
      "            \t ", \(\(\(\[Psi]\_i'\)[\[Rho]] \[Equal] 
            rhs\ \[PartialD]\_\[Rho]\((\[Rho]\ \[ScriptD])\)\  /. 
          w\_j_[z] \[Rule] \[Psi]\_j[\[Rho]]\) /. 
        z \[Rule] \[ScriptD]\ \[Rho]\)}]], "Input",
  FontSize->10],

Cell[BoxData[
    \(SetOptions[NDSolve, \ PrecisionGoal \[Rule] 12, 
      AccuracyGoal \[Rule] 12, MaxSteps \[Rule] 5000]; \)], "Input",
  FontSize->10],

Cell[BoxData[
    RowBox[{\(sectorSheetPatch[reIm_, {w_, z_}, w\[Psi]_, 
        wSheet_, {odes\[CurlyPhi]_, {\[Psi]_, \[CurlyPhi]_}, 
          r_}, \ \ \ \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
{odesr_, {\[Psi]_, \[Rho]_}, dir_}, 
        sector : {r1_, \[CurlyPhi]1_, r2_, \[CurlyPhi]2_}, {pp\[CurlyPhi]_, \ 
          ppr_}]\), ":=", "\n", "\t", 
      RowBox[{"Module", "[", 
        RowBox[{\({radialStartingValues, radialIFs, azimuthalIFs, points, 
            ra, \[CurlyPhi]a, rb, \[CurlyPhi]b}\), ",", "\n", "\t\t", 
          
          StyleBox[\( (*\ 
              get\ initial\ values\ for\ the\ differential\ equation\ *) \),
            FontWeight->"Plain"], "\n", "\t\t", 
          
          RowBox[{\(radialStartingValues = 
              N[\((\((Last /@ wSheet)\) //. wSheet)\) /. 
                  z \[Rule] r1\ Exp[I\ \[CurlyPhi]1], 25]\), ";", "\n", 
            "\t\t", 
            StyleBox[\( (*\ the\ functions\ of\ the\ odes\ *) \),
              FontWeight->"Plain"], " ", "\n", 
            "\t\t", \(\[Psi]s = \(#\[LeftDoubleBracket]1, 0, 
                    1\[RightDoubleBracket] &\)\  /@ \ odesr\), ";", "\n", 
            "\t\t", 
            
            StyleBox[\( (*\ 
                solve\ the\ differential\ equation\ radially\ *) \),
              FontWeight->"Plain"], "\n", 
            "\t\t", \(radialInits = 
              Apply[Equal, 
                Transpose[{\(#[r1] &\) /@ \[Psi]s, 
                    radialStartingValues}], {1}]\), ";", "\n", 
            "\t\t", \(radialIFs = 
              NDSolve[Join[odesr, radialInits] /. \[ScriptD] \[Rule] 
                    Exp[I\ \[CurlyPhi]1], \[Psi]s\ , {\[Rho], r1, r2}]\), ";",
             "\n", "\t\t\t", 
            
            StyleBox[\( (*\ 
                solve\ the\ differential\ equation\ azimuthally\ *) \),
              FontWeight->"Plain"], "\n", 
            "\t", \(azimuthalIFs = 
              Table[ra = r1 + i/ppr \((r2 - r1)\); \n\ \ \ NDSolve[
                  Join[odes\[CurlyPhi] /. r \[Rule] ra, 
                    Apply[Equal, 
                      Transpose[{\(#[\[CurlyPhi]1] &\) /@ \[Psi]s, \(#[
                                  ra] &\) /@ \[Psi]s /. 
                            radialIFs\[LeftDoubleBracket]1\
\[RightDoubleBracket]}], {1}]], \[Psi]s, {\[CurlyPhi], \[CurlyPhi]1, \
\[CurlyPhi]2}], \n\t\t\t\t{i, 0, ppr}]\), ";", "\n", "\t", 
            StyleBox[\( (*\ generate\ the\ function\ itself\ *) \),
              FontWeight->"Plain"], 
            StyleBox["     ",
              FontWeight->"Plain"], "\n", 
            "\t\t", \(\[CapitalPsi] = \((\(w\[Psi] /. 
                      w\_i_[\[Xi]_] \[Rule] \[Psi]\_i[\[CurlyPhi]b]\) /. 
                    azimuthalIFs)\) /. 
                z \[Rule] 
                  rb\ \[ExponentialE]\^\(\[ImaginaryI]\ \[CurlyPhi]b\)\), ";",
             "\n", "\t", 
            StyleBox[\( (*\ calculate\ points\ for\ the\ patch\ *) \),
              FontWeight->"Plain"], "\t", "\n", 
            "\t\t", \(points = 
              Table[rb = 
                  r1 + i/ppr \((r2 - r1)\); \[CurlyPhi]b = \[CurlyPhi]1 + 
                    k/pp\[CurlyPhi] \((\[CurlyPhi]2 - \[CurlyPhi]1)\); \n\t\t\
\t\t{rb\ Cos[\[CurlyPhi]b], rb\ Sin[\[CurlyPhi]b], 
                  reIm[\[CapitalPsi]\[LeftDoubleBracket]i + 1, 
                      1\[RightDoubleBracket]]}, {i, 0, ppr}, {k, 0, 
                  pp\[CurlyPhi]}]\), ";", "\n", "\t", 
            StyleBox[\( (*\ make\ polygons\ for\ all\ sheets\ *) \),
              FontWeight->"Plain"], "\n", 
            "\t", \(Apply[Polygon[Join[#1, Reverse[#2]]] &, 
              Transpose\  /@ \ 
                Partition[\(Partition[#, 2, 1] &\) /@ points, 2, 
                  1], \n\t{2}]\)}]}], "]"}]}]], "Input",
  FontSize->10],

Cell[BoxData[
    \(complexUnion[l_, 
        SameTest \[Rule] 
          func_] := \n\(Fold[
            Function[{u, v}, 
              If[Select[u, func[#, v] &, 
                    1] === {}, \n\ \ \ \ \ \ \ \ \ \ \ Append[u, v], 
                u]], {First[#]}, Rest[#]] &\)[Union[l]]\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(differentSheetRealizations[allSheets_, wnum_, z_, z1_] := 
      complexUnion[\({#, N[\((wnum //. #)\) /. z \[Rule] z1, 25]} &\) /@ 
          allSheets, \n\t\tSameTest \[Rule] 
          Function[{x, y}, 
            If[x\[LeftDoubleBracket]2\[RightDoubleBracket] \[Equal] 0, 
              x\[LeftDoubleBracket]2\[RightDoubleBracket] \[Equal] 
                y\[LeftDoubleBracket]2\[RightDoubleBracket], 
              Abs[\((x\[LeftDoubleBracket]2\[RightDoubleBracket] - 
                        y\[LeftDoubleBracket]2\[RightDoubleBracket])\)/
                    x\[LeftDoubleBracket]2\[RightDoubleBracket]] < 
                10\^\(-20\)]]]; \)], "Input",
  FontSize->10],

Cell[BoxData[
    RowBox[{\(dropMultipleSheets[sheets_]\), ":=", "\n", "\t", 
      RowBox[{"Module", "[", 
        RowBox[{\({sheetData, goodOnes, 
            actSheet, \[CurlyEpsilon] = 10\^\(-3\)}\), ",", "\n", "\t\t", 
          
          StyleBox[\( (*\ 
              take\ out\ the\ function\ values\ and\ number\ the\ sheets\ *) \
\),
            FontWeight->"Plain"], "\n", "\t ", 
          
          RowBox[{\(sheetData = 
              MapIndexed[{#2\[LeftDoubleBracket]1\[RightDoubleBracket], #1, 
                    Plus @@ Abs[
                        Flatten[#1]]} &, \n\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ Last /@ \((\(Level[#, {\(-2\)}] &\) /@ sheets)\)]\), ";", "\n", 
            "\t\t", \(goodOnes = {}\), ";", "\n", "\t\t", 
            
            StyleBox[\( (*\ 
                put\ all\ different\ one\ in\ the\ list\ goodOnes\ *) \),
              FontWeight->"Plain"], "\n", 
            "\t\t", \(While[
              sheetData =!= {}, \n\t\t\t\ \ \ \ \ \ \ \ \ \ \ actSheet = 
                sheetData\[LeftDoubleBracket]1\[RightDoubleBracket]; \n\t\t\t\
\ \ \ \ \ \ \ \ \ \ \ AppendTo[goodOnes, 
                First[actSheet]]; \n\t\t\t\ \ \ \ \ \ \ \ \ \ \ sameSheets = 
                Select[sheetData, 
                  Function[s, 
                    Plus @@ Abs[actSheet\[LeftDoubleBracket]2\
\[RightDoubleBracket] - \
s\[LeftDoubleBracket]2\[RightDoubleBracket]]\/\(actSheet\[LeftDoubleBracket]3\
\[RightDoubleBracket] + s\[LeftDoubleBracket]3\[RightDoubleBracket]\) < \
\[CurlyEpsilon]]]; \n\t\t\t\ \ \ \ \ \ \ \ \ sheetData = 
                DeleteCases[sheetData, Alternatives @@ sameSheets]]\), ";", 
            "\n", 
            StyleBox[
              RowBox[{"\t", 
                StyleBox[" ",
                  FontWeight->"Plain"]}]], 
            StyleBox[\( (*\ return\ the\ different\ sheets\ *) \),
              FontWeight->"Plain"], "\t", "\n", 
            "\t\t", \(sheets\[LeftDoubleBracket]
              goodOnes\[RightDoubleBracket]\)}]}], "]"}]}]], "Input",
  FontSize->10],

Cell[BoxData[
    \(sectorSheetPatches[reIm_, {w_, z_}, w\[Psi]_, wnum_, 
        sheetRealizations_, {odes\[CurlyPhi]_, {\[Psi]_, \[CurlyPhi]_}, 
          r_}, {odesr_, {\[Psi]_, \[Rho]_}, 
          dir_}, \n\ \ \ \ \ sector : {r1_, \[CurlyPhi]1_, 
            r2_, \[CurlyPhi]2_}, {pp\[CurlyPhi]_, \ ppr_}] := \n
      Module[{sheetValues, \ sheetPolys}, \n\ \ \ \ \ sheetValues = 
          First /@ differentSheetRealizations[sheetRealizations, wnum, z, 
              r1\ E\^\(I\ \[CurlyPhi]1\)]; \n\ \ \ \ \ sheetPolys = \
\(sectorSheetPatch[
                reIm, \ \ \ \ \n\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ {w, z}, w\[Psi], #, {odes\[CurlyPhi], {\[Psi], \[CurlyPhi]}, 
                  r}, {odesr, {\[Psi], \[Rho]}, 
                  dir}, \n\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ sector, {pp\[CurlyPhi], \ ppr}] &\) /@ \ 
            sheetValues; \n\ \ \ \ \ \ dropMultipleSheets[
          sheetPolys]\t]\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(patchPlotPoints[{r1_, \[CurlyPhi]1_, r2_, \[CurlyPhi]2_}, 
        rMax_, {pp\[CurlyPhi]_, \ ppr_}] := \n\(Max[#, 1] &\) /@ 
        Round[{pp\[CurlyPhi], \ 
              ppr}\ {\[CurlyPhi]2 - \[CurlyPhi]1, r2 - r1}/{2  \[Pi], 
                rMax}]\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(RiemannSurface::cantFindAllBranchPoints = "\<Unable to calculate all \
branchpoints for the function `1`.\>"; \)], "Input",
  FontSize->10],

Cell[BoxData[
    \(RiemannSurface::noBrachPointsPresent = "\<`1` is not a multivalued \
function. Simply use Plot3D or ParametricPlot3D to display the surface.\>"; \
\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(RiemannSurface::containsFunctionCurrentlyNotTreated = "\<`1` contains \
the functions `2` which are are not treated in this implementation.\>"; \)], \
"Input",
  FontSize->10],

Cell[BoxData[
    RowBox[{\(notTreatedFunctions[w_, z_]\), ":=", "\n", 
      RowBox[{"Module", "[", 
        RowBox[{\({foreignFunction, u}\), ",", "\n", "\t\t", 
          StyleBox[\( (*\ z\ is\ the\ independent\ variable\ *) \),
            FontWeight->"Plain"], "\n", 
          RowBox[{\(foreignFunction[z] = {}\), ";", "\n", "\t\t", 
            
            StyleBox[\( (*\ 
                u\ is\ the\ dummy\ variable\ needed\ for\ the\ Root\ pure\ \
functions\ *) \),
              FontWeight->"Plain"], "\n", \(foreignFunction[u] = {}\), ";", 
            "\n", "\t\t", 
            StyleBox[\( (*\ numerical\ values\ *) \),
              FontWeight->"Plain"], "\t\t\t", 
            "\n", \(foreignFunction[_?NumericQ] := {}\), ";", "\n", "\t\t", 
            
            StyleBox[\( (*\ recursively\ go\ down\ in\ Power, \ 
                Root\ and\ ArcTrigs\ *) \),
              FontWeight->"Plain"], 
            "\n", \(foreignFunction[Power[b_, e_]] := 
              foreignFunction /@ {b, e}\), ";", 
            "\n", \(foreignFunction[pt_Plus | pt_Times] := 
              foreignFunction /@ \((List @@ pt)\)\), ";", 
            "\n", \(Map[\((foreignFunction[#[f_]] = 
                    foreignFunction[f])\) &, \n\ \ \ \ \ \ \t{Exp, Log, \ 
                Sin, \ Cos, \ Tan, \ Cot, \ Sec, \ 
                Csc, \n\ \ \ \ \ \ \t\tSinh, \ Cosh, \ Tanh, \ Coth, \ 
                Sech, \ Csch, \n\ \ \ \ \ \ \t\tArcSin, \ ArcCos, \ ArcTan, \ 
                ArcCot, \ ArcSec, \ ArcCsc, \n\ \ \ \ \ \ \t\tArcSinh, \ 
                ArcCosh, \ ArcTanh, \ ArcCoth, \ ArcSech, \ ArcCsch}]\), ";", 
            "\n", \(foreignFunction[Root[p_, __]] := foreignFunction[p[u]]\), 
            ";", "\n", \(First /@ Union[Flatten[{foreignFunction[w]}]]\)}]}], 
        "]"}]}]], "Input",
  FontSize->10],

Cell[BoxData[
    \(numericQ[w_, z_] := \n\t
      Module[{x}, \ 
        SetAttributes[x, 
          NumericFunction]; \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ NumericQ[
          w //. z \[Rule] x[1]]]\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(RiemannSurface::notANumericFunction = "\<`1` is not a numeric function \
of `2`.\>"; \)], "Input",
  FontSize->10],

Cell[BoxData[
    \(RiemannSurface[{w_, z_}, reIm_, {pp\[CurlyPhi]_, ppr_}, k1_ : \(-1\), 
        k2_ : 1] := 
      Module[{}, test1 = \((oF = notTreatedFunctions[w, z])\) === {}; 
          If[test1, wcan = canonicalizeFunction[w]; 
            test2 = \((bps = N[branchPoints[w, z], 30])\) =!= $Failed; 
            test3 = bps =!= {}; 
            polys = If[
                test2 && test3, \((sec = sectors[bps]; )\)\ \((wnum = 
                      numberMultiValuedTerms[wcan, z]; )\)\ \((plts = 
                      powerAndLogTerms[wnum, z]; 
                    Print[Length[bps]]; )\)\ \((subs = 
                      substitutions[plts, wnum, wf, 
                        z]; )\)\ \((odes1 = \((toODE[#1, z] &)\) /@ 
                        subs\[LeftDoubleBracket]1\[RightDoubleBracket]; )\)\ \
\((odes2 = derivativeFreeRhs[odes1]; )\)\ \((sr = \((sheets[#1, k1, k2] &)\) /@ 
                        plts; )\)\ \((asp = allSheets[sr]; 
                    Print[Length[
                        asp]]; )\)\ \((odes\[CurlyPhi] = \((odeAzimuthal[#1, \
{#1\[LeftDoubleBracket]1, 0, 1\[RightDoubleBracket], 
                                z}, {\[Psi], \[CurlyPhi]}, r] &)\) /@ 
                        odes2; )\)\ \((odesr = \((odeRadial[#1, {#1\
\[LeftDoubleBracket]1, 0, 1\[RightDoubleBracket], 
                                z}, {\[Psi], \[Rho]}, \[ScriptD]] &)\) /@ 
                        odes2; )\)\ \((rMax = 
                      Max[\((#1\[LeftDoubleBracket]3\[RightDoubleBracket] \
&)\) /@ sec]; )\)\ \((sectorSheetPatches[reIm, {wf, z}, 
                          subs\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket],\
 wnum, asp, {odes\[CurlyPhi], {\[Psi], \[CurlyPhi]}, 
                            r}, {odesr, {\[Psi], \[Rho]}, \[ScriptD]}, #1, 
                          patchPlotPoints[#1, 
                            rMax, {pp\[CurlyPhi], ppr}]] &)\) /@ sec]]; 
          DeleteCases[polys, 
              Null^_. , \[Infinity]] /; \((If[\(\(\[InvisibleSpace]\)\(! \
test1\)\), Message[RiemannSurface::"\<containsFunctionCurrentlyNotTreated\>", 
                  w, oF]]; 
              If[test1 && \(\(\[InvisibleSpace]\)\(! test2\)\), 
                Message[RiemannSurface::"\<cantFindAllBranchPoints\>", w]]; 
              If[test1 && \(\(\[InvisibleSpace]\)\(! test3\)\), 
                Message[RiemannSurface::"\<noBrachPointsPresent\>", w]]; 
              TrueQ[test1 && test2 && test3])\)] /; 
        If[numericQ[w, z], True, RiemannSurface::"\<notANumericFunction\>"; 
          False]\)], "Input",
  FontSize->10],

Cell[BoxData[
    \(RiemannSurface[{eq_Equal, w_, z_}, reIm_, {pp\[CurlyPhi]_, \ ppr_}, 
        k1_: - 1, k2_:  1] := \n\t
      RiemannSurface[{z /. First[Solve[eq \[Equal] 0, w]], z}, 
        reIm, {pp\[CurlyPhi], \ ppr}, k1, k2]\)], "Input",
  FontSize->10],

Cell[BoxData[
    RowBox[{\(holePolygon[Polygon[l : {p1_, p2_, p3_, p4_}], \ f_, 
        NewPolygonShape \[Rule] OuterConcentric]\), " ", ":=", "\n", 
      RowBox[{"Module", "[", 
        RowBox[{\({mp = Plus\  @@ \ l/4, q}\), ",", "\n", "\t\t", 
          StyleBox[\( (*\ the\ inner\ points\ *) \),
            FontWeight->"Plain"], "\n", "      ", 
          
          RowBox[{\(q\  = \ \(\((mp\  + \ f \((#\  - \ mp)\))\) &\)\  /@ \ 
                l\), ";", "\n", 
            StyleBox[\( (*\ forming\ new\ polygons\ *) \),
              FontWeight->"Plain"], 
            "\n", \({MapThread[
                Polygon[
                    Join[#1, \ Reverse[#2]]] &, \ \(Partition[
                      Append[#, \ First[#]], 2, \ 1] &\) /@ {l, q}], \n\ 
              Line[Append[q, \ First[q]]]}\)}]}], "]"}]}]], "Input",
  FontSize->10],

Cell[BoxData[
    RowBox[{\(holePolygon[Polygon[l : {p1_, p2_, p3_, p4_}], f_, 
        NewPolygonShape \[Rule] VerticesTriangles]\), ":=", "\n", "\t", 
      RowBox[{"Module", "[", 
        RowBox[{\({mp = Plus @@ l/4, q1, q2, q3, q4, r1, r2, r3, r4}\), ",", 
          "\n", "\t\t", 
          
          RowBox[{\({q1, q2, q3, q4} = 
              Apply[Plus, Partition[{p4, p1, p2, p3, p4}, 2, 1], {1}]/2\), 
            ";", "\n", "\t\t", 
            StyleBox[\( (*\ the\ new\ points\ *) \),
              FontWeight->"Plain"], "\n", 
            "\t\t", \({r1, r2, r3, 
                r4} = \(mp + \((1 - f)\) \((# - mp)\) &\) /@ {q1, q2, q3, 
                  q4}\), ";", "\n", "\t\t", 
            StyleBox[\( (*\ forming\ new\ polygons\ *) \),
              FontWeight->"Plain"], "\n", 
            "\t\t", \({Polygon /@ {{r1, p1, r2}, {r2, p2, r3}, {r3, p3, 
                    r4}, {r4, p4, r1}}, \n\t\t\tLine /@ {{r1, r2, r3, r4, 
                    r1}, {p1, r2, p2, r3, p3, r4, p4, r1, p1}}}\)}]}], 
        "]"}]}]], "Input",
  FontSize->10],

Cell[BoxData[
    RowBox[{\(holePolygon[Polygon[{p1_, p2_, p3_, p4_}], f_, 
        NewPolygonShape \[Rule] CuttedVertices]\), ":=", "\n", 
      RowBox[{"Module", "[", 
        RowBox[{\({q1, q2, q3, q4, r1, r2, r3, r4}\), ",", "\n", "\t\t", 
          StyleBox[\( (*\ the\ new\ points\ *) \),
            FontWeight->"Plain"], "\n", "\t\t", 
          
          RowBox[{\({q1, q2, q3, q4} = 
              Apply[\((#1 + #2)\)/
                      2 + \((1 - f)\)/
                        2 \((#1 - #2)\) &, \n\t\t\t\tPartition[{p1, p2, p3, 
                    p4, p1}, 2, 1], {1}]\), ";", "\n", 
            "\t\t", \({r1, r2, r3, r4} = 
              Apply[\((#1 + #2)\)/
                      2 + \((1 - f)\)/
                        2 \((#2 - #1)\) &, \n\t\t\t\tPartition[{p1, p2, p3, 
                    p4, p1}, 2, 1], {1}]\), ";", "\n", " \t", 
            StyleBox[\( (*\ forming\ new\ polygon\ *) \),
              FontWeight->"Plain"], "\n", "\t\t", 
            RowBox[{"If", "[", 
              RowBox[{\(f \[Equal] 1\), ",", 
                StyleBox[\( (*\ for\ efficiency\ reasons\ *) \),
                  FontWeight->"Plain"], "\n", 
                "\t\t\t   ", \({Polygon[{q1, q2, q3, q4}], 
                  Line[{q1, q2, q3, q4, q1}]}\), ",", "\n", 
                "    \t\t", \({Polygon[{q1, r1, q2, r2, q3, r3, q4, 
                      r4}], \n\t\ \ \ \ \ \ \tLine /@ {{r1, q2}, {r2, 
                        q3}, {r3, q4}, {r4, q1}}}\)}], "]"}]}]}], 
        "]"}]}]], "Input",
  FontSize->10],

Cell[BoxData[
    RowBox[{\(holePolygon[Polygon[l : {p1_, p2_, p3_, p4_}], \ f_, 
        NewPolygonShape \[Rule] RandomQuadrilateral]\), " ", ":=", "\n", 
      RowBox[{"Module", "[", 
        RowBox[{\({q}\), ",", "\n", 
          StyleBox[\( (*\ the\ inner\ points\ *) \),
            FontWeight->"Plain"], "\n", 
          
          RowBox[{\(q = 
              Apply[\((#1 + \((1 - f)\)/2\ Random[] #2 + \((1 - f)\)/
                          2\ Random[] #3)\) &, \n\t
                Transpose[{l, \n\t\(-Apply[Subtract, 
                        Partition[Append[l, First[l]], 2, 
                          1], {1}]\), \n\ \ \ \tApply[Subtract, 
                      Partition[Prepend[l, Last[l]], 2, 1], {1}]}], {1}]\), 
            ";", "\n", 
            "\t", \(innerPoints\  = \ \(\((m\  + \ 
                      f \((#\  - \ m)\))\) &\)\  /@ \ l\), ";", "\n", 
            StyleBox[\( (*\ forming\ new\ polygons\ *) \),
              FontWeight->"Plain"], 
            "\n", \({MapThread[
                Polygon[
                    Join[#1, \ Reverse[#2]]] &, \ \(Partition[
                      Append[#, \ First[#]], 2, \ 1] &\) /@ {l, q}], \ 
              Line[Append[q, \ First[q]]]}\)}]}], "]"}]}]], "Input",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving nonlinear systems of equations", "Section"],

Cell[TextData[{
  "Solving systems of nonlinear equations poses several challenges. One is \
that Newton's method is difficult to apply when good initial values are not \
known. Another is that one sometimes wants many or all solutions rather than \
a particular one. The technology used in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to solve such systems was discussed by myself at this conference two \
years ago. Suffice it to say that this is a nice example of a \"hybrid \
symbolic/numeric\" algorithm. Other hybrid technologies for this task are \
also appearing."
}], "Text"],

Cell[CellGroupData[{

Cell["A \"simple\" example", "Subsection"],

Cell["\<\
The next example was sent to me by a friend who works for Martin \
Marietta.\
\>", "Text"],

Cell[BoxData[{
    \(x0 =  .23; x1 =  .119; x2 =  .182; x3 =  .282; x4 =  .1049; Kc = 34.4; 
    Kr = 1.45; Kch = Kr;\), "\[IndentingNewLine]", 
    \(\(eq1 = 
        Kc \((x0 - eh - ec)\) \((x1 - ec + 
                ech)\) \((1 + 2  ec + 2  eh)\)^2 \[Equal] \((x2 + eh + 
                  2  ec - ech)\)^2*\((x3 - 3  eh + 2  ec + 
                  ech)\)^2;\)\), "\n", 
    \(\(r21 = \((x4 - x2 - 2  ec)\)/2 - 
          3 \((x1 - ec - ech)\)/\((2  Kr)\);\)\), "\n", 
    \(\(eq2 = 
        eh \[Equal] 
          r21 + Sqrt[
              r21^2 + Kr \((1 - Kr)\) \((x4 - ech)\) \((x2 + 2  ec - 
                      ech)\)];\)\), "\n", 
    \(\(r31 = \((Kch \((x2 + x4 + 2  ec)\) + x3 + x1 + 3  eh + 
              ec)\)/\((2 \((Kch - 1)\))\);\)\), "\n", 
    \(\(r32 = \((Kch \((x2 + eh + 2  ec)\) \((x4 - eh)\) - \((x3 + 3  eh + 
                    2  ec)\) \((x1 - ec)\))\)/\((Kch - 
              1)\);\)\), "\[IndentingNewLine]", 
    \(\(eq3 = ech \[Equal] r31 + Sqrt[r31^2 - r32];\)\)}], "Input",
  FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[NSolve[{eq1, eq2, eq3}, {ec, eh, ech}]]\)], "Input"],

Cell[BoxData[
    \({0.3500000000000068`\ Second, {{ec \[Rule] \(-15.16177929835962`\), 
          eh \[Rule] 4.858321317240174`, 
          ech \[Rule] \(-10.527968399550568`\)}, {ec \[Rule] \
\(-0.7281987191080754`\) - 0.004177758076265493`\ \[ImaginaryI], 
          eh \[Rule] \(\(0.6142563132407274`\)\(\[InvisibleSpace]\)\) - 
              0.13955971387502125`\ \[ImaginaryI], 
          ech \[Rule] \(\(0.28706409218430523`\)\(\[InvisibleSpace]\)\) - 
              1.0477819258510845`\ \[ImaginaryI]}, {ec \[Rule] \
\(-0.7281987191080754`\) + 0.004177758076265493`\ \[ImaginaryI], 
          eh \[Rule] \(\(0.6142563132407274`\)\(\[InvisibleSpace]\)\) + 
              0.13955971387502125`\ \[ImaginaryI], 
          ech \[Rule] \(\(0.28706409218430523`\)\(\[InvisibleSpace]\)\) + 
              1.0477819258510845`\ \[ImaginaryI]}, {ec \[Rule] \
\(-0.5045254112451081`\), eh \[Rule] 0.11010134840804323`, 
          ech \[Rule] \(-0.39277997389638775`\)}}}\)], "Output"]
}, Open  ]],

Cell["\<\
If our interest was in obtaining the first real\[Hyphen]valued \
solution, note that we need to be careful about starting points in using a \
Newton root finder.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindRoot[
      Evaluate[{eq1, eq2, eq3}], {ec, \(-10\)}, {eh, 
        5}, {ech, \(-12\)}]\)], "Input"],

Cell[BoxData[
    \({ec \[Rule] \(-0.5045254115669601`\), eh \[Rule] 0.11010134854066118`, 
      ech \[Rule] \(-0.3927799740107018`\)}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["An example from computational geometry", "Subsection"],

Cell[TextData[{
  "We are given 5 points in space and asked to find circular cylinders \
containing those points. Without going into details, I'll say that this can \
be set up as a system of equations for certain parameters that define a \
cylinder. This system is troublesome for a local root finder. Among other \
issues, there may be parameter solutions that are not real\[Hyphen]valued. We \
will use ",
  Cell[BoxData[
      \(TraditionalForm\`NSolve\)]],
  " instead."
}], "Text"],

Cell[BoxData[{
    \(Off[General::spell1]\), "\[IndentingNewLine]", 
    \(Off[ParametricPlot3D::ppcom]\), "\[IndentingNewLine]", 
    \(\(Needs["\<LinearAlgebra`Orthogonalization`\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\)}], "Input",
  FontSize->10],

Cell[BoxData[
    \(perp[vec1_, vec_, offset_] := 
      vec1 - offset - Projection[vec1 - offset, vec]\)], "Input",
  FontSize->10],

Cell[BoxData[{
    \(\(SeedRandom[1111111111111];\)\), "\n", 
    \(vec = {1, a, c}; offset = {0, b, d}; 
    intpoints\  = \ 
      Table[Random[Integer, \ {\(-10\), 10}], \ {5}, \ {3}];\), "\n", 
    \(\(perps\  = \ 
        Table[perp[intpoints[\([j]\)], \ vec, \ offset], \ {j, 
            5}];\)\), "\n", 
    \(\(exprs\  = \ 
        Map[Numerator[Together[# . # - rsqr]] &, \ perps];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[solns\  = \ NSolve[exprs, \ {a, b, c, d, rsqr}]]\)], "Input"],

Cell[BoxData[
    \({0.7510000000000048`\ Second, {{a \[Rule] 0.0011565700725029897`, 
          b \[Rule] 4.665295645152864`, c \[Rule] \(-3.157844260820936`\), 
          d \[Rule] \(-6.966562721558637`\), 
          rsqr \[Rule] 
            39.157703176705574`}, {a \[Rule] \(\(0.1315821524915217`\)\(\
\[InvisibleSpace]\)\) + 0.46019328327564585`\ \[ImaginaryI], 
          b \[Rule] \(\(5.3414487155139785`\)\(\[InvisibleSpace]\)\) + 
              2.093988618751692`\ \[ImaginaryI], 
          c \[Rule] \(\(0.3615268515147293`\)\(\[InvisibleSpace]\)\) - 
              0.2645242683535386`\ \[ImaginaryI], 
          d \[Rule] \(\(0.912312196870305`\)\(\[InvisibleSpace]\)\) - 
              2.1862714415220865`\ \[ImaginaryI], 
          rsqr \[Rule] \(\(39.59620027270957`\)\(\[InvisibleSpace]\)\) - 
              1.9046465352071011`\ \[ImaginaryI]}, {a \[Rule] \
\(\(0.1315821524915217`\)\(\[InvisibleSpace]\)\) - 
              0.46019328327564585`\ \[ImaginaryI], 
          b \[Rule] \(\(5.3414487155139785`\)\(\[InvisibleSpace]\)\) - 
              2.093988618751692`\ \[ImaginaryI], 
          c \[Rule] \(\(0.3615268515147293`\)\(\[InvisibleSpace]\)\) + 
              0.2645242683535386`\ \[ImaginaryI], 
          d \[Rule] \(\(0.912312196870305`\)\(\[InvisibleSpace]\)\) + 
              2.1862714415220865`\ \[ImaginaryI], 
          rsqr \[Rule] \(\(39.59620027270957`\)\(\[InvisibleSpace]\)\) + 
              1.9046465352071011`\ \[ImaginaryI]}, {a \[Rule] \
\(-1.2864017589392907`\), b \[Rule] 0.22688856265772667`, 
          c \[Rule] \(-2.2784063695106207`\), 
          d \[Rule] \(-8.139535515152515`\), 
          rsqr \[Rule] 
            31.2550311194218`}, {a \[Rule] \(-0.04797826938562091`\), 
          b \[Rule] 4.383436166458286`, c \[Rule] 1.0982796524536937`, 
          d \[Rule] 6.582638415612088`, 
          rsqr \[Rule] 32.422100742961184`}, {a \[Rule] 4.412227480647855`, 
          b \[Rule] 36.13890047689476`, c \[Rule] 3.971835785950445`, 
          d \[Rule] 27.857988659393`, 
          rsqr \[Rule] 24.726725268234286`}}}\)], "Output"]
}, Open  ]],

Cell["\<\
We'll plot one of the actual cylinders that has real \
parameters.\
\>", "Text"],

Cell[BoxData[
    \(showlines[points_List, rest : ___]\  := \ 
      Module[\[IndentingNewLine]{plotpoints, \ plotlines, \ 
          len = Length[points]}, \[IndentingNewLine]plotpoints = 
          Table[Graphics3D[{Blue, PointSize[0.03], 
                Point[points[\([j]\)]]}], {j, 1, 
              len}]; \[IndentingNewLine]plotlines\  = 
          Table[Graphics3D[{Hue[\((j^2 + k - 4)\)/26], 
                Line[{points[\([j]\)], \ points[\([k]\)]}]}], {k, 1, 
              len - 1}, \ {j, k + 1, len}]; \[IndentingNewLine]Show[
          plotpoints, plotlines, rest, DisplayFunction \[Rule] Identity, \ 
          Boxed \[Rule] False, Axes \[Rule] False, Shading \[Rule] False, 
          ViewPoint \[Rule] {\(-1\)/2, 2, 1}, 
          ImageSize \[Rule] {300, \ 
              480}\[IndentingNewLine]]\[IndentingNewLine]]\)], "Input",
  FontSize->9],

Cell[BoxData[
    \(cylinderplot[rt_, pts_List, vec_\ , offset_, showcyl_:  True]\  := \ 
      Module[\[IndentingNewLine]{r, \ vec2, \ lin, \ x, \ theta, w1, w2, \ 
          circ, \ cylplot, \ axis}, \[IndentingNewLine]r\  = \ 
          Sqrt[rsqr /. rt]; \[IndentingNewLine]vec2 = 
          vec\  /. \ rt; \[IndentingNewLine]lin = 
          x*vec + offset /. rt; \[IndentingNewLine]pair = 
          NullSpace[{vec2}]; \[IndentingNewLine]{w1, w2} = 
          GramSchmidt[
            pair]; \[IndentingNewLine]circ =  .7*r*Cos[theta]*w1 +  .7*r*
                Sin[theta]*w2 /. rt; \[IndentingNewLine]cylplot = 
          ParametricPlot3D[
            Evaluate[lin + circ], {x, \(-6\), 
              6}, {theta, \(- .5\)*Pi,  .85*Pi}, Shading \[Rule] True, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]axis = 
          ParametricPlot3D[lin, {x, \(-7\), 7}, 
            DisplayFunction \[Rule] Identity]; \[IndentingNewLine]If[showcyl, 
          showlines[pts, axis, cylplot, DisplayFunction \[Rule] Identity], 
          showlines[pts, axis, 
            DisplayFunction \[Rule] Identity]]\[IndentingNewLine]]\)], "Input",\

  FontSize->9],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[
          Table[cylinderplot[solns[\([j]\)], intpoints, vec, offset, 
              True], {j, 1}]]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.91635 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0456273 0.952381 [
[ 0 0 0 0 ]
[ 1 1.91635 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.91635 L
0 1.91635 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0456273 0.97619 1.87072 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.469135 1.96696 -0.0506186 1.96696 [
[ 0 0 0 0 ]
[ 1 1.91635 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.91635 L
0 1.91635 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.3595 .48043 m .33946 .42405 L .36957 .40912 L p 1 g
F P
0 g
s
.3899 .46545 m .36957 .40912 L .39624 .39083 L p 1 g
F P
0 g
s
.36957 .40912 m .3899 .46545 L .3595 .48043 L p 1 g
F P
0 g
s
.41686 .44717 m .39624 .39083 L .41823 .36996 L p 1 g
F P
0 g
s
.39624 .39083 m .41686 .44717 L .3899 .46545 L p 1 g
F P
0 g
s
.37989 .53777 m .3595 .48043 L .3899 .46545 L p 1 g
F P
0 g
s
.43912 .42637 m .41823 .36996 L .43444 .34746 L p 1 g
F P
0 g
s
.41823 .36996 m .43912 .42637 L .41686 .44717 L p 1 g
F P
0 g
s
.41058 .52275 m .3899 .46545 L .41686 .44717 L p 1 g
F P
0 g
s
.3899 .46545 m .41058 .52275 L .37989 .53777 L p 1 g
F P
0 g
s
.43783 .50448 m .41686 .44717 L .43912 .42637 L p 1 g
F P
0 g
s
.41686 .44717 m .43783 .50448 L .41058 .52275 L p 1 g
F P
0 g
s
.45559 .40399 m .43444 .34746 L .44404 .32435 L p 1 g
F P
0 g
s
.43444 .34746 m .45559 .40399 L .43912 .42637 L p 1 g
F P
0 g
s
.40063 .5961 m .37989 .53777 L .41058 .52275 L p 1 g
F P
0 g
s
.46038 .48375 m .43912 .42637 L .45559 .40399 L p 1 g
F P
0 g
s
.43912 .42637 m .46038 .48375 L .43783 .50448 L p 1 g
F P
0 g
s
.43162 .58104 m .41058 .52275 L .43783 .50448 L p 1 g
F P
0 g
s
.41058 .52275 m .43162 .58104 L .40063 .5961 L p 1 g
F P
0 g
s
.26988 .26818 m
.26399 .25152 L
s
.46541 .38104 m .44404 .32435 L .44643 .30172 L p 1 g
F P
0 g
s
.44404 .32435 m .46541 .38104 L .45559 .40399 L p 1 g
F P
0 g
s
.2758 .28493 m
.26988 .26818 L
s
.45917 .56278 m .43783 .50448 L .46038 .48375 L p 1 g
F P
0 g
s
.43783 .50448 m .45917 .56278 L .43162 .58104 L p 1 g
F P
0 g
s
.47711 .4615 m .45559 .40399 L .46541 .38104 L p 1 g
F P
0 g
s
.45559 .40399 m .47711 .4615 L .46038 .48375 L p 1 g
F P
0 g
s
.28175 .30176 m
.2758 .28493 L
s
.42173 .65545 m .40063 .5961 L .43162 .58104 L p 1 g
F P
0 g
s
.482 .54214 m .46038 .48375 L .47711 .4615 L p 1 g
F P
0 g
s
.46038 .48375 m .482 .54214 L .45917 .56278 L p 1 g
F P
0 g
s
.28773 .31868 m
.28175 .30176 L
s
.45302 .64034 m .43162 .58104 L .45917 .56278 L p 1 g
F P
0 g
s
.43162 .58104 m .45302 .64034 L .42173 .65545 L p 1 g
F P
0 g
s
.46798 .35863 m .44643 .30172 L .44135 .2807 L p 1 g
F P
0 g
s
.44643 .30172 m .46798 .35863 L .46541 .38104 L p 1 g
F P
0 g
s
.29374 .33569 m
.28773 .31868 L
s
.48716 .43873 m .46541 .38104 L .46798 .35863 L p 1 g
F P
0 g
s
.46541 .38104 m .48716 .43873 L .47711 .4615 L p 1 g
F P
0 g
s
.48088 .62211 m .45917 .56278 L .482 .54214 L p 1 g
F P
0 g
s
.45917 .56278 m .48088 .62211 L .45302 .64034 L p 1 g
F P
0 g
s
.49901 .52002 m .47711 .4615 L .48716 .43873 L p 1 g
F P
0 g
s
.47711 .4615 m .49901 .52002 L .482 .54214 L p 1 g
F P
0 g
s
.29978 .35279 m
.29374 .33569 L
s
.44321 .71584 m .42173 .65545 L .45302 .64034 L p 1 g
F P
0 g
s
.30585 .36998 m
.29978 .35279 L
s
.50401 .60155 m .482 .54214 L .49901 .52002 L p 1 g
F P
0 g
s
.482 .54214 m .50401 .60155 L .48088 .62211 L p 1 g
F P
0 g
s
.44135 .2807 m .46301 .33784 L .46798 .35863 L p 1 g
F P
0 g
s
.46301 .33784 m .44135 .2807 L .42888 .26236 L p 1 g
F P
0 g
s
.4748 .70069 m .45302 .64034 L .48088 .62211 L p 1 g
F P
0 g
s
.45302 .64034 m .4748 .70069 L .44321 .71584 L p 1 g
F P
0 g
s
.48991 .41653 m .46798 .35863 L .46301 .33784 L p 1 g
F P
0 g
s
.46798 .35863 m .48991 .41653 L .48716 .43873 L p 1 g
F P
0 g
s
.31196 .38726 m
.30585 .36998 L
s
.50929 .49744 m .48716 .43873 L .48991 .41653 L p 1 g
F P
0 g
s
.48716 .43873 m .50929 .49744 L .49901 .52002 L p 1 g
F P
0 g
s
.50297 .68248 m .48088 .62211 L .50401 .60155 L p 1 g
F P
0 g
s
.48088 .62211 m .50297 .68248 L .4748 .70069 L p 1 g
F P
0 g
s
.3181 .40463 m
.31196 .38726 L
s
.52129 .57957 m .49901 .52002 L .50929 .49744 L p 1 g
F P
0 g
s
.49901 .52002 m .52129 .57957 L .50401 .60155 L p 1 g
F P
0 g
s
.32427 .4221 m
.3181 .40463 L
s
.45059 .31977 m .42888 .26236 L .40949 .24772 L p 1 g
F P
0 g
s
.42888 .26236 m .45059 .31977 L .46301 .33784 L p 1 g
F P
0 g
s
.46506 .77731 m .44321 .71584 L .4748 .70069 L p 1 g
F P
0 g
s
.52641 .66201 m .50401 .60155 L .52129 .57957 L p 1 g
F P
0 g
s
.50401 .60155 m .52641 .66201 L .50297 .68248 L p 1 g
F P
0 g
s
.46301 .33784 m .48506 .396 L .48991 .41653 L p 1 g
F P
0 g
s
.48506 .396 m .46301 .33784 L .45059 .31977 L p 1 g
F P
0 g
s
.49697 .76211 m .4748 .70069 L .50297 .68248 L p 1 g
F P
0 g
s
.4748 .70069 m .49697 .76211 L .46506 .77731 L p 1 g
F P
0 g
s
.33047 .43965 m
.32427 .4221 L
s
.14363 .35545 m .16286 .41384 L .17158 .39021 L p 1 g
F P
0 g
s
.17158 .39021 m .15214 .33165 L .14363 .35545 L p 1 g
F P
0 g
s
.51222 .47547 m .48991 .41653 L .48506 .396 L p 1 g
F P
0 g
s
.48991 .41653 m .51222 .47547 L .50929 .49744 L p 1 g
F P
0 g
s
.53182 .55719 m .50929 .49744 L .51222 .47547 L p 1 g
F P
0 g
s
.50929 .49744 m .53182 .55719 L .52129 .57957 L p 1 g
F P
0 g
s
.33671 .4573 m
.33047 .43965 L
s
.52546 .74393 m .50297 .68248 L .52641 .66201 L p 1 g
F P
0 g
s
.50297 .68248 m .52546 .74393 L .49697 .76211 L p 1 g
F P
0 g
s
.54398 .64019 m .52129 .57957 L .53182 .55719 L p 1 g
F P
0 g
s
.52129 .57957 m .54398 .64019 L .52641 .66201 L p 1 g
F P
0 g
s
.43118 .30539 m .40949 .24772 L .38407 .23759 L p 1 g
F P
0 g
s
.40949 .24772 m .43118 .30539 L .45059 .31977 L p 1 g
F P
0 g
s
.34298 .47504 m
.33671 .4573 L
s
.47269 .3782 m .45059 .31977 L .43118 .30539 L p 1 g
F P
0 g
s
.45059 .31977 m .47269 .3782 L .48506 .396 L p 1 g
F P
0 g
s
.15214 .33165 m .17158 .39021 L .18775 .3667 L p 1 g
F P
0 g
s
.18775 .3667 m .16805 .30801 L .15214 .33165 L p 1 g
F P
0 g
s
.4873 .83987 m .46506 .77731 L .49697 .76211 L p 1 g
F P
0 g
s
.54921 .72356 m .52641 .66201 L .54398 .64019 L p 1 g
F P
0 g
s
.52641 .66201 m .54921 .72356 L .52546 .74393 L p 1 g
F P
0 g
s
.48506 .396 m .5075 .45521 L .51222 .47547 L p 1 g
F P
0 g
s
.5075 .45521 m .48506 .396 L .47269 .3782 L p 1 g
F P
0 g
s
.34928 .49287 m
.34298 .47504 L
s
.51953 .82463 m .49697 .76211 L .52546 .74393 L p 1 g
F P
0 g
s
.49697 .76211 m .51953 .82463 L .4873 .83987 L p 1 g
F P
0 g
s
.16286 .41384 m .18244 .47327 L .19137 .44983 L p 1 g
F P
0 g
s
.19137 .44983 m .17158 .39021 L .16286 .41384 L p 1 g
F P
0 g
s
.53494 .53547 m .51222 .47547 L .5075 .45521 L p 1 g
F P
0 g
s
.51222 .47547 m .53494 .53547 L .53182 .55719 L p 1 g
F P
0 g
s
.40567 .29553 m .38407 .23759 L .35385 .23261 L p 1 g
F P
0 g
s
.38407 .23759 m .40567 .29553 L .43118 .30539 L p 1 g
F P
0 g
s
.35561 .51081 m
.34928 .49287 L
s
.55474 .61802 m .53182 .55719 L .53494 .53547 L p 1 g
F P
0 g
s
.53182 .55719 m .55474 .61802 L .54398 .64019 L p 1 g
F P
0 g
s
.54835 .80648 m .52546 .74393 L .54921 .72356 L p 1 g
F P
0 g
s
.52546 .74393 m .54835 .80648 L .51953 .82463 L p 1 g
F P
0 g
s
.16805 .30801 m .18775 .3667 L .21062 .34454 L p 1 g
F P
0 g
s
.21062 .34454 m .19064 .28579 L .16805 .30801 L p 1 g
F P
0 g
s
.56706 .7019 m .54398 .64019 L .55474 .61802 L p 1 g
F P
0 g
s
.54398 .64019 m .56706 .7019 L .54921 .72356 L p 1 g
F P
0 g
s
.36199 .52883 m
.35561 .51081 L
s
.45327 .3641 m .43118 .30539 L .40567 .29553 L p 1 g
F P
0 g
s
.43118 .30539 m .45327 .3641 L .47269 .3782 L p 1 g
F P
0 g
s
.49519 .43769 m .47269 .3782 L .45327 .3641 L p 1 g
F P
0 g
s
.47269 .3782 m .49519 .43769 L .5075 .45521 L p 1 g
F P
0 g
s
.37528 .29079 m .35385 .23261 L .32038 .23311 L p 1 g
F P
0 g
s
.35385 .23261 m .37528 .29079 L .40567 .29553 L p 1 g
F P
0 g
s
.17158 .39021 m .19137 .44983 L .2078 .42644 L p 1 g
F P
0 g
s
.2078 .42644 m .18775 .3667 L .17158 .39021 L p 1 g
F P
0 g
s
.50995 .90356 m .4873 .83987 L .51953 .82463 L p 1 g
F P
0 g
s
.36839 .54696 m
.36199 .52883 L
s
.57242 .78621 m .54921 .72356 L .56706 .7019 L p 1 g
F P
0 g
s
.54921 .72356 m .57242 .78621 L .54835 .80648 L p 1 g
F P
0 g
s
.5075 .45521 m .53035 .51548 L .53494 .53547 L p 1 g
F P
0 g
s
.53035 .51548 m .5075 .45521 L .49519 .43769 L p 1 g
F P
0 g
s
.19064 .28579 m .21062 .34454 L .23906 .32496 L p 1 g
F P
0 g
s
.23906 .32496 m .21876 .26622 L .19064 .28579 L p 1 g
F P
0 g
s
.5425 .88828 m .51953 .82463 L .54835 .80648 L p 1 g
F P
0 g
s
.51953 .82463 m .5425 .88828 L .50995 .90356 L p 1 g
F P
0 g
s
.18244 .47327 m .20237 .53377 L .21152 .51053 L p 1 g
F P
0 g
s
.21152 .51053 m .19137 .44983 L .18244 .47327 L p 1 g
F P
0 g
s
.55807 .59655 m .53494 .53547 L .53035 .51548 L p 1 g
F P
0 g
s
.53494 .53547 m .55807 .59655 L .55474 .61802 L p 1 g
F P
0 g
s
.37483 .56518 m
.36839 .54696 L
s
.34158 .29151 m .32038 .23311 L .28544 .23913 L p 1 g
F P
0 g
s
.32038 .23311 m .34158 .29151 L .37528 .29079 L p 1 g
F P
0 g
s
.42765 .35451 m .40567 .29553 L .37528 .29079 L p 1 g
F P
0 g
s
.40567 .29553 m .42765 .35451 L .45327 .3641 L p 1 g
F P
0 g
s
.57809 .67995 m .55474 .61802 L .55807 .59655 L p 1 g
F P
0 g
s
.55474 .61802 m .57809 .67995 L .56706 .7019 L p 1 g
F P
0 g
s
.21876 .26622 m .23906 .32496 L .27157 .30905 L p 1 g
F P
0 g
s
.27157 .30905 m .25094 .25037 L .21876 .26622 L p 1 g
F P
0 g
s
.57165 .87017 m .54835 .80648 L .57242 .78621 L p 1 g
F P
0 g
s
.54835 .80648 m .57165 .87017 L .5425 .88828 L p 1 g
F P
0 g
s
.30637 .2977 m .28544 .23913 L .25094 .25037 L p 1 g
F P
0 g
s
.28544 .23913 m .30637 .2977 L .34158 .29151 L p 1 g
F P
0 g
s
.25094 .25037 m .27157 .30905 L .30637 .2977 L p 1 g
F P
0 g
s
.3813 .5835 m
.37483 .56518 L
s
.18775 .3667 m .2078 .42644 L .23097 .40436 L p 1 g
F P
0 g
s
.23097 .40436 m .21062 .34454 L .18775 .3667 L p 1 g
F P
0 g
s
.59057 .76473 m .56706 .7019 L .57809 .67995 L p 1 g
F P
0 g
s
.56706 .7019 m .59057 .76473 L .57242 .78621 L p 1 g
F P
0 g
s
.47575 .42388 m .45327 .3641 L .42765 .35451 L p 1 g
F P
0 g
s
.45327 .3641 m .47575 .42388 L .49519 .43769 L p 1 g
F P
0 g
s
.38781 .60192 m
.3813 .5835 L
s
.5181 .49826 m .49519 .43769 L .47575 .42388 L p 1 g
F P
0 g
s
.49519 .43769 m .5181 .49826 L .53035 .51548 L p 1 g
F P
0 g
s
.3971 .35003 m .37528 .29079 L .34158 .29151 L p 1 g
F P
0 g
s
.37528 .29079 m .3971 .35003 L .42765 .35451 L p 1 g
F P
0 g
s
.19137 .44983 m .21152 .51053 L .22822 .48729 L p 1 g
F P
0 g
s
.22822 .48729 m .2078 .42644 L .19137 .44983 L p 1 g
F P
0 g
s
.53301 .96842 m .50995 .90356 L .5425 .88828 L p 1 g
F P
0 g
s
.59605 .85001 m .57242 .78621 L .59057 .76473 L p 1 g
F P
0 g
s
.57242 .78621 m .59605 .85001 L .57165 .87017 L p 1 g
F P
0 g
s
.53035 .51548 m .55361 .57685 L .55807 .59655 L p 1 g
F P
0 g
s
.55361 .57685 m .53035 .51548 L .5181 .49826 L p 1 g
F P
0 g
s
.21062 .34454 m .23097 .40436 L .25974 .38479 L p 1 g
F P
0 g
s
.25974 .38479 m .23906 .32496 L .21062 .34454 L p 1 g
F P
0 g
s
.56589 .9531 m .5425 .88828 L .57165 .87017 L p 1 g
F P
0 g
s
.5425 .88828 m .56589 .9531 L .53301 .96842 L p 1 g
F P
0 g
s
.39436 .62044 m
.38781 .60192 L
s
.20237 .53377 m .22267 .59538 L .23204 .57235 L p 1 g
F P
0 g
s
.23204 .57235 m .21152 .51053 L .20237 .53377 L p 1 g
F P
0 g
s
.58162 .65875 m .55807 .59655 L .55361 .57685 L p 1 g
F P
0 g
s
.55807 .59655 m .58162 .65875 L .57809 .67995 L p 1 g
F P
0 g
s
.36317 .35097 m .34158 .29151 L .30637 .2977 L p 1 g
F P
0 g
s
.34158 .29151 m .36317 .35097 L .3971 .35003 L p 1 g
F P
0 g
s
.45004 .41458 m .42765 .35451 L .3971 .35003 L p 1 g
F P
0 g
s
.42765 .35451 m .45004 .41458 L .47575 .42388 L p 1 g
F P
0 g
s
.60186 .74301 m .57809 .67995 L .58162 .65875 L p 1 g
F P
0 g
s
.57809 .67995 m .60186 .74301 L .59057 .76473 L p 1 g
F P
0 g
s
.23906 .32496 m .25974 .38479 L .29257 .36882 L p 1 g
F P
0 g
s
.29257 .36882 m .27157 .30905 L .23906 .32496 L p 1 g
F P
0 g
s
.40094 .63906 m
.39436 .62044 L
s
.59538 .93502 m .57165 .87017 L .59605 .85001 L p 1 g
F P
0 g
s
.57165 .87017 m .59538 .93502 L .56589 .9531 L p 1 g
F P
0 g
s
.32769 .35734 m .30637 .2977 L .27157 .30905 L p 1 g
F P
0 g
s
.30637 .2977 m .32769 .35734 L .36317 .35097 L p 1 g
F P
0 g
s
.27157 .30905 m .29257 .36882 L .32769 .35734 L p 1 g
F P
0 g
s
.2078 .42644 m .22822 .48729 L .2517 .46528 L p 1 g
F P
0 g
s
.2517 .46528 m .23097 .40436 L .2078 .42644 L p 1 g
F P
0 g
s
.61451 .82871 m .59057 .76473 L .60186 .74301 L p 1 g
F P
0 g
s
.59057 .76473 m .61451 .82871 L .59605 .85001 L p 1 g
F P
0 g
s
.49864 .48476 m .47575 .42388 L .45004 .41458 L p 1 g
F P
0 g
s
.47575 .42388 m .49864 .48476 L .5181 .49826 L p 1 g
F P
0 g
s
.40755 .65778 m
.40094 .63906 L
s
.54143 .55994 m .5181 .49826 L .49864 .48476 L p 1 g
F P
0 g
s
.5181 .49826 m .54143 .55994 L .55361 .57685 L p 1 g
F P
0 g
s
.41932 .41036 m .3971 .35003 L .36317 .35097 L p 1 g
F P
0 g
s
.3971 .35003 m .41932 .41036 L .45004 .41458 L p 1 g
F P
0 g
s
.21152 .51053 m .23204 .57235 L .24901 .54926 L p 1 g
F P
0 g
s
.24901 .54926 m .22822 .48729 L .21152 .51053 L p 1 g
F P
0 g
s
.55649 1.03446 m .53301 .96842 L .56589 .9531 L p 1 g
F P
0 g
s
.62012 .91499 m .59605 .85001 L .61451 .82871 L p 1 g
F P
0 g
s
.59605 .85001 m .62012 .91499 L .59538 .93502 L p 1 g
F P
0 g
s
.55361 .57685 m .57731 .63935 L .58162 .65875 L p 1 g
F P
0 g
s
.57731 .63935 m .55361 .57685 L .54143 .55994 L p 1 g
F P
0 g
s
.4142 .67661 m
.40755 .65778 L
s
.23097 .40436 m .2517 .46528 L .28079 .44572 L p 1 g
F P
0 g
s
.28079 .44572 m .25974 .38479 L .23097 .40436 L p 1 g
F P
0 g
s
.58971 1.01911 m .56589 .9531 L .59538 .93502 L p 1 g
F P
0 g
s
.56589 .9531 m .58971 1.01911 L .55649 1.03446 L p 1 g
F P
0 g
s
.22267 .59538 m .24334 .65813 L .25294 .63532 L p 1 g
F P
0 g
s
.25294 .63532 m .23204 .57235 L .22267 .59538 L p 1 g
F P
0 g
s
.6056 .72209 m .58162 .65875 L .57731 .63935 L p 1 g
F P
0 g
s
.58162 .65875 m .6056 .72209 L .60186 .74301 L p 1 g
F P
0 g
s
.38516 .41153 m .36317 .35097 L .32769 .35734 L p 1 g
F P
0 g
s
.36317 .35097 m .38516 .41153 L .41932 .41036 L p 1 g
F P
0 g
s
.47284 .47575 m .45004 .41458 L .41932 .41036 L p 1 g
F P
0 g
s
.45004 .41458 m .47284 .47575 L .49864 .48476 L p 1 g
F P
0 g
s
.42089 .69554 m
.4142 .67661 L
s
.62607 .80724 m .60186 .74301 L .6056 .72209 L p 1 g
F P
0 g
s
.60186 .74301 m .62607 .80724 L .61451 .82871 L p 1 g
F P
0 g
s
.25974 .38479 m .28079 .44572 L .31396 .42968 L p 1 g
F P
0 g
s
.31396 .42968 m .29257 .36882 L .25974 .38479 L p 1 g
F P
0 g
s
.61955 1.00108 m .59538 .93502 L .62012 .91499 L p 1 g
F P
0 g
s
.59538 .93502 m .61955 1.00108 L .58971 1.01911 L p 1 g
F P
0 g
s
.34939 .41808 m .32769 .35734 L .29257 .36882 L p 1 g
F P
0 g
s
.32769 .35734 m .34939 .41808 L .38516 .41153 L p 1 g
F P
0 g
s
.29257 .36882 m .31396 .42968 L .34939 .41808 L p 1 g
F P
0 g
s
.22822 .48729 m .24901 .54926 L .27281 .52733 L p 1 g
F P
0 g
s
.27281 .52733 m .2517 .46528 L .22822 .48729 L p 1 g
F P
0 g
s
.6389 .89388 m .61451 .82871 L .62607 .80724 L p 1 g
F P
0 g
s
.61451 .82871 m .6389 .89388 L .62012 .91499 L p 1 g
F P
0 g
s
.42762 .71457 m
.42089 .69554 L
s
.52196 .54676 m .49864 .48476 L .47284 .47575 L p 1 g
F P
0 g
s
.49864 .48476 m .52196 .54676 L .54143 .55994 L p 1 g
F P
0 g
s
.56519 .62277 m .54143 .55994 L .52196 .54676 L p 1 g
F P
0 g
s
.54143 .55994 m .56519 .62277 L .57731 .63935 L p 1 g
F P
0 g
s
.44195 .47181 m .41932 .41036 L .38516 .41153 L p 1 g
F P
0 g
s
.41932 .41036 m .44195 .47181 L .47284 .47575 L p 1 g
F P
0 g
s
.23204 .57235 m .25294 .63532 L .2702 .61238 L p 1 g
F P
0 g
s
.2702 .61238 m .24901 .54926 L .23204 .57235 L p 1 g
F P
0 g
s
.58041 1.10173 m .55649 1.03446 L .58971 1.01911 L p 1 g
F P
0 g
s
.43438 .73371 m
.42762 .71457 L
s
.64463 .98117 m .62012 .91499 L .6389 .89388 L p 1 g
F P
0 g
s
.62012 .91499 m .64463 .98117 L .61955 1.00108 L p 1 g
F P
0 g
s
.57731 .63935 m .60144 .70301 L .6056 .72209 L p 1 g
F P
0 g
s
.60144 .70301 m .57731 .63935 L .56519 .62277 L p 1 g
F P
0 g
s
.2517 .46528 m .27281 .52733 L .30224 .50778 L p 1 g
F P
0 g
s
.30224 .50778 m .28079 .44572 L .2517 .46528 L p 1 g
F P
0 g
s
.61398 1.08634 m .58971 1.01911 L .61955 1.00108 L p 1 g
F P
0 g
s
.58971 1.01911 m .61398 1.08634 L .58041 1.10173 L p 1 g
F P
0 g
s
.24334 .65813 m .2644 .72204 L .27424 .69946 L p 1 g
F P
0 g
s
.27424 .69946 m .25294 .63532 L .24334 .65813 L p 1 g
F P
0 g
s
.63003 .78661 m .6056 .72209 L .60144 .70301 L p 1 g
F P
0 g
s
.6056 .72209 m .63003 .78661 L .62607 .80724 L p 1 g
F P
0 g
s
.44118 .75295 m
.43438 .73371 L
s
.40756 .47321 m .38516 .41153 L .34939 .41808 L p 1 g
F P
0 g
s
.38516 .41153 m .40756 .47321 L .44195 .47181 L p 1 g
F P
0 g
s
.49607 .53806 m .47284 .47575 L .44195 .47181 L p 1 g
F P
0 g
s
.47284 .47575 m .49607 .53806 L .52196 .54676 L p 1 g
F P
0 g
s
.65073 .87266 m .62607 .80724 L .63003 .78661 L p 1 g
F P
0 g
s
.62607 .80724 m .65073 .87266 L .6389 .89388 L p 1 g
F P
0 g
s
.28079 .44572 m .30224 .50778 L .33574 .49169 L p 1 g
F P
0 g
s
.33574 .49169 m .31396 .42968 L .28079 .44572 L p 1 g
F P
0 g
s
.64418 1.06836 m .61955 1.00108 L .64463 .98117 L p 1 g
F P
0 g
s
.61955 1.00108 m .64418 1.06836 L .61398 1.08634 L p 1 g
F P
0 g
s
.3715 .47995 m .34939 .41808 L .31396 .42968 L p 1 g
F P
0 g
s
.34939 .41808 m .3715 .47995 L .40756 .47321 L p 1 g
F P
0 g
s
.31396 .42968 m .33574 .49169 L .3715 .47995 L p 1 g
F P
0 g
s
.44802 .7723 m
.44118 .75295 L
s
.24901 .54926 m .2702 .61238 L .29432 .59055 L p 1 g
F P
0 g
s
.29432 .59055 m .27281 .52733 L .24901 .54926 L p 1 g
F P
0 g
s
.66374 .96026 m .6389 .89388 L .65073 .87266 L p 1 g
F P
0 g
s
.6389 .89388 m .66374 .96026 L .64463 .98117 L p 1 g
F P
0 g
s
.54571 .60992 m .52196 .54676 L .49607 .53806 L p 1 g
F P
0 g
s
.52196 .54676 m .54571 .60992 L .56519 .62277 L p 1 g
F P
0 g
s
.45489 .79176 m
.44802 .7723 L
s
.5894 .68677 m .56519 .62277 L .54571 .60992 L p 1 g
F P
0 g
s
.56519 .62277 m .5894 .68677 L .60144 .70301 L p 1 g
F P
0 g
s
.46501 .5344 m .44195 .47181 L .40756 .47321 L p 1 g
F P
0 g
s
.44195 .47181 m .46501 .5344 L .49607 .53806 L p 1 g
F P
0 g
s
.25294 .63532 m .27424 .69946 L .29178 .6767 L p 1 g
F P
0 g
s
.29178 .6767 m .2702 .61238 L .25294 .63532 L p 1 g
F P
0 g
s
.60478 1.17027 m .58041 1.10173 L .61398 1.08634 L p 1 g
F P
0 g
s
.66961 1.04859 m .64463 .98117 L .66374 .96026 L p 1 g
F P
0 g
s
.64463 .98117 m .66961 1.04859 L .64418 1.06836 L p 1 g
F P
0 g
s
.60144 .70301 m .62602 .76787 L .63003 .78661 L p 1 g
F P
0 g
s
.62602 .76787 m .60144 .70301 L .5894 .68677 L p 1 g
F P
0 g
s
.27281 .52733 m .29432 .59055 L .32409 .57101 L p 1 g
F P
0 g
s
.32409 .57101 m .30224 .50778 L .27281 .52733 L p 1 g
F P
0 g
s
.6387 1.15484 m .61398 1.08634 L .64418 1.06836 L p 1 g
F P
0 g
s
.61398 1.08634 m .6387 1.15484 L .60478 1.17027 L p 1 g
F P
0 g
s
.46181 .81133 m
.45489 .79176 L
s
.2644 .72204 m .28585 .78715 L .29593 .76482 L p 1 g
F P
0 g
s
.29593 .76482 m .27424 .69946 L .2644 .72204 L p 1 g
F P
0 g
s
.65492 .85235 m .63003 .78661 L .62602 .76787 L p 1 g
F P
0 g
s
.63003 .78661 m .65492 .85235 L .65073 .87266 L p 1 g
F P
0 g
s
.43038 .53606 m .40756 .47321 L .3715 .47995 L p 1 g
F P
0 g
s
.40756 .47321 m .43038 .53606 L .46501 .5344 L p 1 g
F P
0 g
s
.51973 .60155 m .49607 .53806 L .46501 .5344 L p 1 g
F P
0 g
s
.49607 .53806 m .51973 .60155 L .54571 .60992 L p 1 g
F P
0 g
s
.67586 .93931 m .65073 .87266 L .65492 .85235 L p 1 g
F P
0 g
s
.65073 .87266 m .67586 .93931 L .66374 .96026 L p 1 g
F P
0 g
s
.30224 .50778 m .32409 .57101 L .35794 .55486 L p 1 g
F P
0 g
s
.35794 .55486 m .33574 .49169 L .30224 .50778 L p 1 g
F P
0 g
s
.46876 .831 m
.46181 .81133 L
s
.66926 1.13691 m .64418 1.06836 L .66961 1.04859 L p 1 g
F P
0 g
s
.64418 1.06836 m .66926 1.13691 L .6387 1.15484 L p 1 g
F P
0 g
s
.39403 .54299 m .3715 .47995 L .33574 .49169 L p 1 g
F P
0 g
s
.3715 .47995 m .39403 .54299 L .43038 .53606 L p 1 g
F P
0 g
s
.33574 .49169 m .35794 .55486 L .39403 .54299 L p 1 g
F P
0 g
s
.2702 .61238 m .29178 .6767 L .31623 .65496 L p 1 g
F P
0 g
s
.31623 .65496 m .29432 .59055 L .2702 .61238 L p 1 g
F P
0 g
s
.68904 1.02789 m .66374 .96026 L .67586 .93931 L p 1 g
F P
0 g
s
.66374 .96026 m .68904 1.02789 L .66961 1.04859 L p 1 g
F P
0 g
s
.56991 .67427 m .54571 .60992 L .51973 .60155 L p 1 g
F P
0 g
s
.54571 .60992 m .56991 .67427 L .5894 .68677 L p 1 g
F P
0 g
s
.47575 .85079 m
.46876 .831 L
s
.61406 .75199 m .5894 .68677 L .56991 .67427 L p 1 g
F P
0 g
s
.5894 .68677 m .61406 .75199 L .62602 .76787 L p 1 g
F P
0 g
s
.4885 .59818 m .46501 .5344 L .43038 .53606 L p 1 g
F P
0 g
s
.46501 .5344 m .4885 .59818 L .51973 .60155 L p 1 g
F P
0 g
s
.27424 .69946 m .29593 .76482 L .31378 .74224 L p 1 g
F P
0 g
s
.31378 .74224 m .29178 .6767 L .27424 .69946 L p 1 g
F P
0 g
s
.6296 1.2401 m .60478 1.17027 L .6387 1.15484 L p 1 g
F P
0 g
s
.69505 1.11728 m .66961 1.04859 L .68904 1.02789 L p 1 g
F P
0 g
s
.66961 1.04859 m .69505 1.11728 L .66926 1.13691 L p 1 g
F P
0 g
s
.62602 .76787 m .65108 .83395 L .65492 .85235 L p 1 g
F P
0 g
s
.65108 .83395 m .62602 .76787 L .61406 .75199 L p 1 g
F P
0 g
s
.48278 .87069 m
.47575 .85079 L
s
.29432 .59055 m .31623 .65496 L .34636 .63544 L p 1 g
F P
0 g
s
.34636 .63544 m .32409 .57101 L .29432 .59055 L p 1 g
F P
0 g
s
.66389 1.22463 m .6387 1.15484 L .66926 1.13691 L p 1 g
F P
0 g
s
.6387 1.15484 m .66389 1.22463 L .6296 1.2401 L p 1 g
F P
0 g
s
.28585 .78715 m .30771 .85349 L .31804 .83143 L p 1 g
F P
0 g
s
.31804 .83143 m .29593 .76482 L .28585 .78715 L p 1 g
F P
0 g
s
.68028 .91933 m .65492 .85235 L .65108 .83395 L p 1 g
F P
0 g
s
.65492 .85235 m .68028 .91933 L .67586 .93931 L p 1 g
F P
0 g
s
.45364 .60009 m .43038 .53606 L .39403 .54299 L p 1 g
F P
0 g
s
.43038 .53606 m .45364 .60009 L .4885 .59818 L p 1 g
F P
0 g
s
.54384 .66623 m .51973 .60155 L .4885 .59818 L p 1 g
F P
0 g
s
.51973 .60155 m .54384 .66623 L .56991 .67427 L p 1 g
F P
0 g
s
.48986 .8907 m
.48278 .87069 L
s
.70146 1.00723 m .67586 .93931 L .68028 .91933 L p 1 g
F P
0 g
s
.67586 .93931 m .70146 1.00723 L .68904 1.02789 L p 1 g
F P
0 g
s
.32409 .57101 m .34636 .63544 L .38056 .61923 L p 1 g
F P
0 g
s
.38056 .61923 m .35794 .55486 L .32409 .57101 L p 1 g
F P
0 g
s
1 0 .462 r
.74697 .89754 m
.74649 1.24783 L
s
.69482 1.20677 m .66926 1.13691 L .69505 1.11728 L p 1 g
F P
0 g
s
.66926 1.13691 m .69482 1.20677 L .66389 1.22463 L p 1 g
F P
0 g
s
.41699 .60723 m .39403 .54299 L .35794 .55486 L p 1 g
F P
0 g
s
.39403 .54299 m .41699 .60723 L .45364 .60009 L p 1 g
F P
0 g
s
.35794 .55486 m .38056 .61923 L .41699 .60723 L p 1 g
F P
0 g
s
.29178 .6767 m .31378 .74224 L .33856 .7206 L p 1 g
F P
0 g
s
.33856 .7206 m .31623 .65496 L .29178 .6767 L p 1 g
F P
0 g
s
.71483 1.09681 m .68904 1.02789 L .70146 1.00723 L p 1 g
F P
0 g
s
.68904 1.02789 m .71483 1.09681 L .69505 1.11728 L p 1 g
F P
0 g
s
.49697 .91082 m
.48986 .8907 L
s
1 0 .231 r
.72522 .93793 m
.74697 .89754 L
s
1 0 .692 r
.71339 .93533 m
.74697 .89754 L
s
0 0 1 r
.03 w
.74697 .89754 Mdot
.5 Mabswid
.59458 .73985 m .56991 .67427 L .54384 .66623 L p 1 g
F P
0 g
s
.56991 .67427 m .59458 .73985 L .61406 .75199 L p 1 g
F P
0 g
s
.6392 .81844 m .61406 .75199 L .59458 .73985 L p 1 g
F P
0 g
s
.61406 .75199 m .6392 .81844 L .65108 .83395 L p 1 g
F P
0 g
s
.51245 .66318 m .4885 .59818 L .45364 .60009 L p 1 g
F P
0 g
s
.4885 .59818 m .51245 .66318 L .54384 .66623 L p 1 g
F P
0 g
s
.29593 .76482 m .31804 .83143 L .33619 .80903 L p 1 g
F P
0 g
s
.33619 .80903 m .31378 .74224 L .29593 .76482 L p 1 g
F P
0 g
s
.50412 .93106 m
.49697 .91082 L
s
.6549 1.31126 m .6296 1.2401 L .66389 1.22463 L p 1 g
F P
0 g
s
.72099 1.18729 m .69505 1.11728 L .71483 1.09681 L p 1 g
F P
0 g
s
.69505 1.11728 m .72099 1.18729 L .69482 1.20677 L p 1 g
F P
0 g
s
.65108 .83395 m .6766 .9013 L .68028 .91933 L p 1 g
F P
0 g
s
.6766 .9013 m .65108 .83395 L .6392 .81844 L p 1 g
F P
0 g
s
.31623 .65496 m .33856 .7206 L .36905 .70111 L p 1 g
F P
0 g
s
.36905 .70111 m .34636 .63544 L .31623 .65496 L p 1 g
F P
0 g
s
.68956 1.29576 m .66389 1.22463 L .69482 1.20677 L p 1 g
F P
0 g
s
.66389 1.22463 m .68956 1.29576 L .6549 1.31126 L p 1 g
F P
0 g
s
.30771 .85349 m .32998 .92111 L .34058 .89931 L p 1 g
F P
0 g
s
.34058 .89931 m .31804 .83143 L .30771 .85349 L p 1 g
F P
0 g
s
.70613 .98759 m .68028 .91933 L .6766 .9013 L p 1 g
F P
0 g
s
.68028 .91933 m .70613 .98759 L .70146 1.00723 L p 1 g
F P
0 g
s
.51131 .95142 m
.50412 .93106 L
s
.47733 .66536 m .45364 .60009 L .41699 .60723 L p 1 g
F P
0 g
s
.45364 .60009 m .47733 .66536 L .51245 .66318 L p 1 g
F P
0 g
s
.56842 .73216 m .54384 .66623 L .51245 .66318 L p 1 g
F P
0 g
s
.54384 .66623 m .56842 .73216 L .59458 .73985 L p 1 g
F P
0 g
s
.72756 1.07645 m .70146 1.00723 L .70613 .98759 L p 1 g
F P
0 g
s
.70146 1.00723 m .72756 1.07645 L .71483 1.09681 L p 1 g
F P
0 g
s
.34636 .63544 m .36905 .70111 L .40362 .68484 L p 1 g
F P
0 g
s
.40362 .68484 m .38056 .61923 L .34636 .63544 L p 1 g
F P
0 g
s
.72087 1.27796 m .69482 1.20677 L .72099 1.18729 L p 1 g
F P
0 g
s
0 .538 1 r
.7209 1.26066 m
.74649 1.24783 L
s
.69482 1.20677 m .72087 1.27796 L .68956 1.29576 L p 1 g
F P
0 g
s
.44039 .6727 m .41699 .60723 L .38056 .61923 L p 1 g
F P
0 g
s
.41699 .60723 m .44039 .6727 L .47733 .66536 L p 1 g
F P
0 g
s
.51854 .97189 m
.51131 .95142 L
s
.38056 .61923 m .40362 .68484 L .44039 .6727 L p 1 g
F P
0 g
s
.31378 .74224 m .33619 .80903 L .36133 .78751 L p 1 g
F P
0 g
s
.36133 .78751 m .33856 .7206 L .31378 .74224 L p 1 g
F P
0 g
s
.74111 1.16706 m .71483 1.09681 L .72756 1.07645 L p 1 g
F P
0 g
s
.71483 1.09681 m .74111 1.16706 L .72099 1.18729 L p 1 g
F P
0 g
s
.61971 .80668 m .59458 .73985 L .56842 .73216 L p 1 g
F P
0 g
s
.59458 .73985 m .61971 .80668 L .6392 .81844 L p 1 g
F P
0 g
s
.52582 .99248 m
.51854 .97189 L
s
.66482 .88618 m .6392 .81844 L .61971 .80668 L p 1 g
F P
0 g
s
.6392 .81844 m .66482 .88618 L .6766 .9013 L p 1 g
F P
0 g
s
.53685 .72943 m .51245 .66318 L .47733 .66536 L p 1 g
F P
0 g
s
.51245 .66318 m .53685 .72943 L .56842 .73216 L p 1 g
F P
0 g
s
.31804 .83143 m .34058 .89931 L .35904 .87713 L p 1 g
F P
0 g
s
.35904 .87713 m .33619 .80903 L .31804 .83143 L p 1 g
F P
0 g
s
.68069 1.38379 m .6549 1.31126 L .68956 1.29576 L p 1 g
F P
0 g
s
.74742 1.25864 m .72099 1.18729 L .74111 1.16706 L p 1 g
F P
0 g
s
.72099 1.18729 m .74742 1.25864 L .72087 1.27796 L p 1 g
F P
0 g
s
.615 1 0 r
.87752 1.29638 m
.91505 1.31029 L
s
1 0 .923 r
.74697 .89754 m
.80129 1.03093 L
s
.6766 .9013 m .70263 .96995 L .70613 .98759 L p 1 g
F P
0 g
s
.70263 .96995 m .6766 .9013 L .66482 .88618 L p 1 g
F P
0 g
s
.33856 .7206 m .36133 .78751 L .39218 .76805 L p 1 g
F P
0 g
s
.39218 .76805 m .36905 .70111 L .33856 .7206 L p 1 g
F P
0 g
s
.71572 1.36826 m .68956 1.29576 L .72087 1.27796 L p 1 g
F P
0 g
s
.68956 1.29576 m .71572 1.36826 L .68069 1.38379 L p 1 g
F P
0 g
s
.53314 1.01318 m
.52582 .99248 L
s
.32998 .92111 m .35269 .99003 L .36355 .96852 L p 1 g
F P
0 g
s
.36355 .96852 m .34058 .89931 L .32998 .92111 L p 1 g
F P
0 g
s
.73247 1.05717 m .70613 .98759 L .70263 .96995 L p 1 g
F P
0 g
s
1 0 .231 r
.70471 .97602 m
.70711 .97155 L
s
.70711 .97155 m
.72522 .93793 L
s
.70613 .98759 m .73247 1.05717 L .72756 1.07645 L p 1 g
F P
0 g
s
.50149 .73188 m .47733 .66536 L .44039 .6727 L p 1 g
F P
0 g
s
.47733 .66536 m .50149 .73188 L .53685 .72943 L p 1 g
F P
0 g
s
.59347 .79937 m .56842 .73216 L .53685 .72943 L p 1 g
F P
0 g
s
.56842 .73216 m .59347 .79937 L .61971 .80668 L p 1 g
F P
0 g
s
.75415 1.14701 m .72756 1.07645 L .73247 1.05717 L p 1 g
F P
0 g
s
.72756 1.07645 m .75415 1.14701 L .74111 1.16706 L p 1 g
F P
0 g
s
.36905 .70111 m .39218 .76805 L .42712 .75172 L p 1 g
F P
0 g
s
.42712 .75172 m .40362 .68484 L .36905 .70111 L p 1 g
F P
0 g
s
.54049 1.03401 m
.53314 1.01318 L
s
.74743 1.35053 m .72087 1.27796 L .74742 1.25864 L p 1 g
F P
0 g
s
.72087 1.27796 m .74743 1.35053 L .71572 1.36826 L p 1 g
F P
0 g
s
.46424 .73944 m .44039 .6727 L .40362 .68484 L p 1 g
F P
0 g
s
.44039 .6727 m .46424 .73944 L .50149 .73188 L p 1 g
F P
0 g
s
.40362 .68484 m .42712 .75172 L .46424 .73944 L p 1 g
F P
0 g
s
.33619 .80903 m .35904 .87713 L .38454 .85573 L p 1 g
F P
0 g
s
.38454 .85573 m .36133 .78751 L .33619 .80903 L p 1 g
F P
0 g
s
.76791 1.23867 m .74111 1.16706 L .75415 1.14701 L p 1 g
F P
0 g
s
.74111 1.16706 m .76791 1.23867 L .74742 1.25864 L p 1 g
F P
0 g
s
.64534 .87482 m .61971 .80668 L .59347 .79937 L p 1 g
F P
0 g
s
.61971 .80668 m .64534 .87482 L .66482 .88618 L p 1 g
F P
0 g
s
.5479 1.05495 m
.54049 1.03401 L
s
.69094 .95524 m .66482 .88618 L .64534 .87482 L p 1 g
F P
0 g
s
.66482 .88618 m .69094 .95524 L .70263 .96995 L p 1 g
F P
0 g
s
.56172 .79697 m .53685 .72943 L .50149 .73188 L p 1 g
F P
0 g
s
.53685 .72943 m .56172 .79697 L .59347 .79937 L p 1 g
F P
0 g
s
.34058 .89931 m .36355 .96852 L .38234 .94655 L p 1 g
F P
0 g
s
.38234 .94655 m .35904 .87713 L .34058 .89931 L p 1 g
F P
0 g
s
.70698 1.45774 m .68069 1.38379 L .71572 1.36826 L p 1 g
F P
0 g
s
.77437 1.33139 m .74742 1.25864 L .76791 1.23867 L p 1 g
F P
0 g
s
.74742 1.25864 m .77437 1.33139 L .74743 1.35053 L p 1 g
F P
0 g
s
.55534 1.07602 m
.5479 1.05495 L
s
.70263 .96995 m .72916 1.03993 L .73247 1.05717 L p 1 g
F P
0 g
s
.72916 1.03993 m .70263 .96995 L .69094 .95524 L p 1 g
F P
0 g
s
.36133 .78751 m .38454 .85573 L .41577 .83629 L p 1 g
F P
0 g
s
.41577 .83629 m .39218 .76805 L .36133 .78751 L p 1 g
F P
0 g
s
.7424 1.44217 m .71572 1.36826 L .74743 1.35053 L p 1 g
F P
0 g
s
.71572 1.36826 m .7424 1.44217 L .70698 1.45774 L p 1 g
F P
0 g
s
.35269 .99003 m .37584 1.0603 L .38698 1.03909 L p 1 g
F P
0 g
s
.38698 1.03909 m .36355 .96852 L .35269 .99003 L p 1 g
F P
0 g
s
.75933 1.12811 m .73247 1.05717 L .72916 1.03993 L p 1 g
F P
0 g
s
.73247 1.05717 m .75933 1.12811 L .75415 1.14701 L p 1 g
F P
0 g
s
.52612 .79971 m .50149 .73188 L .46424 .73944 L p 1 g
F P
0 g
s
.50149 .73188 m .52612 .79971 L .56172 .79697 L p 1 g
F P
0 g
s
.619 .86788 m .59347 .79937 L .56172 .79697 L p 1 g
F P
0 g
s
.59347 .79937 m .619 .86788 L .64534 .87482 L p 1 g
F P
0 g
s
.56283 1.09721 m
.55534 1.07602 L
s
.78127 1.21895 m .75415 1.14701 L .75933 1.12811 L p 1 g
F P
0 g
s
.75415 1.14701 m .78127 1.21895 L .76791 1.23867 L p 1 g
F P
0 g
s
.39218 .76805 m .41577 .83629 L .45108 .81991 L p 1 g
F P
0 g
s
.45108 .81991 m .42712 .75172 L .39218 .76805 L p 1 g
F P
0 g
s
.77451 1.42453 m .74743 1.35053 L .77437 1.33139 L p 1 g
F P
0 g
s
.74743 1.35053 m .77451 1.42453 L .7424 1.44217 L p 1 g
F P
0 g
s
.48855 .80749 m .46424 .73944 L .42712 .75172 L p 1 g
F P
0 g
s
.46424 .73944 m .48855 .80749 L .52612 .79971 L p 1 g
F P
0 g
s
.42712 .75172 m .45108 .81991 L .48855 .80749 L p 1 g
F P
0 g
s
.35904 .87713 m .38234 .94655 L .4082 .92528 L p 1 g
F P
0 g
s
.4082 .92528 m .38454 .85573 L .35904 .87713 L p 1 g
F P
0 g
s
.79523 1.31168 m .76791 1.23867 L .78127 1.21895 L p 1 g
F P
0 g
s
.615 1 0 r
.76913 1.25622 m
.77533 1.25851 L
s
.76791 1.23867 m .79523 1.31168 L .77437 1.33139 L p 1 g
F P
0 g
s
.615 1 0 r
.78793 1.26318 m
.83226 1.27961 L
s
0 g
.57036 1.11852 m
.56283 1.09721 L
s
.67146 .94429 m .64534 .87482 L .619 .86788 L p 1 g
F P
0 g
s
.64534 .87482 m .67146 .94429 L .69094 .95524 L p 1 g
F P
0 g
s
.71757 1.02565 m .69094 .95524 L .67146 .94429 L p 1 g
F P
0 g
s
1 0 .231 r
.70124 .98247 m
.70232 .98046 L
s
.69094 .95524 m .71757 1.02565 L .72916 1.03993 L p 1 g
F P
0 g
s
.58709 .86584 m .56172 .79697 L .52612 .79971 L p 1 g
F P
0 g
s
.56172 .79697 m .58709 .86584 L .619 .86788 L p 1 g
F P
0 g
s
.36355 .96852 m .38698 1.03909 L .4061 1.01735 L p 1 g
F P
0 g
s
.4061 1.01735 m .38234 .94655 L .36355 .96852 L p 1 g
F P
0 g
s
.57793 1.13996 m
.57036 1.11852 L
s
.73379 1.53314 m .70698 1.45774 L .7424 1.44217 L p 1 g
F P
0 g
s
.80184 1.40556 m .77437 1.33139 L .79523 1.31168 L p 1 g
F P
0 g
s
.77437 1.33139 m .80184 1.40556 L .77451 1.42453 L p 1 g
F P
0 g
s
.72916 1.03993 m .75621 1.11129 L .75933 1.12811 L p 1 g
F P
0 g
s
.75621 1.11129 m .72916 1.03993 L .71757 1.02565 L p 1 g
F P
0 g
s
.38454 .85573 m .4082 .92528 L .43982 .90588 L p 1 g
F P
0 g
s
.43982 .90588 m .41577 .83629 L .38454 .85573 L p 1 g
F P
0 g
s
.7696 1.51754 m .7424 1.44217 L .77451 1.42453 L p 1 g
F P
0 g
s
.7424 1.44217 m .7696 1.51754 L .73379 1.53314 L p 1 g
F P
0 g
s
.37584 1.0603 m .39944 1.13195 L .41087 1.11106 L p 1 g
F P
0 g
s
.41087 1.11106 m .38698 1.03909 L .37584 1.0603 L p 1 g
F P
0 g
s
.78672 1.20044 m .75933 1.12811 L .75621 1.11129 L p 1 g
F P
0 g
s
.75933 1.12811 m .78672 1.20044 L .78127 1.21895 L p 1 g
F P
0 g
s
.58555 1.16152 m
.57793 1.13996 L
s
.55123 .86887 m .52612 .79971 L .48855 .80749 L p 1 g
F P
0 g
s
.52612 .79971 m .55123 .86887 L .58709 .86584 L p 1 g
F P
0 g
s
.64505 .93775 m .619 .86788 L .58709 .86584 L p 1 g
F P
0 g
s
.619 .86788 m .64505 .93775 L .67146 .94429 L p 1 g
F P
0 g
s
.80893 1.29231 m .78127 1.21895 L .78672 1.20044 L p 1 g
F P
0 g
s
.78127 1.21895 m .80893 1.29231 L .79523 1.31168 L p 1 g
F P
0 g
s
.41577 .83629 m .43982 .90588 L .47552 .88944 L p 1 g
F P
0 g
s
.47552 .88944 m .45108 .81991 L .41577 .83629 L p 1 g
F P
0 g
s
.80212 1.49998 m .77451 1.42453 L .80184 1.40556 L p 1 g
F P
0 g
s
.77451 1.42453 m .80212 1.49998 L .7696 1.51754 L p 1 g
F P
0 g
s
.51335 .87688 m .48855 .80749 L .45108 .81991 L p 1 g
F P
0 g
s
.48855 .80749 m .51335 .87688 L .55123 .86887 L p 1 g
F P
0 g
s
.59322 1.18321 m
.58555 1.16152 L
s
.45108 .81991 m .47552 .88944 L .51335 .87688 L p 1 g
F P
0 g
s
.38234 .94655 m .4061 1.01735 L .43233 .99622 L p 1 g
F P
0 g
s
.43233 .99622 m .4082 .92528 L .38234 .94655 L p 1 g
F P
0 g
s
.82309 1.38614 m .79523 1.31168 L .80893 1.29231 L p 1 g
F P
0 g
s
.79523 1.31168 m .82309 1.38614 L .80184 1.40556 L p 1 g
F P
0 g
s
.69811 1.01513 m .67146 .94429 L .64505 .93775 L p 1 g
F P
0 g
s
1 0 .231 r
.69216 .99932 m
.69727 .98983 L
s
.67146 .94429 m .69811 1.01513 L .71757 1.02565 L p 1 g
F P
0 g
s
1 0 .692 r
.70129 .94895 m
.71339 .93533 L
s
0 g
.60093 1.20503 m
.59322 1.18321 L
s
.74473 1.09746 m .71757 1.02565 L .69811 1.01513 L p 1 g
F P
0 g
s
.71757 1.02565 m .74473 1.09746 L .75621 1.11129 L p 1 g
F P
0 g
s
.61296 .93607 m .58709 .86584 L .55123 .86887 L p 1 g
F P
0 g
s
.58709 .86584 m .61296 .93607 L .64505 .93775 L p 1 g
F P
0 g
s
.38698 1.03909 m .41087 1.11106 L .43034 1.08956 L p 1 g
F P
0 g
s
.43034 1.08956 m .4061 1.01735 L .38698 1.03909 L p 1 g
F P
0 g
s
.76113 1.61003 m .73379 1.53314 L .7696 1.51754 L p 1 g
F P
0 g
s
.82987 1.48121 m .80184 1.40556 L .82309 1.38614 L p 1 g
F P
0 g
s
.80184 1.40556 m .82987 1.48121 L .80212 1.49998 L p 1 g
F P
0 g
s
.75621 1.11129 m .7838 1.18407 L .78672 1.20044 L p 1 g
F P
0 g
s
.7838 1.18407 m .75621 1.11129 L .74473 1.09746 L p 1 g
F P
0 g
s
.4082 .92528 m .43233 .99622 L .46435 .97687 L p 1 g
F P
0 g
s
.46435 .97687 m .43982 .90588 L .4082 .92528 L p 1 g
F P
0 g
s
.79734 1.59441 m .7696 1.51754 L .80212 1.49998 L p 1 g
F P
0 g
s
.7696 1.51754 m .79734 1.59441 L .76113 1.61003 L p 1 g
F P
0 g
s
.60868 1.22698 m
.60093 1.20503 L
s
.39944 1.13195 m .42352 1.20502 L .43524 1.18447 L p 1 g
F P
0 g
s
.43524 1.18447 m .41087 1.11106 L .39944 1.13195 L p 1 g
F P
0 g
s
.81465 1.27422 m .78672 1.20044 L .7838 1.18407 L p 1 g
F P
0 g
s
.78672 1.20044 m .81465 1.27422 L .80893 1.29231 L p 1 g
F P
0 g
s
.57685 .93941 m .55123 .86887 L .51335 .87688 L p 1 g
F P
0 g
s
.55123 .86887 m .57685 .93941 L .61296 .93607 L p 1 g
F P
0 g
s
.67161 1.00901 m .64505 .93775 L .61296 .93607 L p 1 g
F P
0 g
s
.64505 .93775 m .67161 1.00901 L .69811 1.01513 L p 1 g
F P
0 g
s
1 0 .692 r
.6809 .97189 m
.70129 .94895 L
s
.83713 1.36713 m .80893 1.29231 L .81465 1.27422 L p 1 g
F P
0 g
s
.80893 1.29231 m .83713 1.36713 L .82309 1.38614 L p 1 g
F P
0 g
s
.615 1 0 r
.83226 1.27961 m
.87752 1.29638 L
s
.43982 .90588 m .46435 .97687 L .50044 .96037 L p 1 g
F P
0 g
s
.50044 .96037 m .47552 .88944 L .43982 .90588 L p 1 g
F P
0 g
s
.61648 1.24906 m
.60868 1.22698 L
s
.83028 1.57694 m .80212 1.49998 L .82987 1.48121 L p 1 g
F P
0 g
s
.80212 1.49998 m .83028 1.57694 L .79734 1.59441 L p 1 g
F P
0 g
s
.53864 .94765 m .51335 .87688 L .47552 .88944 L p 1 g
F P
0 g
s
.51335 .87688 m .53864 .94765 L .57685 .93941 L p 1 g
F P
0 g
s
.47552 .88944 m .50044 .96037 L .53864 .94765 L p 1 g
F P
0 g
s
.4061 1.01735 m .43034 1.08956 L .45695 1.06858 L p 1 g
F P
0 g
s
.45695 1.06858 m .43233 .99622 L .4061 1.01735 L p 1 g
F P
0 g
s
.8515 1.46208 m .82309 1.38614 L .83713 1.36713 L p 1 g
F P
0 g
s
.82309 1.38614 m .8515 1.46208 L .82987 1.48121 L p 1 g
F P
0 g
s
.72528 1.08739 m .69811 1.01513 L .67161 1.00901 L p 1 g
F P
0 g
s
.69811 1.01513 m .72528 1.08739 L .74473 1.09746 L p 1 g
F P
0 g
s
.62433 1.27126 m
.61648 1.24906 L
s
.77243 1.1707 m .74473 1.09746 L .72528 1.08739 L p 1 g
F P
0 g
s
.74473 1.09746 m .77243 1.1707 L .7838 1.18407 L p 1 g
F P
0 g
s
.63935 1.00771 m .61296 .93607 L .57685 .93941 L p 1 g
F P
0 g
s
.61296 .93607 m .63935 1.00771 L .67161 1.00901 L p 1 g
F P
0 g
s
1 0 .692 r
.65403 1.00214 m
.6809 .97189 L
s
.41087 1.11106 m .43524 1.18447 L .45506 1.16323 L p 1 g
F P
0 g
s
.45506 1.16323 m .43034 1.08956 L .41087 1.11106 L p 1 g
F P
0 g
s
.78902 1.68847 m .76113 1.61003 L .79734 1.59441 L p 1 g
F P
0 g
s
.85845 1.55838 m .82987 1.48121 L .8515 1.46208 L p 1 g
F P
0 g
s
.82987 1.48121 m .85845 1.55838 L .83028 1.57694 L p 1 g
F P
0 g
s
.63223 1.29361 m
.62433 1.27126 L
s
.7838 1.18407 m .81194 1.2583 L .81465 1.27422 L p 1 g
F P
0 g
s
.81194 1.2583 m .7838 1.18407 L .77243 1.1707 L p 1 g
F P
0 g
s
.43233 .99622 m .45695 1.06858 L .48937 1.04928 L p 1 g
F P
0 g
s
.48937 1.04928 m .46435 .97687 L .43233 .99622 L p 1 g
F P
0 g
s
.82564 1.67282 m .79734 1.59441 L .83028 1.57694 L p 1 g
F P
0 g
s
.79734 1.59441 m .82564 1.67282 L .78902 1.68847 L p 1 g
F P
0 g
s
.42352 1.20502 m .44808 1.27956 L .4601 1.25937 L p 1 g
F P
0 g
s
.4601 1.25937 m .43524 1.18447 L .42352 1.20502 L p 1 g
F P
0 g
s
.84315 1.34947 m .81465 1.27422 L .81194 1.2583 L p 1 g
F P
0 g
s
.81465 1.27422 m .84315 1.34947 L .83713 1.36713 L p 1 g
F P
0 g
s
.60298 1.01137 m .57685 .93941 L .53864 .94765 L p 1 g
F P
0 g
s
.57685 .93941 m .60298 1.01137 L .63935 1.00771 L p 1 g
F P
0 g
s
.64017 1.31608 m
.63223 1.29361 L
s
.6987 1.08171 m .67161 1.00901 L .63935 1.00771 L p 1 g
F P
0 g
s
1 0 .231 r
.67788 1.02584 m
.68019 1.02155 L
s
.67161 1.00901 m .6987 1.08171 L .72528 1.08739 L p 1 g
F P
0 g
s
.8659 1.44346 m .83713 1.36713 L .84315 1.34947 L p 1 g
F P
0 g
s
.83713 1.36713 m .8659 1.44346 L .8515 1.46208 L p 1 g
F P
0 g
s
.46435 .97687 m .48937 1.04928 L .52587 1.03273 L p 1 g
F P
0 g
s
.52587 1.03273 m .50044 .96037 L .46435 .97687 L p 1 g
F P
0 g
s
.85901 1.65545 m .83028 1.57694 L .85845 1.55838 L p 1 g
F P
0 g
s
.83028 1.57694 m .85901 1.65545 L .82564 1.67282 L p 1 g
F P
0 g
s
.56445 1.01985 m .53864 .94765 L .50044 .96037 L p 1 g
F P
0 g
s
.53864 .94765 m .56445 1.01985 L .60298 1.01137 L p 1 g
F P
0 g
s
.50044 .96037 m .52587 1.03273 L .56445 1.01985 L p 1 g
F P
0 g
s
.43034 1.08956 m .45506 1.16323 L .48207 1.14241 L p 1 g
F P
0 g
s
.48207 1.14241 m .45695 1.06858 L .43034 1.08956 L p 1 g
F P
0 g
s
.88049 1.53956 m .8515 1.46208 L .8659 1.44346 L p 1 g
F P
0 g
s
.8515 1.46208 m .88049 1.53956 L .85845 1.55838 L p 1 g
F P
0 g
s
.64816 1.33869 m
.64017 1.31608 L
s
.75301 1.16111 m .72528 1.08739 L .6987 1.08171 L p 1 g
F P
0 g
s
.72528 1.08739 m .75301 1.16111 L .77243 1.1707 L p 1 g
F P
0 g
s
.8007 1.24543 m .77243 1.1707 L .75301 1.16111 L p 1 g
F P
0 g
s
.77243 1.1707 m .8007 1.24543 L .81194 1.2583 L p 1 g
F P
0 g
s
.66627 1.0808 m .63935 1.00771 L .60298 1.01137 L p 1 g
F P
0 g
s
1 0 .231 r
.65897 1.06097 m
.66825 1.04374 L
s
.63935 1.00771 m .66627 1.0808 L .6987 1.08171 L p 1 g
F P
0 g
s
.385 1 0 r
.68382 1.08129 m
.72844 1.19986 L
s
.67333 1.05343 m
.67489 1.05756 L
s
.43524 1.18447 m .4601 1.25937 L .48028 1.2384 L p 1 g
F P
0 g
s
.48028 1.2384 m .45506 1.16323 L .43524 1.18447 L p 1 g
F P
0 g
s
.6562 1.36144 m
.64816 1.33869 L
s
.88761 1.63711 m .85845 1.55838 L .88049 1.53956 L p 1 g
F P
0 g
s
.85845 1.55838 m .88761 1.63711 L .85901 1.65545 L p 1 g
F P
0 g
s
.81194 1.2583 m .84065 1.33405 L .84315 1.34947 L p 1 g
F P
0 g
s
.84065 1.33405 m .81194 1.2583 L .8007 1.24543 L p 1 g
F P
0 g
s
1 0 .923 r
.80129 1.03093 m
.91505 1.31029 L
s
.45695 1.06858 m .48207 1.14241 L .5149 1.12316 L p 1 g
F P
0 g
s
.5149 1.12316 m .48937 1.04928 L .45695 1.06858 L p 1 g
F P
0 g
s
.44808 1.27956 m .47313 1.35562 L .48547 1.3358 L p 1 g
F P
0 g
s
.48547 1.3358 m .4601 1.25937 L .44808 1.27956 L p 1 g
F P
0 g
s
.87222 1.42626 m .84315 1.34947 L .84065 1.33405 L p 1 g
F P
0 g
s
.84315 1.34947 m .87222 1.42626 L .8659 1.44346 L p 1 g
F P
0 g
s
.66428 1.38432 m
.6562 1.36144 L
s
.62964 1.08479 m .60298 1.01137 L .56445 1.01985 L p 1 g
F P
0 g
s
.60298 1.01137 m .62964 1.08479 L .66627 1.0808 L p 1 g
F P
0 g
s
.385 1 0 r
.66507 1.03146 m
.67333 1.05343 L
s
.65403 1.00214 m
.66507 1.03146 L
s
.72635 1.15588 m .6987 1.08171 L .66627 1.0808 L p 1 g
F P
0 g
s
.6987 1.08171 m .72635 1.15588 L .75301 1.16111 L p 1 g
F P
0 g
s
.89526 1.52134 m .8659 1.44346 L .87222 1.42626 L p 1 g
F P
0 g
s
.8659 1.44346 m .89526 1.52134 L .88049 1.53956 L p 1 g
F P
0 g
s
.48937 1.04928 m .5149 1.12316 L .55181 1.10656 L p 1 g
F P
0 g
s
.55181 1.10656 m .52587 1.03273 L .48937 1.04928 L p 1 g
F P
0 g
s
.59078 1.09353 m .56445 1.01985 L .52587 1.03273 L p 1 g
F P
0 g
s
.56445 1.01985 m .59078 1.09353 L .62964 1.08479 L p 1 g
F P
0 g
s
.67242 1.40734 m
.66428 1.38432 L
s
.52587 1.03273 m .55181 1.10656 L .59078 1.09353 L p 1 g
F P
0 g
s
.45506 1.16323 m .48028 1.2384 L .5077 1.21775 L p 1 g
F P
0 g
s
.5077 1.21775 m .48207 1.14241 L .45506 1.16323 L p 1 g
F P
0 g
s
1 .231 0 r
.65403 1.00214 m
.71687 1.07633 L
s
0 0 1 r
.03 w
.91505 1.31029 Mdot
.5 Mabswid
.91007 1.61861 m .88049 1.53956 L .89526 1.52134 L p 1 g
F P
0 g
s
.88049 1.53956 m .91007 1.61861 L .88761 1.63711 L p 1 g
F P
0 g
s
.7813 1.23633 m .75301 1.16111 L .72635 1.15588 L p 1 g
F P
0 g
s
.75301 1.16111 m .7813 1.23633 L .8007 1.24543 L p 1 g
F P
0 g
s
.6806 1.4305 m
.67242 1.40734 L
s
.82954 1.32169 m .8007 1.24543 L .7813 1.23633 L p 1 g
F P
0 g
s
.8007 1.24543 m .82954 1.32169 L .84065 1.33405 L p 1 g
F P
0 g
s
.69374 1.15538 m .66627 1.0808 L .62964 1.08479 L p 1 g
F P
0 g
s
.66627 1.0808 m .69374 1.15538 L .72635 1.15588 L p 1 g
F P
0 g
s
1 .231 0 r
.71687 1.07633 m
.77993 1.15077 L
s
.4601 1.25937 m .48547 1.3358 L .50603 1.31511 L p 1 g
F P
0 g
s
.50603 1.31511 m .48028 1.2384 L .4601 1.25937 L p 1 g
F P
0 g
s
.84065 1.33405 m .86995 1.41134 L .87222 1.42626 L p 1 g
F P
0 g
s
.86995 1.41134 m .84065 1.33405 L .82954 1.32169 L p 1 g
F P
0 g
s
0 1 1 r
.83272 1.32318 m
.83798 1.32236 L
s
.83798 1.32236 m
.91505 1.31029 L
s
.48207 1.14241 m .5077 1.21775 L .54096 1.19856 L p 1 g
F P
0 g
s
.54096 1.19856 m .5149 1.12316 L .48207 1.14241 L p 1 g
F P
0 g
s
.68884 1.45381 m
.6806 1.4305 L
s
.47313 1.35562 m .4987 1.43324 L .51137 1.41381 L p 1 g
F P
0 g
s
.51137 1.41381 m .48547 1.3358 L .47313 1.35562 L p 1 g
F P
0 g
s
.90189 1.50462 m .87222 1.42626 L .86995 1.41134 L p 1 g
F P
0 g
s
.87222 1.42626 m .90189 1.50462 L .89526 1.52134 L p 1 g
F P
0 g
s
.65685 1.15972 m .62964 1.08479 L .59078 1.09353 L p 1 g
F P
0 g
s
1 0 .231 r
.63629 1.1031 m
.64 1.0962 L
s
.62964 1.08479 m .65685 1.15972 L .69374 1.15538 L p 1 g
F P
0 g
s
.75457 1.23158 m .72635 1.15588 L .69374 1.15538 L p 1 g
F P
0 g
s
.72635 1.15588 m .75457 1.23158 L .7813 1.23633 L p 1 g
F P
0 g
s
1 .231 0 r
.77993 1.15077 m
.91505 1.31029 L
s
.92522 1.60082 m .89526 1.52134 L .90189 1.50462 L p 1 g
F P
0 g
s
.89526 1.52134 m .92522 1.60082 L .91007 1.61861 L p 1 g
F P
0 g
s
.5149 1.12316 m .54096 1.19856 L .57829 1.18191 L p 1 g
F P
0 g
s
.57829 1.18191 m .55181 1.10656 L .5149 1.12316 L p 1 g
F P
0 g
s
.69712 1.47725 m
.68884 1.45381 L
s
.61765 1.16872 m .59078 1.09353 L .55181 1.10656 L p 1 g
F P
0 g
s
1 0 .231 r
.61099 1.15008 m
.62369 1.1265 L
s
.59078 1.09353 m .61765 1.16872 L .65685 1.15972 L p 1 g
F P
0 g
s
.55181 1.10656 m .57829 1.18191 L .61765 1.16872 L p 1 g
F P
0 g
s
.48028 1.2384 m .50603 1.31511 L .53386 1.29465 L p 1 g
F P
0 g
s
.53386 1.29465 m .5077 1.21775 L .48028 1.2384 L p 1 g
F P
0 g
s
.81017 1.31311 m .7813 1.23633 L .75457 1.23158 L p 1 g
F P
0 g
s
.7813 1.23633 m .81017 1.31311 L .82954 1.32169 L p 1 g
F P
0 g
s
.70546 1.50084 m
.69712 1.47725 L
s
.85898 1.39952 m .82954 1.32169 L .81017 1.31311 L p 1 g
F P
0 g
s
0 1 1 r
.83025 1.32357 m
.83038 1.32355 L
s
.82954 1.32169 m .85898 1.39952 L .86995 1.41134 L p 1 g
F P
0 g
s
.72178 1.23151 m .69374 1.15538 L .65685 1.15972 L p 1 g
F P
0 g
s
.69374 1.15538 m .72178 1.23151 L .75457 1.23158 L p 1 g
F P
0 g
s
.48547 1.3358 m .51137 1.41381 L .53231 1.39343 L p 1 g
F P
0 g
s
.53231 1.39343 m .50603 1.31511 L .48547 1.3358 L p 1 g
F P
0 g
s
.71384 1.52458 m
.70546 1.50084 L
s
.86995 1.41134 m .89986 1.49024 L .90189 1.50462 L p 1 g
F P
0 g
s
.89986 1.49024 m .86995 1.41134 L .85898 1.39952 L p 1 g
F P
0 g
s
.5077 1.21775 m .53386 1.29465 L .56756 1.27553 L p 1 g
F P
0 g
s
.56756 1.27553 m .54096 1.19856 L .5077 1.21775 L p 1 g
F P
0 g
s
1 0 .231 r
.55813 1.24825 m
.59728 1.17554 L
s
0 .769 1 r
.62988 1.05693 m
.65403 1.00214 L
s
0 0 1 r
.03 w
.65403 1.00214 Mdot
.5 Mabswid
.4987 1.43324 m .5248 1.51246 L .5378 1.49345 L p 1 g
F P
0 g
s
.5378 1.49345 m .51137 1.41381 L .4987 1.43324 L p 1 g
F P
0 g
s
.93218 1.5846 m .90189 1.50462 L .89986 1.49024 L p 1 g
F P
0 g
s
.90189 1.50462 m .93218 1.5846 L .92522 1.60082 L p 1 g
F P
0 g
s
.68462 1.2362 m .65685 1.15972 L .61765 1.16872 L p 1 g
F P
0 g
s
.65685 1.15972 m .68462 1.2362 L .72178 1.23151 L p 1 g
F P
0 g
s
.72228 1.54846 m
.71384 1.52458 L
s
.78337 1.30884 m .75457 1.23158 L .72178 1.23151 L p 1 g
F P
0 g
s
.75457 1.23158 m .78337 1.30884 L .81017 1.31311 L p 1 g
F P
0 g
s
.54096 1.19856 m .56756 1.27553 L .60532 1.25882 L p 1 g
F P
0 g
s
.60532 1.25882 m .57829 1.18191 L .54096 1.19856 L p 1 g
F P
0 g
s
0 .769 1 r
.55427 1.22847 m
.56668 1.20033 L
s
.64507 1.24547 m .61765 1.16872 L .57829 1.18191 L p 1 g
F P
0 g
s
.61765 1.16872 m .64507 1.24547 L .68462 1.2362 L p 1 g
F P
0 g
s
.57829 1.18191 m .60532 1.25882 L .64507 1.24547 L p 1 g
F P
0 g
s
0 .769 1 r
.56668 1.20033 m
.62988 1.05693 L
s
.50603 1.31511 m .53231 1.39343 L .56057 1.37316 L p 1 g
F P
0 g
s
.56057 1.37316 m .53386 1.29465 L .50603 1.31511 L p 1 g
F P
0 g
s
0 .538 1 r
.52275 1.36002 m
.53033 1.35622 L
s
.48878 1.37705 m
.52275 1.36002 L
s
1 0 .231 r
.48878 1.37705 m
.52099 1.31723 L
s
0 .538 1 r
.53033 1.35622 m
.53214 1.35531 L
s
1 0 .231 r
.52099 1.31723 m
.53229 1.29624 L
s
0 .538 1 r
.55124 1.34573 m
.71114 1.26555 L
s
0 g
.73077 1.57249 m
.72228 1.54846 L
s
.83965 1.39148 m .81017 1.31311 L .78337 1.30884 L p 1 g
F P
0 g
s
0 1 1 r
.81501 1.32596 m
.81723 1.32561 L
s
.81017 1.31311 m .83965 1.39148 L .85898 1.39952 L p 1 g
F P
0 g
s
.88903 1.47898 m .85898 1.39952 L .83965 1.39148 L p 1 g
F P
0 g
s
.85898 1.39952 m .88903 1.47898 L .89986 1.49024 L p 1 g
F P
0 g
s
.7504 1.30922 m .72178 1.23151 L .68462 1.2362 L p 1 g
F P
0 g
s
.72178 1.23151 m .7504 1.30922 L .78337 1.30884 L p 1 g
F P
0 g
s
.51137 1.41381 m .5378 1.49345 L .55914 1.47339 L p 1 g
F P
0 g
s
.55914 1.47339 m .53231 1.39343 L .51137 1.41381 L p 1 g
F P
0 g
s
.73932 1.59667 m
.73077 1.57249 L
s
.89986 1.49024 m .93039 1.57078 L .93218 1.5846 L p 1 g
F P
0 g
s
.93039 1.57078 m .89986 1.49024 L .88903 1.47898 L p 1 g
F P
0 g
s
.53386 1.29465 m .56057 1.37316 L .59472 1.35411 L p 1 g
F P
0 g
s
0 1 1 r
.54064 1.36893 m
.56033 1.36584 L
s
.59472 1.35411 m .56756 1.27553 L .53386 1.29465 L p 1 g
F P
0 g
s
1 0 .231 r
.53229 1.29624 m
.53879 1.28417 L
s
.53879 1.28417 m
.54031 1.28135 L
s
.5248 1.51246 m .55145 1.59334 L .5648 1.57477 L p 1 g
F P
0 g
s
.5648 1.57477 m .5378 1.49345 L .5248 1.51246 L p 1 g
F P
0 g
s
.74791 1.621 m
.73932 1.59667 L
s
.71297 1.31429 m .68462 1.2362 L .64507 1.24547 L p 1 g
F P
0 g
s
.68462 1.2362 m .71297 1.31429 L .7504 1.30922 L p 1 g
F P
0 g
s
.81277 1.38773 m .78337 1.30884 L .7504 1.30922 L p 1 g
F P
0 g
s
0 1 1 r
.79114 1.3297 m
.79695 1.32879 L
s
.78337 1.30884 m .81277 1.38773 L .83965 1.39148 L p 1 g
F P
0 g
s
.56756 1.27553 m .59472 1.35411 L .63292 1.33736 L p 1 g
F P
0 g
s
.63292 1.33736 m .60532 1.25882 L .56756 1.27553 L p 1 g
F P
0 g
s
.67308 1.32383 m .64507 1.24547 L .60532 1.25882 L p 1 g
F P
0 g
s
.64507 1.24547 m .67308 1.32383 L .71297 1.31429 L p 1 g
F P
0 g
s
.75657 1.64548 m
.74791 1.621 L
s
.60532 1.25882 m .63292 1.33736 L .67308 1.32383 L p 1 g
F P
0 g
s
.53231 1.39343 m .55914 1.47339 L .58785 1.45332 L p 1 g
F P
0 g
s
.58785 1.45332 m .56057 1.37316 L .53231 1.39343 L p 1 g
F P
0 g
s
0 .769 1 r
.48878 1.37705 m
.55427 1.22847 L
s
0 1 1 r
.48878 1.37705 m
.54064 1.36893 L
s
.86974 1.4715 m .83965 1.39148 L .81277 1.38773 L p 1 g
F P
0 g
s
.83965 1.39148 m .86974 1.4715 L .88903 1.47898 L p 1 g
F P
0 g
s
.76527 1.67011 m
.75657 1.64548 L
s
.91972 1.56011 m .88903 1.47898 L .86974 1.4715 L p 1 g
F P
0 g
s
.88903 1.47898 m .91972 1.56011 L .93039 1.57078 L p 1 g
F P
0 g
s
.77963 1.38857 m .7504 1.30922 L .71297 1.31429 L p 1 g
F P
0 g
s
0 1 1 r
.75976 1.33461 m
.76938 1.3331 L
s
.7504 1.30922 m .77963 1.38857 L .81277 1.38773 L p 1 g
F P
0 g
s
.5378 1.49345 m .5648 1.57477 L .58655 1.55504 L p 1 g
F P
0 g
s
.58655 1.55504 m .55914 1.47339 L .5378 1.49345 L p 1 g
F P
0 g
s
.56057 1.37316 m .58785 1.45332 L .62245 1.43436 L p 1 g
F P
0 g
s
.62245 1.43436 m .59472 1.35411 L .56057 1.37316 L p 1 g
F P
0 g
s
0 1 1 r
.5968 1.36013 m
.73473 1.33853 L
s
.56033 1.36584 m
.57283 1.36389 L
s
.57283 1.36389 m
.57758 1.36314 L
s
0 g
.77403 1.6949 m
.76527 1.67011 L
s
.55145 1.59334 m .57866 1.67593 L .59237 1.65782 L p 1 g
F P
0 g
s
.59237 1.65782 m .5648 1.57477 L .55145 1.59334 L p 1 g
F P
0 g
s
.74193 1.39403 m .71297 1.31429 L .67308 1.32383 L p 1 g
F P
0 g
s
.71297 1.31429 m .74193 1.39403 L .77963 1.38857 L p 1 g
F P
0 g
s
.8428 1.46829 m .81277 1.38773 L .77963 1.38857 L p 1 g
F P
0 g
s
.81277 1.38773 m .8428 1.46829 L .86974 1.4715 L p 1 g
F P
0 g
s
.59472 1.35411 m .62245 1.43436 L .6611 1.41756 L p 1 g
F P
0 g
s
.6611 1.41756 m .63292 1.33736 L .59472 1.35411 L p 1 g
F P
0 g
s
.78284 1.71985 m
.77403 1.6949 L
s
.70168 1.40386 m .67308 1.32383 L .63292 1.33736 L p 1 g
F P
0 g
s
.67308 1.32383 m .70168 1.40386 L .74193 1.39403 L p 1 g
F P
0 g
s
.63292 1.33736 m .6611 1.41756 L .70168 1.40386 L p 1 g
F P
0 g
s
.55914 1.47339 m .58655 1.55504 L .6157 1.5352 L p 1 g
F P
0 g
s
.6157 1.5352 m .58785 1.45332 L .55914 1.47339 L p 1 g
F P
0 g
s
.90048 1.55322 m .86974 1.4715 L .8428 1.46829 L p 1 g
F P
0 g
s
.86974 1.4715 m .90048 1.55322 L .91972 1.56011 L p 1 g
F P
0 g
s
.79172 1.74495 m
.78284 1.71985 L
s
.80948 1.46961 m .77963 1.38857 L .74193 1.39403 L p 1 g
F P
0 g
s
.77963 1.38857 m .80948 1.46961 L .8428 1.46829 L p 1 g
F P
0 g
s
.5648 1.57477 m .59237 1.65782 L .61454 1.63845 L p 1 g
F P
0 g
s
.61454 1.63845 m .58655 1.55504 L .5648 1.57477 L p 1 g
F P
0 g
s
.80064 1.77021 m
.79172 1.74495 L
s
.58785 1.45332 m .6157 1.5352 L .65078 1.51633 L p 1 g
F P
0 g
s
.65078 1.51633 m .62245 1.43436 L .58785 1.45332 L p 1 g
F P
0 g
s
0 0 1 r
.03 w
.48878 1.37705 Mdot
.5 Mabswid
.7715 1.47548 m .74193 1.39403 L .70168 1.40386 L p 1 g
F P
0 g
s
.74193 1.39403 m .7715 1.47548 L .80948 1.46961 L p 1 g
F P
0 g
s
.87347 1.55058 m .8428 1.46829 L .80948 1.46961 L p 1 g
F P
0 g
s
.8428 1.46829 m .87347 1.55058 L .90048 1.55322 L p 1 g
F P
0 g
s
.62245 1.43436 m .65078 1.51633 L .68989 1.49948 L p 1 g
F P
0 g
s
.68989 1.49948 m .6611 1.41756 L .62245 1.43436 L p 1 g
F P
0 g
s
.73089 1.48561 m .70168 1.40386 L .6611 1.41756 L p 1 g
F P
0 g
s
.70168 1.40386 m .73089 1.48561 L .7715 1.47548 L p 1 g
F P
0 g
s
.6611 1.41756 m .68989 1.49948 L .73089 1.48561 L p 1 g
F P
0 g
s
.58655 1.55504 m .61454 1.63845 L .64416 1.61885 L p 1 g
F P
0 g
s
.64416 1.61885 m .6157 1.5352 L .58655 1.55504 L p 1 g
F P
0 g
s
.83998 1.55241 m .80948 1.46961 L .7715 1.47548 L p 1 g
F P
0 g
s
.80948 1.46961 m .83998 1.55241 L .87347 1.55058 L p 1 g
F P
0 g
s
.6157 1.5352 m .64416 1.61885 L .67972 1.60007 L p 1 g
F P
0 g
s
.67972 1.60007 m .65078 1.51633 L .6157 1.5352 L p 1 g
F P
0 g
s
.80172 1.55869 m .7715 1.47548 L .73089 1.48561 L p 1 g
F P
0 g
s
.7715 1.47548 m .80172 1.55869 L .83998 1.55241 L p 1 g
F P
0 g
s
.65078 1.51633 m .67972 1.60007 L .7193 1.58318 L p 1 g
F P
0 g
s
.7193 1.58318 m .68989 1.49948 L .65078 1.51633 L p 1 g
F P
0 g
s
.76074 1.56913 m .73089 1.48561 L .68989 1.49948 L p 1 g
F P
0 g
s
.73089 1.48561 m .76074 1.56913 L .80172 1.55869 L p 1 g
F P
0 g
s
.68989 1.49948 m .7193 1.58318 L .76074 1.56913 L p 1 g
F P
0 g
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 551.813},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0002/A000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00M7oo4000i7oo001^Ool60002Ool00`00
Oomoo`08Ool00`00Oomoo`05003OOol006Uoo`D000Uoo`03001oogoo00Qoo`03001oogoo00Aoo`@0
0=]oo`00IWoo0`0000=oo`00Ool02goo00<007ooOol027oo00<007ooOol01Woo00<007oo00000P00
f7oo001SOol30005Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`07Ool01000Oomoogoo
0`00eGoo001POol30008Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomo
o`04Ool2003COol005ioo`8000]oo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Moo`03
001oogoo00Aoo`<00=5oo`00G7oo0`003Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
1goo00<007ooOol01Goo00<007oo0000d7oo001JOol20003Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`05Ool01000Oomoo`00cgoo001HOol20005
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`04
Ool01000Oomoogoo0P00cGoo001FOol20007Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`3:Ool005Aoo`80
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
00Aoo`03001oogoo009oo`800<]oo`00Dgoo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0
2Woo00<007ooOol027oo00<007ooOol01goo00<007ooOol017oo00<007ooOol00goo00<007ooOol0
bGoo001AOol3000<Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool2003:Ool004moo`8000=oo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Aoo`03001o
ogoo009oo`800<Yoo`00CWoo00<007ooOol00goo00<007ooOol02Woo00<007ooOol02goo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol017oo00<007ooOol00goo0P00bGoo
001<Ool20006Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool20039Ool004Yoo`8000Uoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
00Aoo`03001oogoo009oo`03001oo`000<Qoo`00BGoo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol02goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01Goo00<0
07ooOol00Woo0P00b7oo0018Ool2000;Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool00037
Ool004Moo`04001oogoo000;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool@0007
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool00037Ool004Ioo`05001oogooOol0000;Ool0
0`00Oomoo`0:Ool00`00Oomoo`0;Ool01000Oomoogoo1P000Woo00<007ooOol027oo00<007ooOol0
1P000Woo00<007ooOol017oo00<007ooOol00Woo0P00agoo0015Ool00`00Oomoo`02Ool00`00Oomo
o`09Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool50009Ool00`00Oomoo`08Ool00`00Oomoo`05Ool4
0005Ool00`00Oomoo`02Ool00`00Ool00036Ool004Aoo`03001oogoo00Aoo`03001oogoo00Uoo`03
001oogoo00Yoo`03001oogoo00Ioo`<00003Ool007oo00]oo`03001oogoo00Qoo`03001oogoo00Mo
o`04001oo`000003Ool00`00Oomoo`03Ool20036Ool004=oo`03001oogoo00Eoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00=oo`<000Eoo`03001oogoo00Uoo`03001oogoo00Uoo`03001o
ogoo00Moo`03001oogoo00<00003Ool007oo00=oo`03001oo`000<Eoo`00@Woo00<007ooOol01Woo
00<007ooOol02Woo00<007ooOol02Woo00<007oo00000P0027oo00<007ooOol02Woo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol00goo0P0017oo00<007oo0000aGoo0011Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool2000;Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00
Oomoo`07Ool00`00Oomoo`04Ool30003Ool20035Ool0041oo`8000Yoo`03001oogoo00Uoo`03001o
ogoo00Qoo`<000eoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Ao
o`03001oo`00009oo`03001oo`000<Aoo`00@7oo00<007oo00002Goo00<007ooOol02Woo00<007oo
Ool01Goo0P000goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01goo
00<007ooOol017oo00P007ooOol007oo001oo`00a7oo000oOol01000Oomoo`002Woo00<007ooOol0
2Goo00<007ooOol00goo0P001Goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol01Woo00<007ooOol01Goo00<007ooOol00`00aGoo000nOol01@00Oomoogoo00002Woo00<0
07ooOol02Goo00@007ooOomoo`8000Moo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`03001oo`000<=oo`00?Woo00<007oo
Ool00Woo00<007ooOol027oo00<007ooOol02Goo0`002Woo00<007ooOol02Woo00<007ooOol02Woo
00<007ooOol027oo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo0`00`goo000mOol0
0`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
0`00Ool00032Ool003eoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00Moo`<000aoo`03
001oogoo00]oo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Aoo`03
001oogoo009oo`<00<9oo`00?7oo00<007ooOol01Goo00<007ooOol027oo00<007ooOol017oo0P00
0goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
1Woo00<007ooOol01Goo00<007ooOol00Woo0P00`Woo000lOol00`00Oomoo`05Ool00`00Oomoo`08
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool30031Ool003]o
o`03001oo`0000Ioo`03001oogoo00Qoo`04001oogooOol20006Ool00`00Oomoo`0:Ool00`00Oomo
o`0;Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Ool00031Ool003]oo`03001oo`0000Moo`03001oogoo00Qoo`<000Uoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo
00Eoo`03001oogoo009oo`800<5oo`00>Woo00@007ooOol000Moo`03001oogoo00Qoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Moo`03001oogoo00Aoo`03001oogoo009oo`03001oo`000<1oo`00>Woo00D007ooOomoo`0000Mo
o`03001oogoo00Ioo`8000]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Uoo`03001o
ogoo00Yoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo009oo`800<1oo`00>Woo00D007oo
Oomoo`0000Moo`03001oogoo00Eoo`04001oogoo000;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`04Ool80006Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Ool0
002oOol003Uoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Aoo`05001oogooOol0000;
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool90005Ool00`00Oomoo`050002Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool0002oOol003Uoo`03001oogoo00=oo`03001oogoo
00Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo
00]oo`04001oogooOol60002Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool40006Ool00`00Oomoo`02
Ool2002oOol003Uoo`03001oogoo00=oo`03001oogoo00Eoo`05001oogooOol00006Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool50009Ool00`00Oomoo`09Ool00`00Oomoo`06Ool0
0`00Ool000020003Ool00`00Oomoo`02Ool00`00Ool0002nOol003Yoo`03001oogoo009oo`03001o
ogoo00Eoo`04001oogoo0007Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool30000
0goo001oo`0;Ool00`00Oomoo`09Ool00`00Oomoo`07Ool01000Oomoogoo0`0000=oo`00Ool00goo
0P00_Woo000jOol00`00Oomoo`03Ool00`00Oomoo`05Ool20008Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`03Ool30005Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool20004Ool00`00Ool0002mOol003Yoo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oo`00008000Qoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Aoo`<0009oo`03001oo`000;eoo`00>goo
00<007ooOol00goo00<007ooOol00goo0P002Woo00<007ooOol02Goo00<007ooOol02Goo0`002goo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol01Goo00<007oo00000Woo
0P00_Goo000kOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Ool00009Ool00`00Oomoo`0:Ool0
0`00Oomoo`06Ool200000goo001oo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`06
Ool00`00Oomoo`05Ool02000Oomoo`00Ool007oo002lOol003]oo`03001oogoo00=oo`03001oogoo
009oo`04001oogoo000:Ool00`00Oomoo`09Ool00`00Oomoo`04Ool20004Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04002l
Ool003aoo`03001oogoo00=oo`04001oogoo0003Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`02Ool20006Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Ool0002kOol003aoo`03001oogoo00=oo`04001o
ogoo0004Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01000Ool0000027oo00<007ooOol02goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol00Woo0`00
^goo000lOol00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`08Ool00`00Oomoo`09Ool2000;
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool00`00Oomoo`2jOol003eoo`03001oogoo00=oo`8000Eoo`03001oogoo00Qo
o`03001oogoo00Moo`<000aoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Qoo`03001o
ogoo00Moo`03001oogoo00Eoo`03001oogoo009oo`<00;Yoo`00?Goo00<007ooOol00goo00<007oo
Ool01Goo00<007ooOol01goo00<007ooOol01Woo00D007ooOomoo`0000]oo`03001oogoo00]oo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Eoo`07001oogooOol007oo
0000^Woo000nOol00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`02Ool3002iOol003ioo`07001oogooOol007oo
00001Woo00<007ooOol027oo00<007ooOol00Woo0P001Goo00<007ooOol02Woo00<007ooOol02Woo
00<007ooOol02goo00<007ooOol027oo00<007ooOol027oo00<007ooOol017oo00<007ooOol00Woo
00<007oo0000^Goo000nOol01`00Oomoogoo001oo`0000Moo`03001oogoo00Moo`05001oogooOol0
0008Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`07Ool00`00Oomoo`05Ool01`00Oomoogoo001oo`000;Uoo`00?goo00<007oo00000Woo00<007oo
Ool01Goo00<007ooOol027oo0`002Goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02goo
00<007ooOol027oo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00Woo00<007oo0000^7oo
000oOol00`00Ool00002Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`05Ool01`00Oomoogoo001oo`000;Qoo`00?goo00<007oo00000goo00<007ooOol01Goo00<007oo
Ool01Woo0P0037oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02goo00<007ooOol027oo
00<007ooOol01goo00<007ooOol01Goo00D007ooOomoo`00009oo`03001oogoo0;Eoo`00@7oo00<0
07ooOol00Woo00<007ooOol01Goo00<007ooOol01Goo00@007ooOol000]oo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Uooa<000Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oo`00
0;Moo`00@7oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00goo00D007ooOomoo`0000]o
o`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Eoo`@0009oo`03001oogoo00Qoo`03001o
ogoo00=oo`L000Ioo`07001oogooOol007oo0000]goo0010Ool00`00Oomoo`03Ool00`00Oomoo`05
Ool01000Oomoogoo0P0017oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007oo
Ool010001goo00<007ooOol027oo00<007ooOol01goo00<007oo00000P000goo00<007ooOol00Woo
00<007oo0000]Woo0011Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01000Oomoo`001goo00<007oo
Ool02Goo00<007ooOol02Woo00<007ooOol02Goo10002goo00<007ooOol027oo00<007ooOol027oo
00@007ooOomoo`<00003Ool007oo009oo`03001oo`000;Ioo`00@Goo00<007ooOol00Woo00<007oo
Ool01Woo0P0027oo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol01Goo100000=oo`00Ool0
37oo00<007ooOol02Goo00<007ooOol01goo00<007ooOol017oo0P000goo00@007ooOol00;Eoo`00
@Goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol02Woo00<007ooOol0
2Woo00<007ooOol010001Woo00<007ooOol02goo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool017oo0P000goo00<007oo0000]Goo0011Ool00`00Oomoo`03Ool00`00Oomoo`04Ool2000:Ool0
0`00Oomoo`09Ool00`00Oomoo`0:Ool3000:Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`05Ool20002Ool00`00Ool0002eOol0049oo`03001oogoo009oo`03001oogoo
00=oo`04001oogoo0009Ool00`00Oomoo`09Ool00`00Oomoo`08Ool3000=Ool00`00Oomoo`0:Ool0
0`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Ool000020002Ool00`00Oomoo`2b
Ool0049oo`03001oogoo009oo`03001oogoo00=oo`04001oogoo0009Ool00`00Oomoo`0:Ool00`00
Oomoo`05Ool20003Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`05Ool00`00Oomoo`0200000goo001oo`2cOol0049oo`03001oogoo00=oo`05001o
ogooOol00003Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`03Ool20005Ool00`00Oomo
o`0:Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`05Ool01@00Oomo
ogoo00000Woo00<007ooOol0/Goo0013Ool00`00Oomoo`02Ool01000Oomoo`001Goo00<007ooOol0
1goo00<007ooOol02Goo00@007ooOomoo`8000Moo`03001oogoo00]oo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Moo`03001oogoo00Eoo`04001oogooOol200000goo001oo`2bOol004=o
o`03001oogoo009oo`03001oo`0000Ioo`03001oogoo00Moo`03001oogoo00Yoo`<000Yoo`03001o
ogoo00Yoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Eoo`04001o
ogooOol2002dOol004=oo`03001oogoo00=oo`8000Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00Moo`03
001oogoo00Eoo`04001oogooOol200000goo001oo`2aOol004Aoo`03001oogoo009oo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo00Moo`<000eoo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo009oo`800;=oo`00A7oo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00D007ooOomoo`0000ao
o`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Eo
o`06001oogooOol007oo0P00/Goo0014Ool01`00Oomoogoo001oo`0000Moo`03001oogoo00Qoo`03
001oogoo00Aoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Eoo`05001oogooOol00002Ool00`00Oomoo`2_
Ool004Aoo`07001oogooOol007oo000027oo00<007ooOol01goo00<007ooOol00Woo0P001Goo00<0
07ooOol02goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol027oo00<0
07ooOol01Goo00L007ooOomoo`00Ool0002aOol004Eoo`03001oo`00009oo`03001oogoo00Ioo`03
001oogoo00Moo`05001oogooOol00008Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0;
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007oo
Ool0[Woo0015Ool00`00Ool00003Ool00`00Oomoo`05Ool00`00Oomoo`08Ool30009Ool00`00Oomo
o`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomo
o`05Ool01@00Oomoogoo00000Woo00<007ooOol0[Woo0015Ool00`00Ool00003Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`05Ool01`00Oomoogoo001oo`000;1oo`00
AWoo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01Woo0P0037oo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol02goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol01Goo00D0
07ooOomoo`00009oo`03001oogoo0:eoo`00AWoo00<007ooOol00goo00<007ooOol01Goo00<007oo
Ool01Goo00@007ooOol000]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Uooa<000Eo
o`03001oogoo00Aoo`03001oogoo009oo`03001oo`000:moo`00AWoo00<007ooOol00goo00<007oo
Ool01Woo00<007ooOol00goo00D007ooOomoo`0000]oo`03001oogoo00]oo`03001oogoo00Yoo`03
001oogoo00Eoo`@00003Ool007oo00Yoo`03001oogoo00=oo`L000Ioo`07001oogooOol007oo0000
[goo0017Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01000Oomoogoo0P0017oo00<007ooOol02Woo
00<007ooOol02Woo00<007ooOol02goo00<007ooOol010001Woo00<007ooOol02Goo00<007ooOol0
1goo00<007oo00000P000goo00D007ooOomoo`00009oo`03001oogoo0:aoo`00Agoo00<007ooOol0
0goo00<007ooOol01Goo00@007ooOol000Moo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo
00Uoo`@000Yoo`03001oogoo00Uoo`03001oogoo00Qoo`04001oogooOol300000goo001oo`02Ool0
0`00Ool0002^Ool004Moo`03001oogoo00=oo`03001oogoo00Ioo`8000Qoo`03001oogoo00Uoo`03
001oogoo00]oo`03001oogoo00Ioo`<00003Ool007oo00]oo`03001oogoo00Yoo`03001oogoo00Mo
o`03001oogoo00Aoo`8000=oo`03001oo`000:ioo`00B7oo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol00goo0`001Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol01Goo0P000Woo00@007ooOol00:eo
o`00B7oo00<007ooOol00goo00<007ooOol017oo0P002Woo00<007ooOol02Goo00<007ooOol02goo
00<007oo00000P0027oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
1Goo0P000Woo00<007oo0000[Goo0018Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoo`00
2Goo00<007ooOol02Goo00<007ooOol02Woo0`0037oo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol01goo00<007ooOol01Goo00<007oo00000P0000=oo`00Ool0[7oo0019Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool01000Oomoo`002Goo00<007ooOol02Woo00<007ooOol01goo0P0000=oo`00
Ool037oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol017oo00@007oo
Oomoo`800003Ool007oo0:]oo`00BGoo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oogoo
00Qoo`03001oogoo00Uoo`03001oogoo00Eoo`8000Aoo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Eoo`07001oogooOol007oo0000[7oo0019Ool0
0`00Oomoo`03Ool01000Oomoo`001Goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol00Woo
0`001Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<007oo
Ool01Goo00@007ooOomoo`<00:aoo`00BWoo00<007ooOol00Woo00<007oo00001Woo00<007ooOol0
1goo00<007ooOol02Woo00@007oo000000Uoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo009oo`03001oo`000:]oo`00BWoo00<0
07ooOol00goo0P001Woo00<007ooOol027oo00<007ooOol02Goo0P0037oo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01Goo00@007ooOomoo`<00:]o
o`00BWoo00<007ooOol00goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo0`003Goo
00<007ooOol02goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol01Goo
00<007ooOol00Woo0P00Zgoo001;Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`06Ool01@00Oomoogoo000037oo00<007ooOol02goo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol017oo00<007ooOol00Woo0`00ZWoo001;Ool01`00Oomoogoo
001oo`0000Moo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00]oo`03
001oogoo00]oo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Eoo`07
001oogooOol007oo0000ZWoo001;Ool01`00Oomoogoo001oo`0000Qoo`03001oogoo00Moo`03001o
ogoo009oo`8000Eoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo009oo`800:Yoo`00C7oo00<007oo00000Woo
00<007ooOol01Woo00<007ooOol01goo00D007ooOomoo`0000Qoo`03001oogoo00Yoo`03001oogoo
00]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo
009oo`03001oo`000:Uoo`00C7oo00<007oo00000goo00<007ooOol01Goo00<007ooOol027oo0`00
2Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
1goo00<007ooOol01Goo00L007ooOomoo`00Ool0002YOol004aoo`03001oo`0000=oo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo009oo`03001oo`00
0:Qoo`00CGoo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01Woo0P0037oo00<007ooOol0
2Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol01goo00<007ooOol0
17oo00<007ooOol00Woo00<007oo0000Z7oo001=Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool01000Oomoo`002goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<0
07ooOol017oo20001goo00<007ooOol01Goo00<007ooOol00Woo0P00Z7oo001=Ool00`00Oomoo`03
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool01@00Oomoogoo000037oo00<007ooOol02Woo00<007oo
Ool02goo00<007ooOol027oo2@001Goo00<007ooOol01P000Woo00<007ooOol017oo00<007ooOol0
0Woo00<007oo0000Ygoo001>Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01000Oomoogoo0P001Goo
00<007ooOol02Goo00<007ooOol02Woo00<007ooOol037oo00@007ooOomoo`H0009oo`03001oogoo
00Yoo`03001oogoo00Eoo`@000Eoo`03001oogoo009oo`03001oo`000:Moo`00CWoo00<007ooOol0
0goo00<007ooOol01Goo00@007ooOol000Moo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo
00Yoo`D000Uoo`03001oogoo00Uoo`03001oogoo00Moo`03001oo`0000<0009oo`03001oogoo009o
o`800:Moo`00CWoo00<007ooOol00goo00<007ooOol01Woo0P0027oo00<007ooOol02Woo00<007oo
Ool02Woo00<007ooOol01goo0`0000=oo`00Ool02goo00<007ooOol02Goo00<007ooOol027oo00<0
07ooOol00Woo0`0017oo00<007oo0000YWoo001?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool40005Ool00`00Oomoo`09
Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`04Ool30002Ool00`00Ool0002VOol004mo
o`03001oogoo00=oo`03001oogoo00Aoo`8000Yoo`03001oogoo00Uoo`03001oogoo00]oo`03001o
o`00008000Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Aoo`03
001oo`00009oo`03001oo`000:Eoo`00Cgoo00<007ooOol00goo00<007ooOol00goo00@007ooOol0
00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`8000aoo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Moo`03001oogoo00Aoo`08001oogoo001oo`00Ool00:Eoo`00D7oo00<007ooOol00Woo
00<007ooOol00goo00@007ooOol000Yoo`03001oogoo00Uoo`03001oogoo00Qoo`<000ioo`03001o
ogoo00Yoo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00@00:Eoo`00
D7oo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oogoo00Qoo`03001oogoo00Yoo`03001o
ogoo00Eoo`8000=oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo00Aoo`03001oogoo009oo`03001oo`000:Aoo`00D7oo00<007ooOol00goo00@007oo
Ool000Eoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00=oo`8000Eoo`03001oogoo00ao
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009o
o`<00:Aoo`00DGoo00<007ooOol00Woo00<007oo00001Woo00<007ooOol027oo00<007ooOol02Goo
00@007ooOomoo`8000Moo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Moo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo0:=oo`00DGoo00<007ooOol00goo0P00
1Woo00<007ooOol027oo00<007ooOol02Woo0`002Woo00<007ooOol02goo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol027oo00<007ooOol017oo00<007ooOol00Woo0`00Xgoo001AOol00`00
Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`0<Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool2002SOol0059oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Qoo`03001o
ogoo00Moo`<000eoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo00Aoo`03001oogoo009oo`<00:9oo`00DWoo00L007ooOomoo`00Ool00007Ool00`00
Oomoo`08Ool00`00Oomoo`05Ool20003Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool0002R
Ool0059oo`07001oogooOol007oo00001goo00<007ooOol02Goo00<007ooOol00goo00<007ooOol0
0goo00<007ooOol02Woo00<007ooOol037oo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
1goo00<007ooOol01Goo00<007ooOol00Woo0P00XWoo001COol00`00Ool00002Ool00`00Oomoo`06
Ool00`00Oomoo`08Ool01000Oomoogoo0P001Woo00<007ooOol02goo00<007ooOol02goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol017oo00<007ooOol00Woo00<007oo
0000XGoo001COol00`00Ool00003Ool00`00Oomoo`05Ool00`00Oomoo`09Ool30009Ool00`00Oomo
o`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomo
o`05Ool01`00Oomoogoo001oo`000:5oo`00Dgoo00<007oo00000goo00<007ooOol01Goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol037oo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00Woo00<007oo0000X7oo001DOol0
0`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07Ool2000;Ool00`00Oomoo`0;Ool00`00Oomo
o`0;Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`05Ool01`00Oomo
ogoo001oo`000:1oo`00E7oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01Woo00@007oo
Ool000]oo`03001oogoo00Yoo`03001oogoo00aoo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo00Moo`03001oogoo00Eoo`03001oogoo009oo`800:1oo`00E7oo00<007ooOol00goo00<007oo
Ool01Goo00<007ooOol01Goo00D007ooOomoo`0000]oo`03001oogoo00Yoo`03001oogoo00aoo`03
001oogoo00Yoo`03001oogoo00Aoo`/000Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oo`00
09moo`00EGoo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo0P0017oo00<007ooOol0
2Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol027oo2@001Goo00<007ooOol00goo1`00
1Woo00L007ooOomoo`00Ool0002OOol005Eoo`03001oogoo00=oo`03001oogoo00Eoo`05001oogoo
Ool00007Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool01000Oomoogoo1P000Woo
00<007ooOol02Woo00<007ooOol01goo00<007oo00000P000goo00<007ooOol00Woo0P00Wgoo001E
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`0027oo00<007ooOol02Goo00<007ooOol0
2goo00<007ooOol02Woo1@002Goo00<007ooOol02Goo00<007ooOol027oo00@007ooOomoo`<00003
Ool007oo009oo`03001oo`0009ioo`00EWoo00<007ooOol00goo00<007ooOol01Goo0P002Goo00<0
07ooOol02Goo00<007ooOol02goo00<007ooOol01goo0`0000=oo`00Ool02goo00<007ooOol02Goo
00<007ooOol027oo00<007ooOol017oo0P000goo00<007oo0000WWoo001FOol00`00Oomoo`03Ool0
0`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool4
0005Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`05Ool30002Ool0
0`00Ool0002MOol005Ioo`03001oogoo00=oo`03001oogoo00Aoo`8000]oo`03001oogoo00Uoo`03
001oogoo00]oo`03001oo`00008000Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo00Eoo`07001oo`00Ool007oo0000WGoo001GOol00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Ool0000:Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool2000<Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04002MOol005Moo`03001oogoo
00=oo`03001oogoo009oo`04001oogoo000:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool3000>Ool0
0`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
0`00Ool0002LOol005Moo`03001oogoo00Aoo`04001oogoo0003Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`06Ool20003Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool00`00Oomoo`05Ool01000Oomoogoo0`00W7oo001GOol00`00Oomoo`04Ool01000
Oomoo`0017oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol017oo0P001Goo00<007ooOol0
2goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol0
0Woo00<007ooOol0Vgoo001HOol00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`05Ool01000Oomoogoo0`00Vgoo001HOol00`00Oomoo`04Ool2
0006Ool00`00Oomoo`08Ool00`00Oomoo`09Ool01000Ool000002Woo00<007ooOol02goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00Woo0P00Vgoo
001HOol00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`09Ool2000<Ool0
0`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool3002JOol005Uoo`03001oogoo009oo`8000Moo`03001oogoo00Qoo`03001oogoo
00Moo`<000eoo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Qoo`03
001oogoo00Eoo`07001oogooOol007oo0000VWoo001IOol00`00Oomoo`02Ool00`00Ool00007Ool0
0`00Oomoo`08Ool00`00Oomoo`04Ool20003Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`02Ool2002JOol0
05Uoo`05001oogooOol00002Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Ool0002IOol005Yoo`04001oogoo0002
Ool00`00Oomoo`05Ool00`00Oomoo`08Ool01000Oomoogoo0P001Woo00<007ooOol02goo00<007oo
Ool037oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01Goo00<007oo
Ool00Woo0P00VGoo001JOol00`00Ool00004Ool00`00Oomoo`05Ool00`00Oomoo`08Ool30009Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool00`00Ool0002HOol005Yoo`03001oo`0000Aoo`03001oogoo
00Eoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo009oo`03001oo`00
09Qoo`00Fgoo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo0P0037oo00<007ooOol0
2goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
1Goo00<007ooOol00Woo0P00V7oo001KOol00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool01000Oomoo`002goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol0
2Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00Woo00<007oo0000Ugoo001KOol00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01@00Oomoogoo00002goo00<007ooOol02goo
00<007ooOol037oo00<007ooOol02Woo00<007ooOol017oo2`001Goo00<007ooOol01Goo00<007oo
Ool00Woo0P00Ugoo001LOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool80005Ool0
0`00Oomoo`03Ool70006Ool00`00Oomoo`02Ool00`00Ool0002FOol005aoo`03001oogoo00=oo`03
001oogoo00Ioo`05001oogooOol00006Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0;
Ool00`00Oomoo`05Ool400000goo001oo`0;Ool00`00Oomoo`07Ool00`00Ool000020003Ool00`00
Oomoo`03Ool2002FOol005aoo`03001oogoo00Aoo`03001oogoo00Eoo`04001oogoo0007Ool00`00
Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`040006Ool00`00Oomoo`09Ool0
0`00Oomoo`08Ool01000Oomoogoo0`0000=oo`00Ool00goo0P00UWoo001MOol00`00Oomoo`03Ool0
0`00Oomoo`06Ool20008Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool4000:Ool0
0`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`04Ool20004Ool00`00Ool0002EOol005eoo`03
001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00]oo`03
001oogoo00Moo`<00003Ool007oo00]oo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Eo
o`<000=oo`8009Eoo`00GGoo00<007ooOol017oo00<007ooOol017oo0P002Woo00<007ooOol02Goo
00<007ooOol02goo00<007ooOol00goo10001Goo00<007ooOol02Woo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol01Goo00P007oo000007oo001oo`00U7oo001NOol00`00Oomoo`03Ool00`00
Oomoo`03Ool01000Oomoo`002Goo00<007ooOol02Woo00<007ooOol02goo00<007oo00000P002Goo
00<007ooOol02Woo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01Goo00@007ooOomoo`@0
09Aoo`00GWoo00<007ooOol00goo00<007ooOol00goo00@007ooOol000Yoo`03001oogoo00Uoo`03
001oogoo00Yoo`<000aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo
00Eoo`03001oogoo00=oo`03001oo`0009=oo`00GWoo00<007ooOol017oo00D007ooOomoo`0000=o
o`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00Moo`800003Ool007oo00eoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo009oo`<009=oo`00
Ggoo00<007ooOol00goo00@007ooOol000Eoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo
00Eoo`8000Aoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Moo`03
001oogoo00Eoo`03001oogoo00=oo`03001oogoo099oo`00Ggoo00<007ooOol00goo00<007oo0000
1Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol00Woo0`001Woo00<007ooOol037oo00<0
07ooOol02Goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo0`00
TWoo001OOol00`00Oomoo`04Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool01000Ool00000
2Goo00<007ooOol037oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol01goo00<007ooOol0
1Goo00<007ooOol00Woo00<007oo0000TWoo001POol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool2000<Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool3002AOol0061oo`03001oogoo009o
o`8000Qoo`03001oogoo00Qoo`03001oogoo00Moo`<000eoo`03001oogoo00aoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo00=oo`03001oo`00095o
o`00H7oo00<007ooOol00Woo00<007oo00001goo00<007ooOol027oo00<007ooOol01Woo00D007oo
Oomoo`0000aoo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Moo`03
001oogoo00Eoo`03001oogoo009oo`03001oo`00095oo`00HGoo00@007ooOol0009oo`03001oogoo
00Eoo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo
00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo
00=oo`03001oo`00091oo`00HGoo00@007ooOol0009oo`03001oogoo00Ioo`03001oogoo00Qoo`03
001oogoo009oo`8000Eoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo009oo`03001oo`00091oo`00HGoo00<0
07oo000017oo00<007ooOol01Goo00<007ooOol027oo00D007ooOomoo`0000Qoo`03001oogoo00Yo
o`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Eo
o`03001oogoo009oo`03001oo`00091oo`00HWoo0P0017oo00<007ooOol01Goo00<007ooOol02Goo
0`002Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02Woo00<007oo
Ool01goo00<007ooOol01Goo00<007ooOol00goo00<007oo0000Sgoo001ROol00`00Oomoo`03Ool0
0`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
0`00Ool0002?Ool0069oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Moo`8000aoo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Moo`03
001oogoo00Eoo`03001oogoo00=oo`03001oo`0008ioo`00Hgoo00<007ooOol00goo00<007ooOol0
1Goo00<007ooOol01Goo0P000Woo00<007ooOol02Goo00<007ooOol02goo00<007ooOol037oo00<0
07ooOol02Goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00goo00<0
07oo0000SWoo001SOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`04
Ool;0005Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Ool0002>Ool006=oo`03001oogoo00=o
o`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo00]o
o`03001oogoo00]oo`03001oogoo00Qoo`T000Ioo`03001oogoo009oo`L000Ioo`03001oogoo00=o
o`03001oo`0008eoo`00I7oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00P001goo00<0
07ooOol02Goo00<007ooOol02goo00<007ooOol037oo00@007ooOomoo`H0009oo`03001oogoo00]o
o`03001oogoo00Ioo`03001oo`00008000=oo`03001oogoo00=oo`03001oo`0008eoo`00I7oo00<0
07ooOol00goo00<007ooOol01Woo0P002Goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0
2goo1@002Goo00<007ooOol02Woo00<007ooOol01goo00@007ooOomoo`<00003Ool007oo00=oo`03
001oo`0008eoo`00I7oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
2Woo00<007ooOol02goo00<007ooOol027oo0P0000=oo`00Ool02goo00<007ooOol02Woo00<007oo
Ool01goo00<007ooOol017oo0P001Goo00<007oo0000S7oo001UOol00`00Oomoo`03Ool00`00Oomo
o`04Ool2000;Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool30004Ool00`00Oomo
o`0:Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`04Ool30003Ool00`00Ool0002<Ool0
06Eoo`03001oogoo00=oo`03001oogoo00=oo`04001oogoo000:Ool00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`02Ool30007Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool0
0`00Oomoo`05Ool02000Ool00000Ool007oo002<Ool006Eoo`03001oogoo00=oo`03001oogoo00=o
o`04001oogoo000:Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool01000Ool000002Woo00<007ooOol0
2Woo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01Goo00@007ooOomoo`<00003Ool007oo
08Yoo`00IWoo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Yoo`<000eoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Moo`03001o
ogoo00Eoo`03001oogoo009oo`03001oo`0008]oo`00IWoo00<007ooOol00goo00@007ooOol000Eo
o`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00Moo`800003Ool007oo00eoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo009oo`800003Ool0
07oo08Uoo`00Igoo00<007ooOol00Woo00<007oo00001Woo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol01Goo0P0017oo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol017oo00<007ooOol00goo0`00RWoo001WOol00`00Oomoo`03Ool20006Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`02Ool30006Ool00`00Oomoo`0<Ool00`00Oomo
o`0:Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`02Ool2002;Ool0
06Moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Yoo`04001oo`00
0009Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomo
o`05Ool00`00Oomoo`03Ool30029Ool006Qoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
00Uoo`03001oogoo00Uoo`8000aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03
001oogoo00Moo`03001oogoo00Eoo`03001oogoo009oo`03001oo`0008Uoo`00J7oo00L007ooOomo
o`00Ool00007Ool00`00Oomoo`09Ool00`00Oomoo`07Ool3000=Ool00`00Oomoo`0<Ool00`00Oomo
o`0:Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Ool0
0029Ool006Qoo`07001oogooOol007oo000027oo00<007ooOol027oo00<007ooOol01Woo00D007oo
Oomoo`0000aoo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Moo`03
001oogoo00Eoo`03001oogoo00=oo`03001oo`0008Qoo`00JGoo00<007oo00000Woo00<007ooOol0
1Woo00<007ooOol02Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol0
2goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol0
0Woo00<007oo0000R7oo001YOol00`00Ool00003Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool20005Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Ool00027Ool006Uoo`03001o
o`0000=oo`03001oogoo00Ioo`03001oogoo00Qoo`05001oogooOol00008Ool00`00Oomoo`0:Ool0
0`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool00`00Ool00027Ool006Yoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
00Uoo`<000Uoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03
001oogoo00Moo`03001oogoo00Eoo`03001oogoo009oo`03001oo`0008Moo`00JWoo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02goo00<007ooOol0
37oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0
0Woo00<007oo0000QWoo001ZOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`07Ool2000<
Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Ool00026Ool006]oo`03001oogoo009oo`03001o
ogoo00Ioo`03001oogoo00Eoo`80009oo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00]o
o`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=o
o`03001oo`0008Eoo`00Jgoo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007oo
Ool00Woo00<007ooOol02Goo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007oo
Ool017oo2`001Goo00<007ooOol01Goo00<007ooOol00Woo00<007oo0000QGoo001[Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomo
o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool90005Ool00`00Oomoo`03Ool80005Ool00`00Oomo
o`03Ool20025Ool006aoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo008000Moo`03001o
ogoo00Uoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Eoo`@0009oo`03001oogoo00Yo
o`03001oogoo00Moo`03001oogoo00@0009oo`03001oogoo009oo`03001oo`0008Aoo`00K7oo00<0
07ooOol00goo00<007ooOol01Woo0P002Goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0
37oo00<007ooOol010001goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol00goo0`0017oo
00<007oo0000Q7oo001/Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomo
o`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool4000;Ool00`00Oomoo`09Ool00`00Oomoo`08Ool0
0`00Oomoo`05Ool30003Ool20024Ool006eoo`03001oogoo00=oo`03001oogoo00Aoo`8000Yoo`03
001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Moo`<00003Ool007oo00aoo`03001oogoo00Yo
o`03001oogoo00Qoo`03001oogoo00Eoo`08001oo`00001oo`00Ool008=oo`00KGoo00<007ooOol0
0goo00<007ooOol00goo00@007ooOol000Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00=oo`@000Eoo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Eoo`04
001oogooOol40023Ool006eoo`03001oogoo00=oo`03001oogoo00=oo`04001oogoo000:Ool00`00
Oomoo`0:Ool00`00Oomoo`0;Ool00`00Ool000020009Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool0
0`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Ool00022Ool006eoo`03001oogoo
00Aoo`05001oogooOol00003Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool3000=
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool30022Ool006ioo`03001oogoo00=oo`04001oogoo0005Ool00`00Oomoo`08Ool00`00Oomoo`0:
Ool00`00Oomoo`07Ool200000goo001oo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`21Ool006ioo`03001oogoo00=oo`03
001oo`0000Ioo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00Eoo`8000Aoo`03001oogoo
00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo
009oo`<0085oo`00KWoo00<007ooOol017oo0P001Woo00<007ooOol027oo00<007ooOol02Woo00<0
07ooOol00Woo0`001Woo00<007ooOol037oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0
27oo00<007ooOol01Goo00<007ooOol00Woo00<007oo0000PGoo001_Ool00`00Oomoo`03Ool00`00
Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool01000Ool000002Goo00<007ooOol037oo00<0
07ooOol02goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo0`00
P7oo001_Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool2000<Ool00`00
Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool00`00Ool00020Ool006moo`03001oogoo009oo`03001oo`0000Moo`03001oogoo00Qo
o`03001oogoo00Qoo`<000eoo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Qoo`03001oogoo00Eoo`03001oogoo009oo`03001oo`00081oo`00L7oo00@007ooOol0009o
o`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`05001oogooOol0000=Ool00`00Oomo
o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomo
o`03Ool00`00Ool0001oOol0071oo`04001oogoo0002Ool00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Oomoo`04Ool20004Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Ool0001oOol0071oo`03
001oo`0000Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo009oo`8000Ioo`03001oogoo
00]oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo
00Eoo`03001oogoo009oo`03001oo`0007moo`00LGoo0P0017oo00<007ooOol01Woo00<007ooOol0
1goo00D007ooOomoo`0000Uoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001o
ogoo00Yoo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo009oo`03001oo`0007ioo`00LGoo
00<007ooOol00goo00<007ooOol01Woo00<007ooOol027oo0`002Woo00<007ooOol02goo00<007oo
Ool037oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Goo00<007oo
Ool00Woo00<007oo0000OWoo001aOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Ool0001nOol0079oo`03001oogoo
00=oo`03001oogoo00Ioo`03001oogoo00Ioo`8000eoo`03001oogoo00]oo`03001oogoo00aoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo009oo`03
001oo`0007eoo`00LWoo00<007ooOol00goo00<007ooOol01Woo00<007ooOol01Goo00@007ooOol0
00aoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Qoo`03001oogoo00Eoo`03001oogoo009oo`03001oo`0007eoo`00LWoo00<007ooOol00goo00<0
07ooOol01goo00<007ooOol00goo00D007ooOomoo`0000aoo`03001oogoo00aoo`03001oogoo00]o
o`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo009o
o`03001oo`0007eoo`00Lgoo00<007ooOol00goo00<007ooOol01Woo00@007ooOomoo`8000Aoo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Aooa<0
00Ioo`03001oogoo009oo`03001oo`0007aoo`00Lgoo00<007ooOol00goo00<007ooOol01Woo00@0
07ooOol000Moo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00Qoo`T0
00Ioo`03001oogoo00Qoo`03001oo`00008000=oo`03001oogoo009oo`03001oo`0007aoo`00Lgoo
00<007ooOol00goo00<007ooOol01goo0P0027oo00<007ooOol02Woo00<007ooOol037oo00<007oo
Ool037oo00@007ooOomoo`H0009oo`03001oogoo00]oo`03001oogoo00Qoo`04001oogooOol30000
0goo001oo`02Ool01000Oomoo`00Ngoo001dOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomo
o`08Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool50009Ool00`00Oomoo`0:Ool0
0`00Oomoo`08Ool00`00Oomoo`04Ool20004Ool00`00Ool0001kOol007Aoo`03001oogoo00=oo`03
001oogoo00Eoo`8000Yoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Uoo`800003Ool0
07oo00]oo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Eoo`<0009oo`03001oo`0007]o
o`00M7oo00<007ooOol00goo00<007ooOol017oo00@007ooOol000Uoo`03001oogoo00Yoo`03001o
ogoo00aoo`03001oogoo00Eoo`<000Aoo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00Qo
o`03001oogoo00Eoo`05001oo`00Ool00002Ool00`00Oomoo`1hOol007Eoo`03001oogoo009oo`03
001oogoo00=oo`05001oogooOol0000:Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`02
Ool30007Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00
Oomoo`0300000goo001oo`0HOol201mOOol007Eoo`03001oogoo00=oo`05001oogooOol00004Ool0
0`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool01000Ool000002Woo00<007ooOol02Woo
00<007ooOol02goo00<007ooOol027oo00<007ooOol01Goo00L007ooOomoo`00Ool0000GOol601mM
Ool007Ioo`03001oogoo009oo`05001oogooOol00005Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool0
0`00Oomoo`0;Ool3000=Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomo
o`05Ool01000Oomoogoo0P0000=oo`00Ool057oo200OG7oo001fOol00`00Oomoo`02Ool01000Oomo
o`001Woo00<007ooOol027oo00<007ooOol02Woo00<007ooOol027oo0P0000=oo`00Ool03Goo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00Woo0`00
5Goo200OG7oo001fOol00`00Oomoo`03Ool20007Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00
Oomoo`05Ool30004Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`08
Ool00`00Oomoo`05Ool01000Oomoogoo0P005Goo100O00=l7@0O01l00`0OFgoo001gOol00`00Oomo
o`02Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02Ool30007Ool0
0`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool3000COol401l00g`M01l07`0301mKOol007Moo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo00Qoo`03001oogoo00Yoo`04001oo`00000:Ool00`00Oomoo`0<Ool00`00Oomo
o`0:Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool01`00Oomoogoo001oo`0001Ao
o`@07`04O1d07`0O01mLOol007Moo`07001oogooOol007oo000027oo00<007ooOol027oo00<007oo
Ool02Woo0P003Goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol027oo
00<007ooOol01Goo00L007ooOomoo`00Ool0000DOol401l017`M01l07`0OG7oo001hOol01P00Oomo
o`00Ool000Uoo`03001oogoo00Qoo`03001oogoo00Moo`<000ioo`03001oogoo00aoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo009oo`03001oo`00
01=oo`03O1H07`0O00807`03O1d07goo05aoo`00N7oo00<007oo00000Woo00<007ooOol01goo00<0
07ooOol027oo00<007ooOol01Woo00D007ooOomoo`0000eoo`03001oogoo00aoo`03001oogoo00Yo
o`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Eoo`07001oogooOol007oo00004Woo00Al
5W`7Oomoo`807`03O1eoogoo05aoo`00N7oo00<007oo00000goo00<007ooOol01Woo00<007ooOol0
27oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol02goo00<007ooOol0
2goo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00Woo00<007oo0000
47oo00=l5WooO0L00Woo00=l3WooO1d0GWoo001iOol00`00Oomoo`02Ool00`00Oomoo`07Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool20005Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;
Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Ool0000?
Ool00g`FOoml1`03Ool017`>Oomoog`MGGoo001iOol00`00Oomoo`02Ool00`00Oomoo`07Ool00`00
Oomoo`08Ool01@00Oomoogoo000027oo00<007ooOol02goo00<007ooOol037oo00<007ooOol02Woo
00<007ooOol02goo00<007ooOol027oo00<007ooOol01Goo00L007ooOomoo`00Ool0000>Ool017`F
Oomoog`70goo00Al3WooOoml7Eeoo`00NGoo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0
2Goo0`002Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<0
07ooOol027oo00<007ooOol01Goo00<007ooOol00Woo00<007oo000037oo00Al5WooOoml1`Aoo`05
O0ioogooOoml7@1LOol007Yoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Qoo`03001o
ogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001o
ogoo00Qoo`03001oogoo00Ioo`07001oogooOol007oo000037oo00Al5WooOoml1`Aoo`05O0ioogoo
Ooml7@1LOol007Yoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Moo`8000aoo`03001o
ogoo00]oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Qoo`03001o
ogoo00Eoo`05001oogooOol00002Ool00`00Oomoo`08Ool017`FOomoog`71Goo00=l3WooOol00Woo
00=l7GooOol0FGoo001jOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`05Ool20002Ool0
0`00Oomoo`09Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool0
0`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Ool00009Ool01G`FOomoogooO0L0
1Goo00=l3WooOol00Woo00=l7GooOol0FGoo001kOol00`00Oomoo`02Ool00`00Oomoo`07Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00
Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`05Ool01`00Oomoogoo001oo`00
00Qoo`05O1IoogooOoml1`06Ool00g`>Oomoo`02Ool00g`MOomoo`1IOol007]oo`03001oogoo009o
o`03001oogoo00Moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo00]o
o`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Aooa@000Eoo`03001oogoo009oo`03001o
o`0000Ioo`03O1Ioogoo009oo`03O0Moogoo00Aoo`03O0ioogoo00=oo`03O1eoogoo05Qoo`00Ngoo
00<007ooOol00goo00<007ooOol01Woo00<007ooOol00P001goo00<007ooOol02Goo00<007ooOol0
37oo00<007ooOol02goo00<007ooOol02Goo2@001Woo00<007ooOol027oo00<007ooOol010000Woo
00L007ooOomoo`00Ool00005Ool00g`FOomoo`02Ool00g`7Oomoo`05Ool00g`>Oomoo`03Ool00g`M
Oomoo`1HOol007aoo`03001oogoo009oo`03001oogoo00Moo`8000Uoo`03001oogoo00Yoo`03001o
ogoo00]oo`03001oogoo00]oo`03001oogoo00Eoo`@0009oo`03001oogoo00]oo`03001oogoo00Qo
o`03001oogoo00=oo`<000=oo`03001oo`0000Eoo`03O1Ioogoo009oo`03O0Moogoo00Eoo`03O0io
ogoo00Aoo`03O1eoogoo05Moo`00O7oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol027oo
00<007ooOol02Woo00<007ooOol02goo00<007ooOol037oo00<007ooOol010001goo00<007ooOol0
2Woo00<007ooOol027oo00<007ooOol01Goo0`000Woo00<007oo00000goo00=l5WooOol00Woo00=l
1gooOol01Woo00=l3WooOol017oo00=l7GooOol0Egoo001lOol00`00Oomoo`03Ool00`00Oomoo`05
Ool2000;Ool00`00Oomoo`09Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool4000;Ool00`00Oomoo`0:
Ool00`00Oomoo`08Ool00`00Oomoo`06Ool01`00Ool007oo001oo`00009oo`03O1Ioogoo00=oo`03
O0Moogoo00Ioo`03O0ioogoo00Aoo`03O1eoogoo05Moo`00OGoo00<007ooOol00Woo00<007ooOol0
17oo00@007ooOol000Yoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Moo`<00003Ool0
07oo00aoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo00<00003Ool0
07`F00Eoo`03O0Moogoo00Moo`03O0ioogoo00Eoo`03O1eoogoo05Ioo`00OGoo00<007ooOol00Woo
00<007ooOol00goo00D007ooOomoo`0000Yoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo
00=oo`@000Eoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Eoo`03
001oogoo009oo`03001oog`F00Ioo`03O0Moogoo00Moo`03O0ioogoo00Eoo`03O1eoogoo05Ioo`00
OGoo00<007ooOol00goo00D007ooOomoo`0000Aoo`03001oogoo00Uoo`03001oogoo00Uoo`03001o
ogoo00aoo`03001oo`00008000Uoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Qoo`03
001oogoo00Eoo`06001oogooOol007`F1Woo00=l1gooOol027oo00=l3WooOol01Woo00=l7GooOol0
EGoo001nOol00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007ooOol027oo00<007ooOol02Woo
00<007ooOol02goo0P0037oo00<007ooOol037oo00<007ooOol02Woo00<007ooOol027oo00<007oo
Ool01Goo00D007ooOomoog`F00<000Aoo`03O0Moogoo00Qoo`03O0ioogoo00Ioo`03O1eoogoo05Eo
o`00OWoo00<007ooOol00Woo00@007ooOol000Ioo`03001oogoo00Qoo`03001oogoo00Yoo`03001o
ogoo00Uoo`<000ioo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Io
o`04001oogooO1H20004Ool00g`7Oomoo`09Ool00g`>Oomoo`06Ool00g`MOomoo`1EOol007ioo`03
001oogoo00=oo`8000Moo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Ioo`8000=oo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Eoo`06
001oog`FOol007oo0P000Woo00=l1gooOol02Goo00=l3WooOol01goo00=l7GooOol0E7oo001oOol0
0`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool2
0005Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomo
o`05Ool00`00O1Ioo`02Ool01@00Ool007ooO0L037oo00=l3WooOol01goo00=l7GooOol0E7oo001o
Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`02
Ool20007Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00
Oomoo`05Ool00g`F001oo`02Ool01@00Ool007ooO0L037oo00=l3WooOol027oo00=l7GooOol0Dgoo
001oOol01`00Oomoogoo001oo`0000Qoo`03001oogoo00Uoo`03001oogoo00Yoo`04001oo`00000:
Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`03
Ool00g`FOol00004Ool00`00Ool0000=Ool00g`>Oomoo`08Ool00g`MOomoo`1COol0081oo`06001o
ogoo001oo`002Goo00<007ooOol027oo00<007ooOol02Woo0P0037oo00<007ooOol037oo00<007oo
Ool02goo00<007ooOol02Woo00<007ooOol027oo00<007ooOol00Woo00Al5WooOol000Aoo`03001o
o`0000eoo`03O0ioogoo00Uoo`03O1eoogoo059oo`00P7oo00<007oo00000Woo00<007ooOol01goo
00<007ooOol027oo00<007ooOol027oo0`003Woo00<007ooOol02goo00<007ooOol02goo00<007oo
Ool02goo00<007ooOol01goo00D007ooOomoog`F00Aoo`07001oogooOol007oo00003Goo00=l3Woo
Ool02Goo00=l7GooOol0DWoo0020Ool00`00Ool00003Ool00`00Oomoo`06Ool00`00Oomoo`09Ool0
0`00Oomoo`05Ool20003Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomo
o`0:Ool00`00Oomoo`08Ool00`00Ooml5P05Ool00`00Oomoo`02Ool00`00Ool0000<Ool00g`>Oomo
o`09Ool00g`MOomoo`1BOol0085oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo00=oo`8000Eoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo
00Yoo`03001oogoo00Qoo`03001l5Woo00Eoo`03001oogoo009oo`03001oo`0000aoo`03O0ioogoo
00Yoo`03O1eoogoo055oo`00PGoo00<007ooOol00Woo00<007ooOol01goo00<007ooOol027oo00@0
07ooOomoo`8000Moo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]o
o`03001oogoo00=oo`807`9oo`03001l5Woo00Ioo`05001oogooOol00002Ool00`00Oomoo`09Ool0
0g`>Oomoo`0:Ool00g`MOomoo`1AOol0085oo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo
00Uoo`<000Yoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Yoo`04
001oogooOol601l00g`F001oo`06Ool00`00Oomoo`02Ool00`00Ool0000;Ool00g`>Oomoo`0;Ool0
0g`MOomoo`1@Ool0089oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo
00Yoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo
00P07`03001oogoo00Eoo`03001oogoo009oo`03001oo`0000]oo`03O0ioogoo00]oo`03O1eoogoo
051oo`00PWoo00<007ooOol00Woo00<007ooOol01goo00<007ooOol01goo0P0037oo00<007ooOol0
37oo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007oo01l01`0O00=oo`00Ool0
1Woo00<007ooOol00Woo00<007oo00002Woo00=l3WooOol02goo00=l7GooOol0D7oo0022Ool00`00
Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`05Ool20002Ool00`00Oomoo`0:Ool00`00Oomoo`0;
Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`0001l07`0801l00`00Oomoo`05
Ool00`00Oomoo`02Ool00`00Ool0000:Ool00g`>Oomoo`0<Ool00g`MOomoo`1?Ool008=oo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Yoo`03001o
ogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`X07`03001oogoo00Ioo`07
001oogooOol007oo00002Woo00=l3WooOol037oo00=l7GooOol0Cgoo0023Ool00`00Oomoo`02Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool0
0`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool7000801l2Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool00`00Ool00009Ool00g`>Oomoo`0=Ool00g`MOomoo`1>Ool008=oo`03001oogoo00=o
o`03001oogoo00Ioo`03001oogoo008000Moo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo
00aoo`03001oogoo00Uoo`T000Ioo`0300007`0O00H07`D000Eoo`03001oogoo009oo`03001oo`00
00Uoo`03O0ioogoo00eoo`03O1eoogoo04ioo`00Q7oo00<007ooOol00Woo00<007ooOol01goo0P00
2Goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol037oo00<007ooOol01Goo10000Woo00<0
07ooOol02goo00<0000O01l0100O00Alh7ooOol0009oo`@0009oo`05001oogooOol00002Ool00`00
Oomoo`06Ool00g`>Oomoo`0>Ool00g`MOomoo`1=Ool008Aoo`03001oogoo009oo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00@0
00Moo`03001oogoo00Yoo`03001oo`<O00807`04<n1oogooO>02Ool00`00Oomoo`03Ool30004Ool0
0`00Ool00008Ool00g`>Oomoo`0>Ool00g`MOomoo`1=Ool008Aoo`03001oogoo00=oo`03001oogoo
00Eoo`8000]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`@000]oo`03001oogoo
00Yoo`0300037goo00=oo`06<n1oogooO>1oo`001goo0`000Woo00<007oo000027oo00=l3WooOol0
3Woo00=l7GooOol0CGoo0025Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000Oomoo`002Woo00<0
07ooOol02Woo00<007ooOol037oo00<007ooOol027oo0P0000=oo`00Ool037oo00<007ooOol02goo
00<37gooOol00Woo00Pch7ooOomoogcP001oog`71Woo00P007oo000007oo001oo`001goo00=l3Woo
Ool03goo00=l7GooOol0C7oo0025Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo0000
2Woo00<007ooOol02Woo00<007ooOol037oo00<007ooOol01Goo0`0017oo00<007ooOol02goo00<0
07ooOol02Goo00<37`00Ool00goo00Lch7ooOomoogcPOol00007Ool01000Oomoogoo0P0000=oo`00
Ool01Woo00=l3WooOol03goo00=l7GooOol0C7oo0025Ool00`00Oomoo`03Ool01@00Oomoogoo0000
17oo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol00Woo0`001goo00<0
07ooOol02goo00<007ooOol02Goo00<37goo000017oo00Hch7ooOomoogcP0007Ool00`00Oomoo`02
Ool20008Ool00g`>Oomoo`0@Ool00g`MOomoo`1;Ool008Ioo`03001oogoo009oo`05001oogooOol0
0005Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool01000Ool000002Woo00<007oo
Ool037oo00<007ooOol01goo00@37gooOol000Aoo`03<n1oogoo009oo`03O>0007oo00Ioo`03001o
ogoo009oo`<000Ioo`03O0ioogoo011oo`03O1eoogoo04]oo`00QWoo00<007ooOol00Woo00@007oo
Ool000Ioo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00]oo`<000eoo`03001oogoo00]o
o`03001oogoo00Moo`040amoogoo0004Ool00c?POomoo`03Ool00gcPOomoo`05Ool00`00Oomoo`02
Ool20007Ool00g`>Oomoo`0@Ool00g`MOomoo`1;Ool008Ioo`03001oogoo00=oo`8000Moo`03001o
ogoo00Qoo`03001oogoo00]oo`03001oogoo00Qoo`800003Ool007oo00eoo`03001oogoo00]oo`03
001oogoo00Ioo`030amoogoo009oo`03001oogoo009oo`03<n1oogoo009oo`03001lh7oo00Ioo`03
001oogoo009oo`<000Eoo`03O0ioogoo015oo`03O1eoogoo04Yoo`00Qgoo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol01Goo0`0017oo00<007ooOol0
37oo00<007ooOol02goo00<007ooOol01Goo00<37gooOol00Woo00<007ooOol00Woo00<ch7ooOol0
0goo00=lh7ooOol01Goo00<007ooOol00Woo00<007oo00001Goo00=l3WooOol04Goo00=l7GooOol0
BWoo0027Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00
Oomoo`02Ool30007Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`<OOomoo`03
Ool00`00Oomoo`02Ool00c?POomoo`03Ool00`00O>1oo`05Ool00`00Oomoo`02Ool00`00Ool00005
Ool00g`>Oomoo`0BOol00g`MOomoo`19Ool008Moo`07001oogooOol007oo000027oo00<007ooOol0
27oo00<007ooOol02goo00@007oo000000Yoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo
00Aoo`030amoogoo00Aoo`03001oogoo009oo`03<n1oogoo009oo`03001oogcP00Ioo`03001oogoo
009oo`03001oo`0000Aoo`03O0ioogoo019oo`03O1eoogoo04Uoo`00R7oo00H007ooOol007oo0009
Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool2000=Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00
Oomoo`02Ool00`<OOomoo`05Ool00`00Oomoo`02Ool00c?POomoo`03Ool00`00Oomlh005Ool00`00
Oomoo`02Ool00`00Ool00004Ool00g`>Oomoo`0BOol00g`MOomoo`19Ool008Qoo`03001oo`00009o
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Qoo`<000ioo`03001oogoo00aoo`03001o
ogoo00]oo`03001oogoo009oo`030amoogoo00Eoo`03001oogoo00=oo`03<n1oogoo009oo`04001o
ogooO>04Ool00`00Oomoo`03Ool00`00Ool00003Ool00g`>Oomoo`0COol00g`MOomoo`18Ool008Qo
o`03001oo`0000=oo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Moo`05001oogooOol0
000>Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool01@00Oomoogoo0al02Goo00<007ooOol00Woo00<c
h7ooOol00goo00@007ooOomlh0Aoo`03001oogoo009oo`03001oo`0000=oo`03O0ioogoo01=oo`03
O1eoogoo04Qoo`00RGoo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0
17oo0P0017oo00<007ooOol037oo00<007ooOol037oo00<007ooOol02goo00@007ooOol37`Uoo`03
001oogoo00=oo`03<n1oogoo009oo`04001oogooO>04Ool00`00Oomoo`02Ool00`00Ool00003Ool0
0g`>Oomoo`0DOol00g`MOomoo`17Ool008Uoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo
00Qoo`03001oogoo009oo`8000Ioo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00]oo`04
001oogoo0al9Ool00`00Oomoo`08Ool01@00OomoogooO>0017oo00<007ooOol00Woo00<007oo0000
0Woo00=l3WooOol057oo00=l7GooOol0Agoo0029Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00
Oomoo`08Ool01@00Oomoogoo00002Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo
00<007oo0al02goo00<007ooOol027oo00D007ooOomoogcP00=oo`03001oogoo009oo`03001oo`00
009oo`03O0ioogoo01Aoo`03O1eoogoo04Moo`00RWoo00<007ooOol00Woo00<007ooOol01Woo00<0
07ooOol02Goo0`002Woo00<007ooOol037oo00<007ooOol037oo00<007ooOol02goo00<000<OOol0
2Woo00<007ooOol027oo00<007ooOol00Woo00Alh7ooOol000Eoo`05001oo`00Ooml3P0GOol00g`M
Oomoo`16Ool008Yoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Yo
o`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00]oo`030amoogoo00]oo`03001oogoo00Mo
o`03001oogoo00=oo`04O>1oogoo0004Ool01@00Ool007ooO0h05goo00=l7GooOol0AWoo002:Ool0
0`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`07Ool2000=Ool00`00Oomoo`0<Ool00`00Oomo
o`0;Ool00`00Oomoo`0;Ool00`<O001oo`0;Ool00`00Oomoo`08Ool00`00Oomoo`02Ool017cPOomo
o`0017oo00D007oo001oog`>01Qoo`03O1eoogoo04Eoo`00Rgoo00<007ooOol00Woo00<007ooOol0
1Woo00<007ooOol01Goo0P000Woo00<007ooOol02Woo00<007ooOol037oo00<007ooOol037oo00<0
07ooOol02Goo00<37goo000037oo00<007ooOol027oo00<007ooOol00goo00=lh7oo00001Goo00@0
07oo001l3QQoo`03O1eoogoo04Eoo`00Rgoo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol037oo00<007ooOol037oo00<007ooOol0
2Goo00<37goo00003Goo00<007ooOol027oo00<007ooOol00goo00=lh7oo000017oo00@007oo001l
3QQoo`03O1eoogoo04Eoo`00Rgoo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol02goo00<007ooOol037oo00<007ooOol037oo00<007ooOol027oo00@3
7gooOol000Iooa@000Aoo`03O>0007oo00Aoo`03001oo`0001Uoo`03O1eoogoo04Aoo`00S7oo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol00P001goo00<007ooOol02Woo00<007ooOol037oo
00<007ooOol037oo00<007ooOol01goo00<37goo000020001Woo00<007ooOol027oo00<007ooOol0
100000=oogcP000017oo00<007oo00006Goo00=l7GooOol0A7oo002<Ool00`00Oomoo`02Ool00`00
Oomoo`07Ool20009Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`05
Ool200001@<O001oogoo00003Goo00<007ooOol027oo00<007ooOol00goo0P0000=lh7ooOol00Woo
00<007oo00006Woo00=l7GooOol0@goo002<Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0400000goo0amo
o`04Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00O>000003Ool00`00Ool0
000IOol00g`MOomoo`13Ool008eoo`03001oogoo009oo`03001oogoo00Eoo`8000]oo`03001oogoo
00Yoo`03001oogoo00aoo`03001oogoo00]oo`@000Eoo`030amoogoo00=oo`03001oogoo00Yoo`03
001oogoo00Qoo`03001oogoo00Ioo`08O>1oo`00001oo`00Ool001Yoo`03O1eoogoo049oo`00SGoo
00<007ooOol00Woo00<007ooOol017oo00@007ooOol000Yoo`03001oogoo00]oo`03001oogoo00ao
o`03001oogoo00Qoo`800003Ool007oo00Eoo`030amoogoo00Eoo`03001oog`700Yoo`03001oogoo
00Qoo`03001oogoo00Eoo`04001lh7ooOol300000goo001oo`0HOol00g`MOomoo`12Ool008eoo`03
001oogoo00=oo`03001oogoo009oo`05001oogooOol0000;Ool00`00Oomoo`0:Ool00`00Oomoo`0<
Ool00`00Oomoo`05Ool30004Ool00`00Oomoo`03Ool00`<OOomoo`05Ool00`00Oomoo`0:Ool00`00
Oomoo`08Ool00`00Oomoo`05Ool00`00Oomlh003Ool00`00Ool0000IOol00g`MOomoo`12Ool008eo
o`03001oogoo00=oo`05001oogooOol00004Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`0<Ool00`00Oomoo`02Ool30007Ool00`00Oomoo`03Ool00`<OOomoo`05Ool00`00Oomoo`0:Ool0
0`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomlh002Ool2000KOol00g`MOomoo`11Ool008ioo`03
001oogoo009oo`04001oogoo0006Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool0
1000Ool000002Woo00<007ooOol00Woo00<37gooOol01goo00<007ooOol02Woo00<007ooOol027oo
00<007ooOol01Goo00@007ooOomlh09oo`<001Uoo`03O1eoogoo045oo`00SWoo00<007ooOol00goo
0P001goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02goo0`003Goo00D007ooOomoo`<O
00Uoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Eoo`06001oogooOomlh7oo0P006goo
00=l7GooOol0@7oo002>Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool200000goo001oo`0=Ool01000Oomoo`<O2Woo00<007ooOol02Woo00<0
07ooOol027oo00<007ooOol01Woo00L007ooOomoogcP001oo`02000IOol00g`MOomoo`10Ool008mo
o`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo00Io
o`8000Aoo`03001oogoo00]oo`04001oogoo0al;Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool017cP001oo`006Goo00=l7GooOol0@7oo002?Ool01`00Oomoogoo
001oo`0000Qoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Aoo`8000Ioo`03001oogoo
00aoo`0300037goo00]oo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo
009oo`04O>0007oo000JOol00g`MOomoo`0oOol008moo`07001oogooOol007oo00002Goo00<007oo
Ool027oo00<007ooOol02Woo00<007ooOol00Woo0P0027oo00<007ooOol037oo00<000<OOol037oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol00Woo00Alh000Ool001Uo
o`03O1eoogoo03moo`00T7oo00<007oo00000Woo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool02goo00@007oo000000]oo`03001oogoo00]oo`0300037goo00aoo`03001oogoo00Yoo`03001o
ogoo00Qoo`03001oogoo00Eoo`03001oogoo00=oo`03O>1oo`0001Yoo`03O1eoogoo03ioo`00T7oo
00<007oo00000goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol02Woo0P003Goo00<007oo
Ool02goo00<37`00Ool037oo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Goo00<007oo
Ool00goo00<007cP00006Woo00=l7GooOol0?Woo002@Ool00`00Ool00003Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool3000>Ool00`00Oomoo`0;Ool00`<O001oo`0=Ool00`00Oomo
o`0:Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00O>00000IOol00g`MOomo
o`0nOol0095oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Eoo`80
00=oo`03001oogoo00aoo`03001oogoo00Uoo`030amoo`0000ioo`03001oogoo00Yoo`03001oogoo
00Qoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogcP01Yoo`03O1eoogoo03eoo`00TGoo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol00goo0P001Goo00<007ooOol0
37oo00<007ooOol02Goo00@37gooOol000ioo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo
00Ioo`03001oogoo009oo`04001oogooO>0IOol00g`MOomoo`0mOol0095oo`03001oogoo00=oo`03
001oogoo00Moo`03001oogoo00Qoo`04001oogooOol20007Ool00`00Oomoo`0<Ool00`00Oomoo`08
Ool01@<OOomoogoo00003Woo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Goo00<007oo
Ool00goo00@007oo001lh1Uoo`03O1eoogoo03aoo`00TWoo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol02Goo0`002Woo00<007ooOol037oo00<007ooOol01goo00<37gooOol00Woo00<007oo
Ool02goo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo00@007oo
001lh1Uoo`03O1eoogoo03aoo`00TWoo00<007ooOol00goo00<007ooOol01Woo00<007ooOol02Goo
00<007ooOol02Woo00<007ooOol037oo00<007ooOol01goo00<37gooOol00Woo00<007ooOol037oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol00Woo00D007ooOol007cP
01Qoo`03O1eoogoo03aoo`00TWoo00<007ooOol00goo00<007ooOol01goo00<007ooOol01goo0P00
3Goo00<007ooOol02goo00<007ooOol01Woo00<37gooOol00goo00<007ooOol037oo00<007ooOol0
2Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo00D007oo001oogcP01Qoo`03O1eo
ogoo03]oo`00Tgoo00<007ooOol00Woo00<007ooOol01goo00<007ooOol01Goo0P000Woo00<007oo
Ool02Woo00<007ooOol037oo00<007ooOol01Goo00<37gooOol017oo00<007ooOol02goo00<007oo
Ool02Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo00<007oo00000Woo00=lh7oo
Ool05Goo00=l7GooOol0>goo002COol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`<OOomoo`05Ool0
0`00Oomoo`0<Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00=lh7ooOol05Goo00=l7GooOol0>Woo002COol00`00Oomoo`03Ool00`00Oomo
o`07Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomo
o`03Ool00`<OOomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomo
o`05Ool00`00Oomoo`03Ool00`00Ool00003Ool00gcPOomoo`0DOol00g`MOomoo`0jOol009Aoo`03
001oogoo00=oo`03001oogoo00Ioo`03001oogoo008000Moo`03001oogoo00Yoo`03001oogoo00ao
o`03001oogoo009oo`030amoogoo00Moo`03001oogoo00aoo`03001oogoo00Aooa<000Eoo`03001o
ogoo00=oo`04001oogoo0003Ool00gcPOomoo`0COol00g`MOomoo`0jOol009Aoo`03001oogoo00=o
o`03001oogoo00Moo`8000Uoo`03001oogoo00Yoo`03001oogoo00aoo`03001oogoo009oo`030amo
ogoo00Moo`03001oogoo00Yoo`T000Eoo`03001oogoo00Qoo`03001oogoo00@0009oo`03001oogoo
00=oo`03001oo`0000Aoo`03O>1oogoo01=oo`03O1eoogoo03Uoo`00U7oo00<007ooOol00goo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol02goo00<007ooOol037oo00D007ooOomoo`<O00Uo
o`03001oogoo00Ioo`@0009oo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00=oo`@000Ao
o`03001oo`0000Aoo`03O>1oogoo01=oo`03O1eoogoo03Uoo`00UGoo00<007ooOol00goo00<007oo
Ool01Goo0P002goo00<007ooOol02Woo00<007ooOol037oo00@007ooOol37`]oo`03001oogoo00D0
00Moo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Eoo`04001oo`000002Ool01000Oomo
o`0017oo00=lh7ooOol04goo00=l7GooOol0>7oo002EOol00`00Oomoo`03Ool00`00Oomoo`04Ool0
1000Oomoo`002Woo00<007ooOol02Woo00<007ooOol037oo00@007ooOol37`Yoo`@000aoo`03001o
ogoo00Yoo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo00800004Ool007oo0005Ool00gcP
Oomoo`0BOol00g`MOomoo`0hOol009Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol0
000:Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`000amoo`08Ool200000goo001oo`0=Ool00`00
Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`02Ool20008Ool00gcPOomoo`0A
Ool00g`MOomoo`0hOol009Eoo`03001oogoo00Aoo`05001oogooOol00004Ool00`00Oomoo`09Ool0
0`00Oomoo`0:Ool00`00Oomoo`0<Ool00`000amoo`04Ool017`70000000017oo00<007ooOol037oo
00<007ooOol02Goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol00Woo0P0000=oo`00Ool0
1Goo00=lh7ooOol04Goo00=l7GooOol0=goo002FOol00`00Oomoo`03Ool01@00Oomoogoo00001Goo
00<007ooOol027oo00<007ooOol02Woo00<007ooOol037oo00<37gooOol00Woo0`001goo00<007oo
Ool037oo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo0P0027oo
00=lh7ooOol047oo00=l7GooOol0=goo002FOol00`00Oomoo`03Ool01000Oomoo`001Woo00<007oo
Ool027oo00<007ooOol02goo00<007ooOol02goo00<37`00Ool00P002goo00<007ooOol02goo00<0
07ooOol02Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo00@007oo000000Ioo`03
O>1oogoo015oo`03O1eoogoo03Ioo`00UWoo00<007ooOol017oo0P001goo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02goo00<37`0000003Goo00<007ooOol037oo00<007ooOol02Goo00<0
07ooOol027oo00<007ooOol01Woo00<007ooOol00goo00<007oo00001goo00=lh7ooOol047oo00=l
7GooOol0=Woo002GOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0;
Ool00`00Oomoo`08Ool010000amoo`003Woo00<007ooOol037oo00<007ooOol02Woo00<007ooOol0
27oo00<007ooOol01Goo00<007ooOol00goo00<007oo000027oo00=lh7ooOol047oo00=l7GooOol0
=Goo002GOol00`00Oomoo`02Ool20009Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`05
Ool300001Goo0amoogoo00003Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol027oo00<0
07ooOol01Woo00<007ooOol00Woo00@007ooOol000Qoo`03O>1oogoo00moo`03O1eoogoo03Eoo`00
Ugoo00<007ooOol00Woo00<007oo000027oo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol0
0Woo0`000goo00D37gooOomoo`0000ioo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Qo
o`03001oogoo00Eoo`03001oogoo00=oo`03001oo`0000Uoo`03O>1oogoo00ioo`03O1eoogoo03Eo
o`00V7oo00@007ooOol0009oo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00]oo`04001o
o`000006Ool01@<OOomoogoo00003Woo00<007ooOol037oo00<007ooOol02Woo00<007ooOol027oo
00<007ooOol01Goo00<007ooOol00goo00@007ooOol000Uoo`03O>1oogoo00ioo`03O1eoogoo03Ao
o`00V7oo00@007ooOol0009oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Yoo`8000Mo
o`030amoogoo00=oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Qo
o`03001oogoo00Ioo`03001oogoo00=oo`03001oo`0000Uoo`03O>1oogoo00ioo`03O1eoogoo03Ao
o`00V7oo00<007oo000017oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol027oo0`0027oo
00<37gooOol00goo00<007ooOol037oo00<007ooOol037oo00<007ooOol02Woo00<007ooOol027oo
00<007ooOol01Goo00<007ooOol00goo00<007oo00002Woo00=lh7ooOol03Woo00=l7GooOol0<goo
002IOol20004Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`07Ool01@00Oomoogoo0000
1goo00<37gooOol00goo00<007ooOol03Goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol0
27oo00<007ooOol01Woo00<007ooOol00Woo00@007ooOol000Yoo`03O>1oogoo00eoo`03O1eoogoo
03=oo`00VGoo00<007ooOol00goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol017oo0P00
17oo00<007ooOol017oo00<37gooOol01Goo00<007ooOol037oo00<007ooOol037oo00<007ooOol0
2Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo00<007oo00002goo00=lh7ooOol0
37oo00=l7GooOol0<goo002IOol00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00
Oomoo`02Ool20006Ool00`00Oomoo`04Ool00`<OOomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`0<
Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Ool0000<
Ool00gcPOomoo`0<Ool00g`MOomoo`0bOol009Yoo`03001oogoo00=oo`03001oogoo00Ioo`03001o
ogoo00Uoo`05001oogooOol00009Ool00`00Oomoo`02Ool00`<OOomoo`06Ool00`00Oomoo`0=Ool0
0`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`03Ool0
0`00Ool0000<Ool00gcPOomoo`0;Ool00g`MOomoo`0bOol009Yoo`03001oogoo00=oo`03001oogoo
00Moo`03001oogoo00Uoo`<000Yoo`03001oogoo009oo`030amoogoo00Moo`03001oogoo00aoo`03
001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo00=oo`03
001oo`0000aoo`03O>1oogoo00aoo`03O1eoogoo035oo`00VWoo00<007ooOol017oo00<007ooOol0
1Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol00Woo00<37gooOol01goo00<007ooOol0
3Goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0
0Woo00@007ooOol000aoo`03O>1oogoo00]oo`03O1eoogoo035oo`00Vgoo00<007ooOol00goo00<0
07ooOol01Woo00<007ooOol01goo0`003Goo00@007ooOol37`Yoo`03001oogoo00eoo`03001oogoo
00]oo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00=oo`03001oo`00
00eoo`03O>1oogoo00Yoo`03O1eoogoo035oo`00Vgoo00<007ooOol00goo00<007ooOol01Woo00<0
07ooOol01Woo00D007ooOomoo`0000aoo`04001oogoo0al;Ool00`00Oomoo`0<Ool00`00Oomoo`0<
Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Ool0000>
Ool00gcPOomoo`0:Ool00g`MOomoo`0`Ool009]oo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo00Aoo`03001oogoo009oo`03001oogoo00Yoo`03001oo`<O00aoo`03001oogoo00eoo`03001o
ogoo00]oo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00=oo`03001o
o`0000ioo`03O>1oogoo00Uoo`03O1eoogoo031oo`00W7oo00<007ooOol00goo00<007ooOol01Woo
00<007ooOol00Woo0P001Goo00<007ooOol02goo00<000<OOol037oo00<007ooOol037oo00<007oo
Ool02goo00<007ooOol02goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo00<007oo
00003goo00=lh7ooOol02Goo00=l7GooOol0;goo002LOol00`00Oomoo`03Ool00`00Oomoo`06Ool0
1@00Oomoogoo000027oo00<007ooOol02Woo00<000<OOol037oo00<007ooOol037oo00<007ooOol0
37oo00<007ooOol017oo5P0017oo00<007ooOol00Woo00@007ooOol000ioo`03O>1oogoo00Uoo`03
O1eoogoo02moo`00W7oo00<007ooOol00goo00<007ooOol01goo0`002Goo00<007ooOol02Woo00<3
7gooOol037oo00<007ooOol03Goo00<007ooOol02Goo2@001Woo00<007ooOol027oo00<007ooOol0
0Woo1P0017oo00<007oo00003goo00=lh7ooOol027oo00=l7GooOol0;goo002MOol00`00Oomoo`03
Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`<O001oo`0=Ool00`00Oomoo`0<
Ool00`00Oomoo`05Ool40002Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`05Ool01000
Ool000000Woo00<007oo000047oo00=lh7ooOol027oo00=l7GooOol0;Woo002MOol00`00Oomoo`03
Ool00`00Oomoo`05Ool2000<Ool00`00Oomoo`08Ool00`<OOol0000>Ool00`00Oomoo`0=Ool00`00
Oomoo`040007Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`020000
17oo001oo`0047oo00=lh7ooOol01goo00=l7GooOol0;Woo002MOol00`00Oomoo`03Ool00`00Oomo
o`04Ool01000Oomoo`002goo00<007ooOol027oo00<37goo00003Woo00<007ooOol037oo10002goo
00<007ooOol02goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00Woo0P0000=oo`00Ool0
47oo00=lh7ooOol01goo00=l7GooOol0;Goo002MOol00`00Oomoo`04Ool00`00Oomoo`02Ool01@00
Oomoogoo00002goo00<007ooOol01goo00D37gooOomoo`0000ioo`03001oogoo00Qoo`<00003Ool0
07oo00aoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo00=oo`8001=o
o`03O>1oogoo00Ioo`03O1eoogoo02eoo`00WWoo00<007ooOol00goo00D007ooOomoo`0000Aoo`03
001oogoo00Yoo`03001oogoo00Ioo`050amoogooOol0000>Ool00`00Oomoo`06Ool20005Ool00`00
Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`03Ool3000A
Ool00gcPOomoo`06Ool00g`MOomoo`0]Ool009ioo`03001oogoo00=oo`04001oogoo0006Ool00`00
Oomoo`09Ool00`00Oomoo`05Ool00`<OOomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool30007
Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`03
Ool2000COol00gcPOomoo`06Ool00g`MOomoo`0/Ool009ioo`03001oogoo00Aoo`8000Moo`03001o
ogoo00Uoo`03001oogoo00Eoo`030amoogoo00=oo`03001oogoo00aoo`03001oo`00008000Yoo`03
001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00=oo`<0
019oo`03O>1oogoo00Eoo`03O1eoogoo02aoo`00Wgoo00<007ooOol00goo00<007ooOol01Woo00<0
07ooOol02Woo00<007ooOol00goo00<37gooOol017oo00<007ooOol02goo0`003Woo00<007ooOol0
2goo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol00goo00<007oo0000
4goo00=lh7ooOol01Goo00=l7GooOol0:goo002OOol00`00Oomoo`02Ool20009Ool00`00Oomoo`09
Ool00`00Oomoo`03Ool00`<OOomoo`04Ool00`00Oomoo`09Ool200000goo001oo`0>Ool00`00Oomo
o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Ool0
000DOol00gcPOomoo`04Ool00g`MOomoo`0[Ool009moo`03001oogoo009oo`03001oo`0000Qoo`03
001oogoo00Yoo`05001oogooOol37`08Ool00`00Oomoo`06Ool20004Ool00`00Oomoo`0<Ool00`00
Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00
Ool0000DOol00gcPOomoo`03Ool00g`MOomoo`0[Ool00:1oo`04001oogoo0002Ool00`00Oomoo`06
Ool00`00Oomoo`0:Ool01@00Oomoogoo0al027oo00<007ooOol017oo0P001Woo00<007ooOol03Goo
00<007ooOol02goo00<007ooOol02goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo
00<007oo000057oo00=lh7ooOol017oo00=l7GooOol0:Woo002POol01000Oomoo`000Woo00<007oo
Ool01goo00<007ooOol02Goo00D007ooOomoo`<O00Qoo`03001oogoo009oo`8000Qoo`03001oogoo
00eoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo
00=oo`03001oo`0001Eoo`03O>1oogoo00=oo`03O1eoogoo02Yoo`00X7oo00<007oo000017oo00<0
07ooOol01Woo00<007ooOol02Woo00<007oo0al02Woo00@007oo000000]oo`03001oogoo00aoo`03
001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00=oo`03
001oo`0001Eoo`03O>1oogoo00=oo`03O1eoogoo02Uoo`00XGoo0P0017oo00<007ooOol01Woo00<0
07ooOol02Woo00<007oo0al02Woo0P003Goo00<007ooOol03Goo00<007ooOol02goo00<007ooOol0
2goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo00<007oo00000doP4goo00=lh7oo
Ool00Woo00=l7GooOol0:Goo002QOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`09Ool0
0`000amoo`08Ool3000>Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomo
o`08Ool00`00Oomoo`06Ool00`00Oomoo`03Ool20003Ool3Cn0AOol00gcPOomoo`02Ool00g`MOomo
o`0XOol00:5oo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Yoo`040amoogooO0L4Ool2
0003Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomo
o`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Ool00005Ool2Cn0@Ool01GcPOomoogooO1d0
:Woo002ROol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`08Ool010<O001oog`70goo0P00
1Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol0
27oo00<007ooOol01Goo00<007ooOol00goo00<007oo00001goo0doP3Goo00Elh7ooOomoog`M02Yo
o`00XWoo00<007ooOol00goo00<007ooOol01goo00<007ooOol027oo00<37`00O0L00Woo0P001goo
00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol02Woo00<007ooOol027oo
00<007ooOol01Woo00<007ooOol00goo0P002Woo0ToP37oo00Elh7ooOomoog`M02Uoo`00XWoo00<0
07ooOol017oo00<007ooOol01Woo00<007ooOol01goo00@37gooOoml1`8000Yoo`03001oogoo00ao
o`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Eo
o`03001oogoo00=oo`03001oo`0000]oo`=?h0Yoo`04O>1oogooO1dYOol00:=oo`03001oogoo00=o
o`03001oogoo00Moo`03001oogoo00Ioo`040amoog`7000<Ool00`00Oomoo`0<Ool00`00Oomoo`0=
Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool2000>Ool2Cn09Ool017cPOomoog`M:7oo002SOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00
Oomoo`05Ool01@<OOol007`7000037oo00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo
00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol00goo0P0047oo0doP1goo
00=lh7ooO1d00P0O9Woo002SOol00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`<O
001l1`02Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Ool0000BOol2Cn06
Ool00gcP01l07`0301lTOol00:Aoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`04
0al007ooO0L2Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool0
0`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`03Ool2000DOol3Cn02Ool0
0`0OO>007`0501lSOol00:Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo009oo`040003
7gooO0L3Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Ool0000FOol2Cn02
01l00gcP01l07`0301lSOol00:Aoo`03001oogoo00Aoo`03001oogoo00Ioo`09001oogooOol007oo
0amoog`700Aoo`03001oogoo00Yoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03
001oogoo00Qooa4000Eoo`03001oogoo00=oo`03001oo`0001Moo`@07`03O>007`0O00<07b9oo`00
YGoo00<007ooOol00goo00<007ooOol01goo0`0000Aoo`<OOoml1`Eoo`03001oogoo00Yoo`03001o
ogoo00aoo`03001oogoo00eoo`03001oogoo00aoo`04001oogooOol60003Ool00`00Oomoo`08Ool0
0`00Oomoo`040002Ool00`00Oomoo`03Ool2000GOol201l30ol00gcP01l07`0201lROol00:Eoo`03
001oogoo00Aoo`03001oogoo00Ioo`07001oogooOol37gooO0L01Goo00<007ooOol02Woo00<007oo
Ool037oo00<007ooOol03Goo00<007ooOol02Woo1P002Woo00<007ooOol027oo00<007ooOol00goo
100017oo00<007oo00004Woo1P?o1`0O8goo002UOol00`00Oomoo`04Ool00`00Oomoo`05Ool20002
Ool00`<OOoml1`07Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`06
Ool40002Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Ool0000300000goo
0000000;Ool70ol5Ool801lSOol00:Ioo`03001oogoo00=oo`03001oogoo00Aoo`07001oogoo001o
o`<OO0L027oo00<007ooOol02Woo00<007ooOol037oo00<007ooOol03Goo00<007ooOol01@001goo
00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol00Woo0`001Goo1P?o3Goo
1P0O97oo002VOol00`00Oomoo`04Ool00`00Oomoo`02Ool02000Oomoogoo00037gooO0L8Ool00`00
Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool4000<Ool00`00Oomoo`0;Ool00`00Oomoo`08
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`000ol3o`040olEOol201lVOol00:Moo`03001oogoo
00=oo`05001oogooOol00004Ool00`000aml1`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00
Oomoo`08Ool300000goo001oo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`06Ool0
0`00Oomoo`03Ool20011Ool00:Moo`03001oogoo00=oo`04001oogoo0005Ool00`<O001l1`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool20005Ool00`00Oomoo`0<Ool00`00Oomo
o`0;Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool20011Ool00:Moo`03001oogoo
00Aoo`8000Ioo`030aml1goo00Yoo`03001oogoo00Yoo`03001oogoo00aoo`03001oogoo00=oo`<0
00Moo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo
00=oo`<0041oo`00Z7oo00<007ooOol00goo00<007ooOol017oo00<37gooO0L037oo00<007ooOol0
2Woo00<007ooOol037oo00<007oo00000P002Woo00<007ooOol03Goo00<007ooOol02Woo00<007oo
Ool027oo00<007ooOol01Woo00<007ooOol00goo0P00@7oo002XOol00`00Oomoo`02Ool20006Ool0
10<OO0Moo`002goo00<007ooOol02Woo00<007ooOol02goo0`003Woo00<007ooOol037oo00<007oo
Ool02goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo0P00@7oo002XOol00`00Oomo
o`02Ool00`00Ool00005Ool010<OO0Moo`002goo00<007ooOol02Woo00<007ooOol02Goo0P0000=o
o`00Ool03Woo00<007ooOol037oo00<007ooOol02goo00<007ooOol027oo00<007ooOol01Goo00<0
07ooOol017oo0P00?goo002YOol01000Oomoo`000Woo00<007ooOol00Woo00D37g`7Oomoo`0000ao
o`03001oogoo00Yoo`03001oogoo00Ioo`8000Aoo`03001oogoo00aoo`03001oogoo00eoo`03001o
ogoo00Yoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00=oo`8003moo`00ZGoo00@007oo
Ool0009oo`03001oogoo009oo`030amoogoo009oo`03001oogoo00Qoo`030Sl007oo00]oo`03001o
ogoo00Aoo`8000Ioo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Qo
o`03001oogoo00Eoo`03001oogoo00=oo`03001oo`0003ioo`00ZGoo00<007oo000017oo00D007oo
Ool37g`700Aoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo009oo`8000Qoo`03001oogoo
00eoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo
00=oo`8003ioo`00ZWoo0P0017oo00@007ooOol37`Eoo`03001oogoo00Yoo`03001oogoo00Yoo`04
001oo`00000;Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool0
0`00Oomoo`05Ool00`00Oomoo`03Ool2000nOol00:Yoo`03001oogoo00=oo`04001oo`<OO0L6Ool0
0`00Oomoo`020Sl7Ool00`00Oomoo`0:Ool2000=Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Ool0000mOol00:Yo
o`03001oogoo00Aoo`0300037goo00Ioo`03001oogoo00Uoo`03001oogoo00Qoo`<000moo`03001o
ogoo00aoo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Ioo`03001o
ogoo00=oo`8003eoo`00Zgoo00<007ooOol00goo00<37g`7Ool01Woo0P8o2goo00<007ooOol01Goo
0P000goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol02goo00<007oo
Ool027oo00<007ooOol01Goo00<007ooOol00goo0P00?Goo002[Ool01000Oomoogoo0P0O00<37goo
Ool017oo0P8o00=oo`00Ool02Woo00@007ooOomoo`<3o`03001oogoo00=oo`03001oogoo00aoo`03
001oogoo00eoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Ioo`03
001oogoo00=oo`8003aoo`00Zgoo00<007oo01l01@0O0goo0P8o0goo00<007ooOol01goo1P?o0P00
1goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol0
27oo00<007ooOol01Woo00<007ooOol00goo0P00?7oo002/Ool801l20Sl5Ool00`00Ool3o`070ol3
Ool3000:Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00
Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Ool0000kOol00:aoo`P07`T3o`]oo`03
001oogoo00Yoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00]oo`03
001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00=oo`8003]oo`00Zgoo2P0O1goo00<007ooOol0
1goo0`003Goo00<007ooOol037oo00<007ooOol037oo00<007ooOol03Goo00<007ooOol02goo00<0
07ooOol027oo00<007ooOol01Goo00<007ooOol00goo0P00>goo002[Ool:01l7Ool00`00Oomoo`06
Ool01@00Oomoogoo000037oo00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo00<007oo
Ool02goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo00<007oo0000>Woo002/Ool8
01l9Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomo
o`03Ool2000jOol00:aoo`P07`03001oogoo00Ioo`03001oogoo009oo`8000Eoo`03001oogoo00]o
o`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00Qo
o`03001oogoo00Eoo`03001oogoo00=oo`03001oo`0003Uoo`00[Goo1P0O00=oo`00Ool01goo00D0
07ooOomoo`0000Qoo`03001oogoo00Yoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00ao
o`03001oogoo00Qooa<000Aoo`03001oogoo00=oo`8003Uoo`00[Woo00<0000O01l00goo00<007oo
Ool01goo0`002Goo00<007ooOol02Woo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo
00@007ooOomoo`H000=oo`03001oogoo00Qoo`03001oogoo009oo`H000Aoo`03001oogoo03Qoo`00
[Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol02goo00<007ooOol0
37oo00<007ooOol03Goo00<007ooOol02goo1@002Woo00<007ooOol027oo00<007ooOol01Goo00@0
07oo0000009oo`03001oo`0003Qoo`00[goo00<007ooOol00goo00<007ooOol01Goo0P0037oo00<0
07ooOol02Woo00<007ooOol037oo00<007ooOol03Goo00<007ooOol01goo100000=oo`00Ool037oo
00<007ooOol027oo00<007ooOol01Woo00<007ooOol00P0000=oo`000000>7oo002_Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool01000Oomoo`002goo00<007ooOol02goo00<007ooOol037oo00<007oo
Ool037oo00<007ooOol017oo0`001Woo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Woo
00<007ooOol00Woo0P00>Goo002_Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo0000
2goo00<007ooOol02goo00<007ooOol037oo00<007ooOol03Goo00<007oo00000`002Goo00<007oo
Ool02goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo0`00=goo002`Ool00`00Oomo
o`03Ool01@00Oomoogoo000017oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol03Goo00<0
07ooOol02goo0`003Goo00<007ooOol02goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0
0goo00<007ooOol0=Woo002`Ool00`00Oomoo`03Ool01000Oomoo`001Woo00<007ooOol02Goo00<0
07ooOol02goo00<007ooOol037oo00<007ooOol01goo100000=oo`00Ool03Woo00<007ooOol02Woo
00<007ooOol027oo00<007ooOol01Woo00<007ooOol00goo0`00=Woo002`Ool00`00Oomoo`04Ool2
0007Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool30006Ool0
0`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool0
0`00Ool0000fOol00;5oo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00eoo`03001oo`0000<000Uoo`03001oogoo00aoo`03001oogoo00]oo`03001o
ogoo00Qoo`03001oogoo00Ioo`03001oogoo00=oo`8003Ioo`00/Goo00<007ooOol00Woo0P002Goo
00<007ooOol02Goo00<007ooOol02goo00<007ooOol02goo0`003Goo00<007ooOol03Goo00<007oo
Ool02goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo00<007oo0000=Goo002aOol0
0`00Oomoo`02Ool00`00Ool00008Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool2
00000goo001oo`0>Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`06
Ool00`00Oomoo`03Ool2000eOol00;9oo`04001oogoo0002Ool00`00Oomoo`06Ool00`00Oomoo`0:
Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool20004Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00
Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Ool0000dOol00;9o
o`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`04
Ool20006Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00
Oomoo`05Ool00`00Oomoo`03Ool00`00Ool0000dOol00;9oo`03001oo`0000Aoo`03001oogoo00Io
o`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo009oo`8000Qoo`03001oogoo00eoo`03001o
ogoo00aoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00=oo`8003Ao
o`00/goo0P0017oo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol02goo00@007oo000000]o
o`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Io
o`03001oogoo00=oo`03001oo`0003=oo`00/goo00<007ooOol00goo00<007ooOol01goo00<007oo
Ool02Goo00<007ooOol02goo0P003Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol02goo
00<007ooOol027oo00<007ooOol01Goo00<007ooOol00goo00<007oo0000<goo002cOol00`00Oomo
o`04Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`09Ool3000>Ool00`00Oomoo`0=Ool0
0`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`03Ool0
0`00Ool0000bOol00;Aoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo
00Ioo`8000=oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00Yoo`03
001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00=oo`03001oo`00039oo`00]7oo00<007ooOol0
0goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol017oo0P001Goo00<007ooOol037oo00<0
07ooOol03Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol027oo00<007ooOol01Goo00<0
07ooOol017oo0P00<Woo002dOol00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00
Oomoo`02Ool20007Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0;
Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Ool0000aOol00;Aoo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00Yoo`04001oo`00000:Ool00`00Oomoo`0<Ool00`00
Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00
Oomoo`03Ool00`00Ool0000aOol00;Eoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Uo
o`8000aoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00]oo`03001o
ogoo00Qoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oo`00031oo`00]Goo00<007ooOol017oo
00<007ooOol01Woo00<007ooOol01goo0`003Goo00<007ooOol03Goo00<007ooOol037oo00<007oo
Ool037oo00<007ooOol02goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol00goo00<007oo
0000<7oo002eOol00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`06Ool01@00Oomoogoo0000
3Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol0
27oo00<007ooOol01Goo00<007ooOol00goo00@007ooOol002moo`00]Woo00<007ooOol00goo00<0
07ooOol01goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol037oo00<0
07ooOol03Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol027oo00<007ooOol01Woo00<0
07ooOol00goo00<007oo0000;goo002fOol00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`02
Ool20005Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00
Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Ool0000_Ool00;Io
o`03001oogoo00Aoo`03001oogoo00Ioo`05001oogooOol00008Ool00`00Oomoo`0;Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Ool0000^Ool00;Moo`03001oogoo00=oo`03001oogoo00Moo`<0
00Uoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo
00Qooa<000Aoo`03001oogoo00=oo`03001oo`0002ioo`00]goo00<007ooOol017oo00<007ooOol0
1Woo00<007ooOol02Goo00<007ooOol037oo00<007ooOol037oo00<007ooOol03Goo00<007ooOol0
37oo00@007ooOomoo`H000=oo`03001oogoo00Qoo`03001oogoo009oo`H000Aoo`04001oogoo000]
Ool00;Moo`03001oogoo00Aoo`03001oogoo00Eoo`8000aoo`03001oogoo00]oo`03001oogoo00ao
o`03001oogoo00eoo`03001oogoo00Yoo`H000Yoo`03001oogoo00Qoo`03001oogoo00Eoo`03001o
o`0000<00004Ool007oo000]Ool00;Moo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo000;
Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`06Ool40002Ool00`00
Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`02Ool2000_Ool00;Qoo`03001o
ogoo00Aoo`03001oogoo009oo`05001oogooOol0000<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool0
0`00Oomoo`0=Ool00`00Oomoo`050007Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`05
Ool00`00Oomoo`03Ool200000goo001oo`0[Ool00;Qoo`03001oogoo00Aoo`05001oogooOol00004
Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool4000<Ool00`00
Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`03Ool2000]Ool00;Qoo`03001o
ogoo00Aoo`04001oogoo0006Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00
Oomoo`08Ool300000goo001oo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`06Ool0
0`00Oomoo`03Ool01000Ool00000:goo002iOol00`00Oomoo`04Ool20007Ool00`00Oomoo`0:Ool0
0`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool20005Ool00`00Oomoo`0<Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01000Oomoo`00:goo002iOol0
0`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool0
0`00Oomoo`03Ool30007Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomo
o`06Ool00`00Oomoo`03Ool00`00Ool0000[Ool00;Uoo`03001oogoo00=oo`8000Uoo`03001oogoo
00Uoo`03001oogoo00]oo`03001oogoo00eoo`03001oo`00008000Yoo`03001oogoo00aoo`03001o
ogoo00]oo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00=oo`04001oogoo000ZOol00;Yo
o`03001oogoo009oo`03001oo`0000Qoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]o
o`<000ioo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00Ioo`03001o
ogoo009oo`04001oogoo000ZOol00;Yoo`05001oogooOol00002Ool00`00Oomoo`07Ool00`00Oomo
o`09Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool200000goo001oo`0>Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Ool0000ZOol00;Yo
o`04001oogoo0003Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0<Ool00`00Oomoo`06
Ool20004Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`05Ool00`00Oomoo`03Ool01000Oomoo`00:Goo002jOol00`00Ool00005Ool00`00Oomoo`06
Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`0=Ool00`00
Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00
Ool0000YOol00;]oo`8000Eoo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00]oo`03001o
ogoo009oo`8000Qoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Qo
o`03001oogoo00Ioo`03001oogoo00=oo`03001oo`0002Uoo`00^goo00<007ooOol017oo00<007oo
Ool01goo00<007ooOol02Goo00<007ooOol037oo00@007oo000000]oo`03001oogoo00aoo`03001o
ogoo00eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00=oo`04001o
ogoo000XOol00;]oo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00]o
o`8000eoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Qoo`03001o
ogoo00Ioo`03001oogoo00=oo`03001oo`0002Qoo`00_7oo00<007ooOol017oo00<007ooOol01goo
00<007ooOol02Goo00<007ooOol02Goo0`003Woo00<007ooOol03Goo00<007ooOol037oo00<007oo
Ool02goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol00goo00@007ooOol002Moo`00_7oo
00<007ooOol017oo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01Woo0P000goo00<007oo
Ool037oo00<007ooOol037oo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol02Goo00<007oo
Ool01Woo00<007ooOol00Woo00@007ooOol002Moo`00_7oo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol02Woo00<007ooOol017oo0P001Goo00<007ooOol037oo00<007ooOol03Goo00<007oo
Ool037oo00<007ooOol02goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol00goo00<007oo
00009goo002mOol00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`02Ool2
0007Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomo
o`09Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01000Oomoo`009Woo002mOol00`00Oomoo`04Ool0
0`00Oomoo`07Ool00`00Oomoo`0:Ool01000Ool000002Woo00<007ooOol037oo00<007ooOol03Goo
00<007ooOol037oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol00Woo
00@007ooOol002Ioo`00_Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol02Woo0P0037oo
00<007ooOol037oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02Goo
00<007ooOol01Goo00<007ooOol00goo00<007oo00009Woo002nOol00`00Oomoo`04Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool3000=Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool0
0`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`009Goo
002nOol00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`06Ool01@00Oomoogoo000037oo00<0
07ooOol03Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol027oo00<0
07ooOol01Woo00<007ooOol00Woo00@007ooOol002Eoo`00_goo00<007ooOol00goo00<007ooOol0
27oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol037oo00<007ooOol0
3Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0
0goo00<007oo00009Goo002oOol00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`02Ool20005
Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`0097oo002oOol00`00
Oomoo`04Ool00`00Oomoo`07Ool01@00Oomoogoo000027oo00<007ooOol02Woo00<007ooOol03Goo
00<007ooOol03Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02Goo00<007ooOol01Goo
00<007ooOol00goo00<007oo000097oo0030Ool00`00Oomoo`03Ool00`00Oomoo`08Ool30009Ool0
0`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`08OolD
0004Ool00`00Oomoo`02Ool00`00Ool0000TOol00<1oo`03001oogoo00Aoo`03001oogoo00Moo`03
001oogoo00Uoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`04
001oogooOol6000;Ool00`00Oomoo`05Ool70003Ool01000Oomoo`008goo0031Ool00`00Oomoo`03
Ool00`00Oomoo`06Ool2000;Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00
Oomoo`0;Ool50003Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`04Ool3000017oo001o
o`008goo0031Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`002goo00<007ooOol02goo
00<007ooOol037oo00<007ooOol03Goo00<007ooOol01goo10002Goo00<007ooOol01goo0`002Goo
00<007ooOol017oo00@007oo0000009oo`03001oogoo021oo`00`Goo00<007ooOol017oo00<007oo
Ool00goo00D007ooOomoo`0000]oo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo00aoo`03
001oogoo00Aoo`@000aoo`03001oogoo00Ioo`05001oogooOol00008Ool00`00Oomoo`04Ool01`00
Oomoogoo001oo`00029oo`00`Woo00<007ooOol00goo00@007ooOomoo`8000Aoo`03001oogoo00Uo
o`03001oogoo00]oo`03001oogoo00eoo`03001oogoo00eoo`03001oo`0000<000=oo`03001oogoo
00]oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Eoo`05001oogoo
Ool0000SOol00<9oo`03001oogoo00=oo`04001oogoo0007Ool00`00Oomoo`09Ool00`00Oomoo`0;
Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool30008Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool20005
Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool2000QOol00<9oo`03001oogoo00Ao
o`8000Qoo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo00Qoo`<000]o
o`03001oogoo00Yoo`05001oogooOol00008Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool2000QOol00<=oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo
00]oo`03001oogoo00eoo`03001oogoo00Ioo`<000eoo`03001oogoo00aoo`8000Uoo`03001oogoo
00Ioo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo01moo`00`goo00<007ooOol00Woo0P00
2Goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol037oo00<007ooOol00goo0`000Woo00<0
07ooOol037oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol017oo00<0
07ooOol00Woo00<007ooOol07goo0034Ool01`00Oomoogoo001oo`0000Uoo`03001oogoo00Uoo`03
001oogoo00]oo`03001oogoo00eoo`03001oo`0000<000Eoo`03001oogoo00]oo`03001oogoo00Qo
o`<000aoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo01ioo`00a7oo
00@007ooOol0009oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00ao
o`<000=oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00Eoo`8000=oo`03001oogoo00Uo
o`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo01ioo`00a7oo00<007oo
00000goo00<007ooOol01goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo0P001goo
00<007ooOol00Woo00<007ooOol037oo00<007ooOol00goo0P001Goo00<007ooOol02Goo00<007oo
Ool01goo00<007ooOol017oo00D007ooOomoo`00025oo`00aGoo0P0017oo00<007ooOol01goo00<0
07ooOol02Goo00<007ooOol02goo00<007ooOol01goo0P002Goo00<007ooOol00goo00<007ooOol0
2goo00@007ooOomoo`8000Moo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Eoo`04001o
ogoo000QOol00<Eoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00]o
o`03001oogoo00Aoo`<000aoo`03001oogoo009oo`03001oogoo00aoo`<000Yoo`03001oogoo00Uo
o`03001oogoo00Moo`03001oogoo00Aoo`03001oo`00029oo`00aGoo00<007ooOol00goo00<007oo
Ool01goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol00Woo0P003goo00<007ooOol00Woo
00<007ooOol02goo0P0037oo00<007ooOol02Goo00<007ooOol01goo00<007ooOol017oo00<007oo
00008Woo0036Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool0
1000Ool000004Goo00<007ooOol00goo00<007ooOol027oo0P0000=oo`00Ool037oo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol08Goo0036Ool00`00Oomoo`03Ool00`00
Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool2000DOol00`00Oomoo`02Ool00`00Oomoo`05
Ool30004Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00
Oomoo`0QOol00<Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Uo
o`8001Ioo`03001oogoo009oo`03001oogoo009oo`<000Moo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Moo`03001oogoo00=oo`03001oogoo029oo`00agoo00<007ooOol00goo00<007oo
Ool01goo00<007ooOol02Goo00<007ooOol01Woo0P0067oo00<007ooOol00goo00@007oo000000Yo
o`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00Moo`05001oogooOol0000UOol00<Moo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00Aoo`8001]oo`03001oogoo
009oo`8000eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Moo`04001oogoo000VOol0
0<Moo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo009oo`8001eoo`03
001oogoo009oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Moo`04
001oogoo000VOol00<Moo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00Uoo`04001oo`00
000OOol00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomo
o`08Ool00`00Oomoo`0UOol00<Qoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Uoo`80
029oo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
00Moo`03001oogoo02Ioo`00b7oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol01goo0P00
97oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol02goo00<007ooOol027oo00<007ooOol0
1Woo00<007ooOol09goo0038Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`0TOol00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00
Oomoo`03Ool2000ZOol00<Uoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Aoo`03001o
ogoo02Ioo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo009oo`03001oogoo02Yoo`00bGoo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00Woo
0P00:Goo00<007ooOol00goo00<007ooOol02goo00<007ooOol02goo00<007ooOol027oo00D007oo
Oomoo`0002eoo`00bGoo00<007ooOol017oo00<007ooOol01Woo00D007ooOomoo`0002]oo`03001o
ogoo00=oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`8002ioo`00bWoo00<007oo
Ool00goo00<007ooOol01goo0`00;Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol0;Woo003:Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`0]Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomo
o`0_Ool00<Yoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo02moo`03001oogoo009oo`03
001oogoo00aoo`03001oogoo00Yoo`03001oogoo00Eoo`80039oo`00bgoo00<007ooOol017oo00<0
07ooOol00goo00<007ooOol0<7oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol02goo00<0
07ooOol00goo00<007ooOol0<Woo003;Ool00`00Oomoo`04Ool01000Oomoogoo0P00<goo00<007oo
Ool00goo00<007ooOol02goo00<007ooOol02goo00<007ooOol00Woo00<007ooOol0<goo003;Ool0
0`00Oomoo`04Ool01000Oomoo`00=Woo00<007ooOol00Woo00<007ooOol037oo00<007ooOol02Woo
00<007ooOol00P00=Woo003<Ool00`00Oomoo`04Ool2000gOol00`00Oomoo`03Ool00`00Oomoo`0;
Ool00`00Oomoo`0<Ool00`00Oomoo`0fOol00<aoo`03001oogoo00Aoo`03001oogoo03Ioo`03001o
ogoo00=oo`03001oogoo00]oo`03001oogoo00Yoo`8003Uoo`00c7oo00<007ooOol00goo00<007oo
Ool0>7oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol01goo0P00>goo003<Ool00`00Oomo
o`03Ool00`00Oomoo`0hOol00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool2000mOol0
0<eoo`05001oogooOol0000kOol00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool3000o
Ool00<eoo`04001oogoo000mOol00`00Oomoo`02Ool00`00Oomoo`0<Ool01000Ool00000@Woo003=
Ool00`00Ool0000nOol00`00Oomoo`03Ool00`00Oomoo`0;Ool20014Ool00<ioo`8003ioo`03001o
ogoo00=oo`03001oogoo00Uoo`8004Ioo`00cWoo00<007ooOol0?Woo00<007ooOol00goo00<007oo
Ool01Woo0P00B7oo003oOol@Ool00`00Oomoo`03Ool00`00Oomoo`04Ool2001:Ool00?mooa1oo`03
001oogoo00=oo`03001oogoo009oo`8004aoo`00ogoo4Goo00<007ooOol00goo00@007oo000004io
o`00ogoo4Goo00<007ooOol00goo0P00D7oo003oOolBOol00`00Oomoo`1DOol00?mooa9oo`03001o
ogoo05Aoo`00ogoo4Woo00<007ooOol0E7oo003oOolCOol00`00Oomoo`1COol00?mooa=oo`03001o
ogoo05=oo`00ogoo4goo00<007ooOol0Dgoo003oOolDOol00`00Oomoo`1BOol00?mooaAoo`03001o
ogoo059oo`00ogoo57oo00<007ooOol0DWoo003oOolEOol00`00Oomoo`1AOol00?mooaEoo`03001o
ogoo055oo`00ogoo5Goo00<007ooOol0DGoo003oOolFOol00`00Oomoo`1@Ool00?mooaIoo`03001o
ogoo051oo`00ogoo5Woo00<007ooOol0D7oo003oOolGOol00`00Oomoo`1?Ool00?mooaMoo`03001o
ogoo04moo`00ogoo67oo00<007ooOol0CWoo003oOolHOol00`00Oomoo`1>Ool00?mooaQoo`03001o
ogoo04ioo`00ogoo6Goo00<007ooOol0CGoo003oOolIOol00`00Oomoo`1=Ool00?mooaUoo`03001o
ogoo04eoo`00ogoo6Woo00<007ooOol0C7oo003oOolJOol00`00Oomoo`1<Ool00?mooaYoo`03001o
ogoo04aoo`00ogoo6goo00<007ooOol0Bgoo003oOolKOol00`00Oomoo`1;Ool00?moofUoo`00ogoo
JGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol0
0?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogoo
JGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol0
0?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogoo
JGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol0
0?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogoo
JGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol0
0?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogoo
JGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {688.75, 0}} -> {-0.0250052, -0.0490599, \
0.00365603, 0.00365603}, {{8.5, 350.438}, {671.938, 16.75}} -> {0.225833, \
0.000728967, 0.00185878, 0.00185878}}]
}, Open  ]],

Cell["\<\
An application is to find a best fitting cylinder given more than \
five points. This can be approached via least squares but one requires \
reasonable starting values. These in turn may be obtained by finding \
cylinders through a subset of five points, assuming the set of points is not \
too far from lying on a cylinder. This can be used to gauge discrepancy of a \
given object such as a water pipe from being cylindrical.\
\>", "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["And now, a word from my sponsor", "Section"],

Cell["\<\
As many of you know, the CEO at my company recently came out with a \
big book. A big topic in that big book is cellular automata. In addition to \
generating alot of interest (and no small amount of controversy), these also \
make for neat illustrations. I'll show some. And also tie it in to a very \
real need of technical computation.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Initialization", "Subsubsection"],

Cell[BoxData[
    \(\(RasterGraphics[state_?MatrixQ, colors_Integer : 2, 
          opts___] := \[IndentingNewLine]Graphics[\[IndentingNewLine]Raster[
            Reverse[1 - state\/\(colors - 1\)]], 
          AspectRatio \[Rule] \((\(AspectRatio /. {opts}\) /. 
                AspectRatio \[Rule] Automatic)\), 
          opts\[IndentingNewLine]];\)\)], "Input",
  FontSize->9,
  CellTags->"CellularAutomaton"],

Cell[BoxData[
    \(\(RasterGraphics3D[\ state_?\((TensorRank[#] === 3 &)\), \ 
          opts___\ ]\  := \[IndentingNewLine]Graphics3D[\ \
\[IndentingNewLine]Map[\ Cuboid, \ 
            Position[\ \ Transpose[\ Reverse\ @\ state, \ {3, \ 1, \ 2}\ ], \ 
              1\ ]\ ], \ \[IndentingNewLine]opts\[IndentingNewLine]];\)\)], \
"Input",
  FontSize->9],

Cell[BoxData[
    \(\(CAShow[\ e_\ ]\  := \ Show[\ RasterGraphics[\ e\ ]\ ];\)\)], "Input",
  FontSize->9],

Cell[BoxData[
    \(\(CAShow3D[\ e_\ ]\  := \ 
        Show[\ RasterGraphics3D[\ e\ ]\ ];\)\)], "Input",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell["1D Cellular Automata", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CellularAutomaton[30, \ {{1}, \ 0}, \ 5\ ] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0", "0", "1", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "1", "1", "1", "0", "0", "0", "0"},
            {"0", "0", "0", "1", "1", "0", "0", "1", "0", "0", "0"},
            {"0", "0", "1", "1", "0", "1", "1", "1", "1", "0", "0"},
            {"0", "1", "1", "0", "0", "1", "0", "0", "0", "1", "0"},
            {"1", "1", "0", "1", "1", "1", "1", "0", "1", "1", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(CAShow[\ %\ ];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .54545 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0865801 0.012987 0.0865801 [
[ 0 0 0 0 ]
[ 1 .54545 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .54545 L
0 .54545 L
closepath
clip
newpath
% Start of gray image
p
.02381 .01299 translate
.95238 .51948 scale
11 string
11 6 8 [11 0 0 6 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000FF00000000FF000000
FF0000FFFF00FFFFFF00FF
FFFF0000FF00000000FFFF
FFFFFF0000FFFF00FFFFFF
FFFFFFFF000000FFFFFFFF
FFFFFFFFFF00FFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 157.063},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000WA000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol000Mooc4001Uoof@001UoodX000Qoo`001goo<@006Goo
I0006GooBP0027oo0007Oola000IOomT000IOom:0008Ool000Mooc4001Uoof@001UoodX000Qoo`00
1goo<@006GooI0006GooBP0027oo0007Oola000IOomT000IOom:0008Ool000Mooc4001Uoof@001Uo
odX000Qoo`001goo<@006GooI0006GooBP0027oo0007Oola000IOomT000IOom:0008Ool000Mooc40
01Uoof@001UoodX000Qoo`001goo<@006GooI0006GooBP0027oo0007Oola000IOomT000IOom:0008
Ool000Mooc4001Uoof@001UoodX000Qoo`001goo<@006GooI0006GooBP0027oo0007Oola000IOomT
000IOom:0008Ool000Mooc4001Uoof@001UoodX000Qoo`001goo<@006GooI0006GooBP0027oo0007
Oola000IOomT000IOom:0008Ool000Mooc4001Uoof@001UoodX000Qoo`001goo<@006GooI0006Goo
BP0027oo0007Oola000IOomT000IOom:0008Ool000Mooc4001Uoof@001UoodX000Qoo`001goo<@00
6GooI0006GooBP0027oo0007Oola000IOomT000IOom:0008Ool000Mooc4001Uoof@001UoodX000Qo
o`0087oo<@00<Woo6@00BWoo6@008Goo000POola000bOolI001:OolI000QOol0021ooc40039ooaT0
04YooaT0025oo`0087oo<@00<Woo6@00BWoo6@008Goo000POola000bOolI001:OolI000QOol0021o
oc40039ooaT004YooaT0025oo`0087oo<@00<Woo6@00BWoo6@008Goo000POola000bOolI001:OolI
000QOol0021ooc40039ooaT004YooaT0025oo`0087oo<@00<Woo6@00BWoo6@008Goo000POola000b
OolI001:OolI000QOol0021ooc40039ooaT004YooaT0025oo`0087oo<@00<Woo6@00BWoo6@008Goo
000POola000bOolI001:OolI000QOol0021ooc40039ooaT004YooaT0025oo`0087oo<@00<Woo6@00
BWoo6@008Goo000POola000bOolI001:OolI000QOol0021ooc40039ooaT004YooaT0025oo`0087oo
<@00<Woo6@00BWoo6@008Goo000POola000bOolI001:OolI000QOol0021ooc40039ooaT004YooaT0
025oo`0087oo<@00<Woo6@00BWoo6@008Goo000POola000bOolI001:OolI000QOol0021ooc40039o
oaT004YooaT0025oo`00>7oo<P006GooH`00>Woo000hOolb000IOomS000jOol003Qooc8001Uoof<0
03Yoo`00>7oo<P006GooH`00>Woo000hOolb000IOomS000jOol003Qooc8001Uoof<003Yoo`00>7oo
<P006GooH`00>Woo000hOolb000IOomS000jOol003Qooc8001Uoof<003Yoo`00>7oo<P006GooH`00
>Woo000hOolb000IOomS000jOol003Qooc8001Uoof<003Yoo`00>7oo<P006GooH`00>Woo000hOolb
000IOomS000jOol003Qooc8001Uoof<003Yoo`00>7oo<P006GooH`00>Woo000hOolb000IOomS000j
Ool003Qooc8001Uoof<003Yoo`00>7oo<P006GooH`00>Woo000hOolb000IOomS000jOol003Qooc80
01Uoof<003Yoo`00>7oo<P006GooH`00>Woo000hOolb000IOomS000jOol003Qooc8001Uoof<003Yo
o`00>7oo<P006GooH`00>Woo001AOolb000bOolI001BOol0055ooc80039ooaT0059oo`00DGoo<P00
<Woo6@00DWoo001AOolb000bOolI001BOol0055ooc80039ooaT0059oo`00DGoo<P00<Woo6@00DWoo
001AOolb000bOolI001BOol0055ooc80039ooaT0059oo`00DGoo<P00<Woo6@00DWoo001AOolb000b
OolI001BOol0055ooc80039ooaT0059oo`00DGoo<P00<Woo6@00DWoo001AOolb000bOolI001BOol0
055ooc80039ooaT0059oo`00DGoo<P00<Woo6@00DWoo001AOolb000bOolI001BOol0055ooc80039o
oaT0059oo`00DGoo<P00<Woo6@00DWoo001AOolb000bOolI001BOol0055ooc80039ooaT0059oo`00
DGoo<P00<Woo6@00DWoo001AOolb000bOolI001BOol0055ooc80039ooaT0059oo`00DGoo<P00<Woo
6@00DWoo001AOolb000bOolI001BOol006Yood/006]oo`00JWooB`00Jgoo001ZOom;001[Ool006Yo
od/006]oo`00JWooB`00Jgoo001ZOom;001[Ool006Yood/006]oo`00JWooB`00Jgoo001ZOom;001[
Ool006Yood/006]oo`00JWooB`00Jgoo001ZOom;001[Ool006Yood/006]oo`00JWooB`00Jgoo001Z
Oom;001[Ool006Yood/006]oo`00JWooB`00Jgoo001ZOom;001[Ool006Yood/006]oo`00JWooB`00
Jgoo001ZOom;001[Ool006Yood/006]oo`00JWooB`00Jgoo001ZOom;001[Ool008=ooaT008Aoo`00
Pgoo6@00Q7oo0023OolI0024Ool008=ooaT008Aoo`00Pgoo6@00Q7oo0023OolI0024Ool008=ooaT0
08Aoo`00Pgoo6@00Q7oo0023OolI0024Ool008=ooaT008Aoo`00Pgoo6@00Q7oo0023OolI0024Ool0
08=ooaT008Aoo`00Pgoo6@00Q7oo0023OolI0024Ool008=ooaT008Aoo`00Pgoo6@00Q7oo0023OolI
0024Ool008=ooaT008Aoo`00Pgoo6@00Q7oo0023OolI0024Ool008=ooaT008Aoo`00Pgoo6@00Q7oo
0023OolI0024Ool008=ooaT008Aoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {156.063, 0}} -> {-0.292881, -0.150031, \
0.0403685, 0.0403685}}]
}, Open  ]],

Cell["\<\
This is the first 200 time steps in the evolution of the rule 30 \
cellular automaton with specific initial configuration..\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(CAShow\ @\ 
        CellularAutomaton[\ 30, \ {{1}, 0}, \ 
          200, \ {All, \ {\(-100\), \ 100}}\ ];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00473821 0.0238095 0.00473821 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
201 string
201 201 8 [201 0 0 201 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00FF0000FFFF00FF000000FF00FFFF0000FF000000000000FF00FF00FF00FF00FF00FF00
00000000FF00FF00FF00FF00FF00000000000000FF00FF00FFFF00FFFF0000FFFFFFFF00
0000FFFF0000FF00FF00FFFF0000000000FF000000FF00FFFFFFFF0000FFFFFF00FF00FF
00FF000000FFFF00FF00FFFFFF00FFFFFF0000000000000000000000FFFF00000000FFFF
FF00000000000000FFFFFFFFFFFF00FF00FFFFFF0000FFFF0000FFFFFFFFFF000000FF00
FFFF0000FFFFFFFF000000FFFFFFFF00000000FFFF
FFFFFF0000FF0000FFFF0000FFFFFFFF0000FFFF00FFFF00FF00FF00FF00FF0000FFFFFF
00FFFF00FF00FF00FF00FF00FF00FFFF00FFFF00FF00FF0000FF0000FF00FFFFFFFFFFFF
00FFFFFFFF00FF0000FFFFFFFF00FFFF0000FFFF0000FFFFFFFFFFFF000000FF00FF00FF
0000FFFF0000FF00FF00000000FFFFFFFFFF00FFFF00FFFF00FFFF0000FF00FFFF000000
FF00FFFF00FFFF000000000000FF00FF000000FF00FFFFFFFF000000000000FFFF0000FF
FFFFFF0000000000FFFF00000000FF00FFFF000000
0000FF00FFFFFF0000FF00FFFFFFFFFFFF0000FF0000FF00FF00FF0000FFFFFF000000FF
0000FF00FF00FF00FF00FF00FF0000FF0000FF00FF00FF00FFFFFF00FF000000000000FF
0000000000FFFFFF00000000FF0000FF00FFFFFFFF00000000000000FFFF00FF00FF00FF
00FFFFFFFF00FF00FF00FFFF0000000000FF0000FF000000FFFFFFFF00FF000000FFFF00
FF0000FF000000FFFF00FFFF00FF0000FFFF00FF0000000000FFFF00FFFF0000FF00FFFF
FFFFFFFF00FFFF0000FF00FFFF0000FFFFFFFF00FF
FF0000FFFFFFFFFF00FF000000000000FF00FFFFFF00FF00FF00FF00FFFFFFFFFF00FFFF
FF00FF00FF00FF00FF00FF00FF00FFFFFF00FF00FF00FF00000000FFFFFF00FFFF00FFFF
FF00FFFF00000000FFFF00FFFFFF00FF00000000FF00FFFF00FFFF0000FF00FF00FF00FF
00000000FF00FF00FF0000FF00FFFF00FFFFFF0000FFFF00000000FF0000FFFF000000FF
FFFF0000FFFF0000FF000000FFFFFF000000FFFFFF00FFFF000000FFFFFFFF00FF000000
00000000FFFFFFFF0000FFFFFFFF00000000FF0000
FFFF0000000000FF0000FFFF00FFFF00FF000000FF00FF00FF00FF0000000000FF000000
FF00FF00FF00FF00FF00FF00FF000000FF00FF00FF00FF00FFFF000000FF0000FF000000
FF0000FF00FFFF0000FF000000FF00FF00FFFF00FF000000FFFFFFFF00FF00FF00FF00FF
00FFFF00FF0000FFFFFF00FF000000FFFFFFFFFF000000FFFF00FFFFFF000000FFFF0000
00FF00FFFFFFFF0000FFFF00000000FFFF000000FF000000FFFF00000000FF0000FFFF00
FFFF00FFFFFFFFFFFF0000000000FFFF00FFFFFF00
00FF00FFFF00FFFFFF0000FF0000FF0000FFFF00FF00FF0000FFFFFF00FFFF0000FFFF00
FF00FF00FF00FF00FF00FF0000FFFF00FF00FF00FF00FF000000FFFF00FF00FFFFFF00FF
FFFF0000FFFFFFFF0000FFFF00FF00FF0000FF0000FFFF00000000FF00FF00FF00FF00FF
000000FFFFFF000000FF0000FFFF000000000000FFFF0000FF00000000FFFF000000FFFF
0000FFFFFFFFFFFF0000FF00FFFF000000FFFF0000FFFF000000FFFF00FFFFFF0000FF00
0000FFFFFFFFFFFFFFFF00FFFF000000FFFFFFFFFF
00FF000000FFFFFFFFFF00FF00FFFFFF0000FF0000FFFFFF00000000FFFFFFFF0000FF00
FF00FF00FF00FF0000FFFFFF0000FF00FF00FF00FF0000FFFF0000FF00FF000000FF0000
00FF00FFFFFFFFFFFF0000FF00FF00FF00FFFFFF0000FF00FFFF00FF00FF00FF00FF0000
FFFF00000000FFFF00FF00FFFFFFFF00FFFF00FFFFFFFF00FF00FFFF000000FFFF0000FF
00FFFFFFFFFFFFFFFF0000FFFFFFFF00FFFFFFFF000000FFFF000000FFFFFFFFFF0000FF
FF0000000000000000FF000000FFFF000000000000
0000FFFF0000000000FF00FF000000FF00FFFFFF00000000FFFF00FFFFFFFFFFFF00FF00
FF00FF00FF00FF00FFFFFFFFFF00FF00FF00FF00FF00FFFFFFFF00FF0000FFFF0000FFFF
0000FFFFFFFFFFFFFFFF00FF00FF0000FFFFFFFFFF00FF0000FF00FF00FF0000FFFFFF00
00FF00FFFF0000FF00FF00000000FF0000FF00000000FF0000FFFFFFFF00FFFFFFFF0000
FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFFFFFF0000
FF00FFFF00FFFF00FFFFFF00FFFFFFFF00FFFF00FF
00FFFFFFFF00FFFF00FF0000FFFF00FF000000FF00FFFF0000FF000000000000FF00FF00
FF00FF00FF00FF0000000000FF00FF00FF00FF00FF0000000000FFFFFF0000FF00FFFFFF
FF0000000000000000FF0000FFFFFF000000000000FFFFFF00FF00FF00FF00FFFFFFFFFF
0000FFFFFFFF00FF0000FFFF00FFFFFF0000FFFF00FFFFFF00000000FF00000000FF00FF
FFFFFFFFFFFFFFFFFFFFFF00FFFF000000000000FF0000000000FFFFFFFFFFFFFFFFFF00
FF0000FF0000FF000000FF00000000FF0000FF0000
00000000FF000000FFFFFF0000FF0000FFFF0000FFFFFFFF0000FFFF00FFFF00FF00FF00
FF00FF0000FFFFFF00FFFF00FF00FF00FF00FF00FF00FFFF00FFFFFFFFFF00FF00000000
FF00FFFF00FFFF00FFFFFF00000000FFFF00FFFF000000FF00FF00FF0000FFFFFFFFFFFF
FF0000000000FFFFFF000000FFFFFFFFFF0000FF000000FF00FFFF00FF00FFFF00FF0000
0000000000000000000000FFFFFFFF00FFFF00FFFFFF00FFFF000000000000000000FF00
FF00FFFFFF0000FFFF0000FFFF00FFFFFF0000FFFF
00FFFF0000FFFF000000FF00FFFFFF0000FF00FFFFFFFFFFFF0000FF0000FF00FF00FF00
00FFFFFF000000FF0000FF00FF00FF00FF00FF00FF0000FF0000000000FF00FF00FFFF00
FF0000FF0000FF000000FF00FFFF0000FF000000FFFF00FF0000FFFFFF00000000000000
FF00FFFF00FFFFFFFFFF00FFFFFFFFFFFFFF0000FFFF00FF0000FF00FF0000FF00FF00FF
FF00FFFF00FFFF00FFFF00000000FF0000FF000000FF000000FFFF00FFFF00FFFF00FF00
FF000000FF00FFFFFFFF000000FFFFFFFFFF0000FF
FFFFFFFF000000FFFF0000FFFFFFFFFF00FF000000000000FF00FFFFFF00FF00FF00FF00
FFFFFFFFFF00FFFFFF00FF00FF00FF00FF00FF00FF00FFFFFF00FFFF00FF00FF0000FF00
FF00FFFFFF0000FFFF0000FFFFFFFF0000FFFF000000FFFFFF000000FF00FFFF00FFFF00
FF0000FF000000000000FFFFFFFFFFFFFFFFFF000000FFFFFF0000FFFFFF00FF00FF0000
FF0000FF0000FF000000FFFF00FFFFFF0000FFFF0000FFFF0000FF0000FF0000FF00FF00
00FFFF00FF0000000000FFFF0000000000FF00FFFF
FFFFFFFFFF00FFFFFFFF0000000000FF0000FFFF00FFFF00FF000000FF00FF00FF00FF00
00000000FF000000FF00FF00FF00FF00FF00FF00FF000000FF0000FF0000FFFFFF00FF00
00FFFFFFFFFF0000FF00FFFFFFFFFFFF000000FFFF00000000FFFF00FF0000FF0000FF00
FF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000FF0000FFFFFF00
FF00FFFFFF0000FFFF000000FFFFFFFFFF0000FF00FFFFFFFF00FF00FFFFFF0000FFFFFF
0000FF00FF00FFFF00FFFFFFFF00FFFF00FF000000
00000000FF00000000FF00FFFF00FFFFFF0000FF0000FF0000FFFF00FF00FF0000FFFFFF
00FFFF0000FFFF00FF00FF00FF00FF00FF00FF0000FFFF00FF00FFFFFF000000FF00FF00
FFFFFFFFFFFFFF00FF00000000000000FFFF0000FF00FFFF0000FF00FF00FFFFFF00FF00
FF000000FF0000FF000000000000000000000000FFFFFFFFFFFFFF00FFFFFF000000FF00
FF000000FF00FFFFFFFF00FFFFFFFFFFFFFF00FF00000000FF00FF000000FF00FFFFFFFF
FF00FF00FF0000FF00000000FF0000FF00FF00FFFF
00FFFF00FF00FFFF00FF000000FFFFFFFFFF00FF00FFFFFF0000FF0000FFFFFF00000000
FFFFFFFF0000FF00FF00FF00FF00FF0000FFFFFF0000FF00FF00000000FFFF00FF00FF00
000000000000FF0000FFFF00FFFF00FFFFFFFF0000FFFFFFFF00FF00FF000000FF0000FF
FFFF00FFFFFF0000FFFF00FFFF00FFFF00FFFF00000000000000FF00000000FFFF00FF00
00FFFF00FF00000000FF00000000000000FF00FF00FFFF00FF0000FFFF00FF0000000000
FF0000FFFFFF0000FFFF00FFFFFF00FF00FF000000
0000FF00FF0000FF0000FFFF0000000000FF00FF000000FF00FFFFFF00000000FFFF00FF
FFFFFFFFFF00FF00FF00FF00FF00FF00FFFFFFFFFF00FF00FF00FFFF0000FF00FF0000FF
FF00FFFF00FFFFFF0000FF000000FFFFFFFFFFFF00000000FF0000FFFFFF00FFFFFF0000
0000FFFFFFFFFF0000FF0000FF0000FF0000FF00FFFF00FFFF00FF00FFFF000000FFFFFF
0000FF00FF00FFFF00FF00FFFF00FFFF00FF00FF000000FFFFFF000000FFFFFF00FFFF00
FF00FFFFFFFFFF0000FF000000FF00FF0000FFFF00
FF0000FFFFFF00FF00FFFFFFFF00FFFF00FF0000FFFF00FF000000FF00FFFF0000FF0000
00000000FF00FF00FF00FF00FF00FF0000000000FF00FF0000FFFFFFFF0000FFFFFF0000
FF000000FFFFFFFFFF0000FFFF00000000000000FFFF00FFFFFF000000FF000000FF00FF
FF0000000000FF00FFFFFF00FF00FFFFFF00FF0000FF0000FF0000FFFFFFFF00FFFFFFFF
FF00FF00FF0000FF00FF0000FF0000FF00FF0000FFFF00000000FFFF000000FF0000FF00
00FFFFFFFFFFFFFF0000FFFF0000FFFFFF0000FF00
FFFF000000FF00FF00000000FF000000FFFFFF0000FF0000FFFF0000FFFFFFFF0000FFFF
00FFFF00FF00FF00FF00FF0000FFFFFF00FFFF00FF00FF00FFFFFFFFFFFF000000FF00FF
FFFF00FFFFFFFFFFFFFF0000FF00FFFF00FFFF0000FF00000000FFFF0000FFFF0000FFFF
FFFF00FFFF00FF000000FF00FF00000000FFFFFF00FF00FFFFFF00000000FF0000000000
FF0000FFFFFF00FF00FF00FFFFFF0000FFFFFF000000FFFF00FFFFFFFF00FFFFFF00FF00
FFFFFFFFFFFFFFFFFF0000FF00FFFFFFFFFF00FF00
0000FFFF00FF00FF00FFFF0000FFFF000000FF00FFFFFF0000FF00FFFFFFFFFFFF0000FF
0000FF00FF00FF0000FFFFFF000000FF0000FF00FF00FF00000000000000FFFF00FF0000
0000FFFFFFFFFFFFFFFFFF00FF000000FFFFFFFF00FF00FFFF0000FF00FFFFFFFF000000
00FF0000FF0000FFFF00FF00FF00FFFF000000FF00FF000000FF00FFFF00FF00FFFF00FF
FFFF000000FF00FF0000FFFFFFFFFF00000000FFFF0000FF00000000FF000000FF0000FF
FFFFFFFFFFFFFFFFFFFF00FF0000000000FF0000FF
FF0000FF00FF0000FFFFFFFF000000FFFF0000FFFFFFFFFF00FF000000000000FF00FFFF
FF00FF00FF00FF00FFFFFFFFFF00FFFFFF00FF00FF00FF00FFFF00FFFF0000FF00FF00FF
FF000000000000000000FF0000FFFF00000000FF0000FFFFFFFF00FF00000000FF00FFFF
00FF00FFFFFF0000FF00FF00FF000000FFFF00FF0000FFFF00FF0000FF00FF0000FF0000
0000FFFF0000FFFFFF000000000000FFFF00FFFFFFFF0000FFFF00FFFFFF00FFFFFF0000
000000000000000000FF00FF00FFFF00FFFFFF0000
FFFF00FF00FF00FFFFFFFFFFFF00FFFFFFFF0000000000FF0000FFFF00FFFF00FF000000
FF00FF00FF00FF0000000000FF000000FF00FF00FF00FF000000FFFFFFFF00FF0000FFFF
FFFF00FFFF00FFFF00FFFFFF000000FFFF00FFFFFF00000000FF00FF00FFFF00FF0000FF
0000FFFFFFFFFF00FF00FF0000FFFF000000FFFFFF000000FFFFFF0000FFFFFF0000FFFF
00FFFFFFFF00000000FFFF00FFFF000000FFFFFFFFFFFF0000FF00000000FFFFFFFFFF00
FFFF00FFFF00FFFF00FF00FF0000FF000000FF00FF
00FF00FF00FF000000000000FF00000000FF00FFFF00FFFFFF0000FF0000FF0000FFFF00
FF00FF0000FFFFFF00FFFF0000FFFF00FF00FF00FF0000FFFF0000000000FFFFFF000000
00FF0000FF0000FF00000000FFFF0000FF000000FF00FFFF00FF00FF0000FF00FF00FFFF
FF0000000000FF0000FFFFFF000000FFFF00000000FFFF000000FF00FFFFFFFFFF0000FF
00000000FF00FFFF000000FFFFFFFF00FFFFFFFFFFFFFFFF00FF00FFFF0000000000FF00
00FF0000FF0000FF0000FFFFFF0000FFFF0000FFFF
00FF00FF0000FFFF00FFFF00FF00FFFF00FF000000FFFFFFFFFF00FF00FFFFFF0000FF00
00FFFFFF00000000FFFFFFFF0000FF00FF00FF00FF00FFFFFFFF00FFFF000000FF00FFFF
00FF00FFFFFF0000FFFF00FFFFFFFF0000FFFF00FF0000FF0000FFFFFF00FF00FF000000
FF00FFFF00FFFFFF00000000FFFF0000FF00FFFF000000FFFF0000FFFFFFFFFFFFFF00FF
00FFFF00FF000000FFFF00000000FF0000000000000000FF0000FFFFFFFF00FFFF00FF00
FFFFFF00FF00FFFFFF000000FF00FFFFFFFF000000
0000FFFFFF0000FF0000FF00FF0000FF0000FFFF0000000000FF00FF000000FF00FFFFFF
00000000FFFF00FFFFFFFFFFFF00FF00FF00FF00FF00000000FF000000FFFF00FF0000FF
0000FFFFFFFFFF000000FFFFFFFFFFFF0000FF00FF00FFFFFF000000FF00FF0000FFFF00
FF0000FF00000000FFFF00FFFFFFFF0000FFFFFFFF00FFFFFFFF00000000000000FF00FF
0000FF0000FFFF0000FF00FFFF00FF00FFFF00FFFF00FFFFFF00000000FF0000FF00FF00
0000FF00FF00000000FFFF0000FFFFFFFFFFFF00FF
FF000000FF00FFFFFF0000FFFFFF00FF00FFFFFFFF00FFFF00FF0000FFFF00FF000000FF
00FFFF0000FF000000000000FF00FF00FF00FF00FF00FFFF0000FFFF000000FFFFFF00FF
00FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF00FF00FF00000000FFFF0000FFFFFF000000FF
FFFF00FF00FFFF000000FFFFFFFFFFFF00000000FF00000000FF00FFFF00FFFF0000FFFF
FF00FF00FFFFFFFF00FF0000FF00FF0000FF0000FF00000000FFFF00FFFFFF00FF0000FF
FF00FF0000FFFF00FFFFFFFF000000000000FF0000
00FFFF0000FFFFFFFFFF000000FF00FF00000000FF000000FFFFFF0000FF0000FFFF0000
FFFFFFFF0000FFFF00FFFF00FF00FF00FF00FF0000FFFFFFFF000000FFFF000000FF00FF
00000000000000FF0000000000000000FF00FF0000FFFF00FFFFFFFF00000000FFFF0000
00FF00FF000000FFFF000000000000FF00FFFF00FF00FFFF00FF000000FFFFFFFF000000
FF00FF0000000000FFFFFF00FF00FF00FFFFFF00FF00FFFF0000FF00000000FFFFFF0000
00FFFFFF0000FF0000000000FFFF00FFFF0000FFFF
FFFFFFFF000000000000FFFF00FF00FF00FFFF0000FFFF000000FF00FFFFFF0000FF00FF
FFFFFFFFFF0000FF0000FF00FF00FF0000FFFFFF0000000000FFFF000000FFFF00FF0000
FFFF00FFFF00FFFFFF00FFFF00FFFF0000FFFFFF0000FF00000000FF00FFFF000000FFFF
00FF0000FFFF000000FFFF00FFFF00FF0000FF00FF0000FF0000FFFF0000000000FFFF00
00FFFFFF00FFFF000000FF00FF00FF000000FF0000FFFFFFFF00FF00FFFF00000000FFFF
000000FF00FFFFFF00FFFF0000FF0000FF00FFFFFF
00000000FFFF00FFFF0000FF00FF0000FFFFFFFF000000FFFF0000FFFFFFFFFF00FF0000
00000000FF00FFFFFF00FF00FF00FF00FFFFFFFFFF00FFFF000000FFFF000000FFFFFF00
00FF0000FF000000FF0000FF0000FF00FFFFFFFFFF00FF00FFFF00FF000000FFFF000000
FFFFFF000000FFFF0000FF000000FFFFFF00FF00FF00FFFFFF0000FF00FFFF00FFFFFFFF
000000FF000000FFFF00FF0000FFFFFF00FFFFFF00000000FF00FF0000FF00FFFF000000
FFFF00FF000000FF0000FF00FFFFFF00FF00000000
00FFFF000000FFFFFFFF00FF00FF00FFFFFFFFFFFF00FFFFFFFF0000000000FF0000FFFF
00FFFF00FF000000FF00FF00FF00FF0000000000FF000000FFFF000000FFFF000000FF00
FFFFFF0000FFFF00FF00FFFFFF00FF0000000000FF00FF000000FFFFFF00FFFFFFFF00FF
FFFFFFFF00FFFFFFFF0000FFFF000000FF00FF0000FFFFFFFFFF00FF0000FF0000000000
FFFF0000FFFF000000FFFFFF000000FF000000FF00FFFF0000FFFFFF00FF000000FFFF00
0000FFFFFF00FFFFFF00FF000000FF00FF00FFFF00
000000FFFF00000000FF00FF00FF000000000000FF00000000FF00FFFF00FFFFFF0000FF
0000FF0000FFFF00FF00FF0000FFFFFF00FFFF0000FFFF000000FFFF000000FFFF0000FF
FFFFFFFF0000FF00FF00000000FFFFFF00FFFF00FF0000FFFF000000FF00000000FF0000
00000000FFFFFFFFFFFF000000FFFF0000FFFFFF000000000000FFFFFF00FF00FFFF00FF
FFFFFF000000FFFF00000000FFFF0000FFFF0000FFFFFFFF000000FF0000FFFF000000FF
FF000000FF000000FF0000FFFF00FF00FF0000FF00
FFFF0000FF00FFFF00FF00FF0000FFFF00FFFF00FF00FFFF00FF000000FFFFFFFFFF00FF
00FFFFFF0000FF0000FFFFFF00000000FFFFFFFF000000FFFF000000FFFF0000FF00FFFF
FFFFFFFFFF00FF00FF00FFFF000000FF000000FFFFFF000000FFFF0000FFFF00FFFFFF00
FFFF00FFFFFFFFFFFFFFFF00FFFFFFFF00000000FFFF00FFFF000000FF00FF0000FF0000
000000FFFF0000FF00FFFF0000FF00FFFFFFFF0000000000FFFF00FF00FFFFFFFF00FFFF
FFFF00FFFFFF00FFFFFF0000FF0000FFFFFF00FF00
FFFFFF00FF0000FF0000FFFFFF0000FF0000FF00FF0000FF0000FFFF0000000000FF00FF
000000FF00FFFFFF00000000FFFF00FFFFFFFFFFFF00FFFFFFFF00FFFFFFFF00FF000000
00000000FF00FF0000FFFFFFFF00FFFFFF00FFFFFFFFFF00FFFFFFFF0000FF000000FF00
00FF0000000000000000FF00000000FF00FFFF0000FF000000FFFF0000FFFFFF00FF00FF
FF00FFFFFFFF0000FFFFFFFF0000FFFFFFFFFFFF00FFFF0000FF00FF00000000FF000000
00FF000000FF000000FF00FFFFFF00000000FFFFFF
0000FF00FF00FFFFFF000000FF00FFFFFF0000FFFFFF00FF00FFFFFFFF00FFFF00FF0000
FFFF00FF000000FF00FFFF0000FF000000000000FF00000000FF00000000FF00FF00FFFF
00FFFF0000FFFFFF00000000FF000000FF000000000000FFFFFFFFFFFF0000FFFF00FF00
FFFFFF00FFFF00FFFF00FF00FFFF00FF0000FF00FFFFFF00FFFFFFFF000000FF00FF0000
FF00000000FF00FFFFFFFFFFFF00000000000000FFFFFFFF00FF00FF00FFFF00FF00FFFF
0000FFFF0000FFFF00FF000000FF00FFFF000000FF
FF00FF00FF00000000FFFF0000FFFFFFFFFF000000FF00FF00000000FF000000FFFFFF00
00FF0000FFFF0000FFFFFFFF0000FFFF00FFFF00FF00FFFF00FF00FFFF00FF00FF000000
FFFFFFFF00000000FFFF00FFFFFF00FFFFFF00FFFF00FFFFFFFFFFFFFFFF0000FF00FF00
0000FF0000FF0000FF00FF000000FFFFFF00FF000000FF0000000000FFFF0000FFFFFF00
FF00FFFF00FF000000000000FF00FFFF00FFFF00000000FF00FF00FF0000FF00FF0000FF
00FFFFFFFF0000FF0000FFFF00FF000000FFFF0000
FF00FF0000FFFF00FFFFFFFF000000000000FFFF00FF00FF00FFFF0000FFFF000000FF00
FFFFFF0000FF00FFFFFFFFFFFF0000FF0000FF00FF0000FF00FF0000FF00FF0000FFFF00
000000FF00FFFF0000FF000000FF000000FF000000FFFFFFFFFFFFFFFFFFFF00FF0000FF
FF00FF00FFFFFF00FF0000FFFF000000FF0000FFFF00FF00FFFF00FFFFFFFF000000FF00
FF0000FF0000FFFF00FFFF00FF0000FF0000FF00FFFF00FF0000FFFFFF0000FFFFFF00FF
00000000FF00FFFFFF000000FFFFFF00FFFFFFFF00
00FFFFFF0000FF0000000000FFFF00FFFF0000FF00FF0000FFFFFFFF000000FFFF0000FF
FFFFFFFF00FF000000000000FF00FFFFFF0000FFFFFF0000FFFFFF0000FFFFFF0000FF00
FFFF0000FFFFFFFF0000FFFF0000FFFF0000FFFF0000000000000000000000FFFFFF0000
FF00FF000000FF00FF00FFFFFFFF00FFFFFF0000FF00FF0000FF0000000000FFFF00FF00
FF00FFFFFF0000FF0000FF00FF00FFFFFF00FF0000FF00FF00FFFFFFFFFF000000FF00FF
00FFFF00FF00000000FFFF00000000FFFFFFFFFFFF
000000FF00FFFFFF00FFFF000000FFFFFFFF00FF00FF00FFFFFFFFFFFF00FFFFFFFF0000
000000FF0000FFFF00FFFF00FF000000FF00FFFFFFFFFF000000FF00FFFFFFFFFF00FF00
00FF00FFFFFFFFFFFF0000FF00FFFFFFFF0000FF00FFFF00FFFF00FFFF00FFFFFFFFFF00
FF0000FFFF00FF00FF0000000000FFFFFFFFFF00FF00FF00FFFFFF00FFFF0000FF00FF00
FF000000FF00FFFFFF00FF00FF00000000FFFFFF00FF00FF000000000000FFFF00FF00FF
0000FF00FF00FFFF0000FF00FFFF000000000000FF
FFFF00FF000000FF000000FFFF00000000FF00FF00FF000000000000FF00000000FF00FF
FF00FFFFFF0000FF0000FF0000FFFF00FF000000000000FFFF00FF000000000000FFFFFF
0000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00FF0000FF0000FF0000FF000000000000FF
FFFF0000FF0000FFFFFF00FFFF0000000000FF00FF00FF00000000FFFFFFFF00FF00FF00
00FFFF00FF000000FF00FF00FF00FFFF000000FF00FF0000FFFF00FFFF0000FF0000FFFF
FF00FF0000FFFFFFFF00FF000000FFFF00FFFF00FF
00FF0000FFFF0000FFFF0000FF00FFFF00FF00FF0000FFFF00FFFF00FF00FFFF00FF0000
00FFFFFFFFFF00FF00FFFFFF0000FF0000FFFF00FFFF0000FF0000FFFF00FFFF000000FF
00FFFFFFFFFFFFFFFFFFFF00000000000000FFFFFF00FF00FFFFFF0000FFFF00FFFF0000
00FF00FFFFFF00000000FFFFFFFF00FFFF00FF00FF00FF00FFFF00000000FF0000FFFFFF
0000FF0000FFFF00FF00FF00FF000000FFFF0000FFFFFF0000FF0000FF00FFFFFF000000
00FFFFFF00000000FF0000FFFF0000FF0000FF00FF
FFFFFF0000FF00FFFFFFFF00FF0000FF0000FFFFFF0000FF0000FF00FF0000FF0000FFFF
0000000000FF00FF000000FF00FFFFFF0000FF0000FF00FFFFFF0000FF000000FFFF00FF
00000000000000000000FF00FFFF00FFFF000000FF0000FFFFFFFFFF0000FF000000FFFF
00FF000000FF00FFFF00000000FF0000FF00FF00FF00FF000000FFFF00FFFFFF000000FF
00FFFFFF0000FF00FF0000FFFFFF00FFFFFFFF000000FF00FFFFFF00FF000000FF00FFFF
00000000FFFF00FFFFFF0000FF00FFFFFF00FF00FF
FFFFFFFF00FF00000000FF00FF00FFFFFF000000FF00FFFFFF0000FFFFFF00FF00FFFFFF
FF00FFFF00FF0000FFFF00FF000000FF00FFFFFF0000FFFFFFFFFF0000FFFF0000FF00FF
00FFFF00FFFF00FFFF00FF0000FF000000FFFF00FF00FFFFFFFFFFFFFF0000FFFF0000FF
0000FFFF00FF000000FFFF00FFFFFF00FF00FF00FF0000FFFF0000FF00000000FFFF0000
FFFFFFFFFF0000FFFFFF000000FF0000000000FFFF00FF000000FF0000FFFF00FF0000FF
00FFFF000000FFFFFFFFFF00FF000000FF00FF0000
000000FF00FF00FFFF00FF00FF00000000FFFF0000FFFFFFFFFF000000FF00FF00000000
FF000000FFFFFF0000FF0000FFFF0000FFFFFFFFFF0000000000FF00FFFFFFFF00FF00FF
0000FF0000FF000000FFFFFF0000FFFF0000FF0000FFFFFFFFFFFFFFFFFF0000FF00FFFF
FF0000FF0000FFFF0000FF000000FF00FF00FF00FF00FFFFFFFF0000FFFF00FFFFFFFF00
00000000FF00FFFFFFFFFF00FFFFFF00FFFF000000FFFFFF00FFFFFF000000FFFFFF00FF
000000FFFF0000000000FF0000FFFF0000FFFFFF00
FFFF00FF00FF0000FF00FF0000FFFF00FFFFFFFF000000000000FFFF00FF00FF00FFFF00
00FFFF000000FF00FFFFFF0000FF00FFFFFFFFFFFFFF00FFFF00FF00000000FF00FF00FF
00FFFFFF0000FFFF000000FF00FFFFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFF00FF00FFFFFFFF0000FFFF00FF00FF00FF0000FFFFFFFFFFFF000000FFFFFFFFFFFF
00FFFF00FF0000000000FF000000FF000000FFFF000000FF00000000FFFF00000000FFFF
FF00FFFFFFFF00FFFF00FF00FFFFFFFF000000FF00
00FF0000FFFFFF0000FFFFFF0000FF0000000000FFFF00FFFF0000FF00FF0000FFFFFFFF
000000FFFF0000FFFFFFFFFF00FF00000000000000FF0000FF00FF00FFFF00FF00FF0000
FFFFFFFFFF000000FFFF00FF00000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FF0000FFFFFFFFFFFF0000FF00FF0000FFFFFF00000000000000FFFF000000000000FF
000000FFFFFF00FFFF0000FFFF0000FFFF000000FFFF00FF00FFFF0000FF00FFFF000000
FF00000000FF0000FF00FF0000000000FFFF00FF00
00FF00FFFFFFFFFF000000FF00FFFFFF00FFFF000000FFFFFFFF00FF00FF00FFFFFFFFFF
FF00FFFFFFFF0000000000FF0000FFFF00FFFF00FFFFFF00FF00FF0000FF0000FFFFFF00
0000000000FFFF0000FF00FF00FFFF00FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
00FF00FFFFFFFFFFFFFFFF0000FFFFFF000000FF00FFFF00FFFF000000FFFF00FFFF0000
FFFF000000FF0000FF00FFFFFFFF000000FFFF0000FF0000FFFFFFFF00FF000000FFFF00
00FFFF00FFFFFF0000FFFFFF00FFFF0000FF0000FF
00FF000000000000FFFF00FF000000FF000000FFFF00000000FF00FF00FF000000000000
FF00000000FF00FFFF00FFFFFF0000FF0000FF000000FF0000FFFFFF00FF00FFFFFFFFFF
00FFFF00FFFFFFFF00FF00FF0000FF00FF000000000000000000000000000000FF0000FF
0000FFFFFFFFFFFFFFFFFFFF00000000FFFF00FF0000FF000000FFFF0000FF0000FF00FF
FFFFFF00FFFFFF00FF0000000000FFFF0000FF00FFFFFF0000000000FFFFFF00FFFFFFFF
000000FFFFFFFFFF000000FF0000FF00FFFFFF0000
0000FFFF00FFFF0000FF0000FFFF0000FFFF0000FF00FFFF00FF00FF0000FFFF00FFFF00
FF00FFFF00FF000000FFFFFFFFFF00FF00FFFFFF00FFFFFF000000FF00FF0000000000FF
0000FF00000000FF0000FFFFFF00FF0000FFFF00FFFF00FFFF00FFFF00FFFF00FF00FFFF
FF00000000000000000000FF00FFFF000000FFFFFF0000FFFF0000FF00FFFFFF00FF0000
0000FF000000FF00FF00FFFF00FFFFFFFF0000FFFFFFFFFF00FFFF00000000FFFFFFFFFF
FF00FFFFFFFFFFFFFF00FFFFFF0000FFFFFFFFFF00
FF0000FF0000FF00FFFFFF0000FF00FFFFFFFF00FF0000FF0000FFFFFF0000FF0000FF00
FF0000FF0000FFFF0000000000FF00FF000000FF00000000FFFF00FF00FF00FFFF00FFFF
FF0000FFFF00FFFFFF00000000FFFFFF0000FF0000FF0000FF0000FF0000FF00FF000000
FF00FFFF00FFFF00FFFF00FF000000FFFF000000FF00FFFFFFFF00FF000000FF00FF00FF
FF0000FFFF00FF00FF000000FFFFFFFFFFFF0000000000FF0000FF00FFFF000000000000
FF0000000000000000FFFFFFFFFF000000000000FF
FF00FFFFFF0000FFFFFFFFFF00FF00000000FF00FF00FFFFFF000000FF00FFFFFF0000FF
FFFF00FF00FFFFFFFF00FFFF00FF0000FFFF00FF00FFFF0000FF00FF00FF000000FFFFFF
FFFF0000FF00000000FFFF00FFFFFFFFFF00FF00FFFFFF00FF00FFFFFF00FF0000FFFF00
FF0000FF0000FF0000FF0000FFFF000000FFFF00FF00000000FF0000FFFF00FF0000FFFF
FFFF0000FF00FF0000FFFF000000000000FF00FFFF00FFFFFF0000FFFFFFFF00FFFF00FF
FFFF00FFFF00FFFF000000000000FFFF00FFFF0000
00FFFFFFFFFF0000000000FF00FF00FFFF00FF00FF00000000FFFF0000FFFFFFFFFF0000
00FF00FF00000000FF000000FFFFFF0000FF0000FFFFFFFF00FF0000FFFFFF00FFFFFFFF
FFFFFF00FF00FFFF0000FF0000000000FF00FF000000FF00FF00000000FFFFFF0000FF00
FF00FFFFFF00FF00FFFFFF000000FFFF0000FF0000FFFF00FFFFFF0000FF00FF00FFFFFF
FFFFFF0000FFFFFF000000FFFF00FFFF00FF000000FFFFFFFFFF00000000FF0000FF0000
00FF0000FF000000FFFF00FFFF0000FF000000FFFF
FFFFFFFFFFFFFF00FFFF00FF00FF0000FF00FF0000FFFF00FFFFFFFF000000000000FFFF
00FF00FF00FFFF0000FFFF000000FF00FFFFFF0000000000FFFFFF000000FF0000000000
0000FF00FF0000FF00FFFFFF00FFFF00FF0000FFFF00FF0000FFFF00FFFFFFFFFF00FF00
FF000000FF00FF00000000FFFF0000FF00FFFFFF000000FFFFFFFFFF00FF0000FFFFFFFF
FFFFFFFF00000000FFFF0000FF0000FF0000FFFF0000000000FF00FFFF00FF00FFFFFF00
FFFFFF0000FFFF000000FFFFFFFF0000FFFF0000FF
000000000000FF0000FF0000FFFFFF0000FFFFFF0000FF0000000000FFFF00FFFF0000FF
00FF0000FFFFFFFF000000FFFF0000FFFFFFFFFF00FFFF00000000FFFF00FF00FFFF00FF
FF0000FFFFFF00FF000000FF000000FFFFFF000000FFFFFF0000FF0000000000FF00FF00
00FFFF00FF0000FFFF00FFFFFFFF00FF00000000FFFF000000000000FFFFFF0000000000
000000FF00FFFF0000FF00FFFFFF00FF00FFFFFFFF00FFFF00FF0000FF00FF000000FF00
0000FF00FFFFFFFF00FFFFFFFFFFFF0000FF00FFFF
FF00FFFF00FFFFFF00FF00FFFFFFFFFF000000FF00FFFFFF00FFFF000000FFFFFFFF00FF
00FF00FFFFFFFFFFFF00FFFFFFFF0000000000FF0000FF00FFFF0000FF00FF000000FFFF
FFFF000000FF0000FFFF0000FFFF00000000FFFF000000FF00FFFFFF00FFFF0000FFFFFF
000000FFFFFF0000FF00000000FF0000FFFF00FFFFFFFF00FFFF00FFFFFFFFFF00FFFF00
FFFF0000FFFFFFFF00FF000000FF00FF00000000FF000000FFFFFF00FF0000FFFF0000FF
FF00FF0000000000FFFFFFFFFFFFFFFF00FF000000
FF0000FF000000FF00FF000000000000FFFF00FF000000FF000000FFFF00000000FF00FF
00FF000000000000FF00000000FF00FFFF00FFFFFF0000FFFFFFFF00FF0000FFFF000000
0000FFFF00FF00FFFFFFFF0000FF00FFFF000000FFFF00FF000000FF0000FF00FFFFFFFF
FF00FFFFFFFFFF0000FFFF00FFFFFF0000FF00000000FF0000FF0000000000FF000000FF
FFFFFF00000000FF0000FFFF00FF00FF00FFFF0000FFFF000000FF00FF00FFFFFFFF0000
00FFFFFF00FFFF0000000000000000FF0000FFFF00
FFFF0000FFFF00FF0000FFFF00FFFF0000FF0000FFFF0000FFFF0000FF00FFFF00FF00FF
0000FFFF00FFFF00FF00FFFF00FF000000FFFFFFFFFF00000000FF00FF00FFFFFFFF00FF
FF0000FF0000FFFFFFFFFFFF00FF000000FFFF000000FFFFFF00FFFFFF00FF0000000000
00FFFFFFFFFFFFFF000000FFFFFFFFFF00FF00FFFF00FF00FFFFFF00FFFF0000FFFF0000
000000FFFF00FFFFFF0000FF00FF0000FFFFFFFF000000FFFF00FF00FF0000000000FFFF
000000FF0000FF00FFFF00FFFF00FFFFFF0000FF00
FFFFFF000000FFFFFF0000FF0000FF00FFFFFF0000FF00FFFFFFFF00FF0000FF0000FFFF
FF0000FF0000FF00FF0000FF0000FFFF0000000000FF00FFFF00FF00FF00000000FF0000
FF00FFFFFF000000000000FF0000FFFF000000FFFF000000FF000000FF0000FFFF00FFFF
0000000000000000FFFF0000000000FF00FF0000FF00FF000000FF0000FF00FFFFFFFF00
FFFF000000FFFFFFFFFF0000FFFFFF0000000000FFFF0000FF00FF00FF00FFFF00FFFFFF
FF00FFFFFF00FF0000FF000000FFFFFFFFFF00FF00
000000FFFF000000FF00FFFFFF0000FFFFFFFFFF00FF00000000FF00FF00FFFFFF000000
FF00FFFFFF0000FFFFFF00FF00FFFFFFFF00FFFF00FF0000FF00FF0000FFFF00FFFFFF00
FF00000000FFFF00FFFF00FF00FFFFFFFF00FFFFFFFF00FFFFFF00FFFFFF0000FF0000FF
00FFFF00FFFF00FFFFFFFF00FFFF0000FFFFFF0000FFFFFF00FFFFFF00FF0000000000FF
FFFFFF00FFFFFFFFFFFFFF000000FF00FFFF00FFFFFFFF00FF00FF00FF0000FF00000000
FF00000000FFFFFF0000FFFF0000000000FF0000FF
FFFF000000FFFF0000FFFFFFFFFF0000000000FF00FF00FFFF00FF00FF00000000FFFF00
00FFFFFFFFFF000000FF00FF00000000FF000000FFFFFF0000FFFFFF0000FF000000FF00
FF00FFFF0000FF0000FF00FF00000000FF00000000FF000000FF000000FF00FFFFFF00FF
0000FF0000FF00000000FF0000FF00FFFFFFFFFF000000FF00000000FFFFFF00FFFF0000
0000FF0000000000000000FFFF00FF0000FF00000000FF00FF0000FFFFFF00FF00FFFF00
FF00FFFF000000FF00FFFFFFFF00FFFF00FF00FFFF
0000FFFF0000FF00FFFFFFFFFFFFFF00FFFF00FF00FF0000FF00FF0000FFFF00FFFFFFFF
000000000000FFFF00FF00FF00FFFF0000FFFF000000FF00FFFFFFFFFF0000FFFF00FF00
FF0000FF00FFFFFF00FF00FF00FFFF00FF00FFFF0000FFFF0000FFFF00FF000000FF00FF
00FFFFFF0000FFFF00FFFFFF00FF000000000000FFFF00FF00FFFF000000FF000000FFFF
00FFFFFF00FFFF00FFFF000000FFFFFF00FF00FFFF0000FFFFFF000000FF00FF0000FF00
FF000000FFFF00FF00000000FF0000FF00FF000000
00FFFFFFFF00FF00000000000000FF0000FF0000FFFFFF0000FFFFFF0000FF0000000000
FFFF00FFFF0000FF00FF0000FFFFFFFF000000FFFF0000FFFFFFFFFFFFFF0000FF0000FF
FFFF00FF000000FF00FF00FF0000FF00FF0000FF00FFFFFFFF0000FF0000FFFF00FF0000
FFFFFFFFFF0000FF000000FF0000FFFF00FFFF0000FF00FF000000FFFF0000FFFF0000FF
000000FF0000FF000000FFFF000000FF0000FFFFFFFF00000000FFFF0000FFFFFF00FF00
00FFFF0000FF0000FFFF00FFFFFF00FF0000FFFF00
00000000FF0000FFFF00FFFF00FFFFFF00FF00FFFFFFFFFF000000FF00FFFFFF00FFFF00
0000FFFFFFFF00FF00FF00FFFFFFFFFFFF00FFFFFFFF00000000000000FF00FFFFFF0000
00FF0000FFFF00FF0000FFFFFF0000FFFFFF00FF00000000FF00FFFFFF000000FFFFFF00
00000000FF00FFFFFF00FFFFFF000000FFFFFFFF00FF0000FFFF0000FF00FFFFFFFF0000
FFFF00FF00FFFFFF00FFFFFFFF00FFFFFF0000000000FFFF00FFFFFFFF00000000FFFFFF
0000FF00FFFFFF0000FF00000000FFFFFF0000FF00
FFFF00FFFFFF0000FF0000FF000000FF00FF000000000000FFFF00FF000000FF000000FF
FF00000000FF00FF00FF000000000000FF00000000FF00FFFF00FFFF0000FFFFFFFFFF00
FFFFFF0000FF00FF00FFFFFFFFFF000000FF00FF00FFFF0000FFFFFFFFFF00FFFFFFFFFF
00FFFF00FF000000FF00000000FFFF00000000FF00FF00FFFFFFFF0000FFFFFFFFFFFF00
00FF00FF000000FF0000000000FFFFFFFFFF00FFFF0000FF0000000000FFFF00FFFFFFFF
FF0000FFFFFFFFFF0000FFFF00FFFFFFFFFF0000FF
00FF000000FF00FFFFFF0000FFFF00FF0000FFFF00FFFF0000FF0000FFFF0000FFFF0000
FF00FFFF00FF00FF0000FFFF00FFFF00FF00FFFF00FF000000FFFFFFFF000000000000FF
FFFFFFFF00FF00FF000000000000FFFF00FF0000FFFFFFFF0000000000FF0000000000FF
0000FF0000FFFF00FF00FFFF0000FF00FFFF00FF00FF00000000FF00FFFFFFFFFFFFFFFF
0000FFFFFF00FFFFFF00FFFF0000000000FF0000FF00FFFFFF00FFFF0000FF0000000000
FF00FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF0000
0000FFFF0000FFFFFFFFFF000000FFFFFF0000FF0000FF00FFFFFF0000FF00FFFFFFFF00
FF0000FF0000FFFFFF0000FF0000FF00FF0000FF0000FFFF0000000000FFFF00FFFF0000
000000FF00FF0000FFFF00FFFF000000FFFFFF00000000FF00FFFF00FFFFFF00FFFF00FF
00FFFFFF0000FF0000FFFFFFFF00FF0000FF00FF00FF00FFFF0000FFFFFFFFFFFFFFFFFF
FF000000FF000000FF0000FF00FFFF00FFFFFF00FF000000FF0000FF00FFFFFF00FFFF00
00FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF00
00FFFFFFFF000000000000FFFF000000FF00FFFFFF0000FFFFFFFFFF00FF00000000FF00
FF00FFFFFF000000FF00FFFFFF0000FFFFFF00FF00FFFFFFFF00FFFF000000FFFFFFFF00
FFFF0000FFFFFF0000FF000000FFFF000000FF00FFFF00FF0000FF000000FF0000FF00FF
000000FF00FFFFFF0000000000FFFFFF00FF00FF00FF0000FF00FFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFF00FFFFFF00FF0000FF00000000FFFFFF00FFFFFF00FF00000000FFFFFFFF
000000000000000000FF000000000000000000FF00
0000000000FFFF00FFFF000000FFFF0000FFFFFFFFFF0000000000FF00FF00FFFF00FF00
FF00000000FFFF0000FFFFFFFFFF000000FF00FF00000000FF000000FFFF00000000FF00
00FF00FFFFFFFFFF0000FFFF000000FFFF00FF0000FF00FF00FFFFFF00FFFFFF00FF0000
FFFF0000FFFFFFFFFF00FFFF000000FF00FF0000FFFFFF00FF0000000000000000000000
00FF000000FF00000000FFFFFF00FF00FFFF000000FF000000FF0000FFFF00FFFFFFFFFF
FF00FFFF00FFFF00FFFFFF00FFFF00FFFF00FFFFFF
FF00FFFF0000FF000000FFFF0000FF00FFFFFFFFFFFFFF00FFFF00FF00FF0000FF00FF00
00FFFF00FFFFFFFF000000000000FFFF00FF00FF00FFFF0000FFFF000000FFFF00FFFFFF
0000FFFFFFFFFFFFFF000000FFFF000000FFFFFF00FF00FF000000FF000000FF00FF00FF
FFFFFF0000000000FF000000FFFF0000FFFFFF000000FF0000FFFF00FFFF00FFFF00FFFF
0000FFFF00FF00FFFF000000FF0000FFFFFFFF00FFFFFF00FFFFFF0000FF000000000000
FF0000FF0000FF000000FF0000FF000000FFFFFFFF
FF0000FF00FFFFFF00FFFFFFFF00FF00000000000000FF0000FF0000FFFFFF0000FFFFFF
0000FF0000000000FFFF00FFFF0000FF00FF0000FFFFFFFF000000FFFF000000FFFFFFFF
FF0000000000000000FFFF000000FFFF000000FF00FF0000FFFF0000FFFF00FF0000FFFF
FFFFFFFF00FFFF0000FFFF0000FF00FFFFFFFFFF00FFFFFF0000FF0000FF000000FFFFFF
FF0000FF0000FFFFFFFF00FFFFFF00000000FF000000FF000000FF00FFFFFF00FFFF00FF
FFFF00FF00FFFFFF00FFFFFF0000FFFF0000000000
FFFF00FF000000FF00000000FF0000FFFF00FFFF00FFFFFF00FF00FFFFFFFFFF000000FF
00FFFFFF00FFFF000000FFFFFFFF00FF00FF00FFFFFFFFFFFF00FFFFFFFF00FFFFFFFFFF
FFFF00FFFF00FFFF000000FFFF000000FFFF00FF00FF00FFFFFFFF000000FFFFFF000000
000000FF0000FF00FFFFFFFF00FF0000000000FF000000FF00FFFFFF0000FFFF00000000
FF00FFFFFF00000000FF000000FF00FFFF0000FFFF0000FFFF00FF000000FF0000FF0000
00FF00FF000000FF000000FF00FFFFFFFF00FFFF00
00FF0000FFFF0000FFFF00FFFFFF0000FF0000FF000000FF00FF000000000000FFFF00FF
000000FF000000FFFF00000000FF00FF00FF000000000000FF00000000FF000000000000
00FF0000FF000000FFFF000000FFFF0000FF00FF0000FFFFFFFFFFFF00FFFFFFFFFF00FF
FF00FFFFFF00FF0000000000FFFFFF00FFFF0000FFFF0000FFFFFFFFFF0000FF00FFFF00
FF000000FF00FFFF0000FFFF00FF0000FF00FFFFFFFF000000FFFFFF00FFFFFF0000FFFF
00FF0000FFFF0000FFFF00FF0000000000FFFFFFFF
00FF00FFFFFFFF0000FF000000FF00FFFFFF0000FFFF00FF0000FFFF00FFFF0000FF0000
FFFF0000FFFF0000FF00FFFF00FF00FF0000FFFF00FFFF00FF00FFFF00FF00FFFF00FFFF
00FF00FFFFFF00FFFFFFFF00FFFFFFFF0000FFFFFF000000000000FF0000000000FF0000
FF00000000FFFFFF00FFFF00000000FFFFFFFF0000FF00FFFFFFFFFFFFFF00FF0000FF00
00FFFF0000FFFFFFFF000000FFFFFF00FF0000000000FFFF00000000FFFFFFFFFF0000FF
00FF00FFFFFFFF000000FFFFFF00FFFF0000000000
0000FFFFFFFFFFFF0000FFFF0000FFFFFFFFFF000000FFFFFF0000FF0000FF00FFFFFF00
00FF00FFFFFFFF00FF0000FF0000FFFFFF0000FF0000FF00FF0000FF00FF0000FF0000FF
00FF000000FF0000000000FFFFFFFFFFFF00000000FFFF00FFFF00FF00FFFF00FFFFFF00
FF00FFFF000000FF000000FFFF00FFFFFFFFFFFF00FF0000000000000000FFFFFF00FF00
FFFFFFFF0000000000FFFF00000000FFFFFF00FFFF000000FFFF00FFFFFFFFFFFFFF00FF
00FF0000000000FFFF00000000FFFFFFFF00FFFF00
FF000000000000FF00FFFFFFFF000000000000FFFF000000FF00FFFFFF0000FFFFFFFFFF
00FF00000000FF00FF00FFFFFF000000FF00FFFFFF0000FFFFFF00FF00FF00FFFFFF0000
FFFFFF00FFFFFF00FFFF000000000000FF00FFFF0000FF0000FF00FF0000FF000000FF00
FF000000FFFF0000FFFF0000FF00000000000000FFFFFF00FFFF00FFFF000000FF0000FF
FFFFFFFFFF00FFFF0000FF00FFFF000000FF000000FFFF0000FF00000000000000FF0000
FFFFFF00FFFF0000FF00FFFF00000000FF0000FF00
00FFFF00FFFF00FF0000000000FFFF00FFFF000000FFFF0000FFFFFFFFFF0000000000FF
00FF00FFFF00FF00FF00000000FFFF0000FFFFFFFFFF000000FF00FF0000FFFFFFFFFF00
0000FF000000FF000000FFFF00FFFF00FF0000FF00FFFFFF0000FFFFFF0000FFFF00FF00
00FFFF0000FF00FFFFFFFF00FF00FFFF00FFFF000000FF000000FFFFFFFF00FFFFFF0000
0000000000FFFFFFFF0000FFFFFFFF00FFFFFF00FFFFFFFF0000FFFF00FFFF00FFFFFF00
000000FFFFFFFF00FF000000FFFF00FFFFFF0000FF
0000FF000000FFFFFF00FFFF0000FF000000FFFF0000FF00FFFFFFFFFFFFFF00FFFF00FF
00FF0000FF00FF0000FFFF00FFFFFFFF000000000000FFFF0000FFFFFF000000000000FF
FF0000FFFF0000FFFF0000FF000000FFFFFF00FF000000FF00FFFFFFFFFF0000FF00FF00
FFFFFFFF00FF00000000FF00FF0000FF000000FFFF0000FFFF00000000FF00000000FFFF
00FFFF00FFFFFFFFFFFF00000000FF00000000FFFFFFFFFFFF0000FF0000FF000000FF00
FFFF00000000FF0000FFFF000000FFFFFFFFFF0000
FF0000FFFF000000FF0000FF00FFFFFF00FFFFFFFF00FF00000000000000FF0000FF0000
FFFFFF0000FFFFFF0000FF0000000000FFFF00FFFF0000FF00FFFFFFFFFF00FFFF00FFFF
FFFF0000FF00FFFFFFFF0000FFFF000000FF0000FFFF0000FFFFFFFFFFFFFF00FF00FF00
000000FF00FF00FFFF00FF00FF00FFFFFF00FFFFFFFF0000FF00FFFF00FF00FFFF0000FF
0000FF000000000000FF00FFFF00FF00FFFF000000000000FF00FFFFFF0000FFFF00FF00
00FF00FFFF00FF00FFFFFFFF00FFFFFFFFFFFFFF00
FF00FFFFFFFF00FFFFFF00FF000000FF00000000FF0000FFFF00FFFF00FFFFFF00FF00FF
FFFFFFFF000000FF00FFFFFF00FFFF000000FFFFFFFF00FF0000000000FF000000FFFFFF
FFFFFF0000FFFFFFFFFFFF000000FFFF00FF00FFFFFFFF00000000000000FF00FF00FF00
FFFF00FF00FF0000FF00FF00FF00000000FFFFFFFFFFFF00FF0000FF00FF0000FF00FFFF
FF0000FFFF00FFFF00FF0000FF00FF000000FFFF00FFFF0000FFFFFFFFFF000000FFFFFF
00FF0000FF00FF00000000FF00000000000000FF00
FF00000000FF000000FF0000FFFF0000FFFF00FFFFFF0000FF0000FF000000FF00FF0000
00000000FFFF00FF000000FF000000FFFF00000000FF00FF00FFFF00FFFFFF00FFFFFFFF
FFFFFFFF00000000000000FFFF0000FF00FF00000000FF00FFFF00FFFF00FF00FF00FF00
00FF0000FFFFFF00FF00FF00FF00FFFF00000000000000FFFFFF0000FFFFFF0000FFFFFF
FFFF0000FF000000FFFFFF00FF0000FFFF000000FFFFFFFF000000000000FFFF00000000
FFFFFF00FF00FF00FFFF00FF00FFFF00FFFF00FF00
FF00FFFF0000FFFF00FF00FFFFFFFF0000FF000000FF00FFFFFF0000FFFF00FF0000FFFF
00FFFF0000FF0000FFFF0000FFFF0000FF00FFFF00FF00FF0000FF000000FF0000000000
00000000FFFF00FFFF00FFFFFFFF00FF00FF00FFFF00FF0000FF0000FF00FF00FF00FF00
FFFFFF000000FF00FF00FF00FF000000FFFF00FFFF00FFFFFFFFFF000000FF00FFFFFFFF
FFFFFF0000FFFF00000000FFFFFF000000FFFF0000000000FFFF00FFFF0000FF00FFFF00
0000FF00FF00FF0000FF00FF0000FF0000FF0000FF
00FFFFFFFF0000FF0000FFFFFFFFFFFF0000FFFF0000FFFFFFFFFF000000FFFFFF0000FF
0000FF00FFFFFF0000FF00FFFFFFFF00FF0000FF0000FFFFFF0000FFFF0000FFFF00FFFF
00FFFF0000FF0000FF00000000FF00FF00FF0000FF00FF00FFFFFF00FF00FF00FF00FF00
000000FFFF00FF00FF00FF0000FFFF0000FF0000FF000000000000FFFF0000FFFFFFFFFF
FFFFFFFF000000FFFF00FFFFFFFFFF00FFFFFFFF00FFFF000000FFFFFFFF00FF000000FF
FF00FF0000FFFFFF0000FFFFFF00FF00FFFFFF0000
00000000FF00FFFFFF000000000000FF00FFFFFFFF000000000000FFFF000000FF00FFFF
FF0000FFFFFFFFFF00FF00000000FF00FF00FFFFFF000000FF00FFFFFFFF0000FF0000FF
0000FF00FFFFFF00FF00FFFF00FF0000FFFFFF00FF00FF000000FF00FF00FF00FF00FF00
FFFF0000FF00FF00FF00FF00FFFFFFFF00FF00FFFFFF00FFFF00FFFFFFFF000000000000
00000000FFFF0000FF0000000000FF00000000FF000000FFFF00000000FF0000FFFF0000
FF00FF00FFFFFFFFFF000000FF0000FFFFFFFFFF00
00FFFF00FF00000000FFFF00FFFF00FF0000000000FFFF00FFFF000000FFFF0000FFFFFF
FFFF0000000000FF00FF00FFFF00FF00FF00000000FFFF0000FFFFFFFFFFFF00FF00FFFF
FF00FF000000FF00FF000000FFFFFF000000FF00FF0000FFFF00FF00FF00FF00FF0000FF
FFFFFF00FF00FF00FF00FF00000000FF00FF000000FF0000FF00000000FF00FFFF00FFFF
00FFFF0000FF00FFFFFF00FFFF00FF00FFFF0000FFFF0000FF00FFFF00FF00FFFFFFFF00
FF0000FFFFFFFFFFFFFF00FFFFFF000000000000FF
0000FF00FF00FFFF0000FF000000FFFFFF00FFFF0000FF000000FFFF0000FF00FFFFFFFF
FFFFFF00FFFF00FF00FF0000FF00FF0000FFFF00FFFFFFFF000000000000FF00FF000000
FF0000FFFF00FF0000FFFF00000000FFFF0000FFFFFF0000FF00FF00FF0000FFFFFF0000
0000FF00FF00FF00FF00FF00FFFF0000FFFFFF00FFFFFF00FF00FFFF00FF0000FF000000
FFFFFFFF00FF000000FF0000FF00FF0000FF00FFFFFFFF00FF0000FF00FF0000000000FF
FFFF00000000000000FF00000000FFFF00FFFF0000
FF00FF0000FFFFFFFF0000FFFF000000FF0000FF00FFFFFF00FFFFFFFF00FF0000000000
0000FF0000FF0000FFFFFF0000FFFFFF0000FF0000000000FFFF00FFFF0000FFFFFF00FF
FFFF000000FFFFFF0000FF00FFFF0000FF00FFFFFFFFFF00FF0000FFFFFF000000FF00FF
FF00FF00FF00FF00FF0000FFFFFFFF000000FF000000FF00FF000000FFFFFF0000FFFF00
00000000FFFFFF00FFFFFF0000FFFFFF00FF0000000000FFFFFF0000FFFFFF00FFFF0000
00FF00FFFF00FFFF00FF00FFFF000000FFFFFFFF00
00FFFFFF00000000FF00FFFFFFFF00FFFFFF00FF000000FF00000000FF0000FFFF00FFFF
00FFFFFF00FF00FFFFFFFFFF000000FF00FFFFFF00FFFF000000FFFFFFFF00000000FFFF
FFFFFF00FFFFFFFFFF0000FFFFFFFF00FF000000000000FFFFFF00000000FFFF00FF0000
FF00FF00FF0000FFFFFF0000000000FFFF0000FFFF00FF0000FFFF000000FF00FFFFFFFF
00FFFF00000000FFFFFFFFFF000000FF00FF00FFFF00FFFFFFFFFF000000FF000000FFFF
00FF0000FF0000FF00FF000000FFFF0000000000FF
000000FF00FFFF00FF00000000FF000000FF0000FFFF0000FFFF00FFFFFF0000FF0000FF
000000FF00FF000000000000FFFF00FF000000FF000000FFFF00000000FF00FFFF000000
000000FFFFFFFFFFFFFF00000000FF0000FFFF00FFFF000000FF00FFFF000000FFFFFF00
FF0000FFFFFF000000FF00FFFF00FFFFFFFF000000FFFFFF000000FFFF00FF00000000FF
0000FF00FFFF000000000000FFFF00FF00FF0000FF000000000000FFFF0000FFFF0000FF
00FF00FFFFFF0000FFFFFF00FFFFFFFF00FFFF0000
FFFF00FF0000FF00FF00FFFF0000FFFF00FF00FFFFFFFF0000FF000000FF00FFFFFF0000
FFFF00FF0000FFFF00FFFF0000FF0000FFFF0000FFFF0000FF00FFFF00FF000000FFFF00
FFFF0000000000000000FFFF00FFFFFF0000FF000000FFFF00FF000000FFFF00000000FF
FFFF00000000FFFF00FF0000FF0000000000FFFF00000000FFFF0000FF0000FFFF00FFFF
FF00FF000000FFFF00FFFF0000FF0000FFFFFF0000FFFF00FFFF0000FF00FFFFFFFF00FF
0000FFFFFFFFFF000000FF00000000FF0000FF00FF
0000FFFFFF00FF0000FFFFFFFF0000FF0000FFFFFFFFFFFF0000FFFF0000FFFFFFFFFF00
0000FFFFFF0000FF0000FF00FFFFFF0000FF00FFFFFFFF00FF0000FF0000FFFF000000FF
FFFFFF00FFFF00FFFF000000FFFFFFFFFF0000FFFF0000FF0000FFFF0000FF00FFFF0000
00FF00FFFF0000FF00FF00FFFFFF00FFFF0000FF00FFFF0000FF00FFFFFF0000FF000000
FF0000FFFF000000FFFFFFFF00FF00FFFFFFFFFF000000FFFFFFFF00FF0000000000FFFF
FF000000000000FFFF0000FFFF00FFFFFF00FF0000
FF00000000FFFFFF00000000FF00FFFFFF000000000000FF00FFFFFFFF000000000000FF
FF000000FF00FFFFFF0000FFFFFFFFFF00FF00000000FF00FF00FFFFFF000000FFFF0000
0000FF0000FF000000FFFF0000000000FF00FFFFFFFF00FF00FFFFFFFF00FF000000FFFF
0000FFFFFFFF00FF00FF00000000FFFFFFFF0000FFFFFFFF00FF000000FF00FFFFFF00FF
FFFF000000FFFF00000000FF00FF000000000000FFFF00000000FF00FF00FFFF00FFFFFF
FFFF00FFFF00FFFFFFFF0000FF00000000FFFFFF00
FF00FFFF000000FF00FFFF00FF00000000FFFF00FFFF00FF0000000000FFFF00FFFF0000
00FFFF0000FFFFFFFFFF0000000000FF00FF00FFFF00FF00FF00000000FFFF0000FF00FF
FF00FF00FFFFFF00FFFFFFFF00FFFF00FF00000000FF00FF0000000000FFFFFF00FFFFFF
FF00000000FF00FF0000FFFF00FFFFFFFFFFFF00000000FF0000FFFF00FF000000FF0000
0000FFFF0000FF00FFFF00FF0000FFFF00FFFF0000FF00FFFF00FF00FF0000FF00000000
00FF000000FFFFFFFFFFFF00FF00FFFF000000FF00
FF000000FFFF00FF0000FF00FF00FFFF0000FF000000FFFFFF00FFFF0000FF000000FFFF
0000FF00FFFFFFFFFFFFFF00FFFF00FF00FF0000FF00FF0000FFFF00FFFFFFFF00FF0000
FF00FF000000FF00000000FF0000FF00FF00FFFF0000FFFFFF00FFFF000000FF00000000
FF00FFFF0000FFFFFF0000FF00000000000000FFFF00FFFFFF0000FF0000FFFF0000FFFF
00FFFFFFFF00FF000000FFFFFF000000FFFFFFFF00FF0000FF00FF00FF00FFFFFF00FFFF
0000FFFF000000000000FF0000FFFFFFFF00FFFFFF
00FFFF000000FFFFFF00FF0000FFFFFFFF0000FFFF000000FF0000FF00FFFFFF00FFFFFF
FF00FF00000000000000FF0000FF0000FFFFFF0000FFFFFF0000FF0000000000FFFFFF00
FF0000FFFF0000FFFF00FFFFFF00FF0000FFFFFFFF000000FF000000FFFF00FF00FFFF00
FF0000FF00FFFFFFFFFF00FF00FFFF00FFFF000000FFFFFFFFFF00FF00FFFFFFFF0000FF
00000000FF0000FFFF00000000FFFF0000000000FFFFFF00FF00FF00FF000000FF0000FF
00FFFFFFFF00FFFF00FFFFFF00000000FF000000FF
000000FFFF00000000FFFFFF00000000FF00FFFFFFFF00FFFFFF00FF000000FF00000000
FF0000FFFF00FFFF00FFFFFF00FF00FFFFFFFFFF000000FF00FFFFFF00FFFF000000FF00
FF00FFFFFFFF0000FF00000000FFFFFF0000000000FFFF0000FFFF0000FF00FF000000FF
FFFF00FF0000000000FF00FF0000FF000000FFFF0000000000FF0000FFFFFFFFFFFF0000
FFFF00FFFFFF000000FFFF00FFFFFFFF00FFFF000000FF00FF0000FFFFFF00FFFFFF00FF
00000000FF0000FF000000FF00FFFF0000FFFF00FF
FFFF0000FF00FFFF000000FF00FFFF00FF00000000FF000000FF0000FFFF0000FFFF00FF
FFFF0000FF0000FF000000FF00FF000000000000FFFF00FF000000FF000000FFFF00FF00
00FFFFFFFFFFFF0000FFFF00FFFFFFFFFF00FFFF0000FF00FFFFFFFF00FF0000FFFF0000
0000FFFFFF00FFFF00FF00FF00FFFFFF00FFFFFFFF00FFFF00FF00FFFFFFFFFFFFFFFF00
00FF00000000FFFF0000FF00000000FF000000FFFF0000FFFFFF000000FF000000FF0000
FFFF00FFFFFF0000FFFF0000FFFFFFFF000000FFFF
FFFFFF00FF000000FFFF00FF0000FF00FF00FFFF0000FFFF00FF00FFFFFFFF0000FF0000
00FF00FFFFFF0000FFFF00FF0000FFFF00FFFF0000FF0000FFFF0000FFFF0000FF00FF00
FFFFFFFFFFFFFFFF0000FF000000000000FFFFFFFF00FF0000000000FFFFFF0000FF00FF
FF000000FF0000FF00FF00FF000000FF00000000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
0000FFFF00FFFFFFFF00FF00FFFF0000FFFF0000FF00FFFFFFFFFF00FFFFFF00FFFFFF00
00FF000000FF00FFFFFFFF0000000000FFFF000000
0000FF0000FFFF000000FFFFFF00FF0000FFFFFFFF0000FF0000FFFFFFFFFFFF0000FFFF
0000FFFFFFFFFF000000FFFFFF0000FF0000FF00FFFFFF0000FF00FFFFFFFF00FF0000FF
FFFFFFFFFFFFFFFFFF0000FFFF00FFFF00000000FF00FF00FFFF00FFFFFFFFFF0000FFFF
FFFF00FFFFFF00FF00FF0000FFFF0000FFFF00FFFFFF00FF00FFFFFFFFFFFFFFFFFFFFFF
FF0000FF00000000FF00FF0000FF00FFFFFFFF00FF0000000000FF00000000FFFFFFFFFF
0000FFFF00FF00000000FF00FFFF00FFFFFFFF00FF
00FFFFFF000000FFFF00000000FFFFFF00000000FF00FFFFFF000000000000FF00FFFFFF
FF000000000000FFFF000000FF00FFFFFF0000FFFFFFFFFF00FF00000000FF00FF00FFFF
FFFFFFFFFFFFFFFFFFFF0000FF0000FF00FFFF00FF00FF000000FFFFFFFFFFFFFF000000
00FF000000FF00FF00FF00FFFFFFFF0000FF000000FF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FF00FFFF0000FFFFFF00FF0000000000FFFFFF00FFFF0000FFFF00FFFFFFFFFFFF
FF0000FF00FF00FFFF00FF0000FF0000000000FFFF
00000000FFFF0000FF00FFFF000000FF00FFFF00FF00000000FFFF00FFFF00FF00000000
00FFFF00FFFF000000FFFF0000FFFFFFFFFF0000000000FF00FF00FFFF00FF00FF000000
000000000000000000FF00FFFFFF00FF0000FF00FF0000FFFF00000000000000FF00FFFF
0000FFFF00FF00FF00FF00000000FF00FFFFFF00FFFFFF00000000000000000000000000
00FF0000FFFFFFFF00000000FFFFFF00FFFF00000000FFFFFFFF000000FFFFFFFFFFFFFF
FFFF00FF00FF0000FF00FF00FFFFFF00FFFF000000
FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00FF00FFFF0000FF000000FFFFFF00FFFF
0000FF000000FFFF0000FF00FFFFFFFFFFFFFF00FFFF00FF00FF0000FF00FF0000FFFF00
FFFF00FFFF00FFFF00FF00000000FFFFFF0000FFFFFF0000FF00FFFF00FFFF0000FFFFFF
FF0000FF00FF00FF00FF00FFFF00FF000000FF000000FF00FFFF00FFFF00FFFF00FFFF00
FFFFFF00000000FF00FFFF000000FF0000FF00FFFF0000000000FFFF0000000000000000
00FF0000FFFFFF00FF00FF00000000FFFFFFFF00FF
00FF00000000FF0000FFFF000000FFFFFF00FF0000FFFFFFFF0000FFFF000000FF0000FF
00FFFFFF00FFFFFFFF00FF00000000000000FF0000FF0000FFFFFF0000FFFFFF0000FF00
00FF0000FF0000FF00FF00FFFF000000FF00FFFFFFFFFF00FF0000FF0000FF00FFFFFFFF
FFFF00FF00FF00FF00FF0000FF0000FFFF0000FFFF00FF0000FF0000FF0000FF0000FF00
0000FF00FFFF0000FFFFFFFF00FFFFFF00FF0000FF00FFFF00FFFFFFFF00FFFF00FFFF00
FFFFFF000000FF00FF00FF00FFFF00000000FF0000
0000FFFF00FFFFFF000000FFFF00000000FFFFFF00000000FF00FFFFFFFF00FFFFFF00FF
000000FF00000000FF0000FFFF00FFFF00FFFFFF00FF00FFFFFFFFFF000000FF00FFFFFF
00FF00FFFFFF00FF00FF000000FFFF00FF0000000000FF00FF00FFFFFF00FF0000000000
00FF00FF00FF0000FFFFFF00FF00FFFFFFFF0000FF00FF00FFFFFF00FF00FFFFFF0000FF
FF0000FFFFFFFF00000000FF00000000FFFFFF00FF0000FF00000000FF0000FF0000FF00
000000FFFF00FF00FF00FF000000FFFF00FFFFFF00
FF0000FF00000000FFFF0000FF00FFFF000000FF00FFFF00FF00000000FF000000FF0000
FFFF0000FFFF00FFFFFF0000FF0000FF000000FF00FF000000000000FFFF00FF000000FF
00FF000000FF00FF0000FFFF000000FFFFFF00FFFF00FF00FF000000FF0000FFFF00FFFF
00FF0000FFFFFF000000FF0000FFFFFFFFFFFF00FF00FF000000FF00FF000000FF00FFFF
FFFF00000000FF00FFFF00FF00FFFF00000000FFFFFF00FF00FFFF00FF00FFFFFF00FF00
FFFF0000FF00FF00FF0000FFFF0000FF00000000FF
FFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00FF00FFFF0000FFFF00FF00FF
FFFFFF0000FF000000FF00FFFFFF0000FFFF00FF0000FFFF00FFFF0000FF0000FFFF00FF
0000FFFF0000FFFFFF000000FFFF000000FF0000FF0000FFFFFF00FFFFFF0000FF0000FF
00FF00FFFFFFFFFF00FFFFFF000000000000FF00FF0000FFFF00FF0000FFFF00FF000000
00FF00FFFF00FF0000FF00FF0000FF00FFFF000000FF00FF0000FF00FF000000FF0000FF
FFFFFF00FF00FF00FF00FFFFFFFF0000FFFF00FFFF
FFFFFF0000FF00000000FF0000FFFF000000FFFFFF00FF0000FFFFFFFF0000FF0000FFFF
FFFFFFFF0000FFFF0000FFFFFFFFFF000000FFFFFF0000FF0000FF00FFFFFF0000FF00FF
00FFFFFFFF00000000FFFF000000FFFF00FF00FFFFFF000000FF000000FF00FFFFFF00FF
00FF0000000000FF00000000FFFF00FFFF0000FFFFFF000000FFFFFF0000FF00FF00FFFF
00FF000000FFFFFF0000FFFFFF00FF000000FFFF0000FFFFFF0000FFFFFF00FFFFFF0000
0000FF00FF00FF0000FFFFFFFFFFFF000000FFFFFF
FFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FFFFFF00000000FF00FFFFFF000000
000000FF00FFFFFFFF000000000000FFFF000000FF00FFFFFF0000FFFFFFFFFF00FF00FF
00000000FF00FFFF000000FFFF0000FF00FF00000000FFFF0000FFFF00FF000000FF0000
FFFFFF00FFFF00FF00FFFF0000FF0000FF00FFFFFFFFFF00FFFFFFFFFF00FF00FF000000
FFFFFF00FFFFFFFFFF000000FF0000FFFF0000FF00FFFFFFFFFF000000FF000000FF00FF
FF00FF00FF00FF00FFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFF0000FF00000000FFFF0000FF00FFFF000000FF00FFFF00FF00000000FFFF00
FFFF00FF0000000000FFFF00FFFF000000FFFF0000FFFFFFFFFF0000000000FF00FF00FF
00FFFF0000FFFFFFFF00FFFFFFFF00FF0000FFFF00FFFFFFFF000000FFFFFF00FFFFFF00
0000FF0000FF00FF0000FF00FFFFFF00FF0000000000FF0000000000FF00FF0000FFFF00
0000FF000000000000FFFF00FF00FFFFFFFF00FF000000000000FFFF0000FFFF00FF0000
FF00FF00FF00FF000000000000000000FFFFFFFFFF
FFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00FF00FFFF0000FF00
0000FFFFFF00FFFF0000FF000000FFFF0000FF00FFFFFFFFFFFFFF00FFFF00FF00FF0000
FFFFFFFF00000000FF0000000000FFFFFF0000FF0000000000FFFF00000000FFFFFFFFFF
00FFFFFF0000FFFFFF00FF000000FF00FF00FFFF00FFFFFF00FFFF0000FFFFFF000000FF
FF0000FFFF00FFFF0000FF00FF0000000000FFFFFF00FFFF00FFFFFFFF000000FFFFFF00
FF00FF0000FFFFFF00FFFF00FFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FFFFFF00FF0000FFFFFFFF0000FF
FF000000FF0000FF00FFFFFF00FFFFFFFF00FF00000000000000FF0000FF0000FFFFFF00
00000000FFFF00FFFFFF00FFFF000000FF00FFFFFF00FFFF0000FF00FFFF000000000000
FFFFFFFFFF000000FF0000FFFF00FF00FF0000FF000000FF0000FF00FFFFFFFFFF00FFFF
FFFF000000FFFFFFFF0000FFFFFF00FFFF000000FF0000FF0000000000FFFF000000FF00
00FFFFFF000000FF0000FF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FFFFFF00000000FF00FFFF
FFFF00FFFFFF00FF000000FF00000000FF0000FFFF00FFFF00FFFFFF00FF00FFFFFFFFFF
00FFFF0000FF000000FF000000FFFF00FF00000000FFFFFFFF0000FFFFFFFF00FFFF00FF
FFFFFFFFFFFF00FFFFFF0000FF00FF00FF00FFFFFF00FFFFFF00FF000000000000FFFFFF
FFFFFF00FFFFFFFFFFFF00000000FFFFFFFF00FFFFFF00FF00FFFF00FFFFFFFF00FFFFFF
00000000FFFF00FF00FFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFF000000FF00FFFF00FF000000
00FF000000FF0000FFFF0000FFFF00FFFFFF0000FF0000FF000000FF00FF000000000000
FFFFFFFF0000FFFF0000FFFF0000FF0000FFFF00FFFFFFFFFFFF00000000FF0000FF0000
000000000000FFFFFFFFFF00FF00FF00FF000000FF000000FF0000FFFF00FFFF00000000
0000FF000000000000FF00FFFF00000000FF000000FF00FF0000FF00000000FF000000FF
00FFFF0000FF00FF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00FF00FFFF
0000FFFF00FF00FFFFFFFF0000FF000000FF00FFFFFF0000FFFF00FF0000FFFF00FFFF00
000000FF00FFFFFFFF0000FF00FFFFFF0000FF000000000000FF00FFFF00FF00FFFFFF00
FFFF00FFFF0000000000FF00FF0000FFFFFF00FFFFFF00FFFFFF0000FF000000FFFF00FF
FF0000FFFF00FFFF00FF0000FF00FFFF0000FFFF0000FFFFFF00FF00FFFF0000FFFF0000
FFFFFFFF00FF0000FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FFFFFF00FF0000FFFFFF
FF0000FF0000FFFFFFFFFFFF0000FFFF0000FFFFFFFFFF000000FFFFFF0000FF0000FF00
FFFF0000FFFFFFFFFFFF0000FFFFFFFFFF0000FFFF00FFFF00FF0000FF00FF000000FF00
0000FFFFFFFF00FFFF0000FFFFFF000000FF00000000FFFFFFFFFF0000FFFF000000FFFF
FFFF0000FF000000FFFFFF00FF0000FF00FFFFFFFF000000FF00FF0000FF00FFFFFFFF00
00000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FFFFFF00000000
FF00FFFFFF000000000000FF00FFFFFFFF000000000000FFFF000000FF00FFFFFF0000FF
FFFFFF000000000000FF00FFFFFFFFFFFFFF0000FF000000FFFFFF00FF0000FFFF0000FF
FF0000000000FFFFFFFF00000000FFFF00FF00FFFF0000000000FF00FFFFFFFF00FFFFFF
FFFFFF0000FFFF00000000FFFFFF00FF0000000000FFFF0000FFFFFF00FF00000000FF00
FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFF000000FF00FFFF00
FF00000000FFFF00FFFF00FF0000000000FFFF00FFFF000000FFFF0000FFFFFFFFFF0000
000000FFFF00FFFF0000FFFFFFFFFFFFFFFFFF0000FFFF00000000FFFFFF0000FF00FFFF
FFFF00FFFF00000000FF00FFFF0000FF0000FFFFFFFF00FFFF00FF0000000000FFFFFFFF
FFFFFFFF0000FF00FFFF000000FF00FF00FFFF00FFFFFFFF000000FF00FF00FFFF00FF00
00FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00
FF00FFFF0000FF000000FFFFFF00FFFF0000FF000000FFFF0000FF00FFFFFFFFFFFFFF00
FFFF0000FF0000FF00FFFFFFFFFFFFFFFFFFFFFF000000FFFF00FFFFFFFFFF00FF000000
00FF0000FF00FFFF00FF0000FF00FFFFFF00000000FF0000FF00FF00FFFF00FFFFFFFFFF
FFFFFFFFFF00FF000000FFFF00FF00FF0000FF0000000000FFFF00FF00FF0000FF00FF00
FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FFFFFF00FF00
00FFFFFFFF0000FFFF000000FF0000FF00FFFFFF00FFFFFFFF00FF00000000000000FF00
00FF00FFFFFF00FF000000000000000000000000FFFF0000FF0000000000FF0000FFFF00
FFFFFF00FF000000FFFFFF00FF00000000FFFF00FFFFFF00FF00FF0000FF000000000000
00000000FF0000FFFF0000FF00FF00FF00FFFFFF00FFFF0000FF0000FFFFFF00FF00FF00
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FFFFFF
00000000FF00FFFFFFFF00FFFFFF00FF000000FF00000000FF0000FFFF00FFFF00FFFFFF
00FF00000000FFFFFF00FFFF00FFFF00FFFF00FFFFFFFF00FF00FFFF00FFFFFF0000FF00
0000FF0000FFFF000000FF00FF00FFFF0000FF000000FF0000FFFFFF00FF00FFFF00FFFF
00FFFF00FF00FFFFFFFF00FF00FF00FF000000FF0000FF00FFFFFF000000FF0000FFFFFF
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFF000000FF
00FFFF00FF00000000FF000000FF0000FFFF0000FFFF00FFFFFF0000FF0000FF000000FF
00FF00FFFF000000FF0000FF0000FF0000FF00000000FF00FF0000FF000000FF00FFFFFF
00FFFFFF000000FFFF00FF00FF0000FF00FFFFFF00FFFFFF000000FF00FF0000FF0000FF
0000FF00FF00000000FF00FF0000FFFFFF00FFFFFF0000FFFFFFFFFF00FFFFFF000000FF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF
0000FF00FF00FFFF0000FFFF00FF00FFFFFFFF0000FF000000FF00FFFFFF0000FFFF00FF
0000FFFFFFFF00FFFFFF00FF00FFFFFF00FF00FFFF0000FFFFFF0000FFFF00FF000000FF
00000000FFFF0000FF0000FFFFFF00FF000000FF00000000FFFF0000FFFFFF00FF00FFFF
FF00FF00FF00FFFF0000FFFFFF00000000FFFFFFFFFF0000000000FF00000000FFFF0000
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FFFF
FF00FF0000FFFFFFFF0000FF0000FFFFFFFFFFFF0000FFFF0000FFFFFFFFFF000000FFFF
FF00000000FF000000FF00FF000000FF00FF0000FF00FFFFFFFFFF0000FF0000FFFF00FF
00FFFF0000FF00FFFFFF000000FF0000FFFF0000FFFF00FFFFFFFF000000FF00FF000000
FF00FF0000FFFFFFFF00000000FFFF00FFFFFFFFFFFFFF00FFFF0000FFFF00FFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF000000
00FFFFFF00000000FF00FFFFFF000000000000FF00FFFFFFFF000000000000FFFF000000
FF00FFFF0000FFFF00FF0000FFFF0000FFFFFF00FF0000000000FF00FFFFFF0000FF0000
FFFFFFFF00FF00000000FFFF00FF00FFFFFFFF0000FF0000000000FFFF00FF0000FFFF00
00FFFFFF00000000FF00FFFF0000FF0000000000000000FFFFFFFF000000FFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFF
000000FF00FFFF00FF00000000FFFF00FFFF00FF0000000000FFFF00FFFF000000FFFF00
00FFFFFFFF0000FF00FF00FFFFFFFF00000000FFFFFF00FFFF00FF000000FF00FFFFFF00
000000FF00FF00FFFF0000FF00FF00000000FF00FFFFFF00FFFF0000FF00FF00FFFFFFFF
000000FF00FFFF00FF0000FF00FFFFFF00FFFF00FFFF0000000000FFFF00000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000
FFFF00FF0000FF00FF00FFFF0000FF000000FFFFFF00FFFF0000FF000000FFFF0000FF00
FFFFFFFFFFFF00FF00FF00000000FF00FFFF000000FF0000FF0000FFFF00FF000000FF00
FFFF00FF0000FFFFFFFF00FF00FF00FFFF00FF00000000FFFFFFFF00FF00FF0000000000
FFFF00FF000000FFFFFF00FF000000FF000000FFFFFFFF00FFFF000000FFFF00FFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF00
0000FFFFFF00FF0000FFFFFFFF0000FFFF000000FF0000FF00FFFFFF00FFFFFFFF00FF00
0000000000FF00FF00FF00FFFF00FF000000FFFF00FF00FFFFFF0000FF0000FFFF00FF00
0000FFFFFF00000000FF00FF00FF0000FF00FF00FFFF00000000FF0000FFFFFF00FFFF00
00FF0000FFFF000000FF0000FFFF0000FFFF00000000FF000000FFFF0000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FF
FF00000000FFFFFF00000000FF00FFFFFFFF00FFFFFF00FF000000FF00000000FF0000FF
FF00FFFF00FF00FF00FF0000FF0000FFFF0000FF00FF000000FF00FFFFFF0000FF0000FF
FF000000FF00FFFF00FF0000FFFFFF00FF00FF000000FFFF00FFFFFF000000FF0000FF00
FFFFFF000000FFFF00FF00FFFFFFFF0000FF00FFFF0000FFFF0000FF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000
FF00FFFF000000FF00FFFF00FF00000000FF000000FF0000FFFF0000FFFF00FFFFFF0000
FF0000FF00FF0000FFFFFF00FF00FFFFFFFF00FF0000FFFF00FF000000FF00FFFFFF0000
00FFFF00FF000000FFFFFF000000FF00FF0000FFFF000000FFFFFFFFFF00FFFFFF00FF00
000000FFFF0000FF0000FFFFFFFFFFFF00FF0000FF00FFFFFFFF00FF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00
FF000000FFFF00FF0000FF00FF00FFFF0000FFFF00FF00FFFFFFFF0000FF000000FF00FF
FFFF0000FFFFFF000000FF00FF0000000000FFFFFF0000FF0000FFFF00FF00000000FFFF
0000FF0000FFFF00000000FFFF0000FFFFFF000000FFFF0000000000FF000000FF00FF00
FFFF0000FF00FFFFFF00000000000000FFFFFF00FF00000000FF0000FFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF00
00FFFF000000FFFFFF00FF0000FFFFFFFF0000FF0000FFFFFFFFFFFF0000FFFF0000FFFF
FFFFFF00000000FFFF0000FFFFFF00FFFF000000FF00FFFFFF0000FF00FF00FFFF0000FF
00FFFFFF0000FF00FFFF0000FF00FFFFFFFFFF00FFFFFFFF00FFFF0000FFFF00FF0000FF
FFFFFF00FF000000FF00FFFF00FFFF000000FF0000FFFF00FFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF
000000FFFF00000000FFFFFF00000000FF00FFFFFF000000000000FF00FFFFFFFF000000
000000FFFF00FFFFFFFF000000FF000000FFFF0000FFFFFFFFFF00FF0000FFFFFFFF0000
FFFFFFFFFF0000FFFFFFFF00FF0000000000FF0000000000FFFFFFFF000000FFFFFF0000
0000FF0000FFFF00FF000000FFFFFFFF00FFFFFF000000FFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000
FFFF0000FF00FFFF000000FF00FFFF00FF00000000FFFF00FFFF00FF0000000000FFFF00
FFFF000000FFFFFFFFFFFF00FFFFFF00FFFFFFFF000000000000FFFFFF00000000FF00FF
FFFFFFFFFFFF00000000FF00FF00FFFF00FFFFFF00FFFF0000000000FFFF00000000FFFF
00FFFFFF0000FF0000FFFF00000000FF00000000FFFF000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF
FFFFFF00FF000000FFFF00FF0000FF00FF00FFFF0000FF000000FFFFFF00FFFF0000FF00
0000FFFF000000000000FF000000FF0000000000FFFF00FFFF000000FF00FFFF00FF0000
0000000000FF00FFFF00FF00FF0000FF00000000FFFFFFFF00FFFF0000FF00FFFF0000FF
000000FF00FFFFFF0000FF00FFFF0000FFFF00FFFFFFFF00FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
0000FF0000FFFF000000FFFFFF00FF0000FFFFFFFF0000FFFF000000FF0000FF00FFFFFF
00FFFFFFFF00FFFF00FFFFFF00FFFFFF00FFFF0000FF000000FFFF00FF0000FF00FF00FF
FF00FFFF00FF0000FF0000FFFFFF00FF00FFFF0000000000FFFFFFFF0000FFFFFFFF0000
FFFF0000FFFFFFFFFF0000FFFFFFFF0000FF00000000FF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
00FFFFFF000000FFFF00000000FFFFFF00000000FF00FFFFFFFF00FFFFFF00FF000000FF
00000000FF0000FF000000FF00000000FFFFFFFF0000FFFF000000FFFFFF00FF00FF0000
FF0000FF00FF00FFFFFF000000FF00FF0000FF00FFFF00FFFFFFFFFFFF00000000FF00FF
FFFFFF0000000000FF00FFFFFFFFFFFF0000FFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
00000000FFFF0000FF00FFFF000000FF00FFFF00FF00000000FF000000FF0000FFFF0000
FFFF00FFFFFF0000FFFF0000FFFF00FFFFFFFFFFFF000000FFFF000000FF00FF00FF00FF
FFFF00FF00FF00000000FFFF0000FFFFFF00FF0000FF000000000000FF00FFFF0000FFFF
FFFFFFFF00FFFF0000FFFFFFFFFFFFFFFF0000FF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00FF00FFFF0000FFFF00FF00FFFFFFFF00
00FF000000FF00FFFFFFFF0000FF00000000000000FFFF000000FFFF00FF00FF00FF0000
00FF00FF0000FFFF00FFFFFFFF00000000FFFFFF0000FFFF00FFFF0000FFFFFFFF000000
000000FF0000FF00FFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00000000FF0000FFFF000000FFFFFF00FF0000FFFFFFFF0000FF0000FFFFFFFFFFFF
0000FFFF0000FFFFFFFFFFFF00FF00FFFF00FFFF000000FFFF0000FF00FF00FF0000FFFF
0000FFFFFF0000FF0000000000FFFF00FFFFFFFFFF0000FF0000FF00FFFFFFFFFFFF00FF
FF00FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF00FFFFFF000000FFFF00000000FFFFFF00000000FF00FFFFFF000000000000FF
00FFFFFFFF000000000000FF00FF000000FFFFFFFF00FFFFFFFF00FF00FF00FF00FFFFFF
FF000000FF00FFFFFF00FFFF0000FF0000000000FF00FFFFFF00FF000000000000FF0000
FF000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00000000FFFF0000FF00FFFF000000FF00FFFF00FF00000000FFFF00FFFF00FF
0000000000FFFF00FFFF00FF0000FFFF00000000FF00000000FF00FF00FF00FF00000000
00FFFF00FF000000FF0000FF00FFFFFF00FFFF00FF00000000FFFFFF00FFFF00FFFFFF00
00FFFF00FF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00FF00FFFF0000FF000000FFFF
FF00FFFF0000FF000000FFFFFF0000FF00FFFF00FF00FFFF00FF00FF0000FFFFFF00FFFF
000000FFFFFF00FFFFFF00FF000000FF0000FF00FF00FFFF000000FF000000FFFFFFFFFF
000000FFFFFF00FFFF00FFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF00000000FF0000FFFF000000FFFFFF00FF0000FFFFFFFF0000FFFF000000
FF0000FF00FFFFFF00FFFFFFFFFF00FF0000FF00FF0000FF0000FFFFFF000000FF000000
FFFF000000FF00000000FFFFFF00FFFFFF00FF00FF000000FFFF0000FFFF000000000000
FFFF000000FF0000FF0000FF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FFFFFF00000000FF00FFFFFFFF00FF
FFFF00FF000000FF000000000000FFFFFF00FF00FF00FFFFFF00000000FFFF0000FFFF00
0000FFFF00FF00FFFF000000FF000000FF0000FFFFFF00FFFFFFFF000000FFFF00FFFF00
0000FFFF00FF00FFFFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF00000000FFFF0000FF00FFFF000000FF00FFFF00FF00000000FF0000
00FF0000FFFF0000FFFF00FFFF000000FF00FF00FF00000000FFFF00FFFFFFFF000000FF
FF0000FF0000FFFFFFFF00FFFFFF00FFFFFF000000FF0000000000FFFF0000FF000000FF
FF0000FF00FF000000FF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00FF00FFFF0000FFFF
00FF00FFFFFFFF0000FF000000FFFF00FF00FF00FF00FFFF0000FF0000000000FFFF0000
FF00FFFFFF00000000FF00000000FFFFFFFFFF00FFFFFF00FFFF0000FF00FFFFFF00FFFF
FFFF00FF0000FFFF00FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FFFFFF00FF0000FFFFFFFF0000FF
0000FFFFFFFFFFFF0000FFFF0000FF00FF00FF0000FFFFFFFF00FF00FFFF00FFFFFFFF00
FF000000FF00FFFF00FF00FFFF0000000000FF00000000FFFFFFFF00FF000000FF000000
0000FFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FFFFFF00000000FF00FFFF
FF000000000000FF00FFFFFFFF00FF0000FFFFFF00000000FF00FF0000FF00000000FF00
00FFFF00FF0000FF0000FFFFFFFF00FFFF00FF00FFFF00000000FF0000FFFF00FF00FFFF
00FFFFFFFFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFF000000FF00FFFF00FF000000
00FFFF00FFFF00FF0000000000FFFFFF000000FF00FFFF0000FFFFFF0000FFFF00FFFFFF
0000FF00FF00FFFFFF00000000FF0000FF00FF000000FFFF00FFFFFF0000FF00FF0000FF
0000000000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00FF00FFFF
0000FF000000FFFFFF00FFFF00000000FFFF00FF0000FF00FFFFFFFFFF000000FFFFFFFF
FF00FF00FF00000000FFFF00FFFFFF00FF0000FFFF000000FFFFFFFFFF0000FFFFFF00FF
00FFFF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FFFFFF00FF0000FFFFFF
FF0000FFFF000000FF0000FF00FFFF000000FFFFFF00FF000000000000FFFF0000000000
FF00FF00FF00FFFF0000FF000000FF00FF00FFFFFFFF00FFFFFFFFFFFFFF000000FF00FF
0000FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FFFFFF00000000
FF00FFFFFFFF00FFFFFF00FF000000FFFF00000000FFFFFF00FFFF00FFFFFFFF00FFFF00
FF00FF0000FFFFFFFF0000FFFF00FF00FF00000000FF0000000000000000FFFF00FF00FF
00FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFF000000FF00FFFF00
FF00000000FF000000FF0000FFFF0000FF00FFFF000000FF0000FF00000000FF0000FF00
FF00FF00FFFFFFFFFFFF0000FF00FF0000FFFF00FFFFFF00FFFF00FFFF0000FF00FF00FF
000000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00
FF00FFFF0000FFFF00FF00FFFFFFFF0000FFFFFFFF00FFFFFF0000FFFF00FFFFFF00FF00
FF0000FFFFFFFFFFFFFFFF0000FFFFFF0000FF000000FF000000FFFFFFFF00FF00FF0000
FFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FFFFFF00FF00
00FFFFFFFF0000FF0000FFFFFFFFFFFF0000000000FFFFFFFFFF0000FF000000FF0000FF
FFFF0000000000000000FF00FFFFFFFFFF0000FFFF0000FFFF00000000FF00FF00FF00FF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FFFFFF
00000000FF00FFFFFF000000000000FF00FFFF00FFFFFFFFFFFFFF0000FFFF00FF00FFFF
FFFFFF00FFFF00FFFF00FF0000000000FF00FFFFFFFF0000FF00FFFF00FF00FF0000FFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFF000000FF
00FFFF00FF00000000FFFF00FFFF00FF000000FFFFFFFFFFFFFFFFFF0000FF00FF000000
0000FF0000FF000000FFFFFF00FFFF0000FFFFFFFFFFFF00FF0000FF0000FFFFFF000000
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF
0000FF00FF00FFFF0000FF000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF00FF00FF00FFFF
00FFFFFF0000FFFF00000000FFFFFFFF000000000000FF00FF00FFFFFF00000000FFFF00
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FFFF
FF00FF0000FFFFFFFF0000FFFF000000FF0000000000000000000000FF00FF00FF000000
FFFFFFFFFF0000FF00FFFF0000000000FFFF00FFFF00FF00FF000000FF00FFFF0000FF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF000000
00FFFFFF00000000FF00FFFFFFFF00FFFFFF00FFFF00FFFF00FFFF00FF0000FFFFFF00FF
FFFFFFFFFFFF0000FFFFFFFF00FFFF0000FF0000FF00FF0000FFFF00FF0000FF00FFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFF
000000FF00FFFF00FF00000000FF000000FF0000FF0000FF000000FFFFFF00000000FFFF
FFFFFFFFFFFFFF00000000FF0000FF00FFFFFF0000FFFFFF000000FFFFFF00FF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000
FFFF00FF0000FF00FF00FFFF0000FFFF00FF00FFFFFF0000FFFF000000FF00FFFF000000
00000000000000FFFF00FFFFFF0000FFFFFFFFFF00000000FFFF000000FF0000FFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF00
0000FFFFFF00FF0000FFFFFFFF0000FF0000FFFFFFFFFF000000FFFF00FF0000FF00FFFF
00FFFF00FFFF000000FFFFFFFFFF000000000000FFFF00FFFFFFFF00FFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FF
FF00000000FFFFFF00000000FF00FFFFFF000000000000FFFF000000FFFFFF00FF0000FF
0000FF000000FFFF000000000000FFFF00FFFF0000FF0000000000FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000
FF00FFFF000000FF00FFFF00FF00000000FFFF00FFFF000000FFFF000000FF00FF00FFFF
FF0000FFFF000000FFFF00FFFF0000FF0000FF00FFFFFF00FFFF000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00
FF000000FFFF00FF0000FF00FF00FFFF0000FF000000FFFF000000FFFF00FF0000FFFFFF
FFFF000000FFFF0000FF0000FF00FFFFFF00FF00000000FFFFFFFF00FFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF00
00FFFF000000FFFFFF00FF0000FFFFFFFF0000FFFF000000FFFF000000FFFFFF00000000
0000FFFF0000FF00FFFFFF00FF000000FF00FF00FFFF00000000FF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF
000000FFFF00000000FFFFFF00000000FF00FFFFFFFF00FFFFFFFF00FFFFFFFFFF00FFFF
00FFFFFFFF00FF000000FF0000FFFF00FF00FF000000FFFF00FFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000
FFFF0000FF00FFFF000000FF00FFFF00FF00000000FF00000000FF0000000000FF0000FF
0000000000FFFFFF00FFFFFF0000FF00FF0000FFFF0000FF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FF
FFFFFF00FF000000FFFF00FF0000FF00FF00FFFF0000FFFF00FFFFFF00FFFF00FF00FFFF
FF00FFFF00000000FFFFFFFFFF00FF00FF00FFFFFFFF0000FFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000
0000FF0000FFFF000000FFFFFF00FF0000FFFFFFFF0000FF000000FF0000FF00FF000000
FF0000FF00FFFF0000000000FF00FF0000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
00FFFFFF000000FFFF00000000FFFFFF00000000FF00FFFFFF00FFFFFF0000FFFFFF00FF
FFFF0000FFFFFFFF00FFFF00FF00FF00FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
00000000FFFF0000FF00FFFF000000FF00FFFF00FF00000000FFFFFFFFFF00000000FFFF
FFFFFF00000000FF0000FF00FF00FF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00FF00FFFF0000000000FF00FFFF000000
000000FFFF00FFFFFF00FF0000FFFFFF00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FF00000000FF0000FFFF000000FFFFFF00FF0000FFFFFFFF00FFFF00FF000000FFFF00
FFFF0000FF00000000FFFFFF000000FF0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFF00FFFFFF000000FFFF00000000FFFFFF00000000FF0000FF0000FFFF000000FF
FFFFFF00FF00FFFF00000000FFFF00FF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FF00000000FFFF0000FF00FFFF000000FF00FFFF00FF00FFFFFF000000FFFF0000
0000FF00FF0000FF00FFFF0000FF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF0000FF00FF00000000FFFF0000FF00FF
FF0000FFFFFF0000FFFFFFFF00FF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF00000000FF0000FFFF000000FFFFFF00FF0000FFFF00FFFFFFFF00FF0000
FF00FFFFFFFFFF0000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FFFFFF0000FF0000000000FFFFFF00
FF0000000000FF00FFFF00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF00000000FFFF0000FF00FFFF000000FF00FFFFFF00FFFF00000000FF
FFFF00FFFF00FF0000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00FF000000FF0000FF00FFFF0000
00FF0000FF00FF00FFFFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FFFFFF00FFFFFF0000FFFFFFFF00
FFFFFF00FF00FF000000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FFFFFFFFFF00000000FF00
0000FF0000FFFFFF00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFF000000000000FFFF00FFFFFF
00FFFFFF000000FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFF00FFFF0000FF000000FF
00000000FFFF0000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FFFFFFFF0000FFFF0000
FFFF00FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF00000000FF00FFFFFFFF00
0000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFF00FF0000000000FF
FF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF000000FFFFFF00FFFF0000
00FFFF00FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF000000FF000000FFFF
0000FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFF0000FFFF0000FF
00FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF0000FF00FFFFFFFF00FF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FF00000000FF0000
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF0000FFFF00FFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF000000FFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFF00FFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J1000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
ogooJGoo0008Ool200000goo000000020003Ool20002Ool500000goo00000004Ool30002Ool:0002
Ool00`00Oomoo`0200000goo00000002Ool00`00Oomoo`020002Ool80002Ool00`00Oomoo`020002
Ool00`00Oomoo`0200000goo0000000:0002Ool200000goo00000003Ool20004Ool30007Ool50003
Ool400000goo00000002Ool20003Ool80002Ool50002Ool20006Ool40005Ool200000goo00000002
Ool00`00Oomoo`050004Ool00`00Oomoo`020005Ool20005OolB0004Ool70005Ool<000:Ool20000
0goo00000005Ool30004Ool30009Ool50002Ool00`00Oomoo`02Ool30007Ool50007Ool7000=Ool0
00Qoo`800003Ool00000008000=oo`80009oo`D00003Ool0000000Aoo`<0009oo`X0009oo`03001o
ogoo00800003Ool00000009oo`03001oogoo0080009oo`P0009oo`03001oogoo0080009oo`03001o
ogoo00800003Ool0000000X0009oo`800003Ool0000000=oo`8000Aoo`<000Moo`D000=oo`@00003
Ool00000009oo`8000=oo`P0009oo`D0009oo`8000Ioo`@000Eoo`800003Ool00000009oo`03001o
ogoo00D000Aoo`03001oogoo008000Eoo`8000Eooa8000Aoo`L000Eoo``000Yoo`800003Ool00000
00Eoo`<000Aoo`<000Uoo`D0009oo`03001oogoo009oo`<000Moo`D000Moo`L000eoo`003Goo1000
00=oo`0000000P000goo0`001goo10000goo0P000goo0P000Woo00<007ooOol00P0000=oo`000000
0Woo0`001Goo0P000goo0P000Woo00<007ooOol00P000Woo00<007ooOol00P0000=oo`0000000goo
0P0017oo00<007ooOol00P0000=oo`0000000P0000=oo`0000000P000Woo00<007ooOol02Goo00<0
07ooOol01Goo0P0000=oo`0000000P001goo00<007ooOol00Woo0`0017oo0`002Woo1@000Woo0P00
00=oo`0000000Woo0`0017oo0`000Woo00<007ooOol01`0027oo0P000goo0P0017oo00<007ooOol0
0Woo0`000Woo0P000goo1@000Woo00<007ooOol00Woo0P000goo2P000Woo0P0000=oo`0000000`00
0Woo0P001goo2P000goo10001Woo2@000goo1`000Woo00<007ooOol00Woo1@002Woo0008Ool30002
Ool20005Ool30002Ool2000:Ool30002Ool30002Ool20002Ool00`00Oomoo`030005Ool600000goo
0000000200000goo00000002Ool00`00Oomoo`020002Ool00`00Oomoo`0200000goo000000020000
0goo000000020002Ool00`00Oomoo`0200000goo00000005Ool20002Ool:0002Ool80005Ool70002
Ool30002Ool00`00Oomoo`05Ool<0004Ool00`00Oomoo`0200000goo00000002Ool00`00Oomoo`05
Ool20002Ool00`00Oomoo`020003Ool900000goo0000000200000goo000000040006Ool20002Ool5
0003Ool20002Ool30002Ool50003Ool20003Ool20002Ool30004Ool00`00Oomoo`090003Ool20003
Ool30002Ool2000:Ool20003Ool400000goo00000003Ool40007Ool00`00Oomoo`0:Ool000Qoo`<0
009oo`8000Eoo`<0009oo`8000Yoo`<0009oo`<0009oo`80009oo`03001oogoo00<000Eoo`H00003
Ool0000000800003Ool00000009oo`03001oogoo0080009oo`03001oogoo00800003Ool000000080
0003Ool000000080009oo`03001oogoo00800003Ool0000000Eoo`80009oo`X0009oo`P000Eoo`L0
009oo`<0009oo`03001oogoo00Eoo``000Aoo`03001oogoo00800003Ool00000009oo`03001oogoo
00Eoo`80009oo`03001oogoo008000=oo`T00003Ool0000000800003Ool0000000@000Ioo`80009o
o`D000=oo`80009oo`<0009oo`D000=oo`8000=oo`80009oo`<000Aoo`03001oogoo00T000=oo`80
00=oo`<0009oo`8000Yoo`8000=oo`@00003Ool0000000=oo`@000Moo`03001oogoo00Yoo`002Woo
0`002Goo00<007ooOol02P000Woo0P001Goo00<007ooOol00P000Woo00<007ooOol00P0027oo0P00
1Goo0P0000=oo`0000000Woo00<007ooOol00P000Woo00<007ooOol00P0000=oo`0000001Goo0P00
0Woo00<007ooOol00P0000=oo`0000001@001Goo0P000goo0P001Goo0P000goo1`0017oo00<007oo
Ool00goo0P000Woo1`0000=oo`0000000goo0P000goo10000Woo00<007ooOol00P0000=oo`000000
0Woo1`0000=oo`0000000Woo00<007ooOol00`000Woo0P000goo0P001Goo0`0017oo1`0000=oo`00
00000P000goo1@001Goo10000goo100000=oo`0000000`001Woo1@001Goo00<007ooOol00Woo1@00
1goo00<007ooOol030001goo0`001goo1`000Woo0`002Woo000:Ool30009Ool00`00Oomoo`0:0002
Ool20005Ool00`00Oomoo`020002Ool00`00Oomoo`020008Ool20005Ool200000goo00000002Ool0
0`00Oomoo`020002Ool00`00Oomoo`0200000goo00000005Ool20002Ool00`00Oomoo`0200000goo
000000050005Ool20003Ool20005Ool20003Ool70004Ool00`00Oomoo`03Ool20002Ool700000goo
00000003Ool20003Ool40002Ool00`00Oomoo`0200000goo00000002Ool700000goo00000002Ool0
0`00Oomoo`030002Ool20003Ool20005Ool30004Ool700000goo000000020003Ool50005Ool40003
Ool400000goo000000030006Ool50005Ool00`00Oomoo`02Ool50007Ool00`00Oomoo`0<0007Ool3
0007Ool70002Ool3000:Ool000]oo`T0009oo`<000=oo`8000Aoo`03001oogoo00D0009oo`03001o
ogoo0080009oo`03001oogoo00P0009oo`D0009oo`800003Ool00000009oo`03001oogoo0080009o
o`03001oogoo00800003Ool0000000<0009oo`80009oo`03001oogoo00800003Ool0000000=oo`H0
0003Ool0000000800003Ool0000000@00003Ool0000000800003Ool0000000=oo`@0009oo`D00003
Ool00000009oo`03001oogoo009oo`800003Ool0000000<000Moo`80009oo`03001oogoo00800003
Ool00000009oo`03001oogoo009oo`800003Ool00000008000Eoo`03001oogoo00D000Uoo`D000=o
o`8000Eoo`D000Aoo`D00003Ool0000000Moo`<000Aoo`L000=oo`D0009oo`D000=oo`L0009oo`<0
00Aoo`03001oogoo009oo`03001oogoo00Uoo`P000=oo`8000Eoo`8000Yoo`002goo2@000Woo0`00
0goo0P0017oo00<007ooOol01@000Woo00<007ooOol00P000Woo00<007ooOol020000Woo1@000Woo
0P0000=oo`0000000Woo00<007ooOol00P000Woo00<007ooOol00P0000=oo`0000000`000Woo0P00
0Woo00<007ooOol00P0000=oo`0000000goo1P0000=oo`0000000P0000=oo`000000100000=oo`00
00000P0000=oo`0000000goo10000Woo1@0000=oo`0000000Woo00<007ooOol00Woo0P0000=oo`00
00000`001goo0P000Woo00<007ooOol00P0000=oo`0000000Woo00<007ooOol00Woo0P0000=oo`00
00000P001Goo00<007ooOol01@002Goo1@000goo0P001Goo1@0017oo1@0000=oo`0000001goo0`00
17oo1`000goo1@000Woo1@000goo1`000Woo0`0017oo00<007ooOol00Woo00<007ooOol02Goo2000
0goo0P001Goo0P002Woo0008Ool200000goo00000004Ool00`00Oomoo`03Ool400000goo00000002
0002Ool30003Ool20002Ool00`00Oomoo`040005Ool00`00Oomoo`02Ool30004Ool00`00Oomoo`02
00000goo00000002Ool00`00Oomoo`020002Ool00`00Oomoo`030004Ool00`00Oomoo`020002Ool0
0`00Oomoo`0200000goo000000030004Ool200000goo00000005Ool20005Ool30007Ool40003Ool2
00000goo00000002Ool30002Ool30004Ool60002Ool20002Ool00`00Oomoo`0200000goo00000002
Ool50005Ool50002Ool30004Ool:0003Ool400000goo000000050004Ool50003Ool3000;Ool30002
Ool00`00Oomoo`02Ool50003Ool40003Ool50004Ool00`00Oomoo`03Ool40002Ool5000=Ool20003
Ool5000COol000Qoo`800003Ool0000000@000Qoo`800003Ool0000000Eoo`@00003Ool000000080
00Eoo`L000Ioo`@0009oo`03001oogoo00800003Ool00000009oo`03001oogoo00@000Eoo`<0009o
o`03001oogoo0080009oo`03001oogoo00<000Aoo`<0009oo`800003Ool0000000<0009oo`D0009o
o`8000Yoo`<0009oo`800003Ool00000009oo`03001oogoo00Aoo`<0009oo`03001oogoo009oo`03
001oogoo0080009oo`03001oogoo00800003Ool00000008000=oo`L000=oo`80009oo`03001oogoo
00Eoo`8000=oo`8000Moo`800003Ool0000000=oo`H000=oo`<0009oo`8000eoo`@000Moo`03001o
ogoo00Eoo`D000Aoo`D000Qoo`@000=oo`h00003Ool0000000<000Aoo`X000Yoo`0027oo0P0000=o
o`000000100027oo0P0000=oo`0000001Goo100000=oo`0000000P001Goo1`001Woo10000Woo00<0
07ooOol00P0000=oo`0000000Woo00<007ooOol010001Goo0`000Woo00<007ooOol00P000Woo00<0
07ooOol00`0017oo0`000Woo0P0000=oo`0000000`000Woo1@000Woo0P002Woo0`000Woo0P0000=o
o`0000000Woo00<007ooOol017oo0`000Woo00<007ooOol00Woo00<007ooOol00P000Woo00<007oo
Ool00P0000=oo`0000000P000goo1`000goo0P000Woo00<007ooOol01Goo0P000goo0P001goo0P00
00=oo`0000000goo1P000goo0`000Woo0P003Goo10001goo00<007ooOol01Goo1@0017oo1@0027oo
10000goo3P0000=oo`0000000`0017oo2P002Woo0008Ool30004Ool80002Ool200000goo00000004
00000goo00000005Ool70003Ool2000:Ool20002Ool00`00Oomoo`0200000goo00000002Ool00`00
Oomoo`020008Ool20002Ool00`00Oomoo`020002Ool00`00Oomoo`020006Ool20002Ool30004Ool3
0004Ool3000>Ool00`00Oomoo`0200000goo000000020008Ool20002Ool30002Ool00`00Oomoo`02
0002Ool30005Ool30002Ool20003Ool400000goo00000002Ool700000goo0000000200000goo0000
00050002Ool30007Ool20007Ool3000AOol9000:Ool00`00Oomoo`05Ool2000<Ool30002Ool20003
Ool20003Ool20005Ool20006Ool20004Ool00`00Oomoo`0:Ool000Qoo`<000Aoo`P0009oo`800003
Ool0000000@00003Ool0000000Eoo`L000=oo`8000Yoo`80009oo`03001oogoo00800003Ool00000
009oo`03001oogoo008000Qoo`80009oo`03001oogoo0080009oo`03001oogoo008000Ioo`80009o
o`<000Aoo`<000Aoo`<000ioo`03001oogoo00800003Ool00000008000Qoo`80009oo`<0009oo`03
001oogoo0080009oo`<000Eoo`<0009oo`8000=oo`@00003Ool00000009oo`L00003Ool000000080
0003Ool0000000D0009oo`<000Moo`8000Moo`<0015oo`T000Yoo`03001oogoo00Eoo`8000aoo`<0
009oo`8000=oo`8000=oo`8000Eoo`8000Ioo`8000Aoo`03001oogoo00Yoo`0027oo0P001goo00<0
07ooOol00Woo00<007ooOol00`0017oo0P0000=oo`0000000`000Woo0P000goo100000=oo`000000
20000Woo0P000Woo00<007ooOol00P0000=oo`0000000Woo00<007ooOol02@0000=oo`0000000Woo
00<007ooOol00P000Woo00<007ooOol020001Woo0`000Woo00<007ooOol01Goo3P000Woo0`001Goo
2P001Goo0P000Woo00<007ooOol00P000Woo00<007ooOol01goo0`001goo0P0000=oo`0000000P00
0goo0P001Goo0`0017oo00<007ooOol017oo1P000Woo1`000Woo00<007ooOol04goo00<007ooOol0
0Woo2P000Woo200047oo00<007ooOol00`000Woo0`000Woo1@000Woo1`0000=oo`0000000P000Woo
0`002Woo0008Ool70002Ool50005Ool30002Ool30004Ool30007Ool30004Ool00`00Oomoo`02Ool0
0`00Oomoo`020002Ool00`00Oomoo`0200000goo000000020005Ool20003Ool200000goo00000002
Ool00`00Oomoo`020002Ool00`00Oomoo`020003Ool20008Ool20002Ool700000goo00000003Ool2
0003Ool20005Ool70003Ool20004Ool500000goo00000002Ool00`00Oomoo`04000;Ool90005Ool5
0009Ool30002Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`020003Ool20002OolF0007Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool20004Ool?0002Ool00`00Oomoo`020005Ool30004Ool30003Ool2
0005Ool4000=Ool000Qoo`L0009oo`D000Eoo`<0009oo`<000Aoo`<000Moo`<000Aoo`03001oogoo
009oo`03001oogoo0080009oo`03001oogoo00800003Ool00000008000Eoo`8000=oo`800003Ool0
0000009oo`03001oogoo0080009oo`03001oogoo008000=oo`8000Qoo`80009oo`L00003Ool00000
00=oo`8000=oo`8000Eoo`L000=oo`8000Aoo`D00003Ool00000009oo`03001oogoo00@000]oo`T0
00Eoo`D000Uoo`<0009oo`D0009oo`03001oogoo009oo`03001oogoo008000=oo`80009ooaH000Mo
o`03001oogoo009oo`03001oogoo00=oo`8000Aoo`l0009oo`03001oogoo008000Eoo`<000Aoo`<0
00=oo`8000Eoo`@000eoo`0027oo0P000goo10000goo1@000Woo00<007ooOol017oo0`000Woo00<0
07ooOol02Goo0`000Woo0`000Woo00<007ooOol00P000Woo0`001Goo1@000Woo0`000Woo0P0000=o
o`0000000Woo00<007ooOol00P000Woo00<007ooOol00`000Woo2@0000=oo`0000000Woo00<007oo
Ool00Woo0P0000=oo`0000000P0000=oo`0000000P0000=oo`000000100000=oo`0000000goo1000
00=oo`00000010000goo0P0000=oo`0000000P001Goo300000=oo`00000017oo00<007ooOol01goo
00<007ooOol02Woo10000goo0P000Woo0`000Woo00<007ooOol0100000=oo`0000000Woo00<007oo
Ool00Woo00<007ooOol00Woo0P000goo0P000goo1`000Woo0`000Woo1@0000=oo`00000010000goo
0P000goo0P000goo0P000Woo00<007ooOol01@000Woo00<007ooOol01Goo1@002Goo0`0037oo0008
Ool20003Ool40003Ool50002Ool00`00Oomoo`04Ool30002Ool00`00Oomoo`09Ool30002Ool30002
Ool00`00Oomoo`020002Ool30005Ool50002Ool30002Ool200000goo00000002Ool00`00Oomoo`02
0002Ool00`00Oomoo`030002Ool900000goo00000002Ool00`00Oomoo`02Ool200000goo00000002
00000goo0000000200000goo0000000400000goo00000003Ool400000goo000000040003Ool20000
0goo000000020005Ool<00000goo00000004Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool40003Ool2
0002Ool30002Ool00`00Oomoo`0400000goo00000002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool2
0003Ool20003Ool70002Ool30002Ool500000goo000000040003Ool20003Ool20003Ool20002Ool0
0`00Oomoo`050002Ool00`00Oomoo`05Ool50009Ool3000<Ool000moo`D000=oo`@000Qoo`80009o
o`X0009oo`03001oogoo00=oo`80009oo`03001oogoo0080009oo`03001oogoo00Moo`03001oogoo
00Aoo`03001oogoo00800003Ool00000009oo`03001oogoo0080009oo`03001oogoo008000Eoo`03
001oogoo009oo`800003Ool00000009oo`<0009oo`800003Ool0000000Eoo`<000Aoo`<000Moo`<0
00Aoo`D000Eoo`D0009oo`8000=oo`8000=oo`800003Ool000000080009oo`X000moo`D000Eoo`@0
00Eoo`800003Ool00000009oo`<0009oo`<0009oo`<0009oo`D000=oo`8000Eoo`@000=oo`<000Ao
o`<0009oo`<0009oo`<0009oo`80009oo`<000=oo`80009oo`P000Aoo`P0009oo`8000eoo`004Goo
00<007ooOol01Goo2@0000=oo`0000000P000goo0P000goo0P000Woo1@0000=oo`0000000Woo00<0
07ooOol00P000Woo20000Woo1@000Woo00<007ooOol00P0000=oo`0000000Woo00<007ooOol00P00
0Woo00<007ooOol01@000Woo0`000Woo0`001Goo0P000Woo0`002Goo0`000Woo0P002Woo1@000goo
1`000goo0P000Woo0`000Woo0`000Woo0P0000=oo`0000001Goo0P000goo0P004goo00<007ooOol0
1goo1@000Woo0`001Goo0P000Woo00<007ooOol017oo0`000goo1@002Goo0`000Woo0P001goo00<0
07ooOol00P001Goo0`001Goo100000=oo`0000000Woo00<007ooOol00Woo0P001Woo0P000goo0P00
0Woo1@002Woo000AOol00`00Oomoo`05Ool900000goo000000020003Ool20003Ool20002Ool50000
0goo00000002Ool00`00Oomoo`020002Ool80002Ool50002Ool00`00Oomoo`0200000goo00000002
Ool00`00Oomoo`020002Ool00`00Oomoo`050002Ool30002Ool30005Ool20002Ool30009Ool30002
Ool2000:Ool50003Ool70003Ool20002Ool30002Ool30002Ool200000goo00000005Ool20003Ool2
000COol00`00Oomoo`07Ool50002Ool30005Ool20002Ool00`00Oomoo`04Ool30003Ool50009Ool3
0002Ool20007Ool00`00Oomoo`020005Ool30005Ool400000goo00000002Ool00`00Oomoo`02Ool2
0006Ool20003Ool20002Ool5000:Ool000Qoo`L0009oo`H0009oo`8000=oo`8000Eoo`<0009oo`<0
009oo`@000=oo`800003Ool00000009oo`<000Eoo`8000=oo`@000=oo`80009oo`03001oogoo0080
0003Ool00000009oo`03001oogoo0080009oo`<000=oo`80009oo`03001oogoo00Aoo`D00003Ool0
0000009oo`8000]oo`80009oo``000=oo`@00003Ool0000000=oo`@00003Ool00000009oo`8000Eo
o`03001oogoo00800003Ool0000000@00003Ool0000000800003Ool0000001<000aoo`03001oogoo
00Aoo`D00003Ool00000009oo`D0009oo`03001oogoo00Eoo`8000aoo`03001oogoo00L0009oo`03
001oogoo00D0009oo`03001oogoo00Moo`800003Ool00000009oo`<0009oo`L00003Ool000000080
0003Ool00000009oo`8000eoo`0027oo1`000Woo1P000Woo0P000goo0P001Goo0`000Woo0`000Woo
10000goo0P0000=oo`0000000Woo0`001Goo0P000goo10000goo0P000Woo00<007ooOol00P0000=o
o`0000000Woo00<007ooOol00P000Woo0`000goo0P000Woo00<007ooOol017oo1@0000=oo`000000
0Woo0P002goo0P000Woo30000goo100000=oo`0000000goo100000=oo`0000000Woo0P001Goo00<0
07ooOol00P0000=oo`000000100000=oo`0000000P0000=oo`0000004`0037oo00<007ooOol017oo
1@0000=oo`0000000Woo1@000Woo00<007ooOol01Goo0P0037oo00<007ooOol01`000Woo00<007oo
Ool01@000Woo00<007ooOol01goo0P0000=oo`0000000Woo0`000Woo1`0000=oo`0000000P0000=o
o`0000000Woo0P003Goo0008Ool20003Ool20002Ool00`00Oomoo`02Ool00`00Oomoo`050009Ool0
0`00Oomoo`020005Ool30002Ool30005Ool70007Ool30002Ool20002Ool00`00Oomoo`0200000goo
00000002Ool30005Ool400000goo00000002Ool70003Ool200000goo00000002Ool<00000goo0000
00020003Ool20003Ool20007Ool30007Ool200000goo00000002Ool50002Ool30005Ool20005Ool3
0004Ool00`00Oomoo`02Ool20003Ool20003Ool<0002Ool70003Ool200000goo000000020003Ool2
0002Ool60002Ool<0002Ool00`00Oomoo`020003Ool20002Ool30003Ool20002Ool80002Ool30005
Ool40003Ool20005Ool200000goo00000002Ool5000:Ool000Qoo`8000=oo`80009oo`03001oogoo
009oo`03001oogoo00D000Uoo`03001oogoo008000Eoo`<0009oo`<000Eoo`L000Moo`<0009oo`80
009oo`03001oogoo00800003Ool00000009oo`<000Eoo`@00003Ool00000009oo`L000=oo`800003
Ool00000009oo``00003Ool00000008000=oo`8000=oo`8000Moo`<000Moo`800003Ool00000009o
o`D0009oo`<000Eoo`8000Eoo`<000Aoo`03001oogoo009oo`8000=oo`8000=oo``0009oo`L000=o
o`800003Ool00000008000=oo`80009oo`H0009oo``0009oo`03001oogoo008000=oo`80009oo`<0
00=oo`80009oo`P0009oo`<000Eoo`@000=oo`8000Eoo`800003Ool00000009oo`D000Yoo`0027oo
0`000Woo0P000Woo0`000Woo0`000goo2@000Woo00<007ooOol01@000Woo0P001Goo1P0017oo0P00
2Woo00<007ooOol00P000Woo00<007ooOol00P0000=oo`0000000Woo00<007ooOol01goo0P0000=o
o`0000000Woo00<007ooOol00Woo0`000Woo0P0000=oo`0000000P000goo0P000goo0P001Goo1000
00=oo`0000000`002goo1P000Woo0`001Woo00<007ooOol00goo1`002Goo0`000Woo0`000Woo0`00
0Woo0`000Woo0P000goo0P000goo0P000Woo00<007ooOol00Woo1@001Goo0`000Woo0P000Woo00<0
07ooOol00Woo00<007ooOol00P000goo0P000goo0P000Woo00<007ooOol01@001Goo1@001Goo0P00
17oo00<007ooOol00P0027oo100000=oo`0000000`000Woo0P0000=oo`0000000P000goo0P002Woo
000:Ool30005Ool20002Ool00`00Oomoo`05Ool20003Ool20002Ool30003Ool20002Ool50002Ool0
0`00Oomoo`02Ool30002Ool:0002Ool00`00Oomoo`020002Ool00`00Oomoo`0200000goo00000002
Ool80002Ool200000goo000000020007Ool30005Ool400000goo000000030009Ool30004Ool<0003
Ool20005Ool50002Ool500000goo00000003Ool90002Ool00`00Oomoo`03Ool20002Ool20005Ool0
0`00Oomoo`030002Ool400000goo000000020007Ool00`00Oomoo`07Ool00`00Oomoo`020002Ool3
0002Ool00`00Oomoo`030002Ool400000goo00000002Ool30003Ool70004Ool500000goo00000002
0002Ool3000<Ool30004Ool30005Ool400000goo0000000:Ool000Yoo`<000Eoo`80009oo`03001o
ogoo00Eoo`8000=oo`80009oo`<000=oo`80009oo`D0009oo`03001oogoo009oo`<0009oo`X0009o
o`03001oogoo0080009oo`03001oogoo00800003Ool00000009oo`P0009oo`800003Ool000000080
00Moo`<000Eoo`@00003Ool0000000<000Uoo`<000Aoo``000=oo`8000Eoo`D0009oo`D00003Ool0
000000=oo`T0009oo`03001oogoo00=oo`80009oo`8000Eoo`03001oogoo00<0009oo`@00003Ool0
0000008000Moo`03001oogoo00Moo`03001oogoo0080009oo`<0009oo`03001oogoo00<0009oo`@0
0003Ool00000009oo`<000=oo`L000Aoo`D00003Ool000000080009oo`<000aoo`<000Aoo`<000Eo
o`@00003Ool0000000Yoo`002goo1P0000=oo`0000000Woo1P000Woo1@001Goo100000=oo`000000
0P000goo10001Woo10000goo0P000goo0P000Woo00<007ooOol00P000Woo00<007ooOol00`001Goo
0P0017oo00<007ooOol00P0000=oo`0000002Woo1@000Woo0P001Goo0P0037oo0`000Woo00<007oo
Ool00Woo00<007ooOol00Woo0`000Woo1`000goo10000goo0`001goo0P000goo0P000Woo1@0000=o
o`0000000Woo1`001Goo00<007ooOol00P001Goo1`000Woo20000Woo0`001Goo0P000Woo00<007oo
Ool00P001Goo0`001Goo1@0017oo0P001Woo0P001Goo0P000Woo00<007ooOol03Woo0`000Woo00<0
07ooOol01goo0P0000=oo`0000002Woo000;Ool600000goo00000002Ool60002Ool50005Ool40000
0goo000000020003Ool40006Ool40003Ool20003Ool20002Ool00`00Oomoo`020002Ool00`00Oomo
o`030005Ool20004Ool00`00Oomoo`0200000goo0000000:Ool50002Ool20005Ool2000<Ool30002
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool30002Ool70003Ool40003Ool30007Ool20003Ool20002
Ool500000goo00000002Ool70005Ool00`00Oomoo`020005Ool70002Ool80002Ool30005Ool20002
Ool00`00Oomoo`020005Ool30005Ool50004Ool20006Ool20005Ool20002Ool00`00Oomoo`0>Ool3
0002Ool00`00Oomoo`07Ool200000goo0000000:Ool000Qoo`<000Aoo`800003Ool00000009oo`03
001oogoo009oo`<000Aoo`D00003Ool0000000Eoo`@00003Ool0000000Yoo`@00003Ool000000080
0003Ool00000009oo`03001oogoo00@000Eoo`D00003Ool000000080009oo`03001oogoo00800003
Ool0000000X000Aoo`03001oogoo00L000moo`80009oo`D000Moo`03001oogoo008000=oo`<0009o
o`8000Moo`H0009oo`@00003Ool00000008000=oo`800003Ool00000009oo`8000=oo`D0009oo`03
001oogoo00D0009oo`8000=oo`80009oo`03001oogoo009oo`03001oogoo00=oo`H00003Ool00000
009oo`<000Uoo`H000Aoo`<0009oo`L00003Ool0000000<0009oo`@0019oo`80009oo`P0009oo`<0
00aoo`002Woo0`000Woo0P0000=oo`0000000P001Woo1P000goo0`002Goo0P0000=oo`0000002000
0Woo0P001Goo0P0000=oo`0000000Woo00<007ooOol00P0027oo0P001Goo0P000Woo00<007ooOol0
0P0000=oo`0000000goo0P0017oo0`000Woo00<007ooOol00P000goo400000=oo`0000000P000goo
1`000Woo0`001goo00<007ooOol01`000Woo00<007ooOol00Woo00<007ooOol00P001Goo0`000Woo
0P0000=oo`0000000Woo1@000goo0P000Woo0`0017oo00<007ooOol00`000Woo0P000Woo0`000Woo
1P0017oo0`001Goo2`000goo0P001Woo10000goo0P001Goo0P001Goo4`0000=oo`0000000Woo00<0
07ooOol00Woo00<007ooOol017oo0`002Woo000:Ool30002Ool200000goo000000020006Ool60003
Ool30009Ool200000goo000000080002Ool20005Ool200000goo00000002Ool00`00Oomoo`020008
Ool20005Ool20002Ool00`00Oomoo`0200000goo00000003Ool20004Ool30002Ool00`00Oomoo`02
0003Ool@00000goo000000020003Ool70002Ool30007Ool00`00Oomoo`070002Ool00`00Oomoo`02
Ool00`00Oomoo`020005Ool30002Ool200000goo00000002Ool50003Ool20002Ool30004Ool00`00
Oomoo`030002Ool20002Ool30002Ool60004Ool30005Ool;0003Ool20006Ool40003Ool20005Ool2
0005OolC00000goo00000002Ool00`00Oomoo`02Ool00`00Oomoo`04Ool3000:Ool000]oo`80009o
o`800003Ool0000000Yoo`8000Moo`P0009oo`<000Aoo`03001oogoo009oo`03001oogoo00D0009o
o`800003Ool00000009oo`03001oogoo00T00003Ool0000000<0009oo`80009oo`03001oogoo0080
0003Ool0000000<000Moo`80009oo`<000Moo`8000=oo`8000=oo`8000Eoo`D000=oo`8000Eoo`L0
009oo`03001oogoo008000=oo`80009oo`<0009oo`<000Uoo`03001oogoo00800003Ool000000080
00=oo`D000Eoo`H000Eoo`<000Eoo`@000=oo`8000Moo`H000Aoo`03001oogoo009oo`D000Yoo`@0
0003Ool0000000D000Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`800003Ool0
0000009oo`<0009oo`D0009oo`03001oogoo00Yoo`002goo0P000Woo0P0000=oo`0000002Woo0P00
1goo20000Woo0`0017oo00<007ooOol00Woo00<007ooOol01@000Woo0P0000=oo`0000000Woo00<0
07ooOol02@0000=oo`0000000`000Woo0P000Woo00<007ooOol00P0000=oo`0000000`001goo0P00
0Woo0`001goo0P000goo0P000goo0P001Goo1@000goo0P001Goo1`000Woo00<007ooOol00P000goo
0P000Woo0`000Woo0`002Goo00<007ooOol00P0000=oo`0000000P000goo1@001Goo1P001Goo0`00
1Goo10000goo0P001goo1P0017oo00<007ooOol00Woo1@002Woo100000=oo`0000001@002Goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo0P0000=oo`0000000Woo0`000Woo1@000Woo
00<007ooOol02Woo0008Ool200000goo00000002Ool200000goo000000080002Ool70002Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool30002Ool30002Ool30004Ool00`00Oomoo`0200000goo00000002
0005Ool20003Ool30004Ool00`00Oomoo`020002Ool00`00Oomoo`030004Ool80005Ool70002Ool3
0002Ool30002Ool70003Ool400000goo0000000400000goo00000003Ool20002Ool00`00Oomoo`04
00000goo00000002Ool00`00Oomoo`03Ool90002Ool30005Ool50004Ool60004Ool50002Ool00`00
Oomoo`07Ool30002Ool70002Ool00`00Oomoo`02Ool50007Ool00`00Oomoo`0<Ool200000goo0000
0003Ool90002Ool30002Ool30002Ool30002Ool30005Ool40003Ool4000=Ool000Qoo`800003Ool0
0000009oo`<000Aoo`03001oogoo009oo`03001oogoo008000=oo`80009oo`D000Qoo`80009oo`03
001oogoo00=oo`@0009oo`<000Eoo`L000Moo`<0009oo`03001oogoo0080009oo`03001oogoo0080
00Ioo`8000Aoo`D00003Ool0000000Aoo`03001oogoo008000Eoo`<000Aoo`03001oogoo00Eoo`<0
00Aoo`800003Ool0000000800003Ool00000008000Eoo`800003Ool00000009oo`D00003Ool00000
00Aoo`03001oogoo00=oo`L000Aoo`<0009oo`03001oogoo009oo`D000=oo`@000aoo`03001oogoo
008000=oo`80009oo`D000=oo`L0009oo`d0009oo`<000Moo`8000=oo`80009oo`03001oogoo00=o
o`80009oo`03001oogoo00Aoo`D00003Ool0000000Moo`D000Yoo`0027oo0P0000=oo`0000000Woo
0`0017oo00<007ooOol00Woo00<007ooOol00P000goo0P000Woo1@0027oo0P000Woo00<007ooOol0
0goo10000Woo0`001Goo1`001goo0`000Woo00<007ooOol00P000Woo00<007ooOol00P001Woo0P00
17oo1@0000=oo`00000017oo00<007ooOol00P001Goo0`0017oo00<007ooOol01Goo0`0017oo0P00
00=oo`0000000P0000=oo`0000000P001Goo0P0000=oo`0000000Woo1@0000=oo`00000017oo00<0
07ooOol00goo1`0017oo0`000Woo00<007ooOol00Woo1@000goo100037oo00<007ooOol00P000goo
0P000Woo1@000goo1`000Woo3@000Woo0`001goo0P000goo0P000Woo00<007ooOol00goo0P000Woo
00<007ooOol017oo1@0000=oo`0000001goo1@002Woo0008Ool30006Ool30002Ool30002Ool00`00
Oomoo`0400000goo000000020003Ool900000goo00000002Ool500000goo00000005Ool70003Ool2
000:Ool20002Ool00`00Oomoo`020002Ool00`00Oomoo`0700000goo000000040003Ool200000goo
000000020002Ool30008Ool6000:Ool30002Ool200000goo00000005Ool50002Ool200000goo0000
00020003Ool200000goo000000020002Ool60004Ool00`00Oomoo`05Ool40006Ool20007Ool<0002
Ool00`00Oomoo`030002Ool40003Ool30002Ool20003Ool20002Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool60002Ool30002Ool20002Ool500000goo00000002Ool70003Ool3000;
Ool00`00Oomoo`0:Ool000Qoo`<000Ioo`<0009oo`<0009oo`03001oogoo00@00003Ool000000080
00=oo`T00003Ool00000009oo`D00003Ool0000000Eoo`L000=oo`8000Yoo`80009oo`03001oogoo
0080009oo`03001oogoo00L00003Ool0000000@000=oo`800003Ool000000080009oo`<000Qoo`H0
00Yoo`<0009oo`800003Ool0000000Eoo`D0009oo`800003Ool00000008000=oo`800003Ool00000
0080009oo`H000Aoo`03001oogoo00Eoo`@000Ioo`8000Moo``0009oo`03001oogoo00<0009oo`@0
00=oo`<0009oo`8000=oo`80009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`H0
009oo`<0009oo`80009oo`D00003Ool00000009oo`L000=oo`<000]oo`03001oogoo00Yoo`002Woo
1@000Woo00<007ooOol00goo10001Goo0P0000=oo`0000001goo00<007ooOol00Woo0P0000=oo`00
00000P000goo0P0000=oo`000000100000=oo`0000000goo100000=oo`0000002@0000=oo`000000
0Woo00<007ooOol00P000Woo00<007ooOol00P000goo0`0017oo1@001Goo0P000Woo00<007ooOol0
2Woo0P003Goo0P000Woo0P0000=oo`0000001@000goo10001Goo1@001Goo0P000Woo00<007ooOol0
0Woo1@002Woo1`0000=oo`0000001@000Woo0P000goo0P000goo10001Goo00<007ooOol00P001goo
00<007ooOol00`000Woo0P000Woo0`000Woo0`000Woo1`000goo0P001Goo00<007ooOol010000goo
0P0000=oo`0000000P000goo0P001goo2P000Woo0`002Woo000:Ool50002Ool00`00Oomoo`03Ool4
0005Ool200000goo00000007Ool00`00Oomoo`02Ool200000goo000000020003Ool200000goo0000
000400000goo00000003Ool400000goo0000000900000goo00000002Ool00`00Oomoo`020002Ool0
0`00Oomoo`020003Ool30004Ool50005Ool20002Ool00`00Oomoo`0:Ool2000=Ool20002Ool20000
0goo000000050003Ool40005Ool50005Ool20002Ool00`00Oomoo`02Ool5000:Ool700000goo0000
00050002Ool20003Ool20003Ool40005Ool00`00Oomoo`020007Ool00`00Oomoo`030002Ool20002
Ool30002Ool30002Ool70003Ool20005Ool00`00Oomoo`040003Ool200000goo000000020003Ool2
0007Ool:0002Ool3000:Ool000Qoo`8000=oo`@000Qoo`D0009oo`800003Ool0000000D0009oo`D0
00Eoo`<0009oo`<000Aoo`<000Moo`<000Aoo`8000=oo`800003Ool00000009oo`03001oogoo0080
009oo`<000Moo`D000=oo`D0009oo`80009oo`/0009oo`h00003Ool00000009oo`<000Aoo`03001o
ogoo00Eoo`L000=oo`D0009oo`80009oo`D000=oo`X0009oo`8000=oo`800003Ool0000000Aoo`03
001oogoo00D000Moo`D0009oo`03001oogoo00T000Eoo`03001oogoo0080009oo`03001oogoo00=o
o`80009oo`03001oogoo009oo`<0009oo`L000Eoo`D000Eoo`<0009oo`T000=oo`8000=oo`@000eo
o`003goo2P000goo0P000Woo0P0000=oo`0000000goo10000goo1@000Woo0P001Goo0`000Woo0P00
2Woo0`000Woo0`000Woo0P0000=oo`0000000Woo0`001Goo2@000goo1@0017oo00<007ooOol01000
0goo0P000goo0P001Goo0P000goo0P000goo0`001Woo0`000Woo1P000Woo0P000goo1@0017oo00<0
07ooOol010000goo1@000goo0P0017oo00<007ooOol00`000Woo0P0000=oo`0000000P000Woo0`00
0goo2@000goo10001Goo0P000goo1@000Woo00<007ooOol00P000Woo1@0000=oo`0000000P001goo
00<007ooOol00P000goo1`000goo1@000Woo0P001Goo0P000goo0`000Woo0`000Woo0P003goo000?
Ool:0003Ool20002Ool200000goo00000003Ool40003Ool50002Ool20005Ool30002Ool2000:Ool3
0002Ool30002Ool200000goo00000002Ool30005Ool90003Ool50004Ool00`00Oomoo`040003Ool2
0003Ool20005Ool20003Ool20003Ool30006Ool30002Ool60002Ool20003Ool50004Ool00`00Oomo
o`040003Ool50003Ool20004Ool00`00Oomoo`030002Ool200000goo000000020002Ool30003Ool9
0003Ool40005Ool20003Ool50002Ool00`00Oomoo`020002Ool500000goo000000020007Ool00`00
Oomoo`020003Ool70003Ool50002Ool20005Ool20003Ool30002Ool30002Ool2000?Ool000Qoo`L0
00=oo`8000=oo`@00003Ool00000009oo`<000Moo`D000Aoo`<000Qoo`80009oo`X0009oo`03001o
ogoo00Aoo`03001oogoo00800003Ool00000009oo`03001oogoo00Moo`8000=oo`D000Aoo`D000Eo
o`<0009oo`<0009oo`D0009oo`<0009oo`<0009oo`8000Qoo`80009oo`03001oogoo009oo`03001o
ogoo00D000Aoo`D000Eoo`D000=oo`@00003Ool0000000@000Eoo`03001oogoo00800003Ool00000
00Eoo`@00003Ool0000000Aoo`03001oogoo00Eoo`D0009oo`D000=oo`80009oo`<000Eoo`8000Eo
o`L0009oo`03001oogoo00<0009oo`8000=oo`D000Aoo`03001oogoo00D0009oo`<0009oo`8000Eo
o`03001oogoo00L000Yoo`0027oo1`000goo0P000goo100000=oo`0000000Woo0`001goo1@0017oo
0`0027oo0P000Woo2P000Woo00<007ooOol017oo00<007ooOol00P0000=oo`0000000Woo00<007oo
Ool01goo0P000goo1@0017oo1@001Goo0`000Woo0`000Woo1@000Woo0`000Woo0`000Woo0P0027oo
0P000Woo00<007ooOol00Woo00<007ooOol01@0017oo1@001Goo1@000goo100000=oo`0000001000
1Goo00<007ooOol00P0000=oo`0000001Goo100000=oo`00000017oo00<007ooOol01Goo1@000Woo
1@000goo0P000Woo0`001Goo0P001Goo1`000Woo00<007ooOol00`000Woo0P000goo1@0017oo00<0
07ooOol01@000Woo0`000Woo0P001Goo00<007ooOol01`002Woo0008Ool20003Ool50007Ool20000
0goo00000002Ool2000:Ool00`00Oomoo`05Ool900000goo000000020003Ool20003Ool20002Ool5
0002Ool00`00Oomoo`0200000goo00000002Ool80002Ool50003Ool60003Ool50002Ool20005Ool3
0003Ool20002Ool20005Ool00`00Oomoo`0900000goo00000002Ool50005Ool20006Ool20009Ool0
0`00Oomoo`05Ool30004Ool50002Ool00`00Oomoo`030009Ool200000goo000000020002Ool80003
Ool40003Ool50005Ool600000goo000000030002Ool20003Ool40005Ool00`00Oomoo`050004Ool5
0005Ool00`00Oomoo`04Ool00`00Oomoo`050002Ool00`00Oomoo`020003Ool2000:Ool000Qoo`D0
00Aoo`H0009oo`800003Ool00000009oo`X0009oo`L00003Ool0000000=oo`8000Eoo`@00003Ool0
000000800003Ool00000008000=oo`80009oo`03001oogoo00<000Eoo`8000Aoo`<000=oo`D000Ao
o`D000=oo`@000Qoo`@00003Ool00000009oo`L000Eoo`03001oogoo009oo`800003Ool000000080
00=oo`D0009oo`L00003Ool0000000T000Yoo`D000=oo`@000Eoo`X000Eoo`80009oo`03001oogoo
009oo`03001oogoo00Eoo`D000Aoo`H000Aoo`<000Aoo`<000Moo`D0009oo`<000=oo`H000=oo`D0
009oo`D0009oo`<000=oo`80009oo`03001oogoo00@00003Ool0000000Yoo`0027oo1@0017oo1P00
0Woo0P0000=oo`0000000Woo2P000Woo1`0000=oo`0000000goo0P001Goo100000=oo`0000000P00
00=oo`0000000P000goo0P000Woo00<007ooOol00`001Goo0P0017oo0`000goo1@0017oo1@000goo
100027oo100000=oo`0000000Woo1`001Goo00<007ooOol00Woo0P0000=oo`0000000P000goo1@00
0Woo1`0000=oo`0000002@002Woo1@000goo10001Goo2P001Goo0P000Woo00<007ooOol00Woo00<0
07ooOol01Goo1@0017oo1P0017oo0`0017oo0`001goo1@000Woo0`000goo1P000goo1@000Woo1@00
0Woo0`000goo0P000Woo00<007ooOol0100000=oo`0000002Woo000;Ool40002Ool00`00Oomoo`02
Ool00`00Oomoo`0200000goo000000020003Ool20003Ool20002Ool00`00Oomoo`02Ool200000goo
000000030009Ool200000goo00000005Ool30002Ool40005Ool60007Ool50004Ool50003Ool40000
0goo0000000<Ool200000goo00000002Ool20003Ool50002Ool50005Ool50003Ool40003Ool20005
Ool20003Ool2000=Ool20007Ool70003Ool20003Ool50002Ool20002Ool30002Ool80004Ool30002
Ool00`00Oomoo`02Ool30002Ool20006Ool90003Ool20002Ool00`00Oomoo`05Ool20007Ool00`00
Oomoo`03Ool20005Ool400000goo000000020005Ool200000goo0000000:Ool000]oo`@0009oo`03
001oogoo009oo`03001oogoo00800003Ool00000008000=oo`8000=oo`80009oo`03001oogoo009o
o`800003Ool0000000<000Uoo`800003Ool0000000Eoo`<0009oo`@000Eoo`H000Moo`D000Aoo`D0
00=oo`@00003Ool0000000aoo`800003Ool00000009oo`8000=oo`D0009oo`D000Eoo`D000=oo`@0
00=oo`8000Eoo`8000=oo`8000eoo`8000Moo`L000=oo`8000=oo`D0009oo`80009oo`<0009oo`P0
00Aoo`<0009oo`03001oogoo009oo`<0009oo`8000Ioo`T000=oo`80009oo`03001oogoo00Eoo`80
00Moo`03001oogoo00=oo`8000Eoo`@00003Ool00000008000Eoo`800003Ool0000000Yoo`003Goo
0P000Woo0`000Woo0`001Goo100000=oo`0000000P0000=oo`0000000Woo0`000Woo0`0017oo2000
0Woo0P0000=oo`0000000`000Woo0P001Goo1`000goo0P002Woo0P001Woo0P001goo0P0000=oo`00
00002P000Woo0P0000=oo`0000000P001goo00<007ooOol00goo0P002Goo00<007ooOol01Goo1000
00=oo`0000000`000Woo0`000Woo3P0000=oo`0000001@000Woo0P000goo0`000Woo1@0017oo0`00
1Goo0P000Woo00<007ooOol00Woo00<007ooOol01Goo10001Woo10002Woo0P000goo100000=oo`00
00000Woo1P000Woo1`000Woo1@0000=oo`000000100000=oo`0000001Goo1`003goo0008Ool30002
Ool20002Ool00`00Oomoo`03Ool50002Ool20005Ool30005Ool20002Ool20006Ool20003Ool20002
Ool30004Ool00`00Oomoo`050002Ool20003Ool30002Ool:0002Ool700000goo000000050002Ool2
00000goo00000004Ool00`00Oomoo`02Ool30005Ool70002Ool500000goo00000009000:Ool30004
Ool00`00Oomoo`020005Ool20003Ool20003Ool200000goo00000004Ool00`00Oomoo`030002Ool2
0005Ool20006Ool600000goo00000002Ool30002Ool700000goo0000000:Ool<0007Ool200000goo
00000002Ool00`00Oomoo`02Ool00`00Oomoo`020003Ool40003Ool30004Ool200000goo00000003
0002Ool20003Ool5000<Ool000Qoo`<0009oo`80009oo`03001oogoo00=oo`D0009oo`8000Eoo`<0
00Eoo`80009oo`8000Ioo`8000=oo`80009oo`<000Aoo`03001oogoo00D0009oo`8000=oo`<0009o
o`X0009oo`L00003Ool0000000D0009oo`800003Ool0000000Aoo`03001oogoo009oo`<000Eoo`L0
009oo`D00003Ool0000000T000Yoo`<000Aoo`03001oogoo008000Eoo`8000=oo`8000=oo`800003
Ool0000000Aoo`03001oogoo00<0009oo`8000Eoo`8000Ioo`H00003Ool00000009oo`<0009oo`L0
0003Ool0000000Yoo``000Moo`800003Ool00000009oo`03001oogoo009oo`03001oogoo008000=o
o`@000=oo`<000Aoo`800003Ool0000000<0009oo`8000=oo`D000aoo`002Woo00<007ooOol00P00
0Woo1P0017oo0`002Goo1@0000=oo`0000000Woo1`0000=oo`0000000`001Woo0`000Woo0`000goo
10001goo0`000goo0P0017oo00<007ooOol00P000goo0P0000=oo`00000017oo00<007ooOol00P00
00=oo`00000010001Woo1`0017oo00<007ooOol00goo0P001Goo0P000goo0P003Woo0`000Woo00<0
07ooOol01@000Woo0`000Woo0`000Woo0P0000=oo`00000010001Goo00<007ooOol01@000Woo2000
17oo0`001Goo0P000Woo00<007ooOol00Woo0P0000=oo`00000020000Woo0P000goo0P000goo1`00
0Woo0P0000=oo`0000000Woo0`000Woo00<007ooOol0100000=oo`0000001goo0`000Woo0`0017oo
00<007ooOol01@0017oo0`002Woo000:Ool00`00Oomoo`020002Ool60004Ool30009Ool500000goo
00000002Ool700000goo000000030006Ool30002Ool30003Ool40007Ool30003Ool20004Ool00`00
Oomoo`020003Ool200000goo00000004Ool00`00Oomoo`0200000goo000000040006Ool70004Ool0
0`00Oomoo`03Ool20005Ool20003Ool2000>Ool30002Ool00`00Oomoo`050002Ool30002Ool30002
Ool200000goo000000040005Ool00`00Oomoo`050002Ool80004Ool30005Ool20002Ool00`00Oomo
o`02Ool200000goo000000080002Ool20003Ool20003Ool70002Ool200000goo00000002Ool30002
Ool00`00Oomoo`0400000goo00000007Ool30002Ool30004Ool00`00Oomoo`050004Ool3000:Ool0
00Yoo`03001oogoo00@000=oo`8000Ioo`/000=oo`800003Ool00000009oo`8000=oo`<000Aoo`D0
009oo`03001oogoo00=oo`@00003Ool0000000Yoo`@00003Ool000000080009oo`03001oogoo00<0
009oo`800003Ool000000080009oo`03001oogoo00<000Aoo`L00003Ool0000000=oo`@0009oo`D0
0003Ool0000000<0009oo`D0015oo`80009oo`<000=oo`80009oo`8000Eoo`03001oogoo00<000Ao
o`D0009oo`<000=oo`80009oo`8000=oo`8000Moo`D00003Ool00000009oo`<0009oo`<000Aoo`03
001oogoo009oo`03001oogoo00@00003Ool0000000800003Ool0000000=oo`80009oo`<000Eoo`@0
00Eoo`800003Ool0000000D0009oo`03001oogoo00Aoo`D000Eoo`03001oogoo00Eoo`8000Yoo`00
2Woo00<007ooOol010000goo0P001Woo2`000goo0P0000=oo`0000000Woo0P000goo0`0017oo1@00
0Woo00<007ooOol00goo100000=oo`0000002Woo100000=oo`0000000P000Woo00<007ooOol00`00
0Woo0P0000=oo`0000000P000Woo00<007ooOol00`0017oo1`0000=oo`0000000goo10000Woo1@00
00=oo`0000000`000Woo1@004Goo0P000Woo0`000goo0P000Woo0P001Goo00<007ooOol00`0017oo
1@000Woo0`000goo0P000Woo0P000goo0P001goo1@0000=oo`0000000Woo0`000Woo0`0017oo00<0
07ooOol00Woo00<007ooOol0100000=oo`0000000P0000=oo`0000000goo0P000Woo0`001Goo1000
1Goo0P0000=oo`0000001@000Woo00<007ooOol017oo1@001Goo00<007ooOol01Goo0P002Woo0008
Ool20005Ool30002Ool80004Ool20003Ool30002Ool200000goo000000020007Ool50003Ool40008
Ool200000goo0000000900000goo00000005Ool40005Ool30005Ool40005Ool30002Ool20003Ool3
0007Ool40003Ool30004Ool30004OolB0005Ool400000goo00000002Ool50002Ool00`00Oomoo`02
0007Ool00`00Oomoo`03Ool400000goo00000002Ool30002Ool90003Ool200000goo00000002Ool0
0`00Oomoo`04Ool30002Ool30002Ool00`00Oomoo`020005Ool200000goo0000000200000goo0000
0002Ool20008Ool50002Ool200000goo00000003Ool20002Ool70003Ool7000DOol000Qoo`D0009o
o`8000Eoo`03001oogoo009oo`D000Moo`03001oogoo00800003Ool0000000Yoo`8000Moo`P0009o
o`<000Aoo`8000=oo`800003Ool0000000<0009oo`8000Qoo`D0009oo`8000Qoo`80009oo`<0009o
o`8000Yoo`<0009oo`8000Ioo`@0009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009o
o`8000Qoo`800003Ool00000008000=oo`80009oo`03001oogoo00T000Qoo`800003Ool00000009o
o`8000Eoo`03001oogoo009oo`<0009oo`800003Ool00000009oo`D0009oo`03001oogoo00=oo`80
009oo`03001oogoo00L000Eoo`800003Ool00000009oo`X000=oo`80009oo`800003Ool000000080
0003Ool00000009oo`03001oogoo009oo`<0009oo`8000=oo`X000aoo`0027oo1@000Woo0P001Goo
00<007ooOol00Woo1@001goo00<007ooOol00P0000=oo`0000002Woo0P001goo20000Woo0`0017oo
0P000goo0P0000=oo`0000000`000Woo0P0027oo1@000Woo0P0027oo0P000Woo0`000Woo0P002Woo
0`000Woo0P001Woo10000Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo0P0027oo
0P0000=oo`0000000P000goo0P000Woo00<007ooOol02@0027oo0P0000=oo`0000000Woo0P001Goo
00<007ooOol00Woo0`000Woo0P0000=oo`0000000Woo1@000Woo00<007ooOol00goo0P000Woo00<0
07ooOol01`001Goo0P0000=oo`0000000Woo2P000goo0P000Woo0P0000=oo`0000000P0000=oo`00
00000Woo00<007ooOol00Woo0`000Woo0P000goo2P0037oo000;Ool20002Ool50002Ool50003Ool7
0002Ool00`00Oomoo`0200000goo0000000900000goo000000050002Ool20003Ool20005Ool30002
Ool30002Ool30004Ool00`00Oomoo`0:0004Ool00`00Oomoo`0:0006Ool3000>Ool3000:Ool20002
Ool30002Ool30002Ool30002Ool:0005Ool400000goo000000020005Ool00`00Oomoo`02Ool80002
Ool200000goo00000002Ool70007Ool00`00Oomoo`0200000goo000000020003Ool20002Ool50000
0goo00000002Ool00`00Oomoo`020003Ool50002Ool200000goo000000020003Ool20003Ool40000
0goo000000020005Ool200000goo000000020007Ool00`00Oomoo`050003Ool20004Ool00`00Oomo
o`0:Ool000]oo`80009oo`D0009oo`D000=oo`L0009oo`03001oogoo00800003Ool0000000T00003
Ool0000000D0009oo`8000=oo`8000Eoo`<0009oo`<0009oo`<000Aoo`03001oogoo00X000Aoo`03
001oogoo00X000Ioo`<000ioo`<000Yoo`80009oo`<0009oo`<0009oo`<0009oo`X000Eoo`@00003
Ool00000008000Eoo`03001oogoo009oo`P0009oo`800003Ool00000009oo`L000Moo`03001oogoo
00800003Ool00000008000=oo`80009oo`D00003Ool00000009oo`03001oogoo008000=oo`D0009o
o`800003Ool00000008000=oo`8000=oo`@00003Ool00000008000Eoo`800003Ool00000008000Mo
o`03001oogoo00D000=oo`8000Aoo`03001oogoo00Yoo`0027oo0P0000=oo`0000000P000goo1000
0goo0`000Woo0P000goo0P000Woo00<007ooOol00`0017oo0P000goo0P0000=oo`0000000goo0P00
0Woo1@0027oo0P000Woo0P001Goo0`000Woo0`0017oo00<007ooOol00Woo0`000Woo0`0017oo00<0
07ooOol00Woo1@000Woo00<007ooOol03goo30001Goo0P000Woo00<007ooOol00goo10000goo0P00
0goo1@000Woo0P001Goo1`001goo00<007ooOol00Woo00<007ooOol00P0000=oo`0000000Woo0P00
0goo1`000Woo0`001Goo0`000Woo10000goo0P0000=oo`0000000Woo00<007ooOol01@0017oo0`00
1Goo100000=oo`0000000P0000=oo`0000001Goo1`001Goo1`000Woo0`000goo100000=oo`000000
0P000Woo00<007ooOol02Woo000=Ool400000goo00000007Ool00`00Oomoo`0400000goo00000002
0005Ool30002Ool30002Ool200000goo0000000200000goo000000020003Ool900000goo00000002
Ool50002Ool00`00Oomoo`03Ool40002Ool30002Ool00`00Oomoo`03Ool40002Ool50003Ool20002
OolA00000goo00000003Ool20003Ool600000goo000000020008Ool400000goo000000030004Ool0
0`00Oomoo`050002Ool20003Ool70002Ool30002Ool00`00Oomoo`0200000goo00000002Ool50003
Ool20005Ool50002Ool20005Ool30002Ool200000goo000000020005Ool20006Ool50002Ool20005
Ool200000goo000000030002Ool20003Ool70003Ool20005Ool400000goo00000005Ool20002Ool0
0`00Oomoo`0:Ool000eoo`@00003Ool0000000Moo`03001oogoo00@00003Ool00000008000Eoo`<0
009oo`<0009oo`800003Ool0000000800003Ool00000008000=oo`T00003Ool00000009oo`D0009o
o`03001oogoo00=oo`@0009oo`<0009oo`03001oogoo00=oo`@0009oo`D000=oo`80009ooa400003
Ool0000000=oo`8000=oo`H00003Ool00000008000Qoo`@00003Ool0000000<000Aoo`03001oogoo
00D0009oo`8000=oo`L0009oo`<0009oo`03001oogoo00800003Ool00000009oo`D000=oo`8000Eo
o`D0009oo`8000Eoo`<0009oo`800003Ool00000008000Eoo`8000Ioo`D0009oo`8000Eoo`800003
Ool0000000<0009oo`8000=oo`L000=oo`8000Eoo`@00003Ool0000000Eoo`80009oo`03001oogoo
00Yoo`003goo0P0000=oo`0000001@000Woo00<007ooOol00P001Goo1@000Woo00<007ooOol017oo
0`001Goo0P0000=oo`0000001goo0P000goo0P0000=oo`0000000P000goo0P000Woo1@0000=oo`00
00001Goo100027oo10000goo0`000Woo0P000Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00Woo0P0000=oo`0000000P0000=oo`0000000`0017oo0P0000=oo`00000037oo0`0017oo0`00
0Woo0`0017oo00<007ooOol01@000goo0P001Goo0P000Woo00<007ooOol00P0000=oo`0000000P00
0goo100000=oo`0000001@0017oo0`002Goo0`001Goo1@000Woo200017oo00<007ooOol01@000Woo
0`0017oo00<007ooOol0100000=oo`0000000goo1@002Goo0P0000=oo`0000000`000Woo0P000Woo
0`002Woo000?Ool200000goo000000050002Ool00`00Oomoo`020005Ool50002Ool00`00Oomoo`04
Ool30005Ool200000goo00000007Ool20003Ool200000goo000000020003Ool20002Ool500000goo
00000005Ool40008Ool40003Ool30002Ool20002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool200000goo0000000200000goo000000030004Ool200000goo0000000<Ool30004Ool3
0002Ool30004Ool00`00Oomoo`050003Ool20005Ool20002Ool00`00Oomoo`0200000goo00000002
0003Ool400000goo000000050004Ool30009Ool30005Ool50002Ool80004Ool00`00Oomoo`050002
Ool30004Ool00`00Oomoo`0400000goo00000003Ool50009Ool200000goo000000030002Ool20002
Ool3000:Ool000Qoo`D0009oo`800003Ool0000000=oo`80009oo`03001oogoo00L000=oo`@000Qo
o`D0009oo`800003Ool0000000D0009oo`D000Eoo`@00003Ool00000008000=oo`<000Uoo`P0009o
o`8000Moo`03001oogoo0080009oo`<0009oo`<0009oo`D000Eoo`<000Aoo`<0009oo`<0011oo`<0
009oo`03001oogoo00=oo`@0009oo`<000=oo`@00003Ool0000000@00003Ool00000009oo`03001o
ogoo00800003Ool0000000Moo`<000Aoo`8000Ioo`T0009oo`03001oogoo00Moo`03001oogoo00Ao
o`03001oogoo009oo`D000Eoo`8000Eoo`D000Eoo`800003Ool0000000<000Aoo`P0009oo`<000Ao
o`<000Eoo`8000Yoo`002goo0P000Woo0P0000=oo`0000000P0000=oo`0000000Woo0`0017oo00<0
07ooOol01Goo2P0017oo00<007ooOol00P0000=oo`00000017oo0`000goo1@000Woo0P001Goo0`00
0Woo0P0037oo00<007ooOol00Woo00<007ooOol01`000Woo00<007ooOol00P000Woo00<007ooOol0
0goo10000goo1@000Woo0P001Woo0P000Woo0P004Woo100027oo0P000Woo00<007ooOol01Goo0`00
17oo0P0000=oo`0000000Woo00<007ooOol00`002goo1@002Woo0P000goo0P000Woo20000Woo1@00
0Woo1@000goo1@000Woo1`000goo1`001Goo0P001Woo0P0017oo00<007ooOol00P001Woo1P0000=o
o`0000002Woo000;Ool20002Ool200000goo0000000200000goo00000002Ool30004Ool00`00Oomo
o`05Ool:0004Ool00`00Oomoo`0200000goo00000004Ool30003Ool50002Ool20005Ool30002Ool2
000<Ool00`00Oomoo`02Ool00`00Oomoo`070002Ool00`00Oomoo`020002Ool00`00Oomoo`03Ool4
0003Ool50002Ool20006Ool20002Ool2000BOol40008Ool20002Ool00`00Oomoo`05Ool30004Ool2
00000goo00000002Ool00`00Oomoo`03000;Ool5000:Ool20003Ool20002Ool80002Ool50002Ool5
0003Ool50002Ool70003Ool70005Ool20006Ool20004Ool00`00Oomoo`020006Ool600000goo0000
000:Ool000Qoo`800003Ool00000008000Eoo`<000Eoo`@0009oo`P000=oo`8000Aoo`<0009oo`03
001oogoo00<000Moo`D000Aoo`<000Uoo`03001oogoo00`0009oo`<0009oo`03001oogoo008000=o
o`80009oo`03001oogoo00@000Qoo`D000Aoo`03001oogoo00L00003Ool00000008001Ioo`P0009o
o`@000Yoo`<0009oo`800003Ool00000008000Eoo``000=oo`X0009oo`D000Eoo`8000=oo`@000=o
o`@000=oo`D000=oo`80009oo`8000=oo`<0009oo`8000=oo`D0009oo`L00003Ool000000080009o
o`03001oogoo00P000Aoo`800003Ool0000000Yoo`0027oo0P0000=oo`0000000P001Goo0`001Goo
10000Woo20000goo0P0017oo0`000Woo00<007ooOol00`001goo1@0017oo0`002Goo00<007ooOol0
30000Woo0`000Woo00<007ooOol00P000goo0P000Woo00<007ooOol0100027oo1@0017oo00<007oo
Ool01`0000=oo`0000000P005Woo20000Woo10002Woo0`000Woo0P0000=oo`0000000P001Goo3000
0goo2P000Woo1@001Goo0P000goo10000goo10000goo1@000goo0P000Woo0P000goo0`000Woo0P00
0goo1@000Woo1`0000=oo`0000000P000Woo00<007ooOol0200017oo0P0000=oo`0000002Woo0008
Ool200000goo00000009Ool500000goo00000005Ool20003Ool50007Ool20002Ool00`00Oomoo`02
000:Ool20006Ool90002Ool30003Ool20004Ool00`00Oomoo`03Ool20002Ool00`00Oomoo`040000
0goo000000020005Ool:0003Ool40002Ool00`00Oomoo`020003Ool200000goo0000000JOol00`00
Oomoo`02Ool00`00Oomoo`02000=Ool40005Ool50002Ool00`00Oomoo`02Ool20003Ool50004Ool0
0`00Oomoo`02Ool30003Ool600000goo0000000200000goo00000007Ool50003Ool400000goo0000
00020007Ool00`00Oomoo`050004Ool30003Ool20005Ool40005Ool00`00Oomoo`02Ool30002Ool3
000<Ool000Qoo`800003Ool0000000Uoo`D00003Ool0000000Eoo`8000=oo`D000Moo`80009oo`03
001oogoo008000Yoo`8000Ioo`T0009oo`<000=oo`8000Aoo`03001oogoo00=oo`80009oo`03001o
ogoo00@00003Ool00000008000Eoo`X000=oo`@0009oo`03001oogoo008000=oo`800003Ool00000
01Yoo`03001oogoo009oo`03001oogoo008000eoo`@000Eoo`D0009oo`03001oogoo009oo`8000=o
o`D000Aoo`03001oogoo009oo`<000=oo`H00003Ool0000000800003Ool0000000Moo`D000=oo`@0
0003Ool00000008000Moo`03001oogoo00D000Aoo`<000=oo`8000Eoo`@000Eoo`03001oogoo009o
o`<0009oo`<000aoo`0027oo0P0000=oo`0000002@000goo0P0000=oo`000000100000=oo`000000
0`0017oo1`0000=oo`0000000Woo00<007ooOol02P000Woo1`0000=oo`00000017oo00<007ooOol0
0goo100000=oo`0000000P000Woo1@0000=oo`0000000P001Goo0P0000=oo`0000002Goo00<007oo
Ool00Woo00<007ooOol01Goo0P000Woo00<007ooOol00`000Woo0P0000=oo`00000060000Woo0`00
0Woo0`004Goo1`000goo0P000Woo0`000Woo1@000goo10000Woo0`000Woo00<007ooOol01Goo0P00
1Goo0P0000=oo`0000001`000goo100000=oo`0000001Goo2@001Goo00<007ooOol01Goo1@002Goo
1@000Woo0`000Woo00<007ooOol017oo0`002Woo0008Ool30004Ool20003Ool30002Ool30004Ool3
0004Ool30002Ool00`00Oomoo`02Ool200000goo00000002Ool30003Ool20004Ool00`00Oomoo`02
0003Ool200000goo000000040008Ool200000goo00000005Ool20005Ool50002Ool200000goo0000
00070002Ool30002Ool60002Ool40005Ool00`00Oomoo`030004Ool20003Ool20003Ool20003Ool2
0003Ool20002Ool00`00Oomoo`03OolA0002Ool20003Ool50005Ool40003Ool400000goo00000005
Ool20002Ool60002Ool50002Ool200000goo00000003Ool20007Ool30009Ool20003Ool7000:Ool2
000<Ool00`00Oomoo`03Ool40008Ool2000:Ool000Qoo`<000Aoo`8000=oo`<0009oo`<000Aoo`<0
00Aoo`<0009oo`03001oogoo009oo`800003Ool00000009oo`<000=oo`8000Aoo`03001oogoo0080
00=oo`800003Ool0000000@000Qoo`800003Ool0000000Eoo`8000Eoo`D0009oo`800003Ool00000
00L0009oo`<0009oo`H0009oo`@000Eoo`03001oogoo00<000Aoo`8000=oo`8000=oo`8000=oo`80
00=oo`80009oo`03001oogoo00=ooa40009oo`8000=oo`D000Eoo`@000=oo`@00003Ool0000000Eo
o`80009oo`H0009oo`D0009oo`800003Ool0000000=oo`8000Moo`<000Uoo`8000=oo`L000Yoo`80
00aoo`03001oogoo00=oo`@000Qoo`8000Yoo`002Woo0`000Woo0`000Woo0P001Goo0`000Woo0P00
1Woo0P000Woo0`000Woo0`001Goo100000=oo`0000000P000Woo00<007ooOol00`000Woo0`0017oo
20000Woo0P0000=oo`000000100000=oo`0000001@000goo0P000Woo0P0000=oo`0000000goo0P00
1Goo10000goo0P001Goo1`001Goo0`000Woo0`000Woo0`000Woo0`000Woo100000=oo`0000000Woo
1@0000=oo`00000017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01@0017oo1@0000=o
o`0000001goo0P0000=oo`000000100000=oo`0000000Woo00<007ooOol00Woo0`0017oo00<007oo
Ool00P0000=oo`0000000`002goo20000Woo0`000Woo0P000goo2P000Woo3P0027oo2P0037oo000:
Ool30002Ool30002Ool20005Ool30002Ool20006Ool20002Ool30002Ool30005Ool400000goo0000
00020002Ool00`00Oomoo`030002Ool30004Ool80002Ool200000goo0000000400000goo00000005
0003Ool20002Ool200000goo00000003Ool20005Ool40003Ool20005Ool70005Ool30002Ool30002
Ool30002Ool30002Ool400000goo00000002Ool500000goo00000004Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`050004Ool500000goo00000007Ool200000goo0000000400000goo0000
0002Ool00`00Oomoo`02Ool30004Ool00`00Oomoo`0200000goo00000003000;Ool80002Ool30002
Ool20003Ool:0002Ool>0008Ool:000<Ool000Yoo`03001oogoo00Aoo`<000Qoo`80009oo`L00003
Ool00000009oo`03001oogoo00Aoo`D00003Ool0000000Eoo`@000Eoo`03001oogoo008000Moo`03
001oogoo009oo`03001oogoo00<000Aoo`800003Ool0000000=oo`@00003Ool00000009oo`800003
Ool0000000<000Uoo`<0009oo`L000=oo`8000Qoo`80009oo`8000Eoo`03001oogoo008000Eoo`80
0003Ool00000008000=oo`800003Ool000000080009oo`<0009oo`<0009oo`<000Aoo`D000=oo`80
0003Ool0000000D0009oo`<000Aoo`800003Ool00000008000Ioo`@0009oo`03001oogoo00<000Ao
o`X0009oo`03001oogoo009oo`03001oogoo00Aoo`<000Moo`03001oogoo009oo`8000Eoo`03001o
ogoo009oo`03001oogoo009oo`X000=oo`8000Aoo`<000Yoo`0027oo0P0027oo2@0000=oo`000000
0Woo0P000goo0P0000=oo`0000000Woo1`000goo0`002Goo1@000Woo00<007ooOol01`000Woo1@00
1Goo0`000Woo0`001goo0P0000=oo`0000000P001Goo0P0037oo00<007ooOol00P000goo100000=o
o`0000001`0000=oo`0000000Woo1@000Woo00<007ooOol01`001Goo0`000Woo0P0000=oo`000000
1Goo0P000Woo00<007ooOol00goo1P000goo0`000Woo0`0017oo0P001Goo0`000Woo0P0000=oo`00
00002Woo10001Goo1@000goo0P000goo0P000Woo1@0027oo1`000Woo0`000Woo1@000Woo0`000Woo
1@000goo0P000goo100000=oo`00000010003Goo0008Ool20008Ool900000goo00000002Ool20003
Ool200000goo00000002Ool70003Ool30009Ool50002Ool00`00Oomoo`070002Ool50005Ool30002
Ool30007Ool200000goo000000020005Ool2000<Ool00`00Oomoo`020003Ool400000goo00000007
00000goo00000002Ool50002Ool00`00Oomoo`070005Ool30002Ool200000goo00000005Ool20002
Ool00`00Oomoo`03Ool60003Ool30002Ool30004Ool20005Ool30002Ool200000goo0000000:Ool4
0005Ool50003Ool20003Ool20002Ool50008Ool70002Ool30002Ool50002Ool30002Ool50003Ool2
0003Ool400000goo00000004000=Ool001Aoo`8000=oo`800003Ool00000009oo`<0009oo`800003
Ool00000008000=oo`8000Moo`X000=oo`80009oo`03001oogoo008000=oo`@000=oo`D0009oo`03
001oogoo00Aoo`P000Eoo`D0009oo``0009oo`03001oogoo00<0009oo`8000Eoo`8000=oo`800003
Ool00000008000=oo`80009oo`<000=oo`8000Uoo`03001oogoo00800003Ool0000000@00003Ool0
0000009oo`H000Aoo`<0009oo`8000Eoo`D000Qoo`80009oo`<000ioo`L000=oo`<0009oo`@00003
Ool00000008000=oo`T00003Ool0000000=oo`80009oo`03001oogoo00Aoo`03001oogoo00=oo`@0
00=oo`D000Moo`<000Aoo`<000aoo`0057oo0P000goo0P0000=oo`0000000Woo0`000Woo0P0000=o
o`0000000P000goo0P001goo2P000goo0P000Woo00<007ooOol00P000goo10000goo1@000Woo00<0
07ooOol017oo20001Goo1@000Woo30000Woo00<007ooOol00`000Woo0P001Goo0P000goo0P0000=o
o`0000000P000goo0P000Woo0`000goo0P002Goo00<007ooOol00P0000=oo`000000100000=oo`00
00000Woo1P0017oo0`000Woo0P001Goo1@0027oo0P000Woo0`003Woo1`000goo0`000Woo100000=o
o`0000000P000goo2@0000=oo`0000000goo0P000Woo00<007ooOol017oo00<007ooOol00goo1000
0goo1@001goo0`0017oo0`0037oo0008Ool:0002Ool30002Ool30006Ool30005Ool30002Ool90003
Ool20003Ool400000goo00000002Ool30007Ool50003Ool40008Ool20003Ool70004Ool00`00Oomo
o`020003Ool20003Ool40005Ool00`00Oomoo`050002Ool50005Ool50005Ool400000goo00000007
0002Ool00`00Oomoo`030004Ool200000goo000000020003Ool20007Ool00`00Oomoo`070003Ool:
0006Ool=0002Ool20003Ool30002Ool20005Ool200000goo00000007Ool00`00Oomoo`02Ool20000
0goo0000000200000goo00000002Ool50002Ool500000goo00000007Ool2000:Ool30002Ool2000=
Ool000Yoo`03001oogoo009oo`8000Eoo`03001oogoo008000Qoo`D0009oo`8000Eoo`8000=oo`D0
00Moo`800003Ool00000009oo`03001oogoo00Uoo`03001oogoo00Eoo`T00003Ool0000000800003
Ool0000000=oo`@0009oo`03001oogoo00D000Moo`D0009oo`<000Aoo`<000=oo`L000Aoo`D00003
Ool0000000Eoo`8000=oo`@000Eoo`D000Eoo`<0009oo`L0009oo`<000=oo`8000Moo`8000=oo`80
00Qoo`8000=oo`8000=oo`@000Moo`03001oogoo00D0009oo`800003Ool0000000D0009oo`D000Eo
o`800003Ool00000008000=oo`@000=oo`800003Ool0000000L000eoo`80009oo`D000Yoo`002Woo
00<007ooOol00Woo0P001Goo00<007ooOol00P0027oo1@000Woo0P001Goo0P000goo1@001goo0P00
00=oo`0000000Woo00<007ooOol02Goo00<007ooOol01Goo2@0000=oo`0000000P0000=oo`000000
0goo10000Woo00<007ooOol01@001goo1@000Woo0`0017oo0`000goo1`0017oo1@0000=oo`000000
1Goo0P000goo10001Goo1@001Goo0`000Woo1`000Woo0`000goo0P001goo0P000goo0P0027oo0P00
0goo0P000goo10001goo00<007ooOol01@000Woo0P0000=oo`0000001@000Woo1@001Goo0P0000=o
o`0000000P000goo10000goo0P0000=oo`0000001`003Goo0P000Woo1@002Woo000:Ool30002Ool5
0002Ool00`00Oomoo`0:0004Ool00`00Oomoo`050002Ool50003Ool70002Ool200000goo00000002
Ool:0002Ool60002Ool20003Ool20005Ool30007Ool20002Ool30003Ool90003Ool20002Ool00`00
Oomoo`05Ool400000goo00000003Ool60003Ool200000goo000000030002Ool400000goo00000008
Ool20009Ool30003Ool20005Ool400000goo000000050002Ool30002Ool900000goo000000030007
Ool70002Ool30003Ool20002Ool200000goo00000003Ool40003Ool50002Ool200000goo00000007
Ool50005Ool20003Ool>00000goo000000020003Ool2000:Ool000Yoo`<0009oo`D0009oo`03001o
ogoo00X000Aoo`03001oogoo00D0009oo`D000=oo`L0009oo`800003Ool00000009oo`X0009oo`H0
009oo`8000=oo`8000Eoo`<000Moo`80009oo`<000=oo`T000=oo`80009oo`03001oogoo00Eoo`@0
0003Ool0000000=oo`H000=oo`800003Ool0000000<0009oo`@00003Ool0000000Qoo`8000Uoo`<0
00=oo`8000Eoo`@00003Ool0000000D0009oo`<0009oo`T00003Ool0000000<000Moo`L0009oo`<0
00=oo`80009oo`800003Ool0000000=oo`@000=oo`D0009oo`800003Ool0000000Moo`D000Eoo`80
00=oo`h00003Ool00000008000=oo`8000Yoo`002goo10000goo0P000Woo0`000goo0P0017oo0`00
0Woo0`000goo10000goo100000=oo`0000000goo0P000Woo0P0000=oo`0000000P000goo0P000goo
0P000Woo00<007ooOol00Woo00<007ooOol01@002Goo1P000Woo0P000Woo00<007ooOol01Goo0P00
0goo100000=oo`0000000P002Woo0P0000=oo`0000000`0017oo1@001Goo0P001Goo0P0000=oo`00
0000200037oo1@002Goo0P0000=oo`0000000goo0P000Woo0P001Goo00<007ooOol00Woo0`0017oo
200017oo00<007ooOol00goo100000=oo`0000000Woo0`001goo1@0017oo00<007ooOol00P0000=o
o`0000001`000goo1@000Woo0`000Woo0P000goo0P000goo0P001Goo100000=oo`0000002Woo000;
Ool40003Ool20002Ool30003Ool20004Ool30002Ool30003Ool40003Ool400000goo00000003Ool2
0002Ool200000goo000000020003Ool20003Ool20002Ool00`00Oomoo`02Ool00`00Oomoo`050009
Ool60002Ool20002Ool00`00Oomoo`05Ool20003Ool400000goo00000002000:Ool200000goo0000
00030004Ool50005Ool20005Ool200000goo00000008000<Ool50009Ool200000goo00000003Ool2
0002Ool20005Ool00`00Oomoo`02Ool30004Ool80004Ool00`00Oomoo`03Ool400000goo00000002
Ool30007Ool50004Ool00`00Oomoo`0200000goo000000070003Ool50002Ool30002Ool20003Ool2
0003Ool20005Ool400000goo0000000:Ool000eoo`D000Eoo`@00003Ool000000080009oo`03001o
ogoo00=oo`@00003Ool0000000Moo`800003Ool0000000800003Ool00000008000Eoo`<0009oo`<0
009oo`80009oo`<0009oo`<000=oo`T0009oo`03001oogoo009oo`03001oogoo0080009oo`H0009o
o`@00003Ool0000000Eoo`X0009oo`<000Aoo`D000=oo`D0009oo`D0009oo`<000Aoo`03001oogoo
009oo`d000Aoo`P0009oo`800003Ool0000000800003Ool00000009oo`D0009oo`<0009oo`8000Io
o`8000=oo`H000Qoo`<000Ioo`P000=oo`@0009oo`03001oogoo00800003Ool0000000=oo`8000Mo
o`8000Eoo`03001oogoo00@00003Ool0000000<000Uoo`800003Ool0000000Yoo`0027oo1@0017oo
1@0000=oo`0000001Goo100027oo0P0000=oo`0000001@000Woo0P0000=oo`0000001Goo1@000Woo
0P001Goo0`001Goo0P000Woo00<007ooOol01Goo0P000goo0P000Woo0`000Woo00<007ooOol01000
0goo0P001Goo0P0000=oo`0000001@000goo0P0017oo00<007ooOol00P001Woo0P001goo0P001Goo
00<007ooOol017oo0`000Woo0`000Woo00<007ooOol00Woo0P000goo0P001Woo0P0017oo0`001Goo
0`001Woo00<007ooOol00goo0P000Woo20001goo0P0037oo1@000Woo00<007ooOol00Woo00<007oo
Ool01Goo0P000Woo00<007ooOol00P0000=oo`0000000P0000=oo`0000001@000Woo1`001Goo0`00
17oo20000Woo0`0037oo0008Ool50004Ool500000goo00000005Ool40008Ool200000goo00000005
0002Ool200000goo00000005Ool50002Ool20005Ool30005Ool20002Ool00`00Oomoo`05Ool20003
Ool20002Ool30002Ool00`00Oomoo`040003Ool20005Ool200000goo000000050003Ool20004Ool0
0`00Oomoo`020006Ool20007Ool20005Ool00`00Oomoo`04Ool30002Ool30002Ool00`00Oomoo`02
Ool20003Ool20006Ool20004Ool30005Ool30006Ool00`00Oomoo`03Ool20002Ool80007Ool2000<
Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`05Ool20002Ool00`00Oomoo`0200000goo00000002
00000goo000000050002Ool70005Ool30004Ool80002Ool3000<Ool000]oo`H000=oo`<000Uoo`P0
009oo`800003Ool0000000Aoo`03001oogoo00800003Ool0000000D000Aoo`<000Qoo`H00003Ool0
0000009oo`H0009oo`D000Eoo`@000Eoo`<0009oo`D0009oo`800003Ool0000000=oo`@00003Ool0
00000080009oo`03001oogoo00L00003Ool0000000D0009oo`D0009oo`D0009oo`03001oogoo00=o
o`80009oo`<0009oo`<0009oo`L00003Ool000000080009oo`03001oogoo00Moo`D0009oo`H000Io
o`03001oogoo009oo`H0009oo`h000=oo`80009oo`<0009oo`H0009oo`80009oo`<000Eoo`800003
Ool0000000Aoo`03001oogoo008000=oo`D0009oo`8000Ioo`8000=oo`80009oo`8000eoo`002goo
1P000goo0`002Goo20000Woo0P0000=oo`00000017oo00<007ooOol00P0000=oo`0000001@0017oo
0`0027oo1P0000=oo`0000000Woo1P000Woo1@001Goo10001Goo0`000Woo1@000Woo0P0000=oo`00
00000goo100000=oo`0000000P000Woo00<007ooOol01`0000=oo`0000001@000Woo1@000Woo1@00
0Woo00<007ooOol00goo0P000Woo0`000Woo0`000Woo1`0000=oo`0000000P000Woo00<007ooOol0
1goo1@000Woo1P001Woo00<007ooOol00Woo1P000Woo3P000goo0P000Woo0`000Woo1P000Woo0P00
0Woo0`001Goo0P0000=oo`00000017oo00<007ooOol00P000goo1@000Woo0P001Woo0P000goo0P00
0Woo0P003Goo0008Ool30004Ool30002Ool2000<Ool00`00Oomoo`02Ool00`00Oomoo`0200000goo
000000020002Ool00`00Oomoo`030004Ool00`00Oomoo`05Ool:0004Ool200000goo00000002Ool0
0`00Oomoo`02Ool30004Ool500000goo00000009Ool30003Ool20002Ool200000goo000000020000
0goo00000005Ool20002Ool00`00Oomoo`020003Ool200000goo00000004Ool30003Ool40003Ool2
0002Ool500000goo00000002Ool00`00Oomoo`04Ool30003Ool20005Ool20002Ool:0003Ool20002
Ool00`00Oomoo`02Ool50002Ool50003Ool20005Ool20003Ool20003Ool50005Ool20002Ool00`00
Oomoo`02Ool30005Ool50002Ool200000goo000000020002Ool00`00Oomoo`050003Ool20002Ool7
00000goo0000000200000goo00000002Ool5000:Ool000Qoo`8000Moo`03001oogoo00`0009oo`<0
009oo`<000Eoo`@000Eoo`<0009oo`P000Aoo`03001oogoo009oo`<0009oo`800003Ool000000080
00Ioo`H000=oo`<000aoo`@00003Ool00000008000Eoo`800003Ool0000000<0009oo`80009oo`03
001oogoo00<0009oo`800003Ool000000080009oo`03001oogoo00Eoo`<0009oo`@000=oo`800003
Ool00000008000Qoo`@00003Ool0000000<0009oo`@000=oo`8000=oo`<0009oo`80009oo`D000=o
o`@000=oo`<0009oo`D0009oo`<0009oo`D000=oo`H00003Ool00000008000Ioo`L000Aoo`<000Eo
o`80009oo`<000=oo`@00003Ool00000008000=oo`8000Eoo`800003Ool00000008000=oo`8000Yo
o`0027oo0P001goo00<007ooOol030000Woo0`000Woo0`001Goo10001Goo0`000Woo200017oo00<0
07ooOol00Woo0`000Woo0P0000=oo`0000000P001Woo1P000goo0`0037oo100000=oo`0000000P00
1Goo0P0000=oo`0000000`000Woo0P000Woo00<007ooOol00`000Woo0P0000=oo`0000000P000Woo
00<007ooOol01Goo0`000Woo10000goo0P0000=oo`0000000P0027oo100000=oo`0000000`000Woo
10000goo0P000goo0`000Woo0P000Woo1@000goo10000goo0`000Woo1@000Woo0`000Woo1@000goo
1P0000=oo`0000000P001Woo1`0017oo0`001Goo0P000Woo0`000goo100000=oo`0000000P000goo
0P001Goo0P0000=oo`0000000P000goo0P002Woo0008Ool70002Ool30003Ool20003Ool20005Ool2
0002Ool00`00Oomoo`07Ool50002Ool00`00Oomoo`03Ool20004Ool50006Ool20002Ool200000goo
0000000:Ool20007Ool<00000goo00000005Ool50002Ool30004Ool00`00Oomoo`040005Ool30005
Ool20002Ool60002Ool20005Ool50005Ool900000goo00000005Ool20005Ool50007Ool00`00Oomo
o`040003Ool30002Ool20007Ool30003Ool20002Ool20005Ool00`00Oomoo`05Ool20005Ool80004
Ool20006Ool70005Ool400000goo00000005Ool400000goo000000050005Ool400000goo0000000:
Ool000Qoo`L0009oo`<000=oo`8000=oo`8000Eoo`80009oo`03001oogoo00Moo`D0009oo`03001o
ogoo00=oo`8000Aoo`D000Ioo`80009oo`800003Ool0000000Yoo`8000Moo``00003Ool0000000Eo
o`D0009oo`<000Aoo`03001oogoo00@000Eoo`<000Eoo`80009oo`H0009oo`8000Eoo`D000Eoo`T0
0003Ool0000000Eoo`8000Eoo`D000Moo`03001oogoo00@000=oo`<0009oo`8000Moo`<000=oo`80
009oo`8000Eoo`03001oogoo00Eoo`8000Eoo`P000Aoo`8000Ioo`L000Eoo`@00003Ool0000000Eo
o`@00003Ool0000000D000Eoo`@00003Ool0000000Yoo`002goo0P001Goo100000=oo`0000000P00
00=oo`000000100000=oo`0000000Woo2P000goo0P000Woo1@0000=oo`00000010000goo1`0000=o
o`0000000Woo0P0000=oo`00000020000Woo1`000Woo00<007ooOol00Woo00<007ooOol00Woo0`00
2Goo0P001Goo0`000Woo00<007ooOol00P0027oo1@000Woo0P000Woo00<007ooOol00Woo0`002Goo
00<007ooOol01goo00<007ooOol00Woo0P0000=oo`0000000`000Woo1`000goo1`000Woo00<007oo
Ool00P001goo0`002Woo100000=oo`0000000Woo1@000Woo20002Goo00<007ooOol00Woo0`000Woo
200017oo00<007ooOol01goo0`002Goo0`0017oo00<007ooOol01goo0`0037oo0008Ool200000goo
0000000400000goo00000005Ool30004Ool200000goo000000020003Ool20003Ool400000goo0000
00020003Ool30004Ool30002Ool20003Ool200000goo00000002Ool30004Ool00`00Oomoo`02Ool0
0`00Oomoo`020003Ool20002Ool50007Ool:0008Ool20002Ool00`00Oomoo`0:0004Ool00`00Oomo
o`040006Ool90002Ool80002Ool30002Ool30004Ool00`00Oomoo`020003Ool400000goo00000003
Ool20002Ool00`00Oomoo`070002Ool00`00Oomoo`0<Ool30006Ool00`00Oomoo`03Ool20003Ool9
0002Ool30002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool30002Ool80002Ool2000<Ool5000<Ool3
000:Ool000Qoo`800003Ool0000000@00003Ool0000000Eoo`<000Aoo`800003Ool00000008000=o
o`8000=oo`@00003Ool00000008000=oo`<000Aoo`<0009oo`8000=oo`800003Ool00000009oo`<0
00Aoo`03001oogoo009oo`03001oogoo008000=oo`80009oo`D000Moo`X000Qoo`80009oo`03001o
ogoo00X000Aoo`03001oogoo00@000Ioo`T0009oo`P0009oo`<0009oo`<000Aoo`03001oogoo0080
00=oo`@00003Ool0000000=oo`80009oo`03001oogoo00L0009oo`03001oogoo00aoo`<000Ioo`03
001oogoo00=oo`8000=oo`T0009oo`<0009oo`03001oogoo00Aoo`03001oogoo009oo`<0009oo`P0
009oo`8000aoo`D000aoo`<000Yoo`0027oo0`0017oo0`002Goo1@001Goo0`000Woo0`000Woo0P00
1Goo0`000Woo0P001goo00<007ooOol00`000Woo0`001Woo0`000Woo0`000Woo00<007ooOol01000
00=oo`0000000P000goo2@000goo0P000goo2@0000=oo`0000000Woo0`0017oo00<007ooOol00Woo
1@001Goo1`0000=oo`0000000goo0P001Goo0P000goo0P000Woo00<007ooOol017oo0`000Woo0`00
1goo0P0000=oo`0000000P0000=oo`0000000Woo00<007ooOol00P000goo10004Goo1@000Woo1@00
00=oo`0000000P0000=oo`00000017oo00<007ooOol00goo0P000Woo1@000Woo0`000Woo00<007oo
Ool00goo0P0017oo0`003goo0P003goo0P002Woo0008Ool30004Ool30009Ool50005Ool30002Ool3
0002Ool20005Ool30002Ool20007Ool00`00Oomoo`030002Ool30006Ool30002Ool30002Ool00`00
Oomoo`0400000goo000000020003Ool90003Ool20003Ool900000goo00000002Ool30004Ool00`00
Oomoo`02Ool50005Ool700000goo00000003Ool20005Ool20003Ool20002Ool00`00Oomoo`04Ool3
0002Ool30007Ool200000goo0000000200000goo00000002Ool00`00Oomoo`020003Ool4000AOol5
0002Ool500000goo0000000200000goo00000004Ool00`00Oomoo`03Ool20002Ool50002Ool30002
Ool00`00Oomoo`03Ool20004Ool3000?Ool2000?Ool2000:Ool000Qoo`8000Moo`X000=oo`D0009o
o`8000Eoo`<000Uoo`03001oogoo00L0009oo`03001oogoo008000Eoo`D0009oo`03001oogoo00=o
o`@000Eoo`800003Ool0000000Moo`03001oogoo009oo`D000Moo`8000=oo`<000Eoo`@0009oo`D0
00=oo`D0009oo`8000=oo`800003Ool0000000800003Ool0000000@00003Ool0000000800003Ool0
0000009oo`D0009oo`03001oogoo00=oo`T000Eoo`800003Ool00000009oo`03001oogoo00@00003
Ool0000001Aoo`8000Eoo`8000Eoo`800003Ool000000080009oo`H000Eoo`8000Eoo`80009oo`H0
00Mooa000003Ool0000000h00003Ool0000000Yoo`0027oo0P001goo2P000goo1@000Woo0P001Goo
0`002Goo00<007ooOol01`000Woo00<007ooOol00P001Goo1@000Woo00<007ooOol00goo10001Goo
0P0000=oo`0000001goo00<007ooOol00Woo1@001goo0P000goo0`001Goo10000Woo1@000goo1@00
0Woo0P000goo0P0000=oo`0000000P0000=oo`000000100000=oo`0000000P0000=oo`0000000Woo
1@000Woo00<007ooOol00goo2@001Goo0P0000=oo`0000000Woo00<007ooOol0100000=oo`000000
57oo0P001Goo0P001Goo0P0000=oo`0000000P000Woo1P001Goo0P001Goo0P000Woo1P001goo4000
00=oo`0000003P0000=oo`0000002Woo0008Ool90003Ool20003Ool50004Ool30008Ool90002Ool0
0`00Oomoo`020003Ool20002Ool00`00Oomoo`070003Ool40008Ool50002Ool200000goo00000005
0002Ool50003Ool70002Ool30002Ool20008Ool40003Ool50003Ool20002Ool30002Ool200000goo
00000005Ool20005Ool200000goo000000020003Ool40008Ool20003Ool50002Ool200000goo0000
00020005Ool200000goo0000000C00000goo0000000400000goo000000050005Ool20002Ool00`00
Oomoo`02Ool500000goo0000000400000goo000000020003Ool2000:Ool20003Ool20003Ool20005
Ool20003Ool20003Ool2000?Ool000Yoo`03001oogoo009oo`<0009oo`D000=oo`@0009oo`03001o
ogoo00Yoo`8000=oo`80009oo`03001oogoo00<0009oo`80009oo`<000=oo`8000Moo`X000=oo`80
009oo`800003Ool0000000=oo`@000=oo`D000Aoo`03001oogoo00Aoo`<000aoo`D000=oo`D000Io
o`03001oogoo00800003Ool0000000<0009oo`D0009oo`800003Ool0000000Moo`P0009oo`D000Ao
o`<000Eoo`D0009oo`<000Aoo`03001oogoo009oo`8000=oo`8000=oo`<000Aoo`800003Ool00000
00=oo`D0009oo`@000Ioo`8000Eoo`8000Eoo`<0009oo`X0009oo`<0009oo`<0009oo`D0009oo`<0
009oo`D0015oo`002Woo00<007ooOol00Woo0`000Woo1@000goo10000Woo00<007ooOol02Woo0P00
0goo0P000Woo00<007ooOol00`000Woo0P000Woo0`000goo0P001goo2P000goo0P000Woo0P0000=o
o`0000000goo10000goo1@0017oo00<007ooOol017oo0`0037oo1@000goo1@001Woo00<007ooOol0
0P0000=oo`0000000`000Woo1@000Woo0P0000=oo`0000001goo20000Woo1@0017oo0`001Goo1@00
0Woo0`0017oo00<007ooOol00Woo0P000goo0P000goo0`0017oo0P0000=oo`0000000goo1@000Woo
10001Woo0P001Goo0P001Goo0`000Woo2P000Woo0`000Woo0`000Woo1@000Woo0`000Woo1@004Goo
000:Ool30002Ool20005Ool00`00Oomoo`05Ool20002Ool;0002Ool400000goo000000020005Ool3
0005Ool400000goo000000070003Ool20003Ool400000goo00000002Ool30007Ool50004Ool50008
Ool>0003Ool50004Ool50002Ool00`00Oomoo`030004Ool30004Ool00`00Oomoo`03000;Ool00`00
Oomoo`02Ool30003Ool40002Ool00`00Oomoo`07Ool00`00Oomoo`04Ool30002Ool30002Ool50007
Ool30002Ool30007Ool20005Ool700000goo000000030002Ool50002Ool20005Ool00`00Oomoo`02
Ool20005Ool00`00Oomoo`020005Ool20005Ool30003Ool9000:Ool000Yoo`<0009oo`8000Eoo`03
001oogoo00Eoo`80009oo`/0009oo`@00003Ool00000008000Eoo`<000Eoo`@00003Ool0000000L0
00=oo`8000=oo`@00003Ool00000009oo`<000Moo`D000Aoo`D000Qoo`h000=oo`D000Aoo`D0009o
o`03001oogoo00<000Aoo`<000Aoo`03001oogoo00<000]oo`03001oogoo009oo`<000=oo`@0009o
o`03001oogoo00Moo`03001oogoo00Aoo`<0009oo`<0009oo`D000Moo`<0009oo`<000Moo`8000Eo
o`L00003Ool0000000<0009oo`D0009oo`8000Eoo`03001oogoo009oo`8000Eoo`03001oogoo0080
00Eoo`8000Eoo`<000=oo`T000Yoo`002goo0P000Woo1@000Woo1P000Woo10000goo0P000goo0P00
1Goo0P0000=oo`00000027oo1P0000=oo`0000001Goo0P000goo1@001goo0P0000=oo`0000000Woo
0P002Woo00<007ooOol01Goo0P0037oo0P000goo0P000goo1@0017oo1@000goo0P000Woo00<007oo
Ool00P001Woo1P001Goo2P000Woo0`000Woo00<007ooOol01Goo0P000Woo20000Woo1@000Woo00<0
07ooOol00goo10000goo1`000Woo00<007ooOol017oo1P000Woo1@000Woo0P000goo0`0017oo0`00
17oo00<007ooOol01@000Woo0`000Woo1@000Woo00<007ooOol01@000Woo1@000Woo00<007ooOol0
1Goo0P000goo0P002Woo0008Ool200000goo000000020003Ool40003Ool20005Ool30002Ool30002
Ool50002Ool200000goo000000080004Ool200000goo000000030002Ool50004Ool60002Ool20000
0goo00000002Ool:0002Ool700000goo0000000:0002Ool30002Ool50004Ool50003Ool30002Ool2
0002Ool3000:Ool20008Ool20003Ool20005Ool20002Ool80005Ool20003Ool40003Ool40008Ool4
00000goo00000003Ool20002Ool50002Ool00`00Oomoo`02Ool30003Ool20002Ool30002Ool20006
Ool60005Ool00`00Oomoo`03Ool40003Ool20002Ool30003Ool40003Ool20002Ool8000AOol000Qo
o`800003Ool00000008000=oo`@000=oo`8000Eoo`<0009oo`<0009oo`D0009oo`800003Ool00000
00P000Aoo`800003Ool0000000<0009oo`D000Aoo`H0009oo`800003Ool00000009oo`X0009oo`L0
0003Ool0000000X0009oo`<0009oo`D000Aoo`D000=oo`<0009oo`80009oo`<000Yoo`8000Qoo`80
00=oo`8000Eoo`80009oo`P000Eoo`8000=oo`@000=oo`@000Qoo`@00003Ool0000000=oo`80009o
o`D0009oo`03001oogoo009oo`<000=oo`80009oo`<0009oo`8000Ioo`H000Eoo`03001oogoo00=o
o`@000=oo`80009oo`<000=oo`@000=oo`80009oo`P0015oo`0027oo0P0000=oo`0000001goo0`00
0Woo1@000Woo0P001Goo0`000goo0P000Woo0`0017oo00<007ooOol00Woo0`000Woo0`0017oo0`00
0goo10000Woo00<007ooOol00Woo00<007ooOol00P0000=oo`0000000P000goo0P000goo0P000Woo
00<007ooOol00Woo0P0000=oo`0000000goo0P0017oo00<007ooOol00P001Goo00<007ooOol01Goo
0P001goo0`001Goo2P000Woo2@0000=oo`0000000P0000=oo`0000001@001Goo0P000goo1`001goo
0`000Woo0P0037oo0P0000=oo`0000000P0000=oo`0000000P000goo10001Woo1@001Woo00<007oo
Ool0200017oo1`0027oo100000=oo`0000000Woo00<007ooOol01Goo1@001Goo0P000goo2@002Woo
0008Ool200000goo00000007Ool30002Ool50002Ool20005Ool30003Ool20002Ool30004Ool00`00
Oomoo`02Ool30002Ool30004Ool30003Ool40002Ool00`00Oomoo`02Ool00`00Oomoo`0200000goo
000000020003Ool20003Ool20002Ool00`00Oomoo`02Ool200000goo00000003Ool20004Ool00`00
Oomoo`020005Ool00`00Oomoo`05Ool20007Ool30005Ool:0002Ool900000goo0000000200000goo
000000050005Ool20003Ool70007Ool30002Ool2000<Ool200000goo0000000200000goo00000002
0003Ool40006Ool50006Ool00`00Oomoo`080004Ool70008Ool400000goo00000002Ool00`00Oomo
o`05Ool50005Ool20003Ool9000:Ool000Qoo`<000]oo`<000=oo`@000Qoo`D000Ioo`<0009oo`<0
009oo`03001oogoo00Aoo`<0009oo`03001oogoo00Eoo`80009oo`<0009oo`<000Eoo`@00003Ool0
000000800003Ool00000009oo`<0009oo`800003Ool0000000800003Ool000000080009oo`03001o
ogoo00D0009oo`P000Yoo`L000Aoo`03001oogoo009oo`03001oogoo008000=oo`8000Eoo`800003
Ool0000000Aoo`D00003Ool0000000<000Aoo`8000Yoo`03001oogoo00h000Eoo`800003Ool00000
00Moo`P000Aoo`L000Eoo`03001oogoo009oo`D000=oo`8000aoo`800003Ool00000009oo`P000Ao
o`H000Moo`8000=oo`8000Yoo`0027oo0`002goo0`000goo100027oo1@001Woo0`000Woo0`000Woo
00<007ooOol017oo0`000Woo00<007ooOol01Goo0P000Woo0`000Woo0`001Goo100000=oo`000000
0P0000=oo`0000000Woo0`000Woo0P0000=oo`0000000P0000=oo`0000000P000Woo00<007ooOol0
1@000Woo20002Woo1`0017oo00<007ooOol00Woo00<007ooOol00P000goo0P001Goo0P0000=oo`00
000017oo1@0000=oo`0000000`0017oo0P002Woo00<007ooOol03P001Goo0P0000=oo`0000001goo
200017oo1`001Goo00<007ooOol00Woo1@000goo0P0037oo0P0000=oo`0000000Woo200017oo1P00
1goo0P000goo0P002Woo000:Ool:0002Ool00`00Oomoo`05Ool:0004Ool50002Ool00`00Oomoo`03
Ool40008Ool20002Ool60002Ool20002Ool00`00Oomoo`03Ool50002Ool20005Ool30005Ool20002
Ool200000goo00000005Ool40005Ool00`00Oomoo`03Ool20004Ool:00000goo00000004Ool30002
Ool30002Ool00`00Oomoo`0400000goo000000030002Ool200000goo000000040003Ool30004Ool3
0002Ool<0005Ool20003Ool20003Ool50002Ool3000;Ool00`00Oomoo`02Ool30002Ool00`00Oomo
o`02Ool50002Ool50003Ool400000goo0000000:0002Ool30005Ool20003Ool40002Ool00`00Oomo
o`02Ool60002Ool400000goo0000000:Ool000Qoo`8000=oo`8000=oo`80009oo`P000Aoo`03001o
ogoo009oo`D000=oo`@000Qoo`T00003Ool00000009oo`03001oogoo009oo`03001oogoo0080009o
o`H000Aoo`<000Uoo`D00003Ool00000009oo`<000Uoo`D0009oo`D00003Ool0000000@000=oo`80
00=oo`800003Ool000000080009oo`03001oogoo00=oo`@000Eoo`<000Aoo`03001oogoo00<000Ao
o`<0009oo`8000Ioo`80009oo`8000=oo`8000=oo`D0009oo`D000Moo`8000Eoo``000Ioo`@000Mo
o`03001oogoo00=oo`8000Moo`<000Aoo`03001oogoo009oo`03001oogoo00Aoo`H000Moo`80009o
o`D000=oo`8000Eoo`<000aoo`0027oo0P000goo0P000goo0P000Woo200017oo00<007ooOol00Woo
1@000goo100027oo2@0000=oo`0000000Woo00<007ooOol00Woo00<007ooOol00P000Woo1P0017oo
0`002Goo1@0000=oo`0000000Woo0`002Goo1@000Woo1@0000=oo`00000010000goo0P000goo0P00
00=oo`0000000P000Woo00<007ooOol00goo10001Goo0`0017oo00<007ooOol00`0017oo0`000Woo
0P001Woo0P000Woo0P000goo0P000goo1@000Woo1@001goo0P001Goo30001Woo10001goo00<007oo
Ool00goo0P001goo0`0017oo00<007ooOol00Woo00<007ooOol017oo1P001goo0P000Woo1@000goo
0P001Goo0`0037oo0008Ool30002Ool50005Ool20003Ool40002Ool50003Ool30002Ool2000<Ool0
0`00Oomoo`02Ool200000goo00000002Ool30002Ool00`00Oomoo`040003Ool20006Ool;0003Ool3
0006Ool:0003Ool40003Ool30004Ool30002Ool50005Ool20002Ool500000goo00000009Ool30002
Ool00`00Oomoo`020007Ool00`00Oomoo`0700000goo00000002Ool30002Ool50003Ool40003Ool7
0002Ool70003Ool20003Ool2000:Ool70002Ool6000;Ool30002Ool30002Ool50002Ool00`00Oomo
o`02Ool60002Ool40003Ool50009Ool3000:Ool000Qoo`<0009oo`D000Eoo`8000=oo`@0009oo`D0
00=oo`<0009oo`8000aoo`03001oogoo009oo`800003Ool00000009oo`<0009oo`03001oogoo00@0
00=oo`8000Ioo`/000=oo`<000Ioo`X000=oo`@000=oo`<000Aoo`<0009oo`D000Eoo`80009oo`D0
0003Ool0000000Uoo`<0009oo`03001oogoo008000Moo`03001oogoo00L00003Ool00000009oo`<0
009oo`D000=oo`@000=oo`L0009oo`L000=oo`8000=oo`8000Yoo`L0009oo`H000]oo`<0009oo`<0
009oo`D0009oo`03001oogoo009oo`H0009oo`@000=oo`D000Uoo`<000Yoo`002Woo0`0017oo1@00
00=oo`0000000P0000=oo`0000001Goo0P001goo00<007ooOol030000Woo0`000Woo0`001Goo1000
1Goo0`000Woo200017oo0P000goo0`000Woo0P0027oo0P000goo0P001goo0`000Woo0P001goo0`00
0goo1@000Woo10000goo0`0037oo0P000Woo00<007ooOol01`000Woo00<007ooOol00P000goo0P00
00=oo`0000000Woo0P001Goo00<007ooOol01Goo100000=oo`0000000goo0P000Woo0P000goo0`00
0Woo0`000Woo2P000Woo0P000goo0P000Woo00<007ooOol00Woo2P000Woo00<007ooOol00goo1000
0goo0P000Woo0`000Woo00<007ooOol00Woo00<007ooOol00P001goo00<007ooOol02Woo0P002Woo
000:Ool00`00Oomoo`05Ool20005Ool200000goo0000000400000goo000000050002Ool30004Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool20002Ool20008Ool50002Ool20005Ool00`00Oomoo`02Ool5
0007Ool00`00Oomoo`0900000goo00000003000;Ool3000:Ool50004Ool00`00Oomoo`020007Ool<
00000goo00000002Ool00`00Oomoo`020003Ool20002Ool00`00Oomoo`030002Ool200000goo0000
0002Ool7000:Ool200000goo0000000200000goo00000002Ool30002Ool20005Ool30004Ool00`00
Oomoo`02Ool00`00Oomoo`030002Ool20002Ool50003Ool20003Ool40008Ool50005Ool20002Ool3
0002Ool00`00Oomoo`070002Ool<00000goo0000000:Ool000Yoo`03001oogoo00Eoo`8000Eoo`80
0003Ool0000000@00003Ool0000000D0009oo`<000Aoo`03001oogoo009oo`03001oogoo00=oo`80
009oo`8000Qoo`D0009oo`8000Eoo`03001oogoo009oo`D000Moo`03001oogoo00T00003Ool00000
00<000]oo`<000Yoo`D000Aoo`03001oogoo008000Moo``00003Ool00000009oo`03001oogoo0080
00=oo`80009oo`03001oogoo00<0009oo`800003Ool00000009oo`L000Yoo`800003Ool000000080
0003Ool00000009oo`<0009oo`8000Eoo`<000Aoo`03001oogoo009oo`03001oogoo00<0009oo`80
009oo`D000=oo`8000=oo`@000Qoo`D000Eoo`80009oo`<0009oo`03001oogoo00L0009oo``00003
Ool0000000Yoo`002Woo1`0000=oo`0000000`000Woo0`0017oo0`0017oo00<007ooOol00goo1000
0Woo0`000Woo1@0000=oo`0000000Woo2P000goo0P000Woo1@000Woo1@000goo1`000Woo00<007oo
Ool00P000goo0P001Goo0P003Goo300017oo0`000Woo00<007ooOol01`000Woo00<007ooOol00Woo
00<007ooOol00Woo0P0000=oo`0000000Woo00<007ooOol00`000Woo10001Goo00<007ooOol00P00
00=oo`0000000Woo0P000goo30001Goo0`001Woo0`0027oo10000Woo1@001Goo00<007ooOol01000
0goo1@001goo2P000goo1`001Goo0P000Woo00<007ooOol00P000goo0P000Woo00<007ooOol00Woo
00<007ooOol00Woo0P0000=oo`0000002Woo000:Ool700000goo000000030002Ool30004Ool30004
Ool00`00Oomoo`03Ool40002Ool30002Ool500000goo00000002Ool:0003Ool20002Ool50002Ool5
0003Ool70002Ool00`00Oomoo`020003Ool20005Ool2000=Ool<0004Ool30002Ool00`00Oomoo`07
0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool200000goo00000002Ool00`00Oomoo`030002Ool4
0005Ool00`00Oomoo`0200000goo00000002Ool20003Ool<0005Ool30006Ool30008Ool40002Ool5
0005Ool00`00Oomoo`040003Ool50007Ool:0003Ool70005Ool20002Ool00`00Oomoo`020003Ool2
0002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool200000goo0000000:Ool000Yoo`03001oogoo009o
o`<000Aoo`03001oogoo008000Moo`<0009oo`D00003Ool0000000Eoo`@000=oo`800003Ool00000
008000=oo`8000=oo`@00003Ool00000008000=oo`@000=oo`<0009oo`8000=oo`80009oo`03001o
ogoo00<0009oo`D0009oo`l000Aoo`03001oogoo009oo`8000Ioo`80009oo`03001oogoo008000=o
o`80009oo`<0009oo`<0009oo`800003Ool00000009oo`03001oogoo008000Eoo`D0009oo`03001o
ogoo00800003Ool00000009oo`D000=oo`8000=oo`8000Uoo`D0009oo`03001oogoo00Yoo`@000=o
o`L000Eoo`D000=oo`T000=oo`8000=oo`@00003Ool0000000Aoo`D00003Ool00000009oo`03001o
ogoo00@00003Ool00000009oo`<0009oo`<0009oo`<000aoo`0027oo0P001goo0`000Woo0`002Woo
10000goo0`002Goo1@001Goo100000=oo`0000000P0000=oo`0000001Goo100000=oo`0000001goo
00<007ooOol0100000=oo`0000000P001Goo0`0017oo0`000goo0P0017oo00<007ooOol00Woo0`00
0Woo0`000Woo1`0000=oo`0000000Woo00<007ooOol0100000=oo`0000000Woo00<007ooOol00goo
0P000Woo0P0000=oo`0000000Woo00<007ooOol01`000goo0P000Woo00<007ooOol00P0000=oo`00
00000P000goo100000=oo`0000000P0000=oo`0000002@000goo10003goo1@000goo0P002Goo00<0
07ooOol01Goo0P000goo1@001goo0P0000=oo`00000010000goo0P0000=oo`0000000P001Goo0`00
1Goo0P000Woo00<007ooOol017oo0`002Woo0008Ool20007Ool30002Ool3000:Ool40003Ool30009
Ool50005Ool400000goo0000000200000goo00000005Ool400000goo00000007Ool00`00Oomoo`04
00000goo000000020005Ool30004Ool30003Ool20004Ool00`00Oomoo`02Ool30002Ool30002Ool7
00000goo00000002Ool00`00Oomoo`0400000goo00000002Ool00`00Oomoo`03Ool20002Ool20000
0goo00000002Ool00`00Oomoo`070003Ool20002Ool00`00Oomoo`0200000goo000000020003Ool4
00000goo0000000200000goo000000090003Ool4000?Ool50003Ool20009Ool00`00Oomoo`05Ool2
0003Ool50007Ool200000goo000000040003Ool200000goo000000020005Ool30005Ool20002Ool0
0`00Oomoo`04Ool3000:Ool000Qoo`L0009oo`03001oogoo00=oo`/00003Ool0000000Moo`X000=o
o`D0009oo`8000Eoo`<000Uoo`800003Ool0000000D0009oo`03001oogoo008000Eoo`D0009oo`03
001oogoo00Eoo`@00003Ool000000080009oo`<0009oo`03001oogoo00=oo`80009oo`8000=oo`80
0003Ool00000008000Eoo`800003Ool00000009oo`D00003Ool00000009oo`800003Ool00000009o
o`03001oogoo008000=oo`@00003Ool00000009oo`03001oogoo00800003Ool0000000Moo`800003
Ool0000000Eoo`8000=oo`8000Mooa4000=oo`@00003Ool0000000L0009oo`H0009oo`D000Aoo`H0
009oo`<000Aoo`<0009oo`800003Ool0000000Uoo`D00003Ool00000008000Qoo`8000Yoo`0027oo
1`000Woo00<007ooOol00goo2`0000=oo`0000001goo2P000goo1@000Woo0P001Goo0`002Goo0P00
00=oo`0000001@000Woo00<007ooOol00P001Goo1@000Woo00<007ooOol01Goo100000=oo`000000
0P000Woo0`000Woo00<007ooOol00goo0P000Woo0P000goo0P0000=oo`0000000P001Goo0P0000=o
o`0000000Woo1@0000=oo`0000000Woo0P0000=oo`0000000Woo00<007ooOol00P000goo100000=o
o`0000000Woo00<007ooOol00P0000=oo`0000001goo0P0000=oo`0000001Goo0P000goo0P001goo
4@000goo100000=oo`0000001`000Woo1P000Woo1@0017oo1P000Woo0`0017oo0`000Woo0P0000=o
o`0000002Goo1@0000=oo`0000000P0027oo0P002Woo0008Ool20003Ool20002Ool60004Ool00`00
Oomoo`02Ool200000goo000000070003Ool20003Ool50004Ool30009Ool80002Ool200000goo0000
0003Ool20002Ool00`00Oomoo`070003Ool4000:Ool200000goo00000005Ool20002Ool500000goo
00000002Ool50005Ool50002Ool200000goo000000020003Ool200000goo00000002Ool200000goo
00000002Ool30007Ool200000goo00000002Ool00`00Oomoo`0200000goo000000050002Ool20000
0goo000000030002Ool400000goo000000050002Ool20003Ool20003Ool20003Ool400000goo0000
0005Ool20003Ool20002Ool00`00Oomoo`02Ool30003Ool40002Ool00`00Oomoo`02Ool00`00Oomo
o`020007Ool00`00Oomoo`03000<Ool20005Ool:000<Ool000Qoo`8000=oo`80009oo`H000Aoo`03
001oogoo009oo`800003Ool0000000L000=oo`8000=oo`D000Aoo`<000Uoo`P0009oo`800003Ool0
000000=oo`80009oo`03001oogoo00L000=oo`@000Yoo`800003Ool0000000Eoo`80009oo`D00003
Ool00000009oo`D000Eoo`D0009oo`800003Ool00000008000=oo`800003Ool00000009oo`800003
Ool00000009oo`<000Moo`800003Ool00000009oo`03001oogoo00800003Ool0000000D0009oo`80
0003Ool0000000<0009oo`@00003Ool0000000D0009oo`8000=oo`8000=oo`8000=oo`@00003Ool0
000000Eoo`8000=oo`80009oo`03001oogoo009oo`<000=oo`@0009oo`03001oogoo009oo`03001o
ogoo008000Moo`03001oogoo00<000aoo`8000Eoo`X000aoo`0027oo0`000Woo0P000Woo00<007oo
Ool00Woo0`000Woo1@001Goo0P000goo0`000Woo1@0017oo0`000Woo00<007ooOol02Woo0P000goo
0P000Woo0P0000=oo`0000000P0000=oo`0000000Woo0`0017oo00<007ooOol01Goo2P000Woo0P00
00=oo`000000100000=oo`0000000P000goo0P0000=oo`0000000P000goo1`000goo10001Goo0`00
0Woo0P0000=oo`0000000Woo0`001Goo1`000Woo0P0000=oo`0000000Woo00<007ooOol00P0000=o
o`00000017oo0`001Goo0P001Goo0P0000=oo`0000000goo0P000Woo0`000Woo1@001goo0P0000=o
o`0000000`000Woo0`000Woo0P000Woo0`000Woo00<007ooOol01Goo0P000Woo0`000Woo00<007oo
Ool02@001Goo300000=oo`0000001@000goo0P0017oo0`002Woo000:Ool00`00Oomoo`040006Ool4
0003Ool50002Ool30002Ool20005Ool20006Ool20002Ool<00000goo0000000200000goo00000002
0005Ool30005Ool40002Ool80003Ool20004Ool30005Ool20005Ool50005Ool400000goo00000003
Ool400000goo00000009Ool00`00Oomoo`030006Ool500000goo00000003Ool20002Ool200000goo
00000002Ool00`00Oomoo`030007Ool50002Ool50002Ool200000goo000000030006Ool30003Ool9
0005Ool20005Ool30005Ool20002Ool80005Ool40005Ool00`00Oomoo`02Ool50002Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool200000goo00000003Ool50007Ool2000:Ool000Yoo`03001oogoo00@0
00Ioo`@000=oo`D0009oo`<0009oo`8000Eoo`8000Ioo`80009oo``00003Ool0000000800003Ool0
0000008000Eoo`<000Eoo`@0009oo`P000=oo`8000Aoo`<000Eoo`8000Eoo`D000Eoo`@00003Ool0
000000=oo`@00003Ool0000000Uoo`03001oogoo00<000Ioo`D00003Ool0000000=oo`80009oo`80
0003Ool00000009oo`03001oogoo00<000Moo`D0009oo`D0009oo`800003Ool0000000<000Ioo`<0
00=oo`T000Eoo`8000Eoo`<000Eoo`80009oo`P000Eoo`@000Eoo`03001oogoo009oo`D0009oo`03
001oogoo009oo`03001oogoo009oo`800003Ool0000000=oo`D000Moo`8000Yoo`0027oo0P001Goo
1`0000=oo`0000001goo0P001Goo00<007ooOol01@000Woo1`0000=oo`0000000P000goo0P000goo
0P001Goo0P0000=oo`0000002Goo1@0000=oo`0000001Goo0P000goo1@001goo1`002Goo00<007oo
Ool01goo0`001goo0P0000=oo`0000002@001Goo1`000goo0P0000=oo`0000000P0000=oo`000000
0Woo0P0000=oo`0000000P001Goo200017oo0`000goo0P000Woo0`0017oo1@000Woo00<007ooOol0
1Goo0P000goo1`0027oo1P0000=oo`0000000Woo00<007ooOol00Woo00<007ooOol01goo1@000Woo
1@000goo0P000Woo0`000Woo0`000Woo0P0000=oo`0000000`0017oo200037oo0008Ool20005Ool7
00000goo00000007Ool20005Ool00`00Oomoo`050002Ool700000goo000000020003Ool20003Ool2
0005Ool200000goo00000009Ool500000goo00000005Ool20003Ool50007Ool70009Ool00`00Oomo
o`07Ool30007Ool200000goo000000090005Ool70003Ool200000goo0000000200000goo00000002
Ool200000goo000000020005Ool80004Ool30003Ool20002Ool30004Ool50002Ool00`00Oomoo`05
Ool20003Ool70008Ool600000goo00000002Ool00`00Oomoo`02Ool00`00Oomoo`07Ool50002Ool5
0003Ool20002Ool30002Ool30002Ool200000goo000000030004Ool8000<Ool000Qoo`D0009oo`80
00=oo`800003Ool0000000D0009oo`D0009oo`<000=oo`@000=oo`8000Eoo`<0009oo`@00003Ool0
000000<0009oo`800003Ool0000000T000=oo`800003Ool0000000@00003Ool0000000<000Aoo`L0
0003Ool0000000=oo`/000aoo`H0009oo`<000Aoo`8000=oo`D0009oo`03001oogoo009oo`D000Eo
o`800003Ool00000008000Eoo`D0009oo`03001oogoo009oo`8000Ioo`D000Ioo`D000=oo`80009o
o`H0009oo`<0009oo`8000=oo`X000Aoo`800003Ool00000009oo`<0009oo`X000=oo`@000=oo`@0
0003Ool00000009oo`03001oogoo00=oo`@000Eoo`8000Ioo`8000Aoo`<000Yoo`002goo0P000Woo
0`000Woo0P0000=oo`0000000goo10000goo0P000Woo00<007ooOol01Goo100000=oo`0000000`00
0Woo0P001Goo0`0017oo00<007ooOol00`0017oo0P000goo0`000Woo0`0017oo0`0017oo0`000Woo
00<007ooOol00Woo0P0000=oo`0000000`0017oo0P000goo3P000goo0P001Goo0`000Woo1@000goo
0P000Woo1@000goo1`001Goo1`000goo0P000Woo0`000Woo200017oo1`000goo0`000Woo10000goo
0P001Goo00<007ooOol01@0017oo00<007ooOol00Woo0`000Woo0`001Goo10000goo0P000goo1000
00=oo`0000001goo0P0000=oo`0000000P0027oo1@000Woo1`0000=oo`0000000P000Woo00<007oo
Ool02Woo000;Ool20002Ool30002Ool200000goo00000003Ool40003Ool20002Ool00`00Oomoo`05
Ool400000goo000000030002Ool20005Ool30004Ool00`00Oomoo`030004Ool20003Ool30002Ool3
0004Ool30004Ool30002Ool00`00Oomoo`02Ool200000goo000000030004Ool20003Ool>0003Ool2
0005Ool30002Ool50003Ool20002Ool50003Ool70005Ool70003Ool20002Ool30002Ool80004Ool7
0003Ool30002Ool40003Ool20005Ool00`00Oomoo`050004Ool00`00Oomoo`02Ool30002Ool30005
Ool40003Ool20003Ool400000goo00000007Ool200000goo000000020008Ool50002Ool700000goo
000000020002Ool00`00Oomoo`0:Ool000Qoo`<000Ioo`03001oogoo00<000Moo`@00003Ool00000
008000Yoo`<000Aoo`<000Uoo`D000Eoo`<0009oo`<0009oo`8000Eoo`<0009oo`8000Ioo`80009o
o`<0009oo`<000Aoo`D000Moo`03001oogoo009oo`03001oogoo009oo`D000Qoo`@000=oo`@00003
Ool00000008000=oo`@00003Ool0000000=oo`D0009oo`8000=oo`@00003Ool00000009oo`03001o
ogoo00Aoo`03001oogoo009oo`<0009oo`03001oogoo009oo`<0009oo`8000Eoo`<0009oo`D0009o
o`<000Aoo`D000Ioo`80009oo`8000Qoo`D000Moo`800003Ool0000000L000Eoo`X000Aoo`<000=o
o`8000Eoo`80009oo`<000Yoo`0027oo0`001Woo00<007ooOol00`001goo100000=oo`0000000P00
2Woo0`0017oo0`002Goo1@001Goo0`000Woo0`000Woo0P001Goo0`000Woo0P001Woo0P000Woo0`00
0Woo0`0017oo1@001goo00<007ooOol00Woo00<007ooOol00Woo1@0027oo10000goo100000=oo`00
00000P000goo100000=oo`0000000goo1@000Woo0P000goo100000=oo`0000000Woo00<007ooOol0
17oo00<007ooOol00Woo0`000Woo00<007ooOol00Woo0`000Woo0P001Goo0`000Woo1@000Woo0`00
17oo1@001Woo0P000Woo0P0027oo1@001goo0P0000=oo`0000001`001Goo2P0017oo0`000goo0P00
1Goo0P000Woo0`002Woo000:Ool70005Ool60002Ool20005Ool:0002Ool20006Ool;0003Ool50002
Ool00`00Oomoo`04Ool30008Ool20002Ool700000goo00000002Ool00`00Oomoo`04Ool50003Ool7
0002Ool30002Ool50003Ool900000goo00000007Ool200000goo00000007Ool200000goo00000003
0004Ool30007Ool200000goo00000002Ool70006Ool40007Ool00`00Oomoo`050002Ool20005Ool0
0`00Oomoo`03Ool60003Ool700000goo00000002Ool:0003Ool70002Ool200000goo00000003Ool2
0009Ool00`00Oomoo`02Ool00`00Oomoo`05Ool400000goo000000050005Ool2000:Ool000Yoo`03
001oogoo009oo`D0009oo`03001oogoo009oo`03001oogoo00L000=oo`8000=oo`80009oo`P000Ao
o`03001oogoo009oo`D000=oo`@000Qoo`T00003Ool00000009oo`8000=oo`800003Ool00000009o
o`L000=oo`<0009oo`8000=oo`80009oo`03001oogoo00=oo`8000Moo`8000=oo`800003Ool00000
00D0009oo`800003Ool0000000L000Eoo`8000Ioo`L0009oo`800003Ool00000008000=oo`8000Yo
o`L0009oo`<000=oo`80009oo`D0009oo`H000Aoo`<0009oo`8000=oo`800003Ool00000008000=o
o`8000=oo`@00003Ool0000000Aoo`03001oogoo00800003Ool0000000800003Ool0000000L0009o
o`D000Yoo`800003Ool0000000=oo`H00003Ool0000000Yoo`002Woo00<007ooOol00Woo1@000Woo
00<007ooOol00Woo00<007ooOol01`000goo0P000goo0P000Woo200017oo00<007ooOol00Woo1@00
0goo100027oo2@0000=oo`0000000Woo0P000goo0P0000=oo`0000000Woo1`000goo0`000Woo0P00
0goo0P000Woo00<007ooOol00goo0P001goo0P000goo0P0000=oo`0000001@000Woo0P0000=oo`00
00001`001Goo0P001Woo1`000Woo0P0000=oo`0000000P000goo0P002Woo1`000Woo0`000goo0P00
0Woo1@000Woo1P0017oo0`000Woo0P000goo0P0000=oo`0000000P000goo0P000goo100000=oo`00
000017oo00<007ooOol00P0000=oo`0000000P0000=oo`0000001`000Woo1@002Woo0P0000=oo`00
00000goo1P0000=oo`0000002Woo000:Ool50003Ool20002Ool30002Ool00`00Oomoo`020003Ool4
00000goo000000030006Ool00`00Oomoo`02Ool30002Ool50003Ool400000goo0000000<Ool20003
Ool200000goo00000002Ool30002Ool200000goo000000020003Ool20007Ool00`00Oomoo`040000
0goo00000002Ool500000goo000000050002Ool30002Ool200000goo00000004Ool30005Ool20003
Ool50002Ool700000goo00000004Ool30005Ool30002Ool<0003Ool20005Ool400000goo00000002
0003Ool40003Ool20007Ool00`00Oomoo`050005Ool50007Ool200000goo000000020002Ool00`00
Oomoo`0200000goo00000005Ool20003Ool40003Ool:0002Ool30007Ool2000?Ool000Yoo`D000=o
o`80009oo`<0009oo`03001oogoo008000=oo`@00003Ool0000000<000Ioo`03001oogoo009oo`<0
009oo`D000=oo`@00003Ool0000000aoo`8000=oo`800003Ool00000009oo`<0009oo`800003Ool0
0000008000=oo`8000Moo`03001oogoo00@00003Ool00000009oo`D00003Ool0000000D0009oo`<0
009oo`800003Ool0000000Aoo`<000Eoo`8000=oo`D0009oo`L00003Ool0000000Aoo`<000Eoo`<0
009oo``000=oo`8000Eoo`@00003Ool00000008000=oo`@000=oo`8000Moo`03001oogoo00D000Eo
o`D000Moo`800003Ool000000080009oo`03001oogoo00800003Ool0000000Eoo`8000=oo`@000=o
o`X0009oo`<000Moo`8000moo`0027oo0P000goo1@001Goo0P000Woo0`001goo0`0017oo1@000Woo
0`000Woo00<007ooOol00goo0P001goo0P0000=oo`0000002P000Woo0`000Woo0`001Woo0`001Goo
0`000Woo2@001Goo0P0000=oo`0000000P000goo0`0017oo0P001Goo00<007ooOol00`001goo1@00
0Woo1@0017oo00<007ooOol00P000goo0P0000=oo`0000000P000Woo00<007ooOol01goo00<007oo
Ool00P000goo0P000goo1@002Goo0P0000=oo`0000001goo0`000Woo1`000Woo0`000goo1`0017oo
20001Goo0P000Woo00<007ooOol00P0000=oo`0000000`000Woo100000=oo`0000001goo00<007oo
Ool00Woo0P001Goo1P000Woo1@0037oo0008Ool20003Ool50005Ool20002Ool30007Ool30004Ool5
0002Ool30002Ool00`00Oomoo`03Ool20007Ool200000goo0000000:0002Ool30002Ool30006Ool3
0005Ool30002Ool90005Ool200000goo000000020003Ool30004Ool20005Ool00`00Oomoo`030007
Ool50002Ool50004Ool00`00Oomoo`020003Ool200000goo000000020002Ool00`00Oomoo`07Ool0
0`00Oomoo`020003Ool20003Ool50009Ool200000goo00000007Ool30002Ool70002Ool30003Ool7
0004Ool80005Ool20002Ool00`00Oomoo`0200000goo000000030002Ool400000goo00000007Ool0
0`00Oomoo`02Ool20005Ool60002Ool5000<Ool000Qoo`D000Aoo`H000Eoo`L0009oo`8000Ioo`80
00Eoo`80009oo`D00003Ool0000000D0009oo`<000Aoo`03001oogoo009oo`8000Eoo`03001oogoo
008000Qoo`D0009oo`8000Eoo`8000=oo`D0009oo`800003Ool0000000Moo`<0009oo`L000Eoo`P0
00Aoo`<000=oo`@0009oo`03001oogoo00D000Eoo`80009oo`P0009oo`03001oogoo00@00003Ool0
000000<000Aoo`P0009oo`<000]oo`<000=oo`8000Eoo`D000Aoo`03001oogoo00Eoo`8000=oo`D0
009oo`80009oo`<000Eoo`8000Eoo`800003Ool0000000D0009oo`<0009oo`D0009oo`03001oogoo
009oo`<000Aoo`03001oogoo00Yoo`002goo10000Woo00<007ooOol00Woo1@0000=oo`00000017oo
00<007ooOol01`0000=oo`000000100000=oo`0000000P000goo0`0017oo0P001Goo0`000Woo0`00
0Woo1@000Woo00<007ooOol02P0017oo00<007ooOol01@000Woo1@000goo0P000Woo0`002Woo1000
0goo0P0027oo0P0017oo0`000Woo00<007ooOol01Goo0P000Woo0`000goo1`001Goo0P000goo0P00
0Woo00<007ooOol00P001Goo0P001Woo0P0017oo00<007ooOol00P003Goo100000=oo`0000001@00
17oo0`000Woo1`0000=oo`0000000`0017oo0`001Goo1@000Woo1@000Woo0`0017oo00<007ooOol0
0goo10000goo10001Woo1P003Goo000;Ool40002Ool00`00Oomoo`02Ool500000goo00000004Ool0
0`00Oomoo`0700000goo0000000400000goo000000020003Ool30004Ool20005Ool30002Ool30002
Ool50002Ool00`00Oomoo`0:0004Ool00`00Oomoo`050002Ool50003Ool20002Ool3000:Ool40003
Ool20008Ool20004Ool30002Ool00`00Oomoo`05Ool20002Ool30003Ool70005Ool20003Ool20002
Ool00`00Oomoo`020005Ool20006Ool20004Ool00`00Oomoo`02000=Ool400000goo000000050004
Ool30002Ool700000goo000000030004Ool30005Ool50002Ool50002Ool30004Ool00`00Oomoo`03
Ool40003Ool40006Ool6000=Ool000eoo`80009oo`D000=oo`800003Ool000000080009oo`03001o
ogoo008000=oo`<000Aoo`800003Ool0000000Moo`<0009oo`D0009oo`03001oogoo00=oo`@000=o
o`80009oo`<000=oo`8000Aoo`<0009oo`<000=oo`@000=oo`@00003Ool00000009oo`8000eoo`@0
0003Ool0000000P000Moo`80009oo`P000Eoo`@00003Ool0000000=oo`H00003Ool0000000800003
Ool00000009oo`03001oogoo00D0009oo`L00003Ool000000080009oo`<0015oo`<000Aoo`8000Io
o`80009oo`03001oogoo009oo`<000Aoo`<0009oo`03001oogoo00Moo`8000Eoo`03001oogoo00Ao
o`<0009oo`D00003Ool0000000Moo`P000Aoo`D000Yoo`003Goo0P000Woo1@000goo0P0000=oo`00
00000P000Woo00<007ooOol00P000goo0`0017oo0P0000=oo`0000001goo0`000Woo1@000Woo00<0
07ooOol00goo10000goo0P000Woo0`000goo0P0017oo0`000Woo0`000goo10000goo100000=oo`00
00000Woo0P003Goo100000=oo`00000020001goo0P000Woo20001Goo100000=oo`0000000goo1P00
00=oo`0000000P0000=oo`0000000Woo00<007ooOol01@000Woo1`0000=oo`0000000P000Woo0`00
4Goo0`0017oo0P001Woo0P000Woo00<007ooOol00Woo0`0017oo0`000Woo00<007ooOol01goo0P00
1Goo00<007ooOol017oo0`000Woo1@0000=oo`0000001goo200017oo1@002Woo0008Ool30002Ool4
0003Ool50005Ool20002Ool30007Ool30002Ool3000:Ool40003Ool40008Ool50005Ool400000goo
000000020002Ool00`00Oomoo`03Ool400000goo00000007Ool200000goo00000002000AOol30004
Ool00`00Oomoo`02Ool700000goo00000002Ool00`00Oomoo`02Ool00`00Oomoo`07Ool30007Ool2
0005Ool200000goo00000002Ool30004Ool30003Ool20005Ool20002Ool00`00Oomoo`0COol30002
Ool700000goo00000002Ool30002Ool20006Ool20002Ool80002Ool70008Ool40003Ool200000goo
000000050002Ool20003Ool20007Ool00`00Oomoo`0:Ool000Qoo`8000Eoo`D000=oo`L000Eoo`L0
009oo`03001oogoo00Aoo`X00003Ool0000000Moo`X000Aoo`D00003Ool0000000Eoo`@000Qoo`80
0003Ool0000000D0009oo`800003Ool0000001Eoo`<0009oo`<0009oo`03001oogoo009oo`800003
Ool00000009oo`D000aoo`H0009oo`D0009oo`800003Ool00000009oo`03001oogoo00Eoo`@00003
Ool0000000<0009oo`@001Moo`80009oo`8000=oo`<000Eoo`80009oo`P000Eoo`8000Aoo`<000=o
o`8000aoo`<0009oo`800003Ool0000000Aoo`03001oogoo00<0009oo`T000eoo`0027oo0P001Goo
1@000goo1`001Goo1`000Woo00<007ooOol017oo2P0000=oo`0000001goo2P0017oo1@0000=oo`00
00001Goo100027oo0P0000=oo`0000001@000Woo0P0000=oo`0000005Goo0`000Woo0`000Woo00<0
07ooOol00Woo0P0000=oo`0000000Woo1@0037oo1P000Woo1@000Woo0P0000=oo`0000000Woo00<0
07ooOol01Goo100000=oo`0000000`000Woo10005goo0P000Woo0P000goo0`001Goo0P000Woo2000
1Goo0P0017oo0`000goo0P0037oo0`000Woo0P0000=oo`00000017oo00<007ooOol00`000Woo2@00
3Goo0008Ool70003Ool400000goo00000003Ool600000goo00000003Ool20002Ool70003Ool20003
Ool200000goo000000070003Ool20003Ool60003Ool30009Ool80002Ool200000goo00000004Ool0
0`00Oomoo`0200000goo0000000C0002Ool00`00Oomoo`03Ool20002Ool30002Ool200000goo0000
00020003Ool<0002Ool00`00Oomoo`02Ool30004Ool00`00Oomoo`0200000goo00000002Ool70000
0goo00000005Ool20005OolH00000goo000000020007Ool60006Ool00`00Oomoo`02Ool60007Ool5
000@Ool00`00Oomoo`0200000goo000000020002Ool00`00Oomoo`020005Ool00`00Oomoo`02Ool5
000:Ool000Qoo`L000=oo`@00003Ool0000000=oo`H00003Ool0000000=oo`80009oo`L000=oo`80
00=oo`800003Ool0000000L000=oo`8000=oo`H000=oo`<000Uoo`P0009oo`800003Ool0000000Ao
o`03001oogoo00800003Ool0000001<0009oo`03001oogoo00=oo`80009oo`<0009oo`800003Ool0
0000008000=oo``0009oo`03001oogoo009oo`<000Aoo`03001oogoo00800003Ool00000009oo`L0
0003Ool0000000Eoo`8000EooaP00003Ool00000008000Moo`H000Ioo`03001oogoo009oo`H000Mo
o`D0011oo`03001oogoo00800003Ool000000080009oo`03001oogoo008000Eoo`03001oogoo009o
o`D000Yoo`002goo0P001goo0P0000=oo`0000000`0017oo0P0000=oo`0000000P0000=oo`000000
0Woo00<007ooOol00Woo0`000Woo1@001Goo0P000goo100000=oo`0000000`0017oo0`000Woo0P00
37oo00<007ooOol00Woo00<007ooOol00P0000=oo`0000000P000Woo00<007ooOol00`0017oo0P00
0goo0P000goo0P000goo0P000Woo1P001Goo10001Goo0`000Woo0P000goo0P000goo10001Woo1000
0Woo00<007ooOol00P0000=oo`0000000Woo00<007ooOol00Woo0P0000=oo`0000000`000Woo1@00
0Woo0P000goo0P000goo0P000goo0P000goo0P001Goo1`000Woo00<007ooOol00Woo1@000Woo0`00
0Woo00<007ooOol00Woo200017oo3`000Woo0`001Goo0P000Woo00<007ooOol01`001goo00<007oo
Ool02Woo0008Ool200000goo000000050002Ool30004Ool50005Ool200000goo000000020007Ool3
0003Ool50002Ool400000goo00000005Ool20007Ool00`00Oomoo`0<0002Ool30002Ool30005Ool4
0005Ool30002Ool30002Ool30002Ool30002Ool20002Ool00`00Oomoo`02Ool500000goo00000009
Ool00`00Oomoo`030002Ool400000goo0000000:Ool20002Ool00`00Oomoo`0200000goo00000002
Ool30002Ool30004Ool30003Ool20002Ool30002Ool30002Ool400000goo0000000200000goo0000
00030002Ool20003Ool40006Ool20005Ool20002Ool30002Ool00`00Oomoo`02Ool20006Ool20003
Ool20004Ool00`00Oomoo`03Ool50002Ool20002Ool00`00Oomoo`020003Ool70002Ool3000:Ool0
00Qoo`800003Ool0000000D0009oo`<000Aoo`D000Eoo`800003Ool00000008000Moo`<000=oo`D0
009oo`@00003Ool0000000Eoo`8000Moo`03001oogoo00`0009oo`<0009oo`<000Eoo`@000Eoo`<0
009oo`<0009oo`<0009oo`<0009oo`80009oo`03001oogoo009oo`D00003Ool0000000Uoo`03001o
ogoo00<0009oo`@00003Ool0000000Yoo`80009oo`03001oogoo00800003Ool00000009oo`<0009o
o`<000Aoo`<000=oo`80009oo`<0009oo`<0009oo`@00003Ool0000000800003Ool0000000<0009o
o`8000=oo`@000Ioo`8000Eoo`80009oo`<0009oo`03001oogoo009oo`8000Ioo`8000=oo`8000Ao
o`03001oogoo00=oo`D0009oo`80009oo`03001oogoo008000=oo`L0009oo`<000Yoo`0027oo0`00
17oo0P001Goo1@000goo1`001Goo1`000Woo00<007ooOol01Goo0P001Goo0P0000=oo`0000000`00
0Woo1`000Woo0`000goo0P000goo0P001Goo0P000Woo00<007ooOol01goo1@000Woo00<007ooOol0
17oo00<007ooOol00P001Goo00<007ooOol00P000Woo1@000goo0P0000=oo`0000001`000Woo00<0
07ooOol00P001Goo0P0000=oo`00000020000Woo0P000Woo00<007ooOol00`001Goo0P000Woo0P00
1Woo100000=oo`0000000Woo0P001Goo00<007ooOol00P001Goo0`0017oo0`001goo1`0000=oo`00
00001@001Goo0P000Woo0`000Woo1`0000=oo`0000000P0000=oo`0000000P000Woo1P0017oo00<0
07ooOol00P000Woo00<007ooOol01@000goo0P001Goo0P002Woo0008Ool30004Ool20005Ool50003
Ool70005Ool70002Ool00`00Oomoo`05Ool20005Ool200000goo000000030002Ool70002Ool30003
Ool20003Ool20005Ool20002Ool00`00Oomoo`07Ool50002Ool00`00Oomoo`04Ool00`00Oomoo`02
0005Ool00`00Oomoo`020002Ool50003Ool200000goo000000070002Ool00`00Oomoo`020005Ool2
00000goo000000080002Ool20002Ool00`00Oomoo`030005Ool20002Ool20006Ool400000goo0000
0002Ool20005Ool00`00Oomoo`020005Ool30004Ool30007Ool700000goo000000050005Ool20002
Ool30002Ool700000goo0000000200000goo000000020002Ool60004Ool00`00Oomoo`020002Ool0
0`00Oomoo`050003Ool20005Ool2000:Ool000Yoo`<0009oo`L000=oo`<0009oo`8000=oo`D0009o
o`8000=oo`80009oo`H0009oo`D0009oo`<000Aoo`<000=oo`8000Eoo`@00003Ool0000000800003
Ool0000000@00003Ool00000009oo`X000=oo`80009oo`D0009oo`03001oogoo00D0009oo`03001o
ogoo00@000=oo`D000Eoo`8000=oo`80009oo`03001oogoo00D0009oo`<000Aoo`03001oogoo009o
o`03001oogoo00@000Eoo`D00003Ool00000008000Yoo`800003Ool00000009oo`D0009oo`03001o
ogoo00D0009oo`8000Ioo`L0009oo`8000=oo`800003Ool0000000Aoo`H000Eoo`80009oo`8000=o
o`800003Ool0000000Eoo`80009oo`03001oogoo009oo`<0009oo`03001oogoo0080009oo`<000=o
o`@00003Ool0000000D000aoo`002Woo0`000Woo1`000goo0`000Woo0P000goo1@000Woo0P000goo
0P000Woo1P000Woo1@000Woo0`0017oo0`000goo0P001Goo100000=oo`0000000P0000=oo`000000
100000=oo`0000000Woo2P000goo0P000Woo1@000Woo00<007ooOol01@000Woo00<007ooOol01000
0goo1@001Goo0P000goo0P000Woo00<007ooOol01@000Woo0`0017oo00<007ooOol00Woo00<007oo
Ool010001Goo1@0000=oo`0000000P002Woo0P0000=oo`0000000Woo1@000Woo00<007ooOol01@00
0Woo0P001Woo1`000Woo0P000goo0P0000=oo`00000017oo1P001Goo0P000Woo0P000goo0P0000=o
o`0000001Goo0P000Woo00<007ooOol00Woo0`000Woo00<007ooOol00P000Woo0`000goo100000=o
o`0000001@0037oo000;Ool40003Ool20007Ool00`00Oomoo`050004Ool00`00Oomoo`030002Ool2
0002Ool00`00Oomoo`02Ool30003Ool20002Ool20006Ool400000goo0000000400000goo00000005
Ool30004Ool200000goo000000020003Ool20003Ool400000goo000000020003Ool20002Ool30003
Ool40005Ool50003Ool50002Ool400000goo000000020005Ool00`00Oomoo`04Ool30002Ool30002
Ool00`00Oomoo`020008Ool20005Ool:0002Ool200000goo000000020003Ool20002Ool30004Ool0
0`00Oomoo`0700000goo00000004Ool00`00Oomoo`030002Ool200000goo000000020002Ool00`00
Oomoo`02Ool500000goo00000002Ool30002Ool200000goo000000030002Ool40006Ool20002Ool0
0`00Oomoo`020002Ool00`00Oomoo`05Ool30004Ool2000=Ool000eoo`@00003Ool0000000D0009o
o`<000Aoo`D000Eoo`03001oogoo00@000Ioo`@00003Ool00000008000Yoo`<000Aoo`<000Uoo`D0
00Eoo`<0009oo`<0009oo`8000Eoo`<0009oo`80009oo`03001oogoo00Eoo`L000=oo`D000Aoo`03
001oogoo008000Eoo`D0009oo`D0009oo`03001oogoo00=oo`80009oo`03001oogoo00T00003Ool0
000000D000Aoo`03001oogoo009oo`<000Eoo`D000Eoo`@0009oo`03001oogoo008000=oo`800003
Ool0000000@000Eoo`<000Eoo`80009oo`D000=oo`<000Ioo`<000Eoo`8000Eoo`L00003Ool00000
009oo`03001oogoo00@000Yoo`D000moo`003Goo100000=oo`0000001@000Woo0`0017oo1@001Goo
00<007ooOol010001Woo100000=oo`0000000P002Woo0`0017oo0`002Goo1@001Goo0`000Woo0`00
0Woo0P001Goo0`000Woo0P000Woo00<007ooOol01Goo1`000goo1@0017oo00<007ooOol00P001Goo
1@000Woo1@000Woo00<007ooOol00goo0P000Woo00<007ooOol02@0000=oo`0000001@0017oo00<0
07ooOol00Woo0`001Goo1@001Goo10000Woo00<007ooOol00P000goo0P0000=oo`00000010001Goo
0`001Goo0P000Woo1@000goo0`001Woo0`001Goo0P001Goo1`0000=oo`0000000Woo00<007ooOol0
10002Woo1@003goo000?Ool30004Ool00`00Oomoo`03Ool60003Ool70005Ool700000goo00000005
Ool:0002Ool20007Ool:0003Ool50002Ool20005Ool30009Ool00`00Oomoo`020002Ool60002Ool2
0003Ool50004Ool30002Ool00`00Oomoo`070003Ool40003Ool20002Ool500000goo000000020005
Ool20003Ool200000goo00000003Ool40002Ool30002Ool00`00Oomoo`07Ool20008Ool20002Ool0
0`00Oomoo`050005Ool20008Ool50002Ool40003Ool30002Ool20008Ool50002Ool50002Ool20003
Ool200000goo00000002Ool00`00Oomoo`02000=Ool2000AOol000moo`<000Aoo`03001oogoo00=o
o`H000=oo`L000Eoo`L00003Ool0000000Eoo`X0009oo`8000Moo`X000=oo`D0009oo`8000Eoo`<0
00Uoo`03001oogoo0080009oo`H0009oo`8000=oo`D000Aoo`<0009oo`03001oogoo00L000=oo`@0
00=oo`80009oo`D00003Ool00000008000Eoo`8000=oo`800003Ool0000000=oo`@0009oo`<0009o
o`03001oogoo00Moo`8000Qoo`80009oo`03001oogoo00D000Eoo`8000Qoo`D0009oo`@000=oo`<0
009oo`8000Qoo`D0009oo`D0009oo`8000=oo`800003Ool00000009oo`03001oogoo008000eoo`80
015oo`004Goo0`000Woo1P0017oo0`000Woo0P000goo1@000Woo0P000goo0P0000=oo`0000001@00
17oo00<007ooOol00Woo00<007ooOol02@000goo0P000goo1@0017oo0`0027oo2@000Woo00<007oo
Ool00P000Woo00<007ooOol00Woo0`001goo0P001Woo0P000Woo0`0017oo00<007ooOol01Goo1@00
1Goo0P001Goo1@000Woo0`000Woo0P0000=oo`0000000P0000=oo`0000001Goo0P000Woo20000Woo
20000Woo0P000Woo0`000goo1@000Woo2P0017oo00<007ooOol00P001goo00<007ooOol02P0017oo
0`000goo0P000Woo0`000Woo0P0000=oo`0000000Woo00<007ooOol03`004goo000BOol40003Ool2
0007Ool00`00Oomoo`050003Ool20002Ool30002Ool200000goo00000003Ool40002Ool50005Ool0
0`00Oomoo`02Ool30002Ool50003Ool40002Ool00`00Oomoo`0:Ool20003Ool20002Ool00`00Oomo
o`040006Ool70002Ool80005Ool40002Ool80003Ool70009Ool00`00Oomoo`04Ool30005Ool20000
0goo0000000400000goo00000002Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool3
0005Ool50004Ool30004Ool00`00Oomoo`02Ool30002Ool00`00Oomoo`090005Ool00`00Oomoo`02
Ool20006Ool50006Ool00`00Oomoo`0200000goo000000020005Ool20003Ool20003Ool2000DOol0
019oo`@000=oo`8000Moo`03001oogoo00D000=oo`80009oo`<0009oo`800003Ool0000000=oo`@0
009oo`D000Eoo`03001oogoo009oo`<0009oo`D000=oo`@0009oo`03001oogoo00Yoo`8000=oo`80
009oo`03001oogoo00@000Ioo`L0009oo`P000Eoo`@0009oo`P000=oo`L000Uoo`03001oogoo00Ao
o`<000Eoo`800003Ool0000000@00003Ool00000009oo`03001oogoo009oo`03001oogoo00Aoo`03
001oogoo009oo`<000Eoo`D000Aoo`<000Aoo`03001oogoo009oo`<0009oo`03001oogoo00T000Eo
o`03001oogoo009oo`8000Ioo`D000Ioo`03001oogoo00800003Ool00000008000Eoo`8000=oo`80
00=oo`8001Aoo`0057oo0`000Woo1`000Woo0`000goo1@001Woo00<007ooOol00`001goo10000goo
1@000Woo0`000Woo0P001Goo00<007ooOol01Goo0P000Woo2`000Woo100000=oo`0000000P001Goo
200017oo00<007ooOol017oo00<007ooOol00Woo1@0000=oo`0000001Goo0P000goo100000=oo`00
000017oo2P0027oo1@000Woo0`0017oo0P0000=oo`0000000Woo0`000Woo1@000Woo0`000Woo00<0
07ooOol01goo0P001Woo1P001Woo10001Goo0P000goo1@000Woo0`000Woo200017oo1@000Woo0`00
1Goo1@000Woo0`000Woo1@005Woo000DOol30002Ool70002Ool30003Ool50006Ool00`00Oomoo`03
0007Ool40003Ool50002Ool30002Ool20005Ool00`00Oomoo`05Ool20002Ool;0002Ool400000goo
000000020005Ool80004Ool00`00Oomoo`04Ool00`00Oomoo`02Ool500000goo00000005Ool20003
Ool400000goo00000004Ool:0008Ool50002Ool30004Ool200000goo00000002Ool30002Ool50002
Ool30002Ool00`00Oomoo`07Ool20006Ool60006Ool40005Ool20003Ool50002Ool30002Ool80004
Ool50002Ool30005Ool50002Ool30002Ool5000FOol001Ioo`<000=oo`8000Eoo`D000Aoo`L000Eo
o`H0009oo`8000Moo`03001oogoo00=oo`80009oo`D0009oo`H0009oo`@000=oo`8000=oo`8000Eo
o`800003Ool0000000Uoo`03001oogoo009oo`<0009oo`D0009oo`D000=oo`800003Ool0000000D0
00Moo`<000Moo`8000=oo`8000aoo`8000Eoo`<0009oo`800003Ool00000009oo`03001oogoo00=o
o`8000Eoo`80009oo`X000Yoo`8000Yoo`L000Moo`03001oogoo00=oo`80009oo`8000=oo`8000Io
o`8000Eoo`L000=oo`80009oo`8000Eoo`03001oogoo01Ioo`005goo100000=oo`0000001@0017oo
0`000Woo00<007ooOol00Woo1@000Woo00<007ooOol00Woo00<007ooOol01`000Woo1@0000=oo`00
00000P000goo10000goo0P001Goo0`000Woo0`000Woo1@000Woo0P0000=oo`0000002@001Woo1000
0goo10000goo0`000Woo0`0017oo0P002Woo1`0000=oo`0000000P0000=oo`000000300027oo0P00
0Woo0P0000=oo`0000000Woo1@0000=oo`000000100000=oo`0000000P000goo0P000goo2P000Woo
2P000Woo0P000goo1`000Woo1@0000=oo`0000000Woo0`000Woo1`0000=oo`000000100000=oo`00
00000goo100000=oo`0000000Woo1`006Goo000GOol400000goo000000050004Ool30002Ool00`00
Oomoo`02Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`070002Ool500000goo000000020003Ool4
0003Ool20005Ool30002Ool30002Ool50002Ool200000goo000000090006Ool40003Ool40003Ool3
0002Ool30004Ool2000:Ool700000goo0000000200000goo0000000<0008Ool20002Ool200000goo
00000002Ool500000goo0000000400000goo000000020003Ool20003Ool:0002Ool:0002Ool20003
Ool70002Ool500000goo00000002Ool30002Ool700000goo0000000400000goo00000003Ool40000
0goo00000002Ool7000IOol001Uoo`<000Aoo`8000Ioo`80009oo`D000=oo`80009oo`<0009oo`03
001oogoo008000=oo`@000=oo`800003Ool0000000Moo`<0009oo`D0009oo`8000Eoo`<000=oo`80
009oo`<000Aoo`03001oogoo009oo`L00003Ool0000000Moo`<0009oo`8000Eoo`<0009oo`X0009o
o`03001oogoo009oo`800003Ool0000000Eoo`8000=oo`8000=oo`T00003Ool00000009oo`<000Eo
o`8000Eoo`8000Eoo`<0009oo`D000Aoo`03001oogoo009oo`<000Aoo`03001oogoo009oo`03001o
ogoo00<0009oo`8000=oo`@000=oo`<000Ioo`03001oogoo008000=oo`<000Aoo`<000Moo`800003
Ool00000008000=oo`8001]oo`006Goo0`0017oo0P001Woo0P000Woo1@000goo0P000Woo0`000Woo
00<007ooOol00P000goo10000goo0P0000=oo`0000001goo0`000Woo1@000Woo0P001Goo0`000goo
0P000Woo0`0017oo00<007ooOol00Woo1`0000=oo`0000001goo0`000Woo0P001Goo0`000Woo2P00
0Woo00<007ooOol00Woo0P0000=oo`0000001Goo0P000goo0P000goo2@0000=oo`0000000Woo0`00
1Goo0P001Goo0P001Goo0`000Woo1@0017oo00<007ooOol00Woo0`0017oo00<007ooOol00Woo00<0
07ooOol00`000Woo0P000goo10000goo0`001Woo00<007ooOol00P000goo0`0017oo0`001goo0P00
00=oo`0000000P000goo0P006goo000KOol30002Ool700000goo000000020003Ool50005Ool20002
Ool30007Ool30002Ool3000;Ool30003Ool40008Ool50006Ool30002Ool30002Ool20003Ool3000;
Ool30008Ool40003Ool20003Ool20002Ool30002Ool200000goo000000030002Ool50007Ool20003
Ool30006Ool500000goo000000050009Ool30004Ool50006Ool40002Ool50005Ool00`00Oomoo`04
00000goo00000007Ool50002Ool00`00Oomoo`030002Ool20007Ool80005Ool5000MOol001]oo`<0
009oo`L00003Ool00000008000=oo`D000Eoo`80009oo`<000Moo`<0009oo`<000]oo`<000=oo`@0
00Qoo`D000Ioo`<0009oo`<0009oo`8000=oo`<000]oo`<000Qoo`@000=oo`8000=oo`80009oo`<0
009oo`800003Ool0000000<0009oo`D000Moo`8000=oo`<000Ioo`D00003Ool0000000D000Uoo`<0
00Aoo`D000Ioo`@0009oo`D000Eoo`03001oogoo00@00003Ool0000000Moo`D0009oo`03001oogoo
00<0009oo`8000Moo`P000Eoo`D001eoo`0077oo10000goo0P001Goo1@0017oo1P001Goo1`000Woo
0P001Goo2P000Woo00<007ooOol01Goo2P0017oo1@000Woo00<007ooOol00goo10001goo2P000Woo
00<007ooOol02Woo100000=oo`0000000`001Goo0P000Woo0`0017oo0`000goo2@001goo1`000goo
0P0000=oo`0000000goo2@000Woo00<007ooOol01Goo0P002Woo10000goo1`001Goo0P0000=oo`00
00001`000goo10001Goo00<007ooOol01`000Woo00<007ooOol00Woo00<007ooOol01goo0P007Woo
000NOol400000goo000000050003Ool40002Ool00`00Oomoo`02Ool500000goo00000004Ool00`00
Oomoo`070003Ool20003Ool20002Ool80004Ool00`00Oomoo`02Ool50003Ool40008Ool90003Ool2
0003Ool4000?Ool30004Ool60006Ool30002Ool00`00Oomoo`05Ool20003Ool70002Ool00`00Oomo
o`02Ool30002Ool30007Ool20003Ool20002Ool8000>Ool30002Ool20003Ool50002Ool200000goo
00000003Ool20007Ool50002Ool00`00Oomoo`020003Ool20002Ool30002Ool:000POol001ioo`@0
0003Ool0000000D000=oo`@0009oo`03001oogoo009oo`D00003Ool0000000Aoo`03001oogoo00L0
00=oo`8000=oo`80009oo`P000Aoo`03001oogoo009oo`D000=oo`@000Qoo`T000=oo`8000=oo`@0
00moo`<000Aoo`H000Ioo`<0009oo`03001oogoo00Eoo`8000=oo`L0009oo`03001oogoo009oo`<0
009oo`<000Moo`8000=oo`80009oo`P000ioo`<0009oo`8000=oo`D0009oo`800003Ool0000000=o
o`8000Moo`D0009oo`03001oogoo008000=oo`80009oo`<0009oo`X0021oo`0087oo0`0017oo00<0
07ooOol01Goo0P000Woo1@000goo0P0000=oo`0000000P000Woo00<007ooOol00P000goo0`000Woo
1@001Goo0P000goo10000Woo1@000goo0`000Woo0P0037oo0P000goo0`000Woo0`000Woo0P004goo
1@000goo0P0027oo0P000Woo1P000Woo100000=oo`0000000goo0P000Woo0`000Woo0P001Goo1P00
0Woo100000=oo`0000000Woo00<007ooOol00Woo0P004Goo00<007ooOol01@000goo0P000Woo0P00
00=oo`0000000P0000=oo`0000001`000goo0P000Woo00<007ooOol00`000Woo0P000Woo00<007oo
Ool00goo0P000goo0P008Woo000POol30004Ool00`00Oomoo`05Ool20002Ool50003Ool200000goo
000000020002Ool00`00Oomoo`020003Ool30002Ool50005Ool20003Ool40002Ool50003Ool30002
Ool2000<Ool20003Ool30002Ool30002Ool2000COol50003Ool20008Ool20002Ool60002Ool40000
0goo00000003Ool20002Ool30002Ool20005Ool60002Ool400000goo00000002Ool00`00Oomoo`02
Ool2000AOol00`00Oomoo`050003Ool20002Ool200000goo0000000200000goo000000070003Ool2
0002Ool00`00Oomoo`030002Ool20002Ool00`00Oomoo`03Ool20003Ool2000ROol0029oo`<0009o
o`H0009oo`@000=oo`D000Eoo`80009oo`<000Moo`<000Aoo`D00003Ool0000000800003Ool00000
00Eoo`8000Moo`03001oogoo00`0009oo`<0009oo`8000Eoo`03001oogoo01D000=oo`<0009oo`T0
0003Ool00000008000=oo`8000Eoo`800003Ool0000000<000Eoo`80009oo`L000=oo`8000Eoo`80
0003Ool00000009oo`<0009ooa40009oo`<000=oo`@00003Ool00000009oo`800003Ool0000000Eo
o`8000=oo`@00003Ool00000008000Eoo`03001oogoo0080009oo`D00003Ool0000000<002Aoo`00
8goo10000goo0P001Goo1@000goo1`001Goo1`000Woo00<007ooOol01Goo0P001Goo0P0000=oo`00
0000100000=oo`0000001@000Woo0`0017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
1`001Goo0P000goo0P000goo0P000goo0P001goo00<007ooOol00P000goo0P001Goo0`000Woo1@00
0Woo0`0017oo1@0000=oo`0000000Woo0P000goo0`000Woo1@000Woo0`001Goo0P000Woo0P000goo
0P000goo0P000goo0P000Woo00<007ooOol01Goo0P0000=oo`0000000Woo0P0000=oo`0000000`00
0Woo0`000Woo0P001Goo1@000Woo0`001Goo0P001Goo0P009Goo000SOol40003Ool20005Ool50003
Ool70005Ool70002Ool00`00Oomoo`05Ool20005Ool200000goo0000000400000goo000000050002
Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`070005Ool20003Ool20003Ool2
0003Ool20007Ool00`00Oomoo`020003Ool20005Ool30002Ool50002Ool30004Ool500000goo0000
0002Ool20003Ool30002Ool50002Ool30005Ool20002Ool20003Ool20003Ool20003Ool20002Ool0
0`00Oomoo`05Ool200000goo00000002Ool200000goo000000030002Ool30002Ool20005Ool50002
Ool30005Ool20005Ool2000UOol002Eoo`<0009oo`L000=oo`@00003Ool0000000=oo`H00003Ool0
000000=oo`80009oo`L00003Ool0000000<0009oo`<000Aoo`<000Aoo`03001oogoo00=oo`@0009o
o`<0009oo`D0009oo`03001oogoo008000=oo`D0009oo`<0009oo`<0009oo`<0009oo`L0009oo`03
001oogoo00<0009oo`D0009oo`8000Eoo`03001oogoo00Aoo`D000=oo`800003Ool00000009oo`<0
009oo`8000Eoo`03001oogoo00Aoo`D00003Ool00000009oo`<0009oo`<0009oo`<0009oo`80009o
o`H0009oo`800003Ool00000008000Eoo`8000Eoo`<000Uoo`03001oogoo00=oo`H00003Ool00000
00D002Moo`009Goo0`000Woo1`000goo100000=oo`0000000goo1P0000=oo`0000000goo0P000Woo
1`0000=oo`0000000`000Woo0`0017oo0`0017oo00<007ooOol00goo10000Woo0`000Woo1@000Woo
00<007ooOol00P000goo1@000Woo0`000Woo0`000Woo0`000Woo1`000Woo00<007ooOol00`000Woo
1@000Woo0P001Goo00<007ooOol017oo1@000goo0P0000=oo`0000000Woo0`000Woo0P001Goo00<0
07ooOol017oo1@0000=oo`0000000Woo0`000Woo0`000Woo0`000Woo0P000Woo1P000Woo0P0000=o
o`0000000P001Goo0P001Goo0`002Goo00<007ooOol00goo1P0000=oo`0000001@009goo000WOol3
0003Ool20007Ool200000goo000000030004Ool200000goo0000000200000goo00000002Ool00`00
Oomoo`02Ool30004Ool00`00Oomoo`020007Ool30002Ool500000goo00000005Ool40003Ool20002
Ool30007Ool00`00Oomoo`04Ool00`00Oomoo`020005Ool00`00Oomoo`020003Ool40005Ool30004
Ool00`00Oomoo`050002Ool70003Ool30002Ool30006Ool00`00Oomoo`050002Ool70003Ool30006
Ool00`00Oomoo`020005Ool00`00Oomoo`020002Ool00`00Oomoo`02Ool30005Ool70008Ool90002
Ool60004Ool30004Ool00`00Oomoo`0WOol002Qoo`@00003Ool0000000D0009oo`<000Aoo`D000Eo
o`800003Ool00000008000Moo`<0009oo`<000Yoo`@000=oo`<000Uoo`D000Eoo`L0009oo`D0009o
o`03001oogoo00D0009oo`03001oogoo00@00003Ool0000000Qoo`@0009oo`<000=oo`80009oo`03
001oogoo009oo`<0009oo`8000Eoo`D0009oo`<000=oo`@000=oo`8000Moo`D0009oo`03001oogoo
00D0009oo`03001oogoo00@000Ioo`L000Aoo`03001oogoo00Yoo`8000=oo`@000=oo`8000Moo`D0
02Yoo`00:7oo100000=oo`0000001@000Woo0`0017oo1@001Goo0P0000=oo`0000000P001goo0`00
0Woo0`002Woo10000goo0`002Goo1@001Goo1`000Woo1@000Woo00<007ooOol01@000Woo00<007oo
Ool0100000=oo`00000027oo10000Woo0`000goo0P000Woo00<007ooOol00Woo0`000Woo0P001Goo
1@000Woo0`000goo10000goo0P001goo1@000Woo00<007ooOol01@000Woo00<007ooOol010001Woo
1`0017oo00<007ooOol02Woo0P000goo10000goo0P001goo1@00:Woo000ZOol30004Ool20005Ool5
0003Ool70005Ool70002Ool00`00Oomoo`03Ool;00000goo00000007Ool:0003Ool600000goo0000
0003Ool40003Ool20002Ool30003Ool40005Ool200000goo0000000700000goo00000005Ool40000
0goo000000020007Ool00`00Oomoo`070003Ool20002Ool00`00Oomoo`05Ool30002Ool90003Ool2
0002Ool30003Ool40005Ool700000goo00000003Ool40002Ool=0007Ool5000:Ool2000/Ool002Yo
o`<000Aoo`8000Eoo`D000=oo`L000Eoo`L0009oo`03001oogoo00=oo`/00003Ool0000000Moo`X0
00=oo`H00003Ool0000000=oo`@000=oo`80009oo`<000=oo`@000Eoo`800003Ool0000000L00003
Ool0000000Eoo`@00003Ool00000008000Moo`03001oogoo00L000=oo`80009oo`03001oogoo00Eo
o`<0009oo`T000=oo`80009oo`<000=oo`@000Eoo`L00003Ool0000000=oo`@0009oo`d000Moo`D0
00Yoo`8002aoo`00;7oo0`000Woo1`000goo0`000Woo0P000goo1@000Woo0P000goo0P000Woo1P00
17oo00<007ooOol00Woo0P0000=oo`0000001`000goo0P000goo1@0017oo0`001goo0`000Woo0P00
0Woo00<007ooOol01Goo1`001Goo0P000goo0P0000=oo`000000100000=oo`0000001Goo1`000Woo
00<007ooOol00P000goo0`000Woo0P000Woo1P000Woo0P001Goo0P000goo0`000Woo0P000Woo00<0
07ooOol01Goo1@000Woo0P000goo0P0000=oo`0000000P0000=oo`0000001Goo0P000goo0P000goo
2@000goo3000;Woo000/Ool30002Ool70003Ool30002Ool20003Ool50002Ool20003Ool20002Ool6
0004Ool00`00Oomoo`02Ool200000goo000000070003Ool20003Ool50004Ool30007Ool30002Ool2
0002Ool00`00Oomoo`05Ool70005Ool20003Ool200000goo0000000400000goo00000005Ool70002
Ool00`00Oomoo`020003Ool30002Ool20002Ool60002Ool20005Ool20003Ool30002Ool20002Ool0
0`00Oomoo`05Ool50002Ool20003Ool200000goo0000000200000goo00000005Ool20003Ool20003
Ool90003Ool<000^Ool002eoo`@000=oo`8000Moo`03001oogoo00D000Aoo`03001oogoo00<0009o
o`80009oo`03001oogoo009oo`<0009oo`D000Eoo`8000=oo`<0009oo`D000Aoo`<0009oo`8000Yo
o`03001oogoo0080009oo`H0009oo`8000=oo`D0009oo`<0009oo`<000Aoo`800003Ool0000000<0
009oo`8000=oo`80009oo`<000Moo`03001oogoo0080009oo`03001oogoo009oo`03001oogoo00L0
00Moo`03001oogoo0080009oo`P000=oo`80009oo`D000Eoo`800003Ool0000000@00003Ool00000
00<000Moo`8000=oo`D000Aoo`03001oogoo009oo`8002moo`00;goo100000=oo`0000001@000Woo
0`0017oo1@001Goo00<007ooOol010001Woo10000goo1@000Woo0`000Woo0P001Goo0P001Woo0P00
0Woo2P000Woo00<007ooOol00P000Woo00<007ooOol00Woo00<007ooOol01@0017oo00<007ooOol0
0P001Goo0`000Woo0`0017oo00<007ooOol01@001Goo1`000Woo00<007ooOol00P000Woo0`000Woo
00<007ooOol00P000goo1`000Woo0`001Goo0P000goo100000=oo`0000000P000goo1@000Woo0`00
17oo0`0017oo1P000Woo1@0017oo0`000Woo1@00<Goo000_Ool400000goo000000050002Ool30004
Ool50005Ool00`00Oomoo`040006Ool40003Ool50002Ool30002Ool20005Ool20006Ool20002Ool:
0002Ool00`00Oomoo`020002Ool00`00Oomoo`02Ool00`00Oomoo`050004Ool00`00Oomoo`020005
Ool30002Ool30004Ool00`00Oomoo`050005Ool70002Ool00`00Oomoo`020002Ool30002Ool00`00
Oomoo`020003Ool70002Ool30005Ool20003Ool400000goo000000020003Ool50002Ool30004Ool3
0004Ool60002Ool50004Ool30002Ool5000aOol0035oo`<000Aoo`03001oogoo00=oo`H000=oo`L0
00Eoo`L00003Ool0000000Moo`8000Eoo`03001oogoo00D0009oo`L00003Ool00000008000=oo`80
00=oo`80009oo`03001oogoo0080009oo`<0009oo`<000=oo`@0009oo`03001oogoo00D0009oo`03
001oogoo00Aoo`<0009oo`<000=oo`H00003Ool0000000=oo`80009oo`<000Eoo`80009oo`03001o
ogoo00D000Aoo`03001oogoo00=oo`H00003Ool0000000800003Ool0000000Eoo`D000Aoo`03001o
ogoo008000Moo`<0009oo`03001oogoo009oo`<000Aoo`<0009oo`03001oogoo00=oo`8003=oo`00
<Goo0`0017oo00<007ooOol00goo1P000goo1`001Goo1`0000=oo`0000001goo0P001Goo00<007oo
Ool01@000Woo1`0000=oo`0000000P000goo0P000goo0P000Woo00<007ooOol00P000Woo0`000Woo
0`000goo10000Woo00<007ooOol01@000Woo00<007ooOol017oo0`000Woo0`000goo1P0000=oo`00
00000goo0P000Woo0`001Goo0P000Woo00<007ooOol01@0017oo00<007ooOol00goo1P0000=oo`00
00000P0000=oo`0000001Goo1@0017oo00<007ooOol00P001goo0`000Woo00<007ooOol00Woo0`00
17oo0`000Woo00<007ooOol00goo0P00<goo000cOol30002Ool60004Ool30002Ool20003Ool50002
Ool20003Ool200000goo000000050002Ool50002Ool30003Ool40003Ool20005Ool400000goo0000
000200000goo00000002Ool30005Ool20002Ool00`00Oomoo`05Ool20002Ool30003Ool20002Ool5
0002Ool00`00Oomoo`03Ool50004Ool200000goo000000030005Ool600000goo00000002Ool30003
Ool60008Ool20005Ool200000goo000000050004Ool30002Ool3000:Ool20002Ool30002Ool00`00
Oomoo`05Ool20002Ool6000eOol003Aoo`@000=oo`8000Moo`03001oogoo00D000=oo`80009oo`<0
009oo`800003Ool0000000=oo`@000=oo`80009oo`03001oogoo00Eoo`@00003Ool0000000<0009o
o`8000Eoo`<000Eoo`H00003Ool00000009oo`P000Eoo`@00003Ool00000008000=oo`80009oo`H0
00Aoo`<0009oo`<000Aoo`H000Aoo`<000Eoo`D000Aoo`P0009oo`D0009oo`800003Ool0000000=o
o`@0009oo`03001oogoo00=oo``000Eoo`80009oo`L00003Ool00000008000=oo`8003Ioo`00=7oo
10000goo0P001goo00<007ooOol01@000goo0P000Woo0`000Woo0P0000=oo`0000000goo10000goo
0P000Woo00<007ooOol01Goo100000=oo`0000000`000Woo0P001Goo0`001Goo1P0000=oo`000000
0Woo20001Goo100000=oo`0000000P000goo0P000Woo1P0017oo0`000Woo0`0017oo1P0017oo0`00
1Goo1@0017oo20000Woo1@000Woo0P0000=oo`0000000goo10000Woo00<007ooOol00goo30001Goo
0P000Woo1`0000=oo`0000000P000goo0P00=Woo000fOol30002Ool70002Ool30003Ool50006Ool0
0`00Oomoo`030007Ool400000goo00000002000:Ool30004Ool30009Ool60004Ool30005Ool20003
Ool600000goo00000005Ool30002Ool20002Ool00`00Oomoo`02Ool30002Ool00`00Oomoo`04Ool3
0002Ool00`00Oomoo`02Ool30002Ool20008Ool20007Ool00`00Oomoo`02Ool30004Ool00`00Oomo
o`030007Ool20002Ool500000goo00000003Ool20004Ool500000goo000000020003Ool20005Ool5
000hOol003Ioo`<0009oo`L0009oo`<000=oo`D000Ioo`03001oogoo00<000Moo`@00003Ool00000
008000Yoo`<000Aoo`<000Uoo`H000Aoo`<000Eoo`8000=oo`H00003Ool0000000Eoo`<0009oo`80
009oo`03001oogoo009oo`<0009oo`03001oogoo00Aoo`<0009oo`03001oogoo009oo`<0009oo`80
00Qoo`8000Moo`03001oogoo009oo`<000Aoo`03001oogoo00<000Moo`80009oo`D00003Ool00000
00=oo`8000Aoo`D00003Ool00000008000=oo`8000Eoo`D003Qoo`00>7oo0`000goo0P001Goo1@00
17oo1`001Goo1P000Woo0P001Goo2P000Woo0P001Woo2`000goo0P001goo1@0000=oo`0000000`00
17oo0`002Goo00<007ooOol010001Woo100027oo10001Woo0P000Woo20000Woo2@001Woo1P001Goo
1P000Woo10000goo0P0000=oo`0000000`001goo0P001Goo1@002Goo00<007ooOol0>7oo000iOol4
00000goo000000050004Ool30002Ool00`00Oomoo`02Ool50002Ool00`00Oomoo`02Ool00`00Oomo
o`070003Ool20003Ool20002Ool80004Ool20003Ool5000:Ool20005Ool20007Ool:0005Ool70000
0goo0000000<Ool700000goo00000002Ool20003Ool20005Ool00`00Oomoo`02Ool80004Ool70003
Ool20005Ool30002Ool30004Ool700000goo000000050003Ool;000kOol003Uoo`@00003Ool00000
00D000Aoo`<0009oo`03001oogoo009oo`D0009oo`03001oogoo009oo`03001oogoo00L000=oo`80
00=oo`80009oo`P000Aoo`8000=oo`D000Yoo`8000Eoo`8000Moo`X000Eoo`L00003Ool0000000ao
o`L00003Ool00000009oo`8000=oo`8000Eoo`03001oogoo009oo`P000Aoo`L000=oo`8000Eoo`<0
009oo`<000Aoo`L00003Ool0000000D000=oo`/003]oo`00>goo0`0017oo0P001Woo0P000Woo1@00
0goo0P000Woo0`000Woo00<007ooOol00P000goo100000=oo`0000000`001Woo00<007ooOol00Woo
0`000Woo1@000goo2`0000=oo`0000000`000Woo2@000goo0P000goo1@000Woo0P000goo0P0000=o
o`0000002P000Woo0P000goo0P0000=oo`0000000Woo0`000Woo1`001goo00<007ooOol00Woo0`00
0Woo0P000goo0`000Woo1@000Woo0P001Goo0`000Woo00<007ooOol00Woo0`0017oo00<007ooOol0
1Goo0P000goo0P00?Goo000kOol30004Ool20006Ool20002Ool50003Ool20002Ool30002Ool00`00
Oomoo`020003Ool400000goo000000030006Ool00`00Oomoo`02Ool30002Ool50003Ool;00000goo
000000030002Ool90003Ool20003Ool50002Ool20003Ool200000goo0000000:0002Ool20003Ool2
00000goo00000002Ool30002Ool70007Ool00`00Oomoo`02Ool30002Ool20003Ool30002Ool50002
Ool20005Ool30002Ool00`00Oomoo`02Ool30004Ool00`00Oomoo`05Ool20003Ool2000mOol003eo
o`<0009oo`L00003Ool00000008000=oo`D000Eoo`80009oo`<000Moo`<000Aoo`D0009oo`<0009o
o`03001oogoo00Aoo`03001oogoo00Eoo`8000=oo`8000Eoo`8000Eoo`03001oogoo009oo`<0009o
o`D000=oo`80009oo`<0009oo`800003Ool0000000=oo`8000Aoo`03001oogoo00<0009oo`<000Io
o`03001oogoo008000=oo`T000Ioo`@000Moo`<000=oo`@000Qoo`@000Moo`<0009oo`H0009oo`D0
03moo`00?Goo0`000Woo1`0000=oo`0000000P000goo1@001Goo0P000Woo0`001goo0`0017oo1@00
0Woo0`000Woo00<007ooOol017oo00<007ooOol01Goo0P000goo0P001Goo0P001Goo00<007ooOol0
0Woo0`000Woo1@000goo0P000Woo0`000Woo0P0000=oo`0000000goo0P0017oo00<007ooOol00`00
0Woo0`001Woo00<007ooOol00P000goo2@001Woo10001goo0`000goo100027oo10001goo0`000Woo
1P000Woo1@00?goo000nOol40003Ool20005Ool50004Ool60005Ool70002Ool20006Ool20005Ool2
0002Ool50002Ool60002Ool30002Ool50002Ool70007Ool30003Ool50006Ool00`00Oomoo`020000
0goo0000000200000goo000000020002Ool00`00Oomoo`020005Ool50002Ool00`00Oomoo`030002
Ool20003Ool2000:Ool70002Ool00`00Oomoo`05Ool900000goo0000000:Ool40003Ool20005Ool2
0010Ool0041oo`@00003Ool0000000D000=oo`@0009oo`03001oogoo009oo`D00003Ool0000000Ao
o`03001oogoo00L00003Ool0000000@00003Ool00000008000=oo`@000=oo`8000Eoo`<000Aoo`<0
00=oo`8000Yoo`D000Aoo`D0009oo`03001oogoo00800003Ool0000000Eoo`80009oo`03001oogoo
00L000=oo`@000Eoo`03001oogoo00<0009oo`X0009oo`8000=oo`@000Yoo`8000=oo`<000ioo`<0
009oo`L0049oo`00@7oo100000=oo`0000001@000goo10000Woo00<007ooOol00Woo1@0000=oo`00
000017oo00<007ooOol01`0000=oo`000000100000=oo`0000000P000goo10000goo0P001Goo0`00
17oo0`000goo0P002Woo1@0017oo1@000Woo00<007ooOol00P0000=oo`0000001Goo0P000Woo00<0
07ooOol01`000goo10001Goo00<007ooOol00`000Woo2P000Woo0P000goo10002Woo0P000goo0`00
3Woo0`000Woo1`00@Woo0012Ool30004Ool00`00Oomoo`05Ool20002Ool50003Ool200000goo0000
00020002Ool00`00Oomoo`020003Ool30004Ool200000goo00000007Ool30002Ool50002Ool00`00
Oomoo`05Ool400000goo0000000:0004Ool50003Ool20002Ool00`00Oomoo`0200000goo00000003
0002Ool20002Ool30003Ool20007Ool70005Ool30004Ool00`00Oomoo`02Ool30007Ool:0002Ool3
0002Ool2000AOol30003Ool20014Ool0049oo`<000Aoo`03001oogoo00Eoo`80009oo`D000=oo`80
0003Ool000000080009oo`03001oogoo008000=oo`<000Aoo`800003Ool0000000Moo`<0009oo`D0
009oo`03001oogoo00Eoo`@00003Ool0000000X000Aoo`D000=oo`80009oo`03001oogoo00800003
Ool0000000<0009oo`80009oo`<000=oo`8000Moo`L000Eoo`<000Aoo`03001oogoo009oo`<000Mo
o`X0009oo`<0009oo`80015oo`<000=oo`8004Aoo`00A7oo0`000Woo1P000Woo10000goo1@001Goo
0P000Woo0`001goo0`000Woo0`002goo0`000goo10002Woo0P0000=oo`0000000goo0P0017oo1@00
0goo0`000Woo0P000Woo00<007ooOol00`0017oo0`001Goo100000=oo`0000001`000goo0P0027oo
10000Woo0`000Woo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol017oo0`0057oo1@00AWoo
0015Ool40003Ool20005Ool50003Ool70005Ool70002Ool00`00Oomoo`04Ool:0002Ool00`00Oomo
o`05Ool:0002Ool200000goo000000030007Ool20007Ool00`00Oomoo`020002Ool00`00Oomoo`02
0006Ool600000goo00000005Ool20003Ool400000goo0000000700000goo00000005Ool20002Ool:
0002Ool30002Ool50002Ool00`00Oomoo`0FOol20017Ool004Eoo`@000=oo`8000Eoo`D000=oo`L0
00Eoo`L0009oo`03001oogoo00Aoo`X0009oo`03001oogoo00Eoo`X0009oo`800003Ool0000000<0
00Moo`8000Moo`03001oogoo0080009oo`03001oogoo008000Ioo`H00003Ool0000000Eoo`8000=o
o`@00003Ool0000000L00003Ool0000000Eoo`80009oo`X0009oo`<0009oo`D0009oo`03001oogoo
01Ioo`8004Moo`00Agoo0`000Woo1`000goo100000=oo`0000000goo1P0000=oo`0000000goo0P00
0Woo1`000goo0P000goo0P000Woo20000goo0P0017oo00<007ooOol00`0017oo1`0000=oo`000000
1@000Woo00<007ooOol00P000Woo00<007ooOol0200017oo0P0000=oo`0000000`000Woo0`000Woo
0P001Goo0P000goo0P0000=oo`0000001@001Goo0P0017oo00<007ooOol00goo10000goo0P000Woo
6@00BGoo0017Ool30002Ool70003Ool400000goo00000003Ool600000goo00000003Ool20002Ool7
0003Ool20003Ool20002Ool80003Ool20004Ool00`00Oomoo`030004Ool700000goo000000050002
Ool00`00Oomoo`020002Ool00`00Oomoo`080004Ool200000goo000000030002Ool30002Ool20005
Ool20003Ool200000goo000000050005Ool20004Ool00`00Oomoo`03Ool40003Ool20002OolI0019
Ool004Uoo`<000=oo`8000Moo`800003Ool0000000<000Aoo`800003Ool0000000800003Ool00000
009oo`03001oogoo009oo`<0009oo`D000Eoo`8000=oo`@00003Ool0000000@000Eoo`<0009oo`03
001oogoo009oo`800003Ool0000000=oo`80009oo`03001oogoo00@000Eoo`03001oogoo009oo`D0
00Eoo`8000Eoo`03001oogoo00D0009oo`<0009oo`800003Ool0000000Aoo`D00003Ool0000000@0
00Qoo`D000Eoo`8000=oo`8000=oo`8000Aoo`03001oogoo009oo`03001oogoo04Uoo`00BGoo0`00
0goo0P001goo0P0000=oo`0000000`0017oo0P0000=oo`0000000P0000=oo`0000000Woo00<007oo
Ool00Woo0`000Woo1@001Goo0P000goo100000=oo`00000010001Goo0`000Woo00<007ooOol00Woo
0P0000=oo`0000000goo0P000Woo00<007ooOol010001Goo00<007ooOol00Woo1@001Goo0P001Goo
00<007ooOol01@000Woo0`000Woo0P0000=oo`00000017oo1@0000=oo`000000100027oo1@001Goo
0P000goo0P000goo0P0017oo00<007ooOol00Woo00<007ooOol0BGoo001:Ool400000goo00000005
0002Ool30004Ool50005Ool200000goo000000020007Ool30003Ool600000goo0000000200000goo
00000005Ool20008Ool20002Ool30002Ool200000goo0000000200000goo000000020005Ool50002
Ool50003Ool50002Ool70005Ool20005Ool00`00Oomoo`0200000goo000000040003Ool30004Ool:
0003Ool600000goo0000000200000goo0000000200000goo000000020002Ool5001<Ool004aoo`<0
00Aoo`8000Eoo`D000=oo`L000Eoo`L0009oo`03001oogoo00Eoo`8000Eoo`800003Ool0000000<0
009oo`X000Eoo`80009oo`800003Ool0000000Eoo`L000=oo`@000=oo`D000Aoo`03001oogoo0080
00=oo`D0009oo`D0009oo`<000Eoo`8000Moo`D000=oo`8000=oo`D000Aoo`800003Ool0000000Eo
o`800003Ool0000000Eoo`8004ioo`00C7oo0`0017oo0P001Goo1@000goo1`001Goo1`000Woo00<0
07ooOol01Goo0P001Goo0P0000=oo`0000000`000Woo2P001Goo0P000Woo0P0000=oo`0000001Goo
1`000goo10000goo1@0017oo00<007ooOol00P000goo1@000Woo1@000Woo0`001Goo0P001goo1@00
0goo0P000goo1@0017oo0P0000=oo`0000001Goo0P0000=oo`0000001Goo0P00CWoo001>Ool30002
Ool70003Ool30002Ool20003Ool50002Ool20003Ool20002Ool60002Ool50002Ool30004Ool30004
Ool00`00Oomoo`02Ool500000goo00000002Ool200000goo000000050003Ool20007Ool50003Ool4
0002Ool30007Ool00`00Oomoo`04Ool00`00Oomoo`03Ool50002Ool90003Ool400000goo00000003
0004Ool30002Ool200000goo000000030002Ool200000goo00000005001@Ool004ioo`<0009oo`L0
00=oo`<0009oo`8000=oo`D0009oo`8000=oo`80009oo`H0009oo`D0009oo`<000Aoo`<000Aoo`03
001oogoo009oo`D00003Ool00000009oo`800003Ool0000000D000=oo`8000Moo`D000=oo`@0009o
o`<000Moo`03001oogoo00Aoo`03001oogoo00=oo`D0009oo`T000=oo`@00003Ool0000000<000Ao
o`<0009oo`800003Ool0000000<0009oo`800003Ool0000000D0051oo`00Cgoo10000goo0P001goo
00<007ooOol01@0017oo00<007ooOol00`000Woo0P000Woo00<007ooOol00Woo0`0017oo00<007oo
Ool00P001Woo10000Woo1@000goo0P0000=oo`0000000Woo0P0000=oo`0000000goo100000=oo`00
00001`000goo100000=oo`0000001Goo1`000Woo1`0027oo0P001Goo0P000goo0`000Woo0P001Goo
0P001Woo0P000Woo0`0017oo00<007ooOol00`0017oo0P00DGoo001AOol400000goo000000050002
Ool30004Ool50005Ool00`00Oomoo`040006Ool40002Ool3000:Ool40003Ool30002Ool200000goo
00000002Ool30007Ool200000goo00000004Ool00`00Oomoo`05Ool200000goo0000000400000goo
00000003Ool20002Ool00`00Oomoo`02Ool80002Ool70007Ool00`00Oomoo`050002Ool80006Ool5
0005Ool5001COol0055oo`@00003Ool0000000D0009oo`<000Aoo`D000Eoo`03001oogoo00@000Io
o`@0009oo`<000Yoo`@000=oo`<0009oo`800003Ool00000009oo`<000Moo`800003Ool0000000Ao
o`03001oogoo00Eoo`800003Ool0000000@00003Ool0000000=oo`80009oo`03001oogoo009oo`P0
009oo`L000Moo`03001oogoo00D0009oo`P000Ioo`D000Eoo`D005=oo`00Dgoo0`0017oo00<007oo
Ool00goo1P000goo1`001Goo1`0000=oo`0000001Goo2P000Woo0P001goo00<007ooOol00`001Woo
1P000Woo0P0000=oo`0000000P000Woo1P000Woo0`0017oo0P0000=oo`0000000P0000=oo`000000
0P001goo00<007ooOol00Woo00<007ooOol00P000goo1`000Woo0`0017oo00<007ooOol00P000goo
0P0027oo0P0027oo0P00EGoo001COol30004Ool00`00Oomoo`03Ool60003Ool70005Ool700000goo
00000005Ool:0002Ool20007Ool00`00Oomoo`030006Ool60002Ool200000goo000000020002Ool6
0002Ool30004Ool200000goo0000000200000goo000000020007Ool00`00Oomoo`02Ool00`00Oomo
o`020003Ool70002Ool30004Ool00`00Oomoo`020003Ool20008Ool20008Ool2001EOol005Eoo`<0
009oo`H000Aoo`<0009oo`8000=oo`D0009oo`8000=oo`800003Ool0000000D000Aoo`03001oogoo
009oo`03001oogoo00T000Eoo`D0009oo`03001oogoo009oo`<000Eoo`@000=oo`8000Eoo`<0009o
o`800003Ool0000000Eoo`L0009oo`<0009oo`03001oogoo00D000Aoo`03001oogoo00=oo`@0009o
o`03001oogoo00<0009oo`T00003Ool0000000P005Moo`00EWoo10000goo0P001goo00<007ooOol0
1@000goo0P000Woo0`000Woo0P0000=oo`00000017oo0`000Woo1@001Goo0P000goo1`000goo0P00
0Woo0`000Woo00<007ooOol01goo1@0027oo0P000Woo0P0000=oo`0000001@000goo0P001Goo0P00
0Woo0`000goo1P0027oo10001Goo00<007ooOol00P000goo0P001Goo0P000goo0P00F7oo001FOol4
0003Ool20007Ool00`00Oomoo`050003Ool20002Ool30002Ool200000goo00000004Ool30002Ool5
0005Ool20003Ool70003Ool20002Ool30002Ool00`00Oomoo`07Ool50008Ool20002Ool200000goo
000000050003Ool20005Ool20002Ool30003Ool60008Ool40005Ool00`00Oomoo`020003Ool20005
Ool20003Ool2001HOol005Qoo`<0009oo`L0009oo`<000=oo`D000Ioo`03001oogoo00<000Moo`@0
00=oo`D0009oo`<0009oo`8000=oo`D000Eoo`80009oo`X000=oo`T00003Ool00000009oo`800003
Ool0000000=oo`@00003Ool0000000@00003Ool00000009oo`03001oogoo00Eoo`8000aoo`D0009o
o`03001oogoo00<0009oo`D0009oo`D005Yoo`00F7oo0`000Woo1`000Woo0`000goo1@001Woo00<0
07ooOol00`001goo10000goo1@000Woo0`000Woo0P000goo1@001Goo0P000Woo2P000goo2@0000=o
o`0000000Woo0P0000=oo`0000000goo100000=oo`000000100000=oo`0000000Woo00<007ooOol0
1Goo0P0037oo1@000Woo00<007ooOol00`000Woo1@000Woo1@00FWoo001JOol30003Ool20005Ool5
0004Ool70005Ool700000goo00000007Ool00`00Oomoo`04Ool00`00Oomoo`050003Ool70005Ool2
0003Ool20007Ool20003Ool200000goo00000002Ool30007Ool30004Ool200000goo00000002Ool6
0002Ool>0003Ool20002Ool00`00Oomoo`020005Ool20005Ool00`00Oomoo`1JOol005Yoo`<000=o
o`8000Eoo`D000Aoo`L000Eoo`L00003Ool0000000Moo`03001oogoo00Aoo`03001oogoo00D000=o
o`L000Eoo`8000=oo`8000Moo`8000=oo`800003Ool00000009oo`<000Moo`<000Aoo`800003Ool0
0000009oo`H0009oo`h000=oo`80009oo`03001oogoo008000Eoo`8000Eoo`03001oogoo05Yoo`00
Fgoo100000=oo`0000001@0017oo0`000Woo00<007ooOol00Woo1@000Woo00<007ooOol00Woo0P00
00=oo`0000001@000Woo1@000Woo0`000goo100000=oo`00000017oo1@0000=oo`0000000P0000=o
o`0000001@000Woo0`000Woo0P0000=oo`0000000Woo0P002Woo0`000Woo0P0000=oo`0000000P00
0goo0P001Goo0P000goo0P000goo100000=oo`0000000Woo00<007ooOol01@000Woo1`00GGoo001M
Ool30004Ool20006Ool20002Ool50003Ool20002Ool30002Ool200000goo00000003Ool40003Ool2
0002Ool00`00Oomoo`05Ool30007Ool20005Ool30004Ool20005Ool00`00Oomoo`0200000goo0000
0002000=Ool40005Ool30002Ool50002Ool50007Ool200000goo00000002Ool30003Ool40003Ool2
001OOol005eoo`<000Aoo`8000Ioo`80009oo`D000=oo`80009oo`<0009oo`800003Ool0000000=o
o`@000=oo`80009oo`03001oogoo00Eoo`<000Moo`8000Eoo`<000Aoo`8000Eoo`03001oogoo0080
0003Ool00000008000eoo`@000Eoo`<0009oo`D0009oo`D000Moo`800003Ool00000009oo`<000=o
o`@000=oo`8005moo`00Ggoo0`000Woo1`0000=oo`0000000P000goo1@001Goo0P000Woo0`001goo
0`000Woo10002Woo20002Goo0`000Woo1@000Woo0`001Goo3P0000=oo`0000002Goo0`000goo1000
0goo1`000Woo0P0000=oo`0000000Woo00<007ooOol01Goo1@00HGoo001OOol30002Ool700000goo
000000020003Ool50005Ool20002Ool30007Ool30002Ool4000:Ool80009Ool30002Ool50002Ool3
0005Ool>00000goo00000009Ool30003Ool40003Ool70002Ool200000goo00000002Ool00`00Oomo
o`05Ool5001QOol0061oo`@000=oo`8000Eoo`D000Aoo`H000Ioo`H0009oo`8000Eoo`X0009oo`03
001oogoo009oo`8000]oo`@000=oo`80009oo`03001oogoo00Moo`8000=oo`8000=oo`800003Ool0
000000L0009oo`03001oogoo00Eoo`@00003Ool0000000=oo`80009oo`800003Ool00000008000Yo
o`80069oo`00HWoo100000=oo`0000001@000goo10000Woo00<007ooOol00Woo1@000Woo00<007oo
Ool00Woo00<007ooOol01`000goo0P000goo0P000Woo1@003goo100000=oo`0000000Woo20000Woo
0`000Woo1@001Goo0P000goo10002Woo0P0000=oo`0000000P0000=oo`0000000P001Goo3000I7oo
001ROol400000goo000000050003Ool40002Ool00`00Oomoo`02Ool50002Ool00`00Oomoo`02Ool0
0`00Oomoo`070003Ool20003Ool20002Ool5000?Ool400000goo00000002Ool80002Ool30002Ool5
0005Ool20003Ool4000:Ool200000goo0000000200000goo000000020005Ool<001TOol006Aoo`<0
00Aoo`03001oogoo00Eoo`80009oo`D000=oo`80009oo`<0009oo`03001oogoo008000=oo`@00003
Ool0000000<000Eoo`8001=oo`800003Ool00000009oo`03001oogoo009oo`03001oogoo00Aoo`<0
00=oo`L000Moo`X0009oo`800003Ool0000000Eoo`L000=oo`8000=oo`8006Ioo`00I7oo0`0017oo
00<007ooOol01Goo0P000Woo1@000goo0P000Woo0`000Woo00<007ooOol00P000goo100000=oo`00
00000`001Goo0P004goo0P0000=oo`0000000Woo00<007ooOol00Woo00<007ooOol017oo0`000goo
1`001goo2P000Woo0P0000=oo`0000001Goo1`000goo0P000goo0P00IWoo001VOol30002Ool60002
Ool40003Ool50005Ool20002Ool30007Ool30004Ool500000goo0000000A0002Ool200000goo0000
0002Ool50008Ool400000goo00000003Ool90003Ool20003Ool20002Ool200000goo000000030002
Ool20003Ool400000goo00000003001XOol006Moo`@000=oo`8000Eoo`D000=oo`L000Eoo`L0009o
o`8000Ioo`8000Eoo`8000=oo`8000=oo`8000=oo`80009oo`<000Eoo`8000aoo`<000Moo`8000=o
o`@00003Ool0000000800003Ool00000009oo`<000Aoo`03001oogoo00@00003Ool0000000Eoo`80
06Uoo`00Igoo10000goo0P001Goo1@000goo1`001Goo1`000Woo0P001Woo0P001Goo0P000goo0P00
0goo0P000goo0P000Woo0`001Goo0P0037oo0`001goo0P000goo100000=oo`0000000P0000=oo`00
00000Woo0`0017oo00<007ooOol0100000=oo`0000001Goo0P00JGoo001YOol30002Ool70003Ool4
00000goo00000004Ool500000goo00000003Ool20002Ool700000goo000000030002Ool400000goo
0000000200000goo000000030006Ool6000@Ool60002Ool400000goo00000005Ool30006Ool50005
Ool200000goo00000005001[Ool006Uoo`<0009oo`L000=oo`@00003Ool0000000Aoo`D00003Ool0
000000=oo`80009oo`L00003Ool0000000<0009oo`@00003Ool0000000800003Ool0000000<000Io
o`H0011oo`H0009oo`@00003Ool0000000Eoo`<000Ioo`D000Eoo`800003Ool0000000D006]oo`00
Jgoo0`000goo0P001goo0P0000=oo`00000010000goo0P0000=oo`0000000P0000=oo`0000000Woo
0P000goo0`0017oo00<007ooOol00P001Goo0`0017oo1@000Woo00<007ooOol00Woo4@000goo0P00
1Goo0`002Goo1`000goo1@000Woo0`0017oo00<007ooOol0Jgoo001[Ool30003Ool20007Ool20000
0goo000000040003Ool200000goo0000000200000goo00000002Ool20003Ool30004Ool00`00Oomo
o`020005Ool30004Ool50002Ool00`00Oomoo`02OolA0003Ool20005Ool30009Ool70003Ool50002
Ool30004Ool00`00Oomoo`1[Ool006aoo`@00003Ool0000000D0009oo`<000Aoo`D000Eoo`800003
Ool00000008000Moo`<0009oo`<000Uoo`D000=oo`80009oo`<0009oo`03001oogoo009oo`03001o
ogoo009oo`8000=oo`D000Uoo`X000=oo`8000Moo`03001oogoo00Aoo`D006ioo`00KWoo0`0017oo
0P001Goo1@000goo1`001Goo1`000Woo00<007ooOol00goo2`000goo1@001Goo0P000Woo0`000Woo
0`000Woo1@000goo2`000goo0P000goo0`000Woo2@0027oo0P00L7oo001^Ool30004Ool20005Ool5
0003Ool70005Ool70002Ool00`00Oomoo`03Ool;0003Ool50005Ool20002Ool30002Ool30002Ool5
0003Ool;0003Ool20003Ool30002Ool90008Ool2001`Ool0071oo`<0009oo`L000=oo`@00003Ool0
000000=oo`D0009oo`8000=oo`80009oo`H000Aoo`8000=oo`D000=oo`H00003Ool00000009oo`03
001oogoo00=oo`@000=oo`D000Aoo`03001oogoo009oo`<0009oo`<0009oo`8000Eoo`8000=oo`X0
079oo`00L7oo0`000Woo1`000goo100000=oo`0000000goo1@000Woo0P000goo0P000Woo1P0017oo
0P000goo1@000goo1P0000=oo`0000000Woo00<007ooOol00goo10000goo1@0017oo00<007ooOol0
0Woo0`000Woo0`000Woo0P001Goo0P000goo2P00LWoo001aOol40003Ool20007Ool200000goo0000
00030004Ool00`00Oomoo`0400000goo00000002Ool00`00Oomoo`02Ool30002Ool50003Ool50004
Ool200000goo000000020008Ool50004Ool30002Ool30002Ool20005Ool00`00Oomoo`070007Ool0
0`00Oomoo`02Ool2001cOol007=oo`@00003Ool0000000D0009oo`<000Aoo`D000Eoo`800003Ool0
0000008000Ioo`@000=oo`D000Aoo`D000Eoo`X000Aoo`<0009oo`03001oogoo00=oo`80009oo`D0
009oo`03001oogoo008000=oo`L0009oo`D007Eoo`00Lgoo100000=oo`0000001@000Woo0`0017oo
1@001Goo0P0000=oo`0000000P001Woo10000goo1@0017oo1@001Goo2P0017oo0`000Woo00<007oo
Ool00goo0P000Woo1@000Woo00<007ooOol00P000goo1`000Woo1@00MGoo001eOol30004Ool00`00
Oomoo`04Ool50003Ool70005Ool700000goo00000007Ool20006Ool20009Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool20002Ool500000goo000000020003Ool20002Ool00`00Oomoo`050004Ool00`00
Oomoo`03Ool2001gOol007Eoo`<000Aoo`03001oogoo00Aoo`D000=oo`L000Eoo`L00003Ool00000
00Moo`8000Ioo`8000Uoo`03001oogoo009oo`03001oogoo00Eoo`80009oo`D00003Ool000000080
00=oo`80009oo`03001oogoo00D000Aoo`03001oogoo00=oo`8007Moo`00Mgoo0`000Woo1`000goo
0`000Woo0P000goo1@000Woo0P000goo0P0000=oo`0000001@000Woo1`0000=oo`0000001`000Woo
0`000Woo20001Goo0P001Goo100000=oo`0000000Woo0`000goo10000Woo1P00NGoo001hOol40003
Ool20007Ool00`00Oomoo`050004Ool00`00Oomoo`030002Ool200000goo00000004Ool30003Ool2
0005Ool20003Ool20002Ool00`00Oomoo`03Ool20004Ool60009Ool200000goo00000002Ool00`00
Oomoo`05Ool40003Ool2001jOol007Qoo`@000=oo`8000Moo`03001oogoo00D000Aoo`03001oogoo
00<0009oo`800003Ool0000000Aoo`<000=oo`8000Eoo`8000=oo`80009oo`03001oogoo00=oo`80
00Aoo`H000Uoo`800003Ool00000009oo`03001oogoo00Eoo`@000=oo`8007Yoo`00NWoo0`000Woo
1`000Woo0`000goo1P001Goo00<007ooOol00`001goo100000=oo`0000000`000Woo100000=oo`00
00000Woo1@0000=oo`0000000P000Woo00<007ooOol00Woo20000Woo0P0000=oo`0000000P002Woo
1@00O7oo001jOol30002Ool70002Ool30003Ool60005Ool00`00Oomoo`030007Ool400000goo0000
00030002Ool400000goo00000002Ool500000goo000000020002Ool00`00Oomoo`02Ool80002Ool2
00000goo00000002000:Ool5001lOol007aoo`<000Aoo`03001oogoo00=oo`D000Aoo`L000Eoo`L0
0003Ool0000000Eoo`8000Eoo`<000Eoo`8000Eoo`@000Ioo`8000=oo`80009oo`800003Ool00000
00ioo`03001oogoo07aoo`00O7oo0`0017oo00<007ooOol00goo1@0017oo1`001Goo1`0000=oo`00
00001Goo0P001Goo0`001Goo0P001Goo10001Woo0P000goo0P000Woo0P0000=oo`0000003Woo00<0
07ooOol0O7oo001mOol40002Ool60004Ool30002Ool20003Ool50002Ool00`00Oomoo`02Ool20000
0goo000000050009Ool60009Ool700000goo0000000200000goo00000002Ool200000goo0000000>
001oOol007moo`@000=oo`8000Ioo`80009oo`D000=oo`80009oo`<0009oo`800003Ool0000000=o
o`T0009oo`03001oogoo009oo`X000=oo`8000Eoo`800003Ool00000008000Eoo`8000=oo`8000=o
o`80085oo`00Ogoo10000goo0P001Woo0P000Woo1@000goo0P000Woo0`000Woo0P0000=oo`000000
0goo2@000Woo00<007ooOol00Woo2P000goo0P001Goo0P0000=oo`0000000P001Goo0P000goo0P00
0goo0P00PGoo0021Ool30002Ool700000goo000000020003Ool50005Ool20002Ool30007Ool20003
Ool20002Ool50003Ool20003Ool400000goo000000050005Ool50002Ool30002Ool50023Ool0085o
o`<0009oo`L00003Ool00000008000=oo`D000Eoo`80009oo`<000Moo`8000=oo`80009oo`D000=o
o`8000=oo`@00003Ool0000000D000Eoo`D0009oo`<0009oo`D008=oo`00Pgoo0`000goo0P001Goo
1@0017oo1P001Woo1P000Woo0`000Woo10000goo1@001goo0P0000=oo`0000000goo1`0017oo00<0
07ooOol00P001Goo00<007ooOol0Pgoo0024Ool400000goo000000050004Ool30002Ool00`00Oomo
o`02Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`020005Ool50003Ool70002Ool200000goo0000
000200000goo00000003Ool40002Ool00`00Oomoo`070026Ool008Aoo`@00003Ool0000000D000Ao
o`<0009oo`03001oogoo009oo`D0009oo`03001oogoo009oo`03001oogoo008000Eoo`D000=oo`L0
009oo`800003Ool0000000800003Ool0000000=oo`@0009oo`03001oogoo00L008Ioo`00QWoo0`00
17oo00<007ooOol01Goo0P000Woo1@000goo0P000Woo0`000Woo00<007ooOol01`000goo100000=o
o`0000000goo10001Goo0`001goo0P000Woo0`000goo0P00R7oo0026Ool30004Ool00`00Oomoo`05
Ool20002Ool50003Ool20002Ool30002Ool00`00Oomoo`070003Ool400000goo00000003Ool40005
Ool30007Ool20002Ool30003Ool20028Ool008Qoo`<0009oo`L00003Ool00000008000=oo`D000Eo
o`80009oo`<000=oo`8000Moo`800003Ool0000000800003Ool0000000Uoo`P000Eoo`D008Yoo`00
RGoo10000goo0P001Goo1@000goo1`001Goo100000=oo`0000001`001Goo0P0000=oo`0000001`00
0Woo00<007ooOol00Woo00<007ooOol01goo0P00Rgoo0029Ool40003Ool20005Ool50003Ool70005
Ool400000goo000000070005Ool200000goo000000070002Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool2002;Ool008]oo`<0009oo`L000=oo`@00003Ool0000000Aoo`D00003Ool0000000Eoo`8000=o
o`L000Eoo`8000=oo`80009oo`<0009oo`X008eoo`00Rgoo0`000Woo1`000goo100000=oo`000000
17oo1@0000=oo`0000001Goo0P000goo1`001Goo0P000goo0P000Woo0`000Woo2P00SGoo002=Ool3
0004Ool00`00Oomoo`05Ool200000goo000000040003Ool200000goo000000030002Ool400000goo
00000003Ool50002Ool400000goo00000002Ool00`00Oomoo`03Ool20004Ool00`00Oomoo`2=Ool0
08eoo`<000Aoo`03001oogoo00Eoo`800003Ool0000000@000=oo`800003Ool0000000<0009oo`@0
0003Ool0000000=oo`D0009oo`@00003Ool00000009oo`03001oogoo00=oo`8000Aoo`03001oogoo
08eoo`00SWoo10000Woo1P000Woo0`0017oo1@001Goo0P001Goo0`001goo0P001Goo0P0000=oo`00
00000Woo1@0000=oo`0000001000T7oo002@Ool40003Ool20005Ool50003Ool70009Ool60002Ool5
0002Ool30005Ool20005Ool2002BOol0091oo`@000=oo`8000Eoo`D000=oo`L000Uoo`H0009oo`D0
009oo`<000Eoo`8000Eoo`80099oo`00TWoo0`000Woo1`000goo100000=oo`0000000goo2`000goo
0P001Goo00<007ooOol017oo1@0000=oo`0000001@00U7oo002BOol30002Ool70003Ool400000goo
00000003Ool;0003Ool20005Ool00`00Oomoo`04Ool500000goo00000005002DOol009Aoo`<000=o
o`8000Moo`800003Ool0000000<000Aoo`03001oogoo009oo`<0009oo`D0009oo`L000=oo`<000Ao
o`03001oogoo09Aoo`00UGoo100000=oo`0000001@000Woo0`0017oo1@001goo0`000goo10000goo
0P001goo1@00Ugoo002EOol400000goo000000050002Ool30004Ool50007Ool30003Ool40003Ool2
0007Ool5002GOol009Moo`<000Aoo`03001oogoo00Aoo`D000=oo`L0009oo`03001oogoo00Eoo`D0
00Yoo`8009Uoo`00Ugoo0`0017oo00<007ooOol017oo1@000goo1`000Woo00<007ooOol01Goo1@00
2Woo0P00VGoo002IOol30002Ool70003Ool30002Ool20003Ool20002Ool80003Ool<002KOol009Yo
o`@000=oo`8000Moo`03001oogoo00D000Eoo`8000=oo`D000Aoo`8000=oo`8009aoo`00VWoo1000
0goo0P001goo00<007ooOol01@001Goo0P000goo1@0017oo0P000goo0P00W7oo002LOol30002Ool7
0002Ool30003Ool600000goo000000030004Ool30002Ool5002NOol009aoo`<0009oo`L0009oo`<0
00=oo`H00003Ool0000000<000Aoo`<0009oo`D009ioo`00WWoo0`0017oo00<007ooOol00goo1@00
17oo0`0017oo0`000Woo00<007ooOol017oo00<007ooOol0WWoo002NOol30004Ool00`00Oomoo`03
Ool50004Ool30004Ool30002Ool00`00Oomoo`04Ool00`00Oomoo`2NOol009moo`@0009oo`H000Ao
o`<0009oo`8000Ioo`80009oo`L00:5oo`00XGoo10000goo0P001Woo0P000Woo1`0000=oo`000000
0P000goo0P00Xgoo002QOol40003Ool20006Ool20002Ool700000goo000000020003Ool2002SOol0
0:=oo`<0009oo`L00003Ool00000008000=oo`8000Eoo`D00:Eoo`00Xgoo0`000Woo1`0000=oo`00
00000P000goo0P001Goo1@00YGoo002UOol30003Ool20005Ool50009Ool00`00Oomoo`2UOol00:Io
o`@00003Ool0000000D000Aoo`X00:Qoo`00YWoo100000=oo`0000001@0017oo2P00Z7oo002XOol3
0004Ool00`00Oomoo`05Ool20003Ool2002ZOol00:Qoo`<000Aoo`03001oogoo00Eoo`8000=oo`80
0:Yoo`00ZWoo0`000Woo1`0000=oo`0000000`00[7oo002[Ool40003Ool20005Ool2002]Ool00:]o
o`@000=oo`8000Eoo`800:eoo`00[Goo0`000Woo1`00[goo002]Ool30002Ool7002_Ool00:moo`<0
00Aoo`03001oogoo0:moo`00[goo0`0017oo00<007ooOol0[goo002`Ool6002bOol00;9oo`800;Ao
o`00/Woo0P00]7oo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo
003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-5.02605, -5.02605, 0.734862, \
0.734862}}]
}, Open  ]],

Cell["\<\
The important technical application is that the middle column is \
quite adept at spewing forth \"random\" bits. Indeed, when we use it as a \
generator of random numbers, what we obtain is found to be random by every \
test I have seen, and this includes the entire DIEHARD suite. While the \
properties of this generator are not well understood, the significance of it \
giving \"good\" random numbers cannot be understated.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2D Cellular Automata (more pretty pictures)", "Subsubsection"],

Cell["\<\
We first show as separate plots an evolution of a \
two\[Hyphen]dimensional cellular automaton.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[
          Map[RasterGraphics, 
            CellularAutomaton[{630, {2, 1}, {1, 1}}, {{{1}}, 0}, 
              25, \(-5\)]]]];\)\)], "Input",
  CellTags->"CellularAutomaton"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .18519 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.00440917 0.190476 [
[ 0 0 0 0 ]
[ 1 .18519 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .18519 L
0 .18519 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00440917 0.200176 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.0238095 0.0186741 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
51 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFF00000000FFFFFFFF
FFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFF00000000FFFFFFFF
FFFFFFFF000000000000000000000000FFFFFFFF00000000FFFFFF00000000FFFFFFFF00
0000000000000000000000FFFFFFFF
FFFFFFFF0000000000FFFF0000000000FFFFFFFF00000000FFFFFF00000000FFFFFFFF00
00000000FFFF0000000000FFFFFFFF
FFFFFFFFFFFF000000FFFF0000000000FFFFFFFF0000FFFF000000FFFF0000FFFFFFFF00
00000000FFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFF000000000000FF0000FFFFFF00FFFFFF0000FF00000000
0000FFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FF000000000000000000FF000000000000000000FF
00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFF00FF0000000000FFFFFF000000FFFFFF000000FFFFFF000000
0000FF00FFFF000000FFFFFFFFFFFF
FFFFFFFF0000000000FFFFFF0000FF0000FFFFFF0000FF0000FF0000FF0000FFFFFF0000
FF0000FFFFFF0000000000FFFFFFFF
FFFFFFFF000000000000FF000000FFFF0000FF000000FF0000FF0000FF000000FF0000FF
FF000000FF000000000000FFFFFFFF
FFFFFFFF0000000000000000FFFF00000000FF00000000000000000000000000FF000000
00FFFF0000000000000000FFFFFFFF
FFFFFFFF000000000000FF0000FF00000000FFFF0000FF0000000000FF0000FFFF000000
00FF0000FF000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFF0000FF00FF00FF00FF0000FFFF000000
000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00000000FF00FFFF000000000000000000FFFF00FF0000
0000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00FFFFFFFFFF0000000000FFFFFFFFFF00FFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFF00000000FF00FF00000000FFFFFFFFFF
0000FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000FF0000000000FFFF00000000000000000000000000FFFF0000
000000FF0000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FF0000000000FF00FF0000000000FF000000
000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF0000FFFF0000FFFF00FFFF00FF00000000FFFF00FFFF00000000FF00FFFF
00FFFF0000FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFF0000FFFF000000000000000000000000FFFFFF00FFFFFF00000000000000
0000000000FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00000000FF0000FF00FFFFFFFF00FFFFFFFF00FF0000FF00
000000FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFF00000000000000000000000000000000000000000000
00FFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FF00000000FF0000FF00FFFFFFFF00FFFFFFFF00FF0000FF00
000000FF00FF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFF000000000000000000000000FFFFFF00FFFFFF00000000000000
0000000000FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFF0000FFFF0000FFFF00FFFF00FF00000000FFFF00FFFF00000000FF00FFFF
00FFFF0000FFFF0000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FF0000000000FF00FF0000000000FF000000
000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF0000000000FF0000000000FFFF00000000000000000000000000FFFF0000
000000FF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFF0000FFFFFFFFFF00000000FF00FF00000000FFFFFFFFFF
0000FFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00FFFFFFFFFF0000000000FFFFFFFFFF00FFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FF00000000FF00FFFF000000000000000000FFFF00FF0000
0000FF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFF0000FF00FF00FF00FF0000FFFF000000
000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFF000000000000FF0000FF00000000FFFF0000FF0000000000FF0000FFFF000000
00FF0000FF000000000000FFFFFFFF
FFFFFFFF0000000000000000FFFF00000000FF00000000000000000000000000FF000000
00FFFF0000000000000000FFFFFFFF
FFFFFFFF000000000000FF000000FFFF0000FF000000FF0000FF0000FF000000FF0000FF
FF000000FF000000000000FFFFFFFF
FFFFFFFF0000000000FFFFFF0000FF0000FFFFFF0000FF0000FF0000FF0000FFFFFF0000
FF0000FFFFFF0000000000FFFFFFFF
FFFFFFFFFFFF000000FFFF00FF0000000000FFFFFF000000FFFFFF000000FFFFFF000000
0000FF00FFFF000000FFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFF00FF000000000000000000FF000000000000000000FF
00FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFF000000000000FF0000FFFFFF00FFFFFF0000FF00000000
0000FFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFF000000FFFF0000000000FFFFFFFF0000FFFF000000FFFF0000FFFFFFFF00
00000000FFFF000000FFFFFFFFFFFF
FFFFFFFF0000000000FFFF0000000000FFFFFFFF00000000FFFFFF00000000FFFFFFFF00
00000000FFFF0000000000FFFFFFFF
FFFFFFFF000000000000000000000000FFFFFFFF00000000FFFFFF00000000FFFFFFFF00
0000000000000000000000FFFFFFFF
FFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFF00000000FFFFFFFF
FFFFFFFF00000000FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.00440917 0.39418 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.0238095 0.0186741 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
51 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF0000FFFF0000FFFF0000FFFFFF
FFFFFF000000000000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFF000000000000FFFFFF
FFFFFFFF000000FF00FFFF00FF000000FFFFFF0000FFFF0000FF0000FFFF0000FFFFFF00
0000FF00FFFF00FF000000FFFFFFFF
FFFFFFFF000000FF00000000FF000000FFFFFF000000000000FF000000000000FFFFFF00
0000FF00000000FF000000FFFFFFFF
FFFFFF0000FFFF00FF0000FF00000000FFFFFFFF00FFFF0000FF0000FFFF00FFFFFFFF00
000000FF0000FF00FFFF0000FFFFFF
FFFFFF00000000FF00000000FFFF00FF00FF000000FF00FF000000FF00FF000000FF00FF
00FFFF00000000FF00000000FFFFFF
FFFFFFFFFFFF0000000000000000FFFF00000000FFFF00000000000000FFFF00000000FF
FF0000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000FF00FFFFFFFF000000FFFF0000FF0000FFFF000000FFFFFF
FF00FF000000000000FFFFFFFFFFFF
FFFFFF00000000FF00000000000000FFFF00000000FFFFFF000000FFFFFF00000000FFFF
00000000000000FF00000000FFFFFF
FFFFFF0000FFFF00FF00FF00FF000000FF00FFFF0000FF0000000000FF0000FFFF00FF00
0000FF00FF00FF00FFFF0000FFFFFF
FFFFFFFF00000000FF00000000000000FF000000FFFFFFFFFFFFFFFFFFFFFF000000FF00
000000000000FF00000000FFFFFFFF
FFFFFFFF0000000000FFFF00000000FFFF000000FFFFFFFFFFFFFFFFFFFFFF000000FFFF
00000000FFFF0000000000FFFFFFFF
FFFFFF0000000000FFFFFFFF0000FF0000000000FFFFFF00FFFFFF00FFFFFF0000000000
FF0000FFFFFFFF0000000000FFFFFF
FFFFFF0000FFFFFF0000FFFFFFFFFF00FF00FFFF0000FF00FFFFFF00FF0000FFFF00FF00
FFFFFFFFFF0000FFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFF00FF00000000000000FF00FF000000FFFFFF000000FF00FF000000
00000000FF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FF000000FFFF0000FF00FFFFFFFFFFFFFF00FF0000FFFF00
0000FF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFF0000FF00000000FF000000FF0000FF0000FFFFFFFFFFFFFF0000FF0000FF00
0000FF00000000FF0000FFFFFFFFFF
FFFFFFFFFF00000000FF000000FFFFFF00FFFF00FF0000FFFF00FFFF0000FF00FFFF00FF
FFFF000000FF00000000FFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFF00FFFFFF000000000000FF0000000000FF000000000000FF
FFFF00FFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFF00FF0000FFFFFFFFFFFFFF00FFFF00FF00FF00FF00FF00FF00FFFF00FFFF
FFFFFFFFFF0000FF00FFFFFFFFFFFF
FFFFFFFFFF000000FF0000FF00FFFF000000FFFFFF00FF00FFFFFF00FF00FFFFFF000000
FFFF00FF0000FF000000FFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000FF000000FF0000FFFFFFFFFFFF
FFFF0000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFF0000FF0000FFFFFFFFFFFFFF0000FFFF000000FFFF0000FFFFFFFFFF
FFFF0000FF0000FFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000FF000000FF0000FFFFFFFFFFFF
FFFF0000000000000000FFFFFFFFFF
FFFFFFFFFF000000FF0000FF00FFFF000000FFFFFF00FF00FFFFFF00FF00FFFFFF000000
FFFF00FF0000FF000000FFFFFFFFFF
FFFFFFFFFFFF00FF0000FFFFFFFFFFFFFF00FFFF00FF00FF00FF00FF00FF00FFFF00FFFF
FFFFFFFFFF0000FF00FFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFF00FFFFFF000000000000FF0000000000FF000000000000FF
FFFF00FFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFF00000000FF000000FFFFFF00FFFF00FF0000FFFF00FFFF0000FF00FFFF00FF
FFFF000000FF00000000FFFFFFFFFF
FFFFFFFFFF0000FF00000000FF000000FF0000FF0000FFFFFFFFFFFFFF0000FF0000FF00
0000FF00000000FF0000FFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FF000000FFFF0000FF00FFFFFFFFFFFFFF00FF0000FFFF00
0000FF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF00000000000000FF00FF000000FFFFFF000000FF00FF000000
00000000FF00FFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFF0000FFFFFFFFFF00FF00FFFF0000FF00FFFFFF00FF0000FFFF00FF00
FFFFFFFFFF0000FFFFFF0000FFFFFF
FFFFFF0000000000FFFFFFFF0000FF0000000000FFFFFF00FFFFFF00FFFFFF0000000000
FF0000FFFFFFFF0000000000FFFFFF
FFFFFFFF0000000000FFFF00000000FFFF000000FFFFFFFFFFFFFFFFFFFFFF000000FFFF
00000000FFFF0000000000FFFFFFFF
FFFFFFFF00000000FF00000000000000FF000000FFFFFFFFFFFFFFFFFFFFFF000000FF00
000000000000FF00000000FFFFFFFF
FFFFFF0000FFFF00FF00FF00FF000000FF00FFFF0000FF0000000000FF0000FFFF00FF00
0000FF00FF00FF00FFFF0000FFFFFF
FFFFFF00000000FF00000000000000FFFF00000000FFFFFF000000FFFFFF00000000FFFF
00000000000000FF00000000FFFFFF
FFFFFFFFFFFF000000000000FF00FFFFFFFF000000FFFF0000FF0000FFFF000000FFFFFF
FF00FF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF0000000000000000FFFF00000000FFFF00000000000000FFFF00000000FF
FF0000000000000000FFFFFFFFFFFF
FFFFFF00000000FF00000000FFFF00FF00FF000000FF00FF000000FF00FF000000FF00FF
00FFFF00000000FF00000000FFFFFF
FFFFFF0000FFFF00FF0000FF00000000FFFFFFFF00FFFF0000FF0000FFFF00FFFFFFFF00
000000FF0000FF00FFFF0000FFFFFF
FFFFFFFF000000FF00000000FF000000FFFFFF000000000000FF000000000000FFFFFF00
0000FF00000000FF000000FFFFFFFF
FFFFFFFF000000FF00FFFF00FF000000FFFFFF0000FFFF0000FF0000FFFF0000FFFFFF00
0000FF00FFFF00FF000000FFFFFFFF
FFFFFF000000000000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFF000000000000FFFFFF
FFFFFF0000FFFF0000FFFF0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFF0000FFFF0000FFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.00440917 0.588183 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.0238095 0.0186741 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
51 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000000000000000000000FFFF
FFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000000000000000000000FFFF
FFFF0000FFFF00FF00FFFF00FF00FFFF00000000000000000000000000000000000000FF
FF00FF00FFFF00FF00FFFF0000FFFF
FFFF0000FF00FFFF00000000FFFF00FF00000000000000000000000000000000000000FF
00FFFF00000000FFFF00FF0000FFFF
FFFF000000FF00000000000000FF0000FFFF0000000000FF000000FF0000000000FFFF00
00FF00000000000000FF000000FFFF
FFFF0000FFFF000000FFFF000000FF00FF00FF00000000FF00FF00FF00000000FF00FF00
FF000000FFFF000000FFFF0000FFFF
FFFF000000000000FFFFFFFF0000000000000000000000FFFFFFFFFF0000000000000000
000000FFFFFFFF000000000000FFFF
FFFF0000FF0000FFFF0000FF0000FFFFFF00FFFF000000FFFFFFFFFF000000FFFF00FFFF
FF0000FF0000FFFF0000FF0000FFFF
FFFF0000FF0000FFFF0000FFFF000000FF00FFFF00FFFF00FFFFFF00FFFF00FFFF00FF00
0000FFFF0000FFFF0000FF0000FFFF
FFFF000000000000FFFFFF00FF0000FFFF0000FF0000FF00FFFFFF00FF0000FF0000FFFF
0000FF00FFFFFF000000000000FFFF
FFFF0000FFFF00000000FFFFFFFFFF000000FF0000FF00FF000000FF00FF0000FF000000
FFFFFFFFFF00000000FFFF0000FFFF
FFFF000000FFFF0000000000FFFFFF000000FF0000000000FFFFFF0000000000FF000000
FFFFFF0000000000FFFF000000FFFF
FFFF0000FF0000FF00FF0000FFFFFF0000FF0000FFFF000000FF000000FFFF0000FF0000
FFFFFF0000FF00FF0000FF0000FFFF
FFFF0000FFFF000000FF00FF000000000000FF000000FF0000FF0000FF000000FF000000
000000FF00FF000000FFFF0000FFFF
FFFF00000000FFFF00FFFFFF00000000FF00000000000000FFFFFF00000000000000FF00
000000FFFFFF00FFFF00000000FFFF
FFFF00000000FF00000000000000FF0000000000000000FF00FF00FF0000000000000000
FF00000000000000FF00000000FFFF
FFFFFFFF000000FF00FFFF00FFFF00FF000000000000000000FF000000000000000000FF
00FFFF00FFFF00FF000000FFFFFFFF
FFFFFFFF0000000000FFFFFF000000000000000000000000000000000000000000000000
000000FFFFFF0000000000FFFFFFFF
FFFFFFFF00000000000000000000FF0000000000FF0000FF000000FF0000FF0000000000
FF00000000000000000000FFFFFFFF
FFFFFFFF000000000000FF00FF00FF000000000000000000000000000000000000000000
FF00FF00FF000000000000FFFFFFFF
FFFFFFFF000000000000FFFF000000FF00000000000000000000000000000000000000FF
000000FFFF000000000000FFFFFFFF
FFFFFFFF0000FFFFFFFF0000FF00000000FF0000FF000000000000000000FF0000FF0000
0000FF0000FFFFFFFF0000FFFFFFFF
FFFFFFFF00000000FFFFFFFF00FF0000FF0000000000000000000000000000000000FF00
00FF00FFFFFFFF00000000FFFFFFFF
FFFFFFFF000000FFFFFFFFFF00FFFFFFFFFFFF00000000000000000000000000FFFFFFFF
FFFF00FFFFFFFFFF000000FFFFFFFF
FFFFFFFF00000000FFFFFFFF00FF0000FF0000000000000000000000000000000000FF00
00FF00FFFFFFFF00000000FFFFFFFF
FFFFFFFF0000FFFFFFFF0000FF00000000FF0000FF000000000000000000FF0000FF0000
0000FF0000FFFFFFFF0000FFFFFFFF
FFFFFFFF000000000000FFFF000000FF00000000000000000000000000000000000000FF
000000FFFF000000000000FFFFFFFF
FFFFFFFF000000000000FF00FF00FF000000000000000000000000000000000000000000
FF00FF00FF000000000000FFFFFFFF
FFFFFFFF00000000000000000000FF0000000000FF0000FF000000FF0000FF0000000000
FF00000000000000000000FFFFFFFF
FFFFFFFF0000000000FFFFFF000000000000000000000000000000000000000000000000
000000FFFFFF0000000000FFFFFFFF
FFFFFFFF000000FF00FFFF00FFFF00FF000000000000000000FF000000000000000000FF
00FFFF00FFFF00FF000000FFFFFFFF
FFFF00000000FF00000000000000FF0000000000000000FF00FF00FF0000000000000000
FF00000000000000FF00000000FFFF
FFFF00000000FFFF00FFFFFF00000000FF00000000000000FFFFFF00000000000000FF00
000000FFFFFF00FFFF00000000FFFF
FFFF0000FFFF000000FF00FF000000000000FF000000FF0000FF0000FF000000FF000000
000000FF00FF000000FFFF0000FFFF
FFFF0000FF0000FF00FF0000FFFFFF0000FF0000FFFF000000FF000000FFFF0000FF0000
FFFFFF0000FF00FF0000FF0000FFFF
FFFF000000FFFF0000000000FFFFFF000000FF0000000000FFFFFF0000000000FF000000
FFFFFF0000000000FFFF000000FFFF
FFFF0000FFFF00000000FFFFFFFFFF000000FF0000FF00FF000000FF00FF0000FF000000
FFFFFFFFFF00000000FFFF0000FFFF
FFFF000000000000FFFFFF00FF0000FFFF0000FF0000FF00FFFFFF00FF0000FF0000FFFF
0000FF00FFFFFF000000000000FFFF
FFFF0000FF0000FFFF0000FFFF000000FF00FFFF00FFFF00FFFFFF00FFFF00FFFF00FF00
0000FFFF0000FFFF0000FF0000FFFF
FFFF0000FF0000FFFF0000FF0000FFFFFF00FFFF000000FFFFFFFFFF000000FFFF00FFFF
FF0000FF0000FFFF0000FF0000FFFF
FFFF000000000000FFFFFFFF0000000000000000000000FFFFFFFFFF0000000000000000
000000FFFFFFFF000000000000FFFF
FFFF0000FFFF000000FFFF000000FF00FF00FF00000000FF00FF00FF00000000FF00FF00
FF000000FFFF000000FFFF0000FFFF
FFFF000000FF00000000000000FF0000FFFF0000000000FF000000FF0000000000FFFF00
00FF00000000000000FF000000FFFF
FFFF0000FF00FFFF00000000FFFF00FF00000000000000000000000000000000000000FF
00FFFF00000000FFFF00FF0000FFFF
FFFF0000FFFF00FF00FFFF00FF00FFFF00000000000000000000000000000000000000FF
FF00FF00FFFF00FF00FFFF0000FFFF
FFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000000000000000000000FFFF
FFFF00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000000000000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.00440917 0.782187 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.0238095 0.0186741 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
51 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000
0000000000000000000000000000FF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFF00FF0000000000FFFF0000000000FFFFFF00000000000000000000000000FFFFFF00
00000000FFFF0000000000FF00FFFF
FFFF00FF0000000000FFFF000000000000FFFF000000FFFFFF00FFFFFF000000FFFF0000
00000000FFFF0000000000FF00FFFF
FFFF00FF000000FFFFFFFFFF000000000000FFFF0000FFFF00FF00FFFF0000FFFF000000
000000FFFFFFFFFF000000FF00FFFF
FFFF00FF0000FFFF00000000FFFFFF000000FFFF00000000FF00FF00000000FFFF000000
FFFFFF00000000FFFF0000FF00FFFF
FFFF00FF0000FF0000FFFF00FFFF000000000000FF000000000000000000FF0000000000
00FFFF00FFFF0000FF0000FF00FFFF
FFFF00FFFFFFFF00FF00000000FFFF000000000000FF00FF00FF00FF00FF000000000000
FFFF00000000FF00FFFFFFFF00FFFF
FFFF00FFFFFFFF00FF000000000000FF00000000000000FF00FF00FF00000000000000FF
000000000000FF00FFFFFFFF00FFFF
FFFF00FF0000FF0000000000FF000000000000000000000000FF00000000000000000000
0000FF0000000000FF0000FF00FFFF
FFFF00FF000000FFFF0000FFFF000000FF000000FFFF000000FF000000FFFF000000FF00
0000FFFF0000FFFF000000FF00FFFF
FFFF00FF000000FFFFFF000000FFFF00FF000000000000FF000000FF000000000000FF00
FFFF000000FFFFFF000000FF00FFFF
FFFF00FF000000FF00FF000000FF00FFFF000000FF00FFFF000000FFFF00FF000000FFFF
00FF000000FF00FF000000FF00FFFF
FFFF00FF000000000000FF000000FFFFFF00FFFFFF00FFFF000000FFFF00FFFFFF00FFFF
FF000000FF000000000000FF00FFFF
FFFF00FFFF00000000000000FFFFFFFFFFFFFFFF00FFFF0000000000FFFF00FFFFFFFFFF
FFFFFF00000000000000FFFF00FFFF
FF0000FFFFFF00000000000000000000FFFF00000000FFFF000000FFFF00000000FFFF00
000000000000000000FFFFFF0000FF
FF000000FFFFFFFF00000000000000FFFF0000000000FFFF00FF00FFFF0000000000FFFF
00000000000000FFFFFFFF000000FF
FFFFFFFF0000FFFF00000000000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
00000000000000FFFF0000FFFFFFFF
FFFFFFFF00000000FF000000FF00FFFF000000FFFFFFFFFFFF00FFFFFFFFFFFF000000FF
FF00FF000000FF00000000FFFFFFFF
FFFFFFFF0000000000FF0000FF000000FF0000FFFFFFFFFFFF00FFFFFFFFFFFF0000FF00
0000FF0000FF0000000000FFFFFFFF
FFFFFFFF00FFFF00000000000000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFF
FF00000000000000FFFF00FFFFFFFF
FFFFFFFF00FFFF0000FFFF0000FFFFFF00FFFFFFFFFF00000000000000FFFFFFFFFF00FF
FFFF0000FFFF0000FFFF00FFFFFFFF
FFFFFFFF00FF00FF0000000000000000000000FFFFFF00000000000000FFFFFF00000000
00000000000000FF00FF00FFFFFFFF
FFFFFFFF0000FF0000FFFFFFFF0000000000FFFF0000000000000000000000FFFF000000
0000FFFFFFFF0000FF0000FFFFFFFF
FFFFFFFF00FF00FF0000000000000000000000FFFFFF00000000000000FFFFFF00000000
00000000000000FF00FF00FFFFFFFF
FFFFFFFF00FFFF0000FFFF0000FFFFFF00FFFFFFFFFF00000000000000FFFFFFFFFF00FF
FFFF0000FFFF0000FFFF00FFFFFFFF
FFFFFFFF00FFFF00000000000000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFF
FF00000000000000FFFF00FFFFFFFF
FFFFFFFF0000000000FF0000FF000000FF0000FFFFFFFFFFFF00FFFFFFFFFFFF0000FF00
0000FF0000FF0000000000FFFFFFFF
FFFFFFFF00000000FF000000FF00FFFF000000FFFFFFFFFFFF00FFFFFFFFFFFF000000FF
FF00FF000000FF00000000FFFFFFFF
FFFFFFFF0000FFFF00000000000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
00000000000000FFFF0000FFFFFFFF
FF000000FFFFFFFF00000000000000FFFF0000000000FFFF00FF00FFFF0000000000FFFF
00000000000000FFFFFFFF000000FF
FF0000FFFFFF00000000000000000000FFFF00000000FFFF000000FFFF00000000FFFF00
000000000000000000FFFFFF0000FF
FFFF00FFFF00000000000000FFFFFFFFFFFFFFFF00FFFF0000000000FFFF00FFFFFFFFFF
FFFFFF00000000000000FFFF00FFFF
FFFF00FF000000000000FF000000FFFFFF00FFFFFF00FFFF000000FFFF00FFFFFF00FFFF
FF000000FF000000000000FF00FFFF
FFFF00FF000000FF00FF000000FF00FFFF000000FF00FFFF000000FFFF00FF000000FFFF
00FF000000FF00FF000000FF00FFFF
FFFF00FF000000FFFFFF000000FFFF00FF000000000000FF000000FF000000000000FF00
FFFF000000FFFFFF000000FF00FFFF
FFFF00FF000000FFFF0000FFFF000000FF000000FFFF000000FF000000FFFF000000FF00
0000FFFF0000FFFF000000FF00FFFF
FFFF00FF0000FF0000000000FF000000000000000000000000FF00000000000000000000
0000FF0000000000FF0000FF00FFFF
FFFF00FFFFFFFF00FF000000000000FF00000000000000FF00FF00FF00000000000000FF
000000000000FF00FFFFFFFF00FFFF
FFFF00FFFFFFFF00FF00000000FFFF000000000000FF00FF00FF00FF00FF000000000000
FFFF00000000FF00FFFFFFFF00FFFF
FFFF00FF0000FF0000FFFF00FFFF000000000000FF000000000000000000FF0000000000
00FFFF00FFFF0000FF0000FF00FFFF
FFFF00FF0000FFFF00000000FFFFFF000000FFFF00000000FF00FF00000000FFFF000000
FFFFFF00000000FFFF0000FF00FFFF
FFFF00FF000000FFFFFFFFFF000000000000FFFF0000FFFF00FF00FFFF0000FFFF000000
000000FFFFFFFFFF000000FF00FFFF
FFFF00FF0000000000FFFF000000000000FFFF000000FFFFFF00FFFFFF000000FFFF0000
00000000FFFF0000000000FF00FFFF
FFFF00FF0000000000FFFF0000000000FFFFFF00000000000000000000000000FFFFFF00
00000000FFFF0000000000FF00FFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000
0000000000000000000000000000FF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.00440917 0.97619 0.180776 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.0238095 0.0186741 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
51 string
51 51 8 [51 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFF00000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFF00000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFF00000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF0000000000
000000000000000000000000000000
FFFFFF00000000000000000000000000FF00FF00000000FF000000FF00000000FF00FF00
000000000000000000000000FFFFFF
FFFFFF000000FFFF00000000FF0000FF00FFFF00FFFF00000000000000FFFF00FFFF00FF
0000FF00000000FFFF000000FFFFFF
FFFFFF0000FF0000000000000000FFFFFF00FF00FFFF00FF000000FF00FFFF00FF00FFFF
FF0000000000000000FF0000FFFFFF
FFFFFF0000FF000000000000000000FF00FF000000FFFF0000000000FFFF000000FF00FF
000000000000000000FF0000FFFFFF
FFFFFF00000000000000FF00000000FF00FFFF0000FFFFFF000000FFFFFF0000FFFF00FF
00000000FF00000000000000FFFFFF
FFFFFF00000000000000FFFF000000FFFF0000FFFFFF00FF00FF00FF00FFFFFF0000FFFF
000000FFFF00000000000000FFFFFF
FFFFFF0000000000FFFF00FFFF0000FFFF000000FFFF00FF000000FF00FFFF000000FFFF
0000FFFF00FFFF0000000000FFFFFF
FFFFFF000000000000FFFF0000FFFFFFFFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFFFF
FFFF0000FFFF000000000000FFFFFF
FFFFFF0000FF00000000FF000000FF00FFFF00FFFFFFFFFF00FF00FFFFFFFFFF00FFFF00
FF000000FF00000000FF0000FFFFFF
FFFFFF0000000000000000FF00000000000000FF0000000000FF0000000000FF00000000
000000FF0000000000000000FFFFFF
FFFFFF000000FF00000000FFFF00FF000000FF00000000000000000000000000FF000000
FF00FFFF00000000FF000000FFFFFF
FFFFFF0000FFFFFFFFFFFFFF0000000000FF00FF00FFFF00FF00FF00FFFF00FF00FF0000
000000FFFFFFFFFFFFFF0000FFFFFF
00000000FF00FF0000FFFFFFFF0000000000FF000000FF00FF00FF00FF000000FF000000
0000FFFFFFFF0000FF00FF00000000
0000000000FF00FFFF0000FFFF0000FF00FF00FFFF00FF0000FF0000FF00FFFF00FF00FF
0000FFFF0000FFFF00FF0000000000
00000000FFFFFF00FF0000000000FF00FF00FFFF00000000FF00FF00000000FFFF00FF00
FF0000000000FF00FFFFFF00000000
0000FF000000000000FF00FFFFFF00FF00FFFF00FF00000000FF00000000FF00FFFF00FF
00FFFFFF00FF000000000000FF0000
FFFFFFFF00FFFF0000FFFFFFFF00000000FF00FFFFFFFFFF000000FFFFFFFFFF00FF0000
0000FFFFFFFF0000FFFF00FFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFF0000FF00000000FF0000FF000000FF0000FF00000000FF
0000FFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFF000000FFFF0000FFFF0000FFFFFF0000FF000000FFFFFF000000FF0000FFFFFF
0000FFFF0000FFFF000000FFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFF00000000000000FFFF00000000000000FFFF0000000000
0000FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFF0000000000000000000000FFFF00FF000000FF0000000000FF000000FF00FFFF
0000000000000000000000FFFFFFFF
FFFFFFFF0000000000FF0000FFFF000000FF00FF0000FF0000000000FF0000FF00FF0000
00FFFF0000FF0000000000FFFFFFFF
FFFFFFFF0000000000000000000000FFFF00FF000000FF0000000000FF000000FF00FFFF
0000000000000000000000FFFFFFFF
FFFFFFFFFF00FF00FFFFFFFFFF00000000000000FFFF00000000000000FFFF0000000000
0000FFFFFFFFFF00FF00FFFFFFFFFF
FFFFFFFF000000FFFF0000FFFF0000FFFFFF0000FF000000FFFFFF000000FF0000FFFFFF
0000FFFF0000FFFF000000FFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFF0000FF00000000FF0000FF000000FF0000FF00000000FF
0000FFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFF00FFFF0000FFFFFFFF00000000FF00FFFFFFFFFF000000FFFFFFFFFF00FF0000
0000FFFFFFFF0000FFFF00FFFFFFFF
0000FF000000000000FF00FFFFFF00FF00FFFF00FF00000000FF00000000FF00FFFF00FF
00FFFFFF00FF000000000000FF0000
00000000FFFFFF00FF0000000000FF00FF00FFFF00000000FF00FF00000000FFFF00FF00
FF0000000000FF00FFFFFF00000000
0000000000FF00FFFF0000FFFF0000FF00FF00FFFF00FF0000FF0000FF00FFFF00FF00FF
0000FFFF0000FFFF00FF0000000000
00000000FF00FF0000FFFFFFFF0000000000FF000000FF00FF00FF00FF000000FF000000
0000FFFFFFFF0000FF00FF00000000
FFFFFF0000FFFFFFFFFFFFFF0000000000FF00FF00FFFF00FF00FF00FFFF00FF00FF0000
000000FFFFFFFFFFFFFF0000FFFFFF
FFFFFF000000FF00000000FFFF00FF000000FF00000000000000000000000000FF000000
FF00FFFF00000000FF000000FFFFFF
FFFFFF0000000000000000FF00000000000000FF0000000000FF0000000000FF00000000
000000FF0000000000000000FFFFFF
FFFFFF0000FF00000000FF000000FF00FFFF00FFFFFFFFFF00FF00FFFFFFFFFF00FFFF00
FF000000FF00000000FF0000FFFFFF
FFFFFF000000000000FFFF0000FFFFFFFFFF00FFFFFFFFFF000000FFFFFFFFFF00FFFFFF
FFFF0000FFFF000000000000FFFFFF
FFFFFF0000000000FFFF00FFFF0000FFFF000000FFFF00FF000000FF00FFFF000000FFFF
0000FFFF00FFFF0000000000FFFFFF
FFFFFF00000000000000FFFF000000FFFF0000FFFFFF00FF00FF00FF00FFFFFF0000FFFF
000000FFFF00000000000000FFFFFF
FFFFFF00000000000000FF00000000FF00FFFF0000FFFFFF000000FFFFFF0000FFFF00FF
00000000FF00000000000000FFFFFF
FFFFFF0000FF000000000000000000FF00FF000000FFFF0000000000FFFF000000FF00FF
000000000000000000FF0000FFFFFF
FFFFFF0000FF0000000000000000FFFFFF00FF00FFFF00FF000000FF00FFFF00FF00FFFF
FF0000000000000000FF0000FFFFFF
FFFFFF000000FFFF00000000FF0000FF00FFFF00FFFF00000000000000FFFF00FFFF00FF
0000FF00000000FFFF000000FFFFFF
FFFFFF00000000000000000000000000FF00FF00000000FF000000FF00000000FF00FF00
000000000000000000000000FFFFFF
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF0000000000
000000000000000000000000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFF00000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFF00000000
00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFF00000000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 53.3125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000=A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003UOol4000;Ool3000;Ool3000;Ool4000<Ool00:moo`8000eoo`80
00aoo`8000eoo`8000Qoo`@000]oo`<000]oo`<000]oo`@000aoo`00NGoo3`003Woo3`002Woo4@00
37oo4@0027oo10002goo0`002goo0`002goo100037oo0013Ool20002Ool00`00Oomoo`020002Ool2
000@Ool20002Ool20002Ool00`00Oomoo`02000<Ool?000>Ool?000;Ool00`00Oomoo`0<Ool00`00
Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`07OolB000;OolB000<Ool000ioo`<000Aoo`@0015o
o`@000Aoo`<000ioo`D0009oo`H0011oo`H0009oo`D000aoo`80009oo`07001oogooOol007oo0000
0Woo4P000Woo00<007oo00000goo00<007ooOol00P002goo00<007oo00000`000Woo1@000goo3000
0goo1@000Woo100000=oo`00Ool02goo300000=oo`00Ool00`0000Eoo`00000007oo00<00003Ool0
07oo00`000moo`003Woo0`0017oo10004Goo100017oo0`003goo0`000goo00<007oo00000P000goo
0P000Woo10000Woo0P000goo0`0000=oo`00Ool00Woo0`003Goo0P0000Aoo`00Oomoo`<0009oo`03
001oo`0001400004Ool007ooOol30002Ool01000Ool000002goo00<007oo00000`000Woo1P000Woo
0`001Woo0`000Woo1P000Woo100000=oo`00Ool02goo0`0000=oo`0000000P0000Eoo`00001oo`00
00Aoo`L000Aoo`05001oo`00001oo`04000017oo000000003goo000>Ool40002Ool50003Ool40003
Ool40003Ool50002Ool4000>Ool20002Ool300000goo000000020004Ool00`00Oomoo`040002Ool0
0`00Oomoo`02Ool4000017oo000000000Woo0P0037oo0P000Woo0P000Woo0`0000Eoo`00Ool007oo
00@00004Ool00000Ool400001Goo001oo`00Ool00`000Woo0P000Woo0P002goo00@007oo0000009o
o`<000=oo`<0009oo`@0009oo`@0009oo`<000=oo`<0009oo`800003Ool007oo00]oo`800003Ool0
000000H00003Ool007oo0080009oo`D0009oo`800003Ool007oo00P00003Ool0000000moo`0047oo
0P000Woo1@000goo0P000Woo0`000Woo0P000goo1@000Woo0P0047oo100000Aoo`000000009oo`04
001oo`00Ool300000goo001oo`0200000goo001oo`03000017oo001oo`000Woo0`0000=oo`000000
0P0037oo1P000goo2`0017oo2`000goo1P002goo00H007oo000007oo0002Ool00`00Oomoo`060000
0goo0000000600000goo000000040002Ool01@00Oomoo`00Ool00P0000=oo`00Ool02goo1P0000=o
o`0000000P0000Eoo`00Oomoo`0000=oo`<000=oo`05001oogoo001oo`0400000goo00000004000?
Ool001Ioo`P000=oo`04001oogooOol8000IOol70002Ool40002Ool60002Ool40002Ool7000?Ool2
000017oo000007oo0P0000=oo`0000000goo00<007ooOol00`0017oo0`000Woo00@007ooOomoo`80
0004Ool00000Ool200000goo0000000;Ool00`00Oomoo`02Ool50002Ool600000goo001oo`020000
0goo001oo`060002Ool50004Ool00`00Oomoo`0:Ool60002Ool30002Ool20002Ool01`00Ool007oo
001oo`00009oo`80009oo`<0009oo`H000moo`005goo00<007oo00001`0000=oo`0000001P0000=o
o`00Ool06Goo1@0000=oo`00Ool00goo0`000Woo10000Woo0`0017oo00<007oo000010003goo0P00
00Aoo`00001oo`80009oo`<00005Ool007ooOol00002Ool01000Oomoo`000Woo00D007ooOol007oo
00<0009oo`800004Ool00000Ool2000;Ool00`00Oomoo`02Ool700000goo00000005000017oo0000
07oo1`0000=oo`0000001@0017oo00<007ooOol02Woo10000Woo00<007ooOol00P000Woo0P000Woo
00<007oo00000P0000Aoo`00Oomoo`80009oo`80009oo`03001oogoo00@000moo`0047oo0P000Woo
00<007oo000010000Woo0`000goo0`000Woo1@0000Aoo`00Oomoo`80011oo`@00003Ool0000000@0
009oo`@000=oo`8000=oo`@0009oo`H00003Ool00000008000aoo`H0009oo`04001oo`000002Ool2
00001Goo000007oo00000Woo00D007oo000007oo0080009oo`800004Ool007ooOol6000;Ool01@00
Ool00000Ool0100000=oo`0000005P0000=oo`0000000P0000Eoo`00001oo`0000aoo`D0009oo`80
00Eoo`03001oogoo009oo`<000Aoo`03001oogoo00=oo`80009oo`D000moo`003Woo10000goo0P00
00=oo`0000000Woo0P0000Aoo`00001oo`800003Ool00000009oo`800003Ool0000000=oo`@000io
o`80009oo`800003Ool007oo00<00004Ool007ooOol200000goo0000000200000goo00000002Ool0
0`00Ool0000200000goo001oo`020002Ool2000<Ool20002Ool30005Ool300001Woo000007oo001o
o`800003Ool007oo00800004Ool000000005Ool30002Ool2000;Ool00`00Ool0000200000goo0000
0002Ool3000017oo000000000Woo1P000Woo0`0000Aoo`000000009oo`800006Ool00000001oo`00
37oo0P0000Eoo`00000007oo00<00005Ool007ooOol00004Ool00`00Ool00004Ool01@00Oomoo`00
Ool00`0000Eoo`00000007oo008000moo`003Woo1@0000Aoo`000000009oo`800004Ool00000Ool2
000017oo000007oo0P0000=oo`0000000Woo0`0000=oo`0000000`003goo2`0000Aoo`00000000Yo
o`<00003Ool0000000T000eoo`<0009oo`@000=oo`<00003Ool0000000<0009oo`D00004Ool00000
0003Ool40002Ool3000;Ool00`00Ool000020002Ool30002Ool00`00Ool00005000017oo000007oo
1P0000Aoo`00Oomoo`<0009oo`<00003Ool007oo00]oo`L00003Ool0000000X00003Ool0000000X0
0003Ool0000000D000moo`003Woo1`000Woo100000=oo`0000002@0000=oo`0000000P000Woo1`00
3goo10000Woo10000Woo0`002Woo0`000Woo10000Woo10003Goo0P0000=oo`0000000Woo0P000goo
0P0000=oo`0000000Woo1P000Woo0P0000=oo`0000000goo0P000Woo0P0000=oo`0000002goo00<0
07oo00000P000Woo0`0000Aoo`00Oomoo`<00004Ool007ooOol20002Ool00`00Ool000020002Ool0
0`00Ool000020002Ool300000goo001oo`0;Ool70002Ool00`00Ool0000200000goo000000090000
1Woo00000000Ool0009oo`L000moo`003Woo1@0000Aoo`00001oo`@00004Ool00000Ool5000017oo
000007oo100000Aoo`00001oo`D000ioo`D000=oo`800003Ool0000000<000=oo`04001oogoo0003
Ool500000goo00000003Ool5000<Ool20002Ool200000goo001oo`0600001Goo00000000Ool01000
00Eoo`00000007oo00H00003Ool007oo0080009oo`8000]oo`03001oo`0000@00004Ool000000003
Ool01@00Oomoogoo00000Woo0P000Woo00D007ooOomoo`0000=oo`<00003Ool0000000<00003Ool0
07oo00]oo`8000Ioo`D00003Ool00000009oo`05001oo`00Ool00002Ool200000goo000000030006
Ool2000?Ool0019oo`T0000:Ool00000Ool007oo001oo`00Ool200000goo00000007000BOol20003
Ool00`00Oomoo`03Ool00`00Ool00002Ool200001Woo001oogoo001oo`80009oo`03001oo`0000Eo
o`04001oogooOol2000<Ool40005Ool400000goo000000050002Ool700000goo000000020005Ool4
000;Ool00`00Oomoo`060008Ool00`00Oomoo`040002Ool00`00Oomoo`06Ool60002Ool00`00Oomo
o`07Ool4000017oo0000000017oo1@0000Yoo`00001oo`00Ool007oo001oo`800003Ool0000000<0
00Aoo`<00003Ool00000008000aoo`004Woo0`0000=oo`0000000P0000=oo`00Ool02@0000=oo`00
Ool0100000Aoo`00000001Moo`03001oo`0000H00003Ool007oo00<0009oo`<00003Ool007oo00L0
0003Ool007oo011oo`@00003Ool0000000@00003Ool0000000H00004Ool00000Ool800000goo0000
000400000goo00000002000:Ool20003Ool90002Ool40002Ool20002Ool40002Ool90003Ool20008
Ool50003Ool20002Ool200001goo001oo`00Ool007oo0080000:Ool00000Ool007oo001oo`00Ool2
0002Ool20003Ool5000<Ool0019oo`8000Ioo`03001oogoo009oo`D000Aoo`03001oogoo00Aoo`80
01Moo`<00004Ool000000002Ool200000goo001oo`05Ool01000Ool000000Woo0`0000Aoo`000000
01=oo`<000=oo`05001oogoo001oo`0B00001Goo001oogoo00000goo0`0037oo0`0017oo1P000Woo
1@000Woo0P000Woo1@000Woo1P0017oo0`0027oo10000Woo00<007oo0000100000Eoo`00Ool007oo
00@00003Ool007oo00@00005Ool007oo001oo`05000017oo001oogoo100037oo000@Ool400000goo
000000030002Ool;0002Ool500000goo00000002000BOol3000017oo000000000goo00D007ooOol0
07oo008000Aoo`800005Ool007ooOol00003Ool3000017oo0000000047oo2@0000=oo`0000000`00
00Aoo`00001oo`800004Ool00000Ool500000goo00000007000?Ool7000017oo001oogoo0`0037oo
0`000Woo00<007oo00001P003goo00@007oo000000Aoo`@00003Ool007oo00=oo`<000Aoo`03001o
o`0000<000Aoo`800003Ool007oo00moo`0047oo2`0000=oo`0000000P0000=oo`00Ool0100000=o
o`0000002@004goo00<007ooOol00Woo00@007ooOomoo`H00003Ool0000000800003Ool0000000@0
00=oo`03001oogoo009oo`03001oogoo00moo`D00005Ool007oo001oo`0D00001Goo001oo`00Ool0
1@003goo100000Aoo`00001oo`<00003Ool0000000aoo`800005Ool00000001oo`0200000goo0000
0002000?Ool00`00Oomoo`05Ool200001Goo00000000Ool00P0000Eoo`00000007oo00800005Ool0
0000001oo`020007Ool00`00Oomoo`0>Ool0011oo`03001oogoo0080009oo`05001oogoo001oo`03
0002Ool00`00Oomoo`0300001Goo001oogoo00000Woo0P000Woo00<007ooOol04Goo00<007oo0000
1goo00L007ooOol007oo001oo`02000017oo001oo`000Woo00<007ooOol01Goo00<007oo00004Goo
1@000Woo0`0000=oo`000000400000Aoo`000000009oo`D000moo`03001oogoo00H000Qoo`H000Qo
o`H0009oo`03001oogoo00eoo`80009oo`80009oo`8000=oo`03001oo`00008000=oo`<00003Ool0
07oo009oo`80009oo`80009oo`80011oo`0047oo00<007ooOol02`000goo00@007ooOomoo`/0009o
o`03001oogoo011oo`D00004Ool007ooOol30003Ool00`00Ool00002Ool00`00Ool00003Ool30002
Ool00`00Ool00004000@Ool20003Ool200000goo00000002000017oo000007oo200000Aoo`00001o
o`@00003Ool0000000=oo`8000moo`04001oogoo0002Ool20003Ool00`00Oomoo`03Ool60005Ool0
1000Oomoogoo0P000Woo00@007ooOol0011oo`8000Eoo`H0009oo`L0009oo`H000Eoo`80015oo`00
4Goo00@007oo001oo`@00004Ool000000004Ool00`00Oomoo`02Ool300000goo00000002000017oo
001oo`004goo1`0027oo0P0000Aoo`00001oo`8000Qoo`L0011oo`@000=oo`05001oo`00001oo`0@
00001Goo000007oo00000goo10003goo00@007oo001oo`X000=oo`H000=oo`X00004Ool007oo000?
Ool:0002Ool01@00Ool00000Ool01@0000Eoo`00001oo`00009oo`X0011oo`004Goo0P0017oo5@00
17oo0P005Woo00@007oo000000Moo`80009oo`80009oo`8000Moo`800003Ool007oo019oo`<000Ao
o`03001oogoo00Aoo``000Ioo`03001oogoo009oo`<000moo`800003Ool007oo00=oo`D0009oo`X0
009oo`D000Aoo`04001oo`00000?Ool400000goo00000002Ool300001Goo00000000Ool01@0000Eo
o`00000007oo00<0009oo`800003Ool000000080011oo`004Goo00@007oo001oo`@00004Ool00000
0004Ool00`00Oomoo`02Ool300000goo00000002000017oo001oo`004goo1`0027oo0P0000Aoo`00
001oo`8000Qoo`L0011oo`@000=oo`05001oo`00001oo`0@00001Goo000007oo00000goo10003goo
00@007oo001oo`X000=oo`H000=oo`X00004Ool007oo000?Ool:0002Ool01@00Ool00000Ool01@00
00Eoo`00001oo`00009oo`X0011oo`0047oo00<007ooOol02`000goo00@007ooOomoo`/0009oo`03
001oogoo011oo`D00004Ool007ooOol30003Ool00`00Ool00002Ool00`00Ool00003Ool30002Ool0
0`00Ool00004000@Ool20003Ool200000goo00000002000017oo000007oo200000Aoo`00001oo`@0
0003Ool0000000=oo`8000moo`04001oogoo0002Ool20003Ool00`00Oomoo`03Ool60005Ool01000
Oomoogoo0P000Woo00@007ooOol0011oo`8000Eoo`H0009oo`L0009oo`H000Eoo`80015oo`0047oo
00<007ooOol00P000Woo00D007ooOol007oo00<0009oo`03001oogoo00<00005Ool007ooOol00002
Ool20002Ool00`00Oomoo`0AOol00`00Ool00007Ool01`00Oomoo`00Ool007oo00800004Ool007oo
0002Ool00`00Oomoo`05Ool00`00Ool0000AOol50002Ool300000goo0000000@000017oo00000000
0Woo1@003goo00<007ooOol01P0027oo1P0027oo1P000Woo00<007ooOol03Goo0P000Woo0P000Woo
0P000goo00<007oo00000P000goo0`0000=oo`00Ool00Woo0P000Woo0P000Woo0P0047oo000@Ool;
00000goo0000000200000goo001oo`0400000goo00000009000COol00`00Oomoo`02Ool01000Oomo
ogoo1P0000=oo`0000000P0000=oo`00000010000goo00<007ooOol00Woo00<007ooOol03goo1@00
00Eoo`00Ool007oo01@00005Ool007oo001oo`05000?Ool4000017oo000007oo0`0000=oo`000000
37oo0P0000Eoo`00000007oo00800003Ool00000008000moo`03001oogoo00Eoo`800005Ool00000
001oo`0200001Goo00000000Ool00P0000Eoo`00000007oo008000Moo`03001oogoo00ioo`0047oo
100000=oo`0000000`000Woo2`000Woo1@0000=oo`0000000P004Woo0`0000Aoo`00000000=oo`05
001oogoo001oo`020004Ool200001Goo001oogoo00000goo0`0000Aoo`000000011oo`T00003Ool0
000000<00004Ool00000Ool2000017oo000007oo1@0000=oo`0000001`003goo1`0000Aoo`00Oomo
o`<000aoo`<0009oo`03001oo`0000H000moo`04001oo`000004Ool400000goo001oo`03Ool30004
Ool00`00Ool000030004Ool200000goo001oo`0?Ool0019oo`8000Ioo`03001oogoo009oo`D000Ao
o`03001oogoo00Aoo`8001Moo`<00004Ool000000002Ool200000goo001oo`05Ool01000Ool00000
0Woo0`0000Aoo`00000001=oo`<000=oo`05001oogoo001oo`0B00001Goo001oogoo00000goo0`00
37oo0`0017oo1P000Woo1@000Woo0P000Woo1@000Woo1P0017oo0`0027oo10000Woo00<007oo0000
100000Eoo`00Ool007oo00@00003Ool007oo00@00005Ool007oo001oo`05000017oo001oogoo1000
37oo000BOol300000goo0000000200000goo001oo`0900000goo001oo`04000017oo000000005goo
00<007oo00001P0000=oo`00Ool00`000Woo0`0000=oo`00Ool01`0000=oo`00Ool047oo100000=o
o`000000100000=oo`0000001P0000Aoo`00001oo`P00003Ool0000000@00003Ool00000008000Yo
o`8000=oo`T0009oo`@0009oo`80009oo`@0009oo`T000=oo`8000Qoo`D000=oo`80009oo`800007
Ool007oo001oo`00Ool00P0000Yoo`00001oo`00Ool007oo001oo`80009oo`8000=oo`D000aoo`00
4Woo2@0000Yoo`00001oo`00Ool007oo001oo`800003Ool0000000L0019oo`8000=oo`03001oogoo
00=oo`03001oo`00009oo`800006Ool007ooOol007oo0P000Woo00<007oo00001Goo00@007ooOomo
o`8000aoo`@000Eoo`@00003Ool0000000D0009oo`L00003Ool00000008000Eoo`@000]oo`03001o
ogoo00H000Qoo`03001oogoo00@0009oo`03001oogoo00Ioo`H0009oo`03001oogoo00Moo`@00004
Ool000000004Ool500002Woo000007oo001oo`00Ool007oo0P0000=oo`0000000`0017oo0`0000=o
o`0000000P0037oo000>Ool5000017oo000007oo100000Aoo`00001oo`D00004Ool00000Ool40000
17oo000007oo1@003Woo1@000goo0P0000=oo`0000000`000goo00@007ooOol000=oo`D00003Ool0
000000=oo`D000aoo`80009oo`800003Ool007oo00H00005Ool00000001oo`0400001Goo00000000
Ool01P0000=oo`00Ool00P000Woo0P002goo00<007oo0000100000Aoo`00000000=oo`05001oogoo
Ool00002Ool20002Ool01@00Oomoogoo00000goo0`0000=oo`0000000`0000=oo`00Ool02goo0P00
1Woo1@0000=oo`0000000Woo00D007oo001oo`00009oo`800003Ool0000000<000Ioo`8000moo`00
3Woo1`000Woo100000=oo`0000002@0000=oo`0000000P000Woo1`003goo10000Woo10000Woo0`00
2Woo0`000Woo10000Woo10003Goo0P0000=oo`0000000Woo0P000goo0P0000=oo`0000000Woo1P00
0Woo0P0000=oo`0000000goo0P000Woo0P0000=oo`0000002goo00<007oo00000P000Woo0`0000Ao
o`00Oomoo`<00004Ool007ooOol20002Ool00`00Ool000020002Ool00`00Ool000020002Ool30000
0goo001oo`0;Ool70002Ool00`00Ool0000200000goo0000000900001Woo00000000Ool0009oo`L0
00moo`003Woo1@0000Aoo`000000009oo`800004Ool00000Ool2000017oo000007oo0P0000=oo`00
00000Woo0`0000=oo`0000000`003goo2`0000Aoo`00000000Yoo`<00003Ool0000000T000eoo`<0
009oo`@000=oo`<00003Ool0000000<0009oo`D00004Ool000000003Ool40002Ool3000;Ool00`00
Ool000020002Ool30002Ool00`00Ool00005000017oo000007oo1P0000Aoo`00Oomoo`<0009oo`<0
0003Ool007oo00]oo`L00003Ool0000000X00003Ool0000000X00003Ool0000000D000moo`003Woo
10000goo0P0000=oo`0000000Woo0P0000Aoo`00001oo`800003Ool00000009oo`800003Ool00000
00=oo`@000ioo`80009oo`800003Ool007oo00<00004Ool007ooOol200000goo0000000200000goo
00000002Ool00`00Ool0000200000goo001oo`020002Ool2000<Ool20002Ool30005Ool300001Woo
000007oo001oo`800003Ool007oo00800004Ool000000005Ool30002Ool2000;Ool00`00Ool00002
00000goo00000002Ool3000017oo000000000Woo1P000Woo0`0000Aoo`000000009oo`800006Ool0
0000001oo`0037oo0P0000Eoo`00000007oo00<00005Ool007ooOol00004Ool00`00Ool00004Ool0
1@00Oomoo`00Ool00`0000Eoo`00000007oo008000moo`0047oo0P000Woo00<007oo000010000Woo
0`000goo0`000Woo1@0000Aoo`00Oomoo`80011oo`@00003Ool0000000@0009oo`@000=oo`8000=o
o`@0009oo`H00003Ool00000008000aoo`H0009oo`04001oo`000002Ool200001Goo000007oo0000
0Woo00D007oo000007oo0080009oo`800004Ool007ooOol6000;Ool01@00Ool00000Ool0100000=o
o`0000005P0000=oo`0000000P0000Eoo`00001oo`0000aoo`D0009oo`8000Eoo`03001oogoo009o
o`<000Aoo`03001oogoo00=oo`80009oo`D000moo`005goo00<007oo00001`0000=oo`0000001P00
00=oo`00Ool06Goo1@0000=oo`00Ool00goo0`000Woo10000Woo0`0017oo00<007oo000010003goo
0P0000Aoo`00001oo`80009oo`<00005Ool007ooOol00002Ool01000Oomoo`000Woo00D007ooOol0
07oo00<0009oo`800004Ool00000Ool2000;Ool00`00Oomoo`02Ool700000goo00000005000017oo
000007oo1`0000=oo`0000001@0017oo00<007ooOol02Woo10000Woo00<007ooOol00P000Woo0P00
0Woo00<007oo00000P0000Aoo`00Oomoo`80009oo`80009oo`03001oogoo00@000moo`005Woo2000
0goo00@007ooOomoo`P001Uoo`L0009oo`@0009oo`H0009oo`@0009oo`L000moo`800004Ool00000
Ool200000goo00000003Ool00`00Oomoo`030004Ool30002Ool01000Oomoogoo0P0000Aoo`00001o
o`800003Ool0000000]oo`03001oogoo009oo`D0009oo`H00003Ool007oo00800003Ool007oo00H0
009oo`D000Aoo`03001oogoo00Yoo`H0009oo`<0009oo`80009oo`07001oo`00Ool007oo00000Woo
0P000Woo0`000Woo1P003goo000@Ool20002Ool50003Ool20002Ool30002Ool20003Ool50002Ool2
000@Ool4000017oo000000000Woo00@007oo001oo`<00003Ool007oo00800003Ool007oo00<00004
Ool007oo0002Ool300000goo00000002000<Ool60003Ool;0004Ool;0003Ool6000;Ool01P00Ool0
0000Ool0009oo`03001oogoo00H00003Ool0000000H00003Ool0000000@0009oo`05001oogoo001o
o`0200000goo001oo`0;Ool600000goo0000000200001Goo001oogoo00000goo0`000goo00D007oo
Ool007oo00@00003Ool0000000@000moo`003Woo10000Woo1@000goo10000goo10000goo1@000Woo
10003Woo0P000Woo0`0000=oo`0000000P0017oo00<007ooOol010000Woo00<007ooOol00Woo1000
00Aoo`000000009oo`8000aoo`80009oo`80009oo`<00005Ool007oo001oo`04000017oo000007oo
100000Eoo`00Ool007oo00<0009oo`80009oo`8000]oo`04001oo`000002Ool30003Ool30002Ool4
0002Ool40002Ool30003Ool30002Ool200000goo001oo`0;Ool200000goo0000000600000goo001o
o`020002Ool50002Ool200000goo001oo`0800000goo0000000?Ool000ioo`<000Aoo`@0015oo`@0
00Aoo`<000moo`<000=oo`03001oo`00008000=oo`80009oo`@0009oo`8000=oo`<00003Ool007oo
009oo`<000eoo`800004Ool007ooOol30002Ool00`00Ool0000A000017oo001oogoo0`000Woo00@0
07oo000000]oo`03001oo`0000<0009oo`H0009oo`<000Ioo`<0009oo`H0009oo`@00003Ool007oo
00]oo`<00003Ool0000000800005Ool00000Ool00004Ool70004Ool01@00Ool00000Ool0100000Ao
o`00000000moo`003Woo0`0017oo10004Goo100017oo0`003Woo1@000Woo1P0047oo1P000Woo1@00
37oo0P000Woo00L007ooOomoo`00Ool00002OolB0002Ool00`00Ool00003Ool00`00Oomoo`02000;
Ool00`00Ool000030002Ool50003Ool<0003Ool50002Ool400000goo001oo`0;Ool<00000goo001o
o`0300001Goo00000000Ool00`0000=oo`00Ool030003goo0013Ool20002Ool00`00Oomoo`020002
Ool2000@Ool20002Ool20002Ool00`00Oomoo`02000<Ool?000>Ool?000;Ool00`00Oomoo`0<Ool0
0`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`07OolB000;OolB000<Ool007Uoo`l000ioo`l0
00Yooa4000aooa4000Qoo`@000]oo`<000]oo`<000]oo`@000aoo`00[goo0P003Goo0P0037oo0P00
3Goo0P0027oo10002goo0`002goo0`002goo100037oo003UOol4000;Ool3000;Ool3000;Ool4000<
Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {52.3125, 0}} -> {-0.167028, -0.023153, \
0.0185856, 0.0185856}, {{8.9375, 58.75}, {51.0625, 1.1875}} -> {-10.8835, \
-2.65267, 1.07504, 1.07504}, {{63.75, 113.563}, {51.0625, 1.1875}} -> \
{-69.8093, -2.65267, 1.07504, 1.07504}, {{118.563, 168.375}, {51.0625, \
1.1875}} -> {-128.735, -2.65267, 1.07504, 1.07504}, {{173.375, 223.188}, \
{51.0625, 1.1875}} -> {-187.661, -2.65267, 1.07504, 1.07504}, {{228.188, \
278}, {51.0625, 1.1875}} -> {-246.587, -2.65267, 1.07504, 1.07504}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(example = 
      CellularAutomaton[{630, {2, 1}, {1, 1}}, {{{1}}, 0}, 2]\)], "Input"],

Cell[BoxData[
    \({{{0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 1, 0, 0}, {0, 0, 0, 0, 
          0}, {0, 0, 0, 0, 0}}, {{0, 0, 0, 0, 0}, {0, 1, 1, 1, 0}, {0, 1, 1, 
          1, 0}, {0, 1, 1, 1, 0}, {0, 0, 0, 0, 0}}, {{1, 1, 0, 1, 1}, {1, 1, 
          1, 1, 1}, {0, 1, 1, 1, 0}, {1, 1, 1, 1, 1}, {1, 1, 0, 1, 
          1}}}\)], "Output"]
}, Open  ]],

Cell["We can also illustrate this evolution in three dimensions.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show\ @\ RasterGraphics3D[\ example\ ];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.22314e-017 1.05023 -0.0446497 1.05023 [
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.57806 .54122 m .49383 .567 L .44643 .51878 L p .665 .739 .905 r
F P
0 g
s
.57936 .62233 m .57806 .54122 L .49383 .567 L p .573 .367 .563 r
F P
0 g
s
.49383 .567 m .49308 .64745 L .57936 .62233 L p .573 .367 .563 r
F P
0 g
s
.44643 .51878 m .49383 .567 L .49308 .64745 L p .948 .687 .507 r
F P
0 g
s
.66494 .51464 m .57806 .54122 L .53238 .49147 L p .665 .739 .905 r
F P
0 g
s
.66842 .59639 m .66494 .51464 L .57806 .54122 L p .573 .367 .563 r
F P
0 g
s
.57806 .54122 m .57936 .62233 L .66842 .59639 L p .573 .367 .563 r
F P
0 g
s
.44643 .51878 m .53238 .49147 L .57806 .54122 L p .665 .739 .905 r
F P
0 g
s
.53238 .49147 m .57806 .54122 L .57936 .62233 L p .958 .688 .482 r
F P
0 g
s
.53238 .49147 m .57806 .54122 L .57936 .62233 L p .958 .688 .482 r
F P
0 g
s
.49308 .64745 m .44447 .60043 L .44643 .51878 L p .948 .687 .507 r
F P
0 g
s
.57936 .62233 m .49308 .64745 L .44447 .60043 L p .659 .747 .915 r
F P
0 g
s
.53257 .57378 m .53238 .49147 L .44643 .51878 L p .564 .354 .554 r
F P
0 g
s
.44643 .51878 m .44447 .60043 L .53257 .57378 L p .564 .354 .554 r
F P
0 g
s
.53238 .49147 m .44643 .51878 L .39618 .46767 L p .665 .739 .905 r
F P
0 g
s
.53257 .57378 m .53238 .49147 L .44643 .51878 L p .564 .354 .554 r
F P
0 g
s
.44643 .51878 m .44447 .60043 L .53257 .57378 L p .564 .354 .554 r
F P
0 g
s
.39618 .46767 m .44643 .51878 L .44447 .60043 L p .948 .687 .507 r
F P
0 g
s
.53238 .49147 m .62113 .46328 L .66494 .51464 L p .665 .739 .905 r
F P
0 g
s
.62113 .46328 m .66494 .51464 L .66842 .59639 L p .966 .687 .452 r
F P
0 g
s
.57936 .62233 m .53257 .57378 L .53238 .49147 L p .958 .688 .482 r
F P
0 g
s
.57936 .62233 m .53257 .57378 L .53238 .49147 L p .958 .688 .482 r
F P
0 g
s
.66842 .59639 m .57936 .62233 L .53257 .57378 L p .659 .747 .915 r
F P
0 g
s
.44447 .60043 m .53257 .57378 L .57936 .62233 L p .659 .747 .915 r
F P
0 g
s
.6236 .54623 m .62113 .46328 L .53238 .49147 L p .564 .354 .554 r
F P
0 g
s
.53238 .49147 m .53257 .57378 L .6236 .54623 L p .564 .354 .554 r
F P
0 g
s
.62113 .46328 m .53238 .49147 L .48392 .43869 L p .665 .739 .905 r
F P
0 g
s
.6236 .54623 m .62113 .46328 L .53238 .49147 L p .564 .354 .554 r
F P
0 g
s
.53238 .49147 m .53257 .57378 L .6236 .54623 L p .564 .354 .554 r
F P
0 g
s
.39618 .46767 m .48392 .43869 L .53238 .49147 L p .665 .739 .905 r
F P
0 g
s
.48392 .43869 m .53238 .49147 L .53257 .57378 L p .958 .688 .482 r
F P
0 g
s
.48392 .43869 m .53238 .49147 L .53257 .57378 L p .958 .688 .482 r
F P
0 g
s
.84721 .45886 m .75461 .48719 L .71282 .43415 L p .665 .739 .905 r
F P
0 g
s
.8555 .54191 m .84721 .45886 L .75461 .48719 L p .573 .367 .563 r
F P
0 g
s
.75461 .48719 m .76042 .5696 L .8555 .54191 L p .573 .367 .563 r
F P
0 g
s
.71282 .43415 m .75461 .48719 L .76042 .5696 L p .973 .684 .414 r
F P
0 g
s
.44447 .60043 m .39288 .55053 L .39618 .46767 L p .948 .687 .507 r
F P
0 g
s
.53257 .57378 m .44447 .60043 L .39288 .55053 L p .659 .747 .915 r
F P
0 g
s
.53257 .57378 m .6236 .54623 L .66842 .59639 L p .659 .747 .915 r
F P
0 g
s
.66842 .59639 m .6236 .54623 L .62113 .46328 L p .966 .687 .452 r
F P
0 g
s
.48285 .52219 m .48392 .43869 L .39618 .46767 L p .555 .34 .543 r
F P
0 g
s
.39618 .46767 m .39288 .55053 L .48285 .52219 L p .555 .34 .543 r
F P
0 g
s
.71282 .43415 m .62113 .46328 L .57461 .40874 L p .665 .739 .905 r
F P
0 g
s
.71771 .51775 m .71282 .43415 L .62113 .46328 L p .564 .354 .554 r
F P
0 g
s
.62113 .46328 m .6236 .54623 L .71771 .51775 L p .564 .354 .554 r
F P
0 g
s
.48392 .43869 m .57461 .40874 L .62113 .46328 L p .665 .739 .905 r
F P
0 g
s
.57461 .40874 m .62113 .46328 L .6236 .54623 L p .966 .687 .452 r
F P
0 g
s
.57461 .40874 m .62113 .46328 L .6236 .54623 L p .966 .687 .452 r
F P
0 g
s
.94288 .42958 m .84721 .45886 L .80758 .40404 L p .665 .739 .905 r
F P
0 g
s
.95381 .51328 m .94288 .42958 L .84721 .45886 L p .573 .367 .563 r
F P
0 g
s
.84721 .45886 m .8555 .54191 L .95381 .51328 L p .573 .367 .563 r
F P
0 g
s
.71282 .43415 m .80758 .40404 L .84721 .45886 L p .665 .739 .905 r
F P
0 g
s
.80758 .40404 m .84721 .45886 L .8555 .54191 L p .976 .677 .368 r
F P
0 g
s
.80758 .40404 m .84721 .45886 L .8555 .54191 L p .976 .677 .368 r
F P
0 g
s
.53257 .57378 m .48285 .52219 L .48392 .43869 L p .958 .688 .482 r
F P
0 g
s
.53257 .57378 m .48285 .52219 L .48392 .43869 L p .958 .688 .482 r
F P
0 g
s
.6236 .54623 m .53257 .57378 L .48285 .52219 L p .659 .747 .915 r
F P
0 g
s
.62619 .63355 m .6236 .54623 L .53257 .57378 L p .564 .354 .554 r
F P
0 g
s
.53257 .57378 m .53276 .66034 L .62619 .63355 L p .564 .354 .554 r
F P
0 g
s
.39288 .55053 m .48285 .52219 L .53257 .57378 L p .659 .747 .915 r
F P
0 g
s
.48285 .52219 m .53257 .57378 L .53276 .66034 L p .958 .688 .482 r
F P
0 g
s
.6236 .54623 m .53257 .57378 L .48285 .52219 L p .659 .747 .915 r
F P
0 g
s
.76042 .5696 m .71771 .51775 L .71282 .43415 L p .973 .684 .414 r
F P
0 g
s
.8555 .54191 m .76042 .5696 L .71771 .51775 L p .659 .747 .915 r
F P
0 g
s
.57592 .49288 m .57461 .40874 L .48392 .43869 L p .555 .34 .543 r
F P
0 g
s
.48392 .43869 m .48285 .52219 L .57592 .49288 L p .555 .34 .543 r
F P
0 g
s
.57461 .40874 m .48392 .43869 L .43242 .38259 L p .665 .739 .905 r
F P
0 g
s
.57592 .49288 m .57461 .40874 L .48392 .43869 L p .555 .34 .543 r
F P
0 g
s
.48392 .43869 m .48285 .52219 L .57592 .49288 L p .555 .34 .543 r
F P
0 g
s
.43242 .38259 m .48392 .43869 L .48285 .52219 L p .958 .688 .482 r
F P
0 g
s
.81508 .48828 m .80758 .40404 L .71282 .43415 L p .564 .354 .554 r
F P
0 g
s
.71282 .43415 m .71771 .51775 L .81508 .48828 L p .564 .354 .554 r
F P
0 g
s
.80758 .40404 m .71282 .43415 L .66839 .37776 L p .665 .739 .905 r
F P
0 g
s
.81508 .48828 m .80758 .40404 L .71282 .43415 L p .564 .354 .554 r
F P
0 g
s
.71282 .43415 m .71771 .51775 L .81508 .48828 L p .564 .354 .554 r
F P
0 g
s
.57461 .40874 m .66839 .37776 L .71282 .43415 L p .665 .739 .905 r
F P
0 g
s
.66839 .37776 m .71282 .43415 L .71771 .51775 L p .973 .684 .414 r
F P
0 g
s
.66839 .37776 m .71282 .43415 L .71771 .51775 L p .973 .684 .414 r
F P
0 g
s
.80758 .40404 m .90559 .3729 L .94288 .42958 L p .665 .739 .905 r
F P
0 g
s
.90559 .3729 m .94288 .42958 L .95381 .51328 L p .973 .663 .31 r
F P
0 g
s
.6236 .54623 m .57592 .49288 L .57461 .40874 L p .966 .687 .452 r
F P
0 g
s
.6236 .54623 m .57592 .49288 L .57461 .40874 L p .966 .687 .452 r
F P
0 g
s
.71771 .51775 m .6236 .54623 L .57592 .49288 L p .659 .747 .915 r
F P
0 g
s
.72288 .60583 m .71771 .51775 L .6236 .54623 L p .564 .354 .554 r
F P
0 g
s
.6236 .54623 m .62619 .63355 L .72288 .60583 L p .564 .354 .554 r
F P
0 g
s
.48285 .52219 m .57592 .49288 L .6236 .54623 L p .659 .747 .915 r
F P
0 g
s
.48285 .52219 m .57592 .49288 L .6236 .54623 L p .659 .747 .915 r
F P
0 g
s
.57592 .49288 m .6236 .54623 L .62619 .63355 L p .966 .687 .452 r
F P
0 g
s
.71771 .51775 m .6236 .54623 L .57592 .49288 L p .659 .747 .915 r
F P
0 g
s
.57592 .49288 m .6236 .54623 L .62619 .63355 L p .966 .687 .452 r
F P
0 g
s
.8555 .54191 m .81508 .48828 L .80758 .40404 L p .976 .677 .368 r
F P
0 g
s
.8555 .54191 m .81508 .48828 L .80758 .40404 L p .976 .677 .368 r
F P
0 g
s
.95381 .51328 m .8555 .54191 L .81508 .48828 L p .659 .747 .915 r
F P
0 g
s
.71771 .51775 m .81508 .48828 L .8555 .54191 L p .659 .747 .915 r
F P
0 g
s
.43242 .38259 m .34283 .41341 L .28609 .35569 L p .665 .739 .905 r
F P
0 g
s
.42993 .46728 m .43242 .38259 L .34283 .41341 L p .544 .324 .532 r
F P
0 g
s
.34283 .41341 m .33802 .49746 L .42993 .46728 L p .544 .324 .532 r
F P
0 g
s
.28609 .35569 m .34283 .41341 L .33802 .49746 L p .948 .687 .507 r
F P
0 g
s
.67225 .46254 m .66839 .37776 L .57461 .40874 L p .555 .34 .543 r
F P
0 g
s
.57461 .40874 m .57592 .49288 L .67225 .46254 L p .555 .34 .543 r
F P
0 g
s
.66839 .37776 m .57461 .40874 L .52511 .35071 L p .665 .739 .905 r
F P
0 g
s
.67225 .46254 m .66839 .37776 L .57461 .40874 L p .555 .34 .543 r
F P
0 g
s
.57461 .40874 m .57592 .49288 L .67225 .46254 L p .555 .34 .543 r
F P
0 g
s
.43242 .38259 m .52511 .35071 L .57461 .40874 L p .665 .739 .905 r
F P
0 g
s
.52511 .35071 m .57461 .40874 L .57592 .49288 L p .966 .687 .452 r
F P
0 g
s
.52511 .35071 m .57461 .40874 L .57592 .49288 L p .966 .687 .452 r
F P
0 g
s
.91587 .45778 m .90559 .3729 L .80758 .40404 L p .564 .354 .554 r
F P
0 g
s
.80758 .40404 m .81508 .48828 L .91587 .45778 L p .564 .354 .554 r
F P
0 g
s
.90559 .3729 m .80758 .40404 L .76542 .34571 L p .665 .739 .905 r
F P
0 g
s
.91587 .45778 m .90559 .3729 L .80758 .40404 L p .564 .354 .554 r
F P
0 g
s
.80758 .40404 m .81508 .48828 L .91587 .45778 L p .564 .354 .554 r
F P
0 g
s
.66839 .37776 m .76542 .34571 L .80758 .40404 L p .665 .739 .905 r
F P
0 g
s
.76542 .34571 m .80758 .40404 L .81508 .48828 L p .976 .677 .368 r
F P
0 g
s
.76542 .34571 m .80758 .40404 L .81508 .48828 L p .976 .677 .368 r
F P
0 g
s
.53276 .66034 m .48172 .61015 L .48285 .52219 L p .958 .688 .482 r
F P
0 g
s
.62619 .63355 m .53276 .66034 L .48172 .61015 L p .652 .756 .926 r
F P
0 g
s
.5773 .5816 m .57592 .49288 L .48285 .52219 L p .555 .34 .543 r
F P
0 g
s
.48285 .52219 m .48172 .61015 L .5773 .5816 L p .555 .34 .543 r
F P
0 g
s
.48285 .52219 m .42993 .46728 L .43242 .38259 L p .958 .688 .482 r
F P
0 g
s
.57592 .49288 m .48285 .52219 L .42993 .46728 L p .659 .747 .915 r
F P
0 g
s
.5773 .5816 m .57592 .49288 L .48285 .52219 L p .555 .34 .543 r
F P
0 g
s
.48285 .52219 m .48172 .61015 L .5773 .5816 L p .555 .34 .543 r
F P
0 g
s
.42993 .46728 m .48285 .52219 L .48172 .61015 L p .958 .688 .482 r
F P
0 g
s
.57592 .49288 m .48285 .52219 L .42993 .46728 L p .659 .747 .915 r
F P
0 g
s
.71771 .51775 m .67225 .46254 L .66839 .37776 L p .973 .684 .414 r
F P
0 g
s
.71771 .51775 m .67225 .46254 L .66839 .37776 L p .973 .684 .414 r
F P
0 g
s
.81508 .48828 m .71771 .51775 L .67225 .46254 L p .659 .747 .915 r
F P
0 g
s
.82299 .57712 m .81508 .48828 L .71771 .51775 L p .564 .354 .554 r
F P
0 g
s
.71771 .51775 m .72288 .60583 L .82299 .57712 L p .564 .354 .554 r
F P
0 g
s
.57592 .49288 m .67225 .46254 L .71771 .51775 L p .659 .747 .915 r
F P
0 g
s
.57592 .49288 m .67225 .46254 L .71771 .51775 L p .659 .747 .915 r
F P
0 g
s
.67225 .46254 m .71771 .51775 L .72288 .60583 L p .973 .684 .414 r
F P
0 g
s
.81508 .48828 m .71771 .51775 L .67225 .46254 L p .659 .747 .915 r
F P
0 g
s
.67225 .46254 m .71771 .51775 L .72288 .60583 L p .973 .684 .414 r
F P
0 g
s
.81508 .48828 m .91587 .45778 L .95381 .51328 L p .659 .747 .915 r
F P
0 g
s
.95381 .51328 m .91587 .45778 L .90559 .3729 L p .973 .663 .31 r
F P
0 g
s
.52511 .43603 m .52511 .35071 L .43242 .38259 L p .544 .324 .532 r
F P
0 g
s
.43242 .38259 m .42993 .46728 L .52511 .43603 L p .544 .324 .532 r
F P
0 g
s
.52511 .35071 m .43242 .38259 L .37758 .32286 L p .665 .739 .905 r
F P
0 g
s
.52511 .43603 m .52511 .35071 L .43242 .38259 L p .544 .324 .532 r
F P
0 g
s
.43242 .38259 m .42993 .46728 L .52511 .43603 L p .544 .324 .532 r
F P
0 g
s
.28609 .35569 m .37758 .32286 L .43242 .38259 L p .665 .739 .905 r
F P
0 g
s
.37758 .32286 m .43242 .38259 L .42993 .46728 L p .958 .688 .482 r
F P
0 g
s
.37758 .32286 m .43242 .38259 L .42993 .46728 L p .958 .688 .482 r
F P
0 g
s
.77201 .43112 m .76542 .34571 L .66839 .37776 L p .555 .34 .543 r
F P
0 g
s
.66839 .37776 m .67225 .46254 L .77201 .43112 L p .555 .34 .543 r
F P
0 g
s
.76542 .34571 m .66839 .37776 L .62107 .31771 L p .665 .739 .905 r
F P
0 g
s
.77201 .43112 m .76542 .34571 L .66839 .37776 L p .555 .34 .543 r
F P
0 g
s
.66839 .37776 m .67225 .46254 L .77201 .43112 L p .555 .34 .543 r
F P
0 g
s
.52511 .35071 m .62107 .31771 L .66839 .37776 L p .665 .739 .905 r
F P
0 g
s
.62107 .31771 m .66839 .37776 L .67225 .46254 L p .973 .684 .414 r
F P
0 g
s
.62107 .31771 m .66839 .37776 L .67225 .46254 L p .973 .684 .414 r
F P
0 g
s
.76542 .34571 m .86588 .31253 L .90559 .3729 L p .665 .739 .905 r
F P
0 g
s
.86588 .31253 m .90559 .3729 L .91587 .45778 L p .973 .663 .31 r
F P
0 g
s
.62619 .63355 m .5773 .5816 L .57592 .49288 L p .966 .687 .452 r
F P
0 g
s
.62619 .63355 m .5773 .5816 L .57592 .49288 L p .966 .687 .452 r
F P
0 g
s
.72288 .60583 m .62619 .63355 L .5773 .5816 L p .652 .756 .926 r
F P
0 g
s
.48172 .61015 m .5773 .5816 L .62619 .63355 L p .652 .756 .926 r
F P
0 g
s
.33802 .49746 m .27957 .44091 L .28609 .35569 L p .948 .687 .507 r
F P
0 g
s
.42993 .46728 m .33802 .49746 L .27957 .44091 L p .659 .747 .915 r
F P
0 g
s
.67632 .55202 m .67225 .46254 L .57592 .49288 L p .555 .34 .543 r
F P
0 g
s
.57592 .49288 m .5773 .5816 L .67632 .55202 L p .555 .34 .543 r
F P
0 g
s
.57592 .49288 m .52511 .43603 L .52511 .35071 L p .966 .687 .452 r
F P
0 g
s
.57592 .49288 m .52511 .43603 L .52511 .35071 L p .966 .687 .452 r
F P
0 g
s
.67225 .46254 m .57592 .49288 L .52511 .43603 L p .659 .747 .915 r
F P
0 g
s
.67632 .55202 m .67225 .46254 L .57592 .49288 L p .555 .34 .543 r
F P
0 g
s
.57592 .49288 m .5773 .5816 L .67632 .55202 L p .555 .34 .543 r
F P
0 g
s
.42993 .46728 m .52511 .43603 L .57592 .49288 L p .659 .747 .915 r
F P
0 g
s
.42993 .46728 m .52511 .43603 L .57592 .49288 L p .659 .747 .915 r
F P
0 g
s
.52511 .43603 m .57592 .49288 L .5773 .5816 L p .966 .687 .452 r
F P
0 g
s
.67225 .46254 m .57592 .49288 L .52511 .43603 L p .659 .747 .915 r
F P
0 g
s
.52511 .43603 m .57592 .49288 L .5773 .5816 L p .966 .687 .452 r
F P
0 g
s
.81508 .48828 m .77201 .43112 L .76542 .34571 L p .976 .677 .368 r
F P
0 g
s
.81508 .48828 m .77201 .43112 L .76542 .34571 L p .976 .677 .368 r
F P
0 g
s
.91587 .45778 m .81508 .48828 L .77201 .43112 L p .659 .747 .915 r
F P
0 g
s
.67225 .46254 m .77201 .43112 L .81508 .48828 L p .659 .747 .915 r
F P
0 g
s
.67225 .46254 m .77201 .43112 L .81508 .48828 L p .659 .747 .915 r
F P
0 g
s
.77201 .43112 m .81508 .48828 L .82299 .57712 L p .976 .677 .368 r
F P
0 g
s
.37349 .40871 m .37758 .32286 L .28609 .35569 L p .531 .306 .518 r
F P
0 g
s
.28609 .35569 m .27957 .44091 L .37349 .40871 L p .531 .306 .518 r
F P
0 g
s
.37758 .32286 m .28609 .35569 L .2256 .29417 L p .665 .739 .905 r
F P
0 g
s
.37349 .40871 m .37758 .32286 L .28609 .35569 L p .531 .306 .518 r
F P
0 g
s
.28609 .35569 m .27957 .44091 L .37349 .40871 L p .531 .306 .518 r
F P
0 g
s
.2256 .29417 m .28609 .35569 L .27957 .44091 L p .948 .687 .507 r
F P
0 g
s
.62374 .40365 m .62107 .31771 L .52511 .35071 L p .544 .324 .532 r
F P
0 g
s
.52511 .35071 m .52511 .43603 L .62374 .40365 L p .544 .324 .532 r
F P
0 g
s
.62107 .31771 m .52511 .35071 L .47235 .28886 L p .665 .739 .905 r
F P
0 g
s
.62374 .40365 m .62107 .31771 L .52511 .35071 L p .544 .324 .532 r
F P
0 g
s
.52511 .35071 m .52511 .43603 L .62374 .40365 L p .544 .324 .532 r
F P
0 g
s
.37758 .32286 m .47235 .28886 L .52511 .35071 L p .665 .739 .905 r
F P
0 g
s
.47235 .28886 m .52511 .35071 L .52511 .43603 L p .966 .687 .452 r
F P
0 g
s
.47235 .28886 m .52511 .35071 L .52511 .43603 L p .966 .687 .452 r
F P
0 g
s
.87539 .39857 m .86588 .31253 L .76542 .34571 L p .555 .34 .543 r
F P
0 g
s
.76542 .34571 m .77201 .43112 L .87539 .39857 L p .555 .34 .543 r
F P
0 g
s
.62107 .31771 m .72046 .28352 L .76542 .34571 L p .665 .739 .905 r
F P
0 g
s
.72046 .28352 m .76542 .34571 L .77201 .43112 L p .976 .677 .368 r
F P
0 g
s
.48172 .61015 m .42731 .55664 L .42993 .46728 L p .958 .688 .482 r
F P
0 g
s
.5773 .5816 m .48172 .61015 L .42731 .55664 L p .652 .756 .926 r
F P
0 g
s
.72288 .60583 m .67632 .55202 L .67225 .46254 L p .973 .684 .414 r
F P
0 g
s
.72288 .60583 m .67632 .55202 L .67225 .46254 L p .973 .684 .414 r
F P
0 g
s
.82299 .57712 m .72288 .60583 L .67632 .55202 L p .652 .756 .926 r
F P
0 g
s
.5773 .5816 m .67632 .55202 L .72288 .60583 L p .652 .756 .926 r
F P
0 g
s
.52511 .52615 m .52511 .43603 L .42993 .46728 L p .544 .324 .532 r
F P
0 g
s
.42993 .46728 m .42731 .55664 L .52511 .52615 L p .544 .324 .532 r
F P
0 g
s
.42993 .46728 m .37349 .40871 L .37758 .32286 L p .958 .688 .482 r
F P
0 g
s
.42993 .46728 m .37349 .40871 L .37758 .32286 L p .958 .688 .482 r
F P
0 g
s
.52511 .43603 m .42993 .46728 L .37349 .40871 L p .659 .747 .915 r
F P
0 g
s
.52511 .52615 m .52511 .43603 L .42993 .46728 L p .544 .324 .532 r
F P
0 g
s
.42993 .46728 m .42731 .55664 L .52511 .52615 L p .544 .324 .532 r
F P
0 g
s
.27957 .44091 m .37349 .40871 L .42993 .46728 L p .659 .747 .915 r
F P
0 g
s
.37349 .40871 m .42993 .46728 L .42731 .55664 L p .958 .688 .482 r
F P
0 g
s
.52511 .43603 m .42993 .46728 L .37349 .40871 L p .659 .747 .915 r
F P
0 g
s
.77897 .52136 m .77201 .43112 L .67225 .46254 L p .555 .34 .543 r
F P
0 g
s
.67225 .46254 m .67632 .55202 L .77897 .52136 L p .555 .34 .543 r
F P
0 g
s
.67225 .46254 m .62374 .40365 L .62107 .31771 L p .973 .684 .414 r
F P
0 g
s
.67225 .46254 m .62374 .40365 L .62107 .31771 L p .973 .684 .414 r
F P
0 g
s
.77201 .43112 m .67225 .46254 L .62374 .40365 L p .659 .747 .915 r
F P
0 g
s
.77897 .52136 m .77201 .43112 L .67225 .46254 L p .555 .34 .543 r
F P
0 g
s
.67225 .46254 m .67632 .55202 L .77897 .52136 L p .555 .34 .543 r
F P
0 g
s
.52511 .43603 m .62374 .40365 L .67225 .46254 L p .659 .747 .915 r
F P
0 g
s
.52511 .43603 m .62374 .40365 L .67225 .46254 L p .659 .747 .915 r
F P
0 g
s
.62374 .40365 m .67225 .46254 L .67632 .55202 L p .973 .684 .414 r
F P
0 g
s
.77201 .43112 m .67225 .46254 L .62374 .40365 L p .659 .747 .915 r
F P
0 g
s
.62374 .40365 m .67225 .46254 L .67632 .55202 L p .973 .684 .414 r
F P
0 g
s
.77201 .43112 m .87539 .39857 L .91587 .45778 L p .659 .747 .915 r
F P
0 g
s
.91587 .45778 m .87539 .39857 L .86588 .31253 L p .973 .663 .31 r
F P
0 g
s
.47086 .37532 m .47235 .28886 L .37758 .32286 L p .531 .306 .518 r
F P
0 g
s
.37758 .32286 m .37349 .40871 L .47086 .37532 L p .531 .306 .518 r
F P
0 g
s
.47235 .28886 m .37758 .32286 L .31907 .25912 L p .665 .739 .905 r
F P
0 g
s
.47086 .37532 m .47235 .28886 L .37758 .32286 L p .531 .306 .518 r
F P
0 g
s
.37758 .32286 m .37349 .40871 L .47086 .37532 L p .531 .306 .518 r
F P
0 g
s
.2256 .29417 m .31907 .25912 L .37758 .32286 L p .665 .739 .905 r
F P
0 g
s
.31907 .25912 m .37758 .32286 L .37349 .40871 L p .958 .688 .482 r
F P
0 g
s
.31907 .25912 m .37758 .32286 L .37349 .40871 L p .958 .688 .482 r
F P
0 g
s
.726 .37008 m .72046 .28352 L .62107 .31771 L p .544 .324 .532 r
F P
0 g
s
.62107 .31771 m .62374 .40365 L .726 .37008 L p .544 .324 .532 r
F P
0 g
s
.72046 .28352 m .62107 .31771 L .57057 .25362 L p .665 .739 .905 r
F P
0 g
s
.726 .37008 m .72046 .28352 L .62107 .31771 L p .544 .324 .532 r
F P
0 g
s
.62107 .31771 m .62374 .40365 L .726 .37008 L p .544 .324 .532 r
F P
0 g
s
.47235 .28886 m .57057 .25362 L .62107 .31771 L p .665 .739 .905 r
F P
0 g
s
.57057 .25362 m .62107 .31771 L .62374 .40365 L p .973 .684 .414 r
F P
0 g
s
.57057 .25362 m .62107 .31771 L .62374 .40365 L p .973 .684 .414 r
F P
0 g
s
.5773 .5816 m .52511 .52615 L .52511 .43603 L p .966 .687 .452 r
F P
0 g
s
.5773 .5816 m .52511 .52615 L .52511 .43603 L p .966 .687 .452 r
F P
0 g
s
.67632 .55202 m .5773 .5816 L .52511 .52615 L p .652 .756 .926 r
F P
0 g
s
.68063 .6466 m .67632 .55202 L .5773 .5816 L p .555 .34 .543 r
F P
0 g
s
.5773 .5816 m .57876 .67529 L .68063 .6466 L p .555 .34 .543 r
F P
0 g
s
.42731 .55664 m .52511 .52615 L .5773 .5816 L p .652 .756 .926 r
F P
0 g
s
.52511 .52615 m .5773 .5816 L .57876 .67529 L p .966 .687 .452 r
F P
0 g
s
.67632 .55202 m .5773 .5816 L .52511 .52615 L p .652 .756 .926 r
F P
0 g
s
.67632 .55202 m .77897 .52136 L .82299 .57712 L p .652 .756 .926 r
F P
0 g
s
.82299 .57712 m .77897 .52136 L .77201 .43112 L p .976 .677 .368 r
F P
0 g
s
.27957 .44091 m .21716 .38054 L .2256 .29417 L p .948 .687 .507 r
F P
0 g
s
.37349 .40871 m .27957 .44091 L .21716 .38054 L p .659 .747 .915 r
F P
0 g
s
.62656 .49452 m .62374 .40365 L .52511 .43603 L p .544 .324 .532 r
F P
0 g
s
.52511 .43603 m .52511 .52615 L .62656 .49452 L p .544 .324 .532 r
F P
0 g
s
.52511 .43603 m .47086 .37532 L .47235 .28886 L p .966 .687 .452 r
F P
0 g
s
.52511 .43603 m .47086 .37532 L .47235 .28886 L p .966 .687 .452 r
F P
0 g
s
.62374 .40365 m .52511 .43603 L .47086 .37532 L p .659 .747 .915 r
F P
0 g
s
.62656 .49452 m .62374 .40365 L .52511 .43603 L p .544 .324 .532 r
F P
0 g
s
.52511 .43603 m .52511 .52615 L .62656 .49452 L p .544 .324 .532 r
F P
0 g
s
.37349 .40871 m .47086 .37532 L .52511 .43603 L p .659 .747 .915 r
F P
0 g
s
.37349 .40871 m .47086 .37532 L .52511 .43603 L p .659 .747 .915 r
F P
0 g
s
.47086 .37532 m .52511 .43603 L .52511 .52615 L p .966 .687 .452 r
F P
0 g
s
.62374 .40365 m .52511 .43603 L .47086 .37532 L p .659 .747 .915 r
F P
0 g
s
.47086 .37532 m .52511 .43603 L .52511 .52615 L p .966 .687 .452 r
F P
0 g
s
.62374 .40365 m .726 .37008 L .77201 .43112 L p .659 .747 .915 r
F P
0 g
s
.62374 .40365 m .726 .37008 L .77201 .43112 L p .659 .747 .915 r
F P
0 g
s
.726 .37008 m .77201 .43112 L .77897 .52136 L p .976 .677 .368 r
F P
0 g
s
.77201 .43112 m .726 .37008 L .72046 .28352 L p .976 .677 .368 r
F P
0 g
s
.31315 .3461 m .31907 .25912 L .2256 .29417 L p .517 .285 .503 r
F P
0 g
s
.2256 .29417 m .21716 .38054 L .31315 .3461 L p .517 .285 .503 r
F P
0 g
s
.57188 .34069 m .57057 .25362 L .47235 .28886 L p .531 .306 .518 r
F P
0 g
s
.47235 .28886 m .47086 .37532 L .57188 .34069 L p .531 .306 .518 r
F P
0 g
s
.31907 .25912 m .41599 .22278 L .47235 .28886 L p .665 .739 .905 r
F P
0 g
s
.41599 .22278 m .47235 .28886 L .47086 .37532 L p .966 .687 .452 r
F P
0 g
s
.82348 .24808 m .72046 .28352 L .67243 .21707 L p .665 .739 .905 r
F P
0 g
s
.8321 .33524 m .82348 .24808 L .72046 .28352 L p .544 .324 .532 r
F P
0 g
s
.72046 .28352 m .726 .37008 L .8321 .33524 L p .544 .324 .532 r
F P
0 g
s
.57057 .25362 m .67243 .21707 L .72046 .28352 L p .665 .739 .905 r
F P
0 g
s
.67243 .21707 m .72046 .28352 L .726 .37008 L p .976 .677 .368 r
F P
0 g
s
.67243 .21707 m .72046 .28352 L .726 .37008 L p .976 .677 .368 r
F P
0 g
s
.42731 .55664 m .36916 .49946 L .37349 .40871 L p .958 .688 .482 r
F P
0 g
s
.52511 .52615 m .42731 .55664 L .36916 .49946 L p .652 .756 .926 r
F P
0 g
s
.67632 .55202 m .62656 .49452 L .62374 .40365 L p .973 .684 .414 r
F P
0 g
s
.67632 .55202 m .62656 .49452 L .62374 .40365 L p .973 .684 .414 r
F P
0 g
s
.77897 .52136 m .67632 .55202 L .62656 .49452 L p .652 .756 .926 r
F P
0 g
s
.52511 .52615 m .62656 .49452 L .67632 .55202 L p .652 .756 .926 r
F P
0 g
s
.52511 .52615 m .62656 .49452 L .67632 .55202 L p .652 .756 .926 r
F P
0 g
s
.62656 .49452 m .67632 .55202 L .68063 .6466 L p .973 .684 .414 r
F P
0 g
s
.46928 .46682 m .47086 .37532 L .37349 .40871 L p .531 .306 .518 r
F P
0 g
s
.37349 .40871 m .36916 .49946 L .46928 .46682 L p .531 .306 .518 r
F P
0 g
s
.37349 .40871 m .31315 .3461 L .31907 .25912 L p .958 .688 .482 r
F P
0 g
s
.37349 .40871 m .31315 .3461 L .31907 .25912 L p .958 .688 .482 r
F P
0 g
s
.47086 .37532 m .37349 .40871 L .31315 .3461 L p .659 .747 .915 r
F P
0 g
s
.21716 .38054 m .31315 .3461 L .37349 .40871 L p .659 .747 .915 r
F P
0 g
s
.73186 .46169 m .726 .37008 L .62374 .40365 L p .544 .324 .532 r
F P
0 g
s
.62374 .40365 m .62656 .49452 L .73186 .46169 L p .544 .324 .532 r
F P
0 g
s
.62374 .40365 m .57188 .34069 L .57057 .25362 L p .973 .684 .414 r
F P
0 g
s
.62374 .40365 m .57188 .34069 L .57057 .25362 L p .973 .684 .414 r
F P
0 g
s
.726 .37008 m .62374 .40365 L .57188 .34069 L p .659 .747 .915 r
F P
0 g
s
.73186 .46169 m .726 .37008 L .62374 .40365 L p .544 .324 .532 r
F P
0 g
s
.62374 .40365 m .62656 .49452 L .73186 .46169 L p .544 .324 .532 r
F P
0 g
s
.47086 .37532 m .57188 .34069 L .62374 .40365 L p .659 .747 .915 r
F P
0 g
s
.47086 .37532 m .57188 .34069 L .62374 .40365 L p .659 .747 .915 r
F P
0 g
s
.57188 .34069 m .62374 .40365 L .62656 .49452 L p .973 .684 .414 r
F P
0 g
s
.726 .37008 m .62374 .40365 L .57188 .34069 L p .659 .747 .915 r
F P
0 g
s
.57188 .34069 m .62374 .40365 L .62656 .49452 L p .973 .684 .414 r
F P
0 g
s
.4128 .31035 m .41599 .22278 L .31907 .25912 L p .517 .285 .503 r
F P
0 g
s
.31907 .25912 m .31315 .3461 L .4128 .31035 L p .517 .285 .503 r
F P
0 g
s
.57876 .67529 m .52511 .62148 L .52511 .52615 L p .966 .687 .452 r
F P
0 g
s
.68063 .6466 m .57876 .67529 L .52511 .62148 L p .643 .765 .937 r
F P
0 g
s
.67675 .30473 m .67243 .21707 L .57057 .25362 L p .531 .306 .518 r
F P
0 g
s
.57057 .25362 m .57188 .34069 L .67675 .30473 L p .531 .306 .518 r
F P
0 g
s
.67243 .21707 m .57057 .25362 L .51656 .18508 L p .665 .739 .905 r
F P
0 g
s
.67675 .30473 m .67243 .21707 L .57057 .25362 L p .531 .306 .518 r
F P
0 g
s
.57057 .25362 m .57188 .34069 L .67675 .30473 L p .531 .306 .518 r
F P
0 g
s
.51656 .18508 m .57057 .25362 L .57188 .34069 L p .973 .684 .414 r
F P
0 g
s
.67243 .21707 m .77814 .17915 L .82348 .24808 L p .665 .739 .905 r
F P
0 g
s
.77814 .17915 m .82348 .24808 L .8321 .33524 L p .973 .663 .31 r
F P
0 g
s
.62956 .59074 m .62656 .49452 L .52511 .52615 L p .544 .324 .532 r
F P
0 g
s
.52511 .52615 m .52511 .62148 L .62956 .59074 L p .544 .324 .532 r
F P
0 g
s
.52511 .52615 m .46928 .46682 L .47086 .37532 L p .966 .687 .452 r
F P
0 g
s
.52511 .52615 m .46928 .46682 L .47086 .37532 L p .966 .687 .452 r
F P
0 g
s
.62656 .49452 m .52511 .52615 L .46928 .46682 L p .652 .756 .926 r
F P
0 g
s
.36916 .49946 m .46928 .46682 L .52511 .52615 L p .652 .756 .926 r
F P
0 g
s
.62656 .49452 m .73186 .46169 L .77897 .52136 L p .652 .756 .926 r
F P
0 g
s
.77897 .52136 m .73186 .46169 L .726 .37008 L p .976 .677 .368 r
F P
0 g
s
.57327 .43292 m .57188 .34069 L .47086 .37532 L p .531 .306 .518 r
F P
0 g
s
.47086 .37532 m .46928 .46682 L .57327 .43292 L p .531 .306 .518 r
F P
0 g
s
.31315 .3461 m .4128 .31035 L .47086 .37532 L p .659 .747 .915 r
F P
0 g
s
.47086 .37532 m .4128 .31035 L .41599 .22278 L p .966 .687 .452 r
F P
0 g
s
.726 .37008 m .67675 .30473 L .67243 .21707 L p .976 .677 .368 r
F P
0 g
s
.726 .37008 m .67675 .30473 L .67243 .21707 L p .976 .677 .368 r
F P
0 g
s
.8321 .33524 m .726 .37008 L .67675 .30473 L p .659 .747 .915 r
F P
0 g
s
.57188 .34069 m .67675 .30473 L .726 .37008 L p .659 .747 .915 r
F P
0 g
s
.57188 .34069 m .67675 .30473 L .726 .37008 L p .659 .747 .915 r
F P
0 g
s
.67675 .30473 m .726 .37008 L .73186 .46169 L p .976 .677 .368 r
F P
0 g
s
.52511 .62148 m .62956 .59074 L .68063 .6466 L p .643 .765 .937 r
F P
0 g
s
.68063 .6466 m .62956 .59074 L .62656 .49452 L p .973 .684 .414 r
F P
0 g
s
.78571 .26738 m .77814 .17915 L .67243 .21707 L p .531 .306 .518 r
F P
0 g
s
.67243 .21707 m .67675 .30473 L .78571 .26738 L p .531 .306 .518 r
F P
0 g
s
.77814 .17915 m .67243 .21707 L .62099 .14592 L p .665 .739 .905 r
F P
0 g
s
.78571 .26738 m .77814 .17915 L .67243 .21707 L p .531 .306 .518 r
F P
0 g
s
.67243 .21707 m .67675 .30473 L .78571 .26738 L p .531 .306 .518 r
F P
0 g
s
.51656 .18508 m .62099 .14592 L .67243 .21707 L p .665 .739 .905 r
F P
0 g
s
.62099 .14592 m .67243 .21707 L .67675 .30473 L p .976 .677 .368 r
F P
0 g
s
.62099 .14592 m .67243 .21707 L .67675 .30473 L p .976 .677 .368 r
F P
0 g
s
.62656 .49452 m .57327 .43292 L .57188 .34069 L p .973 .684 .414 r
F P
0 g
s
.62656 .49452 m .57327 .43292 L .57188 .34069 L p .973 .684 .414 r
F P
0 g
s
.73186 .46169 m .62656 .49452 L .57327 .43292 L p .652 .756 .926 r
F P
0 g
s
.46928 .46682 m .57327 .43292 L .62656 .49452 L p .652 .756 .926 r
F P
0 g
s
.68134 .39769 m .67675 .30473 L .57188 .34069 L p .531 .306 .518 r
F P
0 g
s
.57188 .34069 m .57327 .43292 L .68134 .39769 L p .531 .306 .518 r
F P
0 g
s
.57188 .34069 m .51631 .27322 L .51656 .18508 L p .973 .684 .414 r
F P
0 g
s
.67675 .30473 m .57188 .34069 L .51631 .27322 L p .659 .747 .915 r
F P
0 g
s
.67675 .30473 m .78571 .26738 L .8321 .33524 L p .659 .747 .915 r
F P
0 g
s
.8321 .33524 m .78571 .26738 L .77814 .17915 L p .973 .663 .31 r
F P
0 g
s
.62391 .23461 m .62099 .14592 L .51656 .18508 L p .517 .285 .503 r
F P
0 g
s
.51656 .18508 m .51631 .27322 L .62391 .23461 L p .517 .285 .503 r
F P
0 g
s
.62099 .14592 m .72951 .10523 L .77814 .17915 L p .665 .739 .905 r
F P
0 g
s
.72951 .10523 m .77814 .17915 L .78571 .26738 L p .973 .663 .31 r
F P
0 g
s
.57327 .43292 m .68134 .39769 L .73186 .46169 L p .652 .756 .926 r
F P
0 g
s
.73186 .46169 m .68134 .39769 L .67675 .30473 L p .976 .677 .368 r
F P
0 g
s
.67675 .30473 m .62391 .23461 L .62099 .14592 L p .976 .677 .368 r
F P
0 g
s
.67675 .30473 m .62391 .23461 L .62099 .14592 L p .976 .677 .368 r
F P
0 g
s
.78571 .26738 m .67675 .30473 L .62391 .23461 L p .659 .747 .915 r
F P
0 g
s
.51631 .27322 m .62391 .23461 L .67675 .30473 L p .659 .747 .915 r
F P
0 g
s
.73586 .19445 m .72951 .10523 L .62099 .14592 L p .517 .285 .503 r
F P
0 g
s
.62099 .14592 m .62391 .23461 L .73586 .19445 L p .517 .285 .503 r
F P
0 g
s
.62391 .23461 m .73586 .19445 L .78571 .26738 L p .659 .747 .915 r
F P
0 g
s
.78571 .26738 m .73586 .19445 L .72951 .10523 L p .973 .663 .31 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=A000`40O003h00OmGoo0P00LGoo003c
Ool200000goo0000001`Ool00?1oo`<000=oo`80071oo`00kWoo0P001Woo00<007oo0000Kgoo003[
Ool30008Ool01000Oomoo`00KWoo003YOol2000;Ool01000Oomoo`00KWoo003VOol3000=Ool01@00
Oomoogoo0000KGoo003TOol2000@Ool00`00Oomoo`02Ool00`00Oomoo`1ZOol00>5oo`<0019oo`03
001oogoo009oo`03001oogoo06Yoo`00gWoo0`005Goo00<007ooOol00goo00<007ooOol0JGoo003L
Ool2000IOol00`00Oomoo`02Ool00`00Oomoo`1YOol00=Uoo`<001]oo`03001oogoo00=oo`03001o
ogoo06Qoo`00egoo0P007Woo00<007ooOol017oo00<007ooOol0Igoo003DOol3000POol00`00Oomo
o`04Ool00`00Oomoo`1WOol00=9oo`8002=oo`03001oogoo00Eoo`03001oogoo06Ioo`00cgoo0`00
9Goo00<007ooOol01Woo00<007ooOol0IGoo003=Ool2000XOol00`00Oomoo`06Ool00`00Oomoo`1U
Ool00<Yoo`<002Yoo`03001oogoo00Moo`03001oogoo06Aoo`00b7oo0P00;Goo00<007ooOol027oo
00<007ooOol0Hgoo0035Ool3000_Ool00`00Oomoo`08Ool00`00Oomoo`1SOol00<=oo`80039oo`03
001oogoo00Uoo`03001oogoo069oo`00`7oo0`00=7oo00<007ooOol02Woo00<007ooOol0HGoo002n
Ool2000gOol00`00Oomoo`0:Ool00`00Oomoo`1QOol00;]oo`<003Uoo`03001oogoo00]oo`03001o
ogoo061oo`00^Goo0P00?7oo00<007ooOol037oo00<007ooOol0Ggoo002fOol3000nOol00`00Oomo
o`0<Ool00`00Oomoo`1OOol00;Aoo`80045oo`03001oogoo00eoo`03001oogoo05ioo`00/Goo0`00
@goo00<007ooOol03Goo00<007ooOol0GWoo002^Ool30017Ool00`00Oomoo`0=Ool00`00Oomoo`1M
Ool00:aoo`8004Yoo`03001oogoo00ioo`03001oogoo05aoo`00ZGoo0`00C7oo00<007ooOol03Woo
00<007ooOol0G7oo002WOol2001?Ool00`00Oomoo`0?Ool00`00Oomoo`1KOol00:Aoo`<0055oo`03
001oogoo011oo`03001oogoo05Yoo`00XWoo0P00E7oo00<007ooOol047oo00<007ooOol0FWoo002O
Ool3001FOol00`00Oomoo`0AOol00`00Oomoo`1IOol009eoo`8005Uoo`03001oogoo019oo`03001o
ogoo05Qoo`00VWoo0`00Fgoo00<007ooOol04Woo00<007ooOol0F7oo002HOol2001NOol00`00Oomo
o`0COol00`00Oomoo`1GOol009Eoo`<0061oo`03001oogoo00Uoo`8000Uoo`03001oogoo05Ioo`00
Tgoo0P00Hgoo00<007ooOol01Woo0`0000=1<000000027oo00<007ooOol0EWoo002@Ool3001UOol0
0`00Oomoo`04Ool20004@C020009Ool00`00Oomoo`1EOol008ioo`8006Qoo`04001oogooOol30006
@C000`00OZT00009Ool00`00Oomoo`1DOol008]oo`<006Yoo`@000U1<004001nZGjY0008Ool00`00
Oomoo`1DOol008Uoo`8006]oo`<000a1<004001nZGjY0009Ool00`00Oomoo`1COol008Ioo`<006Yo
o`<00091<0030011<44`00]1<004001nZGjY0008Ool00`00Oomoo`1COol008Aoo`8006]oo`8000E1
<0030011<44`00]1<005001nZGjYOZT00008Ool00`00Oomoo`1BOol0085oo`<006Yoo`<000Q1<003
0011<44`00Y1<003001nZGjY009nZ@03001oogoo00Ioo`03001oogoo055oo`00OWoo0`00JWoo0`00
2d4`00<0044`@C002T4`00<007jYOZT00WjY00<007ooOol01Woo00<007ooOol0DGoo001lOol2001Z
Ool3000>@C000`00@C11<00:@C000`00OZUnZ@03OZT00`00Oomoo`06Ool00`00Oomoo`1@Ool007Uo
o`<006Uoo`<00151<0030011<44`00Y1<003001nZGjY00AnZ@03001oogoo00Ioo`03001oogoo04mo
o`00Mgoo0P00JWoo0P00544`00<0044`@C002T4`00<007jYOZT017jY00<007ooOol01Woo00<007oo
Ool0Cgoo001dOol3001YOol3000F@C000`00@C11<00:@C000`00OZUnZ@05OZT00`00Oomoo`06Ool0
0`00Oomoo`1>Ool0079oo`8006Uoo`<001U1<0030011<44`00Y1<003001nZGjY00InZ@03001oogoo
00Ioo`03001oogoo04eoo`00Kgoo0`00JGoo0P0000=1<000@C006D4`00<0044`@C002T4`00<007jY
OZT01WjY00<007ooOol01Woo00<007ooOol0CGoo001]Ool2001YOol30003@C000`00@C11<00H@C00
0`00@C11<00:@C000`00OZUnZ@07OZT00`00Oomoo`06Ool00`00Oomoo`1<Ool006Yoo`<006Uoo`80
00I1<0030011<44`01Q1<0030011<44`00]1<003001nZGjY00MnZ@03001oogoo00Ioo`03001oogoo
04]oo`00J7oo0P00JGoo0`00244`00<0044`@C00644`00<0044`@C002d4`00<007jYOZT01gjY00<0
07ooOol01Woo00<007ooOol0Bgoo001UOol3001YOol2000;@C000`00@C11<00H@C000`00@C11<00;
@C000`00OZUnZ@08OZT00`00Oomoo`06Ool00`00Oomoo`1:Ool006=oo`8006Uoo`<000e1<0030011
<44`01Q1<0030011<44`00]1<003001nZGjY00UnZ@03001oogoo00Ioo`03001oogoo04Uoo`00H7oo
0`00JGoo0P00444`00<0044`@C00644`00<0044`@C002d4`00<007jYOZT02WjY00<007ooOol01Goo
00<007ooOol0BGoo001NOol2001ZOol2000B@C000`00@C11<00H@C000`00@C11<00;@C000`00OZUn
Z@0:OZT00`00Oomoo`06Ool00`00Oomoo`18Ool005]oo`<006Uoo`<001A1<0030011<44`01Q1<003
0011<44`00]1<003001nZGjY00]nZ@03001oogoo00Eoo`03001oogoo04Qoo`00FGoo0P00JWoo0P00
5d4`00<0044`@C00644`00<0044`@C002d4`00<007jYOZT037jY00<007ooOol01Goo00<007ooOol0
Agoo001FOol3001YOol3000I@C000`00@C11<00H@C000`00@C11<00;@C000`00OZUnZ@0<OZT00`00
Oomoo`06Ool00`00Oomoo`16Ool005=oo`<006Yoo`8001a1<0030011<44`01U1<0030011<44`00Y1
<003001nZGjY00enZ@03001oogoo00Eoo`03001oogoo04Ioo`00DGoo0P00JWoo0`007T4`00<0044`
@C006D4`00<0044`@C002d4`00<007jYOZT037jY0P001goo00<007ooOol0AGoo001>Ool3001ZOol2
000Q@C000`00@C11<00I@C000`00@C11<00;@C000`00OZUnZ@0<OZT20008Ool00`00Oomoo`14Ool0
04aoo`8006]oo`8002=1<0030011<44`01U1<0030011<44`00]1<003001nZGjY00anZ@03001nZ@00
00Moo`03001oogoo04Aoo`00BGoo0`00KGoo00<0044`@C008T4`00<0044`@C006D4`00<0044`@C00
2d4`00<007jYOZT037jY00@007jYOZT000Moo`03001oogoo04=oo`00Agoo0P00L7oo00<0044`@C00
8d4`00<0044`@C00644`00<0044`@C002d4`00<007jYOZT037jY00@007jYOZT000Qoo`03001oogoo
049oo`00A7oo0`00LWoo00<0044`@C008d4`00<0044`@C00644`00<0044`@C002T4`0P003gjY00@0
07jYOZT000Moo`03001oogoo049oo`00@Woo0P00MGoo00<0044`@C008d4`00<0044`@C00644`00<0
044`@C001d4`0`000UKm00<007jYOZT037jY00@007jYOZT000Qoo`03001oogoo045oo`00?goo0`00
Mgoo00<0044`@C008d4`00<0044`@C00644`00<0044`@C00144`0`001EKm00<007jYOZT037jY00D0
07jYOZUnZ@0000Qoo`03001oogoo041oo`00?Goo0P00NWoo00<0044`@C008d4`00<0044`@C00644`
00@0044`@C11<0<000UFo@03001nZGjY00]nZ@03001nZGjY009nZ@03001oogoo00Eoo`03001oogoo
041oo`00>Woo0`00O7oo00<0044`@C008d4`00<0044`@C00644`10003EKm00<007jYOZT02WjY00<0
07jYOZT00WjY00<007ooOol01Woo00<007ooOol0?goo000hOol2001oOol00`00@C11<00S@C000`00
@C11<00F@C03000@E_d00`00OZUnZ@0:OZT00`00OZUnZ@03OZT00`00Oomoo`06Ool00`00Oomoo`0n
Ool003Eoo`<0085oo`030011<44`02=1<0030011<44`01=1<0<0009Fo@03001FoEKm00mFo@03001n
ZGjY00UnZ@03001nZGjY00AnZ@03001oogoo00Eoo`03001oogoo03ioo`00<goo0P00Q7oo00<0044`
@C008d4`00<0044`@C004D4`0P001EKm00<005KmE_d045Km00<007jYOZT027jY00<007jYOZT017jY
00<007ooOol01Woo00<007ooOol0?Goo000`Ool30026Ool00`00@C11<00S@C000`00@C11<00>@C03
0007E_d00`00E_eFo@0AE_d00`00OZUnZ@07OZT00`00OZUnZ@05OZT00`00Oomoo`05Ool00`00Oomo
o`0mOol002ioo`8008Uoo`030011<44`02=1<0030011<44`00]1<0<000YFo@03001FoEKm015Fo@03
001nZGjY00MnZ@03001nZGjY00InZ@03001oogoo00Eoo`03001oogoo03aoo`00:goo0`00IWoo0P00
8goo00<0044`@C008d4`00<0044`@C00244`0`003EKm00<005KmE_d04UKm00<007jYOZT01WjY00<0
07jYOZT01WjY00<007ooOol01Woo00<007ooOol0>goo000YOol2001VOol300000d4`0000000ROol0
0`00@C11<00S@C000`00@C11<005@C03000@E_d00`00E_eFo@0CE_d00`00OZUnZ@06OZT00`00OZUn
Z@06OZT00`00Oomoo`05Ool00`00Oomoo`0kOol002Ioo`<006Ioo`8000A1<003001j[P00025oo`03
0011<44`02=1<0030011<44`0091<0<001AFo@03001FoEKm019Fo@03001nZGjY00InZ@03001nZGjY
00MnZ@03001oogoo00Eoo`03001oogoo03Yoo`008goo0`00IWoo0`001T4`00<007Z^00008Goo00<0
044`@C008d4`00<0044`00000P005eKm00<005KmE_d04eKm00<007jYOZT01GjY00<007jYOZT01gjY
00<007ooOol01Woo00<007ooOol0>Goo000QOol2001VOol30009@C001000NZij[P0087oo00<0044`
@C008T4`0`006UKm00<005KmE_d055Km00<007jYOZT017jY00<007jYOZT027jY00<007ooOol01Goo
00<007ooOol0>Goo000NOol3001VOol2000<@C001@00NZij[WZ^00007goo00<0044`@C007d4`0`00
0UKm00<005KmE_d065Km00<005KmE_d055Km00<007jYOZT017jY00<007jYOZT027jY00<007ooOol0
1Woo00<007ooOol0>7oo000LOol2001VOol3000>@C000`00NZij[P02NZh00`00Oomoo`0LOol00`00
@C11<00M@C020006E_d00`00E_eFo@0GE_d00`00E_eFo@0EE_d00`00OZUnZ@03OZT00`00OZUnZ@09
OZT00`00Oomoo`06Ool00`00Oomoo`0gOol001Uoo`<006Eoo`<00151<003001j[WZ^00=j[P03001o
ogoo01]oo`030011<44`01Y1<0<000QFo@03001FoEKm01MFo@03001FoEKm01IFo@03001nZGjY009n
Z@03001nZGjY00YnZ@03001oogoo00Eoo`03001oogoo03Moo`005goo0P00IWoo0P00544`00<007Z^
NZh017Z^00<007ooOol06Woo00<0044`@C005d4`0`0035Km00<005KmE_d05UKm00<005KmE_d05UKm
00<007jYOZT00WjY00<007jYOZT02WjY00<007ooOol01Woo00<007ooOol0=Woo000DOol3001UOol3
000F@C000`00NZij[P04NZh00`00Oomoo`0JOol00`00@C11<00E@C02000@E_d00`00E_eFo@0EE_d0
0`00E_eFo@0GE_d01@00OZUnZGjY00003GjY00<007ooOol01Woo00<007ooOol0=Goo000BOol2001U
Ool3000I@C000`00NZij[P05NZh00`00Oomoo`0IOol00`00@C11<00B@C03000CE_d00`00E_eFo@0D
E_d00`00E_eFo@0HE_d01000OZUnZ@003GjY00<007ooOol01Woo00<007ooOol0=Goo000@Ool2001U
Ool2000L@C000`00NZij[P06NZh00`00Oomoo`0HOol00`00@C11<00?@C03000FE_d00`00E_eFo@0D
E_d00`00E_eFo@0IE_d01000OZUnZ@0037jY00<007ooOol01goo00<007ooOol0=7oo000@Ool2001R
Ool3000N@C000`00NZij[P07NZh00`00Oomoo`0GOol00`00@C11<00<@C03000JE_d00`00E_eFo@0C
E_d00`00E_eFo@0IE_d01000OZUnZ@0037jY00<007ooOol027oo00<007ooOol0<goo000@Ool00`00
Ool0001NOol3000Q@C000`00NZij[P08NZh00`00Oomoo`0FOol00`00@C11<00:@C02000NE_d00`00
E_eFo@0BE_d00`00E_eFo@0JE_d00`00OZT0000<OZT00`00Oomoo`08Ool00`00Oomoo`0cOol0011o
o`04001oogoo001KOol200000d4`0011<00Q@C000`00NZij[P09NZh00`00Oomoo`0EOol00`00@C11
<007@C03000QE_d00`00E_eFo@0AE_d00`00E_eFo@0KE_d2000<OZT00`00Oomoo`09Ool00`00Oomo
o`0bOol000moo`03001oogoo009oo`03001oogoo05Eoo`<000=1<0030011<44`0211<003001j[WZ^
00Uj[P03001oogoo01Eoo`030011<44`00A1<0<002AFo@03001FoEKm015Fo@03001FoEKm01]Fo@80
00enZ@03001oogoo00Qoo`03001oogoo039oo`003goo00<007ooOol00goo00<007ooOol0DWoo0P00
1T4`00<0044`@C007d4`00<007Z^NZh02gZ^00<007ooOol057oo00<0044`@C000T4`0P00:5Km00<0
05KmE_d045Km00<005KmE_d06eKm0P003GjY00<007ooOol02Goo00<007ooOol0<Goo000?Ool00`00
Oomoo`04Ool00`00Oomoo`1>Ool30008@C000`00@C11<00O@C000`00NZij[P0<NZh00`00Oomoo`0C
Ool00`00@C000002000[E_d00`00E_eFo@0?E_d00`00E_eFo@0HE_d30002E_d00`00OZUnZ@0:OZT0
0`00Oomoo`0:Ool00`00Oomoo`0`Ool000moo`03001oogoo00Eoo`03001oogoo04]oo`8000]1<003
0011<44`01m1<003001j[WZ^00ej[P03001oogoo015oo`<002mFo@03001FoEKm00iFo@03001FoEKm
01EFo@<000EFo@03001nZGjY00YnZ@03001oogoo00Yoo`03001oogoo031oo`003goo00<007ooOol0
1Woo00<007ooOol0Agoo0`003D4`00<0044`@C007d4`00<007Z^NZh03WZ^00<007ooOol03Woo0P00
0T4`00<005KmE_d0;EKm00<005KmE_d03UKm00<005KmE_d04UKm0`002EKm00<007jYOZT02GjY00<0
07ooOol02goo00<007ooOol0;goo000?Ool00`00Oomoo`07Ool20014Ool3000@@C000`00@C11<00O
@C000`00NZij[P0?NZh00`00Oomoo`0:Ool30005@C000`00E_eFo@0]E_d00`00E_eFo@0>E_d00`00
E_eFo@0>E_d3000=E_d00`00OZUnZ@08OZT00`00Oomoo`0<Ool00`00Oomoo`0^Ool000ioo`03001o
ogoo00Yoo`03001oogoo03moo`800191<0030011<44`0211<003001j[WZ^00mj[P03001oogoo00Mo
o`<000Q1<003001FoEKm02iFo@03001FoEKm00eFo@03001FoEKm00]Fo@<0011Fo@03001nZGjY00Qn
Z@03001oogoo00aoo`03001oogoo02ioo`003Woo00<007ooOol02goo00<007ooOol0>goo0`00544`
00<0044`@C00844`00<007Z^NZh047Z^00<007ooOol017oo0P00344`00<005KmE_d0;UKm00<005Km
E_d035Km00<005KmE_d025Km0`0055Km00<007jYOZT01gjY00<007ooOol03Goo00<007ooOol0;Goo
000>Ool00`00Oomoo`0<Ool00`00Oomoo`0hOol2000G@C000`00@C11<00P@C000`00NZij[P0ANZh0
0`00Oomoo`03000?@C000`00E_eFo@0]E_d00`00E_eFo@0<E_d00`00E_eFo@04E_d4000HE_d00`00
OZUnZ@06OZT00`00Oomoo`0>Ool00`00Oomoo`0/Ool000ioo`03001oogoo00eoo`03001oogoo03Ao
o`<001U1<0030011<44`0211<003001j[WZ^019j[P8001=1<003001FoEKm02eFo@03001FoEKm00]F
o@04001FoEKmE_d3000LE_d00`00OZUnZ@06OZT00`00Oomoo`0>Ool00`00Oomoo`0/Ool000ioo`03
001oogoo00ioo`03001oogoo035oo`8001a1<0030011<44`0211<003001j[WZ^019j[P030011<44`
01=1<003001FoEKm02eFo@03001FoEKm00YFo@@0021Fo@03001nZGjY00InZ@03001oogoo00ioo`03
001oogoo02]oo`003Woo00<007ooOol03goo00<007ooOol0;Woo0P007T4`00<0044`@C00844`00<0
07Z^NZh04WZ^00<0044`@C00544`00<005KmE_d0;EKm00<005KmE_d01eKm0`0095Km00<007jYOZT0
1GjY00<007ooOol03goo00<007ooOol0:Woo000>Ool00`00Oomoo`0@Ool00`00Oomoo`0]Ool00`00
@C11<00M@C000`00@C11<00P@C000`00NZij[P0BNZh00`00@C11<00D@C000`00E_eFo@0]E_d00`00
E_eFo@04E_d30002E_d00`00E_eFo@0RE_d00`00OZUnZ@05OZT00`00Oomoo`0?Ool00`00Oomoo`0Z
Ool000eoo`03001oogoo019oo`03001oogoo02aoo`030011<44`01e1<0030011<44`0211<003001j
[WZ^019j[P030011<44`01E1<003001FoEKm02eFo@03001FoEKm00<000EFo@03001FoEKm02=Fo@03
001nZGjY00AnZ@03001oogoo011oo`03001oogoo02Uoo`003Goo00<007ooOol04goo00<007ooOol0
:goo00<0044`@C007D4`00<0044`@C00844`00<007Z^NZh04WZ^00<0044`@C005T4`00<005KmE_d0
;5Km0`001eKm0P009UKm00<007jYOZT00gjY00<007ooOol04Goo00<007ooOol0:7oo000=Ool00`00
Oomoo`0DOol00`00Oomoo`0ZOol00`00@C11<00M@C000`00@C11<00P@C000`00NZij[P0BNZh00`00
@C11<00G@C000`00E_eFo@0XE_d300000d4`00000004E_d30002E_d00`00E_eFo@0SE_d00`00OZUn
Z@03OZT00`00Oomoo`0AOol00`00Oomoo`0XOol000eoo`03001oogoo01Eoo`03001oogoo02Uoo`03
0011<44`01e1<0030011<44`01m1<08001Aj[P030011<44`01Q1<003001FoEKm02AFo@<000A1<080
0004E_d000000005E_d00`00E_eFo@0TE_d00`00OZUnZ@02OZT00`00Oomoo`0BOol00`00Oomoo`0W
Ool000eoo`03001oogoo01Ioo`03001oogoo02Moo`030011<44`01i1<0030011<44`01a1<0<0009F
o@03001j[WZ^015j[P030011<44`01U1<003001FoEKm025Fo@8000M1<0<000UFo@03001FoEKm02AF
o@05001nZGjYOZT0000;Ool20007Ool00`00Oomoo`0WOol000eoo`03001oogoo01Moo`03001oogoo
02Ioo`030011<44`01i1<0030011<44`01Y1<08000IFo@03001j[WZ^011j[P030011<44`01U1<003
001FoEKm01iFo@<000I1<0@0009nZ`03001FoEKm00MFo@03001FoEKm02=Fo@05001nZGjYOZT00008
Ool300000dEA00000007Ool00`00Oomoo`0VOol000aoo`03001oogoo01Uoo`03001oogoo02Eoo`03
0011<44`01i1<0030011<44`01M1<0<000UFo@03001j[WZ^00mj[P030011<44`01Y1<003001FoEKm
01YFo@<000I1<0<000=1<005001nZgj[OZ/00009E_d00`00E_eFo@0SE_d01000OZUnZ@001Goo0`00
14EA0P0027oo00<007ooOol09Goo000<Ool00`00Oomoo`0JOol00`00Oomoo`0TOol00`00@C11<00N
@C000`00@C11<00D@C03000<E_d00`00NZij[P0?NZh00`00@C11<00K@C000`00E_eFo@0FE_d30006
@C030006@C001@00OZ]nZgj[00002EKm00<005KmE_d095Km00D007jYOZT007oo00<000M5D@03001n
Z@0000Moo`03001oogoo02Eoo`0037oo00<007ooOol06goo00<007ooOol08goo00<0044`@C007T4`
00<0044`@C004D4`0`0045Km00<007Z^NZh03WZ^00<0044`@C00744`00<005KmE_d04UKm0`001d4`
0P002D4`00<007j[OZ/00Wj[00<005KmE_d01eKm00<005KmE_d08eKm00<007jYOZT00P002dEA00<0
07jY00001goo00<007ooOol097oo000<Ool00`00Oomoo`0LOol2000SOol00`00@C11<00M@C000`00
@C11<00@@C02000DE_d00`00NZij[P0=NZh00`00@C11<00M@C000`00E_eFo@0>E_d30007@C03000;
@C000`00OZ]nZ`03OZ/00`00E_eFo@07E_d00`00E_eFo@0SE_d00`00OZT0000<AE400`00OZT00008
Ool00`00Oomoo`0SOol000aoo`03001oogoo01ioo`03001oogoo021oo`030011<44`01e1<0030011
<44`00e1<0<001MFo@03001j[WZ^00aj[P030011<44`01i1<003001FoEKm00YFo@<000M1<0<000m1
<003001nZgj[00=nZ`03001FoEKm00MFo@03001FoEKm02=Fo@8000a5D@04001nZGjY0007Ool00`00
Oomoo`0SOol000aoo`03001oogoo01moo`03001oogoo01moo`030011<44`01e1<0030011<44`00Y1
<0<001]Fo@03001j[WZ^00]j[P030011<44`01i1<003001FoEKm00QFo@8000M1<0<00191<003001n
Zgj[00=nZ`03001FoEKm00MFo@03001FoEKm02=Fo@8000a5D@05001nZGjYOZT00007Ool00`00Oomo
o`0ROol000aoo`03001oogoo021oo`03001oogoo01ioo`030011<44`01e1<0030011<44`00M1<0<0
01mFo@03001j[WZ^00Yj[P030011<44`01m1<003001FoEKm00AFo@<000I1<0<001E1<003001nZgj[
00AnZ`03001FoEKm00MFo@03001FoEKm029Fo@8000a5D@05001nZGjYOZT00008Ool00`00Oomoo`0Q
Ool000]oo`03001oogoo029oo`03001oogoo01eoo`030011<44`01e1<0030011<44`00A1<0<002=F
o@03001j[WZ^00Uj[P030011<44`0211<003001FoEKm00<000I1<0<001Q1<003001nZgj[00EnZ`03
001FoEKm00MFo@03001FoEKm01iFo@<000i5D@03001nZGjY009nZ@03001oogoo00Eoo`03001oogoo
025oo`002goo00<007ooOol08goo00<007ooOol06goo00<0044`@C007T4`00<0044`@C000T4`0P00
9eKm00<007Z^NZh027Z^00<0044`@C00844`0`001T4`0`006d4`00<007j[OZ/01Wj[00<005KmE_d0
1eKm00<005KmE_d06UKm0`004DEA00<007jYOZT00gjY00<007ooOol01Goo00<007ooOol087oo000;
Ool00`00Oomoo`0TOol00`00Oomoo`0JOol00`00@C11<00N@C000`00@C000002000YE_d00`00NZij
[P08NZh00`00@C11<00M@C0300000d4`0011<003@C03000N@C000`00OZ]nZ`06OZ/00`00E_eFo@07
E_d00`00E_eFo@0GE_d3000DAE400`00OZUnZ@03OZT00`00Oomoo`06Ool00`00Oomoo`0OOol000]o
o`03001oogoo02Eoo`03001oogoo01Uoo`030011<44`01e1<0<002eFo@03001j[WZ^00Mj[P030011
<44`01]1<08000A1<0030011<00000800251<003001nZgj[00MnZ`03001FoEKm00MFo@03001FoEKm
01=Fo@<001Q5D@03001nZGjY00=nZ@03001oogoo00Eoo`03001oogoo01moo`002goo00<007ooOol0
9Woo00<007ooOol067oo00<0044`@C006d4`0P000UKm00<005KmE_d0;5Km00<007Z^NZh01WZ^00<0
044`@C00644`0`001D4`0`00944`00<007j[OZ/027j[00<005KmE_d01eKm00<005KmE_d03eKm0`00
6dEA00<007jYOZT017jY00<007ooOol01Goo00<007ooOol07Woo000;Ool00`00Oomoo`0WOol00`00
Oomoo`0GOol00`00@C11<00H@C030005E_d00`00E_eFo@0/E_d00`00NZij[P05NZh00`00@C11<00E
@C030005@C0300000d4`0011<00T@C000`00OZ]nZ`09OZ/00`00E_eFo@07E_d00`00E_eFo@0<E_d2
000NAE400`00OZUnZ@05OZT00`00Oomoo`05Ool00`00Oomoo`0MOol000Yoo`03001oogoo02Uoo`03
001oogoo01Ioo`030011<44`01E1<0<000UFo@03001FoEKm02aFo@03001j[WZ^00Aj[P030011<44`
0191<0<000E1<0<000A1<0030011<44`02=1<003001nZgj[00UnZ`03001FoEKm00MFo@03001FoEKm
00UFo@<00215D@03001nZGjY00EnZ@03001oogoo00Eoo`03001oogoo01eoo`002Woo00<007ooOol0
:Woo00<007ooOol05Goo00<0044`@C004d4`0P003EKm00<005KmE_d0;5Km00<007Z^NZh00gZ^00<0
044`@C00444`0P001D4`0`001d4`00<0044`@C008d4`00<007j[OZ/02Wj[00<005KmE_d01eKm00<0
05KmE_d01EKm0`008dEA00<007jYOZT01WjY00<007ooOol01Goo00<007ooOol077oo000:Ool00`00
Oomoo`0[Ool00`00Oomoo`0DOol00`00@C11<00@@C03000@E_d00`00E_eFo@0/E_d00`00NZij[P02
NZh00`00@C11<00=@C030004@C03000:@C000`00@C11<00S@C000`00OZ]nZ`0;OZ/00`00E_eFo@07
E_d01000E_eFoEKm10009DEA00<007jYOZT01gjY00<007ooOol017oo00<007ooOol077oo000:Ool0
0`00Oomoo`0/Ool00`00Oomoo`0COol00`00@C11<00>@C02000DE_d00`00E_eFo@0/E_d01@00NZij
[WZ^0000344`0`001D4`0P003D4`00<0044`@C008d4`00<007j[OZ/037j[00<005KmE_d01UKm1000
17j[00<004EAAE408TEA00<007jYOZT01gjY00<007ooOol01Goo00<007ooOol06goo000:Ool00`00
Oomoo`0]Ool00`00Oomoo`0BOol00`00@C11<00;@C03000GE_d00`00E_eFo@0[E_d01@00NZij[WZ^
00002D4`0`001D4`0`003d4`00<0044`@C008d4`00<007j[OZ/037j[00<005KmE_d015Km10001Wj[
00<004EAAE408TEA00<007jYOZT027jY00<007ooOol01Goo00<007ooOol06Woo000:Ool00`00Oomo
o`0^Ool00`00Oomoo`0@Ool00`00@C11<009@C03000KE_d00`00E_eFo@0[E_d01000NZij[P001T4`
0`001D4`0`004T4`00<0044`@C008d4`00<007j[OZ/03Gj[00<005KmE_d00`0017j[00<007j[OZ/0
0gj[00<004EAAE408dEA00<007jYOZT027jY00<007ooOol017oo00<007ooOol06Woo000:Ool00`00
Oomoo`0_Ool00`00Oomoo`0?Ool00`00@C11<007@C02000OE_d00`00E_eFo@0[E_d00`00NZh00004
@C020005@C03000E@C000`00@C11<00S@C000`00OZ]nZ`0>OZ/20008OZ/00`00OZ]nZ`02OZ/00`00
AE55D@0SAE400`00OZUnZ@08OZT00`00Oomoo`05Ool00`00Oomoo`0IOol000Uoo`03001oogoo035o
o`03001oogoo00ioo`030011<44`00A1<0<0029Fo@03001FoEKm02]Fo@800004@C0000000004@C03
000H@C000`00@C11<00S@C000`00OZ]nZ`0>OZ/20008OZ/00`00OZ]nZ`02OZ/00`00AE55D@0SAE40
0`00OZUnZ@09OZT00`00Oomoo`05Ool00`00Oomoo`0HOol000Uoo`03001oogoo039oo`8000ioo`04
0011<44`@C03000VE_d00`00E_eFo@0ZE_d30004@C03000K@C000`00@C11<00T@C000`00OZ]nZ`0=
OZ/00`00OZ/00008OZ/01@00OZ]nZgj[00009DEA00<007jYOZT02GjY0P001Woo00<007ooOol067oo
0009Ool00`00Oomoo`0dOol00`00Oomoo`0;Ool01000@C000000:EKm00<005KmE_d09eKm0`0000A1
<000@C11<0<001i1<0030011<44`02A1<003001nZgj[00enZ`03001nZ`0000UnZ`04001nZgj[000U
AE400`00OZUnZ@09OZT20007Ool00`00Oomoo`0GOol000Uoo`03001oogoo03Eoo`03001oogoo00Yo
o`8002aFo@03001FoEKm02=Fo@<000A1<0<00251<0030011<44`02A1<003001nZgj[00enZ`04001n
Zgj[0009OZ/00`00OZ/0000UAE400`00OZUnZ@09OZT00`00OZT00007Ool00`00Oomoo`0FOol000Uo
o`03001oogoo03Ioo`03001oogoo00Yoo`03001FoEKm02]Fo@03001FoEKm01mFo@<000A1<0@002=1
<0030011<44`02A1<003001nZgj[00enZ`05001nZgj[OZ/00008OZ/00`00OZ/0000UAE400`00OZUn
Z@09OZT01000OZUnZ@001Woo00<007ooOol05Woo0009Ool00`00Oomoo`0gOol00`00Oomoo`0:Ool0
0`00E_eFo@0[E_d00`00E_eFo@0KE_d30004@C030003@C000`00@C11<00Q@C000`00@C11<00T@C00
0`00OZ]nZ`0=OZ/00`00OZ]nZ`02OZ/00`00OZ]nZ`06OZ/2000UAE400`00OZUnZ@09OZT01000OZUn
Z@001goo00<007ooOol05Goo0008Ool00`00Oomoo`0iOol00`00Oomoo`0:Ool00`00E_eFo@0[E_d0
0`00E_eFo@0GE_d30004@C030006@C000`00@C11<00Q@C000`00@C11<00T@C000`00OZ]nZ`0=OZ/0
0`00OZ]nZ`02OZ/00`00OZ]nZ`07OZ/2000UAE400`00OZUnZ@09OZT01000OZUnZ@001goo00<007oo
Ool057oo0008Ool00`00Oomoo`0jOol00`00Oomoo`0:Ool00`00E_eFo@0[E_d00`00E_eFo@0DE_d2
0004@C030009@C000`00@C11<00Q@C000`00@C11<00T@C000`00OZ]nZ`0=OZ/00`00OZ]nZ`03OZ/0
0`00OZ]nZ`07OZ/00`00AE55D@0SAE400`00OZUnZ@09OZT01@00OZUnZGjY00001Woo00<007ooOol0
57oo0008Ool00`00Oomoo`0kOol00`00Oomoo`0:Ool00`00E_eFo@0[E_d00`00E_eFo@0@E_d30003
@C03000<@C000`00@C11<00Q@C000`00@C11<00T@C000`00OZ]nZ`0>OZ/00`00OZ]nZ`03OZ/00`00
OZ]nZ`06OZ/00`00AE55D@0SAE400`00OZUnZ@09OZT01@00OZUnZGjY00001goo00<007ooOol04goo
0008Ool00`00Oomoo`0lOol00`00Oomoo`0:Ool00`00E_eFo@0[E_d00`00E_eFo@0<E_d30003@C03
000?@C000`00@C11<00Q@C000`00@C11<00S@C02000@OZ/00`00OZ]nZ`04OZ/00`00OZ]nZ`05OZ/2
000SAE42000;OZT00`00OZUnZ@02OZT00`00Oomoo`05Ool00`00Oomoo`0BOol000Qoo`03001oogoo
03eoo`03001oogoo00Yoo`03001FoEKm02]Fo@03001FoEKm00QFo@<000=1<0<00191<0030011<44`
0251<0030011<44`0211<0<0009C7@03001nZgj[00enZ`03001nZgj[00AnZ`03001nZgj[00EnZ`03
0015D@0001m5D@<0009Fo@03001nZGjY00QnZ@03001nZGjY009nZ@03001oogoo00Eoo`03001oogoo
019oo`0027oo00<007ooOol0?Woo00<007ooOol02Woo00<005KmE_d0:eKm00<005KmE_d015Km0`00
144`0P005D4`00<0044`@C008D4`00<0044`@C00744`10001U<M00<007j[OZ/037j[00<007j[OZ/0
1Gj[00<007j[OZ/017j[00<004EA000074EA0`001EKm00<007jYOZT027jY00<007jYOZT00gjY00<0
07ooOol01Goo00<007ooOol04Goo0008Ool00`00Oomoo`0oOol00`00Oomoo`0:Ool00`00E_eFo@0[
E_d00`00E_eFo@030004@C03000G@C000`00@C11<00Q@C000`00@C11<00I@C03000:Dad00`00OZ]n
Z`0<OZ/00`00OZ]nZ`06OZ/00`00OZ]nZ`03OZ/01000AE55D@0064EA0`002EKm00<007jYOZT01gjY
00<007jYOZT017jY00<007ooOol017oo00<007ooOol04Goo0007Ool00`00Oomoo`11Ool00`00Oomo
o`0:Ool00`00E_eFo@0ZE_d30004@C03000J@C000`00@C11<00Q@C000`00@C11<00F@C03000>Dad0
0`00OZ]nZ`0;OZ/00`00OZ]nZ`07OZ/00`00OZ]nZ`02OZ/01@00AE55DDEA000054EA0`003EKm00<0
07jYOZT01WjY00<007jYOZT017jY00<007ooOol01Goo00<007ooOol047oo0007Ool00`00Oomoo`12
Ool00`00Oomoo`0:Ool2000WE_d3000015Km0011<44`0`007D4`00<0044`@C008D4`00<0044`@C00
4d4`0`004U<M00<007j[OZ/02Wj[00<007j[OZ/027j[00D007j[OZ]nZ`0000A5D@030015DDEA00i5
D@<0011Fo@03001nZGjY00InZ@03001nZGjY00EnZ@03001oogoo00Eoo`03001oogoo00moo`001goo
00<007ooOol0@goo00<007ooOol02goo00<005KmE_d08EKm0`0015Km0`00844`00<0044`@C008D4`
00<0044`@C003d4`10005U<M00<007j[OZ/02Gj[00<007j[OZ/027j[00D007j[OZ]nZ`0000A5D@03
0015DDEA00Y5D@@001AFo@03001nZGjY00EnZ@03001nZGjY00InZ@03001oogoo00Aoo`03001oogoo
00moo`001goo00<007ooOol0A7oo00<007ooOol02goo00<005KmE_d07EKm0`0015Km10008T4`00<0
044`@C008D4`00<0044`@C00344`0`006U<M00<007j[OZ/02Gj[00<007j[OZ/02Gj[00D007j[OZ]n
Z`0000A5D@030015DDEA00I5D@<001UFo@03001nZGjY00EnZ@03001nZGjY00EnZ@03001oogoo00Eo
o`03001oogoo00ioo`001goo00<007ooOol0AGoo00<007ooOol02goo00<005KmE_d06EKm0`0015Km
0`000eKm00<0044`@C00844`00<0044`@C008D4`00<0044`@C002D4`0`007U<M00<007j[OZ/027j[
00<007j[OZ/02Wj[00@007j[OZ/000E5D@030015DDEA0095D@<001aFo@03001nZGjY00EnZ@03001n
ZGjY00InZ@03001oogoo00Eoo`03001oogoo00eoo`001goo00<007ooOol0AWoo00<007ooOol02goo
00<005KmE_d05EKm0`0015Km0`001UKm00<0044`@C007d4`00<0044`@C008T4`00<0044`@C001T4`
0`008U<M00<007j[OZ/01gj[00<007j[OZ/02gj[00<007j[00001TEA100085Km00<007jYOZT017jY
00<007jYOZT01gjY00<007ooOol017oo00<007ooOol03Goo0006Ool00`00Oomoo`18Ool2000<Ool0
0`00E_eFo@0@E_d40004E_d30009E_d00`00@C11<00O@C000`00@C11<00R@C000`00@C11<002@C04
000VDad00`00OZ]nZ`06OZ/00`00OZ]nZ`0;OZ/00`00OZ/00004AE43000TE_d00`00OZUnZ@03OZT0
0`00OZUnZ@07OZT00`00Oomoo`04Ool2000>Ool000Ioo`03001oogoo04Yoo`03001oogoo00Yoo`03
001FoEKm00aFo@<000EFo@<000aFo@030011<44`01m1<0030011<44`0291<0030011<000008002]C
7@03001nZgj[00EnZ`03001nZgj[00anZ`800004AE4000000003E_d00`00E_eFo@0QE_d00`00OZUn
Z@03OZT00`00OZUnZ@08OZT00`00Oomoo`0300000goo001oo`0=Ool000Ioo`03001oogoo04]oo`03
001oogoo00Yoo`03001FoEKm00QFo@<000EFo@<000iFo@030011<44`0211<0030011<44`0251<0<0
02iC7@03001nZgj[00EnZ`03001nZgj[00enZ`8000MFo@03001FoEKm025Fo@03001nZGjY009nZ@03
001nZGjY00QnZ@<000Aoo`03001oogoo00aoo`001Woo00<007ooOol0C7oo00<007ooOol02Woo00<0
05KmE_d015Km0`001EKm0`004EKm00<0044`@C00844`00<0044`@C007T4`0`000U<M00<005<MDad0
;E<M00<007j[OZ/017j[00<007j[OZ/03Gj[0P0025Km00<005KmE_d08EKm00D007jYOZUnZ@0000Yn
Z@03001oogoo00Aoo`03001oogoo00aoo`001Woo00<007ooOol0CGoo00<007ooOol02Woo00<005Km
E_d00`001EKm0`0055Km00<0044`@C00844`00<0044`@C006d4`0`001U<M00<005<MDad0;E<M00<0
07j[OZ/00gj[00<007j[OZ/03Gj[0P0025Km00<005KmE_d08EKm00D007jYOZUnZ@0000YnZ@03001o
ogoo00Eoo`03001oogoo00]oo`001Woo00<007ooOol0CWoo00<007ooOol02Woo0P001EKm0`005eKm
00<0044`@C00844`00<0044`@C006D4`0P002E<M00<005<MDad0;U<M00<007j[OZ/00gj[00<007j[
OZ/037j[00<007j[000025Km00<005KmE_d08EKm00@007jYOZT000]nZ@03001oogoo00Aoo`03001o
ogoo00]oo`001Woo00<007ooOol0Cgoo00<007ooOol02Woo00@005KmE_eFo@8001YFo@030011<44`
0211<0030011<44`01I1<0<000aC7@03001C7E<M02iC7@03001nZgj[009nZ`03001nZgj[00anZ`04
001nZgj[0008E_d00`00E_eFo@0QE_d00`00OZT0000;OZT00`00Oomoo`04Ool00`00Oomoo`0;Ool0
00Eoo`03001oogoo055oo`03001oogoo00Yoo`<001aFo@030011<44`0211<0030011<44`01=1<0<0
011C7@03001C7E<M02eC7@03001nZgj[009nZ`03001nZgj[00anZ`05001nZgj[OZ/00008E_d00`00
E_eFo@0PE_d01000OZUnZ@002WjY00<007ooOol017oo00<007ooOol02goo0005Ool00`00Oomoo`1B
Ool00`00Oomoo`06Ool300000goo001Fo@0LE_d00`00@C11<00P@C000`00@C11<00@@C03000DDad0
0`00DaeC7@0]Dad01@00OZ]nZgj[00003Wj[00D007j[OZ]nZ`0000QFo@03001FoEKm025Fo@03001n
Z@0000YnZ@03001oogoo00Aoo`03001oogoo00]oo`001Goo00<007ooOol0Dgoo00<007ooOol00Woo
0`001Goo00<005KmE_d06UKm00<0044`@C00844`00<0044`@C003D4`0`0065<M00<005<MDad0;E<M
00@007j[OZ/000inZ`03001nZgj[009nZ`03001FoEKm00IFo@03001FoEKm025Fo@8000YnZ@03001o
ogoo00Aoo`03001oogoo00]oo`001Goo00<007ooOol0E7oo10002Goo00<005KmE_d06EKm00<0044`
@C00844`00<0044`@C002T4`0`0075<M00<005<MDad0;E<M00<007j[00003Wj[00<007j[OZ/00gj[
00<005KmE_d01UKm00<005KmE_d085Km0P002WjY00<007ooOol017oo00<007ooOol02goo0005Ool0
0`00Oomoo`1BOol4000<Ool00`00E_eFo@0HE_d00`00@C11<00P@C000`00@C11<007@C03000ODad0
0`00DaeC7@0]Dad00`00OZ/0000?OZ/00`00OZ]nZ`03OZ/00`00E_eFo@05E_d00`00E_eFo@0PE_d2
000:OZT00`00Oomoo`04Ool00`00Oomoo`0;Ool000Eoo`03001oogoo04moo`<000Aoo`03001oogoo
00Yoo`03001FoEKm01MFo@030011<44`0211<0030011<44`00E1<08002=C7@03001C7E<M02eC7@80
00mnZ`03001nZgj[00=nZ`03001FoEKm00IFo@03001FoEKm01aFo@<0009Fo@03001nZGjY00MnZ@03
001oogoo00Eoo`03001oogoo00Yoo`0017oo00<007ooOol0CGoo0`0027oo00<007ooOol02Woo00<0
05KmE_d05UKm00<0044`@C00844`00<0044`@C000T4`0`009U<M00<005<MDad0;5<M0P003gj[00<0
07j[OZ/017j[00<005KmE_d01UKm00<005KmE_d05eKm10001EKm00<007jYOZT027jY00<007ooOol0
17oo00<007ooOol02Woo0004Ool00`00Oomoo`1:Ool3000<Ool00`00Oomoo`0:Ool00`00E_eFo@0E
E_d00`00@C11<00P@C000`00@C000002000ZDad00`00DaeC7@0XDad30002Dad00`00OZ]nZ`0<OZ/0
0`00OZ]nZ`05OZ/00`00E_eFo@06E_d00`00E_eFo@0CE_d3000:E_d00`00OZUnZ@07OZT00`00Oomo
o`04Ool00`00Oomoo`0:Ool000Aoo`03001oogoo04Moo`<0011oo`03001oogoo00Yoo`03001FoEKm
01AFo@030011<44`01m1<0<002iC7@03001C7E<M02AC7@<000IC7@03001nZgj[00]nZ`03001nZgj[
00InZ`03001FoEKm00EFo@03001FoEKm011Fo@<000iFo@03001nZGjY00InZ@03001oogoo00Aoo`03
001oogoo00Yoo`0017oo00<007ooOol0A7oo0`0057oo00<007ooOol02Woo00<005KmE_d04eKm00<0
044`@C00744`0`000U<M00<005<MDad0;E<M00<005<MDad07e<M10002E<M00<007j[OZ/02gj[00<0
07j[OZ/01Wj[00<005KmE_d01UKm00<005KmE_d035Km0`004EKm00<007jYOZT01WjY00<007ooOol0
17oo00<007ooOol02Woo0004Ool00`00Oomoo`11Ool3000HOol2000;Ool00`00E_eFo@0BE_d00`00
@C11<00H@C040006Dad00`00DaeC7@0/Dad00`00DaeC7@0LDad3000>Dad00`00OZ]nZ`0:OZ/00`00
OZ]nZ`07OZ/00`00E_eFo@06E_d00`00E_eFo@07E_d4000EE_d00`00OZUnZ@05OZT00`00Oomoo`04
Ool00`00Oomoo`0:Ool000Aoo`03001oogoo03ioo`<001eoo`03001oogoo00Uoo`03001FoEKm011F
o@030011<44`01I1<0<000]C7@03001C7E<M02aC7@03001C7E<M01QC7@<0019C7@03001nZgj[00Un
Z`03001nZgj[00QnZ`03001FoEKm00IFo@03001FoEKm00=Fo@<001YFo@03001nZGjY00AnZ@03001o
ogoo00Aoo`03001oogoo00Yoo`0017oo00<007ooOol0>goo0`008Goo00<007ooOol02Goo00<005Km
E_d03eKm00<0044`@C004d4`0`003e<M00<005<MDad0;5<M00<005<MDad055<M0`005U<M00<007j[
OZ/027j[00<007j[OZ/02Gj[00<005KmE_d01EKm00<005KmE_d00`007UKm00<007jYOZT00gjY00<0
07ooOol017oo00<007ooOol02Woo0003Ool00`00Oomoo`0jOol2000UOol00`00Oomoo`09Ool00`00
E_eFo@0>E_d00`00@C11<00@@C03000CDad00`00DaeC7@0/Dad00`00DaeC7@0@Dad3000JDad00`00
OZ]nZ`07OZ/00`00OZ]nZ`09OZ/00`00E_eFo@04E_d4000QE_d00`00OZUnZ@04OZT00`00Oomoo`04
Ool00`00Oomoo`09Ool000=oo`03001oogoo03Moo`<002Qoo`03001oogoo00Uoo`03001FoEKm00eF
o@030011<44`00a1<0@001MC7@03001C7E<M02aC7@03001C7E<M00aC7@<001eC7@03001nZgj[00Mn
Z`03001nZgj[00YnZ`03001FoEKm00<000=Fo@03001FoEKm021Fo@03001nZGjY00=nZ@03001oogoo
00Aoo`03001oogoo00Uoo`000goo00<007ooOol0=7oo0`00;7oo00<007ooOol02Goo00<005KmE_d0
35Km00<0044`@C002D4`0`0075<M00<005<MDad0;5<M00<005<MDad01e<M10008E<M00<007j[OZ/0
1Wj[00<007j[OZ/02gj[0P001eKm00<005KmE_d085Km00<007jYOZT00WjY00<007ooOol017oo00<0
07ooOol02Goo0003Ool00`00Oomoo`0aOol3000`Ool00`00Oomoo`09Ool00`00E_eFo@08E_d40008
@C03000PDad00`00DaeC7@0[Dad00`00DaeC7@04Dad3000VDad00`00OZ]nZ`05OZ/00`00OZ]nZ`0;
OZ/20007E_d00`00E_eFo@0PE_d00`00OZUnZ@02OZT00`00Oomoo`04Ool00`00Oomoo`09Ool000=o
o`03001oogoo02ioo`<003Aoo`03001oogoo00Uoo`03001FoEKm00AFo@<000=oo`030011<44`0091
<0@002AC7@03001C7E<M02]C7@03001C7E<M00<002YC7@03001nZgj[00AnZ`03001nZgj[00]nZ`80
00QFo@03001FoEKm021Fo@05001nZGjYOZT00006Ool00`00Oomoo`09Ool000=oo`03001oogoo02]o
o`<003Qoo`03001oogoo00Uoo`03001FoEKm00<000Ioo`030011<000008002UC7@03001C7E<M02YC
7@<002iC7@03001nZgj[00=nZ`03001nZgj[00]nZ`03001Fo@0000QFo@03001FoEKm021Fo@04001n
ZGjY0006Ool00`00Oomoo`09Ool0009oo`03001oogoo02Uoo`<003aoo`03001oogoo00Uoo`8000Uo
o`8002aC7@03001C7E<M02MC7@<00003AE40000002mC7@03001nZgj[009nZ`03001nZgj[00]nZ`04
001FoEKm0008E_d00`00E_eFo@0OE_d01000OZUnZ@001Woo00<007ooOol02Goo0002Ool00`00Oomo
o`0VOol30010Ool00`00Oomoo`0DOol00`00DaeC7@0[Dad00`00DaeC7@0RDad40004AE400`00OZd0
000^Dad00`00OZ]nZ`03OZ/00`00OZ]nZ`0:OZ/01@00E_eFoEKm00001eKm00<005KmE_d085Km00<0
07jY00001goo00<007ooOol027oo0002Ool00`00Oomoo`0SOol30014Ool00`00Oomoo`0DOol00`00
DaeC7@0[Dad00`00DaeC7@0NDad30008AE401000OZen[@00;U<M00<007j[OZ/00Wj[00<007j[OZ/0
2gj[00@005KmE_d000QFo@03001FoEKm021Fo@03001nZ@0000Ioo`03001oogoo00Qoo`000Woo00<0
07ooOol087oo0`00B7oo00<007ooOol057oo00<005<MDad0:e<M00<005<MDad06U<M0`002dEA00D0
07j]OZen[@0002iC7@05001nZgj[OZ/0000=OZ/01@00E_eFoEKm000025Km00<005KmE_d085Km0P00
1Woo00<007ooOol027oo0002Ool00`00Oomoo`0MOol3001<Ool00`00Oomoo`0DOol00`00DaeC7@0[
Dad00`00DaeC7@0FDad3000>AE401@00OZen[Gj]0000;e<M00@007j[OZ/000enZ`03001FoEKm009F
o@03001FoEKm00EFo@03001FoEKm021Fo@8000Ioo`03001oogoo00Qoo`000Woo00<007ooOol06Woo
0`00D7oo00<007ooOol057oo00<005<MDad0:e<M00<005<MDad04E<M10004DEA00<007j]OZd00Wj]
00<005<MDad0;E<M00<007j[00003Gj[00<005KmE_d00eKm00<005KmE_d01EKm00<005KmE_d07eKm
0P001Woo00<007ooOol027oo0002Ool00`00Oomoo`0GOol3001DOol00`00Oomoo`0DOol00`00DaeC
7@0[Dad00`00DaeC7@0=Dad3000EAE400`00OZen[@03OZd00`00DaeC7@0/Dad00`00OZ/0000=OZ/0
0`00E_eFo@03E_d00`00E_eFo@06E_d00`00E_eFo@0KE_d30008Ool00`00Oomoo`08Ool00003Ool0
07oo01Ioo`<005Qoo`03001oogoo01Aoo`03001C7E<M02]C7@03001C7E<M00UC7@<001Q5D@03001n
[Gj]00An[@03001C7E<M02aC7@8000enZ`03001FoEKm00AFo@03001FoEKm00IFo@03001FoEKm01MF
o@<000]oo`03001oogoo00Qoo`0000=oo`00Ool04goo0`00G7oo00<007ooOol057oo00<005<MDad0
:e<M00<005<MDad015<M10006dEA00<007j]OZd01Gj]00<005<MDad0:e<M0P003Gj[00<005KmE_d0
1EKm00<005KmE_d01EKm00<005KmE_d04eKm10003Woo00<007ooOol027oo00000goo001oo`0AOol2
001POol2000EOol00`00DaeC7@0[Dad00`00DaeC7@03000OAE400`00OZen[@06OZd00`00DaeC7@0V
Dad40002Dad00`00OZ]nZ`0:OZ/00`00E_eFo@06E_d00`00E_eFo@05E_d00`00E_eFo@0?E_d3000C
Ool00`00Oomoo`07Ool00003Ool007oo00ioo`<006Aoo`03001oogoo019oo`8002aC7@<00295D@03
001n[Gj]00Mn[@03001C7E<M029C7@<000MC7@03001nZgj[00UnZ`03001FoEKm00IFo@03001FoEKm
00IFo@03001FoEKm00]Fo@<001Ioo`03001oogoo00Moo`0000=oo`00Ool02goo0`00J7oo00<007oo
Ool04Goo00<004EA0000:5<M0`0000=C7@00AE408TEA00<007j]OZd027j]00<005<MDad07U<M0`00
2U<M00<007j[OZ/02Gj[00<005KmE_d01eKm00<005KmE_d01UKm00<005KmE_d01eKm0`006Goo00<0
07ooOol01goo00000goo001oo`08Ool3001/Ool00`00Oomoo`0@Ool01000AE55D@0095<M0`0015<M
00<004EAAE408DEA00<007j]OZd02Gj]00<005<MDad06E<M10003U<M00<007j[OZ/027j[00<005Km
E_d025Km00<005KmE_d01EKm00<005KmE_d015Km0`0077oo00<007ooOol01goo00000`00Oomoo`05
Ool3001`Ool00`00Oomoo`0?Ool01@00AE55DDEA00007e<M10001e<M00<004EAAE408DEA00<007j]
OZd02Wj]00<005<MDad05E<M0`004e<M00<007j[OZ/027j[00<005KmE_d025Km00<005KmE_d01EKm
00<005Km00000`007goo00<007ooOol01goo00000`00Oomoo`02Ool3001dOol00`00Oomoo`0>Ool0
0`00AE55D@02AE400`00DaeC7@0IDad3000;Dad00`00AE55D@0QAE400`00OZen[@0:OZd00`00DaeC
7@0BDad3000GDad00`00OZ]nZ`07OZ/00`00E_eFo@08E_d00`00E_eFo@04E_d3000SOol00`00Oomo
o`07Ool00003001oo`00008007Qoo`03001oogoo00eoo`030015DDEA00=5D@03001C7E<M01EC7@<0
00iC7@030015DDEA0255D@03001n[Gj]00]n[@03001C7E<M00eC7@@001]C7@03001nZgj[00InZ`03
001FoEKm00UFo@03001FoEKm00<000=oo`03001oogoo021oo`03001oogoo00Moo`000P00O7oo00<0
07ooOol037oo00<004EAAE4014EA00<005<MDad04E<M0`004E<M00<004EAAE408DEA00<007j]OZd0
37j]00<005<MDad02E<M0`007e<M00<007j[OZ/01Wj[00<005KmE_d02EKm0`001Woo00<007ooOol0
87oo00<007ooOol01goo00000goo001oo`1lOol00`00Oomoo`0;Ool00`00AE55D@02AE44000?Dad3
000DDad00`00AE55D@0RAE400`00OZen[@0<OZd00`00DaeC7@05Dad3000SDad00`00OZ]nZ`05OZ/0
0`00E_eFo@05E_d4000:Ool00`00Oomoo`0POol00`00Oomoo`06Ool0009oo`8007aoo`03001oogoo
00Yoo`030015D@00008000AFo@03001C7E<M00QC7@@001MC7@030015DDEA0295D@03001n[Gj]00en
[@03001C7E<M00@002MC7@03001nZgj[00AnZ`04001FoEKmE_d4000?Ool00`00Oomoo`0OOol00`00
Oomoo`06Ool000Aoo`03001oogoo07Yoo`03001oogoo00Uoo`8000QFo@03001C7E<M00AC7@<001]C
7@030015DDEA0295D@03001n[Gj]00in[@8002aC7@03001nZgj[00=nZ`@001Aoo`03001oogoo01io
o`03001oogoo00Ioo`001Goo00<007ooOol0NWoo00<007ooOol02Goo00<005KmE_d01eKm00<005<M
Dad00`007U<M00<004EAAE408TEA00<007j]OZd03Wj]0P00;E<M00<007j[OZ/00Wj[00<007ooOol0
5Goo00<007ooOol07Woo00<007ooOol01Woo0006Ool00`00Oomoo`1jOol00`00Oomoo`09Ool00`00
E_eFo@07E_d2000QDad00`00AE55D@0RAE400`00OZen[@0>OZd00`00Dad0000/Dad00`00OZ]nZ`02
OZ/00`00Oomoo`0FOol00`00Oomoo`0MOol00`00Oomoo`06Ool000Moo`8007]oo`03001oogoo00Uo
o`03001FoEKm00MFo@03001C7E<M01mC7@030015DDEA0295D@03001n[Gj]00in[@04001C7E<M000/
Dad01@00OZ]nZgj[00006Goo00<007ooOol077oo00<007ooOol01Woo0009Ool00`00Oomoo`1iOol0
0`00Oomoo`09Ool00`00E_eFo@07E_d00`00DaeC7@0NDad00`00AE55D@0RAE400`00OZen[@0>OZd0
1@00DaeC7E<M0000;5<M00D007j[OZ]nZ`0001Qoo`03001oogoo01aoo`03001oogoo00Ioo`002Woo
00<007ooOol0NGoo00<007ooOol02Goo00<005KmE_d01eKm00<005<MDad07E<M00<004EAAE408TEA
00<007j]OZd03Wj]00D005<MDaeC7@0002eC7@04001nZgj[000IOol00`00Oomoo`0KOol00`00Oomo
o`06Ool000]oo`8007Yoo`03001oogoo00Uoo`03001FoEKm00MFo@03001C7E<M01aC7@030015DDEA
0295D@03001n[Gj]00in[@03001C7E<M009C7@03001C7E<M02]C7@03001nZ`0001Yoo`03001oogoo
01]oo`03001oogoo00Eoo`003Goo00<007ooOol0N7oo0P002Woo00<005KmE_d01eKm00<005<MDad0
6e<M00<004EAAE408TEA00<007j]OZd03Wj]00<005<MDad00e<M00<005<MDad0:U<M00<007j[0000
6goo00<007ooOol06Woo00<007ooOol01Goo000>Ool00`00Oomoo`1iOol00`00Oomoo`08Ool00`00
E_eFo@07E_d00`00DaeC7@0JDad00`00AE55D@0RAE400`00OZen[@0>OZd00`00DaeC7@04Dad00`00
DaeC7@0ZDad2000KOol00`00Oomoo`0JOol00`00Oomoo`05Ool000moo`03001oogoo07Uoo`03001o
ogoo00Qoo`03001FoEKm00MFo@03001C7E<M01UC7@030015DDEA0295D@03001n[Gj]00mn[@03001C
7E<M00AC7@03001C7E<M02UC7@8001aoo`03001oogoo01Uoo`03001oogoo00Eoo`0047oo0P00NWoo
00<007ooOol027oo00<005KmE_d01eKm00<005<MDad065<M00<004EAAE408TEA00<007j]OZd03gj]
00<005<MDad01E<M00<005<MDad095<M10007goo00<007ooOol067oo00<007ooOol01Goo000BOol0
0`00Oomoo`1hOol00`00Oomoo`08Ool00`00E_eFo@07E_d00`00DaeC7@0GDad00`00AE55D@0RAE40
0`00OZen[@0?OZd00`00DaeC7@06Dad00`00DaeC7@0PDad3000TOol00`00Oomoo`0GOol00`00Oomo
o`05Ool001=oo`03001oogoo07Qoo`03001oogoo00Qoo`03001FoEKm00MFo@03001C7E<M01IC7@03
0015DDEA0295D@03001n[Gj]00mn[@03001C7E<M00MC7@03001C7E<M01]C7@@002Moo`03001oogoo
01Moo`03001oogoo00Eoo`0057oo00<007ooOol0N7oo00<007ooOol027oo00<005KmE_d01eKm00<0
05<MDad05E<M00<004EAAE408TEA00<007j]OZd03gj]00<005<MDad025<M00<005<MDad05U<M1000
;7oo00<007ooOol05goo00<007ooOol017oo000EOol2001iOol00`00Oomoo`04Ool50009E_d00`00
DaeC7@0DDad00`00AE55D@0QAE42000AOZd00`00DaeC7@09Dad00`00DaeC7@0BDad3000aOol00`00
Oomoo`0FOol00`00Oomoo`04Ool001Moo`03001oogoo07Moo`03001oogoo00<000Eoo`03001FoEKm
00MFo@03001C7E<M01=C7@030015DDEA01e5D@@0009C7@03001n[Gj]00in[@03001C7E<M00UC7@03
001C7E<M00iC7@@003Eoo`03001oogoo01Eoo`03001oogoo00Aoo`0067oo00<007ooOol0Mgoo0P00
2Goo00<005KmE_d015Km100055<M00<004EAAE406TEA0`001e<M00<007j]OZd03Gj]00<005<MDad0
2U<M00<005<MDad02U<M0`00>Goo00<007ooOol05Goo00<007ooOol017oo000IOol00`00Oomoo`1f
Ool00`00Oomoo`09Ool00`00E_eFo@030004E_d00`00DaeC7@0>Dad4000IAE43000;Dad00`00OZen
[@0<OZd00`00DaeC7@0;Dad00`00DaeC7@05Dad4000mOol00`00Oomoo`0DOol00`00Oomoo`04Ool0
01Yoo`8007Ioo`03001oogoo00Yoo`8000QFo@03001C7E<M00UC7@@000=C7@030015DDEA01=5D@@0
00mC7@03001n[Gj]00]n[@03001C7E<M00aC7@03001C7E<M00@0049oo`03001oogoo01=oo`03001o
ogoo00Aoo`0077oo00<007ooOol0Lgoo00<007ooOol02goo00<005KmE_d01eKm00<005<MDad01E<M
0`001e<M00<004EAAE4044EA0`0055<M00<007j]OZd02Wj]00<005<MDad035<M0`00AWoo00<007oo
Ool04goo00<007ooOol017oo000MOol00`00Oomoo`1bOol00`00Oomoo`0<Ool00`00E_eFo@07E_d0
0`00DaeC7@04000:Dad00`00AE55D@0=AE43000HDad00`00OZen[@09OZd00`00DaeC7@08Dad4001:
Ool00`00Oomoo`0BOol00`00Oomoo`04Ool001ioo`80079oo`03001oogoo00eoo`03001FoEKm00MF
o@8000iC7@030015DDEA00U5D@@001aC7@03001n[Gj]00Qn[@03001C7E<M00EC7@<004moo`03001o
ogoo019oo`03001oogoo00=oo`0087oo00<007ooOol0Kgoo00<007ooOol03Woo0P0025Km00<005<M
Dad035<M00<004EAAE401TEA0`008E<M00<007j]OZd01gj]00@005<MDaeC7@@005=oo`03001oogoo
015oo`03001oogoo00=oo`008Goo00<007ooOol0KWoo00<007ooOol047oo00<005KmE_d01UKm00<0
05<MDad02e<M00<004EAAE400dEA0`009E<M00<007j]OZd01Wj]1000Egoo00<007ooOol04Goo00<0
07ooOol00goo000ROol00`00Oomoo`1]Ool00`00Oomoo`0AOol00`00E_eFo@06E_d00`00DaeC7@0:
Dad00`00AE400003000XDad00`00OZen[@06OZd00`00Oomoo`1IOol00`00Oomoo`0@Ool00`00Oomo
o`03Ool002=oo`8006eoo`03001oogoo019oo`03001FoEKm00IFo@03001C7E<M00UC7@8002eC7@03
001n[Gj]00En[@03001oogoo05Yoo`03001oogoo00moo`03001oogoo00=oo`009Goo00<007ooOol0
JWoo00<007ooOol04goo00<005KmE_d01UKm00<005<MDad02E<M00<005<MDad0;5<M00<007j]OZd0
1Gj]00<007ooOol0FWoo00<007ooOol03Woo00<007ooOol00goo000VOol00`00Oomoo`1YOol00`00
Oomoo`0DOol00`00E_eFo@06E_d00`00DaeC7@09Dad00`00DaeC7@0/Dad00`00OZen[@04OZd00`00
Oomoo`1JOol00`00Oomoo`0>Ool00`00Oomoo`03Ool002Moo`03001oogoo06Qoo`03001oogoo01Eo
o`03001FoEKm00IFo@03001C7E<M00UC7@03001C7E<M02aC7@03001n[Gj]00=n[@03001oogoo05]o
o`03001oogoo00eoo`03001oogoo00=oo`00:7oo0P00J7oo00<007ooOol05Woo00<005KmE_d01UKm
00<005<MDad02E<M00<005<MDad0;5<M00<007j]OZd00Wj]00<007ooOol0G7oo00<007ooOol03Goo
00<007ooOol00Woo000ZOol00`00Oomoo`1UOol00`00Oomoo`0GOol20007E_d2000:Dad00`00DaeC
7@0/Dad01@00OZen[Gj]0000Ggoo00<007ooOol037oo00<007ooOol00Woo000[Ool00`00Oomoo`1T
Ool00`00Oomoo`0IOol00`00E_eFo@06E_d00`00DaeC7@08Dad00`00DaeC7@0/Dad01000OZen[@00
Ggoo00<007ooOol037oo00<007ooOol00Woo000/Ool00`00Oomoo`1ROol00`00Oomoo`0KOol00`00
E_eFo@05E_d2000:Dad00`00DaeC7@0/Dad00`00OZd0001POol00`00Oomoo`0;Ool00`00Oomoo`02
Ool002eoo`80069oo`03001oogoo01aoo`03001FoEKm00@0009oo`03001C7E<M00QC7@03001C7E<M
02aC7@80065oo`03001oogoo00Yoo`03001oogoo009oo`00;goo00<007ooOol0Ggoo00<007ooOol0
7Goo0P001goo00<005<MDad025<M00<005<MDad0:e<M0P00HWoo00<007ooOol02Goo00<007ooOol0
0Woo000`Ool00`00Oomoo`1NOol00`00Oomoo`0WOol00`00DaeC7@08Dad00`00DaeC7@0VDad4001T
Ool00`00Oomoo`09Ool00`00Oomoo`02Ool0035oo`03001oogoo05eoo`03001oogoo02Qoo`03001C
7E<M00QC7@03001C7E<M025C7@@006Uoo`03001oogoo00Uoo`03001oogoo005oo`00<Woo0P00GGoo
00<007ooOol0:Goo00<005<MDad015<M1@007e<M0`00KWoo00<007ooOol027oo00<007ooOol00Goo
000dOol00`00Oomoo`1JOol00`00Oomoo`0ZOol00`00DaeC7@030005Ool00`00DaeC7@0HDad4001a
Ool00`00Oomoo`08Ool00`00Oomoo`01Ool003Eoo`03001oogoo05Uoo`03001oogoo02]oo`8000Uo
o`03001C7E<M01=C7@@007Ioo`03001oogoo00Moo`03001oogoo005oo`00=Woo0P00FGoo00<007oo
Ool0=goo00<005<MDad03U<M1000Ngoo00<007ooOol01Woo00<007ooOol00Goo000hOol00`00Oomo
o`1FOol00`00Oomoo`0hOol00`00DaeC7@0:Dad30020Ool00`00Oomoo`05Ool00`00Oomoo`01Ool0
03Uoo`03001oogoo05Eoo`03001oogoo03Uoo`03001C7E<M00EC7@@008=oo`03001oogoo00Eoo`03
001oogoo005oo`00>Woo00<007ooOol0E7oo00<007ooOol0>Woo00<005<MDad01000R7oo00<007oo
Ool017oo00<007ooOol00Goo000kOol2001DOol00`00Oomoo`0kOol2002=Ool00`00Oomoo`04Ool1
0001Ool1Ool003eoo`03001oogoo055oo`03001oogoo0<]oo`03001oogoo00=oo`40005oo`5oo`00
?Woo00<007ooOol0D7oo00<007ooOol0bgoo00<007ooOol00goo0@000Goo0Goo000oOol00`00Oomo
o`1?Ool00`00Oomoo`3<Ool00`00Oomoo`02Ool10001Ool1Ool0041oo`8004moo`03001oogoo0<eo
o`05001oogooOol00002Ool0049oo`03001oogoo04aoo`03001oogoo0<ioo`04001oogoo0002Ool0
04=oo`03001oogoo04]oo`03001oogoo0<ioo`04001oogoo0002Ool004Aoo`03001oogoo04Yoo`03
001oogoo0<moo`03001oo`00009oo`00AGoo0P00BWoo00<007ooOol0d7oo00<007oo00000Goo0017
Ool00`00Oomoo`17Ool00`00Oomoo`3AOol20001Ool004Qoo`03001oogoo04Ioo`03001oogoo0=5o
o`80005oo`00BGoo0P00AWoo00<007ooOol0dGoo0P000Goo001;Ool00`00Oomoo`13Ool00`00Oomo
o`3=Ool40003Ool004aoo`03001oogoo049oo`03001oogoo0<Uoo`@000Moo`00CGoo00<007ooOol0
@Goo00<007ooOol0aGoo10002goo001>Ool20011Ool00`00Oomoo`31Ool4000?Ool0051oo`03001o
ogoo03ioo`03001oogoo0;eoo`@001=oo`00DGoo00<007ooOol0?Goo00<007ooOol0^Goo10005goo
001BOol00`00Oomoo`0lOol00`00Oomoo`2eOol4000KOol005=oo`8003]oo`03001oogoo0;9oo`@0
01moo`00EGoo00<007ooOol0>7oo00<007ooOol0[Woo10008goo001FOol00`00Oomoo`0gOol00`00
Oomoo`2ZOol4000WOol005Moo`03001oogoo03Ioo`03001oogoo0:Moo`<002]oo`00F7oo0P00=Woo
00<007ooOol0Xgoo1000;Woo001JOol00`00Oomoo`0cOol00`00Oomoo`2OOol4000bOol005]oo`03
001oogoo039oo`03001oogoo09]oo`@003Ioo`00G7oo0P00<Woo00<007ooOol0Ugoo1000>Woo001N
Ool00`00Oomoo`0_Ool00`00Oomoo`2COol4000nOol005moo`03001oogoo02ioo`03001oogoo08mo
o`@0049oo`00H7oo00<007ooOol0;Goo00<007ooOol0Rgoo1000AWoo001QOol2000]Ool00`00Oomo
o`27Ool4001:Ool006=oo`03001oogoo02Yoo`03001oogoo08=oo`@004ioo`00I7oo00<007ooOol0
:Goo00<007ooOol0Ogoo1000DWoo001UOol00`00Oomoo`0XOol00`00Oomoo`1lOol3001FOol006Io
o`8002Qoo`03001oogoo07Qoo`@005Uoo`00J7oo00<007ooOol09Goo00<007ooOol0M7oo1000GGoo
001YOol00`00Oomoo`0TOol00`00Oomoo`1`Ool4001QOol006Yoo`03001oogoo02=oo`03001oogoo
06aoo`@006Eoo`00Jgoo0P008goo00<007ooOol0J7oo1000JGoo001]Ool00`00Oomoo`0POol00`00
Oomoo`1TOol4001]Ool006ioo`03001oogoo01moo`03001oogoo061oo`@0075oo`00Kgoo00<007oo
Ool07Woo00<007ooOol0G7oo1000MGoo001`Ool2000NOol00`00Oomoo`1HOol4001iOol0079oo`03
001oogoo01]oo`03001oogoo05Aoo`@007eoo`00Lgoo00<007ooOol06Woo00<007ooOol0DGoo0`00
PGoo001dOol2000JOol00`00Oomoo`1=Ool40024Ool007Ioo`03001oogoo01Moo`03001oogoo04Uo
o`@008Qoo`00Mgoo00<007ooOol05Woo00<007ooOol0AGoo1000S7oo001hOol00`00Oomoo`0EOol0
0`00Oomoo`11Ool4002@Ool007Uoo`8001Eoo`03001oogoo03eoo`@009Aoo`00Ngoo00<007ooOol0
4Woo00<007ooOol0>Goo1000V7oo001lOol00`00Oomoo`0@Ool00`00Oomoo`0fOol4002LOol007eo
o`03001oogoo00moo`03001oogoo039oo`@00:1oo`00OWoo0P003goo00<007ooOol0;Woo1000Y7oo
0020Ool00`00Oomoo`0<Ool00`00Oomoo`0ZOol4002XOol0085oo`03001oogoo00]oo`03001oogoo
02Moo`<00:aoo`00PWoo00<007ooOol02Woo00<007ooOol08goo1000[goo0023Ool2000:Ool00`00
Oomoo`0OOol4002cOol008Eoo`03001oogoo00Moo`03001oogoo01]oo`@00;Moo`00QWoo00<007oo
Ool01Woo00<007ooOol05goo1000^goo0027Ool20006Ool00`00Oomoo`0COol4002oOol008Uoo`03
001oogoo00=oo`03001oogoo00moo`@00<=oo`00RWoo00<007ooOol00Woo00<007ooOol02goo1000
agoo002;Ool01@00Oomoogoo00002Goo1000bgoo002<Ool200000goo001oo`04Ool4003?Ool008io
o`800003Ool0000000800==oo`00Sgoo0P00egoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.000330725, 0.0425142, \
0.00331767, 0.00331767}}]
}, Open  ]],

Cell["We'll take it a bit further this time.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show\ @\ \(RasterGraphics3D@\ 
          CellularAutomaton[{630, {2, 1}, {1, 1}}, {{{1}}, 0}, 
            10, \ \(-5\)]\);\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74781 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.42319e-017 1.04921 -0.0991944 1.04921 [
[ 0 0 0 0 ]
[ 1 .74781 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02561 .25675 m
0 .41836 L
s
0 .41836 m
.39737 .74781 L
s
.39737 .74781 m
.40249 .60153 L
s
.40249 .60153 m
.02561 .25675 L
s
.69249 0 m
.97887 .43151 L
s
.97887 .43151 m
1 .5861 L
s
1 .5861 m
.7023 .16913 L
s
.7023 .16913 m
.69249 0 L
s
.02561 .25675 m
0 .41836 L
s
0 .41836 m
.7023 .16913 L
s
.7023 .16913 m
.69249 0 L
s
.69249 0 m
.02561 .25675 L
s
.40249 .60153 m
.97887 .43151 L
s
.97887 .43151 m
1 .5861 L
s
1 .5861 m
.39737 .74781 L
s
.39737 .74781 m
.40249 .60153 L
s
0 0 m
1 0 L
1 .74781 L
0 .74781 L
closepath
clip
newpath
.5 Mabswid
.45285 .60347 m .42966 .61024 L .41609 .5977 L p .66 .747 .915 r
F P
0 g
s
.45238 .62642 m .45285 .60347 L .42966 .61024 L p .573 .367 .563 r
F P
0 g
s
.42966 .61024 m .42904 .63314 L .45238 .62642 L p .573 .367 .563 r
F P
0 g
s
.41609 .5977 m .42966 .61024 L .42904 .63314 L p .941 .685 .523 r
F P
0 g
s
.47624 .59665 m .45285 .60347 L .43941 .59082 L p .66 .747 .915 r
F P
0 g
s
.47592 .61965 m .47624 .59665 L .45285 .60347 L p .573 .367 .563 r
F P
0 g
s
.45285 .60347 m .45238 .62642 L .47592 .61965 L p .573 .367 .563 r
F P
0 g
s
.41609 .5977 m .43941 .59082 L .45285 .60347 L p .66 .747 .915 r
F P
0 g
s
.43941 .59082 m .45285 .60347 L .45238 .62642 L p .943 .686 .517 r
F P
0 g
s
.43941 .59082 m .45285 .60347 L .45238 .62642 L p .943 .686 .517 r
F P
0 g
s
.42904 .63314 m .41538 .6207 L .41609 .5977 L p .941 .685 .523 r
F P
0 g
s
.45238 .62642 m .42904 .63314 L .41538 .6207 L p .658 .749 .917 r
F P
0 g
s
.43884 .61387 m .43941 .59082 L .41609 .5977 L p .571 .363 .56 r
F P
0 g
s
.41609 .5977 m .41538 .6207 L .43884 .61387 L p .571 .363 .56 r
F P
0 g
s
.43941 .59082 m .41609 .5977 L .40231 .58496 L p .66 .747 .915 r
F P
0 g
s
.43884 .61387 m .43941 .59082 L .41609 .5977 L p .571 .363 .56 r
F P
0 g
s
.41609 .5977 m .41538 .6207 L .43884 .61387 L p .571 .363 .56 r
F P
0 g
s
.40231 .58496 m .41609 .5977 L .41538 .6207 L p .941 .685 .523 r
F P
0 g
s
.43941 .59082 m .46292 .58389 L .47624 .59665 L p .66 .747 .915 r
F P
0 g
s
.46292 .58389 m .47624 .59665 L .47592 .61965 L p .946 .686 .511 r
F P
0 g
s
.45238 .62642 m .43884 .61387 L .43941 .59082 L p .943 .686 .517 r
F P
0 g
s
.45238 .62642 m .43884 .61387 L .43941 .59082 L p .943 .686 .517 r
F P
0 g
s
.47592 .61965 m .45238 .62642 L .43884 .61387 L p .658 .749 .917 r
F P
0 g
s
.41538 .6207 m .43884 .61387 L .45238 .62642 L p .658 .749 .917 r
F P
0 g
s
.46251 .60699 m .46292 .58389 L .43941 .59082 L p .571 .363 .56 r
F P
0 g
s
.43941 .59082 m .43884 .61387 L .46251 .60699 L p .571 .363 .56 r
F P
0 g
s
.46292 .58389 m .43941 .59082 L .42575 .57797 L p .66 .747 .915 r
F P
0 g
s
.46251 .60699 m .46292 .58389 L .43941 .59082 L p .571 .363 .56 r
F P
0 g
s
.43941 .59082 m .43884 .61387 L .46251 .60699 L p .571 .363 .56 r
F P
0 g
s
.40231 .58496 m .42575 .57797 L .43941 .59082 L p .66 .747 .915 r
F P
0 g
s
.42575 .57797 m .43941 .59082 L .43884 .61387 L p .943 .686 .517 r
F P
0 g
s
.42575 .57797 m .43941 .59082 L .43884 .61387 L p .943 .686 .517 r
F P
0 g
s
.41538 .6207 m .4015 .60806 L .40231 .58496 L p .941 .685 .523 r
F P
0 g
s
.43884 .61387 m .41538 .6207 L .4015 .60806 L p .658 .749 .917 r
F P
0 g
s
.43884 .61387 m .46251 .60699 L .47592 .61965 L p .658 .749 .917 r
F P
0 g
s
.47592 .61965 m .46251 .60699 L .46292 .58389 L p .946 .686 .511 r
F P
0 g
s
.42509 .60112 m .42575 .57797 L .40231 .58496 L p .569 .36 .558 r
F P
0 g
s
.40231 .58496 m .4015 .60806 L .42509 .60112 L p .569 .36 .558 r
F P
0 g
s
.48663 .57689 m .46292 .58389 L .44939 .57093 L p .66 .747 .915 r
F P
0 g
s
.48638 .60005 m .48663 .57689 L .46292 .58389 L p .571 .363 .56 r
F P
0 g
s
.46292 .58389 m .46251 .60699 L .48638 .60005 L p .571 .363 .56 r
F P
0 g
s
.42575 .57797 m .44939 .57093 L .46292 .58389 L p .66 .747 .915 r
F P
0 g
s
.44939 .57093 m .46292 .58389 L .46251 .60699 L p .946 .686 .511 r
F P
0 g
s
.44939 .57093 m .46292 .58389 L .46251 .60699 L p .946 .686 .511 r
F P
0 g
s
.5476 .57581 m .52361 .58282 L .51055 .56984 L p .66 .747 .915 r
F P
0 g
s
.54775 .59898 m .5476 .57581 L .52361 .58282 L p .573 .367 .563 r
F P
0 g
s
.52361 .58282 m .5236 .60593 L .54775 .59898 L p .573 .367 .563 r
F P
0 g
s
.51055 .56984 m .52361 .58282 L .5236 .60593 L p .952 .687 .499 r
F P
0 g
s
.43884 .61387 m .42509 .60112 L .42575 .57797 L p .943 .686 .517 r
F P
0 g
s
.43884 .61387 m .42509 .60112 L .42575 .57797 L p .943 .686 .517 r
F P
0 g
s
.46251 .60699 m .43884 .61387 L .42509 .60112 L p .658 .749 .917 r
F P
0 g
s
.46209 .63041 m .46251 .60699 L .43884 .61387 L p .571 .363 .56 r
F P
0 g
s
.43884 .61387 m .43827 .63723 L .46209 .63041 L p .571 .363 .56 r
F P
0 g
s
.4015 .60806 m .42509 .60112 L .43884 .61387 L p .658 .749 .917 r
F P
0 g
s
.42509 .60112 m .43884 .61387 L .43827 .63723 L p .943 .686 .517 r
F P
0 g
s
.46251 .60699 m .43884 .61387 L .42509 .60112 L p .658 .749 .917 r
F P
0 g
s
.44888 .59413 m .44939 .57093 L .42575 .57797 L p .569 .36 .558 r
F P
0 g
s
.42575 .57797 m .42509 .60112 L .44888 .59413 L p .569 .36 .558 r
F P
0 g
s
.44939 .57093 m .42575 .57797 L .41187 .56492 L p .66 .747 .915 r
F P
0 g
s
.44888 .59413 m .44939 .57093 L .42575 .57797 L p .569 .36 .558 r
F P
0 g
s
.42575 .57797 m .42509 .60112 L .44888 .59413 L p .569 .36 .558 r
F P
0 g
s
.41187 .56492 m .42575 .57797 L .42509 .60112 L p .943 .686 .517 r
F P
0 g
s
.51055 .56984 m .48663 .57689 L .47323 .56382 L p .66 .747 .915 r
F P
0 g
s
.51046 .59305 m .51055 .56984 L .48663 .57689 L p .571 .363 .56 r
F P
0 g
s
.48663 .57689 m .48638 .60005 L .51046 .59305 L p .571 .363 .56 r
F P
0 g
s
.44939 .57093 m .47323 .56382 L .48663 .57689 L p .66 .747 .915 r
F P
0 g
s
.47323 .56382 m .48663 .57689 L .48638 .60005 L p .949 .687 .505 r
F P
0 g
s
.47323 .56382 m .48663 .57689 L .48638 .60005 L p .949 .687 .505 r
F P
0 g
s
.5718 .56875 m .5476 .57581 L .53468 .56272 L p .66 .747 .915 r
F P
0 g
s
.57212 .59197 m .5718 .56875 L .5476 .57581 L p .573 .367 .563 r
F P
0 g
s
.5476 .57581 m .54775 .59898 L .57212 .59197 L p .573 .367 .563 r
F P
0 g
s
.51055 .56984 m .53468 .56272 L .5476 .57581 L p .66 .747 .915 r
F P
0 g
s
.53468 .56272 m .5476 .57581 L .54775 .59898 L p .954 .688 .492 r
F P
0 g
s
.53468 .56272 m .5476 .57581 L .54775 .59898 L p .954 .688 .492 r
F P
0 g
s
.46251 .60699 m .44888 .59413 L .44939 .57093 L p .946 .686 .511 r
F P
0 g
s
.46251 .60699 m .44888 .59413 L .44939 .57093 L p .946 .686 .511 r
F P
0 g
s
.48638 .60005 m .46251 .60699 L .44888 .59413 L p .658 .749 .917 r
F P
0 g
s
.48612 .62352 m .48638 .60005 L .46251 .60699 L p .571 .363 .56 r
F P
0 g
s
.46251 .60699 m .46209 .63041 L .48612 .62352 L p .571 .363 .56 r
F P
0 g
s
.42509 .60112 m .44888 .59413 L .46251 .60699 L p .658 .749 .917 r
F P
0 g
s
.42509 .60112 m .44888 .59413 L .46251 .60699 L p .658 .749 .917 r
F P
0 g
s
.44888 .59413 m .46251 .60699 L .46209 .63041 L p .946 .686 .511 r
F P
0 g
s
.48638 .60005 m .46251 .60699 L .44888 .59413 L p .658 .749 .917 r
F P
0 g
s
.44888 .59413 m .46251 .60699 L .46209 .63041 L p .946 .686 .511 r
F P
0 g
s
.5236 .60593 m .51046 .59305 L .51055 .56984 L p .952 .687 .499 r
F P
0 g
s
.54775 .59898 m .5236 .60593 L .51046 .59305 L p .658 .749 .917 r
F P
0 g
s
.47289 .58708 m .47323 .56382 L .44939 .57093 L p .569 .36 .558 r
F P
0 g
s
.44939 .57093 m .44888 .59413 L .47289 .58708 L p .569 .36 .558 r
F P
0 g
s
.47323 .56382 m .44939 .57093 L .43564 .55776 L p .66 .747 .915 r
F P
0 g
s
.47289 .58708 m .47323 .56382 L .44939 .57093 L p .569 .36 .558 r
F P
0 g
s
.44939 .57093 m .44888 .59413 L .47289 .58708 L p .569 .36 .558 r
F P
0 g
s
.41187 .56492 m .43564 .55776 L .44939 .57093 L p .66 .747 .915 r
F P
0 g
s
.43564 .55776 m .44939 .57093 L .44888 .59413 L p .946 .686 .511 r
F P
0 g
s
.43564 .55776 m .44939 .57093 L .44888 .59413 L p .946 .686 .511 r
F P
0 g
s
.53475 .58599 m .53468 .56272 L .51055 .56984 L p .571 .363 .56 r
F P
0 g
s
.51055 .56984 m .51046 .59305 L .53475 .58599 L p .571 .363 .56 r
F P
0 g
s
.53468 .56272 m .51055 .56984 L .49729 .55665 L p .66 .747 .915 r
F P
0 g
s
.53475 .58599 m .53468 .56272 L .51055 .56984 L p .571 .363 .56 r
F P
0 g
s
.51055 .56984 m .51046 .59305 L .53475 .58599 L p .571 .363 .56 r
F P
0 g
s
.47323 .56382 m .49729 .55665 L .51055 .56984 L p .66 .747 .915 r
F P
0 g
s
.49729 .55665 m .51055 .56984 L .51046 .59305 L p .952 .687 .499 r
F P
0 g
s
.49729 .55665 m .51055 .56984 L .51046 .59305 L p .952 .687 .499 r
F P
0 g
s
.43827 .63723 m .42442 .62458 L .42509 .60112 L p .943 .686 .517 r
F P
0 g
s
.46209 .63041 m .43827 .63723 L .42442 .62458 L p .656 .751 .92 r
F P
0 g
s
.53468 .56272 m .55902 .55554 L .5718 .56875 L p .66 .747 .915 r
F P
0 g
s
.55902 .55554 m .5718 .56875 L .57212 .59197 L p .957 .688 .485 r
F P
0 g
s
.44837 .61765 m .44888 .59413 L .42509 .60112 L p .569 .36 .558 r
F P
0 g
s
.42509 .60112 m .42442 .62458 L .44837 .61765 L p .569 .36 .558 r
F P
0 g
s
.42509 .60112 m .41111 .58817 L .41187 .56492 L p .943 .686 .517 r
F P
0 g
s
.44888 .59413 m .42509 .60112 L .41111 .58817 L p .658 .749 .917 r
F P
0 g
s
.44837 .61765 m .44888 .59413 L .42509 .60112 L p .569 .36 .558 r
F P
0 g
s
.42509 .60112 m .42442 .62458 L .44837 .61765 L p .569 .36 .558 r
F P
0 g
s
.41111 .58817 m .42509 .60112 L .42442 .62458 L p .943 .686 .517 r
F P
0 g
s
.44888 .59413 m .42509 .60112 L .41111 .58817 L p .658 .749 .917 r
F P
0 g
s
.48638 .60005 m .47289 .58708 L .47323 .56382 L p .949 .687 .505 r
F P
0 g
s
.48638 .60005 m .47289 .58708 L .47323 .56382 L p .949 .687 .505 r
F P
0 g
s
.51046 .59305 m .48638 .60005 L .47289 .58708 L p .658 .749 .917 r
F P
0 g
s
.51036 .61658 m .51046 .59305 L .48638 .60005 L p .571 .363 .56 r
F P
0 g
s
.48638 .60005 m .48612 .62352 L .51036 .61658 L p .571 .363 .56 r
F P
0 g
s
.44888 .59413 m .47289 .58708 L .48638 .60005 L p .658 .749 .917 r
F P
0 g
s
.44888 .59413 m .47289 .58708 L .48638 .60005 L p .658 .749 .917 r
F P
0 g
s
.47289 .58708 m .48638 .60005 L .48612 .62352 L p .949 .687 .505 r
F P
0 g
s
.51046 .59305 m .48638 .60005 L .47289 .58708 L p .658 .749 .917 r
F P
0 g
s
.47289 .58708 m .48638 .60005 L .48612 .62352 L p .949 .687 .505 r
F P
0 g
s
.54775 .59898 m .53475 .58599 L .53468 .56272 L p .954 .688 .492 r
F P
0 g
s
.54775 .59898 m .53475 .58599 L .53468 .56272 L p .954 .688 .492 r
F P
0 g
s
.57212 .59197 m .54775 .59898 L .53475 .58599 L p .658 .749 .917 r
F P
0 g
s
.51046 .59305 m .53475 .58599 L .54775 .59898 L p .658 .749 .917 r
F P
0 g
s
.43504 .58106 m .43564 .55776 L .41187 .56492 L p .566 .356 .555 r
F P
0 g
s
.41187 .56492 m .41111 .58817 L .43504 .58106 L p .566 .356 .555 r
F P
0 g
s
.43564 .55776 m .41187 .56492 L .39777 .55165 L p .66 .747 .915 r
F P
0 g
s
.43504 .58106 m .43564 .55776 L .41187 .56492 L p .566 .356 .555 r
F P
0 g
s
.41187 .56492 m .41111 .58817 L .43504 .58106 L p .566 .356 .555 r
F P
0 g
s
.39777 .55165 m .41187 .56492 L .41111 .58817 L p .943 .686 .517 r
F P
0 g
s
.49711 .57996 m .49729 .55665 L .47323 .56382 L p .569 .36 .558 r
F P
0 g
s
.47323 .56382 m .47289 .58708 L .49711 .57996 L p .569 .36 .558 r
F P
0 g
s
.49729 .55665 m .47323 .56382 L .45962 .55054 L p .66 .747 .915 r
F P
0 g
s
.49711 .57996 m .49729 .55665 L .47323 .56382 L p .569 .36 .558 r
F P
0 g
s
.47323 .56382 m .47289 .58708 L .49711 .57996 L p .569 .36 .558 r
F P
0 g
s
.43564 .55776 m .45962 .55054 L .47323 .56382 L p .66 .747 .915 r
F P
0 g
s
.45962 .55054 m .47323 .56382 L .47289 .58708 L p .949 .687 .505 r
F P
0 g
s
.45962 .55054 m .47323 .56382 L .47289 .58708 L p .949 .687 .505 r
F P
0 g
s
.55925 .57886 m .55902 .55554 L .53468 .56272 L p .571 .363 .56 r
F P
0 g
s
.53468 .56272 m .53475 .58599 L .55925 .57886 L p .571 .363 .56 r
F P
0 g
s
.55902 .55554 m .53468 .56272 L .52156 .54942 L p .66 .747 .915 r
F P
0 g
s
.55925 .57886 m .55902 .55554 L .53468 .56272 L p .571 .363 .56 r
F P
0 g
s
.53468 .56272 m .53475 .58599 L .55925 .57886 L p .571 .363 .56 r
F P
0 g
s
.49729 .55665 m .52156 .54942 L .53468 .56272 L p .66 .747 .915 r
F P
0 g
s
.52156 .54942 m .53468 .56272 L .53475 .58599 L p .954 .688 .492 r
F P
0 g
s
.52156 .54942 m .53468 .56272 L .53475 .58599 L p .954 .688 .492 r
F P
0 g
s
.46209 .63041 m .44837 .61765 L .44888 .59413 L p .946 .686 .511 r
F P
0 g
s
.46209 .63041 m .44837 .61765 L .44888 .59413 L p .946 .686 .511 r
F P
0 g
s
.48612 .62352 m .46209 .63041 L .44837 .61765 L p .656 .751 .92 r
F P
0 g
s
.42442 .62458 m .44837 .61765 L .46209 .63041 L p .656 .751 .92 r
F P
0 g
s
.47254 .61065 m .47289 .58708 L .44888 .59413 L p .569 .36 .558 r
F P
0 g
s
.44888 .59413 m .44837 .61765 L .47254 .61065 L p .569 .36 .558 r
F P
0 g
s
.44888 .59413 m .43504 .58106 L .43564 .55776 L p .946 .686 .511 r
F P
0 g
s
.44888 .59413 m .43504 .58106 L .43564 .55776 L p .946 .686 .511 r
F P
0 g
s
.47289 .58708 m .44888 .59413 L .43504 .58106 L p .658 .749 .917 r
F P
0 g
s
.47254 .61065 m .47289 .58708 L .44888 .59413 L p .569 .36 .558 r
F P
0 g
s
.44888 .59413 m .44837 .61765 L .47254 .61065 L p .569 .36 .558 r
F P
0 g
s
.41111 .58817 m .43504 .58106 L .44888 .59413 L p .658 .749 .917 r
F P
0 g
s
.41111 .58817 m .43504 .58106 L .44888 .59413 L p .658 .749 .917 r
F P
0 g
s
.43504 .58106 m .44888 .59413 L .44837 .61765 L p .946 .686 .511 r
F P
0 g
s
.47289 .58708 m .44888 .59413 L .43504 .58106 L p .658 .749 .917 r
F P
0 g
s
.43504 .58106 m .44888 .59413 L .44837 .61765 L p .946 .686 .511 r
F P
0 g
s
.51046 .59305 m .49711 .57996 L .49729 .55665 L p .952 .687 .499 r
F P
0 g
s
.51046 .59305 m .49711 .57996 L .49729 .55665 L p .952 .687 .499 r
F P
0 g
s
.53475 .58599 m .51046 .59305 L .49711 .57996 L p .658 .749 .917 r
F P
0 g
s
.53482 .60957 m .53475 .58599 L .51046 .59305 L p .571 .363 .56 r
F P
0 g
s
.51046 .59305 m .51036 .61658 L .53482 .60957 L p .571 .363 .56 r
F P
0 g
s
.47289 .58708 m .49711 .57996 L .51046 .59305 L p .658 .749 .917 r
F P
0 g
s
.47289 .58708 m .49711 .57996 L .51046 .59305 L p .658 .749 .917 r
F P
0 g
s
.49711 .57996 m .51046 .59305 L .51036 .61658 L p .952 .687 .499 r
F P
0 g
s
.53475 .58599 m .51046 .59305 L .49711 .57996 L p .658 .749 .917 r
F P
0 g
s
.49711 .57996 m .51046 .59305 L .51036 .61658 L p .952 .687 .499 r
F P
0 g
s
.39777 .55165 m .37407 .55887 L .35961 .5455 L p .66 .747 .915 r
F P
0 g
s
.39691 .575 m .39777 .55165 L .37407 .55887 L p .564 .353 .553 r
F P
0 g
s
.37407 .55887 m .37306 .58216 L .39691 .575 L p .564 .353 .553 r
F P
0 g
s
.35961 .5455 m .37407 .55887 L .37306 .58216 L p .941 .685 .523 r
F P
0 g
s
.53475 .58599 m .55925 .57886 L .57212 .59197 L p .658 .749 .917 r
F P
0 g
s
.57212 .59197 m .55925 .57886 L .55902 .55554 L p .957 .688 .485 r
F P
0 g
s
.45918 .57389 m .45962 .55054 L .43564 .55776 L p .566 .356 .555 r
F P
0 g
s
.43564 .55776 m .43504 .58106 L .45918 .57389 L p .566 .356 .555 r
F P
0 g
s
.45962 .55054 m .43564 .55776 L .42167 .54438 L p .66 .747 .915 r
F P
0 g
s
.45918 .57389 m .45962 .55054 L .43564 .55776 L p .566 .356 .555 r
F P
0 g
s
.43564 .55776 m .43504 .58106 L .45918 .57389 L p .566 .356 .555 r
F P
0 g
s
.39777 .55165 m .42167 .54438 L .43564 .55776 L p .66 .747 .915 r
F P
0 g
s
.42167 .54438 m .43564 .55776 L .43504 .58106 L p .946 .686 .511 r
F P
0 g
s
.42167 .54438 m .43564 .55776 L .43504 .58106 L p .946 .686 .511 r
F P
0 g
s
.52153 .57279 m .52156 .54942 L .49729 .55665 L p .569 .36 .558 r
F P
0 g
s
.49729 .55665 m .49711 .57996 L .52153 .57279 L p .569 .36 .558 r
F P
0 g
s
.52156 .54942 m .49729 .55665 L .48381 .54325 L p .66 .747 .915 r
F P
0 g
s
.52153 .57279 m .52156 .54942 L .49729 .55665 L p .569 .36 .558 r
F P
0 g
s
.49729 .55665 m .49711 .57996 L .52153 .57279 L p .569 .36 .558 r
F P
0 g
s
.45962 .55054 m .48381 .54325 L .49729 .55665 L p .66 .747 .915 r
F P
0 g
s
.48381 .54325 m .49729 .55665 L .49711 .57996 L p .952 .687 .499 r
F P
0 g
s
.48381 .54325 m .49729 .55665 L .49711 .57996 L p .952 .687 .499 r
F P
0 g
s
.42442 .62458 m .41034 .61173 L .41111 .58817 L p .943 .686 .517 r
F P
0 g
s
.44837 .61765 m .42442 .62458 L .41034 .61173 L p .656 .751 .92 r
F P
0 g
s
.52156 .54942 m .54603 .54213 L .55902 .55554 L p .66 .747 .915 r
F P
0 g
s
.54603 .54213 m .55902 .55554 L .55925 .57886 L p .957 .688 .485 r
F P
0 g
s
.48612 .62352 m .47254 .61065 L .47289 .58708 L p .949 .687 .505 r
F P
0 g
s
.48612 .62352 m .47254 .61065 L .47289 .58708 L p .949 .687 .505 r
F P
0 g
s
.51036 .61658 m .48612 .62352 L .47254 .61065 L p .656 .751 .92 r
F P
0 g
s
.44837 .61765 m .47254 .61065 L .48612 .62352 L p .656 .751 .92 r
F P
0 g
s
.43443 .60468 m .43504 .58106 L .41111 .58817 L p .566 .356 .555 r
F P
0 g
s
.41111 .58817 m .41034 .61173 L .43443 .60468 L p .566 .356 .555 r
F P
0 g
s
.41111 .58817 m .39691 .575 L .39777 .55165 L p .943 .686 .517 r
F P
0 g
s
.43504 .58106 m .41111 .58817 L .39691 .575 L p .658 .749 .917 r
F P
0 g
s
.43443 .60468 m .43504 .58106 L .41111 .58817 L p .566 .356 .555 r
F P
0 g
s
.41111 .58817 m .41034 .61173 L .43443 .60468 L p .566 .356 .555 r
F P
0 g
s
.39691 .575 m .41111 .58817 L .41034 .61173 L p .943 .686 .517 r
F P
0 g
s
.43504 .58106 m .41111 .58817 L .39691 .575 L p .658 .749 .917 r
F P
0 g
s
.49692 .60359 m .49711 .57996 L .47289 .58708 L p .569 .36 .558 r
F P
0 g
s
.47289 .58708 m .47254 .61065 L .49692 .60359 L p .569 .36 .558 r
F P
0 g
s
.47289 .58708 m .45918 .57389 L .45962 .55054 L p .949 .687 .505 r
F P
0 g
s
.47289 .58708 m .45918 .57389 L .45962 .55054 L p .949 .687 .505 r
F P
0 g
s
.49711 .57996 m .47289 .58708 L .45918 .57389 L p .658 .749 .917 r
F P
0 g
s
.49692 .60359 m .49711 .57996 L .47289 .58708 L p .569 .36 .558 r
F P
0 g
s
.47289 .58708 m .47254 .61065 L .49692 .60359 L p .569 .36 .558 r
F P
0 g
s
.43504 .58106 m .45918 .57389 L .47289 .58708 L p .658 .749 .917 r
F P
0 g
s
.43504 .58106 m .45918 .57389 L .47289 .58708 L p .658 .749 .917 r
F P
0 g
s
.45918 .57389 m .47289 .58708 L .47254 .61065 L p .949 .687 .505 r
F P
0 g
s
.49711 .57996 m .47289 .58708 L .45918 .57389 L p .658 .749 .917 r
F P
0 g
s
.45918 .57389 m .47289 .58708 L .47254 .61065 L p .949 .687 .505 r
F P
0 g
s
.53475 .58599 m .52153 .57279 L .52156 .54942 L p .954 .688 .492 r
F P
0 g
s
.53475 .58599 m .52153 .57279 L .52156 .54942 L p .954 .688 .492 r
F P
0 g
s
.55925 .57886 m .53475 .58599 L .52153 .57279 L p .658 .749 .917 r
F P
0 g
s
.49711 .57996 m .52153 .57279 L .53475 .58599 L p .658 .749 .917 r
F P
0 g
s
.49711 .57996 m .52153 .57279 L .53475 .58599 L p .658 .749 .917 r
F P
0 g
s
.52153 .57279 m .53475 .58599 L .53482 .60957 L p .954 .688 .492 r
F P
0 g
s
.42097 .56778 m .42167 .54438 L .39777 .55165 L p .564 .353 .553 r
F P
0 g
s
.39777 .55165 m .39691 .575 L .42097 .56778 L p .564 .353 .553 r
F P
0 g
s
.42167 .54438 m .39777 .55165 L .38344 .53817 L p .66 .747 .915 r
F P
0 g
s
.42097 .56778 m .42167 .54438 L .39777 .55165 L p .564 .353 .553 r
F P
0 g
s
.39777 .55165 m .39691 .575 L .42097 .56778 L p .564 .353 .553 r
F P
0 g
s
.35961 .5455 m .38344 .53817 L .39777 .55165 L p .66 .747 .915 r
F P
0 g
s
.38344 .53817 m .39777 .55165 L .39691 .575 L p .943 .686 .517 r
F P
0 g
s
.38344 .53817 m .39777 .55165 L .39691 .575 L p .943 .686 .517 r
F P
0 g
s
.48353 .56666 m .48381 .54325 L .45962 .55054 L p .566 .356 .555 r
F P
0 g
s
.45962 .55054 m .45918 .57389 L .48353 .56666 L p .566 .356 .555 r
F P
0 g
s
.48381 .54325 m .45962 .55054 L .44578 .53704 L p .66 .747 .915 r
F P
0 g
s
.48353 .56666 m .48381 .54325 L .45962 .55054 L p .566 .356 .555 r
F P
0 g
s
.45962 .55054 m .45918 .57389 L .48353 .56666 L p .566 .356 .555 r
F P
0 g
s
.42167 .54438 m .44578 .53704 L .45962 .55054 L p .66 .747 .915 r
F P
0 g
s
.44578 .53704 m .45962 .55054 L .45918 .57389 L p .949 .687 .505 r
F P
0 g
s
.44578 .53704 m .45962 .55054 L .45918 .57389 L p .949 .687 .505 r
F P
0 g
s
.54618 .56554 m .54603 .54213 L .52156 .54942 L p .569 .36 .558 r
F P
0 g
s
.52156 .54942 m .52153 .57279 L .54618 .56554 L p .569 .36 .558 r
F P
0 g
s
.48381 .54325 m .50821 .5359 L .52156 .54942 L p .66 .747 .915 r
F P
0 g
s
.50821 .5359 m .52156 .54942 L .52153 .57279 L p .954 .688 .492 r
F P
0 g
s
.44837 .61765 m .43443 .60468 L .43504 .58106 L p .946 .686 .511 r
F P
0 g
s
.44837 .61765 m .43443 .60468 L .43504 .58106 L p .946 .686 .511 r
F P
0 g
s
.47254 .61065 m .44837 .61765 L .43443 .60468 L p .656 .751 .92 r
F P
0 g
s
.47218 .63454 m .47254 .61065 L .44837 .61765 L p .569 .36 .558 r
F P
0 g
s
.44837 .61765 m .44786 .64148 L .47218 .63454 L p .569 .36 .558 r
F P
0 g
s
.41034 .61173 m .43443 .60468 L .44837 .61765 L p .656 .751 .92 r
F P
0 g
s
.43443 .60468 m .44837 .61765 L .44786 .64148 L p .946 .686 .511 r
F P
0 g
s
.47254 .61065 m .44837 .61765 L .43443 .60468 L p .656 .751 .92 r
F P
0 g
s
.51036 .61658 m .49692 .60359 L .49711 .57996 L p .952 .687 .499 r
F P
0 g
s
.51036 .61658 m .49692 .60359 L .49711 .57996 L p .952 .687 .499 r
F P
0 g
s
.53482 .60957 m .51036 .61658 L .49692 .60359 L p .656 .751 .92 r
F P
0 g
s
.47254 .61065 m .49692 .60359 L .51036 .61658 L p .656 .751 .92 r
F P
0 g
s
.37306 .58216 m .35849 .56889 L .35961 .5455 L p .941 .685 .523 r
F P
0 g
s
.39691 .575 m .37306 .58216 L .35849 .56889 L p .658 .749 .917 r
F P
0 g
s
.45873 .59757 m .45918 .57389 L .43504 .58106 L p .566 .356 .555 r
F P
0 g
s
.43504 .58106 m .43443 .60468 L .45873 .59757 L p .566 .356 .555 r
F P
0 g
s
.43504 .58106 m .42097 .56778 L .42167 .54438 L p .946 .686 .511 r
F P
0 g
s
.43504 .58106 m .42097 .56778 L .42167 .54438 L p .946 .686 .511 r
F P
0 g
s
.45918 .57389 m .43504 .58106 L .42097 .56778 L p .658 .749 .917 r
F P
0 g
s
.45873 .59757 m .45918 .57389 L .43504 .58106 L p .566 .356 .555 r
F P
0 g
s
.43504 .58106 m .43443 .60468 L .45873 .59757 L p .566 .356 .555 r
F P
0 g
s
.39691 .575 m .42097 .56778 L .43504 .58106 L p .658 .749 .917 r
F P
0 g
s
.39691 .575 m .42097 .56778 L .43504 .58106 L p .658 .749 .917 r
F P
0 g
s
.42097 .56778 m .43504 .58106 L .43443 .60468 L p .946 .686 .511 r
F P
0 g
s
.45918 .57389 m .43504 .58106 L .42097 .56778 L p .658 .749 .917 r
F P
0 g
s
.42097 .56778 m .43504 .58106 L .43443 .60468 L p .946 .686 .511 r
F P
0 g
s
.52151 .59647 m .52153 .57279 L .49711 .57996 L p .569 .36 .558 r
F P
0 g
s
.49711 .57996 m .49692 .60359 L .52151 .59647 L p .569 .36 .558 r
F P
0 g
s
.49711 .57996 m .48353 .56666 L .48381 .54325 L p .952 .687 .499 r
F P
0 g
s
.49711 .57996 m .48353 .56666 L .48381 .54325 L p .952 .687 .499 r
F P
0 g
s
.52153 .57279 m .49711 .57996 L .48353 .56666 L p .658 .749 .917 r
F P
0 g
s
.52151 .59647 m .52153 .57279 L .49711 .57996 L p .569 .36 .558 r
F P
0 g
s
.49711 .57996 m .49692 .60359 L .52151 .59647 L p .569 .36 .558 r
F P
0 g
s
.45918 .57389 m .48353 .56666 L .49711 .57996 L p .658 .749 .917 r
F P
0 g
s
.45918 .57389 m .48353 .56666 L .49711 .57996 L p .658 .749 .917 r
F P
0 g
s
.48353 .56666 m .49711 .57996 L .49692 .60359 L p .952 .687 .499 r
F P
0 g
s
.52153 .57279 m .49711 .57996 L .48353 .56666 L p .658 .749 .917 r
F P
0 g
s
.48353 .56666 m .49711 .57996 L .49692 .60359 L p .952 .687 .499 r
F P
0 g
s
.38247 .56162 m .38344 .53817 L .35961 .5455 L p .561 .349 .55 r
F P
0 g
s
.35961 .5455 m .35849 .56889 L .38247 .56162 L p .561 .349 .55 r
F P
0 g
s
.38344 .53817 m .35961 .5455 L .34492 .53192 L p .66 .747 .915 r
F P
0 g
s
.38247 .56162 m .38344 .53817 L .35961 .5455 L p .561 .349 .55 r
F P
0 g
s
.35961 .5455 m .35849 .56889 L .38247 .56162 L p .561 .349 .55 r
F P
0 g
s
.34492 .53192 m .35961 .5455 L .35849 .56889 L p .941 .685 .523 r
F P
0 g
s
.52153 .57279 m .54618 .56554 L .55925 .57886 L p .658 .749 .917 r
F P
0 g
s
.55925 .57886 m .54618 .56554 L .54603 .54213 L p .957 .688 .485 r
F P
0 g
s
.44524 .56049 m .44578 .53704 L .42167 .54438 L p .564 .353 .553 r
F P
0 g
s
.42167 .54438 m .42097 .56778 L .44524 .56049 L p .564 .353 .553 r
F P
0 g
s
.44578 .53704 m .42167 .54438 L .40747 .53078 L p .66 .747 .915 r
F P
0 g
s
.44524 .56049 m .44578 .53704 L .42167 .54438 L p .564 .353 .553 r
F P
0 g
s
.42167 .54438 m .42097 .56778 L .44524 .56049 L p .564 .353 .553 r
F P
0 g
s
.38344 .53817 m .40747 .53078 L .42167 .54438 L p .66 .747 .915 r
F P
0 g
s
.40747 .53078 m .42167 .54438 L .42097 .56778 L p .946 .686 .511 r
F P
0 g
s
.40747 .53078 m .42167 .54438 L .42097 .56778 L p .946 .686 .511 r
F P
0 g
s
.5081 .55937 m .50821 .5359 L .48381 .54325 L p .566 .356 .555 r
F P
0 g
s
.48381 .54325 m .48353 .56666 L .5081 .55937 L p .566 .356 .555 r
F P
0 g
s
.44578 .53704 m .47011 .52963 L .48381 .54325 L p .66 .747 .915 r
F P
0 g
s
.47011 .52963 m .48381 .54325 L .48353 .56666 L p .952 .687 .499 r
F P
0 g
s
.41034 .61173 m .39604 .59867 L .39691 .575 L p .943 .686 .517 r
F P
0 g
s
.43443 .60468 m .41034 .61173 L .39604 .59867 L p .656 .751 .92 r
F P
0 g
s
.47254 .61065 m .45873 .59757 L .45918 .57389 L p .949 .687 .505 r
F P
0 g
s
.47254 .61065 m .45873 .59757 L .45918 .57389 L p .949 .687 .505 r
F P
0 g
s
.49692 .60359 m .47254 .61065 L .45873 .59757 L p .656 .751 .92 r
F P
0 g
s
.49673 .62754 m .49692 .60359 L .47254 .61065 L p .569 .36 .558 r
F P
0 g
s
.47254 .61065 m .47218 .63454 L .49673 .62754 L p .569 .36 .558 r
F P
0 g
s
.43443 .60468 m .45873 .59757 L .47254 .61065 L p .656 .751 .92 r
F P
0 g
s
.43443 .60468 m .45873 .59757 L .47254 .61065 L p .656 .751 .92 r
F P
0 g
s
.45873 .59757 m .47254 .61065 L .47218 .63454 L p .949 .687 .505 r
F P
0 g
s
.49692 .60359 m .47254 .61065 L .45873 .59757 L p .656 .751 .92 r
F P
0 g
s
.45873 .59757 m .47254 .61065 L .47218 .63454 L p .949 .687 .505 r
F P
0 g
s
.49692 .60359 m .52151 .59647 L .53482 .60957 L p .656 .751 .92 r
F P
0 g
s
.53482 .60957 m .52151 .59647 L .52153 .57279 L p .954 .688 .492 r
F P
0 g
s
.42026 .5915 m .42097 .56778 L .39691 .575 L p .564 .353 .553 r
F P
0 g
s
.39691 .575 m .39604 .59867 L .42026 .5915 L p .564 .353 .553 r
F P
0 g
s
.39691 .575 m .38247 .56162 L .38344 .53817 L p .943 .686 .517 r
F P
0 g
s
.39691 .575 m .38247 .56162 L .38344 .53817 L p .943 .686 .517 r
F P
0 g
s
.42097 .56778 m .39691 .575 L .38247 .56162 L p .658 .749 .917 r
F P
0 g
s
.42026 .5915 m .42097 .56778 L .39691 .575 L p .564 .353 .553 r
F P
0 g
s
.39691 .575 m .39604 .59867 L .42026 .5915 L p .564 .353 .553 r
F P
0 g
s
.35849 .56889 m .38247 .56162 L .39691 .575 L p .658 .749 .917 r
F P
0 g
s
.38247 .56162 m .39691 .575 L .39604 .59867 L p .943 .686 .517 r
F P
0 g
s
.42097 .56778 m .39691 .575 L .38247 .56162 L p .658 .749 .917 r
F P
0 g
s
.48325 .59039 m .48353 .56666 L .45918 .57389 L p .566 .356 .555 r
F P
0 g
s
.45918 .57389 m .45873 .59757 L .48325 .59039 L p .566 .356 .555 r
F P
0 g
s
.45918 .57389 m .44524 .56049 L .44578 .53704 L p .949 .687 .505 r
F P
0 g
s
.45918 .57389 m .44524 .56049 L .44578 .53704 L p .949 .687 .505 r
F P
0 g
s
.48353 .56666 m .45918 .57389 L .44524 .56049 L p .658 .749 .917 r
F P
0 g
s
.48325 .59039 m .48353 .56666 L .45918 .57389 L p .566 .356 .555 r
F P
0 g
s
.45918 .57389 m .45873 .59757 L .48325 .59039 L p .566 .356 .555 r
F P
0 g
s
.42097 .56778 m .44524 .56049 L .45918 .57389 L p .658 .749 .917 r
F P
0 g
s
.42097 .56778 m .44524 .56049 L .45918 .57389 L p .658 .749 .917 r
F P
0 g
s
.44524 .56049 m .45918 .57389 L .45873 .59757 L p .949 .687 .505 r
F P
0 g
s
.48353 .56666 m .45918 .57389 L .44524 .56049 L p .658 .749 .917 r
F P
0 g
s
.44524 .56049 m .45918 .57389 L .45873 .59757 L p .949 .687 .505 r
F P
0 g
s
.48353 .56666 m .5081 .55937 L .52153 .57279 L p .658 .749 .917 r
F P
0 g
s
.48353 .56666 m .5081 .55937 L .52153 .57279 L p .658 .749 .917 r
F P
0 g
s
.5081 .55937 m .52153 .57279 L .52151 .59647 L p .954 .688 .492 r
F P
0 g
s
.52153 .57279 m .5081 .55937 L .50821 .5359 L p .954 .688 .492 r
F P
0 g
s
.40667 .55428 m .40747 .53078 L .38344 .53817 L p .561 .349 .55 r
F P
0 g
s
.38344 .53817 m .38247 .56162 L .40667 .55428 L p .561 .349 .55 r
F P
0 g
s
.40747 .53078 m .38344 .53817 L .36887 .52447 L p .66 .747 .915 r
F P
0 g
s
.40667 .55428 m .40747 .53078 L .38344 .53817 L p .561 .349 .55 r
F P
0 g
s
.38344 .53817 m .38247 .56162 L .40667 .55428 L p .561 .349 .55 r
F P
0 g
s
.34492 .53192 m .36887 .52447 L .38344 .53817 L p .66 .747 .915 r
F P
0 g
s
.36887 .52447 m .38344 .53817 L .38247 .56162 L p .943 .686 .517 r
F P
0 g
s
.36887 .52447 m .38344 .53817 L .38247 .56162 L p .943 .686 .517 r
F P
0 g
s
.44786 .64148 m .43381 .62862 L .43443 .60468 L p .946 .686 .511 r
F P
0 g
s
.47218 .63454 m .44786 .64148 L .43381 .62862 L p .654 .754 .923 r
F P
0 g
s
.46974 .55314 m .47011 .52963 L .44578 .53704 L p .564 .353 .553 r
F P
0 g
s
.44578 .53704 m .44524 .56049 L .46974 .55314 L p .564 .353 .553 r
F P
0 g
s
.40747 .53078 m .43172 .52331 L .44578 .53704 L p .66 .747 .915 r
F P
0 g
s
.43172 .52331 m .44578 .53704 L .44524 .56049 L p .949 .687 .505 r
F P
0 g
s
.53283 .52849 m .50821 .5359 L .49465 .52216 L p .66 .747 .915 r
F P
0 g
s
.53289 .552 m .53283 .52849 L .50821 .5359 L p .566 .356 .555 r
F P
0 g
s
.50821 .5359 m .5081 .55937 L .53289 .552 L p .566 .356 .555 r
F P
0 g
s
.49465 .52216 m .50821 .5359 L .5081 .55937 L p .954 .688 .492 r
F P
0 g
s
.45828 .62157 m .45873 .59757 L .43443 .60468 L p .566 .356 .555 r
F P
0 g
s
.43443 .60468 m .43381 .62862 L .45828 .62157 L p .566 .356 .555 r
F P
0 g
s
.43443 .60468 m .42026 .5915 L .42097 .56778 L p .946 .686 .511 r
F P
0 g
s
.43443 .60468 m .42026 .5915 L .42097 .56778 L p .946 .686 .511 r
F P
0 g
s
.45873 .59757 m .43443 .60468 L .42026 .5915 L p .656 .751 .92 r
F P
0 g
s
.45828 .62157 m .45873 .59757 L .43443 .60468 L p .566 .356 .555 r
F P
0 g
s
.43443 .60468 m .43381 .62862 L .45828 .62157 L p .566 .356 .555 r
F P
0 g
s
.39604 .59867 m .42026 .5915 L .43443 .60468 L p .656 .751 .92 r
F P
0 g
s
.42026 .5915 m .43443 .60468 L .43381 .62862 L p .946 .686 .511 r
F P
0 g
s
.45873 .59757 m .43443 .60468 L .42026 .5915 L p .656 .751 .92 r
F P
0 g
s
.49692 .60359 m .48325 .59039 L .48353 .56666 L p .952 .687 .499 r
F P
0 g
s
.49692 .60359 m .48325 .59039 L .48353 .56666 L p .952 .687 .499 r
F P
0 g
s
.52151 .59647 m .49692 .60359 L .48325 .59039 L p .656 .751 .92 r
F P
0 g
s
.45873 .59757 m .48325 .59039 L .49692 .60359 L p .656 .751 .92 r
F P
0 g
s
.45873 .59757 m .48325 .59039 L .49692 .60359 L p .656 .751 .92 r
F P
0 g
s
.48325 .59039 m .49692 .60359 L .49673 .62754 L p .952 .687 .499 r
F P
0 g
s
.35849 .56889 m .34368 .55541 L .34492 .53192 L p .941 .685 .523 r
F P
0 g
s
.38247 .56162 m .35849 .56889 L .34368 .55541 L p .658 .749 .917 r
F P
0 g
s
.4447 .58427 m .44524 .56049 L .42097 .56778 L p .564 .353 .553 r
F P
0 g
s
.42097 .56778 m .42026 .5915 L .4447 .58427 L p .564 .353 .553 r
F P
0 g
s
.42097 .56778 m .40667 .55428 L .40747 .53078 L p .946 .686 .511 r
F P
0 g
s
.42097 .56778 m .40667 .55428 L .40747 .53078 L p .946 .686 .511 r
F P
0 g
s
.44524 .56049 m .42097 .56778 L .40667 .55428 L p .658 .749 .917 r
F P
0 g
s
.4447 .58427 m .44524 .56049 L .42097 .56778 L p .564 .353 .553 r
F P
0 g
s
.42097 .56778 m .42026 .5915 L .4447 .58427 L p .564 .353 .553 r
F P
0 g
s
.38247 .56162 m .40667 .55428 L .42097 .56778 L p .658 .749 .917 r
F P
0 g
s
.38247 .56162 m .40667 .55428 L .42097 .56778 L p .658 .749 .917 r
F P
0 g
s
.40667 .55428 m .42097 .56778 L .42026 .5915 L p .946 .686 .511 r
F P
0 g
s
.44524 .56049 m .42097 .56778 L .40667 .55428 L p .658 .749 .917 r
F P
0 g
s
.40667 .55428 m .42097 .56778 L .42026 .5915 L p .946 .686 .511 r
F P
0 g
s
.50799 .58315 m .5081 .55937 L .48353 .56666 L p .566 .356 .555 r
F P
0 g
s
.48353 .56666 m .48325 .59039 L .50799 .58315 L p .566 .356 .555 r
F P
0 g
s
.48353 .56666 m .46974 .55314 L .47011 .52963 L p .952 .687 .499 r
F P
0 g
s
.5081 .55937 m .48353 .56666 L .46974 .55314 L p .658 .749 .917 r
F P
0 g
s
.50799 .58315 m .5081 .55937 L .48353 .56666 L p .566 .356 .555 r
F P
0 g
s
.48353 .56666 m .48325 .59039 L .50799 .58315 L p .566 .356 .555 r
F P
0 g
s
.44524 .56049 m .46974 .55314 L .48353 .56666 L p .658 .749 .917 r
F P
0 g
s
.44524 .56049 m .46974 .55314 L .48353 .56666 L p .658 .749 .917 r
F P
0 g
s
.46974 .55314 m .48353 .56666 L .48325 .59039 L p .952 .687 .499 r
F P
0 g
s
.46974 .55314 m .48353 .56666 L .48325 .59039 L p .952 .687 .499 r
F P
0 g
s
.3678 .54801 m .36887 .52447 L .34492 .53192 L p .558 .345 .547 r
F P
0 g
s
.34492 .53192 m .34368 .55541 L .3678 .54801 L p .558 .345 .547 r
F P
0 g
s
.43108 .54687 m .43172 .52331 L .40747 .53078 L p .561 .349 .55 r
F P
0 g
s
.40747 .53078 m .40667 .55428 L .43108 .54687 L p .561 .349 .55 r
F P
0 g
s
.36887 .52447 m .39304 .51695 L .40747 .53078 L p .66 .747 .915 r
F P
0 g
s
.39304 .51695 m .40747 .53078 L .40667 .55428 L p .946 .686 .511 r
F P
0 g
s
.47218 .63454 m .45828 .62157 L .45873 .59757 L p .949 .687 .505 r
F P
0 g
s
.47218 .63454 m .45828 .62157 L .45873 .59757 L p .949 .687 .505 r
F P
0 g
s
.49673 .62754 m .47218 .63454 L .45828 .62157 L p .654 .754 .923 r
F P
0 g
s
.43381 .62862 m .45828 .62157 L .47218 .63454 L p .654 .754 .923 r
F P
0 g
s
.39604 .59867 m .38149 .58539 L .38247 .56162 L p .943 .686 .517 r
F P
0 g
s
.42026 .5915 m .39604 .59867 L .38149 .58539 L p .656 .751 .92 r
F P
0 g
s
.49465 .52216 m .51942 .51462 L .53283 .52849 L p .66 .747 .915 r
F P
0 g
s
.51942 .51462 m .53283 .52849 L .53289 .552 L p .957 .688 .485 r
F P
0 g
s
.48296 .61445 m .48325 .59039 L .45873 .59757 L p .566 .356 .555 r
F P
0 g
s
.45873 .59757 m .45828 .62157 L .48296 .61445 L p .566 .356 .555 r
F P
0 g
s
.45873 .59757 m .4447 .58427 L .44524 .56049 L p .949 .687 .505 r
F P
0 g
s
.45873 .59757 m .4447 .58427 L .44524 .56049 L p .949 .687 .505 r
F P
0 g
s
.48325 .59039 m .45873 .59757 L .4447 .58427 L p .656 .751 .92 r
F P
0 g
s
.48296 .61445 m .48325 .59039 L .45873 .59757 L p .566 .356 .555 r
F P
0 g
s
.45873 .59757 m .45828 .62157 L .48296 .61445 L p .566 .356 .555 r
F P
0 g
s
.42026 .5915 m .4447 .58427 L .45873 .59757 L p .656 .751 .92 r
F P
0 g
s
.42026 .5915 m .4447 .58427 L .45873 .59757 L p .656 .751 .92 r
F P
0 g
s
.4447 .58427 m .45873 .59757 L .45828 .62157 L p .949 .687 .505 r
F P
0 g
s
.48325 .59039 m .45873 .59757 L .4447 .58427 L p .656 .751 .92 r
F P
0 g
s
.4447 .58427 m .45873 .59757 L .45828 .62157 L p .949 .687 .505 r
F P
0 g
s
.62078 .51985 m .59565 .52734 L .58274 .51346 L p .66 .747 .915 r
F P
0 g
s
.62145 .54343 m .62078 .51985 L .59565 .52734 L p .569 .36 .558 r
F P
0 g
s
.59565 .52734 m .59613 .55087 L .62145 .54343 L p .569 .36 .558 r
F P
0 g
s
.58274 .51346 m .59565 .52734 L .59613 .55087 L p .962 .688 .469 r
F P
0 g
s
.48325 .59039 m .50799 .58315 L .52151 .59647 L p .656 .751 .92 r
F P
0 g
s
.52151 .59647 m .50799 .58315 L .5081 .55937 L p .954 .688 .492 r
F P
0 g
s
.40585 .5781 m .40667 .55428 L .38247 .56162 L p .561 .349 .55 r
F P
0 g
s
.38247 .56162 m .38149 .58539 L .40585 .5781 L p .561 .349 .55 r
F P
0 g
s
.38247 .56162 m .3678 .54801 L .36887 .52447 L p .943 .686 .517 r
F P
0 g
s
.38247 .56162 m .3678 .54801 L .36887 .52447 L p .943 .686 .517 r
F P
0 g
s
.40667 .55428 m .38247 .56162 L .3678 .54801 L p .658 .749 .917 r
F P
0 g
s
.34368 .55541 m .3678 .54801 L .38247 .56162 L p .658 .749 .917 r
F P
0 g
s
.46936 .57698 m .46974 .55314 L .44524 .56049 L p .564 .353 .553 r
F P
0 g
s
.44524 .56049 m .4447 .58427 L .46936 .57698 L p .564 .353 .553 r
F P
0 g
s
.44524 .56049 m .43108 .54687 L .43172 .52331 L p .949 .687 .505 r
F P
0 g
s
.46974 .55314 m .44524 .56049 L .43108 .54687 L p .658 .749 .917 r
F P
0 g
s
.46936 .57698 m .46974 .55314 L .44524 .56049 L p .564 .353 .553 r
F P
0 g
s
.44524 .56049 m .4447 .58427 L .46936 .57698 L p .564 .353 .553 r
F P
0 g
s
.40667 .55428 m .43108 .54687 L .44524 .56049 L p .658 .749 .917 r
F P
0 g
s
.40667 .55428 m .43108 .54687 L .44524 .56049 L p .658 .749 .917 r
F P
0 g
s
.43108 .54687 m .44524 .56049 L .4447 .58427 L p .949 .687 .505 r
F P
0 g
s
.43108 .54687 m .44524 .56049 L .4447 .58427 L p .949 .687 .505 r
F P
0 g
s
.5081 .55937 m .49445 .54572 L .49465 .52216 L p .954 .688 .492 r
F P
0 g
s
.53289 .552 m .5081 .55937 L .49445 .54572 L p .658 .749 .917 r
F P
0 g
s
.46974 .55314 m .49445 .54572 L .5081 .55937 L p .658 .749 .917 r
F P
0 g
s
.49445 .54572 m .5081 .55937 L .50799 .58315 L p .954 .688 .492 r
F P
0 g
s
.39213 .54055 m .39304 .51695 L .36887 .52447 L p .558 .345 .547 r
F P
0 g
s
.36887 .52447 m .3678 .54801 L .39213 .54055 L p .558 .345 .547 r
F P
0 g
s
.43381 .62862 m .41954 .61555 L .42026 .5915 L p .946 .686 .511 r
F P
0 g
s
.45828 .62157 m .43381 .62862 L .41954 .61555 L p .654 .754 .923 r
F P
0 g
s
.45618 .51579 m .43172 .52331 L .41742 .50936 L p .66 .747 .915 r
F P
0 g
s
.45571 .5394 m .45618 .51579 L .43172 .52331 L p .561 .349 .55 r
F P
0 g
s
.43172 .52331 m .43108 .54687 L .45571 .5394 L p .561 .349 .55 r
F P
0 g
s
.41742 .50936 m .43172 .52331 L .43108 .54687 L p .949 .687 .505 r
F P
0 g
s
.45828 .62157 m .48296 .61445 L .49673 .62754 L p .654 .754 .923 r
F P
0 g
s
.49673 .62754 m .48296 .61445 L .48325 .59039 L p .952 .687 .499 r
F P
0 g
s
.51938 .53824 m .51942 .51462 L .49465 .52216 L p .564 .353 .553 r
F P
0 g
s
.49465 .52216 m .49445 .54572 L .51938 .53824 L p .564 .353 .553 r
F P
0 g
s
.44414 .60838 m .4447 .58427 L .42026 .5915 L p .564 .353 .553 r
F P
0 g
s
.42026 .5915 m .41954 .61555 L .44414 .60838 L p .564 .353 .553 r
F P
0 g
s
.42026 .5915 m .40585 .5781 L .40667 .55428 L p .946 .686 .511 r
F P
0 g
s
.42026 .5915 m .40585 .5781 L .40667 .55428 L p .946 .686 .511 r
F P
0 g
s
.4447 .58427 m .42026 .5915 L .40585 .5781 L p .656 .751 .92 r
F P
0 g
s
.38149 .58539 m .40585 .5781 L .42026 .5915 L p .656 .751 .92 r
F P
0 g
s
.48325 .59039 m .46936 .57698 L .46974 .55314 L p .952 .687 .499 r
F P
0 g
s
.48325 .59039 m .46936 .57698 L .46974 .55314 L p .952 .687 .499 r
F P
0 g
s
.50799 .58315 m .48325 .59039 L .46936 .57698 L p .656 .751 .92 r
F P
0 g
s
.50787 .60727 m .50799 .58315 L .48325 .59039 L p .566 .356 .555 r
F P
0 g
s
.48325 .59039 m .48296 .61445 L .50787 .60727 L p .566 .356 .555 r
F P
0 g
s
.4447 .58427 m .46936 .57698 L .48325 .59039 L p .656 .751 .92 r
F P
0 g
s
.4447 .58427 m .46936 .57698 L .48325 .59039 L p .656 .751 .92 r
F P
0 g
s
.46936 .57698 m .48325 .59039 L .48296 .61445 L p .952 .687 .499 r
F P
0 g
s
.50799 .58315 m .48325 .59039 L .46936 .57698 L p .656 .751 .92 r
F P
0 g
s
.46936 .57698 m .48325 .59039 L .48296 .61445 L p .952 .687 .499 r
F P
0 g
s
.64615 .51229 m .62078 .51985 L .60803 .50584 L p .66 .747 .915 r
F P
0 g
s
.64699 .53592 m .64615 .51229 L .62078 .51985 L p .569 .36 .558 r
F P
0 g
s
.62078 .51985 m .62145 .54343 L .64699 .53592 L p .569 .36 .558 r
F P
0 g
s
.58274 .51346 m .60803 .50584 L .62078 .51985 L p .66 .747 .915 r
F P
0 g
s
.60803 .50584 m .62078 .51985 L .62145 .54343 L p .964 .688 .461 r
F P
0 g
s
.60803 .50584 m .62078 .51985 L .62145 .54343 L p .964 .688 .461 r
F P
0 g
s
.43043 .57075 m .43108 .54687 L .40667 .55428 L p .561 .349 .55 r
F P
0 g
s
.40667 .55428 m .40585 .5781 L .43043 .57075 L p .561 .349 .55 r
F P
0 g
s
.3678 .54801 m .39213 .54055 L .40667 .55428 L p .658 .749 .917 r
F P
0 g
s
.40667 .55428 m .39213 .54055 L .39304 .51695 L p .946 .686 .511 r
F P
0 g
s
.49424 .56961 m .49445 .54572 L .46974 .55314 L p .564 .353 .553 r
F P
0 g
s
.46974 .55314 m .46936 .57698 L .49424 .56961 L p .564 .353 .553 r
F P
0 g
s
.49445 .54572 m .46974 .55314 L .45571 .5394 L p .658 .749 .917 r
F P
0 g
s
.49424 .56961 m .49445 .54572 L .46974 .55314 L p .564 .353 .553 r
F P
0 g
s
.46974 .55314 m .46936 .57698 L .49424 .56961 L p .564 .353 .553 r
F P
0 g
s
.43108 .54687 m .45571 .5394 L .46974 .55314 L p .658 .749 .917 r
F P
0 g
s
.45571 .5394 m .46974 .55314 L .46936 .57698 L p .952 .687 .499 r
F P
0 g
s
.45571 .5394 m .46974 .55314 L .46936 .57698 L p .952 .687 .499 r
F P
0 g
s
.49445 .54572 m .51938 .53824 L .53289 .552 L p .658 .749 .917 r
F P
0 g
s
.53289 .552 m .51938 .53824 L .51942 .51462 L p .957 .688 .485 r
F P
0 g
s
.45828 .62157 m .44414 .60838 L .4447 .58427 L p .949 .687 .505 r
F P
0 g
s
.45828 .62157 m .44414 .60838 L .4447 .58427 L p .949 .687 .505 r
F P
0 g
s
.48296 .61445 m .45828 .62157 L .44414 .60838 L p .654 .754 .923 r
F P
0 g
s
.48267 .63885 m .48296 .61445 L .45828 .62157 L p .566 .356 .555 r
F P
0 g
s
.45828 .62157 m .45782 .6459 L .48267 .63885 L p .566 .356 .555 r
F P
0 g
s
.41954 .61555 m .44414 .60838 L .45828 .62157 L p .654 .754 .923 r
F P
0 g
s
.44414 .60838 m .45828 .62157 L .45782 .6459 L p .949 .687 .505 r
F P
0 g
s
.48296 .61445 m .45828 .62157 L .44414 .60838 L p .654 .754 .923 r
F P
0 g
s
.59613 .55087 m .58314 .53708 L .58274 .51346 L p .962 .688 .469 r
F P
0 g
s
.62145 .54343 m .59613 .55087 L .58314 .53708 L p .658 .749 .917 r
F P
0 g
s
.41742 .50936 m .44202 .50171 L .45618 .51579 L p .66 .747 .915 r
F P
0 g
s
.44202 .50171 m .45618 .51579 L .45571 .5394 L p .952 .687 .499 r
F P
0 g
s
.5444 .50702 m .51942 .51462 L .50577 .50053 L p .66 .747 .915 r
F P
0 g
s
.54454 .53069 m .5444 .50702 L .51942 .51462 L p .564 .353 .553 r
F P
0 g
s
.51942 .51462 m .51938 .53824 L .54454 .53069 L p .564 .353 .553 r
F P
0 g
s
.50577 .50053 m .51942 .51462 L .51938 .53824 L p .957 .688 .485 r
F P
0 g
s
.46897 .60114 m .46936 .57698 L .4447 .58427 L p .564 .353 .553 r
F P
0 g
s
.4447 .58427 m .44414 .60838 L .46897 .60114 L p .564 .353 .553 r
F P
0 g
s
.4447 .58427 m .43043 .57075 L .43108 .54687 L p .949 .687 .505 r
F P
0 g
s
.4447 .58427 m .43043 .57075 L .43108 .54687 L p .949 .687 .505 r
F P
0 g
s
.46936 .57698 m .4447 .58427 L .43043 .57075 L p .656 .751 .92 r
F P
0 g
s
.46897 .60114 m .46936 .57698 L .4447 .58427 L p .564 .353 .553 r
F P
0 g
s
.4447 .58427 m .44414 .60838 L .46897 .60114 L p .564 .353 .553 r
F P
0 g
s
.40585 .5781 m .43043 .57075 L .4447 .58427 L p .656 .751 .92 r
F P
0 g
s
.43043 .57075 m .4447 .58427 L .44414 .60838 L p .949 .687 .505 r
F P
0 g
s
.46936 .57698 m .4447 .58427 L .43043 .57075 L p .656 .751 .92 r
F P
0 g
s
.60861 .52952 m .60803 .50584 L .58274 .51346 L p .566 .356 .555 r
F P
0 g
s
.58274 .51346 m .58314 .53708 L .60861 .52952 L p .566 .356 .555 r
F P
0 g
s
.60803 .50584 m .58274 .51346 L .56961 .49934 L p .66 .747 .915 r
F P
0 g
s
.60861 .52952 m .60803 .50584 L .58274 .51346 L p .566 .356 .555 r
F P
0 g
s
.58274 .51346 m .58314 .53708 L .60861 .52952 L p .566 .356 .555 r
F P
0 g
s
.56961 .49934 m .58274 .51346 L .58314 .53708 L p .962 .688 .469 r
F P
0 g
s
.50799 .58315 m .49424 .56961 L .49445 .54572 L p .954 .688 .492 r
F P
0 g
s
.53295 .57585 m .50799 .58315 L .49424 .56961 L p .656 .751 .92 r
F P
0 g
s
.53301 .60002 m .53295 .57585 L .50799 .58315 L p .566 .356 .555 r
F P
0 g
s
.50799 .58315 m .50787 .60727 L .53301 .60002 L p .566 .356 .555 r
F P
0 g
s
.46936 .57698 m .49424 .56961 L .50799 .58315 L p .656 .751 .92 r
F P
0 g
s
.46936 .57698 m .49424 .56961 L .50799 .58315 L p .656 .751 .92 r
F P
0 g
s
.49424 .56961 m .50799 .58315 L .50787 .60727 L p .954 .688 .492 r
F P
0 g
s
.49424 .56961 m .50799 .58315 L .50787 .60727 L p .954 .688 .492 r
F P
0 g
s
.60803 .50584 m .63354 .49816 L .64615 .51229 L p .66 .747 .915 r
F P
0 g
s
.63354 .49816 m .64615 .51229 L .64699 .53592 L p .966 .687 .452 r
F P
0 g
s
.45523 .56333 m .45571 .5394 L .43108 .54687 L p .561 .349 .55 r
F P
0 g
s
.43108 .54687 m .43043 .57075 L .45523 .56333 L p .561 .349 .55 r
F P
0 g
s
.43108 .54687 m .41667 .53302 L .41742 .50936 L p .949 .687 .505 r
F P
0 g
s
.45571 .5394 m .43108 .54687 L .41667 .53302 L p .658 .749 .917 r
F P
0 g
s
.51938 .53824 m .49445 .54572 L .48056 .53185 L p .658 .749 .917 r
F P
0 g
s
.51934 .56219 m .51938 .53824 L .49445 .54572 L p .564 .353 .553 r
F P
0 g
s
.49445 .54572 m .49424 .56961 L .51934 .56219 L p .564 .353 .553 r
F P
0 g
s
.45571 .5394 m .48056 .53185 L .49445 .54572 L p .658 .749 .917 r
F P
0 g
s
.48056 .53185 m .49445 .54572 L .49424 .56961 L p .954 .688 .492 r
F P
0 g
s
.48056 .53185 m .49445 .54572 L .49424 .56961 L p .954 .688 .492 r
F P
0 g
s
.44145 .52542 m .44202 .50171 L .41742 .50936 L p .558 .345 .547 r
F P
0 g
s
.41742 .50936 m .41667 .53302 L .44145 .52542 L p .558 .345 .547 r
F P
0 g
s
.48296 .61445 m .46897 .60114 L .46936 .57698 L p .952 .687 .499 r
F P
0 g
s
.48296 .61445 m .46897 .60114 L .46936 .57698 L p .952 .687 .499 r
F P
0 g
s
.50787 .60727 m .48296 .61445 L .46897 .60114 L p .654 .754 .923 r
F P
0 g
s
.50776 .63172 m .50787 .60727 L .48296 .61445 L p .566 .356 .555 r
F P
0 g
s
.48296 .61445 m .48267 .63885 L .50776 .63172 L p .566 .356 .555 r
F P
0 g
s
.44414 .60838 m .46897 .60114 L .48296 .61445 L p .654 .754 .923 r
F P
0 g
s
.44414 .60838 m .46897 .60114 L .48296 .61445 L p .654 .754 .923 r
F P
0 g
s
.46897 .60114 m .48296 .61445 L .48267 .63885 L p .952 .687 .499 r
F P
0 g
s
.50787 .60727 m .48296 .61445 L .46897 .60114 L p .654 .754 .923 r
F P
0 g
s
.46897 .60114 m .48296 .61445 L .48267 .63885 L p .952 .687 .499 r
F P
0 g
s
.62145 .54343 m .60861 .52952 L .60803 .50584 L p .964 .688 .461 r
F P
0 g
s
.62145 .54343 m .60861 .52952 L .60803 .50584 L p .964 .688 .461 r
F P
0 g
s
.64699 .53592 m .62145 .54343 L .60861 .52952 L p .658 .749 .917 r
F P
0 g
s
.58314 .53708 m .60861 .52952 L .62145 .54343 L p .658 .749 .917 r
F P
0 g
s
.50577 .50053 m .48087 .50819 L .46685 .49399 L p .66 .747 .915 r
F P
0 g
s
.50564 .52424 m .50577 .50053 L .48087 .50819 L p .561 .349 .55 r
F P
0 g
s
.48087 .50819 m .48056 .53185 L .50564 .52424 L p .561 .349 .55 r
F P
0 g
s
.46685 .49399 m .48087 .50819 L .48056 .53185 L p .954 .688 .492 r
F P
0 g
s
.56961 .49934 m .5444 .50702 L .53091 .49279 L p .66 .747 .915 r
F P
0 g
s
.56993 .52307 m .56961 .49934 L .5444 .50702 L p .564 .353 .553 r
F P
0 g
s
.5444 .50702 m .54454 .53069 L .56993 .52307 L p .564 .353 .553 r
F P
0 g
s
.50577 .50053 m .53091 .49279 L .5444 .50702 L p .66 .747 .915 r
F P
0 g
s
.53091 .49279 m .5444 .50702 L .54454 .53069 L p .959 .688 .477 r
F P
0 g
s
.53091 .49279 m .5444 .50702 L .54454 .53069 L p .959 .688 .477 r
F P
0 g
s
.49402 .59384 m .49424 .56961 L .46936 .57698 L p .564 .353 .553 r
F P
0 g
s
.46936 .57698 m .46897 .60114 L .49402 .59384 L p .564 .353 .553 r
F P
0 g
s
.46936 .57698 m .45523 .56333 L .45571 .5394 L p .952 .687 .499 r
F P
0 g
s
.46936 .57698 m .45523 .56333 L .45571 .5394 L p .952 .687 .499 r
F P
0 g
s
.49424 .56961 m .46936 .57698 L .45523 .56333 L p .656 .751 .92 r
F P
0 g
s
.43043 .57075 m .45523 .56333 L .46936 .57698 L p .656 .751 .92 r
F P
0 g
s
.43043 .57075 m .45523 .56333 L .46936 .57698 L p .656 .751 .92 r
F P
0 g
s
.45523 .56333 m .46936 .57698 L .46897 .60114 L p .952 .687 .499 r
F P
0 g
s
.6343 .52189 m .63354 .49816 L .60803 .50584 L p .566 .356 .555 r
F P
0 g
s
.60803 .50584 m .60861 .52952 L .6343 .52189 L p .566 .356 .555 r
F P
0 g
s
.63354 .49816 m .60803 .50584 L .59505 .4916 L p .66 .747 .915 r
F P
0 g
s
.6343 .52189 m .63354 .49816 L .60803 .50584 L p .566 .356 .555 r
F P
0 g
s
.60803 .50584 m .60861 .52952 L .6343 .52189 L p .566 .356 .555 r
F P
0 g
s
.56961 .49934 m .59505 .4916 L .60803 .50584 L p .66 .747 .915 r
F P
0 g
s
.59505 .4916 m .60803 .50584 L .60861 .52952 L p .964 .688 .461 r
F P
0 g
s
.59505 .4916 m .60803 .50584 L .60861 .52952 L p .964 .688 .461 r
F P
0 g
s
.55813 .56848 m .53295 .57585 L .51934 .56219 L p .656 .751 .92 r
F P
0 g
s
.55837 .59271 m .55813 .56848 L .53295 .57585 L p .566 .356 .555 r
F P
0 g
s
.53295 .57585 m .53301 .60002 L .55837 .59271 L p .566 .356 .555 r
F P
0 g
s
.49424 .56961 m .51934 .56219 L .53295 .57585 L p .656 .751 .92 r
F P
0 g
s
.51934 .56219 m .53295 .57585 L .53301 .60002 L p .957 .688 .485 r
F P
0 g
s
.51934 .56219 m .53295 .57585 L .53301 .60002 L p .957 .688 .485 r
F P
0 g
s
.45782 .6459 m .44358 .63282 L .44414 .60838 L p .949 .687 .505 r
F P
0 g
s
.48267 .63885 m .45782 .6459 L .44358 .63282 L p .652 .756 .926 r
F P
0 g
s
.69756 .49697 m .67174 .50466 L .65929 .4904 L p .66 .747 .915 r
F P
0 g
s
.69877 .52071 m .69756 .49697 L .67174 .50466 L p .569 .36 .558 r
F P
0 g
s
.67174 .50466 m .67276 .52835 L .69877 .52071 L p .569 .36 .558 r
F P
0 g
s
.65929 .4904 m .67174 .50466 L .67276 .52835 L p .969 .687 .442 r
F P
0 g
s
.48025 .55585 m .48056 .53185 L .45571 .5394 L p .561 .349 .55 r
F P
0 g
s
.45571 .5394 m .45523 .56333 L .48025 .55585 L p .561 .349 .55 r
F P
0 g
s
.45571 .5394 m .44145 .52542 L .44202 .50171 L p .952 .687 .499 r
F P
0 g
s
.48056 .53185 m .45571 .5394 L .44145 .52542 L p .658 .749 .917 r
F P
0 g
s
.48025 .55585 m .48056 .53185 L .45571 .5394 L p .561 .349 .55 r
F P
0 g
s
.45571 .5394 m .45523 .56333 L .48025 .55585 L p .561 .349 .55 r
F P
0 g
s
.41667 .53302 m .44145 .52542 L .45571 .5394 L p .658 .749 .917 r
F P
0 g
s
.44145 .52542 m .45571 .5394 L .45523 .56333 L p .952 .687 .499 r
F P
0 g
s
.51938 .53824 m .50564 .52424 L .50577 .50053 L p .957 .688 .485 r
F P
0 g
s
.54454 .53069 m .51938 .53824 L .50564 .52424 L p .658 .749 .917 r
F P
0 g
s
.54468 .55469 m .54454 .53069 L .51938 .53824 L p .564 .353 .553 r
F P
0 g
s
.51938 .53824 m .51934 .56219 L .54468 .55469 L p .564 .353 .553 r
F P
0 g
s
.48056 .53185 m .50564 .52424 L .51938 .53824 L p .658 .749 .917 r
F P
0 g
s
.50564 .52424 m .51938 .53824 L .51934 .56219 L p .957 .688 .485 r
F P
0 g
s
.54454 .53069 m .51938 .53824 L .50564 .52424 L p .658 .749 .917 r
F P
0 g
s
.50564 .52424 m .51938 .53824 L .51934 .56219 L p .957 .688 .485 r
F P
0 g
s
.82586 .49459 m .79942 .5023 L .78803 .488 L p .66 .747 .915 r
F P
0 g
s
.82797 .51834 m .82586 .49459 L .79942 .5023 L p .573 .367 .563 r
F P
0 g
s
.79942 .5023 m .80134 .52601 L .82797 .51834 L p .573 .367 .563 r
F P
0 g
s
.78803 .488 m .79942 .5023 L .80134 .52601 L p .975 .682 .398 r
F P
0 g
s
.46858 .62565 m .46897 .60114 L .44414 .60838 L p .564 .353 .553 r
F P
0 g
s
.44414 .60838 m .44358 .63282 L .46858 .62565 L p .564 .353 .553 r
F P
0 g
s
.44414 .60838 m .42977 .59497 L .43043 .57075 L p .949 .687 .505 r
F P
0 g
s
.46897 .60114 m .44414 .60838 L .42977 .59497 L p .654 .754 .923 r
F P
0 g
s
.46858 .62565 m .46897 .60114 L .44414 .60838 L p .564 .353 .553 r
F P
0 g
s
.44414 .60838 m .44358 .63282 L .46858 .62565 L p .564 .353 .553 r
F P
0 g
s
.42977 .59497 m .44414 .60838 L .44358 .63282 L p .949 .687 .505 r
F P
0 g
s
.46897 .60114 m .44414 .60838 L .42977 .59497 L p .654 .754 .923 r
F P
0 g
s
.58314 .53708 m .56993 .52307 L .56961 .49934 L p .962 .688 .469 r
F P
0 g
s
.60861 .52952 m .58314 .53708 L .56993 .52307 L p .658 .749 .917 r
F P
0 g
s
.46685 .49399 m .44202 .50171 L .42763 .4874 L p .66 .747 .915 r
F P
0 g
s
.46645 .51775 m .46685 .49399 L .44202 .50171 L p .558 .345 .547 r
F P
0 g
s
.44202 .50171 m .44145 .52542 L .46645 .51775 L p .558 .345 .547 r
F P
0 g
s
.42763 .4874 m .44202 .50171 L .44145 .52542 L p .952 .687 .499 r
F P
0 g
s
.50787 .60727 m .49402 .59384 L .49424 .56961 L p .954 .688 .492 r
F P
0 g
s
.50787 .60727 m .49402 .59384 L .49424 .56961 L p .954 .688 .492 r
F P
0 g
s
.53301 .60002 m .50787 .60727 L .49402 .59384 L p .654 .754 .923 r
F P
0 g
s
.53307 .62454 m .53301 .60002 L .50787 .60727 L p .566 .356 .555 r
F P
0 g
s
.50787 .60727 m .50776 .63172 L .53307 .62454 L p .566 .356 .555 r
F P
0 g
s
.46897 .60114 m .49402 .59384 L .50787 .60727 L p .654 .754 .923 r
F P
0 g
s
.46897 .60114 m .49402 .59384 L .50787 .60727 L p .654 .754 .923 r
F P
0 g
s
.49402 .59384 m .50787 .60727 L .50776 .63172 L p .954 .688 .492 r
F P
0 g
s
.53301 .60002 m .50787 .60727 L .49402 .59384 L p .654 .754 .923 r
F P
0 g
s
.49402 .59384 m .50787 .60727 L .50776 .63172 L p .954 .688 .492 r
F P
0 g
s
.60861 .52952 m .6343 .52189 L .64699 .53592 L p .658 .749 .917 r
F P
0 g
s
.64699 .53592 m .6343 .52189 L .63354 .49816 L p .966 .687 .452 r
F P
0 g
s
.53095 .51657 m .53091 .49279 L .50577 .50053 L p .561 .349 .55 r
F P
0 g
s
.50577 .50053 m .50564 .52424 L .53095 .51657 L p .561 .349 .55 r
F P
0 g
s
.46685 .49399 m .4919 .4862 L .50577 .50053 L p .66 .747 .915 r
F P
0 g
s
.4919 .4862 m .50577 .50053 L .50564 .52424 L p .957 .688 .485 r
F P
0 g
s
.45474 .58761 m .45523 .56333 L .43043 .57075 L p .561 .349 .55 r
F P
0 g
s
.43043 .57075 m .42977 .59497 L .45474 .58761 L p .561 .349 .55 r
F P
0 g
s
.45523 .56333 m .43043 .57075 L .41592 .557 L p .656 .751 .92 r
F P
0 g
s
.45474 .58761 m .45523 .56333 L .43043 .57075 L p .561 .349 .55 r
F P
0 g
s
.43043 .57075 m .42977 .59497 L .45474 .58761 L p .561 .349 .55 r
F P
0 g
s
.41592 .557 m .43043 .57075 L .42977 .59497 L p .949 .687 .505 r
F P
0 g
s
.59555 .51538 m .59505 .4916 L .56961 .49934 L p .564 .353 .553 r
F P
0 g
s
.56961 .49934 m .56993 .52307 L .59555 .51538 L p .564 .353 .553 r
F P
0 g
s
.53091 .49279 m .55627 .48499 L .56961 .49934 L p .66 .747 .915 r
F P
0 g
s
.55627 .48499 m .56961 .49934 L .56993 .52307 L p .962 .688 .469 r
F P
0 g
s
.51931 .58647 m .51934 .56219 L .49424 .56961 L p .564 .353 .553 r
F P
0 g
s
.49424 .56961 m .49402 .59384 L .51931 .58647 L p .564 .353 .553 r
F P
0 g
s
.49424 .56961 m .48025 .55585 L .48056 .53185 L p .954 .688 .492 r
F P
0 g
s
.49424 .56961 m .48025 .55585 L .48056 .53185 L p .954 .688 .492 r
F P
0 g
s
.51934 .56219 m .49424 .56961 L .48025 .55585 L p .656 .751 .92 r
F P
0 g
s
.45523 .56333 m .48025 .55585 L .49424 .56961 L p .656 .751 .92 r
F P
0 g
s
.65929 .4904 m .63354 .49816 L .62073 .48378 L p .66 .747 .915 r
F P
0 g
s
.66024 .51419 m .65929 .4904 L .63354 .49816 L p .566 .356 .555 r
F P
0 g
s
.63354 .49816 m .6343 .52189 L .66024 .51419 L p .566 .356 .555 r
F P
0 g
s
.59505 .4916 m .62073 .48378 L .63354 .49816 L p .66 .747 .915 r
F P
0 g
s
.62073 .48378 m .63354 .49816 L .6343 .52189 L p .966 .687 .452 r
F P
0 g
s
.62073 .48378 m .63354 .49816 L .6343 .52189 L p .966 .687 .452 r
F P
0 g
s
.58355 .56104 m .55813 .56848 L .54468 .55469 L p .656 .751 .92 r
F P
0 g
s
.58396 .58533 m .58355 .56104 L .55813 .56848 L p .566 .356 .555 r
F P
0 g
s
.55813 .56848 m .55837 .59271 L .58396 .58533 L p .566 .356 .555 r
F P
0 g
s
.51934 .56219 m .54468 .55469 L .55813 .56848 L p .656 .751 .92 r
F P
0 g
s
.54468 .55469 m .55813 .56848 L .55837 .59271 L p .959 .688 .477 r
F P
0 g
s
.54468 .55469 m .55813 .56848 L .55837 .59271 L p .959 .688 .477 r
F P
0 g
s
.72362 .4892 m .69756 .49697 L .68527 .48258 L p .66 .747 .915 r
F P
0 g
s
.72502 .513 m .72362 .4892 L .69756 .49697 L p .569 .36 .558 r
F P
0 g
s
.69756 .49697 m .69877 .52071 L .72502 .513 L p .569 .36 .558 r
F P
0 g
s
.65929 .4904 m .68527 .48258 L .69756 .49697 L p .66 .747 .915 r
F P
0 g
s
.68527 .48258 m .69756 .49697 L .69877 .52071 L p .971 .686 .432 r
F P
0 g
s
.68527 .48258 m .69756 .49697 L .69877 .52071 L p .971 .686 .432 r
F P
0 g
s
.48267 .63885 m .46858 .62565 L .46897 .60114 L p .952 .687 .499 r
F P
0 g
s
.48267 .63885 m .46858 .62565 L .46897 .60114 L p .952 .687 .499 r
F P
0 g
s
.50776 .63172 m .48267 .63885 L .46858 .62565 L p .652 .756 .926 r
F P
0 g
s
.44358 .63282 m .46858 .62565 L .48267 .63885 L p .652 .756 .926 r
F P
0 g
s
.50551 .54829 m .50564 .52424 L .48056 .53185 L p .561 .349 .55 r
F P
0 g
s
.48056 .53185 m .48025 .55585 L .50551 .54829 L p .561 .349 .55 r
F P
0 g
s
.48056 .53185 m .46645 .51775 L .46685 .49399 L p .954 .688 .492 r
F P
0 g
s
.50564 .52424 m .48056 .53185 L .46645 .51775 L p .658 .749 .917 r
F P
0 g
s
.50551 .54829 m .50564 .52424 L .48056 .53185 L p .561 .349 .55 r
F P
0 g
s
.48056 .53185 m .48025 .55585 L .50551 .54829 L p .561 .349 .55 r
F P
0 g
s
.44145 .52542 m .46645 .51775 L .48056 .53185 L p .658 .749 .917 r
F P
0 g
s
.46645 .51775 m .48056 .53185 L .48025 .55585 L p .954 .688 .492 r
F P
0 g
s
.50564 .52424 m .48056 .53185 L .46645 .51775 L p .658 .749 .917 r
F P
0 g
s
.46645 .51775 m .48056 .53185 L .48025 .55585 L p .954 .688 .492 r
F P
0 g
s
.54454 .53069 m .53095 .51657 L .53091 .49279 L p .959 .688 .477 r
F P
0 g
s
.54454 .53069 m .53095 .51657 L .53091 .49279 L p .959 .688 .477 r
F P
0 g
s
.56993 .52307 m .54454 .53069 L .53095 .51657 L p .658 .749 .917 r
F P
0 g
s
.57025 .54713 m .56993 .52307 L .54454 .53069 L p .564 .353 .553 r
F P
0 g
s
.54454 .53069 m .54468 .55469 L .57025 .54713 L p .564 .353 .553 r
F P
0 g
s
.50564 .52424 m .53095 .51657 L .54454 .53069 L p .658 .749 .917 r
F P
0 g
s
.50564 .52424 m .53095 .51657 L .54454 .53069 L p .658 .749 .917 r
F P
0 g
s
.53095 .51657 m .54454 .53069 L .54468 .55469 L p .959 .688 .477 r
F P
0 g
s
.56993 .52307 m .54454 .53069 L .53095 .51657 L p .658 .749 .917 r
F P
0 g
s
.53095 .51657 m .54454 .53069 L .54468 .55469 L p .959 .688 .477 r
F P
0 g
s
.85254 .4868 m .82586 .49459 L .81464 .48015 L p .66 .747 .915 r
F P
0 g
s
.85485 .51061 m .85254 .4868 L .82586 .49459 L p .573 .367 .563 r
F P
0 g
s
.82586 .49459 m .82797 .51834 L .85485 .51061 L p .573 .367 .563 r
F P
0 g
s
.78803 .488 m .81464 .48015 L .82586 .49459 L p .66 .747 .915 r
F P
0 g
s
.81464 .48015 m .82586 .49459 L .82797 .51834 L p .976 .68 .386 r
F P
0 g
s
.81464 .48015 m .82586 .49459 L .82797 .51834 L p .976 .68 .386 r
F P
0 g
s
.49381 .61841 m .49402 .59384 L .46897 .60114 L p .564 .353 .553 r
F P
0 g
s
.46897 .60114 m .46858 .62565 L .49381 .61841 L p .564 .353 .553 r
F P
0 g
s
.46897 .60114 m .45474 .58761 L .45523 .56333 L p .952 .687 .499 r
F P
0 g
s
.49402 .59384 m .46897 .60114 L .45474 .58761 L p .654 .754 .923 r
F P
0 g
s
.49381 .61841 m .49402 .59384 L .46897 .60114 L p .564 .353 .553 r
F P
0 g
s
.46897 .60114 m .46858 .62565 L .49381 .61841 L p .564 .353 .553 r
F P
0 g
s
.42977 .59497 m .45474 .58761 L .46897 .60114 L p .654 .754 .923 r
F P
0 g
s
.42977 .59497 m .45474 .58761 L .46897 .60114 L p .654 .754 .923 r
F P
0 g
s
.45474 .58761 m .46897 .60114 L .46858 .62565 L p .952 .687 .499 r
F P
0 g
s
.45474 .58761 m .46897 .60114 L .46858 .62565 L p .952 .687 .499 r
F P
0 g
s
.60861 .52952 m .59555 .51538 L .59505 .4916 L p .964 .688 .461 r
F P
0 g
s
.60861 .52952 m .59555 .51538 L .59505 .4916 L p .964 .688 .461 r
F P
0 g
s
.6343 .52189 m .60861 .52952 L .59555 .51538 L p .658 .749 .917 r
F P
0 g
s
.63508 .54596 m .6343 .52189 L .60861 .52952 L p .566 .356 .555 r
F P
0 g
s
.60861 .52952 m .6092 .55353 L .63508 .54596 L p .566 .356 .555 r
F P
0 g
s
.56993 .52307 m .59555 .51538 L .60861 .52952 L p .658 .749 .917 r
F P
0 g
s
.59555 .51538 m .60861 .52952 L .6092 .55353 L p .964 .688 .461 r
F P
0 g
s
.6343 .52189 m .60861 .52952 L .59555 .51538 L p .658 .749 .917 r
F P
0 g
s
.49167 .51001 m .4919 .4862 L .46685 .49399 L p .558 .345 .547 r
F P
0 g
s
.46685 .49399 m .46645 .51775 L .49167 .51001 L p .558 .345 .547 r
F P
0 g
s
.42763 .4874 m .4526 .47955 L .46685 .49399 L p .66 .747 .915 r
F P
0 g
s
.4526 .47955 m .46685 .49399 L .46645 .51775 L p .954 .688 .492 r
F P
0 g
s
.53301 .60002 m .51931 .58647 L .51934 .56219 L p .957 .688 .485 r
F P
0 g
s
.53301 .60002 m .51931 .58647 L .51934 .56219 L p .957 .688 .485 r
F P
0 g
s
.55837 .59271 m .53301 .60002 L .51931 .58647 L p .654 .754 .923 r
F P
0 g
s
.55861 .61729 m .55837 .59271 L .53301 .60002 L p .566 .356 .555 r
F P
0 g
s
.53301 .60002 m .53307 .62454 L .55861 .61729 L p .566 .356 .555 r
F P
0 g
s
.49402 .59384 m .51931 .58647 L .53301 .60002 L p .654 .754 .923 r
F P
0 g
s
.49402 .59384 m .51931 .58647 L .53301 .60002 L p .654 .754 .923 r
F P
0 g
s
.51931 .58647 m .53301 .60002 L .53307 .62454 L p .957 .688 .485 r
F P
0 g
s
.55837 .59271 m .53301 .60002 L .51931 .58647 L p .654 .754 .923 r
F P
0 g
s
.51931 .58647 m .53301 .60002 L .53307 .62454 L p .957 .688 .485 r
F P
0 g
s
.67276 .52835 m .66024 .51419 L .65929 .4904 L p .969 .687 .442 r
F P
0 g
s
.69877 .52071 m .67276 .52835 L .66024 .51419 L p .658 .749 .917 r
F P
0 g
s
.55649 .50882 m .55627 .48499 L .53091 .49279 L p .561 .349 .55 r
F P
0 g
s
.53091 .49279 m .53095 .51657 L .55649 .50882 L p .561 .349 .55 r
F P
0 g
s
.45523 .56333 m .44086 .54946 L .44145 .52542 L p .952 .687 .499 r
F P
0 g
s
.48025 .55585 m .45523 .56333 L .44086 .54946 L p .656 .751 .92 r
F P
0 g
s
.41592 .557 m .44086 .54946 L .45523 .56333 L p .656 .751 .92 r
F P
0 g
s
.44086 .54946 m .45523 .56333 L .45474 .58761 L p .952 .687 .499 r
F P
0 g
s
.62141 .50762 m .62073 .48378 L .59505 .4916 L p .564 .353 .553 r
F P
0 g
s
.59505 .4916 m .59555 .51538 L .62141 .50762 L p .564 .353 .553 r
F P
0 g
s
.54482 .57903 m .54468 .55469 L .51934 .56219 L p .564 .353 .553 r
F P
0 g
s
.51934 .56219 m .51931 .58647 L .54482 .57903 L p .564 .353 .553 r
F P
0 g
s
.51934 .56219 m .50551 .54829 L .50564 .52424 L p .957 .688 .485 r
F P
0 g
s
.51934 .56219 m .50551 .54829 L .50564 .52424 L p .957 .688 .485 r
F P
0 g
s
.54468 .55469 m .51934 .56219 L .50551 .54829 L p .656 .751 .92 r
F P
0 g
s
.48025 .55585 m .50551 .54829 L .51934 .56219 L p .656 .751 .92 r
F P
0 g
s
.44358 .63282 m .4291 .61952 L .42977 .59497 L p .949 .687 .505 r
F P
0 g
s
.46858 .62565 m .44358 .63282 L .4291 .61952 L p .652 .756 .926 r
F P
0 g
s
.80134 .52601 m .78989 .5118 L .78803 .488 L p .975 .682 .398 r
F P
0 g
s
.82797 .51834 m .80134 .52601 L .78989 .5118 L p .658 .749 .917 r
F P
0 g
s
.68641 .50642 m .68527 .48258 L .65929 .4904 L p .566 .356 .555 r
F P
0 g
s
.65929 .4904 m .66024 .51419 L .68641 .50642 L p .566 .356 .555 r
F P
0 g
s
.68527 .48258 m .65929 .4904 L .64663 .4759 L p .66 .747 .915 r
F P
0 g
s
.68641 .50642 m .68527 .48258 L .65929 .4904 L p .566 .356 .555 r
F P
0 g
s
.65929 .4904 m .66024 .51419 L .68641 .50642 L p .566 .356 .555 r
F P
0 g
s
.62073 .48378 m .64663 .4759 L .65929 .4904 L p .66 .747 .915 r
F P
0 g
s
.64663 .4759 m .65929 .4904 L .66024 .51419 L p .969 .687 .442 r
F P
0 g
s
.64663 .4759 m .65929 .4904 L .66024 .51419 L p .969 .687 .442 r
F P
0 g
s
.6092 .55353 m .58355 .56104 L .57025 .54713 L p .656 .751 .92 r
F P
0 g
s
.60979 .57788 m .6092 .55353 L .58355 .56104 L p .566 .356 .555 r
F P
0 g
s
.58355 .56104 m .58396 .58533 L .60979 .57788 L p .566 .356 .555 r
F P
0 g
s
.54468 .55469 m .57025 .54713 L .58355 .56104 L p .656 .751 .92 r
F P
0 g
s
.57025 .54713 m .58355 .56104 L .58396 .58533 L p .962 .688 .469 r
F P
0 g
s
.57025 .54713 m .58355 .56104 L .58396 .58533 L p .962 .688 .469 r
F P
0 g
s
.46603 .54185 m .46645 .51775 L .44145 .52542 L p .558 .345 .547 r
F P
0 g
s
.44145 .52542 m .44086 .54946 L .46603 .54185 L p .558 .345 .547 r
F P
0 g
s
.44145 .52542 m .42694 .51121 L .42763 .4874 L p .952 .687 .499 r
F P
0 g
s
.46645 .51775 m .44145 .52542 L .42694 .51121 L p .658 .749 .917 r
F P
0 g
s
.46603 .54185 m .46645 .51775 L .44145 .52542 L p .558 .345 .547 r
F P
0 g
s
.44145 .52542 m .44086 .54946 L .46603 .54185 L p .558 .345 .547 r
F P
0 g
s
.42694 .51121 m .44145 .52542 L .44086 .54946 L p .952 .687 .499 r
F P
0 g
s
.46645 .51775 m .44145 .52542 L .42694 .51121 L p .658 .749 .917 r
F P
0 g
s
.50776 .63172 m .49381 .61841 L .49402 .59384 L p .954 .688 .492 r
F P
0 g
s
.50776 .63172 m .49381 .61841 L .49402 .59384 L p .954 .688 .492 r
F P
0 g
s
.53307 .62454 m .50776 .63172 L .49381 .61841 L p .652 .756 .926 r
F P
0 g
s
.46858 .62565 m .49381 .61841 L .50776 .63172 L p .652 .756 .926 r
F P
0 g
s
.68527 .48258 m .71149 .47468 L .72362 .4892 L p .66 .747 .915 r
F P
0 g
s
.71149 .47468 m .72362 .4892 L .72502 .513 L p .972 .685 .422 r
F P
0 g
s
.531 .54067 m .53095 .51657 L .50564 .52424 L p .561 .349 .55 r
F P
0 g
s
.50564 .52424 m .50551 .54829 L .531 .54067 L p .561 .349 .55 r
F P
0 g
s
.50564 .52424 m .49167 .51001 L .4919 .4862 L p .957 .688 .485 r
F P
0 g
s
.53095 .51657 m .50564 .52424 L .49167 .51001 L p .658 .749 .917 r
F P
0 g
s
.531 .54067 m .53095 .51657 L .50564 .52424 L p .561 .349 .55 r
F P
0 g
s
.50564 .52424 m .50551 .54829 L .531 .54067 L p .561 .349 .55 r
F P
0 g
s
.46645 .51775 m .49167 .51001 L .50564 .52424 L p .658 .749 .917 r
F P
0 g
s
.46645 .51775 m .49167 .51001 L .50564 .52424 L p .658 .749 .917 r
F P
0 g
s
.49167 .51001 m .50564 .52424 L .50551 .54829 L p .957 .688 .485 r
F P
0 g
s
.49167 .51001 m .50564 .52424 L .50551 .54829 L p .957 .688 .485 r
F P
0 g
s
.3881 .48076 m .36344 .4886 L .34827 .47407 L p .66 .747 .915 r
F P
0 g
s
.38714 .50461 m .3881 .48076 L .36344 .4886 L p .553 .337 .541 r
F P
0 g
s
.36344 .4886 m .36231 .5124 L .38714 .50461 L p .553 .337 .541 r
F P
0 g
s
.34827 .47407 m .36344 .4886 L .36231 .5124 L p .946 .686 .511 r
F P
0 g
s
.81669 .50401 m .81464 .48015 L .78803 .488 L p .571 .363 .56 r
F P
0 g
s
.78803 .488 m .78989 .5118 L .81669 .50401 L p .571 .363 .56 r
F P
0 g
s
.81464 .48015 m .78803 .488 L .77645 .47346 L p .66 .747 .915 r
F P
0 g
s
.81669 .50401 m .81464 .48015 L .78803 .488 L p .571 .363 .56 r
F P
0 g
s
.78803 .488 m .78989 .5118 L .81669 .50401 L p .571 .363 .56 r
F P
0 g
s
.77645 .47346 m .78803 .488 L .78989 .5118 L p .975 .682 .398 r
F P
0 g
s
.45425 .61223 m .45474 .58761 L .42977 .59497 L p .561 .349 .55 r
F P
0 g
s
.42977 .59497 m .4291 .61952 L .45425 .61223 L p .561 .349 .55 r
F P
0 g
s
.42977 .59497 m .41515 .58133 L .41592 .557 L p .949 .687 .505 r
F P
0 g
s
.45474 .58761 m .42977 .59497 L .41515 .58133 L p .654 .754 .923 r
F P
0 g
s
.45425 .61223 m .45474 .58761 L .42977 .59497 L p .561 .349 .55 r
F P
0 g
s
.42977 .59497 m .4291 .61952 L .45425 .61223 L p .561 .349 .55 r
F P
0 g
s
.41515 .58133 m .42977 .59497 L .4291 .61952 L p .949 .687 .505 r
F P
0 g
s
.45474 .58761 m .42977 .59497 L .41515 .58133 L p .654 .754 .923 r
F P
0 g
s
.56993 .52307 m .55649 .50882 L .55627 .48499 L p .962 .688 .469 r
F P
0 g
s
.59555 .51538 m .56993 .52307 L .55649 .50882 L p .658 .749 .917 r
F P
0 g
s
.59605 .53949 m .59555 .51538 L .56993 .52307 L p .564 .353 .553 r
F P
0 g
s
.56993 .52307 m .57025 .54713 L .59605 .53949 L p .564 .353 .553 r
F P
0 g
s
.53095 .51657 m .55649 .50882 L .56993 .52307 L p .658 .749 .917 r
F P
0 g
s
.53095 .51657 m .55649 .50882 L .56993 .52307 L p .658 .749 .917 r
F P
0 g
s
.55649 .50882 m .56993 .52307 L .57025 .54713 L p .962 .688 .469 r
F P
0 g
s
.55649 .50882 m .56993 .52307 L .57025 .54713 L p .962 .688 .469 r
F P
0 g
s
.45209 .50341 m .4526 .47955 L .42763 .4874 L p .556 .341 .544 r
F P
0 g
s
.42763 .4874 m .42694 .51121 L .45209 .50341 L p .556 .341 .544 r
F P
0 g
s
.4526 .47955 m .42763 .4874 L .41299 .47285 L p .66 .747 .915 r
F P
0 g
s
.45209 .50341 m .4526 .47955 L .42763 .4874 L p .556 .341 .544 r
F P
0 g
s
.42763 .4874 m .42694 .51121 L .45209 .50341 L p .556 .341 .544 r
F P
0 g
s
.41299 .47285 m .42763 .4874 L .42694 .51121 L p .952 .687 .499 r
F P
0 g
s
.51927 .6111 m .51931 .58647 L .49402 .59384 L p .564 .353 .553 r
F P
0 g
s
.49402 .59384 m .49381 .61841 L .51927 .6111 L p .564 .353 .553 r
F P
0 g
s
.51931 .58647 m .49402 .59384 L .47994 .58018 L p .654 .754 .923 r
F P
0 g
s
.51927 .6111 m .51931 .58647 L .49402 .59384 L p .564 .353 .553 r
F P
0 g
s
.49402 .59384 m .49381 .61841 L .51927 .6111 L p .564 .353 .553 r
F P
0 g
s
.45474 .58761 m .47994 .58018 L .49402 .59384 L p .654 .754 .923 r
F P
0 g
s
.47994 .58018 m .49402 .59384 L .49381 .61841 L p .954 .688 .492 r
F P
0 g
s
.47994 .58018 m .49402 .59384 L .49381 .61841 L p .954 .688 .492 r
F P
0 g
s
.81464 .48015 m .84149 .47223 L .85254 .4868 L p .66 .747 .915 r
F P
0 g
s
.84149 .47223 m .85254 .4868 L .85485 .51061 L p .976 .678 .372 r
F P
0 g
s
.6343 .52189 m .62141 .50762 L .62073 .48378 L p .966 .687 .452 r
F P
0 g
s
.6343 .52189 m .62141 .50762 L .62073 .48378 L p .966 .687 .452 r
F P
0 g
s
.66024 .51419 m .6343 .52189 L .62141 .50762 L p .658 .749 .917 r
F P
0 g
s
.6612 .53831 m .66024 .51419 L .6343 .52189 L p .566 .356 .555 r
F P
0 g
s
.6343 .52189 m .63508 .54596 L .6612 .53831 L p .566 .356 .555 r
F P
0 g
s
.59555 .51538 m .62141 .50762 L .6343 .52189 L p .658 .749 .917 r
F P
0 g
s
.59555 .51538 m .62141 .50762 L .6343 .52189 L p .658 .749 .917 r
F P
0 g
s
.62141 .50762 m .6343 .52189 L .63508 .54596 L p .966 .687 .452 r
F P
0 g
s
.66024 .51419 m .6343 .52189 L .62141 .50762 L p .658 .749 .917 r
F P
0 g
s
.62141 .50762 m .6343 .52189 L .63508 .54596 L p .966 .687 .452 r
F P
0 g
s
.51719 .47833 m .4919 .4862 L .4778 .47162 L p .66 .747 .915 r
F P
0 g
s
.51713 .5022 m .51719 .47833 L .4919 .4862 L p .558 .345 .547 r
F P
0 g
s
.4919 .4862 m .49167 .51001 L .51713 .5022 L p .558 .345 .547 r
F P
0 g
s
.4778 .47162 m .4919 .4862 L .49167 .51001 L p .957 .688 .485 r
F P
0 g
s
.55837 .59271 m .54482 .57903 L .54468 .55469 L p .959 .688 .477 r
F P
0 g
s
.55837 .59271 m .54482 .57903 L .54468 .55469 L p .959 .688 .477 r
F P
0 g
s
.58396 .58533 m .55837 .59271 L .54482 .57903 L p .654 .754 .923 r
F P
0 g
s
.58438 .60997 m .58396 .58533 L .55837 .59271 L p .566 .356 .555 r
F P
0 g
s
.55837 .59271 m .55861 .61729 L .58438 .60997 L p .566 .356 .555 r
F P
0 g
s
.51931 .58647 m .54482 .57903 L .55837 .59271 L p .654 .754 .923 r
F P
0 g
s
.51931 .58647 m .54482 .57903 L .55837 .59271 L p .654 .754 .923 r
F P
0 g
s
.54482 .57903 m .55837 .59271 L .55861 .61729 L p .959 .688 .477 r
F P
0 g
s
.58396 .58533 m .55837 .59271 L .54482 .57903 L p .654 .754 .923 r
F P
0 g
s
.54482 .57903 m .55837 .59271 L .55861 .61729 L p .959 .688 .477 r
F P
0 g
s
.44027 .57384 m .44086 .54946 L .41592 .557 L p .558 .345 .547 r
F P
0 g
s
.41592 .557 m .41515 .58133 L .44027 .57384 L p .558 .345 .547 r
F P
0 g
s
.44086 .54946 m .41592 .557 L .40116 .54302 L p .656 .751 .92 r
F P
0 g
s
.44027 .57384 m .44086 .54946 L .41592 .557 L p .558 .345 .547 r
F P
0 g
s
.41592 .557 m .41515 .58133 L .44027 .57384 L p .558 .345 .547 r
F P
0 g
s
.40116 .54302 m .41592 .557 L .41515 .58133 L p .949 .687 .505 r
F P
0 g
s
.69877 .52071 m .68641 .50642 L .68527 .48258 L p .971 .686 .432 r
F P
0 g
s
.69877 .52071 m .68641 .50642 L .68527 .48258 L p .971 .686 .432 r
F P
0 g
s
.72502 .513 m .69877 .52071 L .68641 .50642 L p .658 .749 .917 r
F P
0 g
s
.66024 .51419 m .68641 .50642 L .69877 .52071 L p .658 .749 .917 r
F P
0 g
s
.48025 .55585 m .46603 .54185 L .46645 .51775 L p .954 .688 .492 r
F P
0 g
s
.48025 .55585 m .46603 .54185 L .46645 .51775 L p .954 .688 .492 r
F P
0 g
s
.50551 .54829 m .48025 .55585 L .46603 .54185 L p .656 .751 .92 r
F P
0 g
s
.50537 .57269 m .50551 .54829 L .48025 .55585 L p .561 .349 .55 r
F P
0 g
s
.48025 .55585 m .47994 .58018 L .50537 .57269 L p .561 .349 .55 r
F P
0 g
s
.44086 .54946 m .46603 .54185 L .48025 .55585 L p .656 .751 .92 r
F P
0 g
s
.46603 .54185 m .48025 .55585 L .47994 .58018 L p .954 .688 .492 r
F P
0 g
s
.50551 .54829 m .48025 .55585 L .46603 .54185 L p .656 .751 .92 r
F P
0 g
s
.6475 .49978 m .64663 .4759 L .62073 .48378 L p .564 .353 .553 r
F P
0 g
s
.62073 .48378 m .62141 .50762 L .6475 .49978 L p .564 .353 .553 r
F P
0 g
s
.64663 .4759 m .62073 .48378 L .60769 .46917 L p .66 .747 .915 r
F P
0 g
s
.6475 .49978 m .64663 .4759 L .62073 .48378 L p .564 .353 .553 r
F P
0 g
s
.62073 .48378 m .62141 .50762 L .6475 .49978 L p .564 .353 .553 r
F P
0 g
s
.60769 .46917 m .62073 .48378 L .62141 .50762 L p .966 .687 .452 r
F P
0 g
s
.57057 .57153 m .57025 .54713 L .54468 .55469 L p .564 .353 .553 r
F P
0 g
s
.54468 .55469 m .54482 .57903 L .57057 .57153 L p .564 .353 .553 r
F P
0 g
s
.54468 .55469 m .531 .54067 L .53095 .51657 L p .959 .688 .477 r
F P
0 g
s
.54468 .55469 m .531 .54067 L .53095 .51657 L p .959 .688 .477 r
F P
0 g
s
.57025 .54713 m .54468 .55469 L .531 .54067 L p .656 .751 .92 r
F P
0 g
s
.50551 .54829 m .531 .54067 L .54468 .55469 L p .656 .751 .92 r
F P
0 g
s
.46858 .62565 m .45425 .61223 L .45474 .58761 L p .952 .687 .499 r
F P
0 g
s
.46858 .62565 m .45425 .61223 L .45474 .58761 L p .952 .687 .499 r
F P
0 g
s
.49381 .61841 m .46858 .62565 L .45425 .61223 L p .652 .756 .926 r
F P
0 g
s
.49359 .64332 m .49381 .61841 L .46858 .62565 L p .564 .353 .553 r
F P
0 g
s
.46858 .62565 m .46818 .6505 L .49359 .64332 L p .564 .353 .553 r
F P
0 g
s
.4291 .61952 m .45425 .61223 L .46858 .62565 L p .652 .756 .926 r
F P
0 g
s
.45425 .61223 m .46858 .62565 L .46818 .6505 L p .952 .687 .499 r
F P
0 g
s
.49381 .61841 m .46858 .62565 L .45425 .61223 L p .652 .756 .926 r
F P
0 g
s
.82797 .51834 m .81669 .50401 L .81464 .48015 L p .976 .68 .386 r
F P
0 g
s
.82797 .51834 m .81669 .50401 L .81464 .48015 L p .976 .68 .386 r
F P
0 g
s
.85485 .51061 m .82797 .51834 L .81669 .50401 L p .658 .749 .917 r
F P
0 g
s
.78989 .5118 m .81669 .50401 L .82797 .51834 L p .658 .749 .917 r
F P
0 g
s
.71282 .49857 m .71149 .47468 L .68527 .48258 L p .566 .356 .555 r
F P
0 g
s
.68527 .48258 m .68641 .50642 L .71282 .49857 L p .566 .356 .555 r
F P
0 g
s
.71149 .47468 m .68527 .48258 L .67278 .46794 L p .66 .747 .915 r
F P
0 g
s
.71282 .49857 m .71149 .47468 L .68527 .48258 L p .566 .356 .555 r
F P
0 g
s
.68527 .48258 m .68641 .50642 L .71282 .49857 L p .566 .356 .555 r
F P
0 g
s
.64663 .4759 m .67278 .46794 L .68527 .48258 L p .66 .747 .915 r
F P
0 g
s
.67278 .46794 m .68527 .48258 L .68641 .50642 L p .971 .686 .432 r
F P
0 g
s
.67278 .46794 m .68527 .48258 L .68641 .50642 L p .971 .686 .432 r
F P
0 g
s
.6092 .55353 m .59605 .53949 L .59555 .51538 L p .964 .688 .461 r
F P
0 g
s
.63508 .54596 m .6092 .55353 L .59605 .53949 L p .656 .751 .92 r
F P
0 g
s
.63586 .57037 m .63508 .54596 L .6092 .55353 L p .566 .356 .555 r
F P
0 g
s
.6092 .55353 m .60979 .57788 L .63586 .57037 L p .566 .356 .555 r
F P
0 g
s
.57025 .54713 m .59605 .53949 L .6092 .55353 L p .656 .751 .92 r
F P
0 g
s
.59605 .53949 m .6092 .55353 L .60979 .57788 L p .964 .688 .461 r
F P
0 g
s
.63508 .54596 m .6092 .55353 L .59605 .53949 L p .656 .751 .92 r
F P
0 g
s
.59605 .53949 m .6092 .55353 L .60979 .57788 L p .964 .688 .461 r
F P
0 g
s
.49144 .53417 m .49167 .51001 L .46645 .51775 L p .558 .345 .547 r
F P
0 g
s
.46645 .51775 m .46603 .54185 L .49144 .53417 L p .558 .345 .547 r
F P
0 g
s
.46645 .51775 m .45209 .50341 L .4526 .47955 L p .954 .688 .492 r
F P
0 g
s
.49167 .51001 m .46645 .51775 L .45209 .50341 L p .658 .749 .917 r
F P
0 g
s
.49144 .53417 m .49167 .51001 L .46645 .51775 L p .558 .345 .547 r
F P
0 g
s
.46645 .51775 m .46603 .54185 L .49144 .53417 L p .558 .345 .547 r
F P
0 g
s
.42694 .51121 m .45209 .50341 L .46645 .51775 L p .658 .749 .917 r
F P
0 g
s
.42694 .51121 m .45209 .50341 L .46645 .51775 L p .658 .749 .917 r
F P
0 g
s
.45209 .50341 m .46645 .51775 L .46603 .54185 L p .954 .688 .492 r
F P
0 g
s
.45209 .50341 m .46645 .51775 L .46603 .54185 L p .954 .688 .492 r
F P
0 g
s
.53307 .62454 m .51927 .6111 L .51931 .58647 L p .957 .688 .485 r
F P
0 g
s
.53307 .62454 m .51927 .6111 L .51931 .58647 L p .957 .688 .485 r
F P
0 g
s
.55861 .61729 m .53307 .62454 L .51927 .6111 L p .652 .756 .926 r
F P
0 g
s
.49381 .61841 m .51927 .6111 L .53307 .62454 L p .652 .756 .926 r
F P
0 g
s
.55672 .53298 m .55649 .50882 L .53095 .51657 L p .561 .349 .55 r
F P
0 g
s
.53095 .51657 m .531 .54067 L .55672 .53298 L p .561 .349 .55 r
F P
0 g
s
.55649 .50882 m .53095 .51657 L .51713 .5022 L p .658 .749 .917 r
F P
0 g
s
.55672 .53298 m .55649 .50882 L .53095 .51657 L p .561 .349 .55 r
F P
0 g
s
.53095 .51657 m .531 .54067 L .55672 .53298 L p .561 .349 .55 r
F P
0 g
s
.49167 .51001 m .51713 .5022 L .53095 .51657 L p .658 .749 .917 r
F P
0 g
s
.51713 .5022 m .53095 .51657 L .531 .54067 L p .959 .688 .477 r
F P
0 g
s
.51713 .5022 m .53095 .51657 L .531 .54067 L p .959 .688 .477 r
F P
0 g
s
.41299 .47285 m .3881 .48076 L .37307 .46609 L p .66 .747 .915 r
F P
0 g
s
.41219 .49675 m .41299 .47285 L .3881 .48076 L p .553 .337 .541 r
F P
0 g
s
.3881 .48076 m .38714 .50461 L .41219 .49675 L p .553 .337 .541 r
F P
0 g
s
.34827 .47407 m .37307 .46609 L .3881 .48076 L p .66 .747 .915 r
F P
0 g
s
.37307 .46609 m .3881 .48076 L .38714 .50461 L p .949 .687 .505 r
F P
0 g
s
.37307 .46609 m .3881 .48076 L .38714 .50461 L p .949 .687 .505 r
F P
0 g
s
.47962 .60486 m .47994 .58018 L .45474 .58761 L p .561 .349 .55 r
F P
0 g
s
.45474 .58761 m .45425 .61223 L .47962 .60486 L p .561 .349 .55 r
F P
0 g
s
.45474 .58761 m .44027 .57384 L .44086 .54946 L p .952 .687 .499 r
F P
0 g
s
.47994 .58018 m .45474 .58761 L .44027 .57384 L p .654 .754 .923 r
F P
0 g
s
.47962 .60486 m .47994 .58018 L .45474 .58761 L p .561 .349 .55 r
F P
0 g
s
.45474 .58761 m .45425 .61223 L .47962 .60486 L p .561 .349 .55 r
F P
0 g
s
.41515 .58133 m .44027 .57384 L .45474 .58761 L p .654 .754 .923 r
F P
0 g
s
.41515 .58133 m .44027 .57384 L .45474 .58761 L p .654 .754 .923 r
F P
0 g
s
.44027 .57384 m .45474 .58761 L .45425 .61223 L p .952 .687 .499 r
F P
0 g
s
.44027 .57384 m .45474 .58761 L .45425 .61223 L p .952 .687 .499 r
F P
0 g
s
.84374 .49615 m .84149 .47223 L .81464 .48015 L p .571 .363 .56 r
F P
0 g
s
.81464 .48015 m .81669 .50401 L .84374 .49615 L p .571 .363 .56 r
F P
0 g
s
.84149 .47223 m .81464 .48015 L .80323 .46548 L p .66 .747 .915 r
F P
0 g
s
.84374 .49615 m .84149 .47223 L .81464 .48015 L p .571 .363 .56 r
F P
0 g
s
.81464 .48015 m .81669 .50401 L .84374 .49615 L p .571 .363 .56 r
F P
0 g
s
.77645 .47346 m .80323 .46548 L .81464 .48015 L p .66 .747 .915 r
F P
0 g
s
.80323 .46548 m .81464 .48015 L .81669 .50401 L p .976 .68 .386 r
F P
0 g
s
.80323 .46548 m .81464 .48015 L .81669 .50401 L p .976 .68 .386 r
F P
0 g
s
.62209 .53179 m .62141 .50762 L .59555 .51538 L p .564 .353 .553 r
F P
0 g
s
.59555 .51538 m .59605 .53949 L .62209 .53179 L p .564 .353 .553 r
F P
0 g
s
.62141 .50762 m .59555 .51538 L .58227 .50099 L p .658 .749 .917 r
F P
0 g
s
.62209 .53179 m .62141 .50762 L .59555 .51538 L p .564 .353 .553 r
F P
0 g
s
.59555 .51538 m .59605 .53949 L .62209 .53179 L p .564 .353 .553 r
F P
0 g
s
.55649 .50882 m .58227 .50099 L .59555 .51538 L p .658 .749 .917 r
F P
0 g
s
.58227 .50099 m .59555 .51538 L .59605 .53949 L p .964 .688 .461 r
F P
0 g
s
.58227 .50099 m .59555 .51538 L .59605 .53949 L p .964 .688 .461 r
F P
0 g
s
.41299 .47285 m .4381 .46486 L .4526 .47955 L p .66 .747 .915 r
F P
0 g
s
.4381 .46486 m .4526 .47955 L .45209 .50341 L p .954 .688 .492 r
F P
0 g
s
.54497 .60372 m .54482 .57903 L .51931 .58647 L p .564 .353 .553 r
F P
0 g
s
.51931 .58647 m .51927 .6111 L .54497 .60372 L p .564 .353 .553 r
F P
0 g
s
.54482 .57903 m .51931 .58647 L .50537 .57269 L p .654 .754 .923 r
F P
0 g
s
.54497 .60372 m .54482 .57903 L .51931 .58647 L p .564 .353 .553 r
F P
0 g
s
.51931 .58647 m .51927 .6111 L .54497 .60372 L p .564 .353 .553 r
F P
0 g
s
.47994 .58018 m .50537 .57269 L .51931 .58647 L p .654 .754 .923 r
F P
0 g
s
.50537 .57269 m .51931 .58647 L .51927 .6111 L p .957 .688 .485 r
F P
0 g
s
.50537 .57269 m .51931 .58647 L .51927 .6111 L p .957 .688 .485 r
F P
0 g
s
.66024 .51419 m .6475 .49978 L .64663 .4759 L p .969 .687 .442 r
F P
0 g
s
.66024 .51419 m .6475 .49978 L .64663 .4759 L p .969 .687 .442 r
F P
0 g
s
.68641 .50642 m .66024 .51419 L .6475 .49978 L p .658 .749 .917 r
F P
0 g
s
.68756 .5306 m .68641 .50642 L .66024 .51419 L p .566 .356 .555 r
F P
0 g
s
.66024 .51419 m .6612 .53831 L .68756 .5306 L p .566 .356 .555 r
F P
0 g
s
.62141 .50762 m .6475 .49978 L .66024 .51419 L p .658 .749 .917 r
F P
0 g
s
.62141 .50762 m .6475 .49978 L .66024 .51419 L p .658 .749 .917 r
F P
0 g
s
.6475 .49978 m .66024 .51419 L .6612 .53831 L p .969 .687 .442 r
F P
0 g
s
.68641 .50642 m .66024 .51419 L .6475 .49978 L p .658 .749 .917 r
F P
0 g
s
.6475 .49978 m .66024 .51419 L .6612 .53831 L p .969 .687 .442 r
F P
0 g
s
.5427 .4704 m .51719 .47833 L .50323 .46362 L p .66 .747 .915 r
F P
0 g
s
.54283 .49432 m .5427 .4704 L .51719 .47833 L p .558 .345 .547 r
F P
0 g
s
.51719 .47833 m .51713 .5022 L .54283 .49432 L p .558 .345 .547 r
F P
0 g
s
.4778 .47162 m .50323 .46362 L .51719 .47833 L p .66 .747 .915 r
F P
0 g
s
.50323 .46362 m .51719 .47833 L .51713 .5022 L p .959 .688 .477 r
F P
0 g
s
.50323 .46362 m .51719 .47833 L .51713 .5022 L p .959 .688 .477 r
F P
0 g
s
.58396 .58533 m .57057 .57153 L .57025 .54713 L p .962 .688 .469 r
F P
0 g
s
.58396 .58533 m .57057 .57153 L .57025 .54713 L p .962 .688 .469 r
F P
0 g
s
.60979 .57788 m .58396 .58533 L .57057 .57153 L p .654 .754 .923 r
F P
0 g
s
.6104 .60258 m .60979 .57788 L .58396 .58533 L p .566 .356 .555 r
F P
0 g
s
.58396 .58533 m .58438 .60997 L .6104 .60258 L p .566 .356 .555 r
F P
0 g
s
.54482 .57903 m .57057 .57153 L .58396 .58533 L p .654 .754 .923 r
F P
0 g
s
.54482 .57903 m .57057 .57153 L .58396 .58533 L p .654 .754 .923 r
F P
0 g
s
.57057 .57153 m .58396 .58533 L .58438 .60997 L p .962 .688 .469 r
F P
0 g
s
.60979 .57788 m .58396 .58533 L .57057 .57153 L p .654 .754 .923 r
F P
0 g
s
.57057 .57153 m .58396 .58533 L .58438 .60997 L p .962 .688 .469 r
F P
0 g
s
.44086 .54946 m .42625 .53535 L .42694 .51121 L p .952 .687 .499 r
F P
0 g
s
.46603 .54185 m .44086 .54946 L .42625 .53535 L p .656 .751 .92 r
F P
0 g
s
.40116 .54302 m .42625 .53535 L .44086 .54946 L p .656 .751 .92 r
F P
0 g
s
.42625 .53535 m .44086 .54946 L .44027 .57384 L p .952 .687 .499 r
F P
0 g
s
.68641 .50642 m .71282 .49857 L .72502 .513 L p .658 .749 .917 r
F P
0 g
s
.72502 .513 m .71282 .49857 L .71149 .47468 L p .972 .685 .422 r
F P
0 g
s
.50551 .54829 m .49144 .53417 L .49167 .51001 L p .957 .688 .485 r
F P
0 g
s
.50551 .54829 m .49144 .53417 L .49167 .51001 L p .957 .688 .485 r
F P
0 g
s
.531 .54067 m .50551 .54829 L .49144 .53417 L p .656 .751 .92 r
F P
0 g
s
.53104 .56512 m .531 .54067 L .50551 .54829 L p .561 .349 .55 r
F P
0 g
s
.50551 .54829 m .50537 .57269 L .53104 .56512 L p .561 .349 .55 r
F P
0 g
s
.46603 .54185 m .49144 .53417 L .50551 .54829 L p .656 .751 .92 r
F P
0 g
s
.46603 .54185 m .49144 .53417 L .50551 .54829 L p .656 .751 .92 r
F P
0 g
s
.49144 .53417 m .50551 .54829 L .50537 .57269 L p .957 .688 .485 r
F P
0 g
s
.531 .54067 m .50551 .54829 L .49144 .53417 L p .656 .751 .92 r
F P
0 g
s
.49144 .53417 m .50551 .54829 L .50537 .57269 L p .957 .688 .485 r
F P
0 g
s
.36231 .5124 m .34702 .49797 L .34827 .47407 L p .946 .686 .511 r
F P
0 g
s
.38714 .50461 m .36231 .5124 L .34702 .49797 L p .658 .749 .917 r
F P
0 g
s
.4291 .61952 m .41438 .606 L .41515 .58133 L p .949 .687 .505 r
F P
0 g
s
.45425 .61223 m .4291 .61952 L .41438 .606 L p .652 .756 .926 r
F P
0 g
s
.78989 .5118 m .77824 .49736 L .77645 .47346 L p .975 .682 .398 r
F P
0 g
s
.81669 .50401 m .78989 .5118 L .77824 .49736 L p .658 .749 .917 r
F P
0 g
s
.67384 .49188 m .67278 .46794 L .64663 .4759 L p .564 .353 .553 r
F P
0 g
s
.64663 .4759 m .6475 .49978 L .67384 .49188 L p .564 .353 .553 r
F P
0 g
s
.60769 .46917 m .63376 .46115 L .64663 .4759 L p .66 .747 .915 r
F P
0 g
s
.63376 .46115 m .64663 .4759 L .6475 .49978 L p .969 .687 .442 r
F P
0 g
s
.59656 .56395 m .59605 .53949 L .57025 .54713 L p .564 .353 .553 r
F P
0 g
s
.57025 .54713 m .57057 .57153 L .59656 .56395 L p .564 .353 .553 r
F P
0 g
s
.57025 .54713 m .55672 .53298 L .55649 .50882 L p .962 .688 .469 r
F P
0 g
s
.57025 .54713 m .55672 .53298 L .55649 .50882 L p .962 .688 .469 r
F P
0 g
s
.59605 .53949 m .57025 .54713 L .55672 .53298 L p .656 .751 .92 r
F P
0 g
s
.531 .54067 m .55672 .53298 L .57025 .54713 L p .656 .751 .92 r
F P
0 g
s
.45157 .52761 m .45209 .50341 L .42694 .51121 L p .556 .341 .544 r
F P
0 g
s
.42694 .51121 m .42625 .53535 L .45157 .52761 L p .556 .341 .544 r
F P
0 g
s
.42694 .51121 m .41219 .49675 L .41299 .47285 L p .952 .687 .499 r
F P
0 g
s
.45209 .50341 m .42694 .51121 L .41219 .49675 L p .658 .749 .917 r
F P
0 g
s
.45157 .52761 m .45209 .50341 L .42694 .51121 L p .556 .341 .544 r
F P
0 g
s
.42694 .51121 m .42625 .53535 L .45157 .52761 L p .556 .341 .544 r
F P
0 g
s
.41219 .49675 m .42694 .51121 L .42625 .53535 L p .952 .687 .499 r
F P
0 g
s
.45209 .50341 m .42694 .51121 L .41219 .49675 L p .658 .749 .917 r
F P
0 g
s
.49381 .61841 m .47962 .60486 L .47994 .58018 L p .954 .688 .492 r
F P
0 g
s
.49381 .61841 m .47962 .60486 L .47994 .58018 L p .954 .688 .492 r
F P
0 g
s
.51927 .6111 m .49381 .61841 L .47962 .60486 L p .652 .756 .926 r
F P
0 g
s
.51923 .63608 m .51927 .6111 L .49381 .61841 L p .564 .353 .553 r
F P
0 g
s
.49381 .61841 m .49359 .64332 L .51923 .63608 L p .564 .353 .553 r
F P
0 g
s
.45425 .61223 m .47962 .60486 L .49381 .61841 L p .652 .756 .926 r
F P
0 g
s
.45425 .61223 m .47962 .60486 L .49381 .61841 L p .652 .756 .926 r
F P
0 g
s
.47962 .60486 m .49381 .61841 L .49359 .64332 L p .954 .688 .492 r
F P
0 g
s
.51927 .6111 m .49381 .61841 L .47962 .60486 L p .652 .756 .926 r
F P
0 g
s
.47962 .60486 m .49381 .61841 L .49359 .64332 L p .954 .688 .492 r
F P
0 g
s
.81669 .50401 m .84374 .49615 L .85485 .51061 L p .658 .749 .917 r
F P
0 g
s
.85485 .51061 m .84374 .49615 L .84149 .47223 L p .976 .678 .372 r
F P
0 g
s
.67278 .46794 m .69917 .45991 L .71149 .47468 L p .66 .747 .915 r
F P
0 g
s
.69917 .45991 m .71149 .47468 L .71282 .49857 L p .972 .685 .422 r
F P
0 g
s
.63508 .54596 m .62209 .53179 L .62141 .50762 L p .966 .687 .452 r
F P
0 g
s
.63508 .54596 m .62209 .53179 L .62141 .50762 L p .966 .687 .452 r
F P
0 g
s
.6612 .53831 m .63508 .54596 L .62209 .53179 L p .656 .751 .92 r
F P
0 g
s
.66217 .56278 m .6612 .53831 L .63508 .54596 L p .566 .356 .555 r
F P
0 g
s
.63508 .54596 m .63586 .57037 L .66217 .56278 L p .566 .356 .555 r
F P
0 g
s
.59605 .53949 m .62209 .53179 L .63508 .54596 L p .656 .751 .92 r
F P
0 g
s
.59605 .53949 m .62209 .53179 L .63508 .54596 L p .656 .751 .92 r
F P
0 g
s
.62209 .53179 m .63508 .54596 L .63586 .57037 L p .966 .687 .452 r
F P
0 g
s
.6612 .53831 m .63508 .54596 L .62209 .53179 L p .656 .751 .92 r
F P
0 g
s
.62209 .53179 m .63508 .54596 L .63586 .57037 L p .966 .687 .452 r
F P
0 g
s
.51708 .52641 m .51713 .5022 L .49167 .51001 L p .558 .345 .547 r
F P
0 g
s
.49167 .51001 m .49144 .53417 L .51708 .52641 L p .558 .345 .547 r
F P
0 g
s
.49167 .51001 m .47747 .49554 L .4778 .47162 L p .957 .688 .485 r
F P
0 g
s
.51713 .5022 m .49167 .51001 L .47747 .49554 L p .658 .749 .917 r
F P
0 g
s
.51708 .52641 m .51713 .5022 L .49167 .51001 L p .558 .345 .547 r
F P
0 g
s
.49167 .51001 m .49144 .53417 L .51708 .52641 L p .558 .345 .547 r
F P
0 g
s
.45209 .50341 m .47747 .49554 L .49167 .51001 L p .658 .749 .917 r
F P
0 g
s
.47747 .49554 m .49167 .51001 L .49144 .53417 L p .957 .688 .485 r
F P
0 g
s
.51713 .5022 m .49167 .51001 L .47747 .49554 L p .658 .749 .917 r
F P
0 g
s
.47747 .49554 m .49167 .51001 L .49144 .53417 L p .957 .688 .485 r
F P
0 g
s
.37199 .49004 m .37307 .46609 L .34827 .47407 L p .55 .333 .538 r
F P
0 g
s
.34827 .47407 m .34702 .49797 L .37199 .49004 L p .55 .333 .538 r
F P
0 g
s
.37307 .46609 m .34827 .47407 L .33284 .45929 L p .66 .747 .915 r
F P
0 g
s
.37199 .49004 m .37307 .46609 L .34827 .47407 L p .55 .333 .538 r
F P
0 g
s
.34827 .47407 m .34702 .49797 L .37199 .49004 L p .55 .333 .538 r
F P
0 g
s
.33284 .45929 m .34827 .47407 L .34702 .49797 L p .946 .686 .511 r
F P
0 g
s
.55861 .61729 m .54497 .60372 L .54482 .57903 L p .959 .688 .477 r
F P
0 g
s
.55861 .61729 m .54497 .60372 L .54482 .57903 L p .959 .688 .477 r
F P
0 g
s
.58438 .60997 m .55861 .61729 L .54497 .60372 L p .652 .756 .926 r
F P
0 g
s
.51927 .6111 m .54497 .60372 L .55861 .61729 L p .652 .756 .926 r
F P
0 g
s
.43967 .59857 m .44027 .57384 L .41515 .58133 L p .558 .345 .547 r
F P
0 g
s
.41515 .58133 m .41438 .606 L .43967 .59857 L p .558 .345 .547 r
F P
0 g
s
.41515 .58133 m .40029 .56746 L .40116 .54302 L p .949 .687 .505 r
F P
0 g
s
.44027 .57384 m .41515 .58133 L .40029 .56746 L p .654 .754 .923 r
F P
0 g
s
.43967 .59857 m .44027 .57384 L .41515 .58133 L p .558 .345 .547 r
F P
0 g
s
.41515 .58133 m .41438 .606 L .43967 .59857 L p .558 .345 .547 r
F P
0 g
s
.40029 .56746 m .41515 .58133 L .41438 .606 L p .949 .687 .505 r
F P
0 g
s
.44027 .57384 m .41515 .58133 L .40029 .56746 L p .654 .754 .923 r
F P
0 g
s
.80522 .48943 m .80323 .46548 L .77645 .47346 L p .569 .36 .558 r
F P
0 g
s
.77645 .47346 m .77824 .49736 L .80522 .48943 L p .569 .36 .558 r
F P
0 g
s
.58268 .52521 m .58227 .50099 L .55649 .50882 L p .561 .349 .55 r
F P
0 g
s
.55649 .50882 m .55672 .53298 L .58268 .52521 L p .561 .349 .55 r
F P
0 g
s
.58227 .50099 m .55649 .50882 L .54283 .49432 L p .658 .749 .917 r
F P
0 g
s
.58268 .52521 m .58227 .50099 L .55649 .50882 L p .561 .349 .55 r
F P
0 g
s
.55649 .50882 m .55672 .53298 L .58268 .52521 L p .561 .349 .55 r
F P
0 g
s
.51713 .5022 m .54283 .49432 L .55649 .50882 L p .658 .749 .917 r
F P
0 g
s
.54283 .49432 m .55649 .50882 L .55672 .53298 L p .962 .688 .469 r
F P
0 g
s
.54283 .49432 m .55649 .50882 L .55672 .53298 L p .962 .688 .469 r
F P
0 g
s
.43749 .48882 m .4381 .46486 L .41299 .47285 L p .553 .337 .541 r
F P
0 g
s
.41299 .47285 m .41219 .49675 L .43749 .48882 L p .553 .337 .541 r
F P
0 g
s
.37307 .46609 m .3981 .45804 L .41299 .47285 L p .66 .747 .915 r
F P
0 g
s
.3981 .45804 m .41299 .47285 L .41219 .49675 L p .952 .687 .499 r
F P
0 g
s
.50524 .59743 m .50537 .57269 L .47994 .58018 L p .561 .349 .55 r
F P
0 g
s
.47994 .58018 m .47962 .60486 L .50524 .59743 L p .561 .349 .55 r
F P
0 g
s
.47994 .58018 m .46562 .56629 L .46603 .54185 L p .954 .688 .492 r
F P
0 g
s
.50537 .57269 m .47994 .58018 L .46562 .56629 L p .654 .754 .923 r
F P
0 g
s
.44027 .57384 m .46562 .56629 L .47994 .58018 L p .654 .754 .923 r
F P
0 g
s
.46562 .56629 m .47994 .58018 L .47962 .60486 L p .954 .688 .492 r
F P
0 g
s
.86859 .46424 m .84149 .47223 L .83026 .45742 L p .66 .747 .915 r
F P
0 g
s
.87105 .48821 m .86859 .46424 L .84149 .47223 L p .571 .363 .56 r
F P
0 g
s
.84149 .47223 m .84374 .49615 L .87105 .48821 L p .571 .363 .56 r
F P
0 g
s
.80323 .46548 m .83026 .45742 L .84149 .47223 L p .66 .747 .915 r
F P
0 g
s
.83026 .45742 m .84149 .47223 L .84374 .49615 L p .976 .678 .372 r
F P
0 g
s
.83026 .45742 m .84149 .47223 L .84374 .49615 L p .976 .678 .372 r
F P
0 g
s
.64838 .52401 m .6475 .49978 L .62141 .50762 L p .564 .353 .553 r
F P
0 g
s
.62141 .50762 m .62209 .53179 L .64838 .52401 L p .564 .353 .553 r
F P
0 g
s
.62141 .50762 m .60829 .4931 L .60769 .46917 L p .966 .687 .452 r
F P
0 g
s
.6475 .49978 m .62141 .50762 L .60829 .4931 L p .658 .749 .917 r
F P
0 g
s
.64838 .52401 m .6475 .49978 L .62141 .50762 L p .564 .353 .553 r
F P
0 g
s
.62141 .50762 m .62209 .53179 L .64838 .52401 L p .564 .353 .553 r
F P
0 g
s
.58227 .50099 m .60829 .4931 L .62141 .50762 L p .658 .749 .917 r
F P
0 g
s
.60829 .4931 m .62141 .50762 L .62209 .53179 L p .966 .687 .452 r
F P
0 g
s
.6475 .49978 m .62141 .50762 L .60829 .4931 L p .658 .749 .917 r
F P
0 g
s
.60829 .4931 m .62141 .50762 L .62209 .53179 L p .966 .687 .452 r
F P
0 g
s
.50308 .48759 m .50323 .46362 L .4778 .47162 L p .556 .341 .544 r
F P
0 g
s
.4778 .47162 m .47747 .49554 L .50308 .48759 L p .556 .341 .544 r
F P
0 g
s
.50323 .46362 m .4778 .47162 L .46345 .4568 L p .66 .747 .915 r
F P
0 g
s
.50308 .48759 m .50323 .46362 L .4778 .47162 L p .556 .341 .544 r
F P
0 g
s
.4778 .47162 m .47747 .49554 L .50308 .48759 L p .556 .341 .544 r
F P
0 g
s
.46345 .4568 m .4778 .47162 L .47747 .49554 L p .957 .688 .485 r
F P
0 g
s
.5709 .59628 m .57057 .57153 L .54482 .57903 L p .564 .353 .553 r
F P
0 g
s
.54482 .57903 m .54497 .60372 L .5709 .59628 L p .564 .353 .553 r
F P
0 g
s
.57057 .57153 m .54482 .57903 L .53104 .56512 L p .654 .754 .923 r
F P
0 g
s
.5709 .59628 m .57057 .57153 L .54482 .57903 L p .564 .353 .553 r
F P
0 g
s
.54482 .57903 m .54497 .60372 L .5709 .59628 L p .564 .353 .553 r
F P
0 g
s
.50537 .57269 m .53104 .56512 L .54482 .57903 L p .654 .754 .923 r
F P
0 g
s
.53104 .56512 m .54482 .57903 L .54497 .60372 L p .959 .688 .477 r
F P
0 g
s
.53104 .56512 m .54482 .57903 L .54497 .60372 L p .959 .688 .477 r
F P
0 g
s
.42555 .55984 m .42625 .53535 L .40116 .54302 L p .556 .341 .544 r
F P
0 g
s
.40116 .54302 m .40029 .56746 L .42555 .55984 L p .556 .341 .544 r
F P
0 g
s
.42625 .53535 m .40116 .54302 L .38616 .52881 L p .656 .751 .92 r
F P
0 g
s
.42555 .55984 m .42625 .53535 L .40116 .54302 L p .556 .341 .544 r
F P
0 g
s
.40116 .54302 m .40029 .56746 L .42555 .55984 L p .556 .341 .544 r
F P
0 g
s
.38616 .52881 m .40116 .54302 L .40029 .56746 L p .949 .687 .505 r
F P
0 g
s
.93405 .463 m .90663 .47101 L .89594 .45617 L p .66 .747 .915 r
F P
0 g
s
.93697 .48698 m .93405 .463 L .90663 .47101 L p .573 .367 .563 r
F P
0 g
s
.90663 .47101 m .90934 .49493 L .93697 .48698 L p .573 .367 .563 r
F P
0 g
s
.89594 .45617 m .90663 .47101 L .90934 .49493 L p .976 .672 .343 r
F P
0 g
s
.46818 .6505 m .45375 .63719 L .45425 .61223 L p .952 .687 .499 r
F P
0 g
s
.49359 .64332 m .46818 .6505 L .45375 .63719 L p .649 .759 .929 r
F P
0 g
s
.68641 .50642 m .67384 .49188 L .67278 .46794 L p .971 .686 .432 r
F P
0 g
s
.68641 .50642 m .67384 .49188 L .67278 .46794 L p .971 .686 .432 r
F P
0 g
s
.71282 .49857 m .68641 .50642 L .67384 .49188 L p .658 .749 .917 r
F P
0 g
s
.6475 .49978 m .67384 .49188 L .68641 .50642 L p .658 .749 .917 r
F P
0 g
s
.6475 .49978 m .67384 .49188 L .68641 .50642 L p .658 .749 .917 r
F P
0 g
s
.67384 .49188 m .68641 .50642 L .68756 .5306 L p .971 .686 .432 r
F P
0 g
s
.56845 .46239 m .5427 .4704 L .5289 .45555 L p .66 .747 .915 r
F P
0 g
s
.56876 .48636 m .56845 .46239 L .5427 .4704 L p .558 .345 .547 r
F P
0 g
s
.5427 .4704 m .54283 .49432 L .56876 .48636 L p .558 .345 .547 r
F P
0 g
s
.50323 .46362 m .5289 .45555 L .5427 .4704 L p .66 .747 .915 r
F P
0 g
s
.5289 .45555 m .5427 .4704 L .54283 .49432 L p .962 .688 .469 r
F P
0 g
s
.5289 .45555 m .5427 .4704 L .54283 .49432 L p .962 .688 .469 r
F P
0 g
s
.60979 .57788 m .59656 .56395 L .59605 .53949 L p .964 .688 .461 r
F P
0 g
s
.60979 .57788 m .59656 .56395 L .59605 .53949 L p .964 .688 .461 r
F P
0 g
s
.63586 .57037 m .60979 .57788 L .59656 .56395 L p .654 .754 .923 r
F P
0 g
s
.63666 .59512 m .63586 .57037 L .60979 .57788 L p .566 .356 .555 r
F P
0 g
s
.60979 .57788 m .6104 .60258 L .63666 .59512 L p .566 .356 .555 r
F P
0 g
s
.57057 .57153 m .59656 .56395 L .60979 .57788 L p .654 .754 .923 r
F P
0 g
s
.57057 .57153 m .59656 .56395 L .60979 .57788 L p .654 .754 .923 r
F P
0 g
s
.59656 .56395 m .60979 .57788 L .6104 .60258 L p .964 .688 .461 r
F P
0 g
s
.63586 .57037 m .60979 .57788 L .59656 .56395 L p .654 .754 .923 r
F P
0 g
s
.59656 .56395 m .60979 .57788 L .6104 .60258 L p .964 .688 .461 r
F P
0 g
s
.4912 .55867 m .49144 .53417 L .46603 .54185 L p .558 .345 .547 r
F P
0 g
s
.46603 .54185 m .46562 .56629 L .4912 .55867 L p .558 .345 .547 r
F P
0 g
s
.46603 .54185 m .45157 .52761 L .45209 .50341 L p .954 .688 .492 r
F P
0 g
s
.46603 .54185 m .45157 .52761 L .45209 .50341 L p .954 .688 .492 r
F P
0 g
s
.49144 .53417 m .46603 .54185 L .45157 .52761 L p .656 .751 .92 r
F P
0 g
s
.4912 .55867 m .49144 .53417 L .46603 .54185 L p .558 .345 .547 r
F P
0 g
s
.46603 .54185 m .46562 .56629 L .4912 .55867 L p .558 .345 .547 r
F P
0 g
s
.42625 .53535 m .45157 .52761 L .46603 .54185 L p .656 .751 .92 r
F P
0 g
s
.45157 .52761 m .46603 .54185 L .46562 .56629 L p .954 .688 .492 r
F P
0 g
s
.49144 .53417 m .46603 .54185 L .45157 .52761 L p .656 .751 .92 r
F P
0 g
s
.63454 .48513 m .63376 .46115 L .60769 .46917 L p .561 .349 .55 r
F P
0 g
s
.60769 .46917 m .60829 .4931 L .63454 .48513 L p .561 .349 .55 r
F P
0 g
s
.63376 .46115 m .60769 .46917 L .59444 .4543 L p .66 .747 .915 r
F P
0 g
s
.63454 .48513 m .63376 .46115 L .60769 .46917 L p .561 .349 .55 r
F P
0 g
s
.60769 .46917 m .60829 .4931 L .63454 .48513 L p .561 .349 .55 r
F P
0 g
s
.59444 .4543 m .60769 .46917 L .60829 .4931 L p .966 .687 .452 r
F P
0 g
s
.531 .54067 m .51708 .52641 L .51713 .5022 L p .959 .688 .477 r
F P
0 g
s
.531 .54067 m .51708 .52641 L .51713 .5022 L p .959 .688 .477 r
F P
0 g
s
.55672 .53298 m .531 .54067 L .51708 .52641 L p .656 .751 .92 r
F P
0 g
s
.55695 .55749 m .55672 .53298 L .531 .54067 L p .561 .349 .55 r
F P
0 g
s
.531 .54067 m .53104 .56512 L .55695 .55749 L p .561 .349 .55 r
F P
0 g
s
.49144 .53417 m .51708 .52641 L .531 .54067 L p .656 .751 .92 r
F P
0 g
s
.49144 .53417 m .51708 .52641 L .531 .54067 L p .656 .751 .92 r
F P
0 g
s
.51708 .52641 m .531 .54067 L .53104 .56512 L p .959 .688 .477 r
F P
0 g
s
.55672 .53298 m .531 .54067 L .51708 .52641 L p .656 .751 .92 r
F P
0 g
s
.51708 .52641 m .531 .54067 L .53104 .56512 L p .959 .688 .477 r
F P
0 g
s
.38714 .50461 m .37199 .49004 L .37307 .46609 L p .949 .687 .505 r
F P
0 g
s
.38714 .50461 m .37199 .49004 L .37307 .46609 L p .949 .687 .505 r
F P
0 g
s
.41219 .49675 m .38714 .50461 L .37199 .49004 L p .658 .749 .917 r
F P
0 g
s
.34702 .49797 m .37199 .49004 L .38714 .50461 L p .658 .749 .917 r
F P
0 g
s
.4793 .62989 m .47962 .60486 L .45425 .61223 L p .561 .349 .55 r
F P
0 g
s
.45425 .61223 m .45375 .63719 L .4793 .62989 L p .561 .349 .55 r
F P
0 g
s
.45425 .61223 m .43967 .59857 L .44027 .57384 L p .952 .687 .499 r
F P
0 g
s
.45425 .61223 m .43967 .59857 L .44027 .57384 L p .952 .687 .499 r
F P
0 g
s
.47962 .60486 m .45425 .61223 L .43967 .59857 L p .652 .756 .926 r
F P
0 g
s
.4793 .62989 m .47962 .60486 L .45425 .61223 L p .561 .349 .55 r
F P
0 g
s
.45425 .61223 m .45375 .63719 L .4793 .62989 L p .561 .349 .55 r
F P
0 g
s
.41438 .606 m .43967 .59857 L .45425 .61223 L p .652 .756 .926 r
F P
0 g
s
.43967 .59857 m .45425 .61223 L .45375 .63719 L p .952 .687 .499 r
F P
0 g
s
.47962 .60486 m .45425 .61223 L .43967 .59857 L p .652 .756 .926 r
F P
0 g
s
.81669 .50401 m .80522 .48943 L .80323 .46548 L p .976 .68 .386 r
F P
0 g
s
.81669 .50401 m .80522 .48943 L .80323 .46548 L p .976 .68 .386 r
F P
0 g
s
.84374 .49615 m .81669 .50401 L .80522 .48943 L p .658 .749 .917 r
F P
0 g
s
.84603 .5204 m .84374 .49615 L .81669 .50401 L p .571 .363 .56 r
F P
0 g
s
.81669 .50401 m .81877 .52821 L .84603 .5204 L p .571 .363 .56 r
F P
0 g
s
.77824 .49736 m .80522 .48943 L .81669 .50401 L p .658 .749 .917 r
F P
0 g
s
.80522 .48943 m .81669 .50401 L .81877 .52821 L p .976 .68 .386 r
F P
0 g
s
.84374 .49615 m .81669 .50401 L .80522 .48943 L p .658 .749 .917 r
F P
0 g
s
.70042 .4839 m .69917 .45991 L .67278 .46794 L p .564 .353 .553 r
F P
0 g
s
.67278 .46794 m .67384 .49188 L .70042 .4839 L p .564 .353 .553 r
F P
0 g
s
.62279 .55631 m .62209 .53179 L .59605 .53949 L p .564 .353 .553 r
F P
0 g
s
.59605 .53949 m .59656 .56395 L .62279 .55631 L p .564 .353 .553 r
F P
0 g
s
.59605 .53949 m .58268 .52521 L .58227 .50099 L p .964 .688 .461 r
F P
0 g
s
.59605 .53949 m .58268 .52521 L .58227 .50099 L p .964 .688 .461 r
F P
0 g
s
.62209 .53179 m .59605 .53949 L .58268 .52521 L p .656 .751 .92 r
F P
0 g
s
.55672 .53298 m .58268 .52521 L .59605 .53949 L p .656 .751 .92 r
F P
0 g
s
.47713 .5198 m .47747 .49554 L .45209 .50341 L p .556 .341 .544 r
F P
0 g
s
.45209 .50341 m .45157 .52761 L .47713 .5198 L p .556 .341 .544 r
F P
0 g
s
.45209 .50341 m .43749 .48882 L .4381 .46486 L p .954 .688 .492 r
F P
0 g
s
.47747 .49554 m .45209 .50341 L .43749 .48882 L p .658 .749 .917 r
F P
0 g
s
.47713 .5198 m .47747 .49554 L .45209 .50341 L p .556 .341 .544 r
F P
0 g
s
.45209 .50341 m .45157 .52761 L .47713 .5198 L p .556 .341 .544 r
F P
0 g
s
.41219 .49675 m .43749 .48882 L .45209 .50341 L p .658 .749 .917 r
F P
0 g
s
.41219 .49675 m .43749 .48882 L .45209 .50341 L p .658 .749 .917 r
F P
0 g
s
.43749 .48882 m .45209 .50341 L .45157 .52761 L p .954 .688 .492 r
F P
0 g
s
.43749 .48882 m .45209 .50341 L .45157 .52761 L p .954 .688 .492 r
F P
0 g
s
.51927 .6111 m .50524 .59743 L .50537 .57269 L p .957 .688 .485 r
F P
0 g
s
.51927 .6111 m .50524 .59743 L .50537 .57269 L p .957 .688 .485 r
F P
0 g
s
.54497 .60372 m .51927 .6111 L .50524 .59743 L p .652 .756 .926 r
F P
0 g
s
.47962 .60486 m .50524 .59743 L .51927 .6111 L p .652 .756 .926 r
F P
0 g
s
.47962 .60486 m .50524 .59743 L .51927 .6111 L p .652 .756 .926 r
F P
0 g
s
.50524 .59743 m .51927 .6111 L .51923 .63608 L p .957 .688 .485 r
F P
0 g
s
.6612 .53831 m .64838 .52401 L .6475 .49978 L p .969 .687 .442 r
F P
0 g
s
.6612 .53831 m .64838 .52401 L .6475 .49978 L p .969 .687 .442 r
F P
0 g
s
.68756 .5306 m .6612 .53831 L .64838 .52401 L p .656 .751 .92 r
F P
0 g
s
.68873 .55512 m .68756 .5306 L .6612 .53831 L p .566 .356 .555 r
F P
0 g
s
.6612 .53831 m .66217 .56278 L .68873 .55512 L p .566 .356 .555 r
F P
0 g
s
.62209 .53179 m .64838 .52401 L .6612 .53831 L p .656 .751 .92 r
F P
0 g
s
.62209 .53179 m .64838 .52401 L .6612 .53831 L p .656 .751 .92 r
F P
0 g
s
.64838 .52401 m .6612 .53831 L .66217 .56278 L p .969 .687 .442 r
F P
0 g
s
.68756 .5306 m .6612 .53831 L .64838 .52401 L p .656 .751 .92 r
F P
0 g
s
.64838 .52401 m .6612 .53831 L .66217 .56278 L p .969 .687 .442 r
F P
0 g
s
.54296 .51859 m .54283 .49432 L .51713 .5022 L p .558 .345 .547 r
F P
0 g
s
.51713 .5022 m .51708 .52641 L .54296 .51859 L p .558 .345 .547 r
F P
0 g
s
.51713 .5022 m .50308 .48759 L .50323 .46362 L p .959 .688 .477 r
F P
0 g
s
.51713 .5022 m .50308 .48759 L .50323 .46362 L p .959 .688 .477 r
F P
0 g
s
.54283 .49432 m .51713 .5022 L .50308 .48759 L p .658 .749 .917 r
F P
0 g
s
.47747 .49554 m .50308 .48759 L .51713 .5022 L p .658 .749 .917 r
F P
0 g
s
.47747 .49554 m .50308 .48759 L .51713 .5022 L p .658 .749 .917 r
F P
0 g
s
.50308 .48759 m .51713 .5022 L .51708 .52641 L p .959 .688 .477 r
F P
0 g
s
.39719 .48205 m .3981 .45804 L .37307 .46609 L p .55 .333 .538 r
F P
0 g
s
.37307 .46609 m .37199 .49004 L .39719 .48205 L p .55 .333 .538 r
F P
0 g
s
.3981 .45804 m .37307 .46609 L .35778 .45117 L p .66 .747 .915 r
F P
0 g
s
.39719 .48205 m .3981 .45804 L .37307 .46609 L p .55 .333 .538 r
F P
0 g
s
.37307 .46609 m .37199 .49004 L .39719 .48205 L p .55 .333 .538 r
F P
0 g
s
.33284 .45929 m .35778 .45117 L .37307 .46609 L p .66 .747 .915 r
F P
0 g
s
.35778 .45117 m .37307 .46609 L .37199 .49004 L p .949 .687 .505 r
F P
0 g
s
.35778 .45117 m .37307 .46609 L .37199 .49004 L p .949 .687 .505 r
F P
0 g
s
.58438 .60997 m .5709 .59628 L .57057 .57153 L p .962 .688 .469 r
F P
0 g
s
.58438 .60997 m .5709 .59628 L .57057 .57153 L p .962 .688 .469 r
F P
0 g
s
.6104 .60258 m .58438 .60997 L .5709 .59628 L p .652 .756 .926 r
F P
0 g
s
.54497 .60372 m .5709 .59628 L .58438 .60997 L p .652 .756 .926 r
F P
0 g
s
.4652 .59108 m .46562 .56629 L .44027 .57384 L p .558 .345 .547 r
F P
0 g
s
.44027 .57384 m .43967 .59857 L .4652 .59108 L p .558 .345 .547 r
F P
0 g
s
.44027 .57384 m .42555 .55984 L .42625 .53535 L p .952 .687 .499 r
F P
0 g
s
.46562 .56629 m .44027 .57384 L .42555 .55984 L p .654 .754 .923 r
F P
0 g
s
.4652 .59108 m .46562 .56629 L .44027 .57384 L p .558 .345 .547 r
F P
0 g
s
.44027 .57384 m .43967 .59857 L .4652 .59108 L p .558 .345 .547 r
F P
0 g
s
.40029 .56746 m .42555 .55984 L .44027 .57384 L p .654 .754 .923 r
F P
0 g
s
.40029 .56746 m .42555 .55984 L .44027 .57384 L p .654 .754 .923 r
F P
0 g
s
.42555 .55984 m .44027 .57384 L .43967 .59857 L p .952 .687 .499 r
F P
0 g
s
.42555 .55984 m .44027 .57384 L .43967 .59857 L p .952 .687 .499 r
F P
0 g
s
.83245 .48143 m .83026 .45742 L .80323 .46548 L p .569 .36 .558 r
F P
0 g
s
.80323 .46548 m .80522 .48943 L .83245 .48143 L p .569 .36 .558 r
F P
0 g
s
.83026 .45742 m .80323 .46548 L .79162 .45055 L p .66 .747 .915 r
F P
0 g
s
.83245 .48143 m .83026 .45742 L .80323 .46548 L p .569 .36 .558 r
F P
0 g
s
.80323 .46548 m .80522 .48943 L .83245 .48143 L p .569 .36 .558 r
F P
0 g
s
.79162 .45055 m .80323 .46548 L .80522 .48943 L p .976 .68 .386 r
F P
0 g
s
.60889 .51738 m .60829 .4931 L .58227 .50099 L p .561 .349 .55 r
F P
0 g
s
.58227 .50099 m .58268 .52521 L .60889 .51738 L p .561 .349 .55 r
F P
0 g
s
.60829 .4931 m .58227 .50099 L .56876 .48636 L p .658 .749 .917 r
F P
0 g
s
.60889 .51738 m .60829 .4931 L .58227 .50099 L p .561 .349 .55 r
F P
0 g
s
.58227 .50099 m .58268 .52521 L .60889 .51738 L p .561 .349 .55 r
F P
0 g
s
.54283 .49432 m .56876 .48636 L .58227 .50099 L p .658 .749 .917 r
F P
0 g
s
.56876 .48636 m .58227 .50099 L .58268 .52521 L p .964 .688 .461 r
F P
0 g
s
.56876 .48636 m .58227 .50099 L .58268 .52521 L p .964 .688 .461 r
F P
0 g
s
.53109 .58992 m .53104 .56512 L .50537 .57269 L p .561 .349 .55 r
F P
0 g
s
.50537 .57269 m .50524 .59743 L .53109 .58992 L p .561 .349 .55 r
F P
0 g
s
.50537 .57269 m .4912 .55867 L .49144 .53417 L p .957 .688 .485 r
F P
0 g
s
.50537 .57269 m .4912 .55867 L .49144 .53417 L p .957 .688 .485 r
F P
0 g
s
.53104 .56512 m .50537 .57269 L .4912 .55867 L p .654 .754 .923 r
F P
0 g
s
.46562 .56629 m .4912 .55867 L .50537 .57269 L p .654 .754 .923 r
F P
0 g
s
.89594 .45617 m .86859 .46424 L .85754 .44929 L p .66 .747 .915 r
F P
0 g
s
.8986 .48019 m .89594 .45617 L .86859 .46424 L p .571 .363 .56 r
F P
0 g
s
.86859 .46424 m .87105 .48821 L .8986 .48019 L p .571 .363 .56 r
F P
0 g
s
.83026 .45742 m .85754 .44929 L .86859 .46424 L p .66 .747 .915 r
F P
0 g
s
.85754 .44929 m .86859 .46424 L .87105 .48821 L p .976 .675 .358 r
F P
0 g
s
.85754 .44929 m .86859 .46424 L .87105 .48821 L p .976 .675 .358 r
F P
0 g
s
.67491 .51616 m .67384 .49188 L .6475 .49978 L p .564 .353 .553 r
F P
0 g
s
.6475 .49978 m .64838 .52401 L .67491 .51616 L p .564 .353 .553 r
F P
0 g
s
.6475 .49978 m .63454 .48513 L .63376 .46115 L p .969 .687 .442 r
F P
0 g
s
.67384 .49188 m .6475 .49978 L .63454 .48513 L p .658 .749 .917 r
F P
0 g
s
.67491 .51616 m .67384 .49188 L .6475 .49978 L p .564 .353 .553 r
F P
0 g
s
.6475 .49978 m .64838 .52401 L .67491 .51616 L p .564 .353 .553 r
F P
0 g
s
.60829 .4931 m .63454 .48513 L .6475 .49978 L p .658 .749 .917 r
F P
0 g
s
.60829 .4931 m .63454 .48513 L .6475 .49978 L p .658 .749 .917 r
F P
0 g
s
.63454 .48513 m .6475 .49978 L .64838 .52401 L p .969 .687 .442 r
F P
0 g
s
.63454 .48513 m .6475 .49978 L .64838 .52401 L p .969 .687 .442 r
F P
0 g
s
.52893 .47957 m .5289 .45555 L .50323 .46362 L p .556 .341 .544 r
F P
0 g
s
.50323 .46362 m .50308 .48759 L .52893 .47957 L p .556 .341 .544 r
F P
0 g
s
.5289 .45555 m .50323 .46362 L .48903 .44866 L p .66 .747 .915 r
F P
0 g
s
.52893 .47957 m .5289 .45555 L .50323 .46362 L p .556 .341 .544 r
F P
0 g
s
.50323 .46362 m .50308 .48759 L .52893 .47957 L p .556 .341 .544 r
F P
0 g
s
.46345 .4568 m .48903 .44866 L .50323 .46362 L p .66 .747 .915 r
F P
0 g
s
.48903 .44866 m .50323 .46362 L .50308 .48759 L p .959 .688 .477 r
F P
0 g
s
.48903 .44866 m .50323 .46362 L .50308 .48759 L p .959 .688 .477 r
F P
0 g
s
.59708 .58876 m .59656 .56395 L .57057 .57153 L p .564 .353 .553 r
F P
0 g
s
.57057 .57153 m .5709 .59628 L .59708 .58876 L p .564 .353 .553 r
F P
0 g
s
.59656 .56395 m .57057 .57153 L .55695 .55749 L p .654 .754 .923 r
F P
0 g
s
.59708 .58876 m .59656 .56395 L .57057 .57153 L p .564 .353 .553 r
F P
0 g
s
.57057 .57153 m .5709 .59628 L .59708 .58876 L p .564 .353 .553 r
F P
0 g
s
.53104 .56512 m .55695 .55749 L .57057 .57153 L p .654 .754 .923 r
F P
0 g
s
.55695 .55749 m .57057 .57153 L .5709 .59628 L p .962 .688 .469 r
F P
0 g
s
.55695 .55749 m .57057 .57153 L .5709 .59628 L p .962 .688 .469 r
F P
0 g
s
.42625 .53535 m .41139 .521 L .41219 .49675 L p .952 .687 .499 r
F P
0 g
s
.45157 .52761 m .42625 .53535 L .41139 .521 L p .656 .751 .92 r
F P
0 g
s
.38616 .52881 m .41139 .521 L .42625 .53535 L p .656 .751 .92 r
F P
0 g
s
.41139 .521 m .42625 .53535 L .42555 .55984 L p .952 .687 .499 r
F P
0 g
s
.96172 .45493 m .93405 .463 L .92354 .44803 L p .66 .747 .915 r
F P
0 g
s
.96486 .47895 m .96172 .45493 L .93405 .463 L p .573 .367 .563 r
F P
0 g
s
.93405 .463 m .93697 .48698 L .96486 .47895 L p .573 .367 .563 r
F P
0 g
s
.89594 .45617 m .92354 .44803 L .93405 .463 L p .66 .747 .915 r
F P
0 g
s
.92354 .44803 m .93405 .463 L .93697 .48698 L p .975 .668 .327 r
F P
0 g
s
.92354 .44803 m .93405 .463 L .93697 .48698 L p .975 .668 .327 r
F P
0 g
s
.49359 .64332 m .4793 .62989 L .47962 .60486 L p .954 .688 .492 r
F P
0 g
s
.49359 .64332 m .4793 .62989 L .47962 .60486 L p .954 .688 .492 r
F P
0 g
s
.51923 .63608 m .49359 .64332 L .4793 .62989 L p .649 .759 .929 r
F P
0 g
s
.45375 .63719 m .4793 .62989 L .49359 .64332 L p .649 .759 .929 r
F P
0 g
s
.67384 .49188 m .70042 .4839 L .71282 .49857 L p .658 .749 .917 r
F P
0 g
s
.71282 .49857 m .70042 .4839 L .69917 .45991 L p .972 .685 .422 r
F P
0 g
s
.5289 .45555 m .5548 .4474 L .56845 .46239 L p .66 .747 .915 r
F P
0 g
s
.5548 .4474 m .56845 .46239 L .56876 .48636 L p .964 .688 .461 r
F P
0 g
s
.63586 .57037 m .62279 .55631 L .62209 .53179 L p .966 .687 .452 r
F P
0 g
s
.63586 .57037 m .62279 .55631 L .62209 .53179 L p .966 .687 .452 r
F P
0 g
s
.66217 .56278 m .63586 .57037 L .62279 .55631 L p .654 .754 .923 r
F P
0 g
s
.66316 .5876 m .66217 .56278 L .63586 .57037 L p .566 .356 .555 r
F P
0 g
s
.63586 .57037 m .63666 .59512 L .66316 .5876 L p .566 .356 .555 r
F P
0 g
s
.59656 .56395 m .62279 .55631 L .63586 .57037 L p .654 .754 .923 r
F P
0 g
s
.59656 .56395 m .62279 .55631 L .63586 .57037 L p .654 .754 .923 r
F P
0 g
s
.62279 .55631 m .63586 .57037 L .63666 .59512 L p .966 .687 .452 r
F P
0 g
s
.66217 .56278 m .63586 .57037 L .62279 .55631 L p .654 .754 .923 r
F P
0 g
s
.62279 .55631 m .63586 .57037 L .63666 .59512 L p .966 .687 .452 r
F P
0 g
s
.51703 .55097 m .51708 .52641 L .49144 .53417 L p .558 .345 .547 r
F P
0 g
s
.49144 .53417 m .4912 .55867 L .51703 .55097 L p .558 .345 .547 r
F P
0 g
s
.49144 .53417 m .47713 .5198 L .47747 .49554 L p .957 .688 .485 r
F P
0 g
s
.49144 .53417 m .47713 .5198 L .47747 .49554 L p .957 .688 .485 r
F P
0 g
s
.51708 .52641 m .49144 .53417 L .47713 .5198 L p .656 .751 .92 r
F P
0 g
s
.51703 .55097 m .51708 .52641 L .49144 .53417 L p .558 .345 .547 r
F P
0 g
s
.49144 .53417 m .4912 .55867 L .51703 .55097 L p .558 .345 .547 r
F P
0 g
s
.45157 .52761 m .47713 .5198 L .49144 .53417 L p .656 .751 .92 r
F P
0 g
s
.45157 .52761 m .47713 .5198 L .49144 .53417 L p .656 .751 .92 r
F P
0 g
s
.47713 .5198 m .49144 .53417 L .4912 .55867 L p .957 .688 .485 r
F P
0 g
s
.51708 .52641 m .49144 .53417 L .47713 .5198 L p .656 .751 .92 r
F P
0 g
s
.47713 .5198 m .49144 .53417 L .4912 .55867 L p .957 .688 .485 r
F P
0 g
s
.34702 .49797 m .33146 .48328 L .33284 .45929 L p .946 .686 .511 r
F P
0 g
s
.37199 .49004 m .34702 .49797 L .33146 .48328 L p .658 .749 .917 r
F P
0 g
s
.41438 .606 m .3994 .59224 L .40029 .56746 L p .949 .687 .505 r
F P
0 g
s
.43967 .59857 m .41438 .606 L .3994 .59224 L p .652 .756 .926 r
F P
0 g
s
.59444 .4543 m .62067 .44614 L .63376 .46115 L p .66 .747 .915 r
F P
0 g
s
.62067 .44614 m .63376 .46115 L .63454 .48513 L p .969 .687 .442 r
F P
0 g
s
.55672 .53298 m .54296 .51859 L .54283 .49432 L p .962 .688 .469 r
F P
0 g
s
.55672 .53298 m .54296 .51859 L .54283 .49432 L p .962 .688 .469 r
F P
0 g
s
.58268 .52521 m .55672 .53298 L .54296 .51859 L p .656 .751 .92 r
F P
0 g
s
.5831 .54978 m .58268 .52521 L .55672 .53298 L p .561 .349 .55 r
F P
0 g
s
.55672 .53298 m .55695 .55749 L .5831 .54978 L p .561 .349 .55 r
F P
0 g
s
.51708 .52641 m .54296 .51859 L .55672 .53298 L p .656 .751 .92 r
F P
0 g
s
.51708 .52641 m .54296 .51859 L .55672 .53298 L p .656 .751 .92 r
F P
0 g
s
.54296 .51859 m .55672 .53298 L .55695 .55749 L p .962 .688 .469 r
F P
0 g
s
.58268 .52521 m .55672 .53298 L .54296 .51859 L p .656 .751 .92 r
F P
0 g
s
.54296 .51859 m .55672 .53298 L .55695 .55749 L p .962 .688 .469 r
F P
0 g
s
.43686 .51313 m .43749 .48882 L .41219 .49675 L p .553 .337 .541 r
F P
0 g
s
.41219 .49675 m .41139 .521 L .43686 .51313 L p .553 .337 .541 r
F P
0 g
s
.41219 .49675 m .39719 .48205 L .3981 .45804 L p .952 .687 .499 r
F P
0 g
s
.43749 .48882 m .41219 .49675 L .39719 .48205 L p .658 .749 .917 r
F P
0 g
s
.43686 .51313 m .43749 .48882 L .41219 .49675 L p .553 .337 .541 r
F P
0 g
s
.41219 .49675 m .41139 .521 L .43686 .51313 L p .553 .337 .541 r
F P
0 g
s
.37199 .49004 m .39719 .48205 L .41219 .49675 L p .658 .749 .917 r
F P
0 g
s
.39719 .48205 m .41219 .49675 L .41139 .521 L p .952 .687 .499 r
F P
0 g
s
.5051 .62252 m .50524 .59743 L .47962 .60486 L p .561 .349 .55 r
F P
0 g
s
.47962 .60486 m .4793 .62989 L .5051 .62252 L p .561 .349 .55 r
F P
0 g
s
.47962 .60486 m .4652 .59108 L .46562 .56629 L p .954 .688 .492 r
F P
0 g
s
.50524 .59743 m .47962 .60486 L .4652 .59108 L p .652 .756 .926 r
F P
0 g
s
.5051 .62252 m .50524 .59743 L .47962 .60486 L p .561 .349 .55 r
F P
0 g
s
.47962 .60486 m .4793 .62989 L .5051 .62252 L p .561 .349 .55 r
F P
0 g
s
.43967 .59857 m .4652 .59108 L .47962 .60486 L p .652 .756 .926 r
F P
0 g
s
.43967 .59857 m .4652 .59108 L .47962 .60486 L p .652 .756 .926 r
F P
0 g
s
.4652 .59108 m .47962 .60486 L .4793 .62989 L p .954 .688 .492 r
F P
0 g
s
.4652 .59108 m .47962 .60486 L .4793 .62989 L p .954 .688 .492 r
F P
0 g
s
.84374 .49615 m .83245 .48143 L .83026 .45742 L p .976 .678 .372 r
F P
0 g
s
.84374 .49615 m .83245 .48143 L .83026 .45742 L p .976 .678 .372 r
F P
0 g
s
.87105 .48821 m .84374 .49615 L .83245 .48143 L p .658 .749 .917 r
F P
0 g
s
.87354 .51252 m .87105 .48821 L .84374 .49615 L p .571 .363 .56 r
F P
0 g
s
.84374 .49615 m .84603 .5204 L .87354 .51252 L p .571 .363 .56 r
F P
0 g
s
.80522 .48943 m .83245 .48143 L .84374 .49615 L p .658 .749 .917 r
F P
0 g
s
.80522 .48943 m .83245 .48143 L .84374 .49615 L p .658 .749 .917 r
F P
0 g
s
.83245 .48143 m .84374 .49615 L .84603 .5204 L p .976 .678 .372 r
F P
0 g
s
.87105 .48821 m .84374 .49615 L .83245 .48143 L p .658 .749 .917 r
F P
0 g
s
.83245 .48143 m .84374 .49615 L .84603 .5204 L p .976 .678 .372 r
F P
0 g
s
.7258 .4518 m .69917 .45991 L .68663 .44488 L p .66 .747 .915 r
F P
0 g
s
.72725 .47585 m .7258 .4518 L .69917 .45991 L p .564 .353 .553 r
F P
0 g
s
.69917 .45991 m .70042 .4839 L .72725 .47585 L p .564 .353 .553 r
F P
0 g
s
.68663 .44488 m .69917 .45991 L .70042 .4839 L p .972 .685 .422 r
F P
0 g
s
.64927 .54859 m .64838 .52401 L .62209 .53179 L p .564 .353 .553 r
F P
0 g
s
.62209 .53179 m .62279 .55631 L .64927 .54859 L p .564 .353 .553 r
F P
0 g
s
.62209 .53179 m .60889 .51738 L .60829 .4931 L p .966 .687 .452 r
F P
0 g
s
.62209 .53179 m .60889 .51738 L .60829 .4931 L p .966 .687 .452 r
F P
0 g
s
.64838 .52401 m .62209 .53179 L .60889 .51738 L p .656 .751 .92 r
F P
0 g
s
.64927 .54859 m .64838 .52401 L .62209 .53179 L p .564 .353 .553 r
F P
0 g
s
.62209 .53179 m .62279 .55631 L .64927 .54859 L p .564 .353 .553 r
F P
0 g
s
.58268 .52521 m .60889 .51738 L .62209 .53179 L p .656 .751 .92 r
F P
0 g
s
.60889 .51738 m .62209 .53179 L .62279 .55631 L p .966 .687 .452 r
F P
0 g
s
.64838 .52401 m .62209 .53179 L .60889 .51738 L p .656 .751 .92 r
F P
0 g
s
.50292 .51191 m .50308 .48759 L .47747 .49554 L p .556 .341 .544 r
F P
0 g
s
.47747 .49554 m .47713 .5198 L .50292 .51191 L p .556 .341 .544 r
F P
0 g
s
.47747 .49554 m .46301 .48081 L .46345 .4568 L p .957 .688 .485 r
F P
0 g
s
.50308 .48759 m .47747 .49554 L .46301 .48081 L p .658 .749 .917 r
F P
0 g
s
.43749 .48882 m .46301 .48081 L .47747 .49554 L p .658 .749 .917 r
F P
0 g
s
.46301 .48081 m .47747 .49554 L .47713 .5198 L p .957 .688 .485 r
F P
0 g
s
.35658 .47523 m .35778 .45117 L .33284 .45929 L p .547 .329 .535 r
F P
0 g
s
.33284 .45929 m .33146 .48328 L .35658 .47523 L p .547 .329 .535 r
F P
0 g
s
.54497 .60372 m .53109 .58992 L .53104 .56512 L p .959 .688 .477 r
F P
0 g
s
.54497 .60372 m .53109 .58992 L .53104 .56512 L p .959 .688 .477 r
F P
0 g
s
.5709 .59628 m .54497 .60372 L .53109 .58992 L p .652 .756 .926 r
F P
0 g
s
.50524 .59743 m .53109 .58992 L .54497 .60372 L p .652 .756 .926 r
F P
0 g
s
.42484 .58469 m .42555 .55984 L .40029 .56746 L p .556 .341 .544 r
F P
0 g
s
.40029 .56746 m .3994 .59224 L .42484 .58469 L p .556 .341 .544 r
F P
0 g
s
.40029 .56746 m .38516 .55335 L .38616 .52881 L p .949 .687 .505 r
F P
0 g
s
.42555 .55984 m .40029 .56746 L .38516 .55335 L p .654 .754 .923 r
F P
0 g
s
.42484 .58469 m .42555 .55984 L .40029 .56746 L p .556 .341 .544 r
F P
0 g
s
.40029 .56746 m .3994 .59224 L .42484 .58469 L p .556 .341 .544 r
F P
0 g
s
.38516 .55335 m .40029 .56746 L .3994 .59224 L p .949 .687 .505 r
F P
0 g
s
.42555 .55984 m .40029 .56746 L .38516 .55335 L p .654 .754 .923 r
F P
0 g
s
.90934 .49493 m .8986 .48019 L .89594 .45617 L p .976 .672 .343 r
F P
0 g
s
.93697 .48698 m .90934 .49493 L .8986 .48019 L p .658 .749 .917 r
F P
0 g
s
.79162 .45055 m .76466 .45866 L .75268 .44362 L p .66 .747 .915 r
F P
0 g
s
.79354 .4746 m .79162 .45055 L .76466 .45866 L p .566 .356 .555 r
F P
0 g
s
.76466 .45866 m .76638 .48267 L .79354 .4746 L p .566 .356 .555 r
F P
0 g
s
.75268 .44362 m .76466 .45866 L .76638 .48267 L p .975 .682 .398 r
F P
0 g
s
.68756 .5306 m .67491 .51616 L .67384 .49188 L p .971 .686 .432 r
F P
0 g
s
.71417 .52281 m .68756 .5306 L .67491 .51616 L p .656 .751 .92 r
F P
0 g
s
.71553 .54739 m .71417 .52281 L .68756 .5306 L p .566 .356 .555 r
F P
0 g
s
.68756 .5306 m .68873 .55512 L .71553 .54739 L p .566 .356 .555 r
F P
0 g
s
.64838 .52401 m .67491 .51616 L .68756 .5306 L p .656 .751 .92 r
F P
0 g
s
.64838 .52401 m .67491 .51616 L .68756 .5306 L p .656 .751 .92 r
F P
0 g
s
.67491 .51616 m .68756 .5306 L .68873 .55512 L p .971 .686 .432 r
F P
0 g
s
.67491 .51616 m .68756 .5306 L .68873 .55512 L p .971 .686 .432 r
F P
0 g
s
.56908 .51069 m .56876 .48636 L .54283 .49432 L p .558 .345 .547 r
F P
0 g
s
.54283 .49432 m .54296 .51859 L .56908 .51069 L p .558 .345 .547 r
F P
0 g
s
.54283 .49432 m .52893 .47957 L .5289 .45555 L p .962 .688 .469 r
F P
0 g
s
.54283 .49432 m .52893 .47957 L .5289 .45555 L p .962 .688 .469 r
F P
0 g
s
.56876 .48636 m .54283 .49432 L .52893 .47957 L p .658 .749 .917 r
F P
0 g
s
.50308 .48759 m .52893 .47957 L .54283 .49432 L p .658 .749 .917 r
F P
0 g
s
.35778 .45117 m .38295 .44298 L .3981 .45804 L p .66 .747 .915 r
F P
0 g
s
.38295 .44298 m .3981 .45804 L .39719 .48205 L p .952 .687 .499 r
F P
0 g
s
.6104 .60258 m .59708 .58876 L .59656 .56395 L p .964 .688 .461 r
F P
0 g
s
.6104 .60258 m .59708 .58876 L .59656 .56395 L p .964 .688 .461 r
F P
0 g
s
.63666 .59512 m .6104 .60258 L .59708 .58876 L p .652 .756 .926 r
F P
0 g
s
.5709 .59628 m .59708 .58876 L .6104 .60258 L p .652 .756 .926 r
F P
0 g
s
.46562 .56629 m .45105 .55216 L .45157 .52761 L p .954 .688 .492 r
F P
0 g
s
.4912 .55867 m .46562 .56629 L .45105 .55216 L p .654 .754 .923 r
F P
0 g
s
.42555 .55984 m .45105 .55216 L .46562 .56629 L p .654 .754 .923 r
F P
0 g
s
.45105 .55216 m .46562 .56629 L .4652 .59108 L p .954 .688 .492 r
F P
0 g
s
.85993 .47336 m .85754 .44929 L .83026 .45742 L p .569 .36 .558 r
F P
0 g
s
.83026 .45742 m .83245 .48143 L .85993 .47336 L p .569 .36 .558 r
F P
0 g
s
.85754 .44929 m .83026 .45742 L .81883 .44235 L p .66 .747 .915 r
F P
0 g
s
.85993 .47336 m .85754 .44929 L .83026 .45742 L p .569 .36 .558 r
F P
0 g
s
.83026 .45742 m .83245 .48143 L .85993 .47336 L p .569 .36 .558 r
F P
0 g
s
.79162 .45055 m .81883 .44235 L .83026 .45742 L p .66 .747 .915 r
F P
0 g
s
.81883 .44235 m .83026 .45742 L .83245 .48143 L p .976 .678 .372 r
F P
0 g
s
.81883 .44235 m .83026 .45742 L .83245 .48143 L p .976 .678 .372 r
F P
0 g
s
.63533 .50947 m .63454 .48513 L .60829 .4931 L p .561 .349 .55 r
F P
0 g
s
.60829 .4931 m .60889 .51738 L .63533 .50947 L p .561 .349 .55 r
F P
0 g
s
.60829 .4931 m .59494 .47833 L .59444 .4543 L p .966 .687 .452 r
F P
0 g
s
.63454 .48513 m .60829 .4931 L .59494 .47833 L p .658 .749 .917 r
F P
0 g
s
.63533 .50947 m .63454 .48513 L .60829 .4931 L p .561 .349 .55 r
F P
0 g
s
.60829 .4931 m .60889 .51738 L .63533 .50947 L p .561 .349 .55 r
F P
0 g
s
.56876 .48636 m .59494 .47833 L .60829 .4931 L p .658 .749 .917 r
F P
0 g
s
.59494 .47833 m .60829 .4931 L .60889 .51738 L p .966 .687 .452 r
F P
0 g
s
.63454 .48513 m .60829 .4931 L .59494 .47833 L p .658 .749 .917 r
F P
0 g
s
.59494 .47833 m .60829 .4931 L .60889 .51738 L p .966 .687 .452 r
F P
0 g
s
.48878 .47273 m .48903 .44866 L .46345 .4568 L p .553 .337 .541 r
F P
0 g
s
.46345 .4568 m .46301 .48081 L .48878 .47273 L p .553 .337 .541 r
F P
0 g
s
.48903 .44866 m .46345 .4568 L .44886 .44172 L p .66 .747 .915 r
F P
0 g
s
.48878 .47273 m .48903 .44866 L .46345 .4568 L p .553 .337 .541 r
F P
0 g
s
.46345 .4568 m .46301 .48081 L .48878 .47273 L p .553 .337 .541 r
F P
0 g
s
.44886 .44172 m .46345 .4568 L .46301 .48081 L p .957 .688 .485 r
F P
0 g
s
.55718 .58235 m .55695 .55749 L .53104 .56512 L p .561 .349 .55 r
F P
0 g
s
.53104 .56512 m .53109 .58992 L .55718 .58235 L p .561 .349 .55 r
F P
0 g
s
.53104 .56512 m .51703 .55097 L .51708 .52641 L p .959 .688 .477 r
F P
0 g
s
.53104 .56512 m .51703 .55097 L .51708 .52641 L p .959 .688 .477 r
F P
0 g
s
.55695 .55749 m .53104 .56512 L .51703 .55097 L p .654 .754 .923 r
F P
0 g
s
.55718 .58235 m .55695 .55749 L .53104 .56512 L p .561 .349 .55 r
F P
0 g
s
.53104 .56512 m .53109 .58992 L .55718 .58235 L p .561 .349 .55 r
F P
0 g
s
.4912 .55867 m .51703 .55097 L .53104 .56512 L p .654 .754 .923 r
F P
0 g
s
.51703 .55097 m .53104 .56512 L .53109 .58992 L p .959 .688 .477 r
F P
0 g
s
.55695 .55749 m .53104 .56512 L .51703 .55097 L p .654 .754 .923 r
F P
0 g
s
.41057 .5456 m .41139 .521 L .38616 .52881 L p .553 .337 .541 r
F P
0 g
s
.38616 .52881 m .38516 .55335 L .41057 .5456 L p .553 .337 .541 r
F P
0 g
s
.41139 .521 m .38616 .52881 L .37089 .51434 L p .656 .751 .92 r
F P
0 g
s
.41057 .5456 m .41139 .521 L .38616 .52881 L p .553 .337 .541 r
F P
0 g
s
.38616 .52881 m .38516 .55335 L .41057 .5456 L p .553 .337 .541 r
F P
0 g
s
.37089 .51434 m .38616 .52881 L .38516 .55335 L p .949 .687 .505 r
F P
0 g
s
.92642 .47211 m .92354 .44803 L .89594 .45617 L p .571 .363 .56 r
F P
0 g
s
.89594 .45617 m .8986 .48019 L .92642 .47211 L p .571 .363 .56 r
F P
0 g
s
.92354 .44803 m .89594 .45617 L .88507 .44108 L p .66 .747 .915 r
F P
0 g
s
.92642 .47211 m .92354 .44803 L .89594 .45617 L p .571 .363 .56 r
F P
0 g
s
.89594 .45617 m .8986 .48019 L .92642 .47211 L p .571 .363 .56 r
F P
0 g
s
.85754 .44929 m .88507 .44108 L .89594 .45617 L p .66 .747 .915 r
F P
0 g
s
.88507 .44108 m .89594 .45617 L .8986 .48019 L p .976 .672 .343 r
F P
0 g
s
.88507 .44108 m .89594 .45617 L .8986 .48019 L p .976 .672 .343 r
F P
0 g
s
.45375 .63719 m .43906 .62366 L .43967 .59857 L p .952 .687 .499 r
F P
0 g
s
.4793 .62989 m .45375 .63719 L .43906 .62366 L p .649 .759 .929 r
F P
0 g
s
.81877 .52821 m .80723 .51373 L .80522 .48943 L p .976 .68 .386 r
F P
0 g
s
.84603 .5204 m .81877 .52821 L .80723 .51373 L p .656 .751 .92 r
F P
0 g
s
.70042 .4839 m .67384 .49188 L .66104 .47709 L p .658 .749 .917 r
F P
0 g
s
.70168 .50824 m .70042 .4839 L .67384 .49188 L p .564 .353 .553 r
F P
0 g
s
.67384 .49188 m .67491 .51616 L .70168 .50824 L p .564 .353 .553 r
F P
0 g
s
.63454 .48513 m .66104 .47709 L .67384 .49188 L p .658 .749 .917 r
F P
0 g
s
.66104 .47709 m .67384 .49188 L .67491 .51616 L p .971 .686 .432 r
F P
0 g
s
.66104 .47709 m .67384 .49188 L .67491 .51616 L p .971 .686 .432 r
F P
0 g
s
.55502 .47148 m .5548 .4474 L .5289 .45555 L p .556 .341 .544 r
F P
0 g
s
.5289 .45555 m .52893 .47957 L .55502 .47148 L p .556 .341 .544 r
F P
0 g
s
.5548 .4474 m .5289 .45555 L .51486 .44045 L p .66 .747 .915 r
F P
0 g
s
.55502 .47148 m .5548 .4474 L .5289 .45555 L p .556 .341 .544 r
F P
0 g
s
.5289 .45555 m .52893 .47957 L .55502 .47148 L p .556 .341 .544 r
F P
0 g
s
.48903 .44866 m .51486 .44045 L .5289 .45555 L p .66 .747 .915 r
F P
0 g
s
.51486 .44045 m .5289 .45555 L .52893 .47957 L p .962 .688 .469 r
F P
0 g
s
.51486 .44045 m .5289 .45555 L .52893 .47957 L p .962 .688 .469 r
F P
0 g
s
.6235 .58118 m .62279 .55631 L .59656 .56395 L p .564 .353 .553 r
F P
0 g
s
.59656 .56395 m .59708 .58876 L .6235 .58118 L p .564 .353 .553 r
F P
0 g
s
.62279 .55631 m .59656 .56395 L .5831 .54978 L p .654 .754 .923 r
F P
0 g
s
.6235 .58118 m .62279 .55631 L .59656 .56395 L p .564 .353 .553 r
F P
0 g
s
.59656 .56395 m .59708 .58876 L .6235 .58118 L p .564 .353 .553 r
F P
0 g
s
.55695 .55749 m .5831 .54978 L .59656 .56395 L p .654 .754 .923 r
F P
0 g
s
.5831 .54978 m .59656 .56395 L .59708 .58876 L p .964 .688 .461 r
F P
0 g
s
.5831 .54978 m .59656 .56395 L .59708 .58876 L p .964 .688 .461 r
F P
0 g
s
.47679 .5444 m .47713 .5198 L .45157 .52761 L p .556 .341 .544 r
F P
0 g
s
.45157 .52761 m .45105 .55216 L .47679 .5444 L p .556 .341 .544 r
F P
0 g
s
.45157 .52761 m .43686 .51313 L .43749 .48882 L p .954 .688 .492 r
F P
0 g
s
.45157 .52761 m .43686 .51313 L .43749 .48882 L p .954 .688 .492 r
F P
0 g
s
.47713 .5198 m .45157 .52761 L .43686 .51313 L p .656 .751 .92 r
F P
0 g
s
.47679 .5444 m .47713 .5198 L .45157 .52761 L p .556 .341 .544 r
F P
0 g
s
.45157 .52761 m .45105 .55216 L .47679 .5444 L p .556 .341 .544 r
F P
0 g
s
.41139 .521 m .43686 .51313 L .45157 .52761 L p .656 .751 .92 r
F P
0 g
s
.43686 .51313 m .45157 .52761 L .45105 .55216 L p .954 .688 .492 r
F P
0 g
s
.47713 .5198 m .45157 .52761 L .43686 .51313 L p .656 .751 .92 r
F P
0 g
s
.92354 .44803 m .95141 .43982 L .96172 .45493 L p .66 .747 .915 r
F P
0 g
s
.95141 .43982 m .96172 .45493 L .96486 .47895 L p .973 .663 .31 r
F P
0 g
s
.4793 .62989 m .5051 .62252 L .51923 .63608 L p .649 .759 .929 r
F P
0 g
s
.51923 .63608 m .5051 .62252 L .50524 .59743 L p .957 .688 .485 r
F P
0 g
s
.62136 .47023 m .62067 .44614 L .59444 .4543 L p .558 .345 .547 r
F P
0 g
s
.59444 .4543 m .59494 .47833 L .62136 .47023 L p .558 .345 .547 r
F P
0 g
s
.62067 .44614 m .59444 .4543 L .58095 .43918 L p .66 .747 .915 r
F P
0 g
s
.62136 .47023 m .62067 .44614 L .59444 .4543 L p .558 .345 .547 r
F P
0 g
s
.59444 .4543 m .59494 .47833 L .62136 .47023 L p .558 .345 .547 r
F P
0 g
s
.58095 .43918 m .59444 .4543 L .59494 .47833 L p .966 .687 .452 r
F P
0 g
s
.66217 .56278 m .64927 .54859 L .64838 .52401 L p .969 .687 .442 r
F P
0 g
s
.66217 .56278 m .64927 .54859 L .64838 .52401 L p .969 .687 .442 r
F P
0 g
s
.68873 .55512 m .66217 .56278 L .64927 .54859 L p .654 .754 .923 r
F P
0 g
s
.68991 .58 m .68873 .55512 L .66217 .56278 L p .566 .356 .555 r
F P
0 g
s
.66217 .56278 m .66316 .5876 L .68991 .58 L p .566 .356 .555 r
F P
0 g
s
.62279 .55631 m .64927 .54859 L .66217 .56278 L p .654 .754 .923 r
F P
0 g
s
.62279 .55631 m .64927 .54859 L .66217 .56278 L p .654 .754 .923 r
F P
0 g
s
.64927 .54859 m .66217 .56278 L .66316 .5876 L p .969 .687 .442 r
F P
0 g
s
.68873 .55512 m .66217 .56278 L .64927 .54859 L p .654 .754 .923 r
F P
0 g
s
.64927 .54859 m .66217 .56278 L .66316 .5876 L p .969 .687 .442 r
F P
0 g
s
.54309 .5432 m .54296 .51859 L .51708 .52641 L p .558 .345 .547 r
F P
0 g
s
.51708 .52641 m .51703 .55097 L .54309 .5432 L p .558 .345 .547 r
F P
0 g
s
.51708 .52641 m .50292 .51191 L .50308 .48759 L p .959 .688 .477 r
F P
0 g
s
.54296 .51859 m .51708 .52641 L .50292 .51191 L p .656 .751 .92 r
F P
0 g
s
.54309 .5432 m .54296 .51859 L .51708 .52641 L p .558 .345 .547 r
F P
0 g
s
.51708 .52641 m .51703 .55097 L .54309 .5432 L p .558 .345 .547 r
F P
0 g
s
.47713 .5198 m .50292 .51191 L .51708 .52641 L p .656 .751 .92 r
F P
0 g
s
.47713 .5198 m .50292 .51191 L .51708 .52641 L p .656 .751 .92 r
F P
0 g
s
.50292 .51191 m .51708 .52641 L .51703 .55097 L p .959 .688 .477 r
F P
0 g
s
.50292 .51191 m .51708 .52641 L .51703 .55097 L p .959 .688 .477 r
F P
0 g
s
.37199 .49004 m .35658 .47523 L .35778 .45117 L p .949 .687 .505 r
F P
0 g
s
.37199 .49004 m .35658 .47523 L .35778 .45117 L p .949 .687 .505 r
F P
0 g
s
.39719 .48205 m .37199 .49004 L .35658 .47523 L p .658 .749 .917 r
F P
0 g
s
.39627 .5064 m .39719 .48205 L .37199 .49004 L p .55 .333 .538 r
F P
0 g
s
.37199 .49004 m .37089 .51434 L .39627 .5064 L p .55 .333 .538 r
F P
0 g
s
.33146 .48328 m .35658 .47523 L .37199 .49004 L p .658 .749 .917 r
F P
0 g
s
.35658 .47523 m .37199 .49004 L .37089 .51434 L p .949 .687 .505 r
F P
0 g
s
.39719 .48205 m .37199 .49004 L .35658 .47523 L p .658 .749 .917 r
F P
0 g
s
.46477 .61623 m .4652 .59108 L .43967 .59857 L p .558 .345 .547 r
F P
0 g
s
.43967 .59857 m .43906 .62366 L .46477 .61623 L p .558 .345 .547 r
F P
0 g
s
.43967 .59857 m .42484 .58469 L .42555 .55984 L p .952 .687 .499 r
F P
0 g
s
.43967 .59857 m .42484 .58469 L .42555 .55984 L p .952 .687 .499 r
F P
0 g
s
.4652 .59108 m .43967 .59857 L .42484 .58469 L p .652 .756 .926 r
F P
0 g
s
.3994 .59224 m .42484 .58469 L .43967 .59857 L p .652 .756 .926 r
F P
0 g
s
.83467 .50579 m .83245 .48143 L .80522 .48943 L p .569 .36 .558 r
F P
0 g
s
.80522 .48943 m .80723 .51373 L .83467 .50579 L p .569 .36 .558 r
F P
0 g
s
.80522 .48943 m .79354 .4746 L .79162 .45055 L p .976 .68 .386 r
F P
0 g
s
.83245 .48143 m .80522 .48943 L .79354 .4746 L p .658 .749 .917 r
F P
0 g
s
.83467 .50579 m .83245 .48143 L .80522 .48943 L p .569 .36 .558 r
F P
0 g
s
.80522 .48943 m .80723 .51373 L .83467 .50579 L p .569 .36 .558 r
F P
0 g
s
.79354 .4746 m .80522 .48943 L .80723 .51373 L p .976 .68 .386 r
F P
0 g
s
.83245 .48143 m .80522 .48943 L .79354 .4746 L p .658 .749 .917 r
F P
0 g
s
.58268 .52521 m .56908 .51069 L .56876 .48636 L p .964 .688 .461 r
F P
0 g
s
.58268 .52521 m .56908 .51069 L .56876 .48636 L p .964 .688 .461 r
F P
0 g
s
.60889 .51738 m .58268 .52521 L .56908 .51069 L p .656 .751 .92 r
F P
0 g
s
.60949 .542 m .60889 .51738 L .58268 .52521 L p .561 .349 .55 r
F P
0 g
s
.58268 .52521 m .5831 .54978 L .60949 .542 L p .561 .349 .55 r
F P
0 g
s
.54296 .51859 m .56908 .51069 L .58268 .52521 L p .656 .751 .92 r
F P
0 g
s
.54296 .51859 m .56908 .51069 L .58268 .52521 L p .656 .751 .92 r
F P
0 g
s
.56908 .51069 m .58268 .52521 L .5831 .54978 L p .964 .688 .461 r
F P
0 g
s
.60889 .51738 m .58268 .52521 L .56908 .51069 L p .656 .751 .92 r
F P
0 g
s
.56908 .51069 m .58268 .52521 L .5831 .54978 L p .964 .688 .461 r
F P
0 g
s
.46257 .50517 m .46301 .48081 L .43749 .48882 L p .553 .337 .541 r
F P
0 g
s
.43749 .48882 m .43686 .51313 L .46257 .50517 L p .553 .337 .541 r
F P
0 g
s
.46301 .48081 m .43749 .48882 L .42263 .47398 L p .658 .749 .917 r
F P
0 g
s
.46257 .50517 m .46301 .48081 L .43749 .48882 L p .553 .337 .541 r
F P
0 g
s
.43749 .48882 m .43686 .51313 L .46257 .50517 L p .553 .337 .541 r
F P
0 g
s
.39719 .48205 m .42263 .47398 L .43749 .48882 L p .658 .749 .917 r
F P
0 g
s
.42263 .47398 m .43749 .48882 L .43686 .51313 L p .954 .688 .492 r
F P
0 g
s
.42263 .47398 m .43749 .48882 L .43686 .51313 L p .954 .688 .492 r
F P
0 g
s
.53109 .58992 m .50524 .59743 L .49096 .58352 L p .652 .756 .926 r
F P
0 g
s
.53114 .61508 m .53109 .58992 L .50524 .59743 L p .561 .349 .55 r
F P
0 g
s
.50524 .59743 m .5051 .62252 L .53114 .61508 L p .561 .349 .55 r
F P
0 g
s
.4652 .59108 m .49096 .58352 L .50524 .59743 L p .652 .756 .926 r
F P
0 g
s
.49096 .58352 m .50524 .59743 L .5051 .62252 L p .957 .688 .485 r
F P
0 g
s
.49096 .58352 m .50524 .59743 L .5051 .62252 L p .957 .688 .485 r
F P
0 g
s
.87105 .48821 m .85993 .47336 L .85754 .44929 L p .976 .675 .358 r
F P
0 g
s
.87105 .48821 m .85993 .47336 L .85754 .44929 L p .976 .675 .358 r
F P
0 g
s
.8986 .48019 m .87105 .48821 L .85993 .47336 L p .658 .749 .917 r
F P
0 g
s
.90131 .50456 m .8986 .48019 L .87105 .48821 L p .571 .363 .56 r
F P
0 g
s
.87105 .48821 m .87354 .51252 L .90131 .50456 L p .571 .363 .56 r
F P
0 g
s
.83245 .48143 m .85993 .47336 L .87105 .48821 L p .658 .749 .917 r
F P
0 g
s
.83245 .48143 m .85993 .47336 L .87105 .48821 L p .658 .749 .917 r
F P
0 g
s
.85993 .47336 m .87105 .48821 L .87354 .51252 L p .976 .675 .358 r
F P
0 g
s
.8986 .48019 m .87105 .48821 L .85993 .47336 L p .658 .749 .917 r
F P
0 g
s
.85993 .47336 m .87105 .48821 L .87354 .51252 L p .976 .675 .358 r
F P
0 g
s
.75268 .44362 m .7258 .4518 L .71343 .43663 L p .66 .747 .915 r
F P
0 g
s
.75433 .46772 m .75268 .44362 L .7258 .4518 L p .564 .353 .553 r
F P
0 g
s
.7258 .4518 m .72725 .47585 L .75433 .46772 L p .564 .353 .553 r
F P
0 g
s
.68663 .44488 m .71343 .43663 L .7258 .4518 L p .66 .747 .915 r
F P
0 g
s
.71343 .43663 m .7258 .4518 L .72725 .47585 L p .974 .684 .41 r
F P
0 g
s
.71343 .43663 m .7258 .4518 L .72725 .47585 L p .974 .684 .41 r
F P
0 g
s
.67599 .5408 m .67491 .51616 L .64838 .52401 L p .564 .353 .553 r
F P
0 g
s
.64838 .52401 m .64927 .54859 L .67599 .5408 L p .564 .353 .553 r
F P
0 g
s
.64838 .52401 m .63533 .50947 L .63454 .48513 L p .969 .687 .442 r
F P
0 g
s
.64838 .52401 m .63533 .50947 L .63454 .48513 L p .969 .687 .442 r
F P
0 g
s
.67491 .51616 m .64838 .52401 L .63533 .50947 L p .656 .751 .92 r
F P
0 g
s
.60889 .51738 m .63533 .50947 L .64838 .52401 L p .656 .751 .92 r
F P
0 g
s
.60889 .51738 m .63533 .50947 L .64838 .52401 L p .656 .751 .92 r
F P
0 g
s
.63533 .50947 m .64838 .52401 L .64927 .54859 L p .969 .687 .442 r
F P
0 g
s
.50308 .48759 m .48878 .47273 L .48903 .44866 L p .959 .688 .477 r
F P
0 g
s
.50308 .48759 m .48878 .47273 L .48903 .44866 L p .959 .688 .477 r
F P
0 g
s
.52893 .47957 m .50308 .48759 L .48878 .47273 L p .658 .749 .917 r
F P
0 g
s
.46301 .48081 m .48878 .47273 L .50308 .48759 L p .658 .749 .917 r
F P
0 g
s
.38193 .46709 m .38295 .44298 L .35778 .45117 L p .547 .329 .535 r
F P
0 g
s
.35778 .45117 m .35658 .47523 L .38193 .46709 L p .547 .329 .535 r
F P
0 g
s
.38295 .44298 m .35778 .45117 L .34222 .436 L p .66 .747 .915 r
F P
0 g
s
.38193 .46709 m .38295 .44298 L .35778 .45117 L p .547 .329 .535 r
F P
0 g
s
.35778 .45117 m .35658 .47523 L .38193 .46709 L p .547 .329 .535 r
F P
0 g
s
.34222 .436 m .35778 .45117 L .35658 .47523 L p .949 .687 .505 r
F P
0 g
s
.5709 .59628 m .55718 .58235 L .55695 .55749 L p .962 .688 .469 r
F P
0 g
s
.5709 .59628 m .55718 .58235 L .55695 .55749 L p .962 .688 .469 r
F P
0 g
s
.59708 .58876 m .5709 .59628 L .55718 .58235 L p .652 .756 .926 r
F P
0 g
s
.5976 .61393 m .59708 .58876 L .5709 .59628 L p .564 .353 .553 r
F P
0 g
s
.5709 .59628 m .57123 .62138 L .5976 .61393 L p .564 .353 .553 r
F P
0 g
s
.53109 .58992 m .55718 .58235 L .5709 .59628 L p .652 .756 .926 r
F P
0 g
s
.55718 .58235 m .5709 .59628 L .57123 .62138 L p .962 .688 .469 r
F P
0 g
s
.59708 .58876 m .5709 .59628 L .55718 .58235 L p .652 .756 .926 r
F P
0 g
s
.45052 .57706 m .45105 .55216 L .42555 .55984 L p .556 .341 .544 r
F P
0 g
s
.42555 .55984 m .42484 .58469 L .45052 .57706 L p .556 .341 .544 r
F P
0 g
s
.42555 .55984 m .41057 .5456 L .41139 .521 L p .952 .687 .499 r
F P
0 g
s
.45105 .55216 m .42555 .55984 L .41057 .5456 L p .654 .754 .923 r
F P
0 g
s
.45052 .57706 m .45105 .55216 L .42555 .55984 L p .556 .341 .544 r
F P
0 g
s
.42555 .55984 m .42484 .58469 L .45052 .57706 L p .556 .341 .544 r
F P
0 g
s
.38516 .55335 m .41057 .5456 L .42555 .55984 L p .654 .754 .923 r
F P
0 g
s
.38516 .55335 m .41057 .5456 L .42555 .55984 L p .654 .754 .923 r
F P
0 g
s
.41057 .5456 m .42555 .55984 L .42484 .58469 L p .952 .687 .499 r
F P
0 g
s
.41057 .5456 m .42555 .55984 L .42484 .58469 L p .952 .687 .499 r
F P
0 g
s
.93697 .48698 m .92642 .47211 L .92354 .44803 L p .975 .668 .327 r
F P
0 g
s
.93697 .48698 m .92642 .47211 L .92354 .44803 L p .975 .668 .327 r
F P
0 g
s
.96486 .47895 m .93697 .48698 L .92642 .47211 L p .658 .749 .917 r
F P
0 g
s
.8986 .48019 m .92642 .47211 L .93697 .48698 L p .658 .749 .917 r
F P
0 g
s
.82095 .46646 m .81883 .44235 L .79162 .45055 L p .566 .356 .555 r
F P
0 g
s
.79162 .45055 m .79354 .4746 L .82095 .46646 L p .566 .356 .555 r
F P
0 g
s
.75268 .44362 m .77981 .43536 L .79162 .45055 L p .66 .747 .915 r
F P
0 g
s
.77981 .43536 m .79162 .45055 L .79354 .4746 L p .976 .68 .386 r
F P
0 g
s
.74102 .51495 m .71417 .52281 L .70168 .50824 L p .656 .751 .92 r
F P
0 g
s
.74259 .53959 m .74102 .51495 L .71417 .52281 L p .566 .356 .555 r
F P
0 g
s
.71417 .52281 m .71553 .54739 L .74259 .53959 L p .566 .356 .555 r
F P
0 g
s
.67491 .51616 m .70168 .50824 L .71417 .52281 L p .656 .751 .92 r
F P
0 g
s
.70168 .50824 m .71417 .52281 L .71553 .54739 L p .972 .685 .422 r
F P
0 g
s
.70168 .50824 m .71417 .52281 L .71553 .54739 L p .972 .685 .422 r
F P
0 g
s
.59545 .50271 m .59494 .47833 L .56876 .48636 L p .558 .345 .547 r
F P
0 g
s
.56876 .48636 m .56908 .51069 L .59545 .50271 L p .558 .345 .547 r
F P
0 g
s
.56876 .48636 m .55502 .47148 L .5548 .4474 L p .964 .688 .461 r
F P
0 g
s
.59494 .47833 m .56876 .48636 L .55502 .47148 L p .658 .749 .917 r
F P
0 g
s
.59545 .50271 m .59494 .47833 L .56876 .48636 L p .558 .345 .547 r
F P
0 g
s
.56876 .48636 m .56908 .51069 L .59545 .50271 L p .558 .345 .547 r
F P
0 g
s
.52893 .47957 m .55502 .47148 L .56876 .48636 L p .658 .749 .917 r
F P
0 g
s
.55502 .47148 m .56876 .48636 L .56908 .51069 L p .964 .688 .461 r
F P
0 g
s
.63666 .59512 m .6235 .58118 L .62279 .55631 L p .966 .687 .452 r
F P
0 g
s
.63666 .59512 m .6235 .58118 L .62279 .55631 L p .966 .687 .452 r
F P
0 g
s
.66316 .5876 m .63666 .59512 L .6235 .58118 L p .652 .756 .926 r
F P
0 g
s
.59708 .58876 m .6235 .58118 L .63666 .59512 L p .652 .756 .926 r
F P
0 g
s
.4912 .55867 m .47679 .5444 L .47713 .5198 L p .957 .688 .485 r
F P
0 g
s
.4912 .55867 m .47679 .5444 L .47713 .5198 L p .957 .688 .485 r
F P
0 g
s
.51703 .55097 m .4912 .55867 L .47679 .5444 L p .654 .754 .923 r
F P
0 g
s
.51697 .57588 m .51703 .55097 L .4912 .55867 L p .558 .345 .547 r
F P
0 g
s
.4912 .55867 m .49096 .58352 L .51697 .57588 L p .558 .345 .547 r
F P
0 g
s
.45105 .55216 m .47679 .5444 L .4912 .55867 L p .654 .754 .923 r
F P
0 g
s
.47679 .5444 m .4912 .55867 L .49096 .58352 L p .957 .688 .485 r
F P
0 g
s
.51703 .55097 m .4912 .55867 L .47679 .5444 L p .654 .754 .923 r
F P
0 g
s
.88768 .4652 m .88507 .44108 L .85754 .44929 L p .569 .36 .558 r
F P
0 g
s
.85754 .44929 m .85993 .47336 L .88768 .4652 L p .569 .36 .558 r
F P
0 g
s
.88507 .44108 m .85754 .44929 L .84629 .43408 L p .66 .747 .915 r
F P
0 g
s
.88768 .4652 m .88507 .44108 L .85754 .44929 L p .569 .36 .558 r
F P
0 g
s
.85754 .44929 m .85993 .47336 L .88768 .4652 L p .569 .36 .558 r
F P
0 g
s
.81883 .44235 m .84629 .43408 L .85754 .44929 L p .66 .747 .915 r
F P
0 g
s
.84629 .43408 m .85754 .44929 L .85993 .47336 L p .976 .675 .358 r
F P
0 g
s
.84629 .43408 m .85754 .44929 L .85993 .47336 L p .976 .675 .358 r
F P
0 g
s
.66203 .50148 m .66104 .47709 L .63454 .48513 L p .561 .349 .55 r
F P
0 g
s
.63454 .48513 m .63533 .50947 L .66203 .50148 L p .561 .349 .55 r
F P
0 g
s
.63454 .48513 m .62136 .47023 L .62067 .44614 L p .969 .687 .442 r
F P
0 g
s
.66104 .47709 m .63454 .48513 L .62136 .47023 L p .658 .749 .917 r
F P
0 g
s
.66203 .50148 m .66104 .47709 L .63454 .48513 L p .561 .349 .55 r
F P
0 g
s
.63454 .48513 m .63533 .50947 L .66203 .50148 L p .561 .349 .55 r
F P
0 g
s
.59494 .47833 m .62136 .47023 L .63454 .48513 L p .658 .749 .917 r
F P
0 g
s
.59494 .47833 m .62136 .47023 L .63454 .48513 L p .658 .749 .917 r
F P
0 g
s
.62136 .47023 m .63454 .48513 L .63533 .50947 L p .969 .687 .442 r
F P
0 g
s
.62136 .47023 m .63454 .48513 L .63533 .50947 L p .969 .687 .442 r
F P
0 g
s
.51479 .46457 m .51486 .44045 L .48903 .44866 L p .553 .337 .541 r
F P
0 g
s
.48903 .44866 m .48878 .47273 L .51479 .46457 L p .553 .337 .541 r
F P
0 g
s
.51486 .44045 m .48903 .44866 L .47459 .43344 L p .66 .747 .915 r
F P
0 g
s
.51479 .46457 m .51486 .44045 L .48903 .44866 L p .553 .337 .541 r
F P
0 g
s
.48903 .44866 m .48878 .47273 L .51479 .46457 L p .553 .337 .541 r
F P
0 g
s
.44886 .44172 m .47459 .43344 L .48903 .44866 L p .66 .747 .915 r
F P
0 g
s
.47459 .43344 m .48903 .44866 L .48878 .47273 L p .959 .688 .477 r
F P
0 g
s
.47459 .43344 m .48903 .44866 L .48878 .47273 L p .959 .688 .477 r
F P
0 g
s
.58352 .5747 m .5831 .54978 L .55695 .55749 L p .561 .349 .55 r
F P
0 g
s
.55695 .55749 m .55718 .58235 L .58352 .5747 L p .561 .349 .55 r
F P
0 g
s
.55695 .55749 m .54309 .5432 L .54296 .51859 L p .962 .688 .469 r
F P
0 g
s
.55695 .55749 m .54309 .5432 L .54296 .51859 L p .962 .688 .469 r
F P
0 g
s
.5831 .54978 m .55695 .55749 L .54309 .5432 L p .654 .754 .923 r
F P
0 g
s
.51703 .55097 m .54309 .5432 L .55695 .55749 L p .654 .754 .923 r
F P
0 g
s
.51703 .55097 m .54309 .5432 L .55695 .55749 L p .654 .754 .923 r
F P
0 g
s
.54309 .5432 m .55695 .55749 L .55718 .58235 L p .962 .688 .469 r
F P
0 g
s
.41139 .521 m .39627 .5064 L .39719 .48205 L p .952 .687 .499 r
F P
0 g
s
.43686 .51313 m .41139 .521 L .39627 .5064 L p .656 .751 .92 r
F P
0 g
s
.37089 .51434 m .39627 .5064 L .41139 .521 L p .656 .751 .92 r
F P
0 g
s
.39627 .5064 m .41139 .521 L .41057 .5456 L p .952 .687 .499 r
F P
0 g
s
.9545 .46394 m .95141 .43982 L .92354 .44803 L p .571 .363 .56 r
F P
0 g
s
.92354 .44803 m .92642 .47211 L .9545 .46394 L p .571 .363 .56 r
F P
0 g
s
.95141 .43982 m .92354 .44803 L .91286 .4328 L p .66 .747 .915 r
F P
0 g
s
.9545 .46394 m .95141 .43982 L .92354 .44803 L p .571 .363 .56 r
F P
0 g
s
.92354 .44803 m .92642 .47211 L .9545 .46394 L p .571 .363 .56 r
F P
0 g
s
.88507 .44108 m .91286 .4328 L .92354 .44803 L p .66 .747 .915 r
F P
0 g
s
.91286 .4328 m .92354 .44803 L .92642 .47211 L p .975 .668 .327 r
F P
0 g
s
.91286 .4328 m .92354 .44803 L .92642 .47211 L p .975 .668 .327 r
F P
0 g
s
.4793 .62989 m .46477 .61623 L .4652 .59108 L p .954 .688 .492 r
F P
0 g
s
.4793 .62989 m .46477 .61623 L .4652 .59108 L p .954 .688 .492 r
F P
0 g
s
.5051 .62252 m .4793 .62989 L .46477 .61623 L p .649 .759 .929 r
F P
0 g
s
.43906 .62366 m .46477 .61623 L .4793 .62989 L p .649 .759 .929 r
F P
0 g
s
.84603 .5204 m .83467 .50579 L .83245 .48143 L p .976 .678 .372 r
F P
0 g
s
.84603 .5204 m .83467 .50579 L .83245 .48143 L p .976 .678 .372 r
F P
0 g
s
.87354 .51252 m .84603 .5204 L .83467 .50579 L p .656 .751 .92 r
F P
0 g
s
.80723 .51373 m .83467 .50579 L .84603 .5204 L p .656 .751 .92 r
F P
0 g
s
.70042 .4839 m .6878 .46897 L .68663 .44488 L p .972 .685 .422 r
F P
0 g
s
.72725 .47585 m .70042 .4839 L .6878 .46897 L p .658 .749 .917 r
F P
0 g
s
.72871 .50024 m .72725 .47585 L .70042 .4839 L p .564 .353 .553 r
F P
0 g
s
.70042 .4839 m .70168 .50824 L .72871 .50024 L p .564 .353 .553 r
F P
0 g
s
.66104 .47709 m .6878 .46897 L .70042 .4839 L p .658 .749 .917 r
F P
0 g
s
.6878 .46897 m .70042 .4839 L .70168 .50824 L p .972 .685 .422 r
F P
0 g
s
.72725 .47585 m .70042 .4839 L .6878 .46897 L p .658 .749 .917 r
F P
0 g
s
.6878 .46897 m .70042 .4839 L .70168 .50824 L p .972 .685 .422 r
F P
0 g
s
.51486 .44045 m .54092 .43216 L .5548 .4474 L p .66 .747 .915 r
F P
0 g
s
.54092 .43216 m .5548 .4474 L .55502 .47148 L p .964 .688 .461 r
F P
0 g
s
.65017 .57352 m .64927 .54859 L .62279 .55631 L p .564 .353 .553 r
F P
0 g
s
.62279 .55631 m .6235 .58118 L .65017 .57352 L p .564 .353 .553 r
F P
0 g
s
.62279 .55631 m .60949 .542 L .60889 .51738 L p .966 .687 .452 r
F P
0 g
s
.64927 .54859 m .62279 .55631 L .60949 .542 L p .654 .754 .923 r
F P
0 g
s
.65017 .57352 m .64927 .54859 L .62279 .55631 L p .564 .353 .553 r
F P
0 g
s
.62279 .55631 m .6235 .58118 L .65017 .57352 L p .564 .353 .553 r
F P
0 g
s
.5831 .54978 m .60949 .542 L .62279 .55631 L p .654 .754 .923 r
F P
0 g
s
.60949 .542 m .62279 .55631 L .6235 .58118 L p .966 .687 .452 r
F P
0 g
s
.64927 .54859 m .62279 .55631 L .60949 .542 L p .654 .754 .923 r
F P
0 g
s
.60949 .542 m .62279 .55631 L .6235 .58118 L p .966 .687 .452 r
F P
0 g
s
.50277 .53657 m .50292 .51191 L .47713 .5198 L p .556 .341 .544 r
F P
0 g
s
.47713 .5198 m .47679 .5444 L .50277 .53657 L p .556 .341 .544 r
F P
0 g
s
.47713 .5198 m .46257 .50517 L .46301 .48081 L p .957 .688 .485 r
F P
0 g
s
.50292 .51191 m .47713 .5198 L .46257 .50517 L p .656 .751 .92 r
F P
0 g
s
.50277 .53657 m .50292 .51191 L .47713 .5198 L p .556 .341 .544 r
F P
0 g
s
.47713 .5198 m .47679 .5444 L .50277 .53657 L p .556 .341 .544 r
F P
0 g
s
.43686 .51313 m .46257 .50517 L .47713 .5198 L p .656 .751 .92 r
F P
0 g
s
.43686 .51313 m .46257 .50517 L .47713 .5198 L p .656 .751 .92 r
F P
0 g
s
.46257 .50517 m .47713 .5198 L .47679 .5444 L p .957 .688 .485 r
F P
0 g
s
.46257 .50517 m .47713 .5198 L .47679 .5444 L p .957 .688 .485 r
F P
0 g
s
.3994 .59224 m .38416 .57824 L .38516 .55335 L p .949 .687 .505 r
F P
0 g
s
.42484 .58469 m .3994 .59224 L .38416 .57824 L p .652 .756 .926 r
F P
0 g
s
.76638 .48267 m .75433 .46772 L .75268 .44362 L p .975 .682 .398 r
F P
0 g
s
.79354 .4746 m .76638 .48267 L .75433 .46772 L p .658 .749 .917 r
F P
0 g
s
.58095 .43918 m .60735 .43088 L .62067 .44614 L p .66 .747 .915 r
F P
0 g
s
.60735 .43088 m .62067 .44614 L .62136 .47023 L p .969 .687 .442 r
F P
0 g
s
.68873 .55512 m .67599 .5408 L .67491 .51616 L p .971 .686 .432 r
F P
0 g
s
.68873 .55512 m .67599 .5408 L .67491 .51616 L p .971 .686 .432 r
F P
0 g
s
.71553 .54739 m .68873 .55512 L .67599 .5408 L p .654 .754 .923 r
F P
0 g
s
.71692 .57234 m .71553 .54739 L .68873 .55512 L p .566 .356 .555 r
F P
0 g
s
.68873 .55512 m .68991 .58 L .71692 .57234 L p .566 .356 .555 r
F P
0 g
s
.64927 .54859 m .67599 .5408 L .68873 .55512 L p .654 .754 .923 r
F P
0 g
s
.64927 .54859 m .67599 .5408 L .68873 .55512 L p .654 .754 .923 r
F P
0 g
s
.67599 .5408 m .68873 .55512 L .68991 .58 L p .971 .686 .432 r
F P
0 g
s
.71553 .54739 m .68873 .55512 L .67599 .5408 L p .654 .754 .923 r
F P
0 g
s
.67599 .5408 m .68873 .55512 L .68991 .58 L p .971 .686 .432 r
F P
0 g
s
.5694 .53536 m .56908 .51069 L .54296 .51859 L p .558 .345 .547 r
F P
0 g
s
.54296 .51859 m .54309 .5432 L .5694 .53536 L p .558 .345 .547 r
F P
0 g
s
.56908 .51069 m .54296 .51859 L .52896 .50394 L p .656 .751 .92 r
F P
0 g
s
.5694 .53536 m .56908 .51069 L .54296 .51859 L p .558 .345 .547 r
F P
0 g
s
.54296 .51859 m .54309 .5432 L .5694 .53536 L p .558 .345 .547 r
F P
0 g
s
.50292 .51191 m .52896 .50394 L .54296 .51859 L p .656 .751 .92 r
F P
0 g
s
.52896 .50394 m .54296 .51859 L .54309 .5432 L p .962 .688 .469 r
F P
0 g
s
.52896 .50394 m .54296 .51859 L .54309 .5432 L p .962 .688 .469 r
F P
0 g
s
.42189 .49839 m .42263 .47398 L .39719 .48205 L p .55 .333 .538 r
F P
0 g
s
.39719 .48205 m .39627 .5064 L .42189 .49839 L p .55 .333 .538 r
F P
0 g
s
.39719 .48205 m .38193 .46709 L .38295 .44298 L p .952 .687 .499 r
F P
0 g
s
.42263 .47398 m .39719 .48205 L .38193 .46709 L p .658 .749 .917 r
F P
0 g
s
.42189 .49839 m .42263 .47398 L .39719 .48205 L p .55 .333 .538 r
F P
0 g
s
.39719 .48205 m .39627 .5064 L .42189 .49839 L p .55 .333 .538 r
F P
0 g
s
.35658 .47523 m .38193 .46709 L .39719 .48205 L p .658 .749 .917 r
F P
0 g
s
.35658 .47523 m .38193 .46709 L .39719 .48205 L p .658 .749 .917 r
F P
0 g
s
.38193 .46709 m .39719 .48205 L .39627 .5064 L p .952 .687 .499 r
F P
0 g
s
.38193 .46709 m .39719 .48205 L .39627 .5064 L p .952 .687 .499 r
F P
0 g
s
.49072 .60873 m .49096 .58352 L .4652 .59108 L p .558 .345 .547 r
F P
0 g
s
.4652 .59108 m .46477 .61623 L .49072 .60873 L p .558 .345 .547 r
F P
0 g
s
.4652 .59108 m .45052 .57706 L .45105 .55216 L p .954 .688 .492 r
F P
0 g
s
.49096 .58352 m .4652 .59108 L .45052 .57706 L p .652 .756 .926 r
F P
0 g
s
.49072 .60873 m .49096 .58352 L .4652 .59108 L p .558 .345 .547 r
F P
0 g
s
.4652 .59108 m .46477 .61623 L .49072 .60873 L p .558 .345 .547 r
F P
0 g
s
.42484 .58469 m .45052 .57706 L .4652 .59108 L p .652 .756 .926 r
F P
0 g
s
.45052 .57706 m .4652 .59108 L .46477 .61623 L p .954 .688 .492 r
F P
0 g
s
.86237 .49777 m .85993 .47336 L .83245 .48143 L p .569 .36 .558 r
F P
0 g
s
.83245 .48143 m .83467 .50579 L .86237 .49777 L p .569 .36 .558 r
F P
0 g
s
.83245 .48143 m .82095 .46646 L .81883 .44235 L p .976 .678 .372 r
F P
0 g
s
.83245 .48143 m .82095 .46646 L .81883 .44235 L p .976 .678 .372 r
F P
0 g
s
.85993 .47336 m .83245 .48143 L .82095 .46646 L p .658 .749 .917 r
F P
0 g
s
.86237 .49777 m .85993 .47336 L .83245 .48143 L p .569 .36 .558 r
F P
0 g
s
.83245 .48143 m .83467 .50579 L .86237 .49777 L p .569 .36 .558 r
F P
0 g
s
.79354 .4746 m .82095 .46646 L .83245 .48143 L p .658 .749 .917 r
F P
0 g
s
.79354 .4746 m .82095 .46646 L .83245 .48143 L p .658 .749 .917 r
F P
0 g
s
.82095 .46646 m .83245 .48143 L .83467 .50579 L p .976 .678 .372 r
F P
0 g
s
.85993 .47336 m .83245 .48143 L .82095 .46646 L p .658 .749 .917 r
F P
0 g
s
.82095 .46646 m .83245 .48143 L .83467 .50579 L p .976 .678 .372 r
F P
0 g
s
.7148 .46078 m .71343 .43663 L .68663 .44488 L p .561 .349 .55 r
F P
0 g
s
.68663 .44488 m .6878 .46897 L .7148 .46078 L p .561 .349 .55 r
F P
0 g
s
.63614 .53415 m .63533 .50947 L .60889 .51738 L p .561 .349 .55 r
F P
0 g
s
.60889 .51738 m .60949 .542 L .63614 .53415 L p .561 .349 .55 r
F P
0 g
s
.60889 .51738 m .59545 .50271 L .59494 .47833 L p .966 .687 .452 r
F P
0 g
s
.60889 .51738 m .59545 .50271 L .59494 .47833 L p .966 .687 .452 r
F P
0 g
s
.63533 .50947 m .60889 .51738 L .59545 .50271 L p .656 .751 .92 r
F P
0 g
s
.56908 .51069 m .59545 .50271 L .60889 .51738 L p .656 .751 .92 r
F P
0 g
s
.56908 .51069 m .59545 .50271 L .60889 .51738 L p .656 .751 .92 r
F P
0 g
s
.59545 .50271 m .60889 .51738 L .60949 .542 L p .966 .687 .452 r
F P
0 g
s
.46301 .48081 m .44831 .46583 L .44886 .44172 L p .957 .688 .485 r
F P
0 g
s
.48878 .47273 m .46301 .48081 L .44831 .46583 L p .658 .749 .917 r
F P
0 g
s
.42263 .47398 m .44831 .46583 L .46301 .48081 L p .658 .749 .917 r
F P
0 g
s
.44831 .46583 m .46301 .48081 L .46257 .50517 L p .957 .688 .485 r
F P
0 g
s
.34222 .436 m .31714 .44425 L .30117 .42895 L p .66 .747 .915 r
F P
0 g
s
.3409 .46015 m .34222 .436 L .31714 .44425 L p .544 .324 .532 r
F P
0 g
s
.31714 .44425 m .31564 .46835 L .3409 .46015 L p .544 .324 .532 r
F P
0 g
s
.30117 .42895 m .31714 .44425 L .31564 .46835 L p .946 .686 .511 r
F P
0 g
s
.53109 .58992 m .51697 .57588 L .51703 .55097 L p .959 .688 .477 r
F P
0 g
s
.55718 .58235 m .53109 .58992 L .51697 .57588 L p .652 .756 .926 r
F P
0 g
s
.55742 .60757 m .55718 .58235 L .53109 .58992 L p .561 .349 .55 r
F P
0 g
s
.53109 .58992 m .53114 .61508 L .55742 .60757 L p .561 .349 .55 r
F P
0 g
s
.49096 .58352 m .51697 .57588 L .53109 .58992 L p .652 .756 .926 r
F P
0 g
s
.51697 .57588 m .53109 .58992 L .53114 .61508 L p .959 .688 .477 r
F P
0 g
s
.55718 .58235 m .53109 .58992 L .51697 .57588 L p .652 .756 .926 r
F P
0 g
s
.51697 .57588 m .53109 .58992 L .53114 .61508 L p .959 .688 .477 r
F P
0 g
s
.40975 .57056 m .41057 .5456 L .38516 .55335 L p .553 .337 .541 r
F P
0 g
s
.38516 .55335 m .38416 .57824 L .40975 .57056 L p .553 .337 .541 r
F P
0 g
s
.38516 .55335 m .36978 .53899 L .37089 .51434 L p .949 .687 .505 r
F P
0 g
s
.41057 .5456 m .38516 .55335 L .36978 .53899 L p .654 .754 .923 r
F P
0 g
s
.40975 .57056 m .41057 .5456 L .38516 .55335 L p .553 .337 .541 r
F P
0 g
s
.38516 .55335 m .38416 .57824 L .40975 .57056 L p .553 .337 .541 r
F P
0 g
s
.36978 .53899 m .38516 .55335 L .38416 .57824 L p .949 .687 .505 r
F P
0 g
s
.41057 .5456 m .38516 .55335 L .36978 .53899 L p .654 .754 .923 r
F P
0 g
s
.8986 .48019 m .88768 .4652 L .88507 .44108 L p .976 .672 .343 r
F P
0 g
s
.8986 .48019 m .88768 .4652 L .88507 .44108 L p .976 .672 .343 r
F P
0 g
s
.92642 .47211 m .8986 .48019 L .88768 .4652 L p .658 .749 .917 r
F P
0 g
s
.92934 .49653 m .92642 .47211 L .8986 .48019 L p .571 .363 .56 r
F P
0 g
s
.8986 .48019 m .90131 .50456 L .92934 .49653 L p .571 .363 .56 r
F P
0 g
s
.85993 .47336 m .88768 .4652 L .8986 .48019 L p .658 .749 .917 r
F P
0 g
s
.85993 .47336 m .88768 .4652 L .8986 .48019 L p .658 .749 .917 r
F P
0 g
s
.88768 .4652 m .8986 .48019 L .90131 .50456 L p .976 .672 .343 r
F P
0 g
s
.92642 .47211 m .8986 .48019 L .88768 .4652 L p .658 .749 .917 r
F P
0 g
s
.88768 .4652 m .8986 .48019 L .90131 .50456 L p .976 .672 .343 r
F P
0 g
s
.78166 .45951 m .77981 .43536 L .75268 .44362 L p .564 .353 .553 r
F P
0 g
s
.75268 .44362 m .75433 .46772 L .78166 .45951 L p .564 .353 .553 r
F P
0 g
s
.71343 .43663 m .74049 .42831 L .75268 .44362 L p .66 .747 .915 r
F P
0 g
s
.74049 .42831 m .75268 .44362 L .75433 .46772 L p .975 .682 .398 r
F P
0 g
s
.70297 .53294 m .70168 .50824 L .67491 .51616 L p .564 .353 .553 r
F P
0 g
s
.67491 .51616 m .67599 .5408 L .70297 .53294 L p .564 .353 .553 r
F P
0 g
s
.67491 .51616 m .66203 .50148 L .66104 .47709 L p .971 .686 .432 r
F P
0 g
s
.67491 .51616 m .66203 .50148 L .66104 .47709 L p .971 .686 .432 r
F P
0 g
s
.70168 .50824 m .67491 .51616 L .66203 .50148 L p .656 .751 .92 r
F P
0 g
s
.63533 .50947 m .66203 .50148 L .67491 .51616 L p .656 .751 .92 r
F P
0 g
s
.52893 .47957 m .51479 .46457 L .51486 .44045 L p .962 .688 .469 r
F P
0 g
s
.52893 .47957 m .51479 .46457 L .51486 .44045 L p .962 .688 .469 r
F P
0 g
s
.55502 .47148 m .52893 .47957 L .51479 .46457 L p .658 .749 .917 r
F P
0 g
s
.55524 .49591 m .55502 .47148 L .52893 .47957 L p .556 .341 .544 r
F P
0 g
s
.52893 .47957 m .52896 .50394 L .55524 .49591 L p .556 .341 .544 r
F P
0 g
s
.48878 .47273 m .51479 .46457 L .52893 .47957 L p .658 .749 .917 r
F P
0 g
s
.51479 .46457 m .52893 .47957 L .52896 .50394 L p .962 .688 .469 r
F P
0 g
s
.55502 .47148 m .52893 .47957 L .51479 .46457 L p .658 .749 .917 r
F P
0 g
s
.40836 .43472 m .38295 .44298 L .36754 .42767 L p .66 .747 .915 r
F P
0 g
s
.40752 .45888 m .40836 .43472 L .38295 .44298 L p .547 .329 .535 r
F P
0 g
s
.38295 .44298 m .38193 .46709 L .40752 .45888 L p .547 .329 .535 r
F P
0 g
s
.34222 .436 m .36754 .42767 L .38295 .44298 L p .66 .747 .915 r
F P
0 g
s
.36754 .42767 m .38295 .44298 L .38193 .46709 L p .952 .687 .499 r
F P
0 g
s
.36754 .42767 m .38295 .44298 L .38193 .46709 L p .952 .687 .499 r
F P
0 g
s
.59708 .58876 m .58352 .5747 L .5831 .54978 L p .964 .688 .461 r
F P
0 g
s
.59708 .58876 m .58352 .5747 L .5831 .54978 L p .964 .688 .461 r
F P
0 g
s
.6235 .58118 m .59708 .58876 L .58352 .5747 L p .652 .756 .926 r
F P
0 g
s
.62422 .60641 m .6235 .58118 L .59708 .58876 L p .564 .353 .553 r
F P
0 g
s
.59708 .58876 m .5976 .61393 L .62422 .60641 L p .564 .353 .553 r
F P
0 g
s
.55718 .58235 m .58352 .5747 L .59708 .58876 L p .652 .756 .926 r
F P
0 g
s
.55718 .58235 m .58352 .5747 L .59708 .58876 L p .652 .756 .926 r
F P
0 g
s
.58352 .5747 m .59708 .58876 L .5976 .61393 L p .964 .688 .461 r
F P
0 g
s
.6235 .58118 m .59708 .58876 L .58352 .5747 L p .652 .756 .926 r
F P
0 g
s
.58352 .5747 m .59708 .58876 L .5976 .61393 L p .964 .688 .461 r
F P
0 g
s
.45105 .55216 m .43622 .53778 L .43686 .51313 L p .954 .688 .492 r
F P
0 g
s
.47679 .5444 m .45105 .55216 L .43622 .53778 L p .654 .754 .923 r
F P
0 g
s
.47644 .56937 m .47679 .5444 L .45105 .55216 L p .556 .341 .544 r
F P
0 g
s
.45105 .55216 m .45052 .57706 L .47644 .56937 L p .556 .341 .544 r
F P
0 g
s
.41057 .5456 m .43622 .53778 L .45105 .55216 L p .654 .754 .923 r
F P
0 g
s
.43622 .53778 m .45105 .55216 L .45052 .57706 L p .954 .688 .492 r
F P
0 g
s
.47679 .5444 m .45105 .55216 L .43622 .53778 L p .654 .754 .923 r
F P
0 g
s
.43622 .53778 m .45105 .55216 L .45052 .57706 L p .954 .688 .492 r
F P
0 g
s
.92642 .47211 m .9545 .46394 L .96486 .47895 L p .658 .749 .917 r
F P
0 g
s
.96486 .47895 m .9545 .46394 L .95141 .43982 L p .973 .663 .31 r
F P
0 g
s
.84863 .45824 m .84629 .43408 L .81883 .44235 L p .566 .356 .555 r
F P
0 g
s
.81883 .44235 m .82095 .46646 L .84863 .45824 L p .566 .356 .555 r
F P
0 g
s
.84629 .43408 m .81883 .44235 L .8072 .42702 L p .66 .747 .915 r
F P
0 g
s
.84863 .45824 m .84629 .43408 L .81883 .44235 L p .566 .356 .555 r
F P
0 g
s
.81883 .44235 m .82095 .46646 L .84863 .45824 L p .566 .356 .555 r
F P
0 g
s
.8072 .42702 m .81883 .44235 L .82095 .46646 L p .976 .678 .372 r
F P
0 g
s
.76813 .50702 m .74102 .51495 L .72871 .50024 L p .656 .751 .92 r
F P
0 g
s
.7699 .53172 m .76813 .50702 L .74102 .51495 L p .566 .356 .555 r
F P
0 g
s
.74102 .51495 m .74259 .53959 L .7699 .53172 L p .566 .356 .555 r
F P
0 g
s
.70168 .50824 m .72871 .50024 L .74102 .51495 L p .656 .751 .92 r
F P
0 g
s
.72871 .50024 m .74102 .51495 L .74259 .53959 L p .974 .684 .41 r
F P
0 g
s
.72871 .50024 m .74102 .51495 L .74259 .53959 L p .974 .684 .41 r
F P
0 g
s
.62206 .49466 m .62136 .47023 L .59494 .47833 L p .558 .345 .547 r
F P
0 g
s
.59494 .47833 m .59545 .50271 L .62206 .49466 L p .558 .345 .547 r
F P
0 g
s
.59494 .47833 m .58136 .46331 L .58095 .43918 L p .966 .687 .452 r
F P
0 g
s
.62136 .47023 m .59494 .47833 L .58136 .46331 L p .658 .749 .917 r
F P
0 g
s
.62206 .49466 m .62136 .47023 L .59494 .47833 L p .558 .345 .547 r
F P
0 g
s
.59494 .47833 m .59545 .50271 L .62206 .49466 L p .558 .345 .547 r
F P
0 g
s
.55502 .47148 m .58136 .46331 L .59494 .47833 L p .658 .749 .917 r
F P
0 g
s
.58136 .46331 m .59494 .47833 L .59545 .50271 L p .966 .687 .452 r
F P
0 g
s
.62136 .47023 m .59494 .47833 L .58136 .46331 L p .658 .749 .917 r
F P
0 g
s
.58136 .46331 m .59494 .47833 L .59545 .50271 L p .966 .687 .452 r
F P
0 g
s
.47423 .45761 m .47459 .43344 L .44886 .44172 L p .55 .333 .538 r
F P
0 g
s
.44886 .44172 m .44831 .46583 L .47423 .45761 L p .55 .333 .538 r
F P
0 g
s
.66316 .5876 m .65017 .57352 L .64927 .54859 L p .969 .687 .442 r
F P
0 g
s
.66316 .5876 m .65017 .57352 L .64927 .54859 L p .969 .687 .442 r
F P
0 g
s
.68991 .58 m .66316 .5876 L .65017 .57352 L p .652 .756 .926 r
F P
0 g
s
.6235 .58118 m .65017 .57352 L .66316 .5876 L p .652 .756 .926 r
F P
0 g
s
.54323 .56818 m .54309 .5432 L .51703 .55097 L p .558 .345 .547 r
F P
0 g
s
.51703 .55097 m .51697 .57588 L .54323 .56818 L p .558 .345 .547 r
F P
0 g
s
.51703 .55097 m .50277 .53657 L .50292 .51191 L p .959 .688 .477 r
F P
0 g
s
.51703 .55097 m .50277 .53657 L .50292 .51191 L p .959 .688 .477 r
F P
0 g
s
.54309 .5432 m .51703 .55097 L .50277 .53657 L p .654 .754 .923 r
F P
0 g
s
.47679 .5444 m .50277 .53657 L .51703 .55097 L p .654 .754 .923 r
F P
0 g
s
.47679 .5444 m .50277 .53657 L .51703 .55097 L p .654 .754 .923 r
F P
0 g
s
.50277 .53657 m .51703 .55097 L .51697 .57588 L p .959 .688 .477 r
F P
0 g
s
.39534 .53111 m .39627 .5064 L .37089 .51434 L p .55 .333 .538 r
F P
0 g
s
.37089 .51434 m .36978 .53899 L .39534 .53111 L p .55 .333 .538 r
F P
0 g
s
.37089 .51434 m .35536 .49963 L .35658 .47523 L p .949 .687 .505 r
F P
0 g
s
.39627 .5064 m .37089 .51434 L .35536 .49963 L p .656 .751 .92 r
F P
0 g
s
.39534 .53111 m .39627 .5064 L .37089 .51434 L p .55 .333 .538 r
F P
0 g
s
.37089 .51434 m .36978 .53899 L .39534 .53111 L p .55 .333 .538 r
F P
0 g
s
.35536 .49963 m .37089 .51434 L .36978 .53899 L p .949 .687 .505 r
F P
0 g
s
.39627 .5064 m .37089 .51434 L .35536 .49963 L p .656 .751 .92 r
F P
0 g
s
.91568 .45697 m .91286 .4328 L .88507 .44108 L p .569 .36 .558 r
F P
0 g
s
.88507 .44108 m .88768 .4652 L .91568 .45697 L p .569 .36 .558 r
F P
0 g
s
.91286 .4328 m .88507 .44108 L .87401 .42573 L p .66 .747 .915 r
F P
0 g
s
.91568 .45697 m .91286 .4328 L .88507 .44108 L p .569 .36 .558 r
F P
0 g
s
.88507 .44108 m .88768 .4652 L .91568 .45697 L p .569 .36 .558 r
F P
0 g
s
.84629 .43408 m .87401 .42573 L .88507 .44108 L p .66 .747 .915 r
F P
0 g
s
.87401 .42573 m .88507 .44108 L .88768 .4652 L p .976 .672 .343 r
F P
0 g
s
.87401 .42573 m .88507 .44108 L .88768 .4652 L p .976 .672 .343 r
F P
0 g
s
.80723 .51373 m .79549 .49901 L .79354 .4746 L p .976 .68 .386 r
F P
0 g
s
.83467 .50579 m .80723 .51373 L .79549 .49901 L p .656 .751 .92 r
F P
0 g
s
.68898 .49342 m .6878 .46897 L .66104 .47709 L p .561 .349 .55 r
F P
0 g
s
.66104 .47709 m .66203 .50148 L .68898 .49342 L p .561 .349 .55 r
F P
0 g
s
.6878 .46897 m .66104 .47709 L .64803 .46205 L p .658 .749 .917 r
F P
0 g
s
.68898 .49342 m .6878 .46897 L .66104 .47709 L p .561 .349 .55 r
F P
0 g
s
.66104 .47709 m .66203 .50148 L .68898 .49342 L p .561 .349 .55 r
F P
0 g
s
.62136 .47023 m .64803 .46205 L .66104 .47709 L p .658 .749 .917 r
F P
0 g
s
.64803 .46205 m .66104 .47709 L .66203 .50148 L p .971 .686 .432 r
F P
0 g
s
.64803 .46205 m .66104 .47709 L .66203 .50148 L p .971 .686 .432 r
F P
0 g
s
.54104 .45634 m .54092 .43216 L .51486 .44045 L p .553 .337 .541 r
F P
0 g
s
.51486 .44045 m .51479 .46457 L .54104 .45634 L p .553 .337 .541 r
F P
0 g
s
.47459 .43344 m .50057 .42509 L .51486 .44045 L p .66 .747 .915 r
F P
0 g
s
.50057 .42509 m .51486 .44045 L .51479 .46457 L p .962 .688 .469 r
F P
0 g
s
.61011 .56699 m .60949 .542 L .5831 .54978 L p .561 .349 .55 r
F P
0 g
s
.5831 .54978 m .58352 .5747 L .61011 .56699 L p .561 .349 .55 r
F P
0 g
s
.5831 .54978 m .5694 .53536 L .56908 .51069 L p .964 .688 .461 r
F P
0 g
s
.5831 .54978 m .5694 .53536 L .56908 .51069 L p .964 .688 .461 r
F P
0 g
s
.60949 .542 m .5831 .54978 L .5694 .53536 L p .654 .754 .923 r
F P
0 g
s
.61011 .56699 m .60949 .542 L .5831 .54978 L p .561 .349 .55 r
F P
0 g
s
.5831 .54978 m .58352 .5747 L .61011 .56699 L p .561 .349 .55 r
F P
0 g
s
.54309 .5432 m .5694 .53536 L .5831 .54978 L p .654 .754 .923 r
F P
0 g
s
.5694 .53536 m .5831 .54978 L .58352 .5747 L p .964 .688 .461 r
F P
0 g
s
.60949 .542 m .5831 .54978 L .5694 .53536 L p .654 .754 .923 r
F P
0 g
s
.46212 .52989 m .46257 .50517 L .43686 .51313 L p .553 .337 .541 r
F P
0 g
s
.43686 .51313 m .43622 .53778 L .46212 .52989 L p .553 .337 .541 r
F P
0 g
s
.43686 .51313 m .42189 .49839 L .42263 .47398 L p .954 .688 .492 r
F P
0 g
s
.43686 .51313 m .42189 .49839 L .42263 .47398 L p .954 .688 .492 r
F P
0 g
s
.46257 .50517 m .43686 .51313 L .42189 .49839 L p .656 .751 .92 r
F P
0 g
s
.46212 .52989 m .46257 .50517 L .43686 .51313 L p .553 .337 .541 r
F P
0 g
s
.43686 .51313 m .43622 .53778 L .46212 .52989 L p .553 .337 .541 r
F P
0 g
s
.39627 .5064 m .42189 .49839 L .43686 .51313 L p .656 .751 .92 r
F P
0 g
s
.42189 .49839 m .43686 .51313 L .43622 .53778 L p .954 .688 .492 r
F P
0 g
s
.46257 .50517 m .43686 .51313 L .42189 .49839 L p .656 .751 .92 r
F P
0 g
s
.91286 .4328 m .94092 .42444 L .95141 .43982 L p .66 .747 .915 r
F P
0 g
s
.94092 .42444 m .95141 .43982 L .9545 .46394 L p .973 .663 .31 r
F P
0 g
s
.5051 .62252 m .49072 .60873 L .49096 .58352 L p .957 .688 .485 r
F P
0 g
s
.5051 .62252 m .49072 .60873 L .49096 .58352 L p .957 .688 .485 r
F P
0 g
s
.53114 .61508 m .5051 .62252 L .49072 .60873 L p .649 .759 .929 r
F P
0 g
s
.46477 .61623 m .49072 .60873 L .5051 .62252 L p .649 .759 .929 r
F P
0 g
s
.87354 .51252 m .86237 .49777 L .85993 .47336 L p .976 .675 .358 r
F P
0 g
s
.87354 .51252 m .86237 .49777 L .85993 .47336 L p .976 .675 .358 r
F P
0 g
s
.90131 .50456 m .87354 .51252 L .86237 .49777 L p .656 .751 .92 r
F P
0 g
s
.83467 .50579 m .86237 .49777 L .87354 .51252 L p .656 .751 .92 r
F P
0 g
s
.72725 .47585 m .7148 .46078 L .71343 .43663 L p .974 .684 .41 r
F P
0 g
s
.72725 .47585 m .7148 .46078 L .71343 .43663 L p .974 .684 .41 r
F P
0 g
s
.75433 .46772 m .72725 .47585 L .7148 .46078 L p .658 .749 .917 r
F P
0 g
s
.756 .49217 m .75433 .46772 L .72725 .47585 L p .564 .353 .553 r
F P
0 g
s
.72725 .47585 m .72871 .50024 L .756 .49217 L p .564 .353 .553 r
F P
0 g
s
.6878 .46897 m .7148 .46078 L .72725 .47585 L p .658 .749 .917 r
F P
0 g
s
.6878 .46897 m .7148 .46078 L .72725 .47585 L p .658 .749 .917 r
F P
0 g
s
.7148 .46078 m .72725 .47585 L .72871 .50024 L p .974 .684 .41 r
F P
0 g
s
.75433 .46772 m .72725 .47585 L .7148 .46078 L p .658 .749 .917 r
F P
0 g
s
.7148 .46078 m .72725 .47585 L .72871 .50024 L p .974 .684 .41 r
F P
0 g
s
.60795 .45506 m .60735 .43088 L .58095 .43918 L p .556 .341 .544 r
F P
0 g
s
.58095 .43918 m .58136 .46331 L .60795 .45506 L p .556 .341 .544 r
F P
0 g
s
.60735 .43088 m .58095 .43918 L .56723 .42379 L p .66 .747 .915 r
F P
0 g
s
.60795 .45506 m .60735 .43088 L .58095 .43918 L p .556 .341 .544 r
F P
0 g
s
.58095 .43918 m .58136 .46331 L .60795 .45506 L p .556 .341 .544 r
F P
0 g
s
.56723 .42379 m .58095 .43918 L .58136 .46331 L p .966 .687 .452 r
F P
0 g
s
.67709 .56579 m .67599 .5408 L .64927 .54859 L p .564 .353 .553 r
F P
0 g
s
.64927 .54859 m .65017 .57352 L .67709 .56579 L p .564 .353 .553 r
F P
0 g
s
.64927 .54859 m .63614 .53415 L .63533 .50947 L p .969 .687 .442 r
F P
0 g
s
.67599 .5408 m .64927 .54859 L .63614 .53415 L p .654 .754 .923 r
F P
0 g
s
.67709 .56579 m .67599 .5408 L .64927 .54859 L p .564 .353 .553 r
F P
0 g
s
.64927 .54859 m .65017 .57352 L .67709 .56579 L p .564 .353 .553 r
F P
0 g
s
.60949 .542 m .63614 .53415 L .64927 .54859 L p .654 .754 .923 r
F P
0 g
s
.60949 .542 m .63614 .53415 L .64927 .54859 L p .654 .754 .923 r
F P
0 g
s
.63614 .53415 m .64927 .54859 L .65017 .57352 L p .969 .687 .442 r
F P
0 g
s
.63614 .53415 m .64927 .54859 L .65017 .57352 L p .969 .687 .442 r
F P
0 g
s
.52899 .52867 m .52896 .50394 L .50292 .51191 L p .556 .341 .544 r
F P
0 g
s
.50292 .51191 m .50277 .53657 L .52899 .52867 L p .556 .341 .544 r
F P
0 g
s
.52896 .50394 m .50292 .51191 L .48852 .49715 L p .656 .751 .92 r
F P
0 g
s
.52899 .52867 m .52896 .50394 L .50292 .51191 L p .556 .341 .544 r
F P
0 g
s
.50292 .51191 m .50277 .53657 L .52899 .52867 L p .556 .341 .544 r
F P
0 g
s
.46257 .50517 m .48852 .49715 L .50292 .51191 L p .656 .751 .92 r
F P
0 g
s
.48852 .49715 m .50292 .51191 L .50277 .53657 L p .959 .688 .477 r
F P
0 g
s
.48852 .49715 m .50292 .51191 L .50277 .53657 L p .959 .688 .477 r
F P
0 g
s
.38089 .49155 m .38193 .46709 L .35658 .47523 L p .547 .329 .535 r
F P
0 g
s
.35658 .47523 m .35536 .49963 L .38089 .49155 L p .547 .329 .535 r
F P
0 g
s
.35658 .47523 m .3409 .46015 L .34222 .436 L p .949 .687 .505 r
F P
0 g
s
.38193 .46709 m .35658 .47523 L .3409 .46015 L p .658 .749 .917 r
F P
0 g
s
.38089 .49155 m .38193 .46709 L .35658 .47523 L p .547 .329 .535 r
F P
0 g
s
.35658 .47523 m .35536 .49963 L .38089 .49155 L p .547 .329 .535 r
F P
0 g
s
.3409 .46015 m .35658 .47523 L .35536 .49963 L p .949 .687 .505 r
F P
0 g
s
.38193 .46709 m .35658 .47523 L .3409 .46015 L p .658 .749 .917 r
F P
0 g
s
.57123 .62138 m .55742 .60757 L .55718 .58235 L p .962 .688 .469 r
F P
0 g
s
.5976 .61393 m .57123 .62138 L .55742 .60757 L p .649 .759 .929 r
F P
0 g
s
.42484 .58469 m .40975 .57056 L .41057 .5456 L p .952 .687 .499 r
F P
0 g
s
.42484 .58469 m .40975 .57056 L .41057 .5456 L p .952 .687 .499 r
F P
0 g
s
.45052 .57706 m .42484 .58469 L .40975 .57056 L p .652 .756 .926 r
F P
0 g
s
.38416 .57824 m .40975 .57056 L .42484 .58469 L p .652 .756 .926 r
F P
0 g
s
.82311 .49092 m .82095 .46646 L .79354 .4746 L p .566 .356 .555 r
F P
0 g
s
.79354 .4746 m .79549 .49901 L .82311 .49092 L p .566 .356 .555 r
F P
0 g
s
.79354 .4746 m .78166 .45951 L .77981 .43536 L p .976 .68 .386 r
F P
0 g
s
.82095 .46646 m .79354 .4746 L .78166 .45951 L p .658 .749 .917 r
F P
0 g
s
.82311 .49092 m .82095 .46646 L .79354 .4746 L p .566 .356 .555 r
F P
0 g
s
.79354 .4746 m .79549 .49901 L .82311 .49092 L p .566 .356 .555 r
F P
0 g
s
.75433 .46772 m .78166 .45951 L .79354 .4746 L p .658 .749 .917 r
F P
0 g
s
.78166 .45951 m .79354 .4746 L .79549 .49901 L p .976 .68 .386 r
F P
0 g
s
.67387 .42959 m .64714 .43791 L .63399 .4225 L p .66 .747 .915 r
F P
0 g
s
.67496 .45379 m .67387 .42959 L .64714 .43791 L p .558 .345 .547 r
F P
0 g
s
.64714 .43791 m .64803 .46205 L .67496 .45379 L p .558 .345 .547 r
F P
0 g
s
.63399 .4225 m .64714 .43791 L .64803 .46205 L p .971 .686 .432 r
F P
0 g
s
.71553 .54739 m .70297 .53294 L .70168 .50824 L p .972 .685 .422 r
F P
0 g
s
.71553 .54739 m .70297 .53294 L .70168 .50824 L p .972 .685 .422 r
F P
0 g
s
.74259 .53959 m .71553 .54739 L .70297 .53294 L p .654 .754 .923 r
F P
0 g
s
.74418 .5646 m .74259 .53959 L .71553 .54739 L p .566 .356 .555 r
F P
0 g
s
.71553 .54739 m .71692 .57234 L .74418 .5646 L p .566 .356 .555 r
F P
0 g
s
.67599 .5408 m .70297 .53294 L .71553 .54739 L p .654 .754 .923 r
F P
0 g
s
.67599 .5408 m .70297 .53294 L .71553 .54739 L p .654 .754 .923 r
F P
0 g
s
.70297 .53294 m .71553 .54739 L .71692 .57234 L p .972 .685 .422 r
F P
0 g
s
.74259 .53959 m .71553 .54739 L .70297 .53294 L p .654 .754 .923 r
F P
0 g
s
.70297 .53294 m .71553 .54739 L .71692 .57234 L p .972 .685 .422 r
F P
0 g
s
.59596 .52745 m .59545 .50271 L .56908 .51069 L p .558 .345 .547 r
F P
0 g
s
.56908 .51069 m .5694 .53536 L .59596 .52745 L p .558 .345 .547 r
F P
0 g
s
.56908 .51069 m .55524 .49591 L .55502 .47148 L p .964 .688 .461 r
F P
0 g
s
.59545 .50271 m .56908 .51069 L .55524 .49591 L p .656 .751 .92 r
F P
0 g
s
.59596 .52745 m .59545 .50271 L .56908 .51069 L p .558 .345 .547 r
F P
0 g
s
.56908 .51069 m .5694 .53536 L .59596 .52745 L p .558 .345 .547 r
F P
0 g
s
.52896 .50394 m .55524 .49591 L .56908 .51069 L p .656 .751 .92 r
F P
0 g
s
.55524 .49591 m .56908 .51069 L .5694 .53536 L p .964 .688 .461 r
F P
0 g
s
.59545 .50271 m .56908 .51069 L .55524 .49591 L p .656 .751 .92 r
F P
0 g
s
.55524 .49591 m .56908 .51069 L .5694 .53536 L p .964 .688 .461 r
F P
0 g
s
.44775 .4903 m .44831 .46583 L .42263 .47398 L p .55 .333 .538 r
F P
0 g
s
.42263 .47398 m .42189 .49839 L .44775 .4903 L p .55 .333 .538 r
F P
0 g
s
.44831 .46583 m .42263 .47398 L .40752 .45888 L p .658 .749 .917 r
F P
0 g
s
.44775 .4903 m .44831 .46583 L .42263 .47398 L p .55 .333 .538 r
F P
0 g
s
.42263 .47398 m .42189 .49839 L .44775 .4903 L p .55 .333 .538 r
F P
0 g
s
.38193 .46709 m .40752 .45888 L .42263 .47398 L p .658 .749 .917 r
F P
0 g
s
.40752 .45888 m .42263 .47398 L .42189 .49839 L p .954 .688 .492 r
F P
0 g
s
.40752 .45888 m .42263 .47398 L .42189 .49839 L p .954 .688 .492 r
F P
0 g
s
.51692 .60116 m .51697 .57588 L .49096 .58352 L p .558 .345 .547 r
F P
0 g
s
.49096 .58352 m .49072 .60873 L .51692 .60116 L p .558 .345 .547 r
F P
0 g
s
.49096 .58352 m .47644 .56937 L .47679 .5444 L p .957 .688 .485 r
F P
0 g
s
.51697 .57588 m .49096 .58352 L .47644 .56937 L p .652 .756 .926 r
F P
0 g
s
.51692 .60116 m .51697 .57588 L .49096 .58352 L p .558 .345 .547 r
F P
0 g
s
.49096 .58352 m .49072 .60873 L .51692 .60116 L p .558 .345 .547 r
F P
0 g
s
.45052 .57706 m .47644 .56937 L .49096 .58352 L p .652 .756 .926 r
F P
0 g
s
.47644 .56937 m .49096 .58352 L .49072 .60873 L p .957 .688 .485 r
F P
0 g
s
.51697 .57588 m .49096 .58352 L .47644 .56937 L p .652 .756 .926 r
F P
0 g
s
.47644 .56937 m .49096 .58352 L .49072 .60873 L p .957 .688 .485 r
F P
0 g
s
.89032 .48967 m .88768 .4652 L .85993 .47336 L p .569 .36 .558 r
F P
0 g
s
.85993 .47336 m .86237 .49777 L .89032 .48967 L p .569 .36 .558 r
F P
0 g
s
.85993 .47336 m .84863 .45824 L .84629 .43408 L p .976 .675 .358 r
F P
0 g
s
.85993 .47336 m .84863 .45824 L .84629 .43408 L p .976 .675 .358 r
F P
0 g
s
.88768 .4652 m .85993 .47336 L .84863 .45824 L p .658 .749 .917 r
F P
0 g
s
.89032 .48967 m .88768 .4652 L .85993 .47336 L p .569 .36 .558 r
F P
0 g
s
.85993 .47336 m .86237 .49777 L .89032 .48967 L p .569 .36 .558 r
F P
0 g
s
.82095 .46646 m .84863 .45824 L .85993 .47336 L p .658 .749 .917 r
F P
0 g
s
.82095 .46646 m .84863 .45824 L .85993 .47336 L p .658 .749 .917 r
F P
0 g
s
.84863 .45824 m .85993 .47336 L .86237 .49777 L p .976 .675 .358 r
F P
0 g
s
.88768 .4652 m .85993 .47336 L .84863 .45824 L p .658 .749 .917 r
F P
0 g
s
.84863 .45824 m .85993 .47336 L .86237 .49777 L p .976 .675 .358 r
F P
0 g
s
.74206 .45251 m .74049 .42831 L .71343 .43663 L p .561 .349 .55 r
F P
0 g
s
.71343 .43663 m .7148 .46078 L .74206 .45251 L p .561 .349 .55 r
F P
0 g
s
.63533 .50947 m .62206 .49466 L .62136 .47023 L p .969 .687 .442 r
F P
0 g
s
.63533 .50947 m .62206 .49466 L .62136 .47023 L p .969 .687 .442 r
F P
0 g
s
.66203 .50148 m .63533 .50947 L .62206 .49466 L p .656 .751 .92 r
F P
0 g
s
.66303 .52622 m .66203 .50148 L .63533 .50947 L p .561 .349 .55 r
F P
0 g
s
.63533 .50947 m .63614 .53415 L .66303 .52622 L p .561 .349 .55 r
F P
0 g
s
.59545 .50271 m .62206 .49466 L .63533 .50947 L p .656 .751 .92 r
F P
0 g
s
.62206 .49466 m .63533 .50947 L .63614 .53415 L p .969 .687 .442 r
F P
0 g
s
.66203 .50148 m .63533 .50947 L .62206 .49466 L p .656 .751 .92 r
F P
0 g
s
.48878 .47273 m .47423 .45761 L .47459 .43344 L p .959 .688 .477 r
F P
0 g
s
.48878 .47273 m .47423 .45761 L .47459 .43344 L p .959 .688 .477 r
F P
0 g
s
.51479 .46457 m .48878 .47273 L .47423 .45761 L p .658 .749 .917 r
F P
0 g
s
.51472 .48905 m .51479 .46457 L .48878 .47273 L p .553 .337 .541 r
F P
0 g
s
.48878 .47273 m .48852 .49715 L .51472 .48905 L p .553 .337 .541 r
F P
0 g
s
.44831 .46583 m .47423 .45761 L .48878 .47273 L p .658 .749 .917 r
F P
0 g
s
.47423 .45761 m .48878 .47273 L .48852 .49715 L p .959 .688 .477 r
F P
0 g
s
.51479 .46457 m .48878 .47273 L .47423 .45761 L p .658 .749 .917 r
F P
0 g
s
.3664 .45187 m .36754 .42767 L .34222 .436 L p .544 .324 .532 r
F P
0 g
s
.34222 .436 m .3409 .46015 L .3664 .45187 L p .544 .324 .532 r
F P
0 g
s
.36754 .42767 m .34222 .436 L .3264 .42055 L p .66 .747 .915 r
F P
0 g
s
.3664 .45187 m .36754 .42767 L .34222 .436 L p .544 .324 .532 r
F P
0 g
s
.34222 .436 m .3409 .46015 L .3664 .45187 L p .544 .324 .532 r
F P
0 g
s
.30117 .42895 m .3264 .42055 L .34222 .436 L p .66 .747 .915 r
F P
0 g
s
.3264 .42055 m .34222 .436 L .3409 .46015 L p .949 .687 .505 r
F P
0 g
s
.3264 .42055 m .34222 .436 L .3409 .46015 L p .949 .687 .505 r
F P
0 g
s
.58395 .59999 m .58352 .5747 L .55718 .58235 L p .561 .349 .55 r
F P
0 g
s
.55718 .58235 m .55742 .60757 L .58395 .59999 L p .561 .349 .55 r
F P
0 g
s
.55718 .58235 m .54323 .56818 L .54309 .5432 L p .962 .688 .469 r
F P
0 g
s
.58352 .5747 m .55718 .58235 L .54323 .56818 L p .652 .756 .926 r
F P
0 g
s
.58395 .59999 m .58352 .5747 L .55718 .58235 L p .561 .349 .55 r
F P
0 g
s
.55718 .58235 m .55742 .60757 L .58395 .59999 L p .561 .349 .55 r
F P
0 g
s
.51697 .57588 m .54323 .56818 L .55718 .58235 L p .652 .756 .926 r
F P
0 g
s
.51697 .57588 m .54323 .56818 L .55718 .58235 L p .652 .756 .926 r
F P
0 g
s
.54323 .56818 m .55718 .58235 L .55742 .60757 L p .962 .688 .469 r
F P
0 g
s
.54323 .56818 m .55718 .58235 L .55742 .60757 L p .962 .688 .469 r
F P
0 g
s
.43558 .5628 m .43622 .53778 L .41057 .5456 L p .553 .337 .541 r
F P
0 g
s
.41057 .5456 m .40975 .57056 L .43558 .5628 L p .553 .337 .541 r
F P
0 g
s
.41057 .5456 m .39534 .53111 L .39627 .5064 L p .952 .687 .499 r
F P
0 g
s
.43622 .53778 m .41057 .5456 L .39534 .53111 L p .654 .754 .923 r
F P
0 g
s
.43558 .5628 m .43622 .53778 L .41057 .5456 L p .553 .337 .541 r
F P
0 g
s
.41057 .5456 m .40975 .57056 L .43558 .5628 L p .553 .337 .541 r
F P
0 g
s
.36978 .53899 m .39534 .53111 L .41057 .5456 L p .654 .754 .923 r
F P
0 g
s
.36978 .53899 m .39534 .53111 L .41057 .5456 L p .654 .754 .923 r
F P
0 g
s
.39534 .53111 m .41057 .5456 L .40975 .57056 L p .952 .687 .499 r
F P
0 g
s
.39534 .53111 m .41057 .5456 L .40975 .57056 L p .952 .687 .499 r
F P
0 g
s
.92642 .47211 m .91568 .45697 L .91286 .4328 L p .975 .668 .327 r
F P
0 g
s
.92642 .47211 m .91568 .45697 L .91286 .4328 L p .975 .668 .327 r
F P
0 g
s
.9545 .46394 m .92642 .47211 L .91568 .45697 L p .658 .749 .917 r
F P
0 g
s
.88768 .4652 m .91568 .45697 L .92642 .47211 L p .658 .749 .917 r
F P
0 g
s
.88768 .4652 m .91568 .45697 L .92642 .47211 L p .658 .749 .917 r
F P
0 g
s
.91568 .45697 m .92642 .47211 L .92934 .49653 L p .975 .668 .327 r
F P
0 g
s
.7302 .525 m .72871 .50024 L .70168 .50824 L p .564 .353 .553 r
F P
0 g
s
.70168 .50824 m .70297 .53294 L .7302 .525 L p .564 .353 .553 r
F P
0 g
s
.70168 .50824 m .68898 .49342 L .6878 .46897 L p .972 .685 .422 r
F P
0 g
s
.70168 .50824 m .68898 .49342 L .6878 .46897 L p .972 .685 .422 r
F P
0 g
s
.72871 .50024 m .70168 .50824 L .68898 .49342 L p .656 .751 .92 r
F P
0 g
s
.66203 .50148 m .68898 .49342 L .70168 .50824 L p .656 .751 .92 r
F P
0 g
s
.58178 .48779 m .58136 .46331 L .55502 .47148 L p .556 .341 .544 r
F P
0 g
s
.55502 .47148 m .55524 .49591 L .58178 .48779 L p .556 .341 .544 r
F P
0 g
s
.55502 .47148 m .54104 .45634 L .54092 .43216 L p .964 .688 .461 r
F P
0 g
s
.58136 .46331 m .55502 .47148 L .54104 .45634 L p .658 .749 .917 r
F P
0 g
s
.58178 .48779 m .58136 .46331 L .55502 .47148 L p .556 .341 .544 r
F P
0 g
s
.55502 .47148 m .55524 .49591 L .58178 .48779 L p .556 .341 .544 r
F P
0 g
s
.51479 .46457 m .54104 .45634 L .55502 .47148 L p .658 .749 .917 r
F P
0 g
s
.51479 .46457 m .54104 .45634 L .55502 .47148 L p .658 .749 .917 r
F P
0 g
s
.54104 .45634 m .55502 .47148 L .55524 .49591 L p .964 .688 .461 r
F P
0 g
s
.54104 .45634 m .55502 .47148 L .55524 .49591 L p .964 .688 .461 r
F P
0 g
s
.43401 .42638 m .40836 .43472 L .3931 .41926 L p .66 .747 .915 r
F P
0 g
s
.43335 .45059 m .43401 .42638 L .40836 .43472 L p .547 .329 .535 r
F P
0 g
s
.40836 .43472 m .40752 .45888 L .43335 .45059 L p .547 .329 .535 r
F P
0 g
s
.36754 .42767 m .3931 .41926 L .40836 .43472 L p .66 .747 .915 r
F P
0 g
s
.3931 .41926 m .40836 .43472 L .40752 .45888 L p .954 .688 .492 r
F P
0 g
s
.3931 .41926 m .40836 .43472 L .40752 .45888 L p .954 .688 .492 r
F P
0 g
s
.87656 .44995 m .87401 .42573 L .84629 .43408 L p .566 .356 .555 r
F P
0 g
s
.84629 .43408 m .84863 .45824 L .87656 .44995 L p .566 .356 .555 r
F P
0 g
s
.87401 .42573 m .84629 .43408 L .83485 .41861 L p .66 .747 .915 r
F P
0 g
s
.87656 .44995 m .87401 .42573 L .84629 .43408 L p .566 .356 .555 r
F P
0 g
s
.84629 .43408 m .84863 .45824 L .87656 .44995 L p .566 .356 .555 r
F P
0 g
s
.8072 .42702 m .83485 .41861 L .84629 .43408 L p .66 .747 .915 r
F P
0 g
s
.83485 .41861 m .84629 .43408 L .84863 .45824 L p .976 .675 .358 r
F P
0 g
s
.83485 .41861 m .84629 .43408 L .84863 .45824 L p .976 .675 .358 r
F P
0 g
s
.6235 .58118 m .61011 .56699 L .60949 .542 L p .966 .687 .452 r
F P
0 g
s
.6235 .58118 m .61011 .56699 L .60949 .542 L p .966 .687 .452 r
F P
0 g
s
.65017 .57352 m .6235 .58118 L .61011 .56699 L p .652 .756 .926 r
F P
0 g
s
.58352 .5747 m .61011 .56699 L .6235 .58118 L p .652 .756 .926 r
F P
0 g
s
.58352 .5747 m .61011 .56699 L .6235 .58118 L p .652 .756 .926 r
F P
0 g
s
.61011 .56699 m .6235 .58118 L .62422 .60641 L p .966 .687 .452 r
F P
0 g
s
.50261 .5616 m .50277 .53657 L .47679 .5444 L p .556 .341 .544 r
F P
0 g
s
.47679 .5444 m .47644 .56937 L .50261 .5616 L p .556 .341 .544 r
F P
0 g
s
.47679 .5444 m .46212 .52989 L .46257 .50517 L p .957 .688 .485 r
F P
0 g
s
.47679 .5444 m .46212 .52989 L .46257 .50517 L p .957 .688 .485 r
F P
0 g
s
.50277 .53657 m .47679 .5444 L .46212 .52989 L p .654 .754 .923 r
F P
0 g
s
.43622 .53778 m .46212 .52989 L .47679 .5444 L p .654 .754 .923 r
F P
0 g
s
.43622 .53778 m .46212 .52989 L .47679 .5444 L p .654 .754 .923 r
F P
0 g
s
.46212 .52989 m .47679 .5444 L .47644 .56937 L p .957 .688 .485 r
F P
0 g
s
.79549 .49901 m .76813 .50702 L .756 .49217 L p .656 .751 .92 r
F P
0 g
s
.79747 .52377 m .79549 .49901 L .76813 .50702 L p .566 .356 .555 r
F P
0 g
s
.76813 .50702 m .7699 .53172 L .79747 .52377 L p .566 .356 .555 r
F P
0 g
s
.72871 .50024 m .756 .49217 L .76813 .50702 L p .656 .751 .92 r
F P
0 g
s
.756 .49217 m .76813 .50702 L .7699 .53172 L p .975 .682 .398 r
F P
0 g
s
.756 .49217 m .76813 .50702 L .7699 .53172 L p .975 .682 .398 r
F P
0 g
s
.64893 .48654 m .64803 .46205 L .62136 .47023 L p .558 .345 .547 r
F P
0 g
s
.62136 .47023 m .62206 .49466 L .64893 .48654 L p .558 .345 .547 r
F P
0 g
s
.62136 .47023 m .60795 .45506 L .60735 .43088 L p .969 .687 .442 r
F P
0 g
s
.64803 .46205 m .62136 .47023 L .60795 .45506 L p .658 .749 .917 r
F P
0 g
s
.64893 .48654 m .64803 .46205 L .62136 .47023 L p .558 .345 .547 r
F P
0 g
s
.62136 .47023 m .62206 .49466 L .64893 .48654 L p .558 .345 .547 r
F P
0 g
s
.58136 .46331 m .60795 .45506 L .62136 .47023 L p .658 .749 .917 r
F P
0 g
s
.58136 .46331 m .60795 .45506 L .62136 .47023 L p .658 .749 .917 r
F P
0 g
s
.60795 .45506 m .62136 .47023 L .62206 .49466 L p .969 .687 .442 r
F P
0 g
s
.60795 .45506 m .62136 .47023 L .62206 .49466 L p .969 .687 .442 r
F P
0 g
s
.5004 .44931 m .50057 .42509 L .47459 .43344 L p .55 .333 .538 r
F P
0 g
s
.47459 .43344 m .47423 .45761 L .5004 .44931 L p .55 .333 .538 r
F P
0 g
s
.68991 .58 m .67709 .56579 L .67599 .5408 L p .971 .686 .432 r
F P
0 g
s
.68991 .58 m .67709 .56579 L .67599 .5408 L p .971 .686 .432 r
F P
0 g
s
.71692 .57234 m .68991 .58 L .67709 .56579 L p .652 .756 .926 r
F P
0 g
s
.65017 .57352 m .67709 .56579 L .68991 .58 L p .652 .756 .926 r
F P
0 g
s
.54309 .5432 m .52899 .52867 L .52896 .50394 L p .962 .688 .469 r
F P
0 g
s
.54309 .5432 m .52899 .52867 L .52896 .50394 L p .962 .688 .469 r
F P
0 g
s
.5694 .53536 m .54309 .5432 L .52899 .52867 L p .654 .754 .923 r
F P
0 g
s
.50277 .53657 m .52899 .52867 L .54309 .5432 L p .654 .754 .923 r
F P
0 g
s
.39627 .5064 m .38089 .49155 L .38193 .46709 L p .952 .687 .499 r
F P
0 g
s
.39627 .5064 m .38089 .49155 L .38193 .46709 L p .952 .687 .499 r
F P
0 g
s
.42189 .49839 m .39627 .5064 L .38089 .49155 L p .656 .751 .92 r
F P
0 g
s
.35536 .49963 m .38089 .49155 L .39627 .5064 L p .656 .751 .92 r
F P
0 g
s
.35536 .49963 m .38089 .49155 L .39627 .5064 L p .656 .751 .92 r
F P
0 g
s
.38089 .49155 m .39627 .5064 L .39534 .53111 L p .952 .687 .499 r
F P
0 g
s
.94396 .44867 m .94092 .42444 L .91286 .4328 L p .569 .36 .558 r
F P
0 g
s
.91286 .4328 m .91568 .45697 L .94396 .44867 L p .569 .36 .558 r
F P
0 g
s
.87401 .42573 m .90199 .4173 L .91286 .4328 L p .66 .747 .915 r
F P
0 g
s
.90199 .4173 m .91286 .4328 L .91568 .45697 L p .975 .668 .327 r
F P
0 g
s
.46477 .61623 m .44998 .60233 L .45052 .57706 L p .954 .688 .492 r
F P
0 g
s
.49072 .60873 m .46477 .61623 L .44998 .60233 L p .649 .759 .929 r
F P
0 g
s
.83467 .50579 m .82311 .49092 L .82095 .46646 L p .976 .678 .372 r
F P
0 g
s
.83467 .50579 m .82311 .49092 L .82095 .46646 L p .976 .678 .372 r
F P
0 g
s
.86237 .49777 m .83467 .50579 L .82311 .49092 L p .656 .751 .92 r
F P
0 g
s
.86483 .52254 m .86237 .49777 L .83467 .50579 L p .569 .36 .558 r
F P
0 g
s
.83467 .50579 m .83692 .5305 L .86483 .52254 L p .569 .36 .558 r
F P
0 g
s
.79549 .49901 m .82311 .49092 L .83467 .50579 L p .656 .751 .92 r
F P
0 g
s
.82311 .49092 m .83467 .50579 L .83692 .5305 L p .976 .678 .372 r
F P
0 g
s
.86237 .49777 m .83467 .50579 L .82311 .49092 L p .656 .751 .92 r
F P
0 g
s
.71619 .48528 m .7148 .46078 L .6878 .46897 L p .561 .349 .55 r
F P
0 g
s
.6878 .46897 m .68898 .49342 L .71619 .48528 L p .561 .349 .55 r
F P
0 g
s
.7148 .46078 m .6878 .46897 L .67496 .45379 L p .658 .749 .917 r
F P
0 g
s
.71619 .48528 m .7148 .46078 L .6878 .46897 L p .561 .349 .55 r
F P
0 g
s
.6878 .46897 m .68898 .49342 L .71619 .48528 L p .561 .349 .55 r
F P
0 g
s
.64803 .46205 m .67496 .45379 L .6878 .46897 L p .658 .749 .917 r
F P
0 g
s
.67496 .45379 m .6878 .46897 L .68898 .49342 L p .972 .685 .422 r
F P
0 g
s
.67496 .45379 m .6878 .46897 L .68898 .49342 L p .972 .685 .422 r
F P
0 g
s
.56723 .42379 m .54092 .43216 L .5268 .41665 L p .66 .747 .915 r
F P
0 g
s
.56755 .44802 m .56723 .42379 L .54092 .43216 L p .553 .337 .541 r
F P
0 g
s
.54092 .43216 m .54104 .45634 L .56755 .44802 L p .553 .337 .541 r
F P
0 g
s
.5268 .41665 m .54092 .43216 L .54104 .45634 L p .964 .688 .461 r
F P
0 g
s
.63695 .5592 m .63614 .53415 L .60949 .542 L p .561 .349 .55 r
F P
0 g
s
.60949 .542 m .61011 .56699 L .63695 .5592 L p .561 .349 .55 r
F P
0 g
s
.60949 .542 m .59596 .52745 L .59545 .50271 L p .966 .687 .452 r
F P
0 g
s
.63614 .53415 m .60949 .542 L .59596 .52745 L p .654 .754 .923 r
F P
0 g
s
.63695 .5592 m .63614 .53415 L .60949 .542 L p .561 .349 .55 r
F P
0 g
s
.60949 .542 m .61011 .56699 L .63695 .5592 L p .561 .349 .55 r
F P
0 g
s
.5694 .53536 m .59596 .52745 L .60949 .542 L p .654 .754 .923 r
F P
0 g
s
.5694 .53536 m .59596 .52745 L .60949 .542 L p .654 .754 .923 r
F P
0 g
s
.59596 .52745 m .60949 .542 L .61011 .56699 L p .966 .687 .452 r
F P
0 g
s
.59596 .52745 m .60949 .542 L .61011 .56699 L p .966 .687 .452 r
F P
0 g
s
.48825 .52192 m .48852 .49715 L .46257 .50517 L p .553 .337 .541 r
F P
0 g
s
.46257 .50517 m .46212 .52989 L .48825 .52192 L p .553 .337 .541 r
F P
0 g
s
.46257 .50517 m .44775 .4903 L .44831 .46583 L p .957 .688 .485 r
F P
0 g
s
.48852 .49715 m .46257 .50517 L .44775 .4903 L p .656 .751 .92 r
F P
0 g
s
.48825 .52192 m .48852 .49715 L .46257 .50517 L p .553 .337 .541 r
F P
0 g
s
.46257 .50517 m .46212 .52989 L .48825 .52192 L p .553 .337 .541 r
F P
0 g
s
.42189 .49839 m .44775 .4903 L .46257 .50517 L p .656 .751 .92 r
F P
0 g
s
.42189 .49839 m .44775 .4903 L .46257 .50517 L p .656 .751 .92 r
F P
0 g
s
.44775 .4903 m .46257 .50517 L .46212 .52989 L p .957 .688 .485 r
F P
0 g
s
.44775 .4903 m .46257 .50517 L .46212 .52989 L p .957 .688 .485 r
F P
0 g
s
.31564 .46835 m .29954 .45315 L .30117 .42895 L p .946 .686 .511 r
F P
0 g
s
.3409 .46015 m .31564 .46835 L .29954 .45315 L p .658 .749 .917 r
F P
0 g
s
.53114 .61508 m .51692 .60116 L .51697 .57588 L p .959 .688 .477 r
F P
0 g
s
.53114 .61508 m .51692 .60116 L .51697 .57588 L p .959 .688 .477 r
F P
0 g
s
.55742 .60757 m .53114 .61508 L .51692 .60116 L p .649 .759 .929 r
F P
0 g
s
.49072 .60873 m .51692 .60116 L .53114 .61508 L p .649 .759 .929 r
F P
0 g
s
.38416 .57824 m .36865 .564 L .36978 .53899 L p .949 .687 .505 r
F P
0 g
s
.40975 .57056 m .38416 .57824 L .36865 .564 L p .652 .756 .926 r
F P
0 g
s
.90131 .50456 m .89032 .48967 L .88768 .4652 L p .976 .672 .343 r
F P
0 g
s
.90131 .50456 m .89032 .48967 L .88768 .4652 L p .976 .672 .343 r
F P
0 g
s
.92934 .49653 m .90131 .50456 L .89032 .48967 L p .656 .751 .92 r
F P
0 g
s
.86237 .49777 m .89032 .48967 L .90131 .50456 L p .656 .751 .92 r
F P
0 g
s
.75433 .46772 m .74206 .45251 L .74049 .42831 L p .975 .682 .398 r
F P
0 g
s
.78166 .45951 m .75433 .46772 L .74206 .45251 L p .658 .749 .917 r
F P
0 g
s
.78354 .48402 m .78166 .45951 L .75433 .46772 L p .564 .353 .553 r
F P
0 g
s
.75433 .46772 m .756 .49217 L .78354 .48402 L p .564 .353 .553 r
F P
0 g
s
.7148 .46078 m .74206 .45251 L .75433 .46772 L p .658 .749 .917 r
F P
0 g
s
.7148 .46078 m .74206 .45251 L .75433 .46772 L p .658 .749 .917 r
F P
0 g
s
.74206 .45251 m .75433 .46772 L .756 .49217 L p .975 .682 .398 r
F P
0 g
s
.74206 .45251 m .75433 .46772 L .756 .49217 L p .975 .682 .398 r
F P
0 g
s
.56723 .42379 m .59379 .41535 L .60735 .43088 L p .66 .747 .915 r
F P
0 g
s
.59379 .41535 m .60735 .43088 L .60795 .45506 L p .969 .687 .442 r
F P
0 g
s
.70427 .55799 m .70297 .53294 L .67599 .5408 L p .564 .353 .553 r
F P
0 g
s
.67599 .5408 m .67709 .56579 L .70427 .55799 L p .564 .353 .553 r
F P
0 g
s
.70297 .53294 m .67599 .5408 L .66303 .52622 L p .654 .754 .923 r
F P
0 g
s
.70427 .55799 m .70297 .53294 L .67599 .5408 L p .564 .353 .553 r
F P
0 g
s
.67599 .5408 m .67709 .56579 L .70427 .55799 L p .564 .353 .553 r
F P
0 g
s
.63614 .53415 m .66303 .52622 L .67599 .5408 L p .654 .754 .923 r
F P
0 g
s
.66303 .52622 m .67599 .5408 L .67709 .56579 L p .971 .686 .432 r
F P
0 g
s
.66303 .52622 m .67599 .5408 L .67709 .56579 L p .971 .686 .432 r
F P
0 g
s
.55547 .52069 m .55524 .49591 L .52896 .50394 L p .556 .341 .544 r
F P
0 g
s
.52896 .50394 m .52899 .52867 L .55547 .52069 L p .556 .341 .544 r
F P
0 g
s
.52896 .50394 m .51472 .48905 L .51479 .46457 L p .962 .688 .469 r
F P
0 g
s
.55524 .49591 m .52896 .50394 L .51472 .48905 L p .656 .751 .92 r
F P
0 g
s
.48852 .49715 m .51472 .48905 L .52896 .50394 L p .656 .751 .92 r
F P
0 g
s
.51472 .48905 m .52896 .50394 L .52899 .52867 L p .962 .688 .469 r
F P
0 g
s
.40666 .48339 m .40752 .45888 L .38193 .46709 L p .547 .329 .535 r
F P
0 g
s
.38193 .46709 m .38089 .49155 L .40666 .48339 L p .547 .329 .535 r
F P
0 g
s
.38193 .46709 m .3664 .45187 L .36754 .42767 L p .952 .687 .499 r
F P
0 g
s
.38193 .46709 m .3664 .45187 L .36754 .42767 L p .952 .687 .499 r
F P
0 g
s
.40752 .45888 m .38193 .46709 L .3664 .45187 L p .658 .749 .917 r
F P
0 g
s
.40666 .48339 m .40752 .45888 L .38193 .46709 L p .547 .329 .535 r
F P
0 g
s
.38193 .46709 m .38089 .49155 L .40666 .48339 L p .547 .329 .535 r
F P
0 g
s
.3409 .46015 m .3664 .45187 L .38193 .46709 L p .658 .749 .917 r
F P
0 g
s
.3409 .46015 m .3664 .45187 L .38193 .46709 L p .658 .749 .917 r
F P
0 g
s
.3664 .45187 m .38193 .46709 L .38089 .49155 L p .952 .687 .499 r
F P
0 g
s
.40752 .45888 m .38193 .46709 L .3664 .45187 L p .658 .749 .917 r
F P
0 g
s
.3664 .45187 m .38193 .46709 L .38089 .49155 L p .952 .687 .499 r
F P
0 g
s
.5976 .61393 m .58395 .59999 L .58352 .5747 L p .964 .688 .461 r
F P
0 g
s
.5976 .61393 m .58395 .59999 L .58352 .5747 L p .964 .688 .461 r
F P
0 g
s
.62422 .60641 m .5976 .61393 L .58395 .59999 L p .649 .759 .929 r
F P
0 g
s
.55742 .60757 m .58395 .59999 L .5976 .61393 L p .649 .759 .929 r
F P
0 g
s
.47609 .5947 m .47644 .56937 L .45052 .57706 L p .556 .341 .544 r
F P
0 g
s
.45052 .57706 m .44998 .60233 L .47609 .5947 L p .556 .341 .544 r
F P
0 g
s
.45052 .57706 m .43558 .5628 L .43622 .53778 L p .954 .688 .492 r
F P
0 g
s
.45052 .57706 m .43558 .5628 L .43622 .53778 L p .954 .688 .492 r
F P
0 g
s
.47644 .56937 m .45052 .57706 L .43558 .5628 L p .652 .756 .926 r
F P
0 g
s
.47609 .5947 m .47644 .56937 L .45052 .57706 L p .556 .341 .544 r
F P
0 g
s
.45052 .57706 m .44998 .60233 L .47609 .5947 L p .556 .341 .544 r
F P
0 g
s
.40975 .57056 m .43558 .5628 L .45052 .57706 L p .652 .756 .926 r
F P
0 g
s
.43558 .5628 m .45052 .57706 L .44998 .60233 L p .954 .688 .492 r
F P
0 g
s
.47644 .56937 m .45052 .57706 L .43558 .5628 L p .652 .756 .926 r
F P
0 g
s
.851 .48276 m .84863 .45824 L .82095 .46646 L p .566 .356 .555 r
F P
0 g
s
.82095 .46646 m .82311 .49092 L .851 .48276 L p .566 .356 .555 r
F P
0 g
s
.82095 .46646 m .80926 .45123 L .8072 .42702 L p .976 .678 .372 r
F P
0 g
s
.84863 .45824 m .82095 .46646 L .80926 .45123 L p .658 .749 .917 r
F P
0 g
s
.851 .48276 m .84863 .45824 L .82095 .46646 L p .566 .356 .555 r
F P
0 g
s
.82095 .46646 m .82311 .49092 L .851 .48276 L p .566 .356 .555 r
F P
0 g
s
.78166 .45951 m .80926 .45123 L .82095 .46646 L p .658 .749 .917 r
F P
0 g
s
.80926 .45123 m .82095 .46646 L .82311 .49092 L p .976 .678 .372 r
F P
0 g
s
.84863 .45824 m .82095 .46646 L .80926 .45123 L p .658 .749 .917 r
F P
0 g
s
.80926 .45123 m .82095 .46646 L .82311 .49092 L p .976 .678 .372 r
F P
0 g
s
.70085 .4212 m .67387 .42959 L .66089 .41404 L p .66 .747 .915 r
F P
0 g
s
.70214 .44545 m .70085 .4212 L .67387 .42959 L p .558 .345 .547 r
F P
0 g
s
.67387 .42959 m .67496 .45379 L .70214 .44545 L p .558 .345 .547 r
F P
0 g
s
.63399 .4225 m .66089 .41404 L .67387 .42959 L p .66 .747 .915 r
F P
0 g
s
.66089 .41404 m .67387 .42959 L .67496 .45379 L p .972 .685 .422 r
F P
0 g
s
.66089 .41404 m .67387 .42959 L .67496 .45379 L p .972 .685 .422 r
F P
0 g
s
.74259 .53959 m .7302 .525 L .72871 .50024 L p .974 .684 .41 r
F P
0 g
s
.74259 .53959 m .7302 .525 L .72871 .50024 L p .974 .684 .41 r
F P
0 g
s
.7699 .53172 m .74259 .53959 L .7302 .525 L p .654 .754 .923 r
F P
0 g
s
.77169 .55678 m .7699 .53172 L .74259 .53959 L p .566 .356 .555 r
F P
0 g
s
.74259 .53959 m .74418 .5646 L .77169 .55678 L p .566 .356 .555 r
F P
0 g
s
.70297 .53294 m .7302 .525 L .74259 .53959 L p .654 .754 .923 r
F P
0 g
s
.70297 .53294 m .7302 .525 L .74259 .53959 L p .654 .754 .923 r
F P
0 g
s
.7302 .525 m .74259 .53959 L .74418 .5646 L p .974 .684 .41 r
F P
0 g
s
.7699 .53172 m .74259 .53959 L .7302 .525 L p .654 .754 .923 r
F P
0 g
s
.7302 .525 m .74259 .53959 L .74418 .5646 L p .974 .684 .41 r
F P
0 g
s
.59545 .50271 m .58178 .48779 L .58136 .46331 L p .966 .687 .452 r
F P
0 g
s
.59545 .50271 m .58178 .48779 L .58136 .46331 L p .966 .687 .452 r
F P
0 g
s
.62206 .49466 m .59545 .50271 L .58178 .48779 L p .656 .751 .92 r
F P
0 g
s
.55524 .49591 m .58178 .48779 L .59545 .50271 L p .656 .751 .92 r
F P
0 g
s
.55524 .49591 m .58178 .48779 L .59545 .50271 L p .656 .751 .92 r
F P
0 g
s
.58178 .48779 m .59545 .50271 L .59596 .52745 L p .966 .687 .452 r
F P
0 g
s
.47423 .45761 m .44831 .46583 L .43335 .45059 L p .658 .749 .917 r
F P
0 g
s
.47386 .48213 m .47423 .45761 L .44831 .46583 L p .55 .333 .538 r
F P
0 g
s
.44831 .46583 m .44775 .4903 L .47386 .48213 L p .55 .333 .538 r
F P
0 g
s
.40752 .45888 m .43335 .45059 L .44831 .46583 L p .658 .749 .917 r
F P
0 g
s
.43335 .45059 m .44831 .46583 L .44775 .4903 L p .957 .688 .485 r
F P
0 g
s
.43335 .45059 m .44831 .46583 L .44775 .4903 L p .957 .688 .485 r
F P
0 g
s
.32495 .44481 m .3264 .42055 L .30117 .42895 L p .541 .319 .528 r
F P
0 g
s
.30117 .42895 m .29954 .45315 L .32495 .44481 L p .541 .319 .528 r
F P
0 g
s
.3264 .42055 m .30117 .42895 L .28492 .41339 L p .66 .747 .915 r
F P
0 g
s
.32495 .44481 m .3264 .42055 L .30117 .42895 L p .541 .319 .528 r
F P
0 g
s
.30117 .42895 m .29954 .45315 L .32495 .44481 L p .541 .319 .528 r
F P
0 g
s
.28492 .41339 m .30117 .42895 L .29954 .45315 L p .946 .686 .511 r
F P
0 g
s
.54336 .59352 m .54323 .56818 L .51697 .57588 L p .558 .345 .547 r
F P
0 g
s
.51697 .57588 m .51692 .60116 L .54336 .59352 L p .558 .345 .547 r
F P
0 g
s
.51697 .57588 m .50261 .5616 L .50277 .53657 L p .959 .688 .477 r
F P
0 g
s
.54323 .56818 m .51697 .57588 L .50261 .5616 L p .652 .756 .926 r
F P
0 g
s
.54336 .59352 m .54323 .56818 L .51697 .57588 L p .558 .345 .547 r
F P
0 g
s
.51697 .57588 m .51692 .60116 L .54336 .59352 L p .558 .345 .547 r
F P
0 g
s
.47644 .56937 m .50261 .5616 L .51697 .57588 L p .652 .756 .926 r
F P
0 g
s
.47644 .56937 m .50261 .5616 L .51697 .57588 L p .652 .756 .926 r
F P
0 g
s
.50261 .5616 m .51697 .57588 L .51692 .60116 L p .959 .688 .477 r
F P
0 g
s
.50261 .5616 m .51697 .57588 L .51692 .60116 L p .959 .688 .477 r
F P
0 g
s
.39439 .55618 m .39534 .53111 L .36978 .53899 L p .55 .333 .538 r
F P
0 g
s
.36978 .53899 m .36865 .564 L .39439 .55618 L p .55 .333 .538 r
F P
0 g
s
.36978 .53899 m .35412 .52438 L .35536 .49963 L p .949 .687 .505 r
F P
0 g
s
.39534 .53111 m .36978 .53899 L .35412 .52438 L p .654 .754 .923 r
F P
0 g
s
.39439 .55618 m .39534 .53111 L .36978 .53899 L p .55 .333 .538 r
F P
0 g
s
.36978 .53899 m .36865 .564 L .39439 .55618 L p .55 .333 .538 r
F P
0 g
s
.35412 .52438 m .36978 .53899 L .36865 .564 L p .949 .687 .505 r
F P
0 g
s
.39534 .53111 m .36978 .53899 L .35412 .52438 L p .654 .754 .923 r
F P
0 g
s
.91855 .4815 m .91568 .45697 L .88768 .4652 L p .569 .36 .558 r
F P
0 g
s
.88768 .4652 m .89032 .48967 L .91855 .4815 L p .569 .36 .558 r
F P
0 g
s
.88768 .4652 m .87656 .44995 L .87401 .42573 L p .976 .672 .343 r
F P
0 g
s
.88768 .4652 m .87656 .44995 L .87401 .42573 L p .976 .672 .343 r
F P
0 g
s
.91568 .45697 m .88768 .4652 L .87656 .44995 L p .658 .749 .917 r
F P
0 g
s
.91855 .4815 m .91568 .45697 L .88768 .4652 L p .569 .36 .558 r
F P
0 g
s
.88768 .4652 m .89032 .48967 L .91855 .4815 L p .569 .36 .558 r
F P
0 g
s
.84863 .45824 m .87656 .44995 L .88768 .4652 L p .658 .749 .917 r
F P
0 g
s
.84863 .45824 m .87656 .44995 L .88768 .4652 L p .658 .749 .917 r
F P
0 g
s
.87656 .44995 m .88768 .4652 L .89032 .48967 L p .976 .672 .343 r
F P
0 g
s
.91568 .45697 m .88768 .4652 L .87656 .44995 L p .658 .749 .917 r
F P
0 g
s
.87656 .44995 m .88768 .4652 L .89032 .48967 L p .976 .672 .343 r
F P
0 g
s
.7678 .41991 m .74049 .42831 L .72808 .41273 L p .66 .747 .915 r
F P
0 g
s
.76958 .44416 m .7678 .41991 L .74049 .42831 L p .561 .349 .55 r
F P
0 g
s
.74049 .42831 m .74206 .45251 L .76958 .44416 L p .561 .349 .55 r
F P
0 g
s
.72808 .41273 m .74049 .42831 L .74206 .45251 L p .975 .682 .398 r
F P
0 g
s
.66203 .50148 m .64893 .48654 L .64803 .46205 L p .971 .686 .432 r
F P
0 g
s
.66203 .50148 m .64893 .48654 L .64803 .46205 L p .971 .686 .432 r
F P
0 g
s
.68898 .49342 m .66203 .50148 L .64893 .48654 L p .656 .751 .92 r
F P
0 g
s
.69019 .51822 m .68898 .49342 L .66203 .50148 L p .561 .349 .55 r
F P
0 g
s
.66203 .50148 m .66303 .52622 L .69019 .51822 L p .561 .349 .55 r
F P
0 g
s
.62206 .49466 m .64893 .48654 L .66203 .50148 L p .656 .751 .92 r
F P
0 g
s
.62206 .49466 m .64893 .48654 L .66203 .50148 L p .656 .751 .92 r
F P
0 g
s
.64893 .48654 m .66203 .50148 L .66303 .52622 L p .971 .686 .432 r
F P
0 g
s
.68898 .49342 m .66203 .50148 L .64893 .48654 L p .656 .751 .92 r
F P
0 g
s
.64893 .48654 m .66203 .50148 L .66303 .52622 L p .971 .686 .432 r
F P
0 g
s
.54116 .48087 m .54104 .45634 L .51479 .46457 L p .553 .337 .541 r
F P
0 g
s
.51479 .46457 m .51472 .48905 L .54116 .48087 L p .553 .337 .541 r
F P
0 g
s
.51479 .46457 m .5004 .44931 L .50057 .42509 L p .962 .688 .469 r
F P
0 g
s
.54104 .45634 m .51479 .46457 L .5004 .44931 L p .658 .749 .917 r
F P
0 g
s
.54116 .48087 m .54104 .45634 L .51479 .46457 L p .553 .337 .541 r
F P
0 g
s
.51479 .46457 m .51472 .48905 L .54116 .48087 L p .553 .337 .541 r
F P
0 g
s
.47423 .45761 m .5004 .44931 L .51479 .46457 L p .658 .749 .917 r
F P
0 g
s
.47423 .45761 m .5004 .44931 L .51479 .46457 L p .658 .749 .917 r
F P
0 g
s
.5004 .44931 m .51479 .46457 L .51472 .48905 L p .962 .688 .469 r
F P
0 g
s
.5004 .44931 m .51479 .46457 L .51472 .48905 L p .962 .688 .469 r
F P
0 g
s
.39214 .44351 m .3931 .41926 L .36754 .42767 L p .544 .324 .532 r
F P
0 g
s
.36754 .42767 m .3664 .45187 L .39214 .44351 L p .544 .324 .532 r
F P
0 g
s
.3264 .42055 m .35186 .41208 L .36754 .42767 L p .66 .747 .915 r
F P
0 g
s
.35186 .41208 m .36754 .42767 L .3664 .45187 L p .952 .687 .499 r
F P
0 g
s
.61074 .59234 m .61011 .56699 L .58352 .5747 L p .561 .349 .55 r
F P
0 g
s
.58352 .5747 m .58395 .59999 L .61074 .59234 L p .561 .349 .55 r
F P
0 g
s
.58352 .5747 m .56973 .5604 L .5694 .53536 L p .964 .688 .461 r
F P
0 g
s
.61011 .56699 m .58352 .5747 L .56973 .5604 L p .652 .756 .926 r
F P
0 g
s
.61074 .59234 m .61011 .56699 L .58352 .5747 L p .561 .349 .55 r
F P
0 g
s
.58352 .5747 m .58395 .59999 L .61074 .59234 L p .561 .349 .55 r
F P
0 g
s
.54323 .56818 m .56973 .5604 L .58352 .5747 L p .652 .756 .926 r
F P
0 g
s
.56973 .5604 m .58352 .5747 L .58395 .59999 L p .964 .688 .461 r
F P
0 g
s
.61011 .56699 m .58352 .5747 L .56973 .5604 L p .652 .756 .926 r
F P
0 g
s
.56973 .5604 m .58352 .5747 L .58395 .59999 L p .964 .688 .461 r
F P
0 g
s
.46166 .55497 m .46212 .52989 L .43622 .53778 L p .553 .337 .541 r
F P
0 g
s
.43622 .53778 m .43558 .5628 L .46166 .55497 L p .553 .337 .541 r
F P
0 g
s
.43622 .53778 m .42114 .52315 L .42189 .49839 L p .954 .688 .492 r
F P
0 g
s
.46212 .52989 m .43622 .53778 L .42114 .52315 L p .654 .754 .923 r
F P
0 g
s
.39534 .53111 m .42114 .52315 L .43622 .53778 L p .654 .754 .923 r
F P
0 g
s
.42114 .52315 m .43622 .53778 L .43558 .5628 L p .954 .688 .492 r
F P
0 g
s
.91568 .45697 m .94396 .44867 L .9545 .46394 L p .658 .749 .917 r
F P
0 g
s
.9545 .46394 m .94396 .44867 L .94092 .42444 L p .973 .663 .31 r
F P
0 g
s
.83712 .44287 m .83485 .41861 L .8072 .42702 L p .564 .353 .553 r
F P
0 g
s
.8072 .42702 m .80926 .45123 L .83712 .44287 L p .564 .353 .553 r
F P
0 g
s
.7577 .51698 m .756 .49217 L .72871 .50024 L p .564 .353 .553 r
F P
0 g
s
.72871 .50024 m .7302 .525 L .7577 .51698 L p .564 .353 .553 r
F P
0 g
s
.72871 .50024 m .71619 .48528 L .7148 .46078 L p .974 .684 .41 r
F P
0 g
s
.72871 .50024 m .71619 .48528 L .7148 .46078 L p .974 .684 .41 r
F P
0 g
s
.756 .49217 m .72871 .50024 L .71619 .48528 L p .656 .751 .92 r
F P
0 g
s
.68898 .49342 m .71619 .48528 L .72871 .50024 L p .656 .751 .92 r
F P
0 g
s
.60856 .4796 m .60795 .45506 L .58136 .46331 L p .556 .341 .544 r
F P
0 g
s
.58136 .46331 m .58178 .48779 L .60856 .4796 L p .556 .341 .544 r
F P
0 g
s
.58136 .46331 m .56755 .44802 L .56723 .42379 L p .966 .687 .452 r
F P
0 g
s
.60795 .45506 m .58136 .46331 L .56755 .44802 L p .658 .749 .917 r
F P
0 g
s
.60856 .4796 m .60795 .45506 L .58136 .46331 L p .556 .341 .544 r
F P
0 g
s
.58136 .46331 m .58178 .48779 L .60856 .4796 L p .556 .341 .544 r
F P
0 g
s
.54104 .45634 m .56755 .44802 L .58136 .46331 L p .658 .749 .917 r
F P
0 g
s
.56755 .44802 m .58136 .46331 L .58178 .48779 L p .966 .687 .452 r
F P
0 g
s
.60795 .45506 m .58136 .46331 L .56755 .44802 L p .658 .749 .917 r
F P
0 g
s
.56755 .44802 m .58136 .46331 L .58178 .48779 L p .966 .687 .452 r
F P
0 g
s
.4599 .41796 m .43401 .42638 L .4189 .41077 L p .66 .747 .915 r
F P
0 g
s
.45943 .44222 m .4599 .41796 L .43401 .42638 L p .547 .329 .535 r
F P
0 g
s
.43401 .42638 m .43335 .45059 L .45943 .44222 L p .547 .329 .535 r
F P
0 g
s
.3931 .41926 m .4189 .41077 L .43401 .42638 L p .66 .747 .915 r
F P
0 g
s
.4189 .41077 m .43401 .42638 L .43335 .45059 L p .957 .688 .485 r
F P
0 g
s
.4189 .41077 m .43401 .42638 L .43335 .45059 L p .957 .688 .485 r
F P
0 g
s
.65017 .57352 m .63695 .5592 L .63614 .53415 L p .969 .687 .442 r
F P
0 g
s
.65017 .57352 m .63695 .5592 L .63614 .53415 L p .969 .687 .442 r
F P
0 g
s
.67709 .56579 m .65017 .57352 L .63695 .5592 L p .652 .756 .926 r
F P
0 g
s
.67821 .59115 m .67709 .56579 L .65017 .57352 L p .564 .353 .553 r
F P
0 g
s
.65017 .57352 m .65109 .59882 L .67821 .59115 L p .564 .353 .553 r
F P
0 g
s
.61011 .56699 m .63695 .5592 L .65017 .57352 L p .652 .756 .926 r
F P
0 g
s
.63695 .5592 m .65017 .57352 L .65109 .59882 L p .969 .687 .442 r
F P
0 g
s
.67709 .56579 m .65017 .57352 L .63695 .5592 L p .652 .756 .926 r
F P
0 g
s
.50277 .53657 m .48825 .52192 L .48852 .49715 L p .959 .688 .477 r
F P
0 g
s
.50277 .53657 m .48825 .52192 L .48852 .49715 L p .959 .688 .477 r
F P
0 g
s
.52899 .52867 m .50277 .53657 L .48825 .52192 L p .654 .754 .923 r
F P
0 g
s
.52902 .55376 m .52899 .52867 L .50277 .53657 L p .556 .341 .544 r
F P
0 g
s
.50277 .53657 m .50261 .5616 L .52902 .55376 L p .556 .341 .544 r
F P
0 g
s
.46212 .52989 m .48825 .52192 L .50277 .53657 L p .654 .754 .923 r
F P
0 g
s
.48825 .52192 m .50277 .53657 L .50261 .5616 L p .959 .688 .477 r
F P
0 g
s
.52899 .52867 m .50277 .53657 L .48825 .52192 L p .654 .754 .923 r
F P
0 g
s
.37983 .51636 m .38089 .49155 L .35536 .49963 L p .547 .329 .535 r
F P
0 g
s
.35536 .49963 m .35412 .52438 L .37983 .51636 L p .547 .329 .535 r
F P
0 g
s
.35536 .49963 m .33956 .48465 L .3409 .46015 L p .949 .687 .505 r
F P
0 g
s
.38089 .49155 m .35536 .49963 L .33956 .48465 L p .656 .751 .92 r
F P
0 g
s
.37983 .51636 m .38089 .49155 L .35536 .49963 L p .547 .329 .535 r
F P
0 g
s
.35536 .49963 m .35412 .52438 L .37983 .51636 L p .547 .329 .535 r
F P
0 g
s
.33956 .48465 m .35536 .49963 L .35412 .52438 L p .949 .687 .505 r
F P
0 g
s
.38089 .49155 m .35536 .49963 L .33956 .48465 L p .656 .751 .92 r
F P
0 g
s
.90476 .44158 m .90199 .4173 L .87401 .42573 L p .566 .356 .555 r
F P
0 g
s
.87401 .42573 m .87656 .44995 L .90476 .44158 L p .566 .356 .555 r
F P
0 g
s
.90199 .4173 m .87401 .42573 L .86276 .41011 L p .66 .747 .915 r
F P
0 g
s
.90476 .44158 m .90199 .4173 L .87401 .42573 L p .566 .356 .555 r
F P
0 g
s
.87401 .42573 m .87656 .44995 L .90476 .44158 L p .566 .356 .555 r
F P
0 g
s
.83485 .41861 m .86276 .41011 L .87401 .42573 L p .66 .747 .915 r
F P
0 g
s
.86276 .41011 m .87401 .42573 L .87656 .44995 L p .976 .672 .343 r
F P
0 g
s
.86276 .41011 m .87401 .42573 L .87656 .44995 L p .976 .672 .343 r
F P
0 g
s
.79549 .49901 m .78354 .48402 L .78166 .45951 L p .976 .68 .386 r
F P
0 g
s
.82311 .49092 m .79549 .49901 L .78354 .48402 L p .656 .751 .92 r
F P
0 g
s
.8253 .51574 m .82311 .49092 L .79549 .49901 L p .566 .356 .555 r
F P
0 g
s
.79549 .49901 m .79747 .52377 L .8253 .51574 L p .566 .356 .555 r
F P
0 g
s
.756 .49217 m .78354 .48402 L .79549 .49901 L p .656 .751 .92 r
F P
0 g
s
.78354 .48402 m .79549 .49901 L .79747 .52377 L p .976 .68 .386 r
F P
0 g
s
.82311 .49092 m .79549 .49901 L .78354 .48402 L p .656 .751 .92 r
F P
0 g
s
.78354 .48402 m .79549 .49901 L .79747 .52377 L p .976 .68 .386 r
F P
0 g
s
.67606 .47834 m .67496 .45379 L .64803 .46205 L p .558 .345 .547 r
F P
0 g
s
.64803 .46205 m .64893 .48654 L .67606 .47834 L p .558 .345 .547 r
F P
0 g
s
.64803 .46205 m .63479 .44674 L .63399 .4225 L p .971 .686 .432 r
F P
0 g
s
.67496 .45379 m .64803 .46205 L .63479 .44674 L p .658 .749 .917 r
F P
0 g
s
.60795 .45506 m .63479 .44674 L .64803 .46205 L p .658 .749 .917 r
F P
0 g
s
.63479 .44674 m .64803 .46205 L .64893 .48654 L p .971 .686 .432 r
F P
0 g
s
.5268 .41665 m .50057 .42509 L .48604 .40945 L p .66 .747 .915 r
F P
0 g
s
.52681 .44093 m .5268 .41665 L .50057 .42509 L p .55 .333 .538 r
F P
0 g
s
.50057 .42509 m .5004 .44931 L .52681 .44093 L p .55 .333 .538 r
F P
0 g
s
.48604 .40945 m .50057 .42509 L .5004 .44931 L p .962 .688 .469 r
F P
0 g
s
.71692 .57234 m .70427 .55799 L .70297 .53294 L p .972 .685 .422 r
F P
0 g
s
.71692 .57234 m .70427 .55799 L .70297 .53294 L p .972 .685 .422 r
F P
0 g
s
.74418 .5646 m .71692 .57234 L .70427 .55799 L p .652 .756 .926 r
F P
0 g
s
.67709 .56579 m .70427 .55799 L .71692 .57234 L p .652 .756 .926 r
F P
0 g
s
.59649 .55255 m .59596 .52745 L .5694 .53536 L p .558 .345 .547 r
F P
0 g
s
.5694 .53536 m .56973 .5604 L .59649 .55255 L p .558 .345 .547 r
F P
0 g
s
.5694 .53536 m .55547 .52069 L .55524 .49591 L p .964 .688 .461 r
F P
0 g
s
.5694 .53536 m .55547 .52069 L .55524 .49591 L p .964 .688 .461 r
F P
0 g
s
.59596 .52745 m .5694 .53536 L .55547 .52069 L p .654 .754 .923 r
F P
0 g
s
.59649 .55255 m .59596 .52745 L .5694 .53536 L p .558 .345 .547 r
F P
0 g
s
.5694 .53536 m .56973 .5604 L .59649 .55255 L p .558 .345 .547 r
F P
0 g
s
.52899 .52867 m .55547 .52069 L .5694 .53536 L p .654 .754 .923 r
F P
0 g
s
.55547 .52069 m .5694 .53536 L .56973 .5604 L p .964 .688 .461 r
F P
0 g
s
.59596 .52745 m .5694 .53536 L .55547 .52069 L p .654 .754 .923 r
F P
0 g
s
.44719 .51512 m .44775 .4903 L .42189 .49839 L p .55 .333 .538 r
F P
0 g
s
.42189 .49839 m .42114 .52315 L .44719 .51512 L p .55 .333 .538 r
F P
0 g
s
.42189 .49839 m .40666 .48339 L .40752 .45888 L p .954 .688 .492 r
F P
0 g
s
.42189 .49839 m .40666 .48339 L .40752 .45888 L p .954 .688 .492 r
F P
0 g
s
.44775 .4903 m .42189 .49839 L .40666 .48339 L p .656 .751 .92 r
F P
0 g
s
.44719 .51512 m .44775 .4903 L .42189 .49839 L p .55 .333 .538 r
F P
0 g
s
.42189 .49839 m .42114 .52315 L .44719 .51512 L p .55 .333 .538 r
F P
0 g
s
.38089 .49155 m .40666 .48339 L .42189 .49839 L p .656 .751 .92 r
F P
0 g
s
.40666 .48339 m .42189 .49839 L .42114 .52315 L p .954 .688 .492 r
F P
0 g
s
.44775 .4903 m .42189 .49839 L .40666 .48339 L p .656 .751 .92 r
F P
0 g
s
.49072 .60873 m .47609 .5947 L .47644 .56937 L p .957 .688 .485 r
F P
0 g
s
.49072 .60873 m .47609 .5947 L .47644 .56937 L p .957 .688 .485 r
F P
0 g
s
.51692 .60116 m .49072 .60873 L .47609 .5947 L p .649 .759 .929 r
F P
0 g
s
.44998 .60233 m .47609 .5947 L .49072 .60873 L p .649 .759 .929 r
F P
0 g
s
.86237 .49777 m .851 .48276 L .84863 .45824 L p .976 .675 .358 r
F P
0 g
s
.86237 .49777 m .851 .48276 L .84863 .45824 L p .976 .675 .358 r
F P
0 g
s
.89032 .48967 m .86237 .49777 L .851 .48276 L p .656 .751 .92 r
F P
0 g
s
.89301 .5145 m .89032 .48967 L .86237 .49777 L p .569 .36 .558 r
F P
0 g
s
.86237 .49777 m .86483 .52254 L .89301 .5145 L p .569 .36 .558 r
F P
0 g
s
.82311 .49092 m .851 .48276 L .86237 .49777 L p .656 .751 .92 r
F P
0 g
s
.82311 .49092 m .851 .48276 L .86237 .49777 L p .656 .751 .92 r
F P
0 g
s
.851 .48276 m .86237 .49777 L .86483 .52254 L p .976 .675 .358 r
F P
0 g
s
.89032 .48967 m .86237 .49777 L .851 .48276 L p .656 .751 .92 r
F P
0 g
s
.851 .48276 m .86237 .49777 L .86483 .52254 L p .976 .675 .358 r
F P
0 g
s
.74366 .47707 m .74206 .45251 L .7148 .46078 L p .561 .349 .55 r
F P
0 g
s
.7148 .46078 m .71619 .48528 L .74366 .47707 L p .561 .349 .55 r
F P
0 g
s
.74206 .45251 m .7148 .46078 L .70214 .44545 L p .658 .749 .917 r
F P
0 g
s
.74366 .47707 m .74206 .45251 L .7148 .46078 L p .561 .349 .55 r
F P
0 g
s
.7148 .46078 m .71619 .48528 L .74366 .47707 L p .561 .349 .55 r
F P
0 g
s
.67496 .45379 m .70214 .44545 L .7148 .46078 L p .658 .749 .917 r
F P
0 g
s
.70214 .44545 m .7148 .46078 L .71619 .48528 L p .974 .684 .41 r
F P
0 g
s
.70214 .44545 m .7148 .46078 L .71619 .48528 L p .974 .684 .41 r
F P
0 g
s
.5943 .43963 m .59379 .41535 L .56723 .42379 L p .553 .337 .541 r
F P
0 g
s
.56723 .42379 m .56755 .44802 L .5943 .43963 L p .553 .337 .541 r
F P
0 g
s
.59379 .41535 m .56723 .42379 L .55327 .40814 L p .66 .747 .915 r
F P
0 g
s
.5943 .43963 m .59379 .41535 L .56723 .42379 L p .553 .337 .541 r
F P
0 g
s
.56723 .42379 m .56755 .44802 L .5943 .43963 L p .553 .337 .541 r
F P
0 g
s
.5268 .41665 m .55327 .40814 L .56723 .42379 L p .66 .747 .915 r
F P
0 g
s
.55327 .40814 m .56723 .42379 L .56755 .44802 L p .966 .687 .452 r
F P
0 g
s
.55327 .40814 m .56723 .42379 L .56755 .44802 L p .966 .687 .452 r
F P
0 g
s
.66405 .55133 m .66303 .52622 L .63614 .53415 L p .561 .349 .55 r
F P
0 g
s
.63614 .53415 m .63695 .5592 L .66405 .55133 L p .561 .349 .55 r
F P
0 g
s
.63614 .53415 m .62278 .51946 L .62206 .49466 L p .969 .687 .442 r
F P
0 g
s
.66303 .52622 m .63614 .53415 L .62278 .51946 L p .654 .754 .923 r
F P
0 g
s
.66405 .55133 m .66303 .52622 L .63614 .53415 L p .561 .349 .55 r
F P
0 g
s
.63614 .53415 m .63695 .5592 L .66405 .55133 L p .561 .349 .55 r
F P
0 g
s
.59596 .52745 m .62278 .51946 L .63614 .53415 L p .654 .754 .923 r
F P
0 g
s
.62278 .51946 m .63614 .53415 L .63695 .5592 L p .969 .687 .442 r
F P
0 g
s
.66303 .52622 m .63614 .53415 L .62278 .51946 L p .654 .754 .923 r
F P
0 g
s
.62278 .51946 m .63614 .53415 L .63695 .5592 L p .969 .687 .442 r
F P
0 g
s
.51464 .51388 m .51472 .48905 L .48852 .49715 L p .553 .337 .541 r
F P
0 g
s
.48852 .49715 m .48825 .52192 L .51464 .51388 L p .553 .337 .541 r
F P
0 g
s
.48852 .49715 m .47386 .48213 L .47423 .45761 L p .959 .688 .477 r
F P
0 g
s
.51472 .48905 m .48852 .49715 L .47386 .48213 L p .656 .751 .92 r
F P
0 g
s
.44775 .4903 m .47386 .48213 L .48852 .49715 L p .656 .751 .92 r
F P
0 g
s
.47386 .48213 m .48852 .49715 L .48825 .52192 L p .959 .688 .477 r
F P
0 g
s
.36523 .47643 m .3664 .45187 L .3409 .46015 L p .544 .324 .532 r
F P
0 g
s
.3409 .46015 m .33956 .48465 L .36523 .47643 L p .544 .324 .532 r
F P
0 g
s
.3409 .46015 m .32495 .44481 L .3264 .42055 L p .949 .687 .505 r
F P
0 g
s
.3409 .46015 m .32495 .44481 L .3264 .42055 L p .949 .687 .505 r
F P
0 g
s
.3664 .45187 m .3409 .46015 L .32495 .44481 L p .658 .749 .917 r
F P
0 g
s
.36523 .47643 m .3664 .45187 L .3409 .46015 L p .544 .324 .532 r
F P
0 g
s
.3409 .46015 m .33956 .48465 L .36523 .47643 L p .544 .324 .532 r
F P
0 g
s
.29954 .45315 m .32495 .44481 L .3409 .46015 L p .658 .749 .917 r
F P
0 g
s
.32495 .44481 m .3409 .46015 L .33956 .48465 L p .949 .687 .505 r
F P
0 g
s
.3664 .45187 m .3409 .46015 L .32495 .44481 L p .658 .749 .917 r
F P
0 g
s
.55742 .60757 m .54336 .59352 L .54323 .56818 L p .962 .688 .469 r
F P
0 g
s
.55742 .60757 m .54336 .59352 L .54323 .56818 L p .962 .688 .469 r
F P
0 g
s
.58395 .59999 m .55742 .60757 L .54336 .59352 L p .649 .759 .929 r
F P
0 g
s
.51692 .60116 m .54336 .59352 L .55742 .60757 L p .649 .759 .929 r
F P
0 g
s
.40975 .57056 m .39439 .55618 L .39534 .53111 L p .952 .687 .499 r
F P
0 g
s
.40975 .57056 m .39439 .55618 L .39534 .53111 L p .952 .687 .499 r
F P
0 g
s
.43558 .5628 m .40975 .57056 L .39439 .55618 L p .652 .756 .926 r
F P
0 g
s
.43493 .58819 m .43558 .5628 L .40975 .57056 L p .553 .337 .541 r
F P
0 g
s
.40975 .57056 m .40891 .59588 L .43493 .58819 L p .553 .337 .541 r
F P
0 g
s
.36865 .564 m .39439 .55618 L .40975 .57056 L p .652 .756 .926 r
F P
0 g
s
.39439 .55618 m .40975 .57056 L .40891 .59588 L p .952 .687 .499 r
F P
0 g
s
.43558 .5628 m .40975 .57056 L .39439 .55618 L p .652 .756 .926 r
F P
0 g
s
.89032 .48967 m .91855 .4815 L .92934 .49653 L p .656 .751 .92 r
F P
0 g
s
.92934 .49653 m .91855 .4815 L .91568 .45697 L p .975 .668 .327 r
F P
0 g
s
.81135 .4758 m .80926 .45123 L .78166 .45951 L p .564 .353 .553 r
F P
0 g
s
.78166 .45951 m .78354 .48402 L .81135 .4758 L p .564 .353 .553 r
F P
0 g
s
.80926 .45123 m .78166 .45951 L .76958 .44416 L p .658 .749 .917 r
F P
0 g
s
.81135 .4758 m .80926 .45123 L .78166 .45951 L p .564 .353 .553 r
F P
0 g
s
.78166 .45951 m .78354 .48402 L .81135 .4758 L p .564 .353 .553 r
F P
0 g
s
.74206 .45251 m .76958 .44416 L .78166 .45951 L p .658 .749 .917 r
F P
0 g
s
.76958 .44416 m .78166 .45951 L .78354 .48402 L p .976 .68 .386 r
F P
0 g
s
.76958 .44416 m .78166 .45951 L .78354 .48402 L p .976 .68 .386 r
F P
0 g
s
.66189 .43833 m .66089 .41404 L .63399 .4225 L p .556 .341 .544 r
F P
0 g
s
.63399 .4225 m .63479 .44674 L .66189 .43833 L p .556 .341 .544 r
F P
0 g
s
.66089 .41404 m .63399 .4225 L .62061 .40682 L p .66 .747 .915 r
F P
0 g
s
.66189 .43833 m .66089 .41404 L .63399 .4225 L p .556 .341 .544 r
F P
0 g
s
.63399 .4225 m .63479 .44674 L .66189 .43833 L p .556 .341 .544 r
F P
0 g
s
.62061 .40682 m .63399 .4225 L .63479 .44674 L p .971 .686 .432 r
F P
0 g
s
.73171 .55011 m .7302 .525 L .70297 .53294 L p .564 .353 .553 r
F P
0 g
s
.70297 .53294 m .70427 .55799 L .73171 .55011 L p .564 .353 .553 r
F P
0 g
s
.7302 .525 m .70297 .53294 L .69019 .51822 L p .654 .754 .923 r
F P
0 g
s
.73171 .55011 m .7302 .525 L .70297 .53294 L p .564 .353 .553 r
F P
0 g
s
.70297 .53294 m .70427 .55799 L .73171 .55011 L p .564 .353 .553 r
F P
0 g
s
.66303 .52622 m .69019 .51822 L .70297 .53294 L p .654 .754 .923 r
F P
0 g
s
.69019 .51822 m .70297 .53294 L .70427 .55799 L p .972 .685 .422 r
F P
0 g
s
.69019 .51822 m .70297 .53294 L .70427 .55799 L p .972 .685 .422 r
F P
0 g
s
.5822 .51264 m .58178 .48779 L .55524 .49591 L p .556 .341 .544 r
F P
0 g
s
.55524 .49591 m .55547 .52069 L .5822 .51264 L p .556 .341 .544 r
F P
0 g
s
.55524 .49591 m .54116 .48087 L .54104 .45634 L p .964 .688 .461 r
F P
0 g
s
.55524 .49591 m .54116 .48087 L .54104 .45634 L p .964 .688 .461 r
F P
0 g
s
.58178 .48779 m .55524 .49591 L .54116 .48087 L p .656 .751 .92 r
F P
0 g
s
.51472 .48905 m .54116 .48087 L .55524 .49591 L p .656 .751 .92 r
F P
0 g
s
.43268 .47516 m .43335 .45059 L .40752 .45888 L p .547 .329 .535 r
F P
0 g
s
.40752 .45888 m .40666 .48339 L .43268 .47516 L p .547 .329 .535 r
F P
0 g
s
.40752 .45888 m .39214 .44351 L .3931 .41926 L p .954 .688 .492 r
F P
0 g
s
.40752 .45888 m .39214 .44351 L .3931 .41926 L p .954 .688 .492 r
F P
0 g
s
.43335 .45059 m .40752 .45888 L .39214 .44351 L p .658 .749 .917 r
F P
0 g
s
.43268 .47516 m .43335 .45059 L .40752 .45888 L p .547 .329 .535 r
F P
0 g
s
.40752 .45888 m .40666 .48339 L .43268 .47516 L p .547 .329 .535 r
F P
0 g
s
.3664 .45187 m .39214 .44351 L .40752 .45888 L p .658 .749 .917 r
F P
0 g
s
.3664 .45187 m .39214 .44351 L .40752 .45888 L p .658 .749 .917 r
F P
0 g
s
.39214 .44351 m .40752 .45888 L .40666 .48339 L p .954 .688 .492 r
F P
0 g
s
.43335 .45059 m .40752 .45888 L .39214 .44351 L p .658 .749 .917 r
F P
0 g
s
.39214 .44351 m .40752 .45888 L .40666 .48339 L p .954 .688 .492 r
F P
0 g
s
.58395 .59999 m .61074 .59234 L .62422 .60641 L p .649 .759 .929 r
F P
0 g
s
.62422 .60641 m .61074 .59234 L .61011 .56699 L p .966 .687 .452 r
F P
0 g
s
.50244 .587 m .50261 .5616 L .47644 .56937 L p .556 .341 .544 r
F P
0 g
s
.47644 .56937 m .47609 .5947 L .50244 .587 L p .556 .341 .544 r
F P
0 g
s
.47644 .56937 m .46166 .55497 L .46212 .52989 L p .957 .688 .485 r
F P
0 g
s
.50261 .5616 m .47644 .56937 L .46166 .55497 L p .652 .756 .926 r
F P
0 g
s
.50244 .587 m .50261 .5616 L .47644 .56937 L p .556 .341 .544 r
F P
0 g
s
.47644 .56937 m .47609 .5947 L .50244 .587 L p .556 .341 .544 r
F P
0 g
s
.43558 .5628 m .46166 .55497 L .47644 .56937 L p .652 .756 .926 r
F P
0 g
s
.43558 .5628 m .46166 .55497 L .47644 .56937 L p .652 .756 .926 r
F P
0 g
s
.46166 .55497 m .47644 .56937 L .47609 .5947 L p .957 .688 .485 r
F P
0 g
s
.46166 .55497 m .47644 .56937 L .47609 .5947 L p .957 .688 .485 r
F P
0 g
s
.87915 .47452 m .87656 .44995 L .84863 .45824 L p .566 .356 .555 r
F P
0 g
s
.84863 .45824 m .851 .48276 L .87915 .47452 L p .566 .356 .555 r
F P
0 g
s
.84863 .45824 m .83712 .44287 L .83485 .41861 L p .976 .675 .358 r
F P
0 g
s
.84863 .45824 m .83712 .44287 L .83485 .41861 L p .976 .675 .358 r
F P
0 g
s
.87656 .44995 m .84863 .45824 L .83712 .44287 L p .658 .749 .917 r
F P
0 g
s
.87915 .47452 m .87656 .44995 L .84863 .45824 L p .566 .356 .555 r
F P
0 g
s
.84863 .45824 m .851 .48276 L .87915 .47452 L p .566 .356 .555 r
F P
0 g
s
.80926 .45123 m .83712 .44287 L .84863 .45824 L p .658 .749 .917 r
F P
0 g
s
.80926 .45123 m .83712 .44287 L .84863 .45824 L p .658 .749 .917 r
F P
0 g
s
.83712 .44287 m .84863 .45824 L .851 .48276 L p .976 .675 .358 r
F P
0 g
s
.87656 .44995 m .84863 .45824 L .83712 .44287 L p .658 .749 .917 r
F P
0 g
s
.83712 .44287 m .84863 .45824 L .851 .48276 L p .976 .675 .358 r
F P
0 g
s
.72808 .41273 m .70085 .4212 L .68804 .4055 L p .66 .747 .915 r
F P
0 g
s
.72957 .43703 m .72808 .41273 L .70085 .4212 L p .558 .345 .547 r
F P
0 g
s
.70085 .4212 m .70214 .44545 L .72957 .43703 L p .558 .345 .547 r
F P
0 g
s
.66089 .41404 m .68804 .4055 L .70085 .4212 L p .66 .747 .915 r
F P
0 g
s
.68804 .4055 m .70085 .4212 L .70214 .44545 L p .974 .684 .41 r
F P
0 g
s
.68804 .4055 m .70085 .4212 L .70214 .44545 L p .974 .684 .41 r
F P
0 g
s
.7699 .53172 m .7577 .51698 L .756 .49217 L p .975 .682 .398 r
F P
0 g
s
.7699 .53172 m .7577 .51698 L .756 .49217 L p .975 .682 .398 r
F P
0 g
s
.79747 .52377 m .7699 .53172 L .7577 .51698 L p .654 .754 .923 r
F P
0 g
s
.79948 .5489 m .79747 .52377 L .7699 .53172 L p .566 .356 .555 r
F P
0 g
s
.7699 .53172 m .77169 .55678 L .79948 .5489 L p .566 .356 .555 r
F P
0 g
s
.7302 .525 m .7577 .51698 L .7699 .53172 L p .654 .754 .923 r
F P
0 g
s
.7302 .525 m .7577 .51698 L .7699 .53172 L p .654 .754 .923 r
F P
0 g
s
.7577 .51698 m .7699 .53172 L .77169 .55678 L p .975 .682 .398 r
F P
0 g
s
.79747 .52377 m .7699 .53172 L .7577 .51698 L p .654 .754 .923 r
F P
0 g
s
.7577 .51698 m .7699 .53172 L .77169 .55678 L p .975 .682 .398 r
F P
0 g
s
.64985 .51139 m .64893 .48654 L .62206 .49466 L p .558 .345 .547 r
F P
0 g
s
.62206 .49466 m .62278 .51946 L .64985 .51139 L p .558 .345 .547 r
F P
0 g
s
.62206 .49466 m .60856 .4796 L .60795 .45506 L p .969 .687 .442 r
F P
0 g
s
.62206 .49466 m .60856 .4796 L .60795 .45506 L p .969 .687 .442 r
F P
0 g
s
.64893 .48654 m .62206 .49466 L .60856 .4796 L p .656 .751 .92 r
F P
0 g
s
.64985 .51139 m .64893 .48654 L .62206 .49466 L p .558 .345 .547 r
F P
0 g
s
.62206 .49466 m .62278 .51946 L .64985 .51139 L p .558 .345 .547 r
F P
0 g
s
.58178 .48779 m .60856 .4796 L .62206 .49466 L p .656 .751 .92 r
F P
0 g
s
.60856 .4796 m .62206 .49466 L .62278 .51946 L p .969 .687 .442 r
F P
0 g
s
.64893 .48654 m .62206 .49466 L .60856 .4796 L p .656 .751 .92 r
F P
0 g
s
.50022 .47389 m .5004 .44931 L .47423 .45761 L p .55 .333 .538 r
F P
0 g
s
.47423 .45761 m .47386 .48213 L .50022 .47389 L p .55 .333 .538 r
F P
0 g
s
.5004 .44931 m .47423 .45761 L .45943 .44222 L p .658 .749 .917 r
F P
0 g
s
.50022 .47389 m .5004 .44931 L .47423 .45761 L p .55 .333 .538 r
F P
0 g
s
.47423 .45761 m .47386 .48213 L .50022 .47389 L p .55 .333 .538 r
F P
0 g
s
.43335 .45059 m .45943 .44222 L .47423 .45761 L p .658 .749 .917 r
F P
0 g
s
.45943 .44222 m .47423 .45761 L .47386 .48213 L p .959 .688 .477 r
F P
0 g
s
.45943 .44222 m .47423 .45761 L .47386 .48213 L p .959 .688 .477 r
F P
0 g
s
.35059 .43638 m .35186 .41208 L .3264 .42055 L p .541 .319 .528 r
F P
0 g
s
.3264 .42055 m .32495 .44481 L .35059 .43638 L p .541 .319 .528 r
F P
0 g
s
.35186 .41208 m .3264 .42055 L .31029 .40484 L p .66 .747 .915 r
F P
0 g
s
.35059 .43638 m .35186 .41208 L .3264 .42055 L p .541 .319 .528 r
F P
0 g
s
.3264 .42055 m .32495 .44481 L .35059 .43638 L p .541 .319 .528 r
F P
0 g
s
.28492 .41339 m .31029 .40484 L .3264 .42055 L p .66 .747 .915 r
F P
0 g
s
.31029 .40484 m .3264 .42055 L .32495 .44481 L p .949 .687 .505 r
F P
0 g
s
.31029 .40484 m .3264 .42055 L .32495 .44481 L p .949 .687 .505 r
F P
0 g
s
.57006 .5858 m .56973 .5604 L .54323 .56818 L p .558 .345 .547 r
F P
0 g
s
.54323 .56818 m .54336 .59352 L .57006 .5858 L p .558 .345 .547 r
F P
0 g
s
.50261 .5616 m .52902 .55376 L .54323 .56818 L p .652 .756 .926 r
F P
0 g
s
.52902 .55376 m .54323 .56818 L .54336 .59352 L p .962 .688 .469 r
F P
0 g
s
.42038 .54829 m .42114 .52315 L .39534 .53111 L p .55 .333 .538 r
F P
0 g
s
.39534 .53111 m .39439 .55618 L .42038 .54829 L p .55 .333 .538 r
F P
0 g
s
.39534 .53111 m .37983 .51636 L .38089 .49155 L p .952 .687 .499 r
F P
0 g
s
.42114 .52315 m .39534 .53111 L .37983 .51636 L p .654 .754 .923 r
F P
0 g
s
.42038 .54829 m .42114 .52315 L .39534 .53111 L p .55 .333 .538 r
F P
0 g
s
.39534 .53111 m .39439 .55618 L .42038 .54829 L p .55 .333 .538 r
F P
0 g
s
.35412 .52438 m .37983 .51636 L .39534 .53111 L p .654 .754 .923 r
F P
0 g
s
.35412 .52438 m .37983 .51636 L .39534 .53111 L p .654 .754 .923 r
F P
0 g
s
.37983 .51636 m .39534 .53111 L .39439 .55618 L p .952 .687 .499 r
F P
0 g
s
.37983 .51636 m .39534 .53111 L .39439 .55618 L p .952 .687 .499 r
F P
0 g
s
.87656 .44995 m .90476 .44158 L .91568 .45697 L p .658 .749 .917 r
F P
0 g
s
.87656 .44995 m .90476 .44158 L .91568 .45697 L p .658 .749 .917 r
F P
0 g
s
.90476 .44158 m .91568 .45697 L .91855 .4815 L p .975 .668 .327 r
F P
0 g
s
.91568 .45697 m .90476 .44158 L .90199 .4173 L p .975 .668 .327 r
F P
0 g
s
.72808 .41273 m .75557 .40418 L .7678 .41991 L p .66 .747 .915 r
F P
0 g
s
.75557 .40418 m .7678 .41991 L .76958 .44416 L p .976 .68 .386 r
F P
0 g
s
.83692 .5305 m .8253 .51574 L .82311 .49092 L p .976 .678 .372 r
F P
0 g
s
.86483 .52254 m .83692 .5305 L .8253 .51574 L p .654 .754 .923 r
F P
0 g
s
.68898 .49342 m .67606 .47834 L .67496 .45379 L p .972 .685 .422 r
F P
0 g
s
.68898 .49342 m .67606 .47834 L .67496 .45379 L p .972 .685 .422 r
F P
0 g
s
.71619 .48528 m .68898 .49342 L .67606 .47834 L p .656 .751 .92 r
F P
0 g
s
.7176 .51014 m .71619 .48528 L .68898 .49342 L p .561 .349 .55 r
F P
0 g
s
.68898 .49342 m .69019 .51822 L .7176 .51014 L p .561 .349 .55 r
F P
0 g
s
.64893 .48654 m .67606 .47834 L .68898 .49342 L p .656 .751 .92 r
F P
0 g
s
.64893 .48654 m .67606 .47834 L .68898 .49342 L p .656 .751 .92 r
F P
0 g
s
.67606 .47834 m .68898 .49342 L .69019 .51822 L p .972 .685 .422 r
F P
0 g
s
.71619 .48528 m .68898 .49342 L .67606 .47834 L p .656 .751 .92 r
F P
0 g
s
.67606 .47834 m .68898 .49342 L .69019 .51822 L p .972 .685 .422 r
F P
0 g
s
.56786 .47261 m .56755 .44802 L .54104 .45634 L p .553 .337 .541 r
F P
0 g
s
.54104 .45634 m .54116 .48087 L .56786 .47261 L p .553 .337 .541 r
F P
0 g
s
.54104 .45634 m .52681 .44093 L .5268 .41665 L p .964 .688 .461 r
F P
0 g
s
.56755 .44802 m .54104 .45634 L .52681 .44093 L p .658 .749 .917 r
F P
0 g
s
.56786 .47261 m .56755 .44802 L .54104 .45634 L p .553 .337 .541 r
F P
0 g
s
.54104 .45634 m .54116 .48087 L .56786 .47261 L p .553 .337 .541 r
F P
0 g
s
.5004 .44931 m .52681 .44093 L .54104 .45634 L p .658 .749 .917 r
F P
0 g
s
.52681 .44093 m .54104 .45634 L .54116 .48087 L p .964 .688 .461 r
F P
0 g
s
.56755 .44802 m .54104 .45634 L .52681 .44093 L p .658 .749 .917 r
F P
0 g
s
.52681 .44093 m .54104 .45634 L .54116 .48087 L p .964 .688 .461 r
F P
0 g
s
.41812 .43508 m .4189 .41077 L .3931 .41926 L p .544 .324 .532 r
F P
0 g
s
.3931 .41926 m .39214 .44351 L .41812 .43508 L p .544 .324 .532 r
F P
0 g
s
.61011 .56699 m .59649 .55255 L .59596 .52745 L p .966 .687 .452 r
F P
0 g
s
.61011 .56699 m .59649 .55255 L .59596 .52745 L p .966 .687 .452 r
F P
0 g
s
.63695 .5592 m .61011 .56699 L .59649 .55255 L p .652 .756 .926 r
F P
0 g
s
.56973 .5604 m .59649 .55255 L .61011 .56699 L p .652 .756 .926 r
F P
0 g
s
.56973 .5604 m .59649 .55255 L .61011 .56699 L p .652 .756 .926 r
F P
0 g
s
.59649 .55255 m .61011 .56699 L .61074 .59234 L p .966 .687 .452 r
F P
0 g
s
.46212 .52989 m .44719 .51512 L .44775 .4903 L p .957 .688 .485 r
F P
0 g
s
.46212 .52989 m .44719 .51512 L .44775 .4903 L p .957 .688 .485 r
F P
0 g
s
.48825 .52192 m .46212 .52989 L .44719 .51512 L p .654 .754 .923 r
F P
0 g
s
.42114 .52315 m .44719 .51512 L .46212 .52989 L p .654 .754 .923 r
F P
0 g
s
.86525 .43443 m .86276 .41011 L .83485 .41861 L p .564 .353 .553 r
F P
0 g
s
.83485 .41861 m .83712 .44287 L .86525 .43443 L p .564 .353 .553 r
F P
0 g
s
.86276 .41011 m .83485 .41861 L .8232 .40286 L p .66 .747 .915 r
F P
0 g
s
.86525 .43443 m .86276 .41011 L .83485 .41861 L p .564 .353 .553 r
F P
0 g
s
.83485 .41861 m .83712 .44287 L .86525 .43443 L p .564 .353 .553 r
F P
0 g
s
.8232 .40286 m .83485 .41861 L .83712 .44287 L p .976 .675 .358 r
F P
0 g
s
.78545 .50889 m .78354 .48402 L .756 .49217 L p .564 .353 .553 r
F P
0 g
s
.756 .49217 m .7577 .51698 L .78545 .50889 L p .564 .353 .553 r
F P
0 g
s
.756 .49217 m .74366 .47707 L .74206 .45251 L p .975 .682 .398 r
F P
0 g
s
.756 .49217 m .74366 .47707 L .74206 .45251 L p .975 .682 .398 r
F P
0 g
s
.78354 .48402 m .756 .49217 L .74366 .47707 L p .656 .751 .92 r
F P
0 g
s
.71619 .48528 m .74366 .47707 L .756 .49217 L p .656 .751 .92 r
F P
0 g
s
.6356 .47133 m .63479 .44674 L .60795 .45506 L p .556 .341 .544 r
F P
0 g
s
.60795 .45506 m .60856 .4796 L .6356 .47133 L p .556 .341 .544 r
F P
0 g
s
.60795 .45506 m .5943 .43963 L .59379 .41535 L p .969 .687 .442 r
F P
0 g
s
.63479 .44674 m .60795 .45506 L .5943 .43963 L p .658 .749 .917 r
F P
0 g
s
.6356 .47133 m .63479 .44674 L .60795 .45506 L p .556 .341 .544 r
F P
0 g
s
.60795 .45506 m .60856 .4796 L .6356 .47133 L p .556 .341 .544 r
F P
0 g
s
.56755 .44802 m .5943 .43963 L .60795 .45506 L p .658 .749 .917 r
F P
0 g
s
.56755 .44802 m .5943 .43963 L .60795 .45506 L p .658 .749 .917 r
F P
0 g
s
.5943 .43963 m .60795 .45506 L .60856 .4796 L p .969 .687 .442 r
F P
0 g
s
.5943 .43963 m .60795 .45506 L .60856 .4796 L p .969 .687 .442 r
F P
0 g
s
.48604 .40945 m .4599 .41796 L .44495 .4022 L p .66 .747 .915 r
F P
0 g
s
.48575 .43377 m .48604 .40945 L .4599 .41796 L p .547 .329 .535 r
F P
0 g
s
.4599 .41796 m .45943 .44222 L .48575 .43377 L p .547 .329 .535 r
F P
0 g
s
.4189 .41077 m .44495 .4022 L .4599 .41796 L p .66 .747 .915 r
F P
0 g
s
.44495 .4022 m .4599 .41796 L .45943 .44222 L p .959 .688 .477 r
F P
0 g
s
.44495 .4022 m .4599 .41796 L .45943 .44222 L p .959 .688 .477 r
F P
0 g
s
.67709 .56579 m .66405 .55133 L .66303 .52622 L p .971 .686 .432 r
F P
0 g
s
.67709 .56579 m .66405 .55133 L .66303 .52622 L p .971 .686 .432 r
F P
0 g
s
.70427 .55799 m .67709 .56579 L .66405 .55133 L p .652 .756 .926 r
F P
0 g
s
.7056 .58341 m .70427 .55799 L .67709 .56579 L p .564 .353 .553 r
F P
0 g
s
.67709 .56579 m .67821 .59115 L .7056 .58341 L p .564 .353 .553 r
F P
0 g
s
.63695 .5592 m .66405 .55133 L .67709 .56579 L p .652 .756 .926 r
F P
0 g
s
.63695 .5592 m .66405 .55133 L .67709 .56579 L p .652 .756 .926 r
F P
0 g
s
.66405 .55133 m .67709 .56579 L .67821 .59115 L p .971 .686 .432 r
F P
0 g
s
.70427 .55799 m .67709 .56579 L .66405 .55133 L p .652 .756 .926 r
F P
0 g
s
.66405 .55133 m .67709 .56579 L .67821 .59115 L p .971 .686 .432 r
F P
0 g
s
.52899 .52867 m .51464 .51388 L .51472 .48905 L p .962 .688 .469 r
F P
0 g
s
.55547 .52069 m .52899 .52867 L .51464 .51388 L p .654 .754 .923 r
F P
0 g
s
.55569 .54584 m .55547 .52069 L .52899 .52867 L p .556 .341 .544 r
F P
0 g
s
.52899 .52867 m .52902 .55376 L .55569 .54584 L p .556 .341 .544 r
F P
0 g
s
.48825 .52192 m .51464 .51388 L .52899 .52867 L p .654 .754 .923 r
F P
0 g
s
.48825 .52192 m .51464 .51388 L .52899 .52867 L p .654 .754 .923 r
F P
0 g
s
.51464 .51388 m .52899 .52867 L .52902 .55376 L p .962 .688 .469 r
F P
0 g
s
.51464 .51388 m .52899 .52867 L .52902 .55376 L p .962 .688 .469 r
F P
0 g
s
.38089 .49155 m .36523 .47643 L .3664 .45187 L p .952 .687 .499 r
F P
0 g
s
.38089 .49155 m .36523 .47643 L .3664 .45187 L p .952 .687 .499 r
F P
0 g
s
.40666 .48339 m .38089 .49155 L .36523 .47643 L p .656 .751 .92 r
F P
0 g
s
.40579 .50827 m .40666 .48339 L .38089 .49155 L p .547 .329 .535 r
F P
0 g
s
.38089 .49155 m .37983 .51636 L .40579 .50827 L p .547 .329 .535 r
F P
0 g
s
.33956 .48465 m .36523 .47643 L .38089 .49155 L p .656 .751 .92 r
F P
0 g
s
.33956 .48465 m .36523 .47643 L .38089 .49155 L p .656 .751 .92 r
F P
0 g
s
.36523 .47643 m .38089 .49155 L .37983 .51636 L p .952 .687 .499 r
F P
0 g
s
.40666 .48339 m .38089 .49155 L .36523 .47643 L p .656 .751 .92 r
F P
0 g
s
.36523 .47643 m .38089 .49155 L .37983 .51636 L p .952 .687 .499 r
F P
0 g
s
.86276 .41011 m .89093 .40153 L .90199 .4173 L p .66 .747 .915 r
F P
0 g
s
.89093 .40153 m .90199 .4173 L .90476 .44158 L p .975 .668 .327 r
F P
0 g
s
.44998 .60233 m .43493 .58819 L .43558 .5628 L p .954 .688 .492 r
F P
0 g
s
.47609 .5947 m .44998 .60233 L .43493 .58819 L p .649 .759 .929 r
F P
0 g
s
.8534 .50764 m .851 .48276 L .82311 .49092 L p .566 .356 .555 r
F P
0 g
s
.82311 .49092 m .8253 .51574 L .8534 .50764 L p .566 .356 .555 r
F P
0 g
s
.82311 .49092 m .81135 .4758 L .80926 .45123 L p .976 .678 .372 r
F P
0 g
s
.82311 .49092 m .81135 .4758 L .80926 .45123 L p .976 .678 .372 r
F P
0 g
s
.851 .48276 m .82311 .49092 L .81135 .4758 L p .656 .751 .92 r
F P
0 g
s
.8534 .50764 m .851 .48276 L .82311 .49092 L p .566 .356 .555 r
F P
0 g
s
.82311 .49092 m .8253 .51574 L .8534 .50764 L p .566 .356 .555 r
F P
0 g
s
.78354 .48402 m .81135 .4758 L .82311 .49092 L p .656 .751 .92 r
F P
0 g
s
.78354 .48402 m .81135 .4758 L .82311 .49092 L p .656 .751 .92 r
F P
0 g
s
.81135 .4758 m .82311 .49092 L .8253 .51574 L p .976 .678 .372 r
F P
0 g
s
.851 .48276 m .82311 .49092 L .81135 .4758 L p .656 .751 .92 r
F P
0 g
s
.81135 .4758 m .82311 .49092 L .8253 .51574 L p .976 .678 .372 r
F P
0 g
s
.70344 .47005 m .70214 .44545 L .67496 .45379 L p .558 .345 .547 r
F P
0 g
s
.67496 .45379 m .67606 .47834 L .70344 .47005 L p .558 .345 .547 r
F P
0 g
s
.67496 .45379 m .66189 .43833 L .66089 .41404 L p .972 .685 .422 r
F P
0 g
s
.67496 .45379 m .66189 .43833 L .66089 .41404 L p .972 .685 .422 r
F P
0 g
s
.70214 .44545 m .67496 .45379 L .66189 .43833 L p .658 .749 .917 r
F P
0 g
s
.63479 .44674 m .66189 .43833 L .67496 .45379 L p .658 .749 .917 r
F P
0 g
s
.55348 .43247 m .55327 .40814 L .5268 .41665 L p .55 .333 .538 r
F P
0 g
s
.5268 .41665 m .52681 .44093 L .55348 .43247 L p .55 .333 .538 r
F P
0 g
s
.55327 .40814 m .5268 .41665 L .51242 .40087 L p .66 .747 .915 r
F P
0 g
s
.55348 .43247 m .55327 .40814 L .5268 .41665 L p .55 .333 .538 r
F P
0 g
s
.5268 .41665 m .52681 .44093 L .55348 .43247 L p .55 .333 .538 r
F P
0 g
s
.48604 .40945 m .51242 .40087 L .5268 .41665 L p .66 .747 .915 r
F P
0 g
s
.51242 .40087 m .5268 .41665 L .52681 .44093 L p .964 .688 .461 r
F P
0 g
s
.51242 .40087 m .5268 .41665 L .52681 .44093 L p .964 .688 .461 r
F P
0 g
s
.74418 .5646 m .73171 .55011 L .7302 .525 L p .974 .684 .41 r
F P
0 g
s
.74418 .5646 m .73171 .55011 L .7302 .525 L p .974 .684 .41 r
F P
0 g
s
.77169 .55678 m .74418 .5646 L .73171 .55011 L p .652 .756 .926 r
F P
0 g
s
.70427 .55799 m .73171 .55011 L .74418 .5646 L p .652 .756 .926 r
F P
0 g
s
.6235 .54462 m .62278 .51946 L .59596 .52745 L p .558 .345 .547 r
F P
0 g
s
.59596 .52745 m .59649 .55255 L .6235 .54462 L p .558 .345 .547 r
F P
0 g
s
.55547 .52069 m .5822 .51264 L .59596 .52745 L p .654 .754 .923 r
F P
0 g
s
.55547 .52069 m .5822 .51264 L .59596 .52745 L p .654 .754 .923 r
F P
0 g
s
.5822 .51264 m .59596 .52745 L .59649 .55255 L p .966 .687 .452 r
F P
0 g
s
.59596 .52745 m .5822 .51264 L .58178 .48779 L p .966 .687 .452 r
F P
0 g
s
.47349 .50702 m .47386 .48213 L .44775 .4903 L p .55 .333 .538 r
F P
0 g
s
.44775 .4903 m .44719 .51512 L .47349 .50702 L p .55 .333 .538 r
F P
0 g
s
.44775 .4903 m .43268 .47516 L .43335 .45059 L p .957 .688 .485 r
F P
0 g
s
.44775 .4903 m .43268 .47516 L .43335 .45059 L p .957 .688 .485 r
F P
0 g
s
.47386 .48213 m .44775 .4903 L .43268 .47516 L p .656 .751 .92 r
F P
0 g
s
.47349 .50702 m .47386 .48213 L .44775 .4903 L p .55 .333 .538 r
F P
0 g
s
.44775 .4903 m .44719 .51512 L .47349 .50702 L p .55 .333 .538 r
F P
0 g
s
.40666 .48339 m .43268 .47516 L .44775 .4903 L p .656 .751 .92 r
F P
0 g
s
.40666 .48339 m .43268 .47516 L .44775 .4903 L p .656 .751 .92 r
F P
0 g
s
.43268 .47516 m .44775 .4903 L .44719 .51512 L p .957 .688 .485 r
F P
0 g
s
.47386 .48213 m .44775 .4903 L .43268 .47516 L p .656 .751 .92 r
F P
0 g
s
.43268 .47516 m .44775 .4903 L .44719 .51512 L p .957 .688 .485 r
F P
0 g
s
.29954 .45315 m .28316 .43768 L .28492 .41339 L p .946 .686 .511 r
F P
0 g
s
.32495 .44481 m .29954 .45315 L .28316 .43768 L p .658 .749 .917 r
F P
0 g
s
.51692 .60116 m .50244 .587 L .50261 .5616 L p .959 .688 .477 r
F P
0 g
s
.51692 .60116 m .50244 .587 L .50261 .5616 L p .959 .688 .477 r
F P
0 g
s
.54336 .59352 m .51692 .60116 L .50244 .587 L p .649 .759 .929 r
F P
0 g
s
.47609 .5947 m .50244 .587 L .51692 .60116 L p .649 .759 .929 r
F P
0 g
s
.36865 .564 m .35287 .5495 L .35412 .52438 L p .949 .687 .505 r
F P
0 g
s
.39439 .55618 m .36865 .564 L .35287 .5495 L p .652 .756 .926 r
F P
0 g
s
.89032 .48967 m .87915 .47452 L .87656 .44995 L p .976 .672 .343 r
F P
0 g
s
.89032 .48967 m .87915 .47452 L .87656 .44995 L p .976 .672 .343 r
F P
0 g
s
.91855 .4815 m .89032 .48967 L .87915 .47452 L p .656 .751 .92 r
F P
0 g
s
.851 .48276 m .87915 .47452 L .89032 .48967 L p .656 .751 .92 r
F P
0 g
s
.851 .48276 m .87915 .47452 L .89032 .48967 L p .656 .751 .92 r
F P
0 g
s
.87915 .47452 m .89032 .48967 L .89301 .5145 L p .976 .672 .343 r
F P
0 g
s
.77139 .46877 m .76958 .44416 L .74206 .45251 L p .561 .349 .55 r
F P
0 g
s
.74206 .45251 m .74366 .47707 L .77139 .46877 L p .561 .349 .55 r
F P
0 g
s
.74206 .45251 m .72957 .43703 L .72808 .41273 L p .975 .682 .398 r
F P
0 g
s
.76958 .44416 m .74206 .45251 L .72957 .43703 L p .658 .749 .917 r
F P
0 g
s
.77139 .46877 m .76958 .44416 L .74206 .45251 L p .561 .349 .55 r
F P
0 g
s
.74206 .45251 m .74366 .47707 L .77139 .46877 L p .561 .349 .55 r
F P
0 g
s
.70214 .44545 m .72957 .43703 L .74206 .45251 L p .658 .749 .917 r
F P
0 g
s
.72957 .43703 m .74206 .45251 L .74366 .47707 L p .975 .682 .398 r
F P
0 g
s
.76958 .44416 m .74206 .45251 L .72957 .43703 L p .658 .749 .917 r
F P
0 g
s
.72957 .43703 m .74206 .45251 L .74366 .47707 L p .975 .682 .398 r
F P
0 g
s
.62061 .40682 m .59379 .41535 L .58 .39954 L p .66 .747 .915 r
F P
0 g
s
.62132 .43116 m .62061 .40682 L .59379 .41535 L p .553 .337 .541 r
F P
0 g
s
.59379 .41535 m .5943 .43963 L .62132 .43116 L p .553 .337 .541 r
F P
0 g
s
.55327 .40814 m .58 .39954 L .59379 .41535 L p .66 .747 .915 r
F P
0 g
s
.58 .39954 m .59379 .41535 L .5943 .43963 L p .969 .687 .442 r
F P
0 g
s
.58 .39954 m .59379 .41535 L .5943 .43963 L p .969 .687 .442 r
F P
0 g
s
.69141 .54339 m .69019 .51822 L .66303 .52622 L p .561 .349 .55 r
F P
0 g
s
.66303 .52622 m .66405 .55133 L .69141 .54339 L p .561 .349 .55 r
F P
0 g
s
.66303 .52622 m .64985 .51139 L .64893 .48654 L p .971 .686 .432 r
F P
0 g
s
.66303 .52622 m .64985 .51139 L .64893 .48654 L p .971 .686 .432 r
F P
0 g
s
.69019 .51822 m .66303 .52622 L .64985 .51139 L p .654 .754 .923 r
F P
0 g
s
.62278 .51946 m .64985 .51139 L .66303 .52622 L p .654 .754 .923 r
F P
0 g
s
.62278 .51946 m .64985 .51139 L .66303 .52622 L p .654 .754 .923 r
F P
0 g
s
.64985 .51139 m .66303 .52622 L .66405 .55133 L p .971 .686 .432 r
F P
0 g
s
.51472 .48905 m .50022 .47389 L .5004 .44931 L p .962 .688 .469 r
F P
0 g
s
.51472 .48905 m .50022 .47389 L .5004 .44931 L p .962 .688 .469 r
F P
0 g
s
.54116 .48087 m .51472 .48905 L .50022 .47389 L p .656 .751 .92 r
F P
0 g
s
.54128 .50576 m .54116 .48087 L .51472 .48905 L p .553 .337 .541 r
F P
0 g
s
.51472 .48905 m .51464 .51388 L .54128 .50576 L p .553 .337 .541 r
F P
0 g
s
.47386 .48213 m .50022 .47389 L .51472 .48905 L p .656 .751 .92 r
F P
0 g
s
.50022 .47389 m .51472 .48905 L .51464 .51388 L p .962 .688 .469 r
F P
0 g
s
.54116 .48087 m .51472 .48905 L .50022 .47389 L p .656 .751 .92 r
F P
0 g
s
.39116 .46813 m .39214 .44351 L .3664 .45187 L p .544 .324 .532 r
F P
0 g
s
.3664 .45187 m .36523 .47643 L .39116 .46813 L p .544 .324 .532 r
F P
0 g
s
.3664 .45187 m .35059 .43638 L .35186 .41208 L p .952 .687 .499 r
F P
0 g
s
.39214 .44351 m .3664 .45187 L .35059 .43638 L p .658 .749 .917 r
F P
0 g
s
.39116 .46813 m .39214 .44351 L .3664 .45187 L p .544 .324 .532 r
F P
0 g
s
.3664 .45187 m .36523 .47643 L .39116 .46813 L p .544 .324 .532 r
F P
0 g
s
.32495 .44481 m .35059 .43638 L .3664 .45187 L p .658 .749 .917 r
F P
0 g
s
.32495 .44481 m .35059 .43638 L .3664 .45187 L p .658 .749 .917 r
F P
0 g
s
.35059 .43638 m .3664 .45187 L .36523 .47643 L p .952 .687 .499 r
F P
0 g
s
.35059 .43638 m .3664 .45187 L .36523 .47643 L p .952 .687 .499 r
F P
0 g
s
.58395 .59999 m .57006 .5858 L .56973 .5604 L p .964 .688 .461 r
F P
0 g
s
.58395 .59999 m .57006 .5858 L .56973 .5604 L p .964 .688 .461 r
F P
0 g
s
.61074 .59234 m .58395 .59999 L .57006 .5858 L p .649 .759 .929 r
F P
0 g
s
.54336 .59352 m .57006 .5858 L .58395 .59999 L p .649 .759 .929 r
F P
0 g
s
.46119 .58042 m .46166 .55497 L .43558 .5628 L p .553 .337 .541 r
F P
0 g
s
.43558 .5628 m .43493 .58819 L .46119 .58042 L p .553 .337 .541 r
F P
0 g
s
.43558 .5628 m .42038 .54829 L .42114 .52315 L p .954 .688 .492 r
F P
0 g
s
.46166 .55497 m .43558 .5628 L .42038 .54829 L p .652 .756 .926 r
F P
0 g
s
.46119 .58042 m .46166 .55497 L .43558 .5628 L p .553 .337 .541 r
F P
0 g
s
.43558 .5628 m .43493 .58819 L .46119 .58042 L p .553 .337 .541 r
F P
0 g
s
.39439 .55618 m .42038 .54829 L .43558 .5628 L p .652 .756 .926 r
F P
0 g
s
.39439 .55618 m .42038 .54829 L .43558 .5628 L p .652 .756 .926 r
F P
0 g
s
.42038 .54829 m .43558 .5628 L .43493 .58819 L p .954 .688 .492 r
F P
0 g
s
.42038 .54829 m .43558 .5628 L .43493 .58819 L p .954 .688 .492 r
F P
0 g
s
.83943 .46749 m .83712 .44287 L .80926 .45123 L p .564 .353 .553 r
F P
0 g
s
.80926 .45123 m .81135 .4758 L .83943 .46749 L p .564 .353 .553 r
F P
0 g
s
.83712 .44287 m .80926 .45123 L .79736 .43573 L p .658 .749 .917 r
F P
0 g
s
.83943 .46749 m .83712 .44287 L .80926 .45123 L p .564 .353 .553 r
F P
0 g
s
.80926 .45123 m .81135 .4758 L .83943 .46749 L p .564 .353 .553 r
F P
0 g
s
.76958 .44416 m .79736 .43573 L .80926 .45123 L p .658 .749 .917 r
F P
0 g
s
.79736 .43573 m .80926 .45123 L .81135 .4758 L p .976 .678 .372 r
F P
0 g
s
.79736 .43573 m .80926 .45123 L .81135 .4758 L p .976 .678 .372 r
F P
0 g
s
.68925 .42985 m .68804 .4055 L .66089 .41404 L p .556 .341 .544 r
F P
0 g
s
.66089 .41404 m .66189 .43833 L .68925 .42985 L p .556 .341 .544 r
F P
0 g
s
.68804 .4055 m .66089 .41404 L .64768 .39821 L p .66 .747 .915 r
F P
0 g
s
.68925 .42985 m .68804 .4055 L .66089 .41404 L p .556 .341 .544 r
F P
0 g
s
.66089 .41404 m .66189 .43833 L .68925 .42985 L p .556 .341 .544 r
F P
0 g
s
.62061 .40682 m .64768 .39821 L .66089 .41404 L p .66 .747 .915 r
F P
0 g
s
.64768 .39821 m .66089 .41404 L .66189 .43833 L p .972 .685 .422 r
F P
0 g
s
.64768 .39821 m .66089 .41404 L .66189 .43833 L p .972 .685 .422 r
F P
0 g
s
.75942 .54216 m .7577 .51698 L .7302 .525 L p .564 .353 .553 r
F P
0 g
s
.7302 .525 m .73171 .55011 L .75942 .54216 L p .564 .353 .553 r
F P
0 g
s
.7577 .51698 m .7302 .525 L .7176 .51014 L p .654 .754 .923 r
F P
0 g
s
.75942 .54216 m .7577 .51698 L .7302 .525 L p .564 .353 .553 r
F P
0 g
s
.7302 .525 m .73171 .55011 L .75942 .54216 L p .564 .353 .553 r
F P
0 g
s
.69019 .51822 m .7176 .51014 L .7302 .525 L p .654 .754 .923 r
F P
0 g
s
.7176 .51014 m .7302 .525 L .73171 .55011 L p .974 .684 .41 r
F P
0 g
s
.7176 .51014 m .7302 .525 L .73171 .55011 L p .974 .684 .41 r
F P
0 g
s
.58178 .48779 m .56786 .47261 L .56755 .44802 L p .966 .687 .452 r
F P
0 g
s
.58178 .48779 m .56786 .47261 L .56755 .44802 L p .966 .687 .452 r
F P
0 g
s
.60856 .4796 m .58178 .48779 L .56786 .47261 L p .656 .751 .92 r
F P
0 g
s
.54116 .48087 m .56786 .47261 L .58178 .48779 L p .656 .751 .92 r
F P
0 g
s
.45894 .46685 m .45943 .44222 L .43335 .45059 L p .547 .329 .535 r
F P
0 g
s
.43335 .45059 m .43268 .47516 L .45894 .46685 L p .547 .329 .535 r
F P
0 g
s
.43335 .45059 m .41812 .43508 L .4189 .41077 L p .957 .688 .485 r
F P
0 g
s
.43335 .45059 m .41812 .43508 L .4189 .41077 L p .957 .688 .485 r
F P
0 g
s
.45943 .44222 m .43335 .45059 L .41812 .43508 L p .658 .749 .917 r
F P
0 g
s
.45894 .46685 m .45943 .44222 L .43335 .45059 L p .547 .329 .535 r
F P
0 g
s
.43335 .45059 m .43268 .47516 L .45894 .46685 L p .547 .329 .535 r
F P
0 g
s
.39214 .44351 m .41812 .43508 L .43335 .45059 L p .658 .749 .917 r
F P
0 g
s
.39214 .44351 m .41812 .43508 L .43335 .45059 L p .658 .749 .917 r
F P
0 g
s
.41812 .43508 m .43335 .45059 L .43268 .47516 L p .957 .688 .485 r
F P
0 g
s
.45943 .44222 m .43335 .45059 L .41812 .43508 L p .658 .749 .917 r
F P
0 g
s
.41812 .43508 m .43335 .45059 L .43268 .47516 L p .957 .688 .485 r
F P
0 g
s
.30871 .42919 m .31029 .40484 L .28492 .41339 L p .537 .315 .524 r
F P
0 g
s
.28492 .41339 m .28316 .43768 L .30871 .42919 L p .537 .315 .524 r
F P
0 g
s
.65109 .59882 m .63778 .58461 L .63695 .5592 L p .969 .687 .442 r
F P
0 g
s
.67821 .59115 m .65109 .59882 L .63778 .58461 L p .649 .759 .929 r
F P
0 g
s
.52906 .57922 m .52902 .55376 L .50261 .5616 L p .556 .341 .544 r
F P
0 g
s
.50261 .5616 m .50244 .587 L .52906 .57922 L p .556 .341 .544 r
F P
0 g
s
.50261 .5616 m .48799 .54706 L .48825 .52192 L p .959 .688 .477 r
F P
0 g
s
.52902 .55376 m .50261 .5616 L .48799 .54706 L p .652 .756 .926 r
F P
0 g
s
.52906 .57922 m .52902 .55376 L .50261 .5616 L p .556 .341 .544 r
F P
0 g
s
.50261 .5616 m .50244 .587 L .52906 .57922 L p .556 .341 .544 r
F P
0 g
s
.46166 .55497 m .48799 .54706 L .50261 .5616 L p .652 .756 .926 r
F P
0 g
s
.48799 .54706 m .50261 .5616 L .50244 .587 L p .959 .688 .477 r
F P
0 g
s
.52902 .55376 m .50261 .5616 L .48799 .54706 L p .652 .756 .926 r
F P
0 g
s
.48799 .54706 m .50261 .5616 L .50244 .587 L p .959 .688 .477 r
F P
0 g
s
.37876 .54155 m .37983 .51636 L .35412 .52438 L p .547 .329 .535 r
F P
0 g
s
.35412 .52438 m .35287 .5495 L .37876 .54155 L p .547 .329 .535 r
F P
0 g
s
.35412 .52438 m .33819 .50952 L .33956 .48465 L p .949 .687 .505 r
F P
0 g
s
.37983 .51636 m .35412 .52438 L .33819 .50952 L p .654 .754 .923 r
F P
0 g
s
.37876 .54155 m .37983 .51636 L .35412 .52438 L p .547 .329 .535 r
F P
0 g
s
.35412 .52438 m .35287 .5495 L .37876 .54155 L p .547 .329 .535 r
F P
0 g
s
.33819 .50952 m .35412 .52438 L .35287 .5495 L p .949 .687 .505 r
F P
0 g
s
.37983 .51636 m .35412 .52438 L .33819 .50952 L p .654 .754 .923 r
F P
0 g
s
.90757 .46621 m .90476 .44158 L .87656 .44995 L p .566 .356 .555 r
F P
0 g
s
.87656 .44995 m .87915 .47452 L .90757 .46621 L p .566 .356 .555 r
F P
0 g
s
.87656 .44995 m .86525 .43443 L .86276 .41011 L p .976 .672 .343 r
F P
0 g
s
.87656 .44995 m .86525 .43443 L .86276 .41011 L p .976 .672 .343 r
F P
0 g
s
.90476 .44158 m .87656 .44995 L .86525 .43443 L p .658 .749 .917 r
F P
0 g
s
.90757 .46621 m .90476 .44158 L .87656 .44995 L p .566 .356 .555 r
F P
0 g
s
.87656 .44995 m .87915 .47452 L .90757 .46621 L p .566 .356 .555 r
F P
0 g
s
.83712 .44287 m .86525 .43443 L .87656 .44995 L p .658 .749 .917 r
F P
0 g
s
.83712 .44287 m .86525 .43443 L .87656 .44995 L p .658 .749 .917 r
F P
0 g
s
.86525 .43443 m .87656 .44995 L .87915 .47452 L p .976 .672 .343 r
F P
0 g
s
.90476 .44158 m .87656 .44995 L .86525 .43443 L p .658 .749 .917 r
F P
0 g
s
.86525 .43443 m .87656 .44995 L .87915 .47452 L p .976 .672 .343 r
F P
0 g
s
.75728 .42853 m .75557 .40418 L .72808 .41273 L p .558 .345 .547 r
F P
0 g
s
.72808 .41273 m .72957 .43703 L .75728 .42853 L p .558 .345 .547 r
F P
0 g
s
.68804 .4055 m .71545 .39688 L .72808 .41273 L p .66 .747 .915 r
F P
0 g
s
.71545 .39688 m .72808 .41273 L .72957 .43703 L p .975 .682 .398 r
F P
0 g
s
.79747 .52377 m .78545 .50889 L .78354 .48402 L p .976 .68 .386 r
F P
0 g
s
.79747 .52377 m .78545 .50889 L .78354 .48402 L p .976 .68 .386 r
F P
0 g
s
.8253 .51574 m .79747 .52377 L .78545 .50889 L p .654 .754 .923 r
F P
0 g
s
.82753 .54093 m .8253 .51574 L .79747 .52377 L p .566 .356 .555 r
F P
0 g
s
.79747 .52377 m .79948 .5489 L .82753 .54093 L p .566 .356 .555 r
F P
0 g
s
.7577 .51698 m .78545 .50889 L .79747 .52377 L p .654 .754 .923 r
F P
0 g
s
.7577 .51698 m .78545 .50889 L .79747 .52377 L p .654 .754 .923 r
F P
0 g
s
.78545 .50889 m .79747 .52377 L .79948 .5489 L p .976 .68 .386 r
F P
0 g
s
.8253 .51574 m .79747 .52377 L .78545 .50889 L p .654 .754 .923 r
F P
0 g
s
.78545 .50889 m .79747 .52377 L .79948 .5489 L p .976 .68 .386 r
F P
0 g
s
.67718 .50325 m .67606 .47834 L .64893 .48654 L p .558 .345 .547 r
F P
0 g
s
.64893 .48654 m .64985 .51139 L .67718 .50325 L p .558 .345 .547 r
F P
0 g
s
.64893 .48654 m .6356 .47133 L .63479 .44674 L p .971 .686 .432 r
F P
0 g
s
.67606 .47834 m .64893 .48654 L .6356 .47133 L p .656 .751 .92 r
F P
0 g
s
.67718 .50325 m .67606 .47834 L .64893 .48654 L p .558 .345 .547 r
F P
0 g
s
.64893 .48654 m .64985 .51139 L .67718 .50325 L p .558 .345 .547 r
F P
0 g
s
.60856 .4796 m .6356 .47133 L .64893 .48654 L p .656 .751 .92 r
F P
0 g
s
.60856 .4796 m .6356 .47133 L .64893 .48654 L p .656 .751 .92 r
F P
0 g
s
.6356 .47133 m .64893 .48654 L .64985 .51139 L p .971 .686 .432 r
F P
0 g
s
.6356 .47133 m .64893 .48654 L .64985 .51139 L p .971 .686 .432 r
F P
0 g
s
.52683 .46556 m .52681 .44093 L .5004 .44931 L p .55 .333 .538 r
F P
0 g
s
.5004 .44931 m .50022 .47389 L .52683 .46556 L p .55 .333 .538 r
F P
0 g
s
.5004 .44931 m .48575 .43377 L .48604 .40945 L p .962 .688 .469 r
F P
0 g
s
.52681 .44093 m .5004 .44931 L .48575 .43377 L p .658 .749 .917 r
F P
0 g
s
.52683 .46556 m .52681 .44093 L .5004 .44931 L p .55 .333 .538 r
F P
0 g
s
.5004 .44931 m .50022 .47389 L .52683 .46556 L p .55 .333 .538 r
F P
0 g
s
.45943 .44222 m .48575 .43377 L .5004 .44931 L p .658 .749 .917 r
F P
0 g
s
.48575 .43377 m .5004 .44931 L .50022 .47389 L p .962 .688 .469 r
F P
0 g
s
.52681 .44093 m .5004 .44931 L .48575 .43377 L p .658 .749 .917 r
F P
0 g
s
.48575 .43377 m .5004 .44931 L .50022 .47389 L p .962 .688 .469 r
F P
0 g
s
.31029 .40484 m .33591 .39621 L .35186 .41208 L p .66 .747 .915 r
F P
0 g
s
.33591 .39621 m .35186 .41208 L .35059 .43638 L p .952 .687 .499 r
F P
0 g
s
.59702 .57801 m .59649 .55255 L .56973 .5604 L p .558 .345 .547 r
F P
0 g
s
.56973 .5604 m .57006 .5858 L .59702 .57801 L p .558 .345 .547 r
F P
0 g
s
.56973 .5604 m .55569 .54584 L .55547 .52069 L p .964 .688 .461 r
F P
0 g
s
.59649 .55255 m .56973 .5604 L .55569 .54584 L p .652 .756 .926 r
F P
0 g
s
.59702 .57801 m .59649 .55255 L .56973 .5604 L p .558 .345 .547 r
F P
0 g
s
.56973 .5604 m .57006 .5858 L .59702 .57801 L p .558 .345 .547 r
F P
0 g
s
.55569 .54584 m .56973 .5604 L .57006 .5858 L p .964 .688 .461 r
F P
0 g
s
.59649 .55255 m .56973 .5604 L .55569 .54584 L p .652 .756 .926 r
F P
0 g
s
.42114 .52315 m .40579 .50827 L .40666 .48339 L p .954 .688 .492 r
F P
0 g
s
.44719 .51512 m .42114 .52315 L .40579 .50827 L p .654 .754 .923 r
F P
0 g
s
.44662 .54032 m .44719 .51512 L .42114 .52315 L p .55 .333 .538 r
F P
0 g
s
.42114 .52315 m .42038 .54829 L .44662 .54032 L p .55 .333 .538 r
F P
0 g
s
.37983 .51636 m .40579 .50827 L .42114 .52315 L p .654 .754 .923 r
F P
0 g
s
.40579 .50827 m .42114 .52315 L .42038 .54829 L p .954 .688 .492 r
F P
0 g
s
.44719 .51512 m .42114 .52315 L .40579 .50827 L p .654 .754 .923 r
F P
0 g
s
.40579 .50827 m .42114 .52315 L .42038 .54829 L p .954 .688 .492 r
F P
0 g
s
.8232 .40286 m .79537 .41142 L .78333 .39555 L p .66 .747 .915 r
F P
0 g
s
.82541 .42722 m .8232 .40286 L .79537 .41142 L p .561 .349 .55 r
F P
0 g
s
.79537 .41142 m .79736 .43573 L .82541 .42722 L p .561 .349 .55 r
F P
0 g
s
.78333 .39555 m .79537 .41142 L .79736 .43573 L p .976 .678 .372 r
F P
0 g
s
.86483 .52254 m .8534 .50764 L .851 .48276 L p .976 .675 .358 r
F P
0 g
s
.86483 .52254 m .8534 .50764 L .851 .48276 L p .976 .675 .358 r
F P
0 g
s
.89301 .5145 m .86483 .52254 L .8534 .50764 L p .654 .754 .923 r
F P
0 g
s
.8253 .51574 m .8534 .50764 L .86483 .52254 L p .654 .754 .923 r
F P
0 g
s
.71619 .48528 m .70344 .47005 L .70214 .44545 L p .974 .684 .41 r
F P
0 g
s
.71619 .48528 m .70344 .47005 L .70214 .44545 L p .974 .684 .41 r
F P
0 g
s
.74366 .47707 m .71619 .48528 L .70344 .47005 L p .656 .751 .92 r
F P
0 g
s
.74528 .50199 m .74366 .47707 L .71619 .48528 L p .561 .349 .55 r
F P
0 g
s
.71619 .48528 m .7176 .51014 L .74528 .50199 L p .561 .349 .55 r
F P
0 g
s
.67606 .47834 m .70344 .47005 L .71619 .48528 L p .656 .751 .92 r
F P
0 g
s
.67606 .47834 m .70344 .47005 L .71619 .48528 L p .656 .751 .92 r
F P
0 g
s
.70344 .47005 m .71619 .48528 L .7176 .51014 L p .974 .684 .41 r
F P
0 g
s
.74366 .47707 m .71619 .48528 L .70344 .47005 L p .656 .751 .92 r
F P
0 g
s
.70344 .47005 m .71619 .48528 L .7176 .51014 L p .974 .684 .41 r
F P
0 g
s
.59482 .46427 m .5943 .43963 L .56755 .44802 L p .553 .337 .541 r
F P
0 g
s
.56755 .44802 m .56786 .47261 L .59482 .46427 L p .553 .337 .541 r
F P
0 g
s
.56755 .44802 m .55348 .43247 L .55327 .40814 L p .966 .687 .452 r
F P
0 g
s
.56755 .44802 m .55348 .43247 L .55327 .40814 L p .966 .687 .452 r
F P
0 g
s
.5943 .43963 m .56755 .44802 L .55348 .43247 L p .658 .749 .917 r
F P
0 g
s
.59482 .46427 m .5943 .43963 L .56755 .44802 L p .553 .337 .541 r
F P
0 g
s
.56755 .44802 m .56786 .47261 L .59482 .46427 L p .553 .337 .541 r
F P
0 g
s
.52681 .44093 m .55348 .43247 L .56755 .44802 L p .658 .749 .917 r
F P
0 g
s
.52681 .44093 m .55348 .43247 L .56755 .44802 L p .658 .749 .917 r
F P
0 g
s
.55348 .43247 m .56755 .44802 L .56786 .47261 L p .966 .687 .452 r
F P
0 g
s
.5943 .43963 m .56755 .44802 L .55348 .43247 L p .658 .749 .917 r
F P
0 g
s
.55348 .43247 m .56755 .44802 L .56786 .47261 L p .966 .687 .452 r
F P
0 g
s
.44436 .42656 m .44495 .4022 L .4189 .41077 L p .544 .324 .532 r
F P
0 g
s
.4189 .41077 m .41812 .43508 L .44436 .42656 L p .544 .324 .532 r
F P
0 g
s
.66508 .57681 m .66405 .55133 L .63695 .5592 L p .561 .349 .55 r
F P
0 g
s
.63695 .5592 m .63778 .58461 L .66508 .57681 L p .561 .349 .55 r
F P
0 g
s
.63695 .5592 m .6235 .54462 L .62278 .51946 L p .969 .687 .442 r
F P
0 g
s
.63695 .5592 m .6235 .54462 L .62278 .51946 L p .969 .687 .442 r
F P
0 g
s
.66405 .55133 m .63695 .5592 L .6235 .54462 L p .652 .756 .926 r
F P
0 g
s
.66508 .57681 m .66405 .55133 L .63695 .5592 L p .561 .349 .55 r
F P
0 g
s
.63695 .5592 m .63778 .58461 L .66508 .57681 L p .561 .349 .55 r
F P
0 g
s
.59649 .55255 m .6235 .54462 L .63695 .5592 L p .652 .756 .926 r
F P
0 g
s
.6235 .54462 m .63695 .5592 L .63778 .58461 L p .969 .687 .442 r
F P
0 g
s
.66405 .55133 m .63695 .5592 L .6235 .54462 L p .652 .756 .926 r
F P
0 g
s
.51457 .53908 m .51464 .51388 L .48825 .52192 L p .553 .337 .541 r
F P
0 g
s
.48825 .52192 m .48799 .54706 L .51457 .53908 L p .553 .337 .541 r
F P
0 g
s
.48825 .52192 m .47349 .50702 L .47386 .48213 L p .959 .688 .477 r
F P
0 g
s
.51464 .51388 m .48825 .52192 L .47349 .50702 L p .654 .754 .923 r
F P
0 g
s
.51457 .53908 m .51464 .51388 L .48825 .52192 L p .553 .337 .541 r
F P
0 g
s
.48825 .52192 m .48799 .54706 L .51457 .53908 L p .553 .337 .541 r
F P
0 g
s
.44719 .51512 m .47349 .50702 L .48825 .52192 L p .654 .754 .923 r
F P
0 g
s
.47349 .50702 m .48825 .52192 L .48799 .54706 L p .959 .688 .477 r
F P
0 g
s
.36406 .50136 m .36523 .47643 L .33956 .48465 L p .544 .324 .532 r
F P
0 g
s
.33956 .48465 m .33819 .50952 L .36406 .50136 L p .544 .324 .532 r
F P
0 g
s
.33956 .48465 m .32347 .46941 L .32495 .44481 L p .949 .687 .505 r
F P
0 g
s
.36523 .47643 m .33956 .48465 L .32347 .46941 L p .656 .751 .92 r
F P
0 g
s
.36406 .50136 m .36523 .47643 L .33956 .48465 L p .544 .324 .532 r
F P
0 g
s
.33956 .48465 m .33819 .50952 L .36406 .50136 L p .544 .324 .532 r
F P
0 g
s
.32347 .46941 m .33956 .48465 L .33819 .50952 L p .949 .687 .505 r
F P
0 g
s
.36523 .47643 m .33956 .48465 L .32347 .46941 L p .656 .751 .92 r
F P
0 g
s
.89364 .4259 m .89093 .40153 L .86276 .41011 L p .564 .353 .553 r
F P
0 g
s
.86276 .41011 m .86525 .43443 L .89364 .4259 L p .564 .353 .553 r
F P
0 g
s
.89093 .40153 m .86276 .41011 L .8513 .39421 L p .66 .747 .915 r
F P
0 g
s
.89364 .4259 m .89093 .40153 L .86276 .41011 L p .564 .353 .553 r
F P
0 g
s
.86276 .41011 m .86525 .43443 L .89364 .4259 L p .564 .353 .553 r
F P
0 g
s
.8232 .40286 m .8513 .39421 L .86276 .41011 L p .66 .747 .915 r
F P
0 g
s
.8513 .39421 m .86276 .41011 L .86525 .43443 L p .976 .672 .343 r
F P
0 g
s
.8513 .39421 m .86276 .41011 L .86525 .43443 L p .976 .672 .343 r
F P
0 g
s
.40891 .59588 m .39343 .58162 L .39439 .55618 L p .952 .687 .499 r
F P
0 g
s
.43493 .58819 m .40891 .59588 L .39343 .58162 L p .649 .759 .929 r
F P
0 g
s
.81347 .50073 m .81135 .4758 L .78354 .48402 L p .564 .353 .553 r
F P
0 g
s
.78354 .48402 m .78545 .50889 L .81347 .50073 L p .564 .353 .553 r
F P
0 g
s
.78354 .48402 m .77139 .46877 L .76958 .44416 L p .976 .68 .386 r
F P
0 g
s
.78354 .48402 m .77139 .46877 L .76958 .44416 L p .976 .68 .386 r
F P
0 g
s
.81135 .4758 m .78354 .48402 L .77139 .46877 L p .656 .751 .92 r
F P
0 g
s
.74366 .47707 m .77139 .46877 L .78354 .48402 L p .656 .751 .92 r
F P
0 g
s
.63479 .44674 m .62132 .43116 L .62061 .40682 L p .971 .686 .432 r
F P
0 g
s
.66189 .43833 m .63479 .44674 L .62132 .43116 L p .658 .749 .917 r
F P
0 g
s
.6629 .46298 m .66189 .43833 L .63479 .44674 L p .556 .341 .544 r
F P
0 g
s
.63479 .44674 m .6356 .47133 L .6629 .46298 L p .556 .341 .544 r
F P
0 g
s
.5943 .43963 m .62132 .43116 L .63479 .44674 L p .658 .749 .917 r
F P
0 g
s
.62132 .43116 m .63479 .44674 L .6356 .47133 L p .971 .686 .432 r
F P
0 g
s
.66189 .43833 m .63479 .44674 L .62132 .43116 L p .658 .749 .917 r
F P
0 g
s
.62132 .43116 m .63479 .44674 L .6356 .47133 L p .971 .686 .432 r
F P
0 g
s
.51233 .42524 m .51242 .40087 L .48604 .40945 L p .547 .329 .535 r
F P
0 g
s
.48604 .40945 m .48575 .43377 L .51233 .42524 L p .547 .329 .535 r
F P
0 g
s
.51242 .40087 m .48604 .40945 L .47125 .39354 L p .66 .747 .915 r
F P
0 g
s
.51233 .42524 m .51242 .40087 L .48604 .40945 L p .547 .329 .535 r
F P
0 g
s
.48604 .40945 m .48575 .43377 L .51233 .42524 L p .547 .329 .535 r
F P
0 g
s
.44495 .4022 m .47125 .39354 L .48604 .40945 L p .66 .747 .915 r
F P
0 g
s
.47125 .39354 m .48604 .40945 L .48575 .43377 L p .962 .688 .469 r
F P
0 g
s
.47125 .39354 m .48604 .40945 L .48575 .43377 L p .962 .688 .469 r
F P
0 g
s
.70427 .55799 m .69141 .54339 L .69019 .51822 L p .972 .685 .422 r
F P
0 g
s
.70427 .55799 m .69141 .54339 L .69019 .51822 L p .972 .685 .422 r
F P
0 g
s
.73171 .55011 m .70427 .55799 L .69141 .54339 L p .652 .756 .926 r
F P
0 g
s
.66405 .55133 m .69141 .54339 L .70427 .55799 L p .652 .756 .926 r
F P
0 g
s
.66405 .55133 m .69141 .54339 L .70427 .55799 L p .652 .756 .926 r
F P
0 g
s
.69141 .54339 m .70427 .55799 L .7056 .58341 L p .972 .685 .422 r
F P
0 g
s
.58262 .53785 m .5822 .51264 L .55547 .52069 L p .556 .341 .544 r
F P
0 g
s
.55547 .52069 m .55569 .54584 L .58262 .53785 L p .556 .341 .544 r
F P
0 g
s
.5822 .51264 m .55547 .52069 L .54128 .50576 L p .654 .754 .923 r
F P
0 g
s
.58262 .53785 m .5822 .51264 L .55547 .52069 L p .556 .341 .544 r
F P
0 g
s
.55547 .52069 m .55569 .54584 L .58262 .53785 L p .556 .341 .544 r
F P
0 g
s
.51464 .51388 m .54128 .50576 L .55547 .52069 L p .654 .754 .923 r
F P
0 g
s
.54128 .50576 m .55547 .52069 L .55569 .54584 L p .964 .688 .461 r
F P
0 g
s
.54128 .50576 m .55547 .52069 L .55569 .54584 L p .964 .688 .461 r
F P
0 g
s
.432 .50009 m .43268 .47516 L .40666 .48339 L p .547 .329 .535 r
F P
0 g
s
.40666 .48339 m .40579 .50827 L .432 .50009 L p .547 .329 .535 r
F P
0 g
s
.40666 .48339 m .39116 .46813 L .39214 .44351 L p .954 .688 .492 r
F P
0 g
s
.40666 .48339 m .39116 .46813 L .39214 .44351 L p .954 .688 .492 r
F P
0 g
s
.43268 .47516 m .40666 .48339 L .39116 .46813 L p .656 .751 .92 r
F P
0 g
s
.36523 .47643 m .39116 .46813 L .40666 .48339 L p .656 .751 .92 r
F P
0 g
s
.36523 .47643 m .39116 .46813 L .40666 .48339 L p .656 .751 .92 r
F P
0 g
s
.39116 .46813 m .40666 .48339 L .40579 .50827 L p .954 .688 .492 r
F P
0 g
s
.47609 .5947 m .46119 .58042 L .46166 .55497 L p .957 .688 .485 r
F P
0 g
s
.47609 .5947 m .46119 .58042 L .46166 .55497 L p .957 .688 .485 r
F P
0 g
s
.50244 .587 m .47609 .5947 L .46119 .58042 L p .649 .759 .929 r
F P
0 g
s
.43493 .58819 m .46119 .58042 L .47609 .5947 L p .649 .759 .929 r
F P
0 g
s
.88177 .49946 m .87915 .47452 L .851 .48276 L p .566 .356 .555 r
F P
0 g
s
.851 .48276 m .8534 .50764 L .88177 .49946 L p .566 .356 .555 r
F P
0 g
s
.851 .48276 m .83943 .46749 L .83712 .44287 L p .976 .675 .358 r
F P
0 g
s
.851 .48276 m .83943 .46749 L .83712 .44287 L p .976 .675 .358 r
F P
0 g
s
.87915 .47452 m .851 .48276 L .83943 .46749 L p .656 .751 .92 r
F P
0 g
s
.88177 .49946 m .87915 .47452 L .851 .48276 L p .566 .356 .555 r
F P
0 g
s
.851 .48276 m .8534 .50764 L .88177 .49946 L p .566 .356 .555 r
F P
0 g
s
.81135 .4758 m .83943 .46749 L .851 .48276 L p .656 .751 .92 r
F P
0 g
s
.81135 .4758 m .83943 .46749 L .851 .48276 L p .656 .751 .92 r
F P
0 g
s
.83943 .46749 m .851 .48276 L .8534 .50764 L p .976 .675 .358 r
F P
0 g
s
.87915 .47452 m .851 .48276 L .83943 .46749 L p .656 .751 .92 r
F P
0 g
s
.83943 .46749 m .851 .48276 L .8534 .50764 L p .976 .675 .358 r
F P
0 g
s
.73109 .46169 m .72957 .43703 L .70214 .44545 L p .558 .345 .547 r
F P
0 g
s
.70214 .44545 m .70344 .47005 L .73109 .46169 L p .558 .345 .547 r
F P
0 g
s
.70214 .44545 m .68925 .42985 L .68804 .4055 L p .974 .684 .41 r
F P
0 g
s
.70214 .44545 m .68925 .42985 L .68804 .4055 L p .974 .684 .41 r
F P
0 g
s
.72957 .43703 m .70214 .44545 L .68925 .42985 L p .658 .749 .917 r
F P
0 g
s
.73109 .46169 m .72957 .43703 L .70214 .44545 L p .558 .345 .547 r
F P
0 g
s
.70214 .44545 m .70344 .47005 L .73109 .46169 L p .558 .345 .547 r
F P
0 g
s
.66189 .43833 m .68925 .42985 L .70214 .44545 L p .658 .749 .917 r
F P
0 g
s
.68925 .42985 m .70214 .44545 L .70344 .47005 L p .974 .684 .41 r
F P
0 g
s
.72957 .43703 m .70214 .44545 L .68925 .42985 L p .658 .749 .917 r
F P
0 g
s
.58041 .42392 m .58 .39954 L .55327 .40814 L p .55 .333 .538 r
F P
0 g
s
.55327 .40814 m .55348 .43247 L .58041 .42392 L p .55 .333 .538 r
F P
0 g
s
.58 .39954 m .55327 .40814 L .53907 .3922 L p .66 .747 .915 r
F P
0 g
s
.58041 .42392 m .58 .39954 L .55327 .40814 L p .55 .333 .538 r
F P
0 g
s
.55327 .40814 m .55348 .43247 L .58041 .42392 L p .55 .333 .538 r
F P
0 g
s
.51242 .40087 m .53907 .3922 L .55327 .40814 L p .66 .747 .915 r
F P
0 g
s
.53907 .3922 m .55327 .40814 L .55348 .43247 L p .966 .687 .452 r
F P
0 g
s
.53907 .3922 m .55327 .40814 L .55348 .43247 L p .966 .687 .452 r
F P
0 g
s
.77169 .55678 m .75942 .54216 L .7577 .51698 L p .975 .682 .398 r
F P
0 g
s
.77169 .55678 m .75942 .54216 L .7577 .51698 L p .975 .682 .398 r
F P
0 g
s
.79948 .5489 m .77169 .55678 L .75942 .54216 L p .652 .756 .926 r
F P
0 g
s
.73171 .55011 m .75942 .54216 L .77169 .55678 L p .652 .756 .926 r
F P
0 g
s
.65078 .53661 m .64985 .51139 L .62278 .51946 L p .558 .345 .547 r
F P
0 g
s
.62278 .51946 m .6235 .54462 L .65078 .53661 L p .558 .345 .547 r
F P
0 g
s
.62278 .51946 m .60918 .5045 L .60856 .4796 L p .969 .687 .442 r
F P
0 g
s
.64985 .51139 m .62278 .51946 L .60918 .5045 L p .654 .754 .923 r
F P
0 g
s
.65078 .53661 m .64985 .51139 L .62278 .51946 L p .558 .345 .547 r
F P
0 g
s
.62278 .51946 m .6235 .54462 L .65078 .53661 L p .558 .345 .547 r
F P
0 g
s
.60918 .5045 m .62278 .51946 L .6235 .54462 L p .969 .687 .442 r
F P
0 g
s
.64985 .51139 m .62278 .51946 L .60918 .5045 L p .654 .754 .923 r
F P
0 g
s
.47386 .48213 m .45894 .46685 L .45943 .44222 L p .959 .688 .477 r
F P
0 g
s
.47386 .48213 m .45894 .46685 L .45943 .44222 L p .959 .688 .477 r
F P
0 g
s
.50022 .47389 m .47386 .48213 L .45894 .46685 L p .656 .751 .92 r
F P
0 g
s
.43268 .47516 m .45894 .46685 L .47386 .48213 L p .656 .751 .92 r
F P
0 g
s
.43268 .47516 m .45894 .46685 L .47386 .48213 L p .656 .751 .92 r
F P
0 g
s
.45894 .46685 m .47386 .48213 L .47349 .50702 L p .959 .688 .477 r
F P
0 g
s
.3493 .46105 m .35059 .43638 L .32495 .44481 L p .541 .319 .528 r
F P
0 g
s
.32495 .44481 m .32347 .46941 L .3493 .46105 L p .541 .319 .528 r
F P
0 g
s
.32495 .44481 m .30871 .42919 L .31029 .40484 L p .949 .687 .505 r
F P
0 g
s
.32495 .44481 m .30871 .42919 L .31029 .40484 L p .949 .687 .505 r
F P
0 g
s
.35059 .43638 m .32495 .44481 L .30871 .42919 L p .658 .749 .917 r
F P
0 g
s
.28316 .43768 m .30871 .42919 L .32495 .44481 L p .658 .749 .917 r
F P
0 g
s
.50244 .587 m .52906 .57922 L .54336 .59352 L p .649 .759 .929 r
F P
0 g
s
.54336 .59352 m .52906 .57922 L .52902 .55376 L p .962 .688 .469 r
F P
0 g
s
.41961 .57379 m .42038 .54829 L .39439 .55618 L p .55 .333 .538 r
F P
0 g
s
.39439 .55618 m .39343 .58162 L .41961 .57379 L p .55 .333 .538 r
F P
0 g
s
.39439 .55618 m .37876 .54155 L .37983 .51636 L p .952 .687 .499 r
F P
0 g
s
.39439 .55618 m .37876 .54155 L .37983 .51636 L p .952 .687 .499 r
F P
0 g
s
.42038 .54829 m .39439 .55618 L .37876 .54155 L p .652 .756 .926 r
F P
0 g
s
.41961 .57379 m .42038 .54829 L .39439 .55618 L p .55 .333 .538 r
F P
0 g
s
.39439 .55618 m .39343 .58162 L .41961 .57379 L p .55 .333 .538 r
F P
0 g
s
.35287 .5495 m .37876 .54155 L .39439 .55618 L p .652 .756 .926 r
F P
0 g
s
.37876 .54155 m .39439 .55618 L .39343 .58162 L p .952 .687 .499 r
F P
0 g
s
.42038 .54829 m .39439 .55618 L .37876 .54155 L p .652 .756 .926 r
F P
0 g
s
.87915 .47452 m .90757 .46621 L .91855 .4815 L p .656 .751 .92 r
F P
0 g
s
.91855 .4815 m .90757 .46621 L .90476 .44158 L p .975 .668 .327 r
F P
0 g
s
.79938 .4604 m .79736 .43573 L .76958 .44416 L p .561 .349 .55 r
F P
0 g
s
.76958 .44416 m .77139 .46877 L .79938 .4604 L p .561 .349 .55 r
F P
0 g
s
.76958 .44416 m .75728 .42853 L .75557 .40418 L p .976 .68 .386 r
F P
0 g
s
.79736 .43573 m .76958 .44416 L .75728 .42853 L p .658 .749 .917 r
F P
0 g
s
.79938 .4604 m .79736 .43573 L .76958 .44416 L p .561 .349 .55 r
F P
0 g
s
.76958 .44416 m .77139 .46877 L .79938 .4604 L p .561 .349 .55 r
F P
0 g
s
.72957 .43703 m .75728 .42853 L .76958 .44416 L p .658 .749 .917 r
F P
0 g
s
.72957 .43703 m .75728 .42853 L .76958 .44416 L p .658 .749 .917 r
F P
0 g
s
.75728 .42853 m .76958 .44416 L .77139 .46877 L p .976 .68 .386 r
F P
0 g
s
.75728 .42853 m .76958 .44416 L .77139 .46877 L p .976 .68 .386 r
F P
0 g
s
.64859 .4226 m .64768 .39821 L .62061 .40682 L p .553 .337 .541 r
F P
0 g
s
.62061 .40682 m .62132 .43116 L .64859 .4226 L p .553 .337 .541 r
F P
0 g
s
.58 .39954 m .60699 .39086 L .62061 .40682 L p .66 .747 .915 r
F P
0 g
s
.60699 .39086 m .62061 .40682 L .62132 .43116 L p .971 .686 .432 r
F P
0 g
s
.71903 .53537 m .7176 .51014 L .69019 .51822 L p .561 .349 .55 r
F P
0 g
s
.69019 .51822 m .69141 .54339 L .71903 .53537 L p .561 .349 .55 r
F P
0 g
s
.69019 .51822 m .67718 .50325 L .67606 .47834 L p .972 .685 .422 r
F P
0 g
s
.69019 .51822 m .67718 .50325 L .67606 .47834 L p .972 .685 .422 r
F P
0 g
s
.7176 .51014 m .69019 .51822 L .67718 .50325 L p .654 .754 .923 r
F P
0 g
s
.71903 .53537 m .7176 .51014 L .69019 .51822 L p .561 .349 .55 r
F P
0 g
s
.69019 .51822 m .69141 .54339 L .71903 .53537 L p .561 .349 .55 r
F P
0 g
s
.64985 .51139 m .67718 .50325 L .69019 .51822 L p .654 .754 .923 r
F P
0 g
s
.67718 .50325 m .69019 .51822 L .69141 .54339 L p .972 .685 .422 r
F P
0 g
s
.7176 .51014 m .69019 .51822 L .67718 .50325 L p .654 .754 .923 r
F P
0 g
s
.54116 .48087 m .52683 .46556 L .52681 .44093 L p .964 .688 .461 r
F P
0 g
s
.54116 .48087 m .52683 .46556 L .52681 .44093 L p .964 .688 .461 r
F P
0 g
s
.56786 .47261 m .54116 .48087 L .52683 .46556 L p .656 .751 .92 r
F P
0 g
s
.56818 .49756 m .56786 .47261 L .54116 .48087 L p .553 .337 .541 r
F P
0 g
s
.54116 .48087 m .54128 .50576 L .56818 .49756 L p .553 .337 .541 r
F P
0 g
s
.50022 .47389 m .52683 .46556 L .54116 .48087 L p .656 .751 .92 r
F P
0 g
s
.50022 .47389 m .52683 .46556 L .54116 .48087 L p .656 .751 .92 r
F P
0 g
s
.52683 .46556 m .54116 .48087 L .54128 .50576 L p .964 .688 .461 r
F P
0 g
s
.56786 .47261 m .54116 .48087 L .52683 .46556 L p .656 .751 .92 r
F P
0 g
s
.52683 .46556 m .54116 .48087 L .54128 .50576 L p .964 .688 .461 r
F P
0 g
s
.41733 .45975 m .41812 .43508 L .39214 .44351 L p .544 .324 .532 r
F P
0 g
s
.39214 .44351 m .39116 .46813 L .41733 .45975 L p .544 .324 .532 r
F P
0 g
s
.41812 .43508 m .39214 .44351 L .37648 .42788 L p .658 .749 .917 r
F P
0 g
s
.41733 .45975 m .41812 .43508 L .39214 .44351 L p .544 .324 .532 r
F P
0 g
s
.39214 .44351 m .39116 .46813 L .41733 .45975 L p .544 .324 .532 r
F P
0 g
s
.35059 .43638 m .37648 .42788 L .39214 .44351 L p .658 .749 .917 r
F P
0 g
s
.37648 .42788 m .39214 .44351 L .39116 .46813 L p .954 .688 .492 r
F P
0 g
s
.37648 .42788 m .39214 .44351 L .39116 .46813 L p .954 .688 .492 r
F P
0 g
s
.57006 .5858 m .59702 .57801 L .61074 .59234 L p .649 .759 .929 r
F P
0 g
s
.61074 .59234 m .59702 .57801 L .59649 .55255 L p .966 .687 .452 r
F P
0 g
s
.48772 .57258 m .48799 .54706 L .46166 .55497 L p .553 .337 .541 r
F P
0 g
s
.46166 .55497 m .46119 .58042 L .48772 .57258 L p .553 .337 .541 r
F P
0 g
s
.42038 .54829 m .44662 .54032 L .46166 .55497 L p .652 .756 .926 r
F P
0 g
s
.44662 .54032 m .46166 .55497 L .46119 .58042 L p .957 .688 .485 r
F P
0 g
s
.86777 .4591 m .86525 .43443 L .83712 .44287 L p .564 .353 .553 r
F P
0 g
s
.83712 .44287 m .83943 .46749 L .86777 .4591 L p .564 .353 .553 r
F P
0 g
s
.83712 .44287 m .82541 .42722 L .8232 .40286 L p .976 .675 .358 r
F P
0 g
s
.86525 .43443 m .83712 .44287 L .82541 .42722 L p .658 .749 .917 r
F P
0 g
s
.86777 .4591 m .86525 .43443 L .83712 .44287 L p .564 .353 .553 r
F P
0 g
s
.83712 .44287 m .83943 .46749 L .86777 .4591 L p .564 .353 .553 r
F P
0 g
s
.79736 .43573 m .82541 .42722 L .83712 .44287 L p .658 .749 .917 r
F P
0 g
s
.82541 .42722 m .83712 .44287 L .83943 .46749 L p .976 .675 .358 r
F P
0 g
s
.86525 .43443 m .83712 .44287 L .82541 .42722 L p .658 .749 .917 r
F P
0 g
s
.82541 .42722 m .83712 .44287 L .83943 .46749 L p .976 .675 .358 r
F P
0 g
s
.71687 .42128 m .71545 .39688 L .68804 .4055 L p .556 .341 .544 r
F P
0 g
s
.68804 .4055 m .68925 .42985 L .71687 .42128 L p .556 .341 .544 r
F P
0 g
s
.71545 .39688 m .68804 .4055 L .67501 .38952 L p .66 .747 .915 r
F P
0 g
s
.71687 .42128 m .71545 .39688 L .68804 .4055 L p .556 .341 .544 r
F P
0 g
s
.68804 .4055 m .68925 .42985 L .71687 .42128 L p .556 .341 .544 r
F P
0 g
s
.64768 .39821 m .67501 .38952 L .68804 .4055 L p .66 .747 .915 r
F P
0 g
s
.67501 .38952 m .68804 .4055 L .68925 .42985 L p .974 .684 .41 r
F P
0 g
s
.67501 .38952 m .68804 .4055 L .68925 .42985 L p .974 .684 .41 r
F P
0 g
s
.78739 .53413 m .78545 .50889 L .7577 .51698 L p .564 .353 .553 r
F P
0 g
s
.7577 .51698 m .75942 .54216 L .78739 .53413 L p .564 .353 .553 r
F P
0 g
s
.78545 .50889 m .7577 .51698 L .74528 .50199 L p .654 .754 .923 r
F P
0 g
s
.78739 .53413 m .78545 .50889 L .7577 .51698 L p .564 .353 .553 r
F P
0 g
s
.7577 .51698 m .75942 .54216 L .78739 .53413 L p .564 .353 .553 r
F P
0 g
s
.7176 .51014 m .74528 .50199 L .7577 .51698 L p .654 .754 .923 r
F P
0 g
s
.74528 .50199 m .7577 .51698 L .75942 .54216 L p .975 .682 .398 r
F P
0 g
s
.74528 .50199 m .7577 .51698 L .75942 .54216 L p .975 .682 .398 r
F P
0 g
s
.63643 .49629 m .6356 .47133 L .60856 .4796 L p .556 .341 .544 r
F P
0 g
s
.60856 .4796 m .60918 .5045 L .63643 .49629 L p .556 .341 .544 r
F P
0 g
s
.60856 .4796 m .59482 .46427 L .5943 .43963 L p .969 .687 .442 r
F P
0 g
s
.60856 .4796 m .59482 .46427 L .5943 .43963 L p .969 .687 .442 r
F P
0 g
s
.6356 .47133 m .60856 .4796 L .59482 .46427 L p .656 .751 .92 r
F P
0 g
s
.56786 .47261 m .59482 .46427 L .60856 .4796 L p .656 .751 .92 r
F P
0 g
s
.48547 .45846 m .48575 .43377 L .45943 .44222 L p .547 .329 .535 r
F P
0 g
s
.45943 .44222 m .45894 .46685 L .48547 .45846 L p .547 .329 .535 r
F P
0 g
s
.45943 .44222 m .44436 .42656 L .44495 .4022 L p .959 .688 .477 r
F P
0 g
s
.45943 .44222 m .44436 .42656 L .44495 .4022 L p .959 .688 .477 r
F P
0 g
s
.48575 .43377 m .45943 .44222 L .44436 .42656 L p .658 .749 .917 r
F P
0 g
s
.48547 .45846 m .48575 .43377 L .45943 .44222 L p .547 .329 .535 r
F P
0 g
s
.45943 .44222 m .45894 .46685 L .48547 .45846 L p .547 .329 .535 r
F P
0 g
s
.41812 .43508 m .44436 .42656 L .45943 .44222 L p .658 .749 .917 r
F P
0 g
s
.41812 .43508 m .44436 .42656 L .45943 .44222 L p .658 .749 .917 r
F P
0 g
s
.44436 .42656 m .45943 .44222 L .45894 .46685 L p .959 .688 .477 r
F P
0 g
s
.48575 .43377 m .45943 .44222 L .44436 .42656 L p .658 .749 .917 r
F P
0 g
s
.44436 .42656 m .45943 .44222 L .45894 .46685 L p .959 .688 .477 r
F P
0 g
s
.3345 .42062 m .33591 .39621 L .31029 .40484 L p .537 .315 .524 r
F P
0 g
s
.31029 .40484 m .30871 .42919 L .3345 .42062 L p .537 .315 .524 r
F P
0 g
s
.67821 .59115 m .66508 .57681 L .66405 .55133 L p .971 .686 .432 r
F P
0 g
s
.67821 .59115 m .66508 .57681 L .66405 .55133 L p .971 .686 .432 r
F P
0 g
s
.7056 .58341 m .67821 .59115 L .66508 .57681 L p .649 .759 .929 r
F P
0 g
s
.63778 .58461 m .66508 .57681 L .67821 .59115 L p .649 .759 .929 r
F P
0 g
s
.52902 .55376 m .51457 .53908 L .51464 .51388 L p .962 .688 .469 r
F P
0 g
s
.52902 .55376 m .51457 .53908 L .51464 .51388 L p .962 .688 .469 r
F P
0 g
s
.55569 .54584 m .52902 .55376 L .51457 .53908 L p .652 .756 .926 r
F P
0 g
s
.48799 .54706 m .51457 .53908 L .52902 .55376 L p .652 .756 .926 r
F P
0 g
s
.48799 .54706 m .51457 .53908 L .52902 .55376 L p .652 .756 .926 r
F P
0 g
s
.51457 .53908 m .52902 .55376 L .52906 .57922 L p .962 .688 .469 r
F P
0 g
s
.40491 .53351 m .40579 .50827 L .37983 .51636 L p .547 .329 .535 r
F P
0 g
s
.37983 .51636 m .37876 .54155 L .40491 .53351 L p .547 .329 .535 r
F P
0 g
s
.37983 .51636 m .36406 .50136 L .36523 .47643 L p .952 .687 .499 r
F P
0 g
s
.37983 .51636 m .36406 .50136 L .36523 .47643 L p .952 .687 .499 r
F P
0 g
s
.40579 .50827 m .37983 .51636 L .36406 .50136 L p .654 .754 .923 r
F P
0 g
s
.40491 .53351 m .40579 .50827 L .37983 .51636 L p .547 .329 .535 r
F P
0 g
s
.37983 .51636 m .37876 .54155 L .40491 .53351 L p .547 .329 .535 r
F P
0 g
s
.33819 .50952 m .36406 .50136 L .37983 .51636 L p .654 .754 .923 r
F P
0 g
s
.33819 .50952 m .36406 .50136 L .37983 .51636 L p .654 .754 .923 r
F P
0 g
s
.36406 .50136 m .37983 .51636 L .37876 .54155 L p .952 .687 .499 r
F P
0 g
s
.40579 .50827 m .37983 .51636 L .36406 .50136 L p .654 .754 .923 r
F P
0 g
s
.36406 .50136 m .37983 .51636 L .37876 .54155 L p .952 .687 .499 r
F P
0 g
s
.86525 .43443 m .89364 .4259 L .90476 .44158 L p .658 .749 .917 r
F P
0 g
s
.86525 .43443 m .89364 .4259 L .90476 .44158 L p .658 .749 .917 r
F P
0 g
s
.89364 .4259 m .90476 .44158 L .90757 .46621 L p .975 .668 .327 r
F P
0 g
s
.90476 .44158 m .89364 .4259 L .89093 .40153 L p .975 .668 .327 r
F P
0 g
s
.78333 .39555 m .75557 .40418 L .74313 .38818 L p .66 .747 .915 r
F P
0 g
s
.78525 .41995 m .78333 .39555 L .75557 .40418 L p .558 .345 .547 r
F P
0 g
s
.75557 .40418 m .75728 .42853 L .78525 .41995 L p .558 .345 .547 r
F P
0 g
s
.74313 .38818 m .75557 .40418 L .75728 .42853 L p .976 .68 .386 r
F P
0 g
s
.8253 .51574 m .81347 .50073 L .81135 .4758 L p .976 .678 .372 r
F P
0 g
s
.8253 .51574 m .81347 .50073 L .81135 .4758 L p .976 .678 .372 r
F P
0 g
s
.8534 .50764 m .8253 .51574 L .81347 .50073 L p .654 .754 .923 r
F P
0 g
s
.85584 .53289 m .8534 .50764 L .8253 .51574 L p .566 .356 .555 r
F P
0 g
s
.8253 .51574 m .82753 .54093 L .85584 .53289 L p .566 .356 .555 r
F P
0 g
s
.78545 .50889 m .81347 .50073 L .8253 .51574 L p .654 .754 .923 r
F P
0 g
s
.78545 .50889 m .81347 .50073 L .8253 .51574 L p .654 .754 .923 r
F P
0 g
s
.81347 .50073 m .8253 .51574 L .82753 .54093 L p .976 .678 .372 r
F P
0 g
s
.8534 .50764 m .8253 .51574 L .81347 .50073 L p .654 .754 .923 r
F P
0 g
s
.81347 .50073 m .8253 .51574 L .82753 .54093 L p .976 .678 .372 r
F P
0 g
s
.70477 .49502 m .70344 .47005 L .67606 .47834 L p .558 .345 .547 r
F P
0 g
s
.67606 .47834 m .67718 .50325 L .70477 .49502 L p .558 .345 .547 r
F P
0 g
s
.70344 .47005 m .67606 .47834 L .6629 .46298 L p .656 .751 .92 r
F P
0 g
s
.70477 .49502 m .70344 .47005 L .67606 .47834 L p .558 .345 .547 r
F P
0 g
s
.67606 .47834 m .67718 .50325 L .70477 .49502 L p .558 .345 .547 r
F P
0 g
s
.6356 .47133 m .6629 .46298 L .67606 .47834 L p .656 .751 .92 r
F P
0 g
s
.6629 .46298 m .67606 .47834 L .67718 .50325 L p .972 .685 .422 r
F P
0 g
s
.6629 .46298 m .67606 .47834 L .67718 .50325 L p .972 .685 .422 r
F P
0 g
s
.5537 .45716 m .55348 .43247 L .52681 .44093 L p .55 .333 .538 r
F P
0 g
s
.52681 .44093 m .52683 .46556 L .5537 .45716 L p .55 .333 .538 r
F P
0 g
s
.52681 .44093 m .51233 .42524 L .51242 .40087 L p .964 .688 .461 r
F P
0 g
s
.52681 .44093 m .51233 .42524 L .51242 .40087 L p .964 .688 .461 r
F P
0 g
s
.55348 .43247 m .52681 .44093 L .51233 .42524 L p .658 .749 .917 r
F P
0 g
s
.5537 .45716 m .55348 .43247 L .52681 .44093 L p .55 .333 .538 r
F P
0 g
s
.52681 .44093 m .52683 .46556 L .5537 .45716 L p .55 .333 .538 r
F P
0 g
s
.48575 .43377 m .51233 .42524 L .52681 .44093 L p .658 .749 .917 r
F P
0 g
s
.48575 .43377 m .51233 .42524 L .52681 .44093 L p .658 .749 .917 r
F P
0 g
s
.51233 .42524 m .52681 .44093 L .52683 .46556 L p .964 .688 .461 r
F P
0 g
s
.55348 .43247 m .52681 .44093 L .51233 .42524 L p .658 .749 .917 r
F P
0 g
s
.51233 .42524 m .52681 .44093 L .52683 .46556 L p .964 .688 .461 r
F P
0 g
s
.55569 .54584 m .58262 .53785 L .59649 .55255 L p .652 .756 .926 r
F P
0 g
s
.55569 .54584 m .58262 .53785 L .59649 .55255 L p .652 .756 .926 r
F P
0 g
s
.58262 .53785 m .59649 .55255 L .59702 .57801 L p .966 .687 .452 r
F P
0 g
s
.59649 .55255 m .58262 .53785 L .5822 .51264 L p .966 .687 .452 r
F P
0 g
s
.44719 .51512 m .432 .50009 L .43268 .47516 L p .957 .688 .485 r
F P
0 g
s
.44719 .51512 m .432 .50009 L .43268 .47516 L p .957 .688 .485 r
F P
0 g
s
.47349 .50702 m .44719 .51512 L .432 .50009 L p .654 .754 .923 r
F P
0 g
s
.47311 .53227 m .47349 .50702 L .44719 .51512 L p .55 .333 .538 r
F P
0 g
s
.44719 .51512 m .44662 .54032 L .47311 .53227 L p .55 .333 .538 r
F P
0 g
s
.40579 .50827 m .432 .50009 L .44719 .51512 L p .654 .754 .923 r
F P
0 g
s
.40579 .50827 m .432 .50009 L .44719 .51512 L p .654 .754 .923 r
F P
0 g
s
.432 .50009 m .44719 .51512 L .44662 .54032 L p .957 .688 .485 r
F P
0 g
s
.47349 .50702 m .44719 .51512 L .432 .50009 L p .654 .754 .923 r
F P
0 g
s
.432 .50009 m .44719 .51512 L .44662 .54032 L p .957 .688 .485 r
F P
0 g
s
.85373 .41863 m .8513 .39421 L .8232 .40286 L p .561 .349 .55 r
F P
0 g
s
.8232 .40286 m .82541 .42722 L .85373 .41863 L p .561 .349 .55 r
F P
0 g
s
.78333 .39555 m .81135 .38683 L .8232 .40286 L p .66 .747 .915 r
F P
0 g
s
.81135 .38683 m .8232 .40286 L .82541 .42722 L p .976 .675 .358 r
F P
0 g
s
.8534 .50764 m .88177 .49946 L .89301 .5145 L p .654 .754 .923 r
F P
0 g
s
.89301 .5145 m .88177 .49946 L .87915 .47452 L p .976 .672 .343 r
F P
0 g
s
.74366 .47707 m .73109 .46169 L .72957 .43703 L p .975 .682 .398 r
F P
0 g
s
.74366 .47707 m .73109 .46169 L .72957 .43703 L p .975 .682 .398 r
F P
0 g
s
.77139 .46877 m .74366 .47707 L .73109 .46169 L p .656 .751 .92 r
F P
0 g
s
.77322 .49375 m .77139 .46877 L .74366 .47707 L p .561 .349 .55 r
F P
0 g
s
.74366 .47707 m .74528 .50199 L .77322 .49375 L p .561 .349 .55 r
F P
0 g
s
.70344 .47005 m .73109 .46169 L .74366 .47707 L p .656 .751 .92 r
F P
0 g
s
.70344 .47005 m .73109 .46169 L .74366 .47707 L p .656 .751 .92 r
F P
0 g
s
.73109 .46169 m .74366 .47707 L .74528 .50199 L p .975 .682 .398 r
F P
0 g
s
.77139 .46877 m .74366 .47707 L .73109 .46169 L p .656 .751 .92 r
F P
0 g
s
.73109 .46169 m .74366 .47707 L .74528 .50199 L p .975 .682 .398 r
F P
0 g
s
.62203 .45586 m .62132 .43116 L .5943 .43963 L p .553 .337 .541 r
F P
0 g
s
.5943 .43963 m .59482 .46427 L .62203 .45586 L p .553 .337 .541 r
F P
0 g
s
.5943 .43963 m .58041 .42392 L .58 .39954 L p .969 .687 .442 r
F P
0 g
s
.5943 .43963 m .58041 .42392 L .58 .39954 L p .969 .687 .442 r
F P
0 g
s
.62132 .43116 m .5943 .43963 L .58041 .42392 L p .658 .749 .917 r
F P
0 g
s
.62203 .45586 m .62132 .43116 L .5943 .43963 L p .553 .337 .541 r
F P
0 g
s
.5943 .43963 m .59482 .46427 L .62203 .45586 L p .553 .337 .541 r
F P
0 g
s
.55348 .43247 m .58041 .42392 L .5943 .43963 L p .658 .749 .917 r
F P
0 g
s
.55348 .43247 m .58041 .42392 L .5943 .43963 L p .658 .749 .917 r
F P
0 g
s
.58041 .42392 m .5943 .43963 L .59482 .46427 L p .969 .687 .442 r
F P
0 g
s
.62132 .43116 m .5943 .43963 L .58041 .42392 L p .658 .749 .917 r
F P
0 g
s
.58041 .42392 m .5943 .43963 L .59482 .46427 L p .969 .687 .442 r
F P
0 g
s
.47085 .41796 m .47125 .39354 L .44495 .4022 L p .544 .324 .532 r
F P
0 g
s
.44495 .4022 m .44436 .42656 L .47085 .41796 L p .544 .324 .532 r
F P
0 g
s
.69265 .56893 m .69141 .54339 L .66405 .55133 L p .561 .349 .55 r
F P
0 g
s
.66405 .55133 m .66508 .57681 L .69265 .56893 L p .561 .349 .55 r
F P
0 g
s
.66405 .55133 m .65078 .53661 L .64985 .51139 L p .971 .686 .432 r
F P
0 g
s
.69141 .54339 m .66405 .55133 L .65078 .53661 L p .652 .756 .926 r
F P
0 g
s
.69265 .56893 m .69141 .54339 L .66405 .55133 L p .561 .349 .55 r
F P
0 g
s
.66405 .55133 m .66508 .57681 L .69265 .56893 L p .561 .349 .55 r
F P
0 g
s
.6235 .54462 m .65078 .53661 L .66405 .55133 L p .652 .756 .926 r
F P
0 g
s
.6235 .54462 m .65078 .53661 L .66405 .55133 L p .652 .756 .926 r
F P
0 g
s
.65078 .53661 m .66405 .55133 L .66508 .57681 L p .971 .686 .432 r
F P
0 g
s
.65078 .53661 m .66405 .55133 L .66508 .57681 L p .971 .686 .432 r
F P
0 g
s
.54141 .53102 m .54128 .50576 L .51464 .51388 L p .553 .337 .541 r
F P
0 g
s
.51464 .51388 m .51457 .53908 L .54141 .53102 L p .553 .337 .541 r
F P
0 g
s
.51464 .51388 m .50004 .49883 L .50022 .47389 L p .962 .688 .469 r
F P
0 g
s
.54128 .50576 m .51464 .51388 L .50004 .49883 L p .654 .754 .923 r
F P
0 g
s
.54141 .53102 m .54128 .50576 L .51464 .51388 L p .553 .337 .541 r
F P
0 g
s
.51464 .51388 m .51457 .53908 L .54141 .53102 L p .553 .337 .541 r
F P
0 g
s
.47349 .50702 m .50004 .49883 L .51464 .51388 L p .654 .754 .923 r
F P
0 g
s
.50004 .49883 m .51464 .51388 L .51457 .53908 L p .962 .688 .469 r
F P
0 g
s
.54128 .50576 m .51464 .51388 L .50004 .49883 L p .654 .754 .923 r
F P
0 g
s
.50004 .49883 m .51464 .51388 L .51457 .53908 L p .962 .688 .469 r
F P
0 g
s
.39017 .49312 m .39116 .46813 L .36523 .47643 L p .544 .324 .532 r
F P
0 g
s
.36523 .47643 m .36406 .50136 L .39017 .49312 L p .544 .324 .532 r
F P
0 g
s
.36523 .47643 m .3493 .46105 L .35059 .43638 L p .952 .687 .499 r
F P
0 g
s
.36523 .47643 m .3493 .46105 L .35059 .43638 L p .952 .687 .499 r
F P
0 g
s
.39116 .46813 m .36523 .47643 L .3493 .46105 L p .656 .751 .92 r
F P
0 g
s
.32347 .46941 m .3493 .46105 L .36523 .47643 L p .656 .751 .92 r
F P
0 g
s
.32347 .46941 m .3493 .46105 L .36523 .47643 L p .656 .751 .92 r
F P
0 g
s
.3493 .46105 m .36523 .47643 L .36406 .50136 L p .952 .687 .499 r
F P
0 g
s
.91938 .39287 m .89093 .40153 L .87967 .38548 L p .66 .747 .915 r
F P
0 g
s
.92231 .4173 m .91938 .39287 L .89093 .40153 L p .564 .353 .553 r
F P
0 g
s
.89093 .40153 m .89364 .4259 L .92231 .4173 L p .564 .353 .553 r
F P
0 g
s
.8513 .39421 m .87967 .38548 L .89093 .40153 L p .66 .747 .915 r
F P
0 g
s
.87967 .38548 m .89093 .40153 L .89364 .4259 L p .975 .668 .327 r
F P
0 g
s
.87967 .38548 m .89093 .40153 L .89364 .4259 L p .975 .668 .327 r
F P
0 g
s
.43493 .58819 m .41961 .57379 L .42038 .54829 L p .954 .688 .492 r
F P
0 g
s
.43493 .58819 m .41961 .57379 L .42038 .54829 L p .954 .688 .492 r
F P
0 g
s
.46119 .58042 m .43493 .58819 L .41961 .57379 L p .649 .759 .929 r
F P
0 g
s
.39343 .58162 m .41961 .57379 L .43493 .58819 L p .649 .759 .929 r
F P
0 g
s
.84177 .49248 m .83943 .46749 L .81135 .4758 L p .564 .353 .553 r
F P
0 g
s
.81135 .4758 m .81347 .50073 L .84177 .49248 L p .564 .353 .553 r
F P
0 g
s
.81135 .4758 m .79938 .4604 L .79736 .43573 L p .976 .678 .372 r
F P
0 g
s
.81135 .4758 m .79938 .4604 L .79736 .43573 L p .976 .678 .372 r
F P
0 g
s
.83943 .46749 m .81135 .4758 L .79938 .4604 L p .656 .751 .92 r
F P
0 g
s
.84177 .49248 m .83943 .46749 L .81135 .4758 L p .564 .353 .553 r
F P
0 g
s
.81135 .4758 m .81347 .50073 L .84177 .49248 L p .564 .353 .553 r
F P
0 g
s
.77139 .46877 m .79938 .4604 L .81135 .4758 L p .656 .751 .92 r
F P
0 g
s
.79938 .4604 m .81135 .4758 L .81347 .50073 L p .976 .678 .372 r
F P
0 g
s
.83943 .46749 m .81135 .4758 L .79938 .4604 L p .656 .751 .92 r
F P
0 g
s
.66189 .43833 m .64859 .4226 L .64768 .39821 L p .972 .685 .422 r
F P
0 g
s
.66189 .43833 m .64859 .4226 L .64768 .39821 L p .972 .685 .422 r
F P
0 g
s
.68925 .42985 m .66189 .43833 L .64859 .4226 L p .658 .749 .917 r
F P
0 g
s
.62132 .43116 m .64859 .4226 L .66189 .43833 L p .658 .749 .917 r
F P
0 g
s
.62132 .43116 m .64859 .4226 L .66189 .43833 L p .658 .749 .917 r
F P
0 g
s
.64859 .4226 m .66189 .43833 L .6629 .46298 L p .972 .685 .422 r
F P
0 g
s
.53917 .41663 m .53907 .3922 L .51242 .40087 L p .547 .329 .535 r
F P
0 g
s
.51242 .40087 m .51233 .42524 L .53917 .41663 L p .547 .329 .535 r
F P
0 g
s
.53907 .3922 m .51242 .40087 L .4978 .38481 L p .66 .747 .915 r
F P
0 g
s
.53917 .41663 m .53907 .3922 L .51242 .40087 L p .547 .329 .535 r
F P
0 g
s
.51242 .40087 m .51233 .42524 L .53917 .41663 L p .547 .329 .535 r
F P
0 g
s
.47125 .39354 m .4978 .38481 L .51242 .40087 L p .66 .747 .915 r
F P
0 g
s
.4978 .38481 m .51242 .40087 L .51233 .42524 L p .964 .688 .461 r
F P
0 g
s
.4978 .38481 m .51242 .40087 L .51233 .42524 L p .964 .688 .461 r
F P
0 g
s
.73171 .55011 m .71903 .53537 L .7176 .51014 L p .974 .684 .41 r
F P
0 g
s
.73171 .55011 m .71903 .53537 L .7176 .51014 L p .974 .684 .41 r
F P
0 g
s
.75942 .54216 m .73171 .55011 L .71903 .53537 L p .652 .756 .926 r
F P
0 g
s
.69141 .54339 m .71903 .53537 L .73171 .55011 L p .652 .756 .926 r
F P
0 g
s
.60918 .5045 m .5822 .51264 L .56818 .49756 L p .654 .754 .923 r
F P
0 g
s
.60981 .52978 m .60918 .5045 L .5822 .51264 L p .556 .341 .544 r
F P
0 g
s
.5822 .51264 m .58262 .53785 L .60981 .52978 L p .556 .341 .544 r
F P
0 g
s
.54128 .50576 m .56818 .49756 L .5822 .51264 L p .654 .754 .923 r
F P
0 g
s
.56818 .49756 m .5822 .51264 L .58262 .53785 L p .966 .687 .452 r
F P
0 g
s
.56818 .49756 m .5822 .51264 L .58262 .53785 L p .966 .687 .452 r
F P
0 g
s
.45846 .49184 m .45894 .46685 L .43268 .47516 L p .547 .329 .535 r
F P
0 g
s
.43268 .47516 m .432 .50009 L .45846 .49184 L p .547 .329 .535 r
F P
0 g
s
.43268 .47516 m .41733 .45975 L .41812 .43508 L p .957 .688 .485 r
F P
0 g
s
.43268 .47516 m .41733 .45975 L .41812 .43508 L p .957 .688 .485 r
F P
0 g
s
.45894 .46685 m .43268 .47516 L .41733 .45975 L p .656 .751 .92 r
F P
0 g
s
.39116 .46813 m .41733 .45975 L .43268 .47516 L p .656 .751 .92 r
F P
0 g
s
.50244 .587 m .48772 .57258 L .48799 .54706 L p .959 .688 .477 r
F P
0 g
s
.50244 .587 m .48772 .57258 L .48799 .54706 L p .959 .688 .477 r
F P
0 g
s
.52906 .57922 m .50244 .587 L .48772 .57258 L p .649 .759 .929 r
F P
0 g
s
.46119 .58042 m .48772 .57258 L .50244 .587 L p .649 .759 .929 r
F P
0 g
s
.35287 .5495 m .33681 .53475 L .33819 .50952 L p .949 .687 .505 r
F P
0 g
s
.37876 .54155 m .35287 .5495 L .33681 .53475 L p .652 .756 .926 r
F P
0 g
s
.87915 .47452 m .86777 .4591 L .86525 .43443 L p .976 .672 .343 r
F P
0 g
s
.87915 .47452 m .86777 .4591 L .86525 .43443 L p .976 .672 .343 r
F P
0 g
s
.90757 .46621 m .87915 .47452 L .86777 .4591 L p .656 .751 .92 r
F P
0 g
s
.83943 .46749 m .86777 .4591 L .87915 .47452 L p .656 .751 .92 r
F P
0 g
s
.83943 .46749 m .86777 .4591 L .87915 .47452 L p .656 .751 .92 r
F P
0 g
s
.86777 .4591 m .87915 .47452 L .88177 .49946 L p .976 .672 .343 r
F P
0 g
s
.75901 .45325 m .75728 .42853 L .72957 .43703 L p .558 .345 .547 r
F P
0 g
s
.72957 .43703 m .73109 .46169 L .75901 .45325 L p .558 .345 .547 r
F P
0 g
s
.72957 .43703 m .71687 .42128 L .71545 .39688 L p .975 .682 .398 r
F P
0 g
s
.75728 .42853 m .72957 .43703 L .71687 .42128 L p .658 .749 .917 r
F P
0 g
s
.75901 .45325 m .75728 .42853 L .72957 .43703 L p .558 .345 .547 r
F P
0 g
s
.72957 .43703 m .73109 .46169 L .75901 .45325 L p .558 .345 .547 r
F P
0 g
s
.68925 .42985 m .71687 .42128 L .72957 .43703 L p .658 .749 .917 r
F P
0 g
s
.68925 .42985 m .71687 .42128 L .72957 .43703 L p .658 .749 .917 r
F P
0 g
s
.71687 .42128 m .72957 .43703 L .73109 .46169 L p .975 .682 .398 r
F P
0 g
s
.71687 .42128 m .72957 .43703 L .73109 .46169 L p .975 .682 .398 r
F P
0 g
s
.6076 .4153 m .60699 .39086 L .58 .39954 L p .55 .333 .538 r
F P
0 g
s
.58 .39954 m .58041 .42392 L .6076 .4153 L p .55 .333 .538 r
F P
0 g
s
.60699 .39086 m .58 .39954 L .56596 .38346 L p .66 .747 .915 r
F P
0 g
s
.6076 .4153 m .60699 .39086 L .58 .39954 L p .55 .333 .538 r
F P
0 g
s
.58 .39954 m .58041 .42392 L .6076 .4153 L p .55 .333 .538 r
F P
0 g
s
.53907 .3922 m .56596 .38346 L .58 .39954 L p .66 .747 .915 r
F P
0 g
s
.56596 .38346 m .58 .39954 L .58041 .42392 L p .969 .687 .442 r
F P
0 g
s
.56596 .38346 m .58 .39954 L .58041 .42392 L p .969 .687 .442 r
F P
0 g
s
.79948 .5489 m .78739 .53413 L .78545 .50889 L p .976 .68 .386 r
F P
0 g
s
.79948 .5489 m .78739 .53413 L .78545 .50889 L p .976 .68 .386 r
F P
0 g
s
.82753 .54093 m .79948 .5489 L .78739 .53413 L p .652 .756 .926 r
F P
0 g
s
.75942 .54216 m .78739 .53413 L .79948 .5489 L p .652 .756 .926 r
F P
0 g
s
.64985 .51139 m .63643 .49629 L .6356 .47133 L p .971 .686 .432 r
F P
0 g
s
.64985 .51139 m .63643 .49629 L .6356 .47133 L p .971 .686 .432 r
F P
0 g
s
.67718 .50325 m .64985 .51139 L .63643 .49629 L p .654 .754 .923 r
F P
0 g
s
.60918 .5045 m .63643 .49629 L .64985 .51139 L p .654 .754 .923 r
F P
0 g
s
.60918 .5045 m .63643 .49629 L .64985 .51139 L p .654 .754 .923 r
F P
0 g
s
.63643 .49629 m .64985 .51139 L .65078 .53661 L p .971 .686 .432 r
F P
0 g
s
.52685 .49056 m .52683 .46556 L .50022 .47389 L p .55 .333 .538 r
F P
0 g
s
.50022 .47389 m .50004 .49883 L .52685 .49056 L p .55 .333 .538 r
F P
0 g
s
.50022 .47389 m .48547 .45846 L .48575 .43377 L p .962 .688 .469 r
F P
0 g
s
.50022 .47389 m .48547 .45846 L .48575 .43377 L p .962 .688 .469 r
F P
0 g
s
.52683 .46556 m .50022 .47389 L .48547 .45846 L p .656 .751 .92 r
F P
0 g
s
.52685 .49056 m .52683 .46556 L .50022 .47389 L p .55 .333 .538 r
F P
0 g
s
.50022 .47389 m .50004 .49883 L .52685 .49056 L p .55 .333 .538 r
F P
0 g
s
.45894 .46685 m .48547 .45846 L .50022 .47389 L p .656 .751 .92 r
F P
0 g
s
.48547 .45846 m .50022 .47389 L .50004 .49883 L p .962 .688 .469 r
F P
0 g
s
.52683 .46556 m .50022 .47389 L .48547 .45846 L p .656 .751 .92 r
F P
0 g
s
.37538 .4526 m .37648 .42788 L .35059 .43638 L p .541 .319 .528 r
F P
0 g
s
.35059 .43638 m .3493 .46105 L .37538 .4526 L p .541 .319 .528 r
F P
0 g
s
.35059 .43638 m .3345 .42062 L .33591 .39621 L p .952 .687 .499 r
F P
0 g
s
.37648 .42788 m .35059 .43638 L .3345 .42062 L p .658 .749 .917 r
F P
0 g
s
.37538 .4526 m .37648 .42788 L .35059 .43638 L p .541 .319 .528 r
F P
0 g
s
.35059 .43638 m .3493 .46105 L .37538 .4526 L p .541 .319 .528 r
F P
0 g
s
.30871 .42919 m .3345 .42062 L .35059 .43638 L p .658 .749 .917 r
F P
0 g
s
.3345 .42062 m .35059 .43638 L .3493 .46105 L p .952 .687 .499 r
F P
0 g
s
.22614 .39019 m .20096 .39888 L .18354 .38278 L p .66 .747 .915 r
F P
0 g
s
.22391 .41463 m .22614 .39019 L .20096 .39888 L p .53 .304 .517 r
F P
0 g
s
.20096 .39888 m .19856 .42326 L .22391 .41463 L p .53 .304 .517 r
F P
0 g
s
.18354 .38278 m .20096 .39888 L .19856 .42326 L p .941 .685 .523 r
F P
0 g
s
.57006 .5858 m .55593 .57136 L .55569 .54584 L p .964 .688 .461 r
F P
0 g
s
.59702 .57801 m .57006 .5858 L .55593 .57136 L p .649 .759 .929 r
F P
0 g
s
.44604 .56588 m .44662 .54032 L .42038 .54829 L p .55 .333 .538 r
F P
0 g
s
.42038 .54829 m .41961 .57379 L .44604 .56588 L p .55 .333 .538 r
F P
0 g
s
.42038 .54829 m .40491 .53351 L .40579 .50827 L p .954 .688 .492 r
F P
0 g
s
.42038 .54829 m .40491 .53351 L .40579 .50827 L p .954 .688 .492 r
F P
0 g
s
.44662 .54032 m .42038 .54829 L .40491 .53351 L p .652 .756 .926 r
F P
0 g
s
.44604 .56588 m .44662 .54032 L .42038 .54829 L p .55 .333 .538 r
F P
0 g
s
.42038 .54829 m .41961 .57379 L .44604 .56588 L p .55 .333 .538 r
F P
0 g
s
.37876 .54155 m .40491 .53351 L .42038 .54829 L p .652 .756 .926 r
F P
0 g
s
.37876 .54155 m .40491 .53351 L .42038 .54829 L p .652 .756 .926 r
F P
0 g
s
.40491 .53351 m .42038 .54829 L .41961 .57379 L p .954 .688 .492 r
F P
0 g
s
.44662 .54032 m .42038 .54829 L .40491 .53351 L p .652 .756 .926 r
F P
0 g
s
.40491 .53351 m .42038 .54829 L .41961 .57379 L p .954 .688 .492 r
F P
0 g
s
.82765 .45194 m .82541 .42722 L .79736 .43573 L p .561 .349 .55 r
F P
0 g
s
.79736 .43573 m .79938 .4604 L .82765 .45194 L p .561 .349 .55 r
F P
0 g
s
.79736 .43573 m .78525 .41995 L .78333 .39555 L p .976 .678 .372 r
F P
0 g
s
.82541 .42722 m .79736 .43573 L .78525 .41995 L p .658 .749 .917 r
F P
0 g
s
.75728 .42853 m .78525 .41995 L .79736 .43573 L p .658 .749 .917 r
F P
0 g
s
.78525 .41995 m .79736 .43573 L .79938 .4604 L p .976 .678 .372 r
F P
0 g
s
.67613 .41397 m .67501 .38952 L .64768 .39821 L p .553 .337 .541 r
F P
0 g
s
.64768 .39821 m .64859 .4226 L .67613 .41397 L p .553 .337 .541 r
F P
0 g
s
.67501 .38952 m .64768 .39821 L .63423 .3821 L p .66 .747 .915 r
F P
0 g
s
.67613 .41397 m .67501 .38952 L .64768 .39821 L p .553 .337 .541 r
F P
0 g
s
.64768 .39821 m .64859 .4226 L .67613 .41397 L p .553 .337 .541 r
F P
0 g
s
.63423 .3821 m .64768 .39821 L .64859 .4226 L p .972 .685 .422 r
F P
0 g
s
.74692 .52728 m .74528 .50199 L .7176 .51014 L p .561 .349 .55 r
F P
0 g
s
.7176 .51014 m .71903 .53537 L .74692 .52728 L p .561 .349 .55 r
F P
0 g
s
.7176 .51014 m .70477 .49502 L .70344 .47005 L p .974 .684 .41 r
F P
0 g
s
.7176 .51014 m .70477 .49502 L .70344 .47005 L p .974 .684 .41 r
F P
0 g
s
.74528 .50199 m .7176 .51014 L .70477 .49502 L p .654 .754 .923 r
F P
0 g
s
.67718 .50325 m .70477 .49502 L .7176 .51014 L p .654 .754 .923 r
F P
0 g
s
.67718 .50325 m .70477 .49502 L .7176 .51014 L p .654 .754 .923 r
F P
0 g
s
.70477 .49502 m .7176 .51014 L .71903 .53537 L p .974 .684 .41 r
F P
0 g
s
.56786 .47261 m .5537 .45716 L .55348 .43247 L p .966 .687 .452 r
F P
0 g
s
.56786 .47261 m .5537 .45716 L .55348 .43247 L p .966 .687 .452 r
F P
0 g
s
.59482 .46427 m .56786 .47261 L .5537 .45716 L p .656 .751 .92 r
F P
0 g
s
.59534 .48928 m .59482 .46427 L .56786 .47261 L p .553 .337 .541 r
F P
0 g
s
.56786 .47261 m .56818 .49756 L .59534 .48928 L p .553 .337 .541 r
F P
0 g
s
.52683 .46556 m .5537 .45716 L .56786 .47261 L p .656 .751 .92 r
F P
0 g
s
.52683 .46556 m .5537 .45716 L .56786 .47261 L p .656 .751 .92 r
F P
0 g
s
.5537 .45716 m .56786 .47261 L .56818 .49756 L p .966 .687 .452 r
F P
0 g
s
.59482 .46427 m .56786 .47261 L .5537 .45716 L p .656 .751 .92 r
F P
0 g
s
.5537 .45716 m .56786 .47261 L .56818 .49756 L p .966 .687 .452 r
F P
0 g
s
.44376 .45129 m .44436 .42656 L .41812 .43508 L p .544 .324 .532 r
F P
0 g
s
.41812 .43508 m .41733 .45975 L .44376 .45129 L p .544 .324 .532 r
F P
0 g
s
.44436 .42656 m .41812 .43508 L .40263 .41929 L p .658 .749 .917 r
F P
0 g
s
.44376 .45129 m .44436 .42656 L .41812 .43508 L p .544 .324 .532 r
F P
0 g
s
.41812 .43508 m .41733 .45975 L .44376 .45129 L p .544 .324 .532 r
F P
0 g
s
.37648 .42788 m .40263 .41929 L .41812 .43508 L p .658 .749 .917 r
F P
0 g
s
.40263 .41929 m .41812 .43508 L .41733 .45975 L p .957 .688 .485 r
F P
0 g
s
.40263 .41929 m .41812 .43508 L .41733 .45975 L p .957 .688 .485 r
F P
0 g
s
.63778 .58461 m .62424 .57015 L .6235 .54462 L p .969 .687 .442 r
F P
0 g
s
.66508 .57681 m .63778 .58461 L .62424 .57015 L p .649 .759 .929 r
F P
0 g
s
.51449 .56466 m .51457 .53908 L .48799 .54706 L p .553 .337 .541 r
F P
0 g
s
.48799 .54706 m .48772 .57258 L .51449 .56466 L p .553 .337 .541 r
F P
0 g
s
.48799 .54706 m .47311 .53227 L .47349 .50702 L p .959 .688 .477 r
F P
0 g
s
.51457 .53908 m .48799 .54706 L .47311 .53227 L p .652 .756 .926 r
F P
0 g
s
.36286 .52665 m .36406 .50136 L .33819 .50952 L p .544 .324 .532 r
F P
0 g
s
.33819 .50952 m .33681 .53475 L .36286 .52665 L p .544 .324 .532 r
F P
0 g
s
.33819 .50952 m .32198 .49439 L .32347 .46941 L p .949 .687 .505 r
F P
0 g
s
.36406 .50136 m .33819 .50952 L .32198 .49439 L p .654 .754 .923 r
F P
0 g
s
.36286 .52665 m .36406 .50136 L .33819 .50952 L p .544 .324 .532 r
F P
0 g
s
.33819 .50952 m .33681 .53475 L .36286 .52665 L p .544 .324 .532 r
F P
0 g
s
.32198 .49439 m .33819 .50952 L .33681 .53475 L p .949 .687 .505 r
F P
0 g
s
.36406 .50136 m .33819 .50952 L .32198 .49439 L p .654 .754 .923 r
F P
0 g
s
.89639 .45064 m .89364 .4259 L .86525 .43443 L p .564 .353 .553 r
F P
0 g
s
.86525 .43443 m .86777 .4591 L .89639 .45064 L p .564 .353 .553 r
F P
0 g
s
.86525 .43443 m .85373 .41863 L .8513 .39421 L p .976 .672 .343 r
F P
0 g
s
.86525 .43443 m .85373 .41863 L .8513 .39421 L p .976 .672 .343 r
F P
0 g
s
.89364 .4259 m .86525 .43443 L .85373 .41863 L p .658 .749 .917 r
F P
0 g
s
.89639 .45064 m .89364 .4259 L .86525 .43443 L p .564 .353 .553 r
F P
0 g
s
.86525 .43443 m .86777 .4591 L .89639 .45064 L p .564 .353 .553 r
F P
0 g
s
.82541 .42722 m .85373 .41863 L .86525 .43443 L p .658 .749 .917 r
F P
0 g
s
.82541 .42722 m .85373 .41863 L .86525 .43443 L p .658 .749 .917 r
F P
0 g
s
.85373 .41863 m .86525 .43443 L .86777 .4591 L p .976 .672 .343 r
F P
0 g
s
.89364 .4259 m .86525 .43443 L .85373 .41863 L p .658 .749 .917 r
F P
0 g
s
.85373 .41863 m .86525 .43443 L .86777 .4591 L p .976 .672 .343 r
F P
0 g
s
.67501 .38952 m .7026 .38075 L .71545 .39688 L p .66 .747 .915 r
F P
0 g
s
.7026 .38075 m .71545 .39688 L .71687 .42128 L p .975 .682 .398 r
F P
0 g
s
.81563 .52603 m .81347 .50073 L .78545 .50889 L p .564 .353 .553 r
F P
0 g
s
.78545 .50889 m .78739 .53413 L .81563 .52603 L p .564 .353 .553 r
F P
0 g
s
.81347 .50073 m .78545 .50889 L .77322 .49375 L p .654 .754 .923 r
F P
0 g
s
.81563 .52603 m .81347 .50073 L .78545 .50889 L p .564 .353 .553 r
F P
0 g
s
.78545 .50889 m .78739 .53413 L .81563 .52603 L p .564 .353 .553 r
F P
0 g
s
.74528 .50199 m .77322 .49375 L .78545 .50889 L p .654 .754 .923 r
F P
0 g
s
.77322 .49375 m .78545 .50889 L .78739 .53413 L p .976 .68 .386 r
F P
0 g
s
.77322 .49375 m .78545 .50889 L .78739 .53413 L p .976 .68 .386 r
F P
0 g
s
.66394 .488 m .6629 .46298 L .6356 .47133 L p .556 .341 .544 r
F P
0 g
s
.6356 .47133 m .63643 .49629 L .66394 .488 L p .556 .341 .544 r
F P
0 g
s
.6356 .47133 m .62203 .45586 L .62132 .43116 L p .971 .686 .432 r
F P
0 g
s
.6356 .47133 m .62203 .45586 L .62132 .43116 L p .971 .686 .432 r
F P
0 g
s
.6629 .46298 m .6356 .47133 L .62203 .45586 L p .656 .751 .92 r
F P
0 g
s
.59482 .46427 m .62203 .45586 L .6356 .47133 L p .656 .751 .92 r
F P
0 g
s
.51224 .44998 m .51233 .42524 L .48575 .43377 L p .547 .329 .535 r
F P
0 g
s
.48575 .43377 m .48547 .45846 L .51224 .44998 L p .547 .329 .535 r
F P
0 g
s
.48575 .43377 m .47085 .41796 L .47125 .39354 L p .962 .688 .469 r
F P
0 g
s
.48575 .43377 m .47085 .41796 L .47125 .39354 L p .962 .688 .469 r
F P
0 g
s
.51233 .42524 m .48575 .43377 L .47085 .41796 L p .658 .749 .917 r
F P
0 g
s
.51224 .44998 m .51233 .42524 L .48575 .43377 L p .547 .329 .535 r
F P
0 g
s
.48575 .43377 m .48547 .45846 L .51224 .44998 L p .547 .329 .535 r
F P
0 g
s
.44436 .42656 m .47085 .41796 L .48575 .43377 L p .658 .749 .917 r
F P
0 g
s
.44436 .42656 m .47085 .41796 L .48575 .43377 L p .658 .749 .917 r
F P
0 g
s
.47085 .41796 m .48575 .43377 L .48547 .45846 L p .962 .688 .469 r
F P
0 g
s
.51233 .42524 m .48575 .43377 L .47085 .41796 L p .658 .749 .917 r
F P
0 g
s
.47085 .41796 m .48575 .43377 L .48547 .45846 L p .962 .688 .469 r
F P
0 g
s
.36177 .3875 m .33591 .39621 L .31966 .38007 L p .66 .747 .915 r
F P
0 g
s
.36055 .41196 m .36177 .3875 L .33591 .39621 L p .537 .315 .524 r
F P
0 g
s
.33591 .39621 m .3345 .42062 L .36055 .41196 L p .537 .315 .524 r
F P
0 g
s
.31966 .38007 m .33591 .39621 L .3345 .42062 L p .952 .687 .499 r
F P
0 g
s
.66508 .57681 m .69265 .56893 L .7056 .58341 L p .649 .759 .929 r
F P
0 g
s
.7056 .58341 m .69265 .56893 L .69141 .54339 L p .972 .685 .422 r
F P
0 g
s
.58306 .56344 m .58262 .53785 L .55569 .54584 L p .556 .341 .544 r
F P
0 g
s
.55569 .54584 m .55593 .57136 L .58306 .56344 L p .556 .341 .544 r
F P
0 g
s
.55569 .54584 m .54141 .53102 L .54128 .50576 L p .964 .688 .461 r
F P
0 g
s
.55569 .54584 m .54141 .53102 L .54128 .50576 L p .964 .688 .461 r
F P
0 g
s
.58262 .53785 m .55569 .54584 L .54141 .53102 L p .652 .756 .926 r
F P
0 g
s
.58306 .56344 m .58262 .53785 L .55569 .54584 L p .556 .341 .544 r
F P
0 g
s
.55569 .54584 m .55593 .57136 L .58306 .56344 L p .556 .341 .544 r
F P
0 g
s
.51457 .53908 m .54141 .53102 L .55569 .54584 L p .652 .756 .926 r
F P
0 g
s
.54141 .53102 m .55569 .54584 L .55593 .57136 L p .964 .688 .461 r
F P
0 g
s
.58262 .53785 m .55569 .54584 L .54141 .53102 L p .652 .756 .926 r
F P
0 g
s
.43131 .5254 m .432 .50009 L .40579 .50827 L p .547 .329 .535 r
F P
0 g
s
.40579 .50827 m .40491 .53351 L .43131 .5254 L p .547 .329 .535 r
F P
0 g
s
.40579 .50827 m .39017 .49312 L .39116 .46813 L p .954 .688 .492 r
F P
0 g
s
.432 .50009 m .40579 .50827 L .39017 .49312 L p .654 .754 .923 r
F P
0 g
s
.43131 .5254 m .432 .50009 L .40579 .50827 L p .547 .329 .535 r
F P
0 g
s
.40579 .50827 m .40491 .53351 L .43131 .5254 L p .547 .329 .535 r
F P
0 g
s
.36406 .50136 m .39017 .49312 L .40579 .50827 L p .654 .754 .923 r
F P
0 g
s
.36406 .50136 m .39017 .49312 L .40579 .50827 L p .654 .754 .923 r
F P
0 g
s
.39017 .49312 m .40579 .50827 L .40491 .53351 L p .954 .688 .492 r
F P
0 g
s
.39017 .49312 m .40579 .50827 L .40491 .53351 L p .954 .688 .492 r
F P
0 g
s
.81349 .41129 m .81135 .38683 L .78333 .39555 L p .558 .345 .547 r
F P
0 g
s
.78333 .39555 m .78525 .41995 L .81349 .41129 L p .558 .345 .547 r
F P
0 g
s
.74313 .38818 m .77107 .37939 L .78333 .39555 L p .66 .747 .915 r
F P
0 g
s
.77107 .37939 m .78333 .39555 L .78525 .41995 L p .976 .678 .372 r
F P
0 g
s
.8534 .50764 m .84177 .49248 L .83943 .46749 L p .976 .675 .358 r
F P
0 g
s
.8534 .50764 m .84177 .49248 L .83943 .46749 L p .976 .675 .358 r
F P
0 g
s
.88177 .49946 m .8534 .50764 L .84177 .49248 L p .654 .754 .923 r
F P
0 g
s
.81347 .50073 m .84177 .49248 L .8534 .50764 L p .654 .754 .923 r
F P
0 g
s
.81347 .50073 m .84177 .49248 L .8534 .50764 L p .654 .754 .923 r
F P
0 g
s
.84177 .49248 m .8534 .50764 L .85584 .53289 L p .976 .675 .358 r
F P
0 g
s
.73263 .48672 m .73109 .46169 L .70344 .47005 L p .558 .345 .547 r
F P
0 g
s
.70344 .47005 m .70477 .49502 L .73263 .48672 L p .558 .345 .547 r
F P
0 g
s
.70344 .47005 m .69047 .45456 L .68925 .42985 L p .974 .684 .41 r
F P
0 g
s
.73109 .46169 m .70344 .47005 L .69047 .45456 L p .656 .751 .92 r
F P
0 g
s
.73263 .48672 m .73109 .46169 L .70344 .47005 L p .558 .345 .547 r
F P
0 g
s
.70344 .47005 m .70477 .49502 L .73263 .48672 L p .558 .345 .547 r
F P
0 g
s
.6629 .46298 m .69047 .45456 L .70344 .47005 L p .656 .751 .92 r
F P
0 g
s
.69047 .45456 m .70344 .47005 L .70477 .49502 L p .974 .684 .41 r
F P
0 g
s
.73109 .46169 m .70344 .47005 L .69047 .45456 L p .656 .751 .92 r
F P
0 g
s
.69047 .45456 m .70344 .47005 L .70477 .49502 L p .974 .684 .41 r
F P
0 g
s
.58083 .44867 m .58041 .42392 L .55348 .43247 L p .55 .333 .538 r
F P
0 g
s
.55348 .43247 m .5537 .45716 L .58083 .44867 L p .55 .333 .538 r
F P
0 g
s
.55348 .43247 m .53917 .41663 L .53907 .3922 L p .966 .687 .452 r
F P
0 g
s
.55348 .43247 m .53917 .41663 L .53907 .3922 L p .966 .687 .452 r
F P
0 g
s
.58041 .42392 m .55348 .43247 L .53917 .41663 L p .658 .749 .917 r
F P
0 g
s
.58083 .44867 m .58041 .42392 L .55348 .43247 L p .55 .333 .538 r
F P
0 g
s
.55348 .43247 m .5537 .45716 L .58083 .44867 L p .55 .333 .538 r
F P
0 g
s
.51233 .42524 m .53917 .41663 L .55348 .43247 L p .658 .749 .917 r
F P
0 g
s
.51233 .42524 m .53917 .41663 L .55348 .43247 L p .658 .749 .917 r
F P
0 g
s
.53917 .41663 m .55348 .43247 L .5537 .45716 L p .966 .687 .452 r
F P
0 g
s
.58041 .42392 m .55348 .43247 L .53917 .41663 L p .658 .749 .917 r
F P
0 g
s
.53917 .41663 m .55348 .43247 L .5537 .45716 L p .966 .687 .452 r
F P
0 g
s
.42973 .38616 m .40353 .39488 L .38788 .37871 L p .66 .747 .915 r
F P
0 g
s
.42902 .41062 m .42973 .38616 L .40353 .39488 L p .541 .319 .528 r
F P
0 g
s
.40353 .39488 m .40263 .41929 L .42902 .41062 L p .541 .319 .528 r
F P
0 g
s
.38788 .37871 m .40353 .39488 L .40263 .41929 L p .957 .688 .485 r
F P
0 g
s
.65172 .56221 m .65078 .53661 L .6235 .54462 L p .558 .345 .547 r
F P
0 g
s
.6235 .54462 m .62424 .57015 L .65172 .56221 L p .558 .345 .547 r
F P
0 g
s
.6235 .54462 m .60981 .52978 L .60918 .5045 L p .969 .687 .442 r
F P
0 g
s
.65078 .53661 m .6235 .54462 L .60981 .52978 L p .652 .756 .926 r
F P
0 g
s
.65172 .56221 m .65078 .53661 L .6235 .54462 L p .558 .345 .547 r
F P
0 g
s
.6235 .54462 m .62424 .57015 L .65172 .56221 L p .558 .345 .547 r
F P
0 g
s
.60981 .52978 m .6235 .54462 L .62424 .57015 L p .969 .687 .442 r
F P
0 g
s
.65078 .53661 m .6235 .54462 L .60981 .52978 L p .652 .756 .926 r
F P
0 g
s
.49986 .52414 m .50004 .49883 L .47349 .50702 L p .55 .333 .538 r
F P
0 g
s
.47349 .50702 m .47311 .53227 L .49986 .52414 L p .55 .333 .538 r
F P
0 g
s
.47349 .50702 m .45846 .49184 L .45894 .46685 L p .959 .688 .477 r
F P
0 g
s
.50004 .49883 m .47349 .50702 L .45846 .49184 L p .654 .754 .923 r
F P
0 g
s
.49986 .52414 m .50004 .49883 L .47349 .50702 L p .55 .333 .538 r
F P
0 g
s
.47349 .50702 m .47311 .53227 L .49986 .52414 L p .55 .333 .538 r
F P
0 g
s
.432 .50009 m .45846 .49184 L .47349 .50702 L p .654 .754 .923 r
F P
0 g
s
.432 .50009 m .45846 .49184 L .47349 .50702 L p .654 .754 .923 r
F P
0 g
s
.45846 .49184 m .47349 .50702 L .47311 .53227 L p .959 .688 .477 r
F P
0 g
s
.45846 .49184 m .47349 .50702 L .47311 .53227 L p .959 .688 .477 r
F P
0 g
s
.34799 .48608 m .3493 .46105 L .32347 .46941 L p .541 .319 .528 r
F P
0 g
s
.32347 .46941 m .32198 .49439 L .34799 .48608 L p .541 .319 .528 r
F P
0 g
s
.3493 .46105 m .32347 .46941 L .3071 .4539 L p .656 .751 .92 r
F P
0 g
s
.34799 .48608 m .3493 .46105 L .32347 .46941 L p .541 .319 .528 r
F P
0 g
s
.32347 .46941 m .32198 .49439 L .34799 .48608 L p .541 .319 .528 r
F P
0 g
s
.3071 .4539 m .32347 .46941 L .32198 .49439 L p .949 .687 .505 r
F P
0 g
s
.88232 .40995 m .87967 .38548 L .8513 .39421 L p .561 .349 .55 r
F P
0 g
s
.8513 .39421 m .85373 .41863 L .88232 .40995 L p .561 .349 .55 r
F P
0 g
s
.87967 .38548 m .8513 .39421 L .83964 .37803 L p .66 .747 .915 r
F P
0 g
s
.88232 .40995 m .87967 .38548 L .8513 .39421 L p .561 .349 .55 r
F P
0 g
s
.8513 .39421 m .85373 .41863 L .88232 .40995 L p .561 .349 .55 r
F P
0 g
s
.83964 .37803 m .8513 .39421 L .85373 .41863 L p .976 .672 .343 r
F P
0 g
s
.39343 .58162 m .37768 .5671 L .37876 .54155 L p .952 .687 .499 r
F P
0 g
s
.41961 .57379 m .39343 .58162 L .37768 .5671 L p .649 .759 .929 r
F P
0 g
s
.77139 .46877 m .75901 .45325 L .75728 .42853 L p .976 .68 .386 r
F P
0 g
s
.77139 .46877 m .75901 .45325 L .75728 .42853 L p .976 .68 .386 r
F P
0 g
s
.79938 .4604 m .77139 .46877 L .75901 .45325 L p .656 .751 .92 r
F P
0 g
s
.73109 .46169 m .75901 .45325 L .77139 .46877 L p .656 .751 .92 r
F P
0 g
s
.73109 .46169 m .75901 .45325 L .77139 .46877 L p .656 .751 .92 r
F P
0 g
s
.75901 .45325 m .77139 .46877 L .77322 .49375 L p .976 .68 .386 r
F P
0 g
s
.64951 .44736 m .64859 .4226 L .62132 .43116 L p .553 .337 .541 r
F P
0 g
s
.62132 .43116 m .62203 .45586 L .64951 .44736 L p .553 .337 .541 r
F P
0 g
s
.62132 .43116 m .6076 .4153 L .60699 .39086 L p .971 .686 .432 r
F P
0 g
s
.64859 .4226 m .62132 .43116 L .6076 .4153 L p .658 .749 .917 r
F P
0 g
s
.64951 .44736 m .64859 .4226 L .62132 .43116 L p .553 .337 .541 r
F P
0 g
s
.62132 .43116 m .62203 .45586 L .64951 .44736 L p .553 .337 .541 r
F P
0 g
s
.58041 .42392 m .6076 .4153 L .62132 .43116 L p .658 .749 .917 r
F P
0 g
s
.58041 .42392 m .6076 .4153 L .62132 .43116 L p .658 .749 .917 r
F P
0 g
s
.6076 .4153 m .62132 .43116 L .62203 .45586 L p .971 .686 .432 r
F P
0 g
s
.6076 .4153 m .62132 .43116 L .62203 .45586 L p .971 .686 .432 r
F P
0 g
s
.4976 .40928 m .4978 .38481 L .47125 .39354 L p .544 .324 .532 r
F P
0 g
s
.47125 .39354 m .47085 .41796 L .4976 .40928 L p .544 .324 .532 r
F P
0 g
s
.4978 .38481 m .47125 .39354 L .45619 .37735 L p .66 .747 .915 r
F P
0 g
s
.4976 .40928 m .4978 .38481 L .47125 .39354 L p .544 .324 .532 r
F P
0 g
s
.47125 .39354 m .47085 .41796 L .4976 .40928 L p .544 .324 .532 r
F P
0 g
s
.45619 .37735 m .47125 .39354 L .47085 .41796 L p .962 .688 .469 r
F P
0 g
s
.69141 .54339 m .67831 .52853 L .67718 .50325 L p .972 .685 .422 r
F P
0 g
s
.71903 .53537 m .69141 .54339 L .67831 .52853 L p .652 .756 .926 r
F P
0 g
s
.72048 .56098 m .71903 .53537 L .69141 .54339 L p .561 .349 .55 r
F P
0 g
s
.69141 .54339 m .69265 .56893 L .72048 .56098 L p .561 .349 .55 r
F P
0 g
s
.65078 .53661 m .67831 .52853 L .69141 .54339 L p .652 .756 .926 r
F P
0 g
s
.67831 .52853 m .69141 .54339 L .69265 .56893 L p .972 .685 .422 r
F P
0 g
s
.71903 .53537 m .69141 .54339 L .67831 .52853 L p .652 .756 .926 r
F P
0 g
s
.67831 .52853 m .69141 .54339 L .69265 .56893 L p .972 .685 .422 r
F P
0 g
s
.56851 .52289 m .56818 .49756 L .54128 .50576 L p .553 .337 .541 r
F P
0 g
s
.54128 .50576 m .54141 .53102 L .56851 .52289 L p .553 .337 .541 r
F P
0 g
s
.54128 .50576 m .52685 .49056 L .52683 .46556 L p .964 .688 .461 r
F P
0 g
s
.54128 .50576 m .52685 .49056 L .52683 .46556 L p .964 .688 .461 r
F P
0 g
s
.56818 .49756 m .54128 .50576 L .52685 .49056 L p .654 .754 .923 r
F P
0 g
s
.56851 .52289 m .56818 .49756 L .54128 .50576 L p .553 .337 .541 r
F P
0 g
s
.54128 .50576 m .54141 .53102 L .56851 .52289 L p .553 .337 .541 r
F P
0 g
s
.50004 .49883 m .52685 .49056 L .54128 .50576 L p .654 .754 .923 r
F P
0 g
s
.50004 .49883 m .52685 .49056 L .54128 .50576 L p .654 .754 .923 r
F P
0 g
s
.52685 .49056 m .54128 .50576 L .54141 .53102 L p .964 .688 .461 r
F P
0 g
s
.56818 .49756 m .54128 .50576 L .52685 .49056 L p .654 .754 .923 r
F P
0 g
s
.52685 .49056 m .54128 .50576 L .54141 .53102 L p .964 .688 .461 r
F P
0 g
s
.39116 .46813 m .37538 .4526 L .37648 .42788 L p .954 .688 .492 r
F P
0 g
s
.39116 .46813 m .37538 .4526 L .37648 .42788 L p .954 .688 .492 r
F P
0 g
s
.41733 .45975 m .39116 .46813 L .37538 .4526 L p .656 .751 .92 r
F P
0 g
s
.41653 .48479 m .41733 .45975 L .39116 .46813 L p .544 .324 .532 r
F P
0 g
s
.39116 .46813 m .39017 .49312 L .41653 .48479 L p .544 .324 .532 r
F P
0 g
s
.3493 .46105 m .37538 .4526 L .39116 .46813 L p .656 .751 .92 r
F P
0 g
s
.37538 .4526 m .39116 .46813 L .39017 .49312 L p .954 .688 .492 r
F P
0 g
s
.41733 .45975 m .39116 .46813 L .37538 .4526 L p .656 .751 .92 r
F P
0 g
s
.87967 .38548 m .90832 .37667 L .91938 .39287 L p .66 .747 .915 r
F P
0 g
s
.90832 .37667 m .91938 .39287 L .92231 .4173 L p .973 .663 .31 r
F P
0 g
s
.41961 .57379 m .44604 .56588 L .46119 .58042 L p .649 .759 .929 r
F P
0 g
s
.46119 .58042 m .44604 .56588 L .44662 .54032 L p .957 .688 .485 r
F P
0 g
s
.87034 .48415 m .86777 .4591 L .83943 .46749 L p .564 .353 .553 r
F P
0 g
s
.83943 .46749 m .84177 .49248 L .87034 .48415 L p .564 .353 .553 r
F P
0 g
s
.83943 .46749 m .82765 .45194 L .82541 .42722 L p .976 .675 .358 r
F P
0 g
s
.83943 .46749 m .82765 .45194 L .82541 .42722 L p .976 .675 .358 r
F P
0 g
s
.86777 .4591 m .83943 .46749 L .82765 .45194 L p .656 .751 .92 r
F P
0 g
s
.79938 .4604 m .82765 .45194 L .83943 .46749 L p .656 .751 .92 r
F P
0 g
s
.79938 .4604 m .82765 .45194 L .83943 .46749 L p .656 .751 .92 r
F P
0 g
s
.82765 .45194 m .83943 .46749 L .84177 .49248 L p .976 .675 .358 r
F P
0 g
s
.7183 .44604 m .71687 .42128 L .68925 .42985 L p .556 .341 .544 r
F P
0 g
s
.68925 .42985 m .69047 .45456 L .7183 .44604 L p .556 .341 .544 r
F P
0 g
s
.68925 .42985 m .67613 .41397 L .67501 .38952 L p .974 .684 .41 r
F P
0 g
s
.68925 .42985 m .67613 .41397 L .67501 .38952 L p .974 .684 .41 r
F P
0 g
s
.71687 .42128 m .68925 .42985 L .67613 .41397 L p .658 .749 .917 r
F P
0 g
s
.64859 .4226 m .67613 .41397 L .68925 .42985 L p .658 .749 .917 r
F P
0 g
s
.56627 .40794 m .56596 .38346 L .53907 .3922 L p .547 .329 .535 r
F P
0 g
s
.53907 .3922 m .53917 .41663 L .56627 .40794 L p .547 .329 .535 r
F P
0 g
s
.56596 .38346 m .53907 .3922 L .5246 .37599 L p .66 .747 .915 r
F P
0 g
s
.56627 .40794 m .56596 .38346 L .53907 .3922 L p .547 .329 .535 r
F P
0 g
s
.53907 .3922 m .53917 .41663 L .56627 .40794 L p .547 .329 .535 r
F P
0 g
s
.4978 .38481 m .5246 .37599 L .53907 .3922 L p .66 .747 .915 r
F P
0 g
s
.5246 .37599 m .53907 .3922 L .53917 .41663 L p .966 .687 .452 r
F P
0 g
s
.5246 .37599 m .53907 .3922 L .53917 .41663 L p .966 .687 .452 r
F P
0 g
s
.75942 .54216 m .74692 .52728 L .74528 .50199 L p .975 .682 .398 r
F P
0 g
s
.75942 .54216 m .74692 .52728 L .74528 .50199 L p .975 .682 .398 r
F P
0 g
s
.78739 .53413 m .75942 .54216 L .74692 .52728 L p .652 .756 .926 r
F P
0 g
s
.78935 .55975 m .78739 .53413 L .75942 .54216 L p .564 .353 .553 r
F P
0 g
s
.75942 .54216 m .76116 .56771 L .78935 .55975 L p .564 .353 .553 r
F P
0 g
s
.71903 .53537 m .74692 .52728 L .75942 .54216 L p .652 .756 .926 r
F P
0 g
s
.74692 .52728 m .75942 .54216 L .76116 .56771 L p .975 .682 .398 r
F P
0 g
s
.78739 .53413 m .75942 .54216 L .74692 .52728 L p .652 .756 .926 r
F P
0 g
s
.63726 .52163 m .63643 .49629 L .60918 .5045 L p .556 .341 .544 r
F P
0 g
s
.60918 .5045 m .60981 .52978 L .63726 .52163 L p .556 .341 .544 r
F P
0 g
s
.63643 .49629 m .60918 .5045 L .59534 .48928 L p .654 .754 .923 r
F P
0 g
s
.63726 .52163 m .63643 .49629 L .60918 .5045 L p .556 .341 .544 r
F P
0 g
s
.60918 .5045 m .60981 .52978 L .63726 .52163 L p .556 .341 .544 r
F P
0 g
s
.56818 .49756 m .59534 .48928 L .60918 .5045 L p .654 .754 .923 r
F P
0 g
s
.59534 .48928 m .60918 .5045 L .60981 .52978 L p .969 .687 .442 r
F P
0 g
s
.59534 .48928 m .60918 .5045 L .60981 .52978 L p .969 .687 .442 r
F P
0 g
s
.45894 .46685 m .44376 .45129 L .44436 .42656 L p .959 .688 .477 r
F P
0 g
s
.45894 .46685 m .44376 .45129 L .44436 .42656 L p .959 .688 .477 r
F P
0 g
s
.48547 .45846 m .45894 .46685 L .44376 .45129 L p .656 .751 .92 r
F P
0 g
s
.41733 .45975 m .44376 .45129 L .45894 .46685 L p .656 .751 .92 r
F P
0 g
s
.48772 .57258 m .51449 .56466 L .52906 .57922 L p .649 .759 .929 r
F P
0 g
s
.52906 .57922 m .51449 .56466 L .51457 .53908 L p .962 .688 .469 r
F P
0 g
s
.40401 .55913 m .40491 .53351 L .37876 .54155 L p .547 .329 .535 r
F P
0 g
s
.37876 .54155 m .37768 .5671 L .40401 .55913 L p .547 .329 .535 r
F P
0 g
s
.37876 .54155 m .36286 .52665 L .36406 .50136 L p .952 .687 .499 r
F P
0 g
s
.37876 .54155 m .36286 .52665 L .36406 .50136 L p .952 .687 .499 r
F P
0 g
s
.40491 .53351 m .37876 .54155 L .36286 .52665 L p .652 .756 .926 r
F P
0 g
s
.33681 .53475 m .36286 .52665 L .37876 .54155 L p .652 .756 .926 r
F P
0 g
s
.86777 .4591 m .89639 .45064 L .90757 .46621 L p .656 .751 .92 r
F P
0 g
s
.90757 .46621 m .89639 .45064 L .89364 .4259 L p .975 .668 .327 r
F P
0 g
s
.7872 .44473 m .78525 .41995 L .75728 .42853 L p .558 .345 .547 r
F P
0 g
s
.75728 .42853 m .75901 .45325 L .7872 .44473 L p .558 .345 .547 r
F P
0 g
s
.75728 .42853 m .74476 .41263 L .74313 .38818 L p .976 .68 .386 r
F P
0 g
s
.78525 .41995 m .75728 .42853 L .74476 .41263 L p .658 .749 .917 r
F P
0 g
s
.7872 .44473 m .78525 .41995 L .75728 .42853 L p .558 .345 .547 r
F P
0 g
s
.75728 .42853 m .75901 .45325 L .7872 .44473 L p .558 .345 .547 r
F P
0 g
s
.71687 .42128 m .74476 .41263 L .75728 .42853 L p .658 .749 .917 r
F P
0 g
s
.74476 .41263 m .75728 .42853 L .75901 .45325 L p .976 .68 .386 r
F P
0 g
s
.78525 .41995 m .75728 .42853 L .74476 .41263 L p .658 .749 .917 r
F P
0 g
s
.74476 .41263 m .75728 .42853 L .75901 .45325 L p .976 .68 .386 r
F P
0 g
s
.63423 .3821 m .60699 .39086 L .59312 .37462 L p .66 .747 .915 r
F P
0 g
s
.63505 .40659 m .63423 .3821 L .60699 .39086 L p .55 .333 .538 r
F P
0 g
s
.60699 .39086 m .6076 .4153 L .63505 .40659 L p .55 .333 .538 r
F P
0 g
s
.56596 .38346 m .59312 .37462 L .60699 .39086 L p .66 .747 .915 r
F P
0 g
s
.59312 .37462 m .60699 .39086 L .6076 .4153 L p .971 .686 .432 r
F P
0 g
s
.59312 .37462 m .60699 .39086 L .6076 .4153 L p .971 .686 .432 r
F P
0 g
s
.82753 .54093 m .81563 .52603 L .81347 .50073 L p .976 .678 .372 r
F P
0 g
s
.82753 .54093 m .81563 .52603 L .81347 .50073 L p .976 .678 .372 r
F P
0 g
s
.85584 .53289 m .82753 .54093 L .81563 .52603 L p .652 .756 .926 r
F P
0 g
s
.78739 .53413 m .81563 .52603 L .82753 .54093 L p .652 .756 .926 r
F P
0 g
s
.70612 .52037 m .70477 .49502 L .67718 .50325 L p .558 .345 .547 r
F P
0 g
s
.67718 .50325 m .67831 .52853 L .70612 .52037 L p .558 .345 .547 r
F P
0 g
s
.67718 .50325 m .66394 .488 L .6629 .46298 L p .972 .685 .422 r
F P
0 g
s
.67718 .50325 m .66394 .488 L .6629 .46298 L p .972 .685 .422 r
F P
0 g
s
.70477 .49502 m .67718 .50325 L .66394 .488 L p .654 .754 .923 r
F P
0 g
s
.63643 .49629 m .66394 .488 L .67718 .50325 L p .654 .754 .923 r
F P
0 g
s
.55392 .48222 m .5537 .45716 L .52683 .46556 L p .55 .333 .538 r
F P
0 g
s
.52683 .46556 m .52685 .49056 L .55392 .48222 L p .55 .333 .538 r
F P
0 g
s
.52683 .46556 m .51224 .44998 L .51233 .42524 L p .964 .688 .461 r
F P
0 g
s
.52683 .46556 m .51224 .44998 L .51233 .42524 L p .964 .688 .461 r
F P
0 g
s
.5537 .45716 m .52683 .46556 L .51224 .44998 L p .656 .751 .92 r
F P
0 g
s
.55392 .48222 m .5537 .45716 L .52683 .46556 L p .55 .333 .538 r
F P
0 g
s
.52683 .46556 m .52685 .49056 L .55392 .48222 L p .55 .333 .538 r
F P
0 g
s
.48547 .45846 m .51224 .44998 L .52683 .46556 L p .656 .751 .92 r
F P
0 g
s
.48547 .45846 m .51224 .44998 L .52683 .46556 L p .656 .751 .92 r
F P
0 g
s
.51224 .44998 m .52683 .46556 L .52685 .49056 L p .964 .688 .461 r
F P
0 g
s
.5537 .45716 m .52683 .46556 L .51224 .44998 L p .656 .751 .92 r
F P
0 g
s
.51224 .44998 m .52683 .46556 L .52685 .49056 L p .964 .688 .461 r
F P
0 g
s
.40171 .44407 m .40263 .41929 L .37648 .42788 L p .541 .319 .528 r
F P
0 g
s
.37648 .42788 m .37538 .4526 L .40171 .44407 L p .541 .319 .528 r
F P
0 g
s
.40263 .41929 m .37648 .42788 L .36055 .41196 L p .658 .749 .917 r
F P
0 g
s
.40171 .44407 m .40263 .41929 L .37648 .42788 L p .541 .319 .528 r
F P
0 g
s
.37648 .42788 m .37538 .4526 L .40171 .44407 L p .541 .319 .528 r
F P
0 g
s
.3345 .42062 m .36055 .41196 L .37648 .42788 L p .658 .749 .917 r
F P
0 g
s
.36055 .41196 m .37648 .42788 L .37538 .4526 L p .954 .688 .492 r
F P
0 g
s
.36055 .41196 m .37648 .42788 L .37538 .4526 L p .954 .688 .492 r
F P
0 g
s
.25155 .38142 m .22614 .39019 L .20886 .37394 L p .66 .747 .915 r
F P
0 g
s
.24951 .40592 m .25155 .38142 L .22614 .39019 L p .53 .304 .517 r
F P
0 g
s
.22614 .39019 m .22391 .41463 L .24951 .40592 L p .53 .304 .517 r
F P
0 g
s
.18354 .38278 m .20886 .37394 L .22614 .39019 L p .66 .747 .915 r
F P
0 g
s
.20886 .37394 m .22614 .39019 L .22391 .41463 L p .943 .686 .517 r
F P
0 g
s
.20886 .37394 m .22614 .39019 L .22391 .41463 L p .943 .686 .517 r
F P
0 g
s
.55593 .57136 m .58306 .56344 L .59702 .57801 L p .649 .759 .929 r
F P
0 g
s
.59702 .57801 m .58306 .56344 L .58262 .53785 L p .966 .687 .452 r
F P
0 g
s
.44662 .54032 m .43131 .5254 L .432 .50009 L p .957 .688 .485 r
F P
0 g
s
.44662 .54032 m .43131 .5254 L .432 .50009 L p .957 .688 .485 r
F P
0 g
s
.47311 .53227 m .44662 .54032 L .43131 .5254 L p .652 .756 .926 r
F P
0 g
s
.47272 .5579 m .47311 .53227 L .44662 .54032 L p .55 .333 .538 r
F P
0 g
s
.44662 .54032 m .44604 .56588 L .47272 .5579 L p .55 .333 .538 r
F P
0 g
s
.40491 .53351 m .43131 .5254 L .44662 .54032 L p .652 .756 .926 r
F P
0 g
s
.40491 .53351 m .43131 .5254 L .44662 .54032 L p .652 .756 .926 r
F P
0 g
s
.43131 .5254 m .44662 .54032 L .44604 .56588 L p .957 .688 .485 r
F P
0 g
s
.47311 .53227 m .44662 .54032 L .43131 .5254 L p .652 .756 .926 r
F P
0 g
s
.43131 .5254 m .44662 .54032 L .44604 .56588 L p .957 .688 .485 r
F P
0 g
s
.85619 .44341 m .85373 .41863 L .82541 .42722 L p .561 .349 .55 r
F P
0 g
s
.82541 .42722 m .82765 .45194 L .85619 .44341 L p .561 .349 .55 r
F P
0 g
s
.78525 .41995 m .81349 .41129 L .82541 .42722 L p .658 .749 .917 r
F P
0 g
s
.82541 .42722 m .81349 .41129 L .81135 .38683 L p .976 .675 .358 r
F P
0 g
s
.70393 .40524 m .7026 .38075 L .67501 .38952 L p .553 .337 .541 r
F P
0 g
s
.67501 .38952 m .67613 .41397 L .70393 .40524 L p .553 .337 .541 r
F P
0 g
s
.7026 .38075 m .67501 .38952 L .66174 .37325 L p .66 .747 .915 r
F P
0 g
s
.70393 .40524 m .7026 .38075 L .67501 .38952 L p .553 .337 .541 r
F P
0 g
s
.67501 .38952 m .67613 .41397 L .70393 .40524 L p .553 .337 .541 r
F P
0 g
s
.63423 .3821 m .66174 .37325 L .67501 .38952 L p .66 .747 .915 r
F P
0 g
s
.66174 .37325 m .67501 .38952 L .67613 .41397 L p .974 .684 .41 r
F P
0 g
s
.66174 .37325 m .67501 .38952 L .67613 .41397 L p .974 .684 .41 r
F P
0 g
s
.77508 .5191 m .77322 .49375 L .74528 .50199 L p .561 .349 .55 r
F P
0 g
s
.74528 .50199 m .74692 .52728 L .77508 .5191 L p .561 .349 .55 r
F P
0 g
s
.74528 .50199 m .73263 .48672 L .73109 .46169 L p .975 .682 .398 r
F P
0 g
s
.74528 .50199 m .73263 .48672 L .73109 .46169 L p .975 .682 .398 r
F P
0 g
s
.77322 .49375 m .74528 .50199 L .73263 .48672 L p .654 .754 .923 r
F P
0 g
s
.70477 .49502 m .73263 .48672 L .74528 .50199 L p .654 .754 .923 r
F P
0 g
s
.59482 .46427 m .58083 .44867 L .58041 .42392 L p .969 .687 .442 r
F P
0 g
s
.59482 .46427 m .58083 .44867 L .58041 .42392 L p .969 .687 .442 r
F P
0 g
s
.62203 .45586 m .59482 .46427 L .58083 .44867 L p .656 .751 .92 r
F P
0 g
s
.62276 .48093 m .62203 .45586 L .59482 .46427 L p .553 .337 .541 r
F P
0 g
s
.59482 .46427 m .59534 .48928 L .62276 .48093 L p .553 .337 .541 r
F P
0 g
s
.5537 .45716 m .58083 .44867 L .59482 .46427 L p .656 .751 .92 r
F P
0 g
s
.5537 .45716 m .58083 .44867 L .59482 .46427 L p .656 .751 .92 r
F P
0 g
s
.58083 .44867 m .59482 .46427 L .59534 .48928 L p .969 .687 .442 r
F P
0 g
s
.62203 .45586 m .59482 .46427 L .58083 .44867 L p .656 .751 .92 r
F P
0 g
s
.58083 .44867 m .59482 .46427 L .59534 .48928 L p .969 .687 .442 r
F P
0 g
s
.47045 .44275 m .47085 .41796 L .44436 .42656 L p .544 .324 .532 r
F P
0 g
s
.44436 .42656 m .44376 .45129 L .47045 .44275 L p .544 .324 .532 r
F P
0 g
s
.47085 .41796 m .44436 .42656 L .42902 .41062 L p .658 .749 .917 r
F P
0 g
s
.47045 .44275 m .47085 .41796 L .44436 .42656 L p .544 .324 .532 r
F P
0 g
s
.44436 .42656 m .44376 .45129 L .47045 .44275 L p .544 .324 .532 r
F P
0 g
s
.40263 .41929 m .42902 .41062 L .44436 .42656 L p .658 .749 .917 r
F P
0 g
s
.42902 .41062 m .44436 .42656 L .44376 .45129 L p .959 .688 .477 r
F P
0 g
s
.42902 .41062 m .44436 .42656 L .44376 .45129 L p .959 .688 .477 r
F P
0 g
s
.66508 .57681 m .65172 .56221 L .65078 .53661 L p .971 .686 .432 r
F P
0 g
s
.66508 .57681 m .65172 .56221 L .65078 .53661 L p .971 .686 .432 r
F P
0 g
s
.69265 .56893 m .66508 .57681 L .65172 .56221 L p .649 .759 .929 r
F P
0 g
s
.62424 .57015 m .65172 .56221 L .66508 .57681 L p .649 .759 .929 r
F P
0 g
s
.51457 .53908 m .49986 .52414 L .50004 .49883 L p .962 .688 .469 r
F P
0 g
s
.51457 .53908 m .49986 .52414 L .50004 .49883 L p .962 .688 .469 r
F P
0 g
s
.54141 .53102 m .51457 .53908 L .49986 .52414 L p .652 .756 .926 r
F P
0 g
s
.54153 .55667 m .54141 .53102 L .51457 .53908 L p .553 .337 .541 r
F P
0 g
s
.51457 .53908 m .51449 .56466 L .54153 .55667 L p .553 .337 .541 r
F P
0 g
s
.47311 .53227 m .49986 .52414 L .51457 .53908 L p .652 .756 .926 r
F P
0 g
s
.49986 .52414 m .51457 .53908 L .51449 .56466 L p .962 .688 .469 r
F P
0 g
s
.54141 .53102 m .51457 .53908 L .49986 .52414 L p .652 .756 .926 r
F P
0 g
s
.38916 .51847 m .39017 .49312 L .36406 .50136 L p .544 .324 .532 r
F P
0 g
s
.36406 .50136 m .36286 .52665 L .38916 .51847 L p .544 .324 .532 r
F P
0 g
s
.36406 .50136 m .34799 .48608 L .3493 .46105 L p .952 .687 .499 r
F P
0 g
s
.39017 .49312 m .36406 .50136 L .34799 .48608 L p .654 .754 .923 r
F P
0 g
s
.38916 .51847 m .39017 .49312 L .36406 .50136 L p .544 .324 .532 r
F P
0 g
s
.36406 .50136 m .36286 .52665 L .38916 .51847 L p .544 .324 .532 r
F P
0 g
s
.32198 .49439 m .34799 .48608 L .36406 .50136 L p .654 .754 .923 r
F P
0 g
s
.32198 .49439 m .34799 .48608 L .36406 .50136 L p .654 .754 .923 r
F P
0 g
s
.34799 .48608 m .36406 .50136 L .36286 .52665 L p .952 .687 .499 r
F P
0 g
s
.34799 .48608 m .36406 .50136 L .36286 .52665 L p .952 .687 .499 r
F P
0 g
s
.89364 .4259 m .88232 .40995 L .87967 .38548 L p .975 .668 .327 r
F P
0 g
s
.89364 .4259 m .88232 .40995 L .87967 .38548 L p .975 .668 .327 r
F P
0 g
s
.92231 .4173 m .89364 .4259 L .88232 .40995 L p .658 .749 .917 r
F P
0 g
s
.85373 .41863 m .88232 .40995 L .89364 .4259 L p .658 .749 .917 r
F P
0 g
s
.85373 .41863 m .88232 .40995 L .89364 .4259 L p .658 .749 .917 r
F P
0 g
s
.88232 .40995 m .89364 .4259 L .89639 .45064 L p .975 .668 .327 r
F P
0 g
s
.77292 .40389 m .77107 .37939 L .74313 .38818 L p .556 .341 .544 r
F P
0 g
s
.74313 .38818 m .74476 .41263 L .77292 .40389 L p .556 .341 .544 r
F P
0 g
s
.77107 .37939 m .74313 .38818 L .73046 .37189 L p .66 .747 .915 r
F P
0 g
s
.77292 .40389 m .77107 .37939 L .74313 .38818 L p .556 .341 .544 r
F P
0 g
s
.74313 .38818 m .74476 .41263 L .77292 .40389 L p .556 .341 .544 r
F P
0 g
s
.73046 .37189 m .74313 .38818 L .74476 .41263 L p .976 .68 .386 r
F P
0 g
s
.84415 .51784 m .84177 .49248 L .81347 .50073 L p .564 .353 .553 r
F P
0 g
s
.81347 .50073 m .81563 .52603 L .84415 .51784 L p .564 .353 .553 r
F P
0 g
s
.81347 .50073 m .80143 .48544 L .79938 .4604 L p .976 .678 .372 r
F P
0 g
s
.84177 .49248 m .81347 .50073 L .80143 .48544 L p .654 .754 .923 r
F P
0 g
s
.84415 .51784 m .84177 .49248 L .81347 .50073 L p .564 .353 .553 r
F P
0 g
s
.81347 .50073 m .81563 .52603 L .84415 .51784 L p .564 .353 .553 r
F P
0 g
s
.77322 .49375 m .80143 .48544 L .81347 .50073 L p .654 .754 .923 r
F P
0 g
s
.80143 .48544 m .81347 .50073 L .81563 .52603 L p .976 .678 .372 r
F P
0 g
s
.84177 .49248 m .81347 .50073 L .80143 .48544 L p .654 .754 .923 r
F P
0 g
s
.80143 .48544 m .81347 .50073 L .81563 .52603 L p .976 .678 .372 r
F P
0 g
s
.69171 .47963 m .69047 .45456 L .6629 .46298 L p .556 .341 .544 r
F P
0 g
s
.6629 .46298 m .66394 .488 L .69171 .47963 L p .556 .341 .544 r
F P
0 g
s
.6629 .46298 m .64951 .44736 L .64859 .4226 L p .972 .685 .422 r
F P
0 g
s
.69047 .45456 m .6629 .46298 L .64951 .44736 L p .656 .751 .92 r
F P
0 g
s
.69171 .47963 m .69047 .45456 L .6629 .46298 L p .556 .341 .544 r
F P
0 g
s
.6629 .46298 m .66394 .488 L .69171 .47963 L p .556 .341 .544 r
F P
0 g
s
.62203 .45586 m .64951 .44736 L .6629 .46298 L p .656 .751 .92 r
F P
0 g
s
.64951 .44736 m .6629 .46298 L .66394 .488 L p .972 .685 .422 r
F P
0 g
s
.53928 .44143 m .53917 .41663 L .51233 .42524 L p .547 .329 .535 r
F P
0 g
s
.51233 .42524 m .51224 .44998 L .53928 .44143 L p .547 .329 .535 r
F P
0 g
s
.51233 .42524 m .4976 .40928 L .4978 .38481 L p .964 .688 .461 r
F P
0 g
s
.51233 .42524 m .4976 .40928 L .4978 .38481 L p .964 .688 .461 r
F P
0 g
s
.53917 .41663 m .51233 .42524 L .4976 .40928 L p .658 .749 .917 r
F P
0 g
s
.53928 .44143 m .53917 .41663 L .51233 .42524 L p .547 .329 .535 r
F P
0 g
s
.51233 .42524 m .51224 .44998 L .53928 .44143 L p .547 .329 .535 r
F P
0 g
s
.47085 .41796 m .4976 .40928 L .51233 .42524 L p .658 .749 .917 r
F P
0 g
s
.47085 .41796 m .4976 .40928 L .51233 .42524 L p .658 .749 .917 r
F P
0 g
s
.4976 .40928 m .51233 .42524 L .51224 .44998 L p .964 .688 .461 r
F P
0 g
s
.53917 .41663 m .51233 .42524 L .4976 .40928 L p .658 .749 .917 r
F P
0 g
s
.4976 .40928 m .51233 .42524 L .51224 .44998 L p .964 .688 .461 r
F P
0 g
s
.31966 .38007 m .34568 .3712 L .36177 .3875 L p .66 .747 .915 r
F P
0 g
s
.34568 .3712 m .36177 .3875 L .36055 .41196 L p .954 .688 .492 r
F P
0 g
s
.58262 .53785 m .56851 .52289 L .56818 .49756 L p .966 .687 .452 r
F P
0 g
s
.58262 .53785 m .56851 .52289 L .56818 .49756 L p .966 .687 .452 r
F P
0 g
s
.60981 .52978 m .58262 .53785 L .56851 .52289 L p .652 .756 .926 r
F P
0 g
s
.61045 .55543 m .60981 .52978 L .58262 .53785 L p .556 .341 .544 r
F P
0 g
s
.58262 .53785 m .58306 .56344 L .61045 .55543 L p .556 .341 .544 r
F P
0 g
s
.54141 .53102 m .56851 .52289 L .58262 .53785 L p .652 .756 .926 r
F P
0 g
s
.54141 .53102 m .56851 .52289 L .58262 .53785 L p .652 .756 .926 r
F P
0 g
s
.56851 .52289 m .58262 .53785 L .58306 .56344 L p .966 .687 .452 r
F P
0 g
s
.60981 .52978 m .58262 .53785 L .56851 .52289 L p .652 .756 .926 r
F P
0 g
s
.56851 .52289 m .58262 .53785 L .58306 .56344 L p .966 .687 .452 r
F P
0 g
s
.45796 .51721 m .45846 .49184 L .432 .50009 L p .547 .329 .535 r
F P
0 g
s
.432 .50009 m .43131 .5254 L .45796 .51721 L p .547 .329 .535 r
F P
0 g
s
.39017 .49312 m .41653 .48479 L .432 .50009 L p .654 .754 .923 r
F P
0 g
s
.41653 .48479 m .432 .50009 L .43131 .5254 L p .957 .688 .485 r
F P
0 g
s
.84177 .49248 m .87034 .48415 L .88177 .49946 L p .654 .754 .923 r
F P
0 g
s
.88177 .49946 m .87034 .48415 L .86777 .4591 L p .976 .672 .343 r
F P
0 g
s
.76077 .47834 m .75901 .45325 L .73109 .46169 L p .558 .345 .547 r
F P
0 g
s
.73109 .46169 m .73263 .48672 L .76077 .47834 L p .558 .345 .547 r
F P
0 g
s
.73109 .46169 m .7183 .44604 L .71687 .42128 L p .975 .682 .398 r
F P
0 g
s
.73109 .46169 m .7183 .44604 L .71687 .42128 L p .975 .682 .398 r
F P
0 g
s
.75901 .45325 m .73109 .46169 L .7183 .44604 L p .656 .751 .92 r
F P
0 g
s
.76077 .47834 m .75901 .45325 L .73109 .46169 L p .558 .345 .547 r
F P
0 g
s
.73109 .46169 m .73263 .48672 L .76077 .47834 L p .558 .345 .547 r
F P
0 g
s
.69047 .45456 m .7183 .44604 L .73109 .46169 L p .656 .751 .92 r
F P
0 g
s
.69047 .45456 m .7183 .44604 L .73109 .46169 L p .656 .751 .92 r
F P
0 g
s
.7183 .44604 m .73109 .46169 L .73263 .48672 L p .975 .682 .398 r
F P
0 g
s
.75901 .45325 m .73109 .46169 L .7183 .44604 L p .656 .751 .92 r
F P
0 g
s
.7183 .44604 m .73109 .46169 L .73263 .48672 L p .975 .682 .398 r
F P
0 g
s
.60822 .4401 m .6076 .4153 L .58041 .42392 L p .55 .333 .538 r
F P
0 g
s
.58041 .42392 m .58083 .44867 L .60822 .4401 L p .55 .333 .538 r
F P
0 g
s
.58041 .42392 m .56627 .40794 L .56596 .38346 L p .969 .687 .442 r
F P
0 g
s
.58041 .42392 m .56627 .40794 L .56596 .38346 L p .969 .687 .442 r
F P
0 g
s
.6076 .4153 m .58041 .42392 L .56627 .40794 L p .658 .749 .917 r
F P
0 g
s
.60822 .4401 m .6076 .4153 L .58041 .42392 L p .55 .333 .538 r
F P
0 g
s
.58041 .42392 m .58083 .44867 L .60822 .4401 L p .55 .333 .538 r
F P
0 g
s
.53917 .41663 m .56627 .40794 L .58041 .42392 L p .658 .749 .917 r
F P
0 g
s
.53917 .41663 m .56627 .40794 L .58041 .42392 L p .658 .749 .917 r
F P
0 g
s
.56627 .40794 m .58041 .42392 L .58083 .44867 L p .969 .687 .442 r
F P
0 g
s
.6076 .4153 m .58041 .42392 L .56627 .40794 L p .658 .749 .917 r
F P
0 g
s
.56627 .40794 m .58041 .42392 L .58083 .44867 L p .969 .687 .442 r
F P
0 g
s
.45619 .37735 m .42973 .38616 L .41424 .36983 L p .66 .747 .915 r
F P
0 g
s
.45568 .40187 m .45619 .37735 L .42973 .38616 L p .541 .319 .528 r
F P
0 g
s
.42973 .38616 m .42902 .41062 L .45568 .40187 L p .541 .319 .528 r
F P
0 g
s
.38788 .37871 m .41424 .36983 L .42973 .38616 L p .66 .747 .915 r
F P
0 g
s
.41424 .36983 m .42973 .38616 L .42902 .41062 L p .959 .688 .477 r
F P
0 g
s
.41424 .36983 m .42973 .38616 L .42902 .41062 L p .959 .688 .477 r
F P
0 g
s
.67947 .55419 m .67831 .52853 L .65078 .53661 L p .558 .345 .547 r
F P
0 g
s
.65078 .53661 m .65172 .56221 L .67947 .55419 L p .558 .345 .547 r
F P
0 g
s
.60981 .52978 m .63726 .52163 L .65078 .53661 L p .652 .756 .926 r
F P
0 g
s
.60981 .52978 m .63726 .52163 L .65078 .53661 L p .652 .756 .926 r
F P
0 g
s
.63726 .52163 m .65078 .53661 L .65172 .56221 L p .971 .686 .432 r
F P
0 g
s
.65078 .53661 m .63726 .52163 L .63643 .49629 L p .971 .686 .432 r
F P
0 g
s
.52686 .51594 m .52685 .49056 L .50004 .49883 L p .55 .333 .538 r
F P
0 g
s
.50004 .49883 m .49986 .52414 L .52686 .51594 L p .55 .333 .538 r
F P
0 g
s
.50004 .49883 m .48517 .48351 L .48547 .45846 L p .962 .688 .469 r
F P
0 g
s
.52685 .49056 m .50004 .49883 L .48517 .48351 L p .654 .754 .923 r
F P
0 g
s
.52686 .51594 m .52685 .49056 L .50004 .49883 L p .55 .333 .538 r
F P
0 g
s
.50004 .49883 m .49986 .52414 L .52686 .51594 L p .55 .333 .538 r
F P
0 g
s
.45846 .49184 m .48517 .48351 L .50004 .49883 L p .654 .754 .923 r
F P
0 g
s
.48517 .48351 m .50004 .49883 L .49986 .52414 L p .962 .688 .469 r
F P
0 g
s
.52685 .49056 m .50004 .49883 L .48517 .48351 L p .654 .754 .923 r
F P
0 g
s
.48517 .48351 m .50004 .49883 L .49986 .52414 L p .962 .688 .469 r
F P
0 g
s
.3493 .46105 m .33308 .44539 L .3345 .42062 L p .952 .687 .499 r
F P
0 g
s
.37538 .4526 m .3493 .46105 L .33308 .44539 L p .656 .751 .92 r
F P
0 g
s
.3071 .4539 m .33308 .44539 L .3493 .46105 L p .656 .751 .92 r
F P
0 g
s
.33308 .44539 m .3493 .46105 L .34799 .48608 L p .952 .687 .499 r
F P
0 g
s
.19856 .42326 m .18099 .40726 L .18354 .38278 L p .941 .685 .523 r
F P
0 g
s
.22391 .41463 m .19856 .42326 L .18099 .40726 L p .658 .749 .917 r
F P
0 g
s
.9112 .40119 m .90832 .37667 L .87967 .38548 L p .561 .349 .55 r
F P
0 g
s
.87967 .38548 m .88232 .40995 L .9112 .40119 L p .561 .349 .55 r
F P
0 g
s
.90832 .37667 m .87967 .38548 L .86821 .36914 L p .66 .747 .915 r
F P
0 g
s
.9112 .40119 m .90832 .37667 L .87967 .38548 L p .561 .349 .55 r
F P
0 g
s
.87967 .38548 m .88232 .40995 L .9112 .40119 L p .561 .349 .55 r
F P
0 g
s
.83964 .37803 m .86821 .36914 L .87967 .38548 L p .66 .747 .915 r
F P
0 g
s
.86821 .36914 m .87967 .38548 L .88232 .40995 L p .975 .668 .327 r
F P
0 g
s
.86821 .36914 m .87967 .38548 L .88232 .40995 L p .975 .668 .327 r
F P
0 g
s
.41961 .57379 m .40401 .55913 L .40491 .53351 L p .954 .688 .492 r
F P
0 g
s
.41961 .57379 m .40401 .55913 L .40491 .53351 L p .954 .688 .492 r
F P
0 g
s
.44604 .56588 m .41961 .57379 L .40401 .55913 L p .649 .759 .929 r
F P
0 g
s
.37768 .5671 m .40401 .55913 L .41961 .57379 L p .649 .759 .929 r
F P
0 g
s
.82992 .47704 m .82765 .45194 L .79938 .4604 L p .561 .349 .55 r
F P
0 g
s
.79938 .4604 m .80143 .48544 L .82992 .47704 L p .561 .349 .55 r
F P
0 g
s
.79938 .4604 m .7872 .44473 L .78525 .41995 L p .976 .678 .372 r
F P
0 g
s
.82765 .45194 m .79938 .4604 L .7872 .44473 L p .656 .751 .92 r
F P
0 g
s
.82992 .47704 m .82765 .45194 L .79938 .4604 L p .561 .349 .55 r
F P
0 g
s
.79938 .4604 m .80143 .48544 L .82992 .47704 L p .561 .349 .55 r
F P
0 g
s
.75901 .45325 m .7872 .44473 L .79938 .4604 L p .656 .751 .92 r
F P
0 g
s
.7872 .44473 m .79938 .4604 L .80143 .48544 L p .976 .678 .372 r
F P
0 g
s
.64859 .4226 m .63505 .40659 L .63423 .3821 L p .972 .685 .422 r
F P
0 g
s
.67613 .41397 m .64859 .4226 L .63505 .40659 L p .658 .749 .917 r
F P
0 g
s
.67726 .43878 m .67613 .41397 L .64859 .4226 L p .553 .337 .541 r
F P
0 g
s
.64859 .4226 m .64951 .44736 L .67726 .43878 L p .553 .337 .541 r
F P
0 g
s
.6076 .4153 m .63505 .40659 L .64859 .4226 L p .658 .749 .917 r
F P
0 g
s
.63505 .40659 m .64859 .4226 L .64951 .44736 L p .972 .685 .422 r
F P
0 g
s
.67613 .41397 m .64859 .4226 L .63505 .40659 L p .658 .749 .917 r
F P
0 g
s
.63505 .40659 m .64859 .4226 L .64951 .44736 L p .972 .685 .422 r
F P
0 g
s
.5246 .40051 m .5246 .37599 L .4978 .38481 L p .544 .324 .532 r
F P
0 g
s
.4978 .38481 m .4976 .40928 L .5246 .40051 L p .544 .324 .532 r
F P
0 g
s
.5246 .37599 m .4978 .38481 L .4829 .36846 L p .66 .747 .915 r
F P
0 g
s
.5246 .40051 m .5246 .37599 L .4978 .38481 L p .544 .324 .532 r
F P
0 g
s
.4978 .38481 m .4976 .40928 L .5246 .40051 L p .544 .324 .532 r
F P
0 g
s
.45619 .37735 m .4829 .36846 L .4978 .38481 L p .66 .747 .915 r
F P
0 g
s
.4829 .36846 m .4978 .38481 L .4976 .40928 L p .964 .688 .461 r
F P
0 g
s
.4829 .36846 m .4978 .38481 L .4976 .40928 L p .964 .688 .461 r
F P
0 g
s
.71903 .53537 m .70612 .52037 L .70477 .49502 L p .974 .684 .41 r
F P
0 g
s
.74692 .52728 m .71903 .53537 L .70612 .52037 L p .652 .756 .926 r
F P
0 g
s
.74859 .55295 m .74692 .52728 L .71903 .53537 L p .561 .349 .55 r
F P
0 g
s
.71903 .53537 m .72048 .56098 L .74859 .55295 L p .561 .349 .55 r
F P
0 g
s
.67831 .52853 m .70612 .52037 L .71903 .53537 L p .652 .756 .926 r
F P
0 g
s
.67831 .52853 m .70612 .52037 L .71903 .53537 L p .652 .756 .926 r
F P
0 g
s
.70612 .52037 m .71903 .53537 L .72048 .56098 L p .974 .684 .41 r
F P
0 g
s
.70612 .52037 m .71903 .53537 L .72048 .56098 L p .974 .684 .41 r
F P
0 g
s
.59587 .51467 m .59534 .48928 L .56818 .49756 L p .553 .337 .541 r
F P
0 g
s
.56818 .49756 m .56851 .52289 L .59587 .51467 L p .553 .337 .541 r
F P
0 g
s
.56818 .49756 m .55392 .48222 L .5537 .45716 L p .966 .687 .452 r
F P
0 g
s
.56818 .49756 m .55392 .48222 L .5537 .45716 L p .966 .687 .452 r
F P
0 g
s
.59534 .48928 m .56818 .49756 L .55392 .48222 L p .654 .754 .923 r
F P
0 g
s
.59587 .51467 m .59534 .48928 L .56818 .49756 L p .553 .337 .541 r
F P
0 g
s
.56818 .49756 m .56851 .52289 L .59587 .51467 L p .553 .337 .541 r
F P
0 g
s
.52685 .49056 m .55392 .48222 L .56818 .49756 L p .654 .754 .923 r
F P
0 g
s
.52685 .49056 m .55392 .48222 L .56818 .49756 L p .654 .754 .923 r
F P
0 g
s
.55392 .48222 m .56818 .49756 L .56851 .52289 L p .966 .687 .452 r
F P
0 g
s
.59534 .48928 m .56818 .49756 L .55392 .48222 L p .654 .754 .923 r
F P
0 g
s
.55392 .48222 m .56818 .49756 L .56851 .52289 L p .966 .687 .452 r
F P
0 g
s
.41733 .45975 m .40171 .44407 L .40263 .41929 L p .957 .688 .485 r
F P
0 g
s
.41733 .45975 m .40171 .44407 L .40263 .41929 L p .957 .688 .485 r
F P
0 g
s
.44376 .45129 m .41733 .45975 L .40171 .44407 L p .656 .751 .92 r
F P
0 g
s
.44315 .47639 m .44376 .45129 L .41733 .45975 L p .544 .324 .532 r
F P
0 g
s
.41733 .45975 m .41653 .48479 L .44315 .47639 L p .544 .324 .532 r
F P
0 g
s
.37538 .4526 m .40171 .44407 L .41733 .45975 L p .656 .751 .92 r
F P
0 g
s
.37538 .4526 m .40171 .44407 L .41733 .45975 L p .656 .751 .92 r
F P
0 g
s
.40171 .44407 m .41733 .45975 L .41653 .48479 L p .957 .688 .485 r
F P
0 g
s
.44376 .45129 m .41733 .45975 L .40171 .44407 L p .656 .751 .92 r
F P
0 g
s
.40171 .44407 m .41733 .45975 L .41653 .48479 L p .957 .688 .485 r
F P
0 g
s
.33681 .53475 m .32046 .51974 L .32198 .49439 L p .949 .687 .505 r
F P
0 g
s
.36286 .52665 m .33681 .53475 L .32046 .51974 L p .652 .756 .926 r
F P
0 g
s
.86777 .4591 m .85619 .44341 L .85373 .41863 L p .976 .672 .343 r
F P
0 g
s
.86777 .4591 m .85619 .44341 L .85373 .41863 L p .976 .672 .343 r
F P
0 g
s
.89639 .45064 m .86777 .4591 L .85619 .44341 L p .656 .751 .92 r
F P
0 g
s
.82765 .45194 m .85619 .44341 L .86777 .4591 L p .656 .751 .92 r
F P
0 g
s
.74641 .43745 m .74476 .41263 L .71687 .42128 L p .556 .341 .544 r
F P
0 g
s
.71687 .42128 m .7183 .44604 L .74641 .43745 L p .556 .341 .544 r
F P
0 g
s
.71687 .42128 m .70393 .40524 L .7026 .38075 L p .975 .682 .398 r
F P
0 g
s
.74476 .41263 m .71687 .42128 L .70393 .40524 L p .658 .749 .917 r
F P
0 g
s
.74641 .43745 m .74476 .41263 L .71687 .42128 L p .556 .341 .544 r
F P
0 g
s
.71687 .42128 m .7183 .44604 L .74641 .43745 L p .556 .341 .544 r
F P
0 g
s
.67613 .41397 m .70393 .40524 L .71687 .42128 L p .658 .749 .917 r
F P
0 g
s
.70393 .40524 m .71687 .42128 L .7183 .44604 L p .975 .682 .398 r
F P
0 g
s
.59364 .39916 m .59312 .37462 L .56596 .38346 L p .547 .329 .535 r
F P
0 g
s
.56596 .38346 m .56627 .40794 L .59364 .39916 L p .547 .329 .535 r
F P
0 g
s
.59312 .37462 m .56596 .38346 L .55167 .36708 L p .66 .747 .915 r
F P
0 g
s
.59364 .39916 m .59312 .37462 L .56596 .38346 L p .547 .329 .535 r
F P
0 g
s
.56596 .38346 m .56627 .40794 L .59364 .39916 L p .547 .329 .535 r
F P
0 g
s
.5246 .37599 m .55167 .36708 L .56596 .38346 L p .66 .747 .915 r
F P
0 g
s
.55167 .36708 m .56596 .38346 L .56627 .40794 L p .969 .687 .442 r
F P
0 g
s
.55167 .36708 m .56596 .38346 L .56627 .40794 L p .969 .687 .442 r
F P
0 g
s
.78739 .53413 m .77508 .5191 L .77322 .49375 L p .976 .68 .386 r
F P
0 g
s
.78739 .53413 m .77508 .5191 L .77322 .49375 L p .976 .68 .386 r
F P
0 g
s
.81563 .52603 m .78739 .53413 L .77508 .5191 L p .652 .756 .926 r
F P
0 g
s
.81782 .55171 m .81563 .52603 L .78739 .53413 L p .564 .353 .553 r
F P
0 g
s
.78739 .53413 m .78935 .55975 L .81782 .55171 L p .564 .353 .553 r
F P
0 g
s
.74692 .52728 m .77508 .5191 L .78739 .53413 L p .652 .756 .926 r
F P
0 g
s
.74692 .52728 m .77508 .5191 L .78739 .53413 L p .652 .756 .926 r
F P
0 g
s
.77508 .5191 m .78739 .53413 L .78935 .55975 L p .976 .68 .386 r
F P
0 g
s
.81563 .52603 m .78739 .53413 L .77508 .5191 L p .652 .756 .926 r
F P
0 g
s
.77508 .5191 m .78739 .53413 L .78935 .55975 L p .976 .68 .386 r
F P
0 g
s
.66394 .488 m .63643 .49629 L .62276 .48093 L p .654 .754 .923 r
F P
0 g
s
.66498 .5134 m .66394 .488 L .63643 .49629 L p .556 .341 .544 r
F P
0 g
s
.63643 .49629 m .63726 .52163 L .66498 .5134 L p .556 .341 .544 r
F P
0 g
s
.59534 .48928 m .62276 .48093 L .63643 .49629 L p .654 .754 .923 r
F P
0 g
s
.62276 .48093 m .63643 .49629 L .63726 .52163 L p .971 .686 .432 r
F P
0 g
s
.62276 .48093 m .63643 .49629 L .63726 .52163 L p .971 .686 .432 r
F P
0 g
s
.51215 .47509 m .51224 .44998 L .48547 .45846 L p .547 .329 .535 r
F P
0 g
s
.48547 .45846 m .48517 .48351 L .51215 .47509 L p .547 .329 .535 r
F P
0 g
s
.48547 .45846 m .47045 .44275 L .47085 .41796 L p .962 .688 .469 r
F P
0 g
s
.48547 .45846 m .47045 .44275 L .47085 .41796 L p .962 .688 .469 r
F P
0 g
s
.51224 .44998 m .48547 .45846 L .47045 .44275 L p .656 .751 .92 r
F P
0 g
s
.51215 .47509 m .51224 .44998 L .48547 .45846 L p .547 .329 .535 r
F P
0 g
s
.48547 .45846 m .48517 .48351 L .51215 .47509 L p .547 .329 .535 r
F P
0 g
s
.44376 .45129 m .47045 .44275 L .48547 .45846 L p .656 .751 .92 r
F P
0 g
s
.47045 .44275 m .48547 .45846 L .48517 .48351 L p .962 .688 .469 r
F P
0 g
s
.51224 .44998 m .48547 .45846 L .47045 .44275 L p .656 .751 .92 r
F P
0 g
s
.35932 .43678 m .36055 .41196 L .3345 .42062 L p .537 .315 .524 r
F P
0 g
s
.3345 .42062 m .33308 .44539 L .35932 .43678 L p .537 .315 .524 r
F P
0 g
s
.3345 .42062 m .31813 .40457 L .31966 .38007 L p .952 .687 .499 r
F P
0 g
s
.36055 .41196 m .3345 .42062 L .31813 .40457 L p .658 .749 .917 r
F P
0 g
s
.35932 .43678 m .36055 .41196 L .3345 .42062 L p .537 .315 .524 r
F P
0 g
s
.3345 .42062 m .33308 .44539 L .35932 .43678 L p .537 .315 .524 r
F P
0 g
s
.31813 .40457 m .3345 .42062 L .33308 .44539 L p .952 .687 .499 r
F P
0 g
s
.36055 .41196 m .3345 .42062 L .31813 .40457 L p .658 .749 .917 r
F P
0 g
s
.20649 .39848 m .20886 .37394 L .18354 .38278 L p .526 .299 .513 r
F P
0 g
s
.18354 .38278 m .18099 .40726 L .20649 .39848 L p .526 .299 .513 r
F P
0 g
s
.20886 .37394 m .18354 .38278 L .16581 .36639 L p .66 .747 .915 r
F P
0 g
s
.20649 .39848 m .20886 .37394 L .18354 .38278 L p .526 .299 .513 r
F P
0 g
s
.18354 .38278 m .18099 .40726 L .20649 .39848 L p .526 .299 .513 r
F P
0 g
s
.16581 .36639 m .18354 .38278 L .18099 .40726 L p .941 .685 .523 r
F P
0 g
s
.55593 .57136 m .54153 .55667 L .54141 .53102 L p .964 .688 .461 r
F P
0 g
s
.58306 .56344 m .55593 .57136 L .54153 .55667 L p .649 .759 .929 r
F P
0 g
s
.4306 .55108 m .43131 .5254 L .40491 .53351 L p .547 .329 .535 r
F P
0 g
s
.40491 .53351 m .40401 .55913 L .4306 .55108 L p .547 .329 .535 r
F P
0 g
s
.40491 .53351 m .38916 .51847 L .39017 .49312 L p .954 .688 .492 r
F P
0 g
s
.40491 .53351 m .38916 .51847 L .39017 .49312 L p .954 .688 .492 r
F P
0 g
s
.43131 .5254 m .40491 .53351 L .38916 .51847 L p .652 .756 .926 r
F P
0 g
s
.36286 .52665 m .38916 .51847 L .40491 .53351 L p .652 .756 .926 r
F P
0 g
s
.74476 .41263 m .77292 .40389 L .78525 .41995 L p .658 .749 .917 r
F P
0 g
s
.74476 .41263 m .77292 .40389 L .78525 .41995 L p .658 .749 .917 r
F P
0 g
s
.77292 .40389 m .78525 .41995 L .7872 .44473 L p .976 .678 .372 r
F P
0 g
s
.78525 .41995 m .77292 .40389 L .77107 .37939 L p .976 .678 .372 r
F P
0 g
s
.66277 .3978 m .66174 .37325 L .63423 .3821 L p .55 .333 .538 r
F P
0 g
s
.63423 .3821 m .63505 .40659 L .66277 .3978 L p .55 .333 .538 r
F P
0 g
s
.59312 .37462 m .62054 .3657 L .63423 .3821 L p .66 .747 .915 r
F P
0 g
s
.62054 .3657 m .63423 .3821 L .63505 .40659 L p .972 .685 .422 r
F P
0 g
s
.81563 .52603 m .84415 .51784 L .85584 .53289 L p .652 .756 .926 r
F P
0 g
s
.85584 .53289 m .84415 .51784 L .84177 .49248 L p .976 .675 .358 r
F P
0 g
s
.70477 .49502 m .69171 .47963 L .69047 .45456 L p .974 .684 .41 r
F P
0 g
s
.70477 .49502 m .69171 .47963 L .69047 .45456 L p .974 .684 .41 r
F P
0 g
s
.73263 .48672 m .70477 .49502 L .69171 .47963 L p .654 .754 .923 r
F P
0 g
s
.7342 .51213 m .73263 .48672 L .70477 .49502 L p .558 .345 .547 r
F P
0 g
s
.70477 .49502 m .70612 .52037 L .7342 .51213 L p .558 .345 .547 r
F P
0 g
s
.66394 .488 m .69171 .47963 L .70477 .49502 L p .654 .754 .923 r
F P
0 g
s
.69171 .47963 m .70477 .49502 L .70612 .52037 L p .974 .684 .41 r
F P
0 g
s
.73263 .48672 m .70477 .49502 L .69171 .47963 L p .654 .754 .923 r
F P
0 g
s
.58125 .47379 m .58083 .44867 L .5537 .45716 L p .55 .333 .538 r
F P
0 g
s
.5537 .45716 m .55392 .48222 L .58125 .47379 L p .55 .333 .538 r
F P
0 g
s
.5537 .45716 m .53928 .44143 L .53917 .41663 L p .966 .687 .452 r
F P
0 g
s
.5537 .45716 m .53928 .44143 L .53917 .41663 L p .966 .687 .452 r
F P
0 g
s
.58083 .44867 m .5537 .45716 L .53928 .44143 L p .656 .751 .92 r
F P
0 g
s
.58125 .47379 m .58083 .44867 L .5537 .45716 L p .55 .333 .538 r
F P
0 g
s
.5537 .45716 m .55392 .48222 L .58125 .47379 L p .55 .333 .538 r
F P
0 g
s
.51224 .44998 m .53928 .44143 L .5537 .45716 L p .656 .751 .92 r
F P
0 g
s
.51224 .44998 m .53928 .44143 L .5537 .45716 L p .656 .751 .92 r
F P
0 g
s
.53928 .44143 m .5537 .45716 L .55392 .48222 L p .966 .687 .452 r
F P
0 g
s
.58083 .44867 m .5537 .45716 L .53928 .44143 L p .656 .751 .92 r
F P
0 g
s
.53928 .44143 m .5537 .45716 L .55392 .48222 L p .966 .687 .452 r
F P
0 g
s
.4283 .43545 m .42902 .41062 L .40263 .41929 L p .541 .319 .528 r
F P
0 g
s
.40263 .41929 m .40171 .44407 L .4283 .43545 L p .541 .319 .528 r
F P
0 g
s
.40263 .41929 m .38685 .40322 L .38788 .37871 L p .957 .688 .485 r
F P
0 g
s
.42902 .41062 m .40263 .41929 L .38685 .40322 L p .658 .749 .917 r
F P
0 g
s
.36055 .41196 m .38685 .40322 L .40263 .41929 L p .658 .749 .917 r
F P
0 g
s
.38685 .40322 m .40263 .41929 L .40171 .44407 L p .957 .688 .485 r
F P
0 g
s
.20886 .37394 m .23442 .36501 L .25155 .38142 L p .66 .747 .915 r
F P
0 g
s
.23442 .36501 m .25155 .38142 L .24951 .40592 L p .946 .686 .511 r
F P
0 g
s
.62424 .57015 m .61045 .55543 L .60981 .52978 L p .969 .687 .442 r
F P
0 g
s
.65172 .56221 m .62424 .57015 L .61045 .55543 L p .649 .759 .929 r
F P
0 g
s
.47311 .53227 m .45796 .51721 L .45846 .49184 L p .959 .688 .477 r
F P
0 g
s
.47311 .53227 m .45796 .51721 L .45846 .49184 L p .959 .688 .477 r
F P
0 g
s
.49986 .52414 m .47311 .53227 L .45796 .51721 L p .652 .756 .926 r
F P
0 g
s
.49967 .54984 m .49986 .52414 L .47311 .53227 L p .55 .333 .538 r
F P
0 g
s
.47311 .53227 m .47272 .5579 L .49967 .54984 L p .55 .333 .538 r
F P
0 g
s
.43131 .5254 m .45796 .51721 L .47311 .53227 L p .652 .756 .926 r
F P
0 g
s
.43131 .5254 m .45796 .51721 L .47311 .53227 L p .652 .756 .926 r
F P
0 g
s
.45796 .51721 m .47311 .53227 L .47272 .5579 L p .959 .688 .477 r
F P
0 g
s
.49986 .52414 m .47311 .53227 L .45796 .51721 L p .652 .756 .926 r
F P
0 g
s
.45796 .51721 m .47311 .53227 L .47272 .5579 L p .959 .688 .477 r
F P
0 g
s
.34666 .51149 m .34799 .48608 L .32198 .49439 L p .541 .319 .528 r
F P
0 g
s
.32198 .49439 m .32046 .51974 L .34666 .51149 L p .541 .319 .528 r
F P
0 g
s
.32198 .49439 m .30547 .47899 L .3071 .4539 L p .949 .687 .505 r
F P
0 g
s
.34799 .48608 m .32198 .49439 L .30547 .47899 L p .654 .754 .923 r
F P
0 g
s
.34666 .51149 m .34799 .48608 L .32198 .49439 L p .541 .319 .528 r
F P
0 g
s
.32198 .49439 m .32046 .51974 L .34666 .51149 L p .541 .319 .528 r
F P
0 g
s
.30547 .47899 m .32198 .49439 L .32046 .51974 L p .949 .687 .505 r
F P
0 g
s
.34799 .48608 m .32198 .49439 L .30547 .47899 L p .654 .754 .923 r
F P
0 g
s
.88501 .43479 m .88232 .40995 L .85373 .41863 L p .561 .349 .55 r
F P
0 g
s
.85373 .41863 m .85619 .44341 L .88501 .43479 L p .561 .349 .55 r
F P
0 g
s
.85373 .41863 m .84201 .40254 L .83964 .37803 L p .976 .672 .343 r
F P
0 g
s
.88232 .40995 m .85373 .41863 L .84201 .40254 L p .658 .749 .917 r
F P
0 g
s
.66174 .37325 m .68952 .36432 L .7026 .38075 L p .66 .747 .915 r
F P
0 g
s
.68952 .36432 m .7026 .38075 L .70393 .40524 L p .975 .682 .398 r
F P
0 g
s
.80352 .51085 m .80143 .48544 L .77322 .49375 L p .561 .349 .55 r
F P
0 g
s
.77322 .49375 m .77508 .5191 L .80352 .51085 L p .561 .349 .55 r
F P
0 g
s
.77322 .49375 m .76077 .47834 L .75901 .45325 L p .976 .68 .386 r
F P
0 g
s
.80143 .48544 m .77322 .49375 L .76077 .47834 L p .654 .754 .923 r
F P
0 g
s
.80352 .51085 m .80143 .48544 L .77322 .49375 L p .561 .349 .55 r
F P
0 g
s
.77322 .49375 m .77508 .5191 L .80352 .51085 L p .561 .349 .55 r
F P
0 g
s
.73263 .48672 m .76077 .47834 L .77322 .49375 L p .654 .754 .923 r
F P
0 g
s
.76077 .47834 m .77322 .49375 L .77508 .5191 L p .976 .68 .386 r
F P
0 g
s
.62203 .45586 m .60822 .4401 L .6076 .4153 L p .971 .686 .432 r
F P
0 g
s
.62203 .45586 m .60822 .4401 L .6076 .4153 L p .971 .686 .432 r
F P
0 g
s
.64951 .44736 m .62203 .45586 L .60822 .4401 L p .656 .751 .92 r
F P
0 g
s
.65045 .47249 m .64951 .44736 L .62203 .45586 L p .553 .337 .541 r
F P
0 g
s
.62203 .45586 m .62276 .48093 L .65045 .47249 L p .553 .337 .541 r
F P
0 g
s
.58083 .44867 m .60822 .4401 L .62203 .45586 L p .656 .751 .92 r
F P
0 g
s
.58083 .44867 m .60822 .4401 L .62203 .45586 L p .656 .751 .92 r
F P
0 g
s
.60822 .4401 m .62203 .45586 L .62276 .48093 L p .971 .686 .432 r
F P
0 g
s
.64951 .44736 m .62203 .45586 L .60822 .4401 L p .656 .751 .92 r
F P
0 g
s
.60822 .4401 m .62203 .45586 L .62276 .48093 L p .971 .686 .432 r
F P
0 g
s
.49739 .43412 m .4976 .40928 L .47085 .41796 L p .544 .324 .532 r
F P
0 g
s
.47085 .41796 m .47045 .44275 L .49739 .43412 L p .544 .324 .532 r
F P
0 g
s
.47085 .41796 m .45568 .40187 L .45619 .37735 L p .962 .688 .469 r
F P
0 g
s
.4976 .40928 m .47085 .41796 L .45568 .40187 L p .658 .749 .917 r
F P
0 g
s
.49739 .43412 m .4976 .40928 L .47085 .41796 L p .544 .324 .532 r
F P
0 g
s
.47085 .41796 m .47045 .44275 L .49739 .43412 L p .544 .324 .532 r
F P
0 g
s
.42902 .41062 m .45568 .40187 L .47085 .41796 L p .658 .749 .917 r
F P
0 g
s
.45568 .40187 m .47085 .41796 L .47045 .44275 L p .962 .688 .469 r
F P
0 g
s
.4976 .40928 m .47085 .41796 L .45568 .40187 L p .658 .749 .917 r
F P
0 g
s
.45568 .40187 m .47085 .41796 L .47045 .44275 L p .962 .688 .469 r
F P
0 g
s
.34433 .39576 m .34568 .3712 L .31966 .38007 L p .534 .309 .521 r
F P
0 g
s
.31966 .38007 m .31813 .40457 L .34433 .39576 L p .534 .309 .521 r
F P
0 g
s
.34568 .3712 m .31966 .38007 L .30313 .36363 L p .66 .747 .915 r
F P
0 g
s
.34433 .39576 m .34568 .3712 L .31966 .38007 L p .534 .309 .521 r
F P
0 g
s
.31966 .38007 m .31813 .40457 L .34433 .39576 L p .534 .309 .521 r
F P
0 g
s
.30313 .36363 m .31966 .38007 L .31813 .40457 L p .952 .687 .499 r
F P
0 g
s
.69265 .56893 m .67947 .55419 L .67831 .52853 L p .972 .685 .422 r
F P
0 g
s
.69265 .56893 m .67947 .55419 L .67831 .52853 L p .972 .685 .422 r
F P
0 g
s
.72048 .56098 m .69265 .56893 L .67947 .55419 L p .649 .759 .929 r
F P
0 g
s
.65172 .56221 m .67947 .55419 L .69265 .56893 L p .649 .759 .929 r
F P
0 g
s
.56884 .54859 m .56851 .52289 L .54141 .53102 L p .553 .337 .541 r
F P
0 g
s
.54141 .53102 m .54153 .55667 L .56884 .54859 L p .553 .337 .541 r
F P
0 g
s
.54141 .53102 m .52686 .51594 L .52685 .49056 L p .964 .688 .461 r
F P
0 g
s
.54141 .53102 m .52686 .51594 L .52685 .49056 L p .964 .688 .461 r
F P
0 g
s
.56851 .52289 m .54141 .53102 L .52686 .51594 L p .652 .756 .926 r
F P
0 g
s
.49986 .52414 m .52686 .51594 L .54141 .53102 L p .652 .756 .926 r
F P
0 g
s
.49986 .52414 m .52686 .51594 L .54141 .53102 L p .652 .756 .926 r
F P
0 g
s
.52686 .51594 m .54141 .53102 L .54153 .55667 L p .964 .688 .461 r
F P
0 g
s
.41572 .51021 m .41653 .48479 L .39017 .49312 L p .544 .324 .532 r
F P
0 g
s
.39017 .49312 m .38916 .51847 L .41572 .51021 L p .544 .324 .532 r
F P
0 g
s
.39017 .49312 m .37426 .47769 L .37538 .4526 L p .954 .688 .492 r
F P
0 g
s
.41653 .48479 m .39017 .49312 L .37426 .47769 L p .654 .754 .923 r
F P
0 g
s
.41572 .51021 m .41653 .48479 L .39017 .49312 L p .544 .324 .532 r
F P
0 g
s
.39017 .49312 m .38916 .51847 L .41572 .51021 L p .544 .324 .532 r
F P
0 g
s
.34799 .48608 m .37426 .47769 L .39017 .49312 L p .654 .754 .923 r
F P
0 g
s
.37426 .47769 m .39017 .49312 L .38916 .51847 L p .954 .688 .492 r
F P
0 g
s
.41653 .48479 m .39017 .49312 L .37426 .47769 L p .654 .754 .923 r
F P
0 g
s
.37426 .47769 m .39017 .49312 L .38916 .51847 L p .954 .688 .492 r
F P
0 g
s
.88232 .40995 m .9112 .40119 L .92231 .4173 L p .658 .749 .917 r
F P
0 g
s
.92231 .4173 m .9112 .40119 L .90832 .37667 L p .973 .663 .31 r
F P
0 g
s
.73046 .37189 m .75859 .36294 L .77107 .37939 L p .66 .747 .915 r
F P
0 g
s
.75859 .36294 m .77107 .37939 L .77292 .40389 L p .976 .678 .372 r
F P
0 g
s
.80143 .48544 m .82992 .47704 L .84177 .49248 L p .654 .754 .923 r
F P
0 g
s
.80143 .48544 m .82992 .47704 L .84177 .49248 L p .654 .754 .923 r
F P
0 g
s
.82992 .47704 m .84177 .49248 L .84415 .51784 L p .976 .675 .358 r
F P
0 g
s
.84177 .49248 m .82992 .47704 L .82765 .45194 L p .976 .675 .358 r
F P
0 g
s
.71976 .47118 m .7183 .44604 L .69047 .45456 L p .556 .341 .544 r
F P
0 g
s
.69047 .45456 m .69171 .47963 L .71976 .47118 L p .556 .341 .544 r
F P
0 g
s
.7183 .44604 m .69047 .45456 L .67726 .43878 L p .656 .751 .92 r
F P
0 g
s
.71976 .47118 m .7183 .44604 L .69047 .45456 L p .556 .341 .544 r
F P
0 g
s
.69047 .45456 m .69171 .47963 L .71976 .47118 L p .556 .341 .544 r
F P
0 g
s
.64951 .44736 m .67726 .43878 L .69047 .45456 L p .656 .751 .92 r
F P
0 g
s
.67726 .43878 m .69047 .45456 L .69171 .47963 L p .974 .684 .41 r
F P
0 g
s
.67726 .43878 m .69047 .45456 L .69171 .47963 L p .974 .684 .41 r
F P
0 g
s
.56659 .43279 m .56627 .40794 L .53917 .41663 L p .547 .329 .535 r
F P
0 g
s
.53917 .41663 m .53928 .44143 L .56659 .43279 L p .547 .329 .535 r
F P
0 g
s
.53917 .41663 m .5246 .40051 L .5246 .37599 L p .966 .687 .452 r
F P
0 g
s
.53917 .41663 m .5246 .40051 L .5246 .37599 L p .966 .687 .452 r
F P
0 g
s
.56627 .40794 m .53917 .41663 L .5246 .40051 L p .658 .749 .917 r
F P
0 g
s
.56659 .43279 m .56627 .40794 L .53917 .41663 L p .547 .329 .535 r
F P
0 g
s
.53917 .41663 m .53928 .44143 L .56659 .43279 L p .547 .329 .535 r
F P
0 g
s
.4976 .40928 m .5246 .40051 L .53917 .41663 L p .658 .749 .917 r
F P
0 g
s
.4976 .40928 m .5246 .40051 L .53917 .41663 L p .658 .749 .917 r
F P
0 g
s
.5246 .40051 m .53917 .41663 L .53928 .44143 L p .966 .687 .452 r
F P
0 g
s
.56627 .40794 m .53917 .41663 L .5246 .40051 L p .658 .749 .917 r
F P
0 g
s
.5246 .40051 m .53917 .41663 L .53928 .44143 L p .966 .687 .452 r
F P
0 g
s
.41341 .39439 m .41424 .36983 L .38788 .37871 L p .537 .315 .524 r
F P
0 g
s
.38788 .37871 m .38685 .40322 L .41341 .39439 L p .537 .315 .524 r
F P
0 g
s
.41424 .36983 m .38788 .37871 L .37194 .36225 L p .66 .747 .915 r
F P
0 g
s
.41341 .39439 m .41424 .36983 L .38788 .37871 L p .537 .315 .524 r
F P
0 g
s
.38788 .37871 m .38685 .40322 L .41341 .39439 L p .537 .315 .524 r
F P
0 g
s
.37194 .36225 m .38788 .37871 L .38685 .40322 L p .957 .688 .485 r
F P
0 g
s
.76116 .56771 m .74859 .55295 L .74692 .52728 L p .975 .682 .398 r
F P
0 g
s
.78935 .55975 m .76116 .56771 L .74859 .55295 L p .649 .759 .929 r
F P
0 g
s
.63811 .54734 m .63726 .52163 L .60981 .52978 L p .556 .341 .544 r
F P
0 g
s
.60981 .52978 m .61045 .55543 L .63811 .54734 L p .556 .341 .544 r
F P
0 g
s
.60981 .52978 m .59587 .51467 L .59534 .48928 L p .969 .687 .442 r
F P
0 g
s
.60981 .52978 m .59587 .51467 L .59534 .48928 L p .969 .687 .442 r
F P
0 g
s
.63726 .52163 m .60981 .52978 L .59587 .51467 L p .652 .756 .926 r
F P
0 g
s
.63811 .54734 m .63726 .52163 L .60981 .52978 L p .556 .341 .544 r
F P
0 g
s
.60981 .52978 m .61045 .55543 L .63811 .54734 L p .556 .341 .544 r
F P
0 g
s
.56851 .52289 m .59587 .51467 L .60981 .52978 L p .652 .756 .926 r
F P
0 g
s
.56851 .52289 m .59587 .51467 L .60981 .52978 L p .652 .756 .926 r
F P
0 g
s
.59587 .51467 m .60981 .52978 L .61045 .55543 L p .969 .687 .442 r
F P
0 g
s
.63726 .52163 m .60981 .52978 L .59587 .51467 L p .652 .756 .926 r
F P
0 g
s
.59587 .51467 m .60981 .52978 L .61045 .55543 L p .969 .687 .442 r
F P
0 g
s
.48488 .50894 m .48517 .48351 L .45846 .49184 L p .547 .329 .535 r
F P
0 g
s
.45846 .49184 m .45796 .51721 L .48488 .50894 L p .547 .329 .535 r
F P
0 g
s
.48517 .48351 m .45846 .49184 L .44315 .47639 L p .654 .754 .923 r
F P
0 g
s
.48488 .50894 m .48517 .48351 L .45846 .49184 L p .547 .329 .535 r
F P
0 g
s
.45846 .49184 m .45796 .51721 L .48488 .50894 L p .547 .329 .535 r
F P
0 g
s
.44315 .47639 m .45846 .49184 L .45796 .51721 L p .959 .688 .477 r
F P
0 g
s
.33164 .47053 m .33308 .44539 L .3071 .4539 L p .537 .315 .524 r
F P
0 g
s
.3071 .4539 m .30547 .47899 L .33164 .47053 L p .537 .315 .524 r
F P
0 g
s
.33308 .44539 m .3071 .4539 L .29044 .43811 L p .656 .751 .92 r
F P
0 g
s
.33164 .47053 m .33308 .44539 L .3071 .4539 L p .537 .315 .524 r
F P
0 g
s
.3071 .4539 m .30547 .47899 L .33164 .47053 L p .537 .315 .524 r
F P
0 g
s
.29044 .43811 m .3071 .4539 L .30547 .47899 L p .949 .687 .505 r
F P
0 g
s
.8708 .39371 m .86821 .36914 L .83964 .37803 L p .558 .345 .547 r
F P
0 g
s
.83964 .37803 m .84201 .40254 L .8708 .39371 L p .558 .345 .547 r
F P
0 g
s
.75901 .45325 m .74641 .43745 L .74476 .41263 L p .976 .68 .386 r
F P
0 g
s
.75901 .45325 m .74641 .43745 L .74476 .41263 L p .976 .68 .386 r
F P
0 g
s
.7872 .44473 m .75901 .45325 L .74641 .43745 L p .656 .751 .92 r
F P
0 g
s
.7183 .44604 m .74641 .43745 L .75901 .45325 L p .656 .751 .92 r
F P
0 g
s
.7183 .44604 m .74641 .43745 L .75901 .45325 L p .656 .751 .92 r
F P
0 g
s
.74641 .43745 m .75901 .45325 L .76077 .47834 L p .976 .68 .386 r
F P
0 g
s
.63588 .43145 m .63505 .40659 L .6076 .4153 L p .55 .333 .538 r
F P
0 g
s
.6076 .4153 m .60822 .4401 L .63588 .43145 L p .55 .333 .538 r
F P
0 g
s
.6076 .4153 m .59364 .39916 L .59312 .37462 L p .971 .686 .432 r
F P
0 g
s
.6076 .4153 m .59364 .39916 L .59312 .37462 L p .971 .686 .432 r
F P
0 g
s
.63505 .40659 m .6076 .4153 L .59364 .39916 L p .658 .749 .917 r
F P
0 g
s
.63588 .43145 m .63505 .40659 L .6076 .4153 L p .55 .333 .538 r
F P
0 g
s
.6076 .4153 m .60822 .4401 L .63588 .43145 L p .55 .333 .538 r
F P
0 g
s
.56627 .40794 m .59364 .39916 L .6076 .4153 L p .658 .749 .917 r
F P
0 g
s
.56627 .40794 m .59364 .39916 L .6076 .4153 L p .658 .749 .917 r
F P
0 g
s
.59364 .39916 m .6076 .4153 L .60822 .4401 L p .971 .686 .432 r
F P
0 g
s
.63505 .40659 m .6076 .4153 L .59364 .39916 L p .658 .749 .917 r
F P
0 g
s
.59364 .39916 m .6076 .4153 L .60822 .4401 L p .971 .686 .432 r
F P
0 g
s
.48259 .39303 m .4829 .36846 L .45619 .37735 L p .541 .319 .528 r
F P
0 g
s
.45619 .37735 m .45568 .40187 L .48259 .39303 L p .541 .319 .528 r
F P
0 g
s
.41424 .36983 m .44086 .36086 L .45619 .37735 L p .66 .747 .915 r
F P
0 g
s
.44086 .36086 m .45619 .37735 L .45568 .40187 L p .962 .688 .469 r
F P
0 g
s
.70749 .54609 m .70612 .52037 L .67831 .52853 L p .558 .345 .547 r
F P
0 g
s
.67831 .52853 m .67947 .55419 L .70749 .54609 L p .558 .345 .547 r
F P
0 g
s
.70612 .52037 m .67831 .52853 L .66498 .5134 L p .652 .756 .926 r
F P
0 g
s
.70749 .54609 m .70612 .52037 L .67831 .52853 L p .558 .345 .547 r
F P
0 g
s
.67831 .52853 m .67947 .55419 L .70749 .54609 L p .558 .345 .547 r
F P
0 g
s
.66498 .5134 m .67831 .52853 L .67947 .55419 L p .972 .685 .422 r
F P
0 g
s
.55414 .50766 m .55392 .48222 L .52685 .49056 L p .55 .333 .538 r
F P
0 g
s
.52685 .49056 m .52686 .51594 L .55414 .50766 L p .55 .333 .538 r
F P
0 g
s
.52685 .49056 m .51215 .47509 L .51224 .44998 L p .964 .688 .461 r
F P
0 g
s
.52685 .49056 m .51215 .47509 L .51224 .44998 L p .964 .688 .461 r
F P
0 g
s
.55392 .48222 m .52685 .49056 L .51215 .47509 L p .654 .754 .923 r
F P
0 g
s
.55414 .50766 m .55392 .48222 L .52685 .49056 L p .55 .333 .538 r
F P
0 g
s
.52685 .49056 m .52686 .51594 L .55414 .50766 L p .55 .333 .538 r
F P
0 g
s
.48517 .48351 m .51215 .47509 L .52685 .49056 L p .654 .754 .923 r
F P
0 g
s
.48517 .48351 m .51215 .47509 L .52685 .49056 L p .654 .754 .923 r
F P
0 g
s
.51215 .47509 m .52685 .49056 L .52686 .51594 L p .964 .688 .461 r
F P
0 g
s
.55392 .48222 m .52685 .49056 L .51215 .47509 L p .654 .754 .923 r
F P
0 g
s
.51215 .47509 m .52685 .49056 L .52686 .51594 L p .964 .688 .461 r
F P
0 g
s
.40079 .46922 m .40171 .44407 L .37538 .4526 L p .541 .319 .528 r
F P
0 g
s
.37538 .4526 m .37426 .47769 L .40079 .46922 L p .541 .319 .528 r
F P
0 g
s
.37538 .4526 m .35932 .43678 L .36055 .41196 L p .954 .688 .492 r
F P
0 g
s
.37538 .4526 m .35932 .43678 L .36055 .41196 L p .954 .688 .492 r
F P
0 g
s
.40171 .44407 m .37538 .4526 L .35932 .43678 L p .656 .751 .92 r
F P
0 g
s
.40079 .46922 m .40171 .44407 L .37538 .4526 L p .541 .319 .528 r
F P
0 g
s
.37538 .4526 m .37426 .47769 L .40079 .46922 L p .541 .319 .528 r
F P
0 g
s
.33308 .44539 m .35932 .43678 L .37538 .4526 L p .656 .751 .92 r
F P
0 g
s
.35932 .43678 m .37538 .4526 L .37426 .47769 L p .954 .688 .492 r
F P
0 g
s
.40171 .44407 m .37538 .4526 L .35932 .43678 L p .656 .751 .92 r
F P
0 g
s
.22391 .41463 m .20649 .39848 L .20886 .37394 L p .943 .686 .517 r
F P
0 g
s
.22391 .41463 m .20649 .39848 L .20886 .37394 L p .943 .686 .517 r
F P
0 g
s
.24951 .40592 m .22391 .41463 L .20649 .39848 L p .658 .749 .917 r
F P
0 g
s
.18099 .40726 m .20649 .39848 L .22391 .41463 L p .658 .749 .917 r
F P
0 g
s
.86821 .36914 m .89706 .36017 L .90832 .37667 L p .66 .747 .915 r
F P
0 g
s
.89706 .36017 m .90832 .37667 L .9112 .40119 L p .973 .663 .31 r
F P
0 g
s
.44604 .56588 m .4306 .55108 L .43131 .5254 L p .957 .688 .485 r
F P
0 g
s
.44604 .56588 m .4306 .55108 L .43131 .5254 L p .957 .688 .485 r
F P
0 g
s
.47272 .5579 m .44604 .56588 L .4306 .55108 L p .649 .759 .929 r
F P
0 g
s
.40401 .55913 m .4306 .55108 L .44604 .56588 L p .649 .759 .929 r
F P
0 g
s
.7872 .44473 m .81566 .43612 L .82765 .45194 L p .656 .751 .92 r
F P
0 g
s
.81566 .43612 m .82765 .45194 L .82992 .47704 L p .976 .675 .358 r
F P
0 g
s
.67613 .41397 m .66277 .3978 L .66174 .37325 L p .974 .684 .41 r
F P
0 g
s
.67613 .41397 m .66277 .3978 L .66174 .37325 L p .974 .684 .41 r
F P
0 g
s
.70393 .40524 m .67613 .41397 L .66277 .3978 L p .658 .749 .917 r
F P
0 g
s
.63505 .40659 m .66277 .3978 L .67613 .41397 L p .658 .749 .917 r
F P
0 g
s
.63505 .40659 m .66277 .3978 L .67613 .41397 L p .658 .749 .917 r
F P
0 g
s
.66277 .3978 m .67613 .41397 L .67726 .43878 L p .974 .684 .41 r
F P
0 g
s
.55188 .39166 m .55167 .36708 L .5246 .37599 L p .544 .324 .532 r
F P
0 g
s
.5246 .37599 m .5246 .40051 L .55188 .39166 L p .544 .324 .532 r
F P
0 g
s
.55167 .36708 m .5246 .37599 L .50988 .35948 L p .66 .747 .915 r
F P
0 g
s
.55188 .39166 m .55167 .36708 L .5246 .37599 L p .544 .324 .532 r
F P
0 g
s
.5246 .37599 m .5246 .40051 L .55188 .39166 L p .544 .324 .532 r
F P
0 g
s
.4829 .36846 m .50988 .35948 L .5246 .37599 L p .66 .747 .915 r
F P
0 g
s
.50988 .35948 m .5246 .37599 L .5246 .40051 L p .966 .687 .452 r
F P
0 g
s
.50988 .35948 m .5246 .37599 L .5246 .40051 L p .966 .687 .452 r
F P
0 g
s
.77697 .54484 m .77508 .5191 L .74692 .52728 L p .561 .349 .55 r
F P
0 g
s
.74692 .52728 m .74859 .55295 L .77697 .54484 L p .561 .349 .55 r
F P
0 g
s
.77508 .5191 m .74692 .52728 L .7342 .51213 L p .652 .756 .926 r
F P
0 g
s
.77697 .54484 m .77508 .5191 L .74692 .52728 L p .561 .349 .55 r
F P
0 g
s
.74692 .52728 m .74859 .55295 L .77697 .54484 L p .561 .349 .55 r
F P
0 g
s
.70612 .52037 m .7342 .51213 L .74692 .52728 L p .652 .756 .926 r
F P
0 g
s
.7342 .51213 m .74692 .52728 L .74859 .55295 L p .975 .682 .398 r
F P
0 g
s
.7342 .51213 m .74692 .52728 L .74859 .55295 L p .975 .682 .398 r
F P
0 g
s
.6235 .50637 m .62276 .48093 L .59534 .48928 L p .553 .337 .541 r
F P
0 g
s
.59534 .48928 m .59587 .51467 L .6235 .50637 L p .553 .337 .541 r
F P
0 g
s
.59534 .48928 m .58125 .47379 L .58083 .44867 L p .969 .687 .442 r
F P
0 g
s
.59534 .48928 m .58125 .47379 L .58083 .44867 L p .969 .687 .442 r
F P
0 g
s
.62276 .48093 m .59534 .48928 L .58125 .47379 L p .654 .754 .923 r
F P
0 g
s
.6235 .50637 m .62276 .48093 L .59534 .48928 L p .553 .337 .541 r
F P
0 g
s
.59534 .48928 m .59587 .51467 L .6235 .50637 L p .553 .337 .541 r
F P
0 g
s
.55392 .48222 m .58125 .47379 L .59534 .48928 L p .654 .754 .923 r
F P
0 g
s
.55392 .48222 m .58125 .47379 L .59534 .48928 L p .654 .754 .923 r
F P
0 g
s
.58125 .47379 m .59534 .48928 L .59587 .51467 L p .969 .687 .442 r
F P
0 g
s
.62276 .48093 m .59534 .48928 L .58125 .47379 L p .654 .754 .923 r
F P
0 g
s
.58125 .47379 m .59534 .48928 L .59587 .51467 L p .969 .687 .442 r
F P
0 g
s
.44376 .45129 m .4283 .43545 L .42902 .41062 L p .959 .688 .477 r
F P
0 g
s
.44376 .45129 m .4283 .43545 L .42902 .41062 L p .959 .688 .477 r
F P
0 g
s
.47045 .44275 m .44376 .45129 L .4283 .43545 L p .656 .751 .92 r
F P
0 g
s
.40171 .44407 m .4283 .43545 L .44376 .45129 L p .656 .751 .92 r
F P
0 g
s
.40171 .44407 m .4283 .43545 L .44376 .45129 L p .656 .751 .92 r
F P
0 g
s
.4283 .43545 m .44376 .45129 L .44315 .47639 L p .959 .688 .477 r
F P
0 g
s
.51449 .56466 m .49967 .54984 L .49986 .52414 L p .962 .688 .469 r
F P
0 g
s
.54153 .55667 m .51449 .56466 L .49967 .54984 L p .649 .759 .929 r
F P
0 g
s
.36286 .52665 m .34666 .51149 L .34799 .48608 L p .952 .687 .499 r
F P
0 g
s
.36286 .52665 m .34666 .51149 L .34799 .48608 L p .952 .687 .499 r
F P
0 g
s
.38916 .51847 m .36286 .52665 L .34666 .51149 L p .652 .756 .926 r
F P
0 g
s
.38814 .54421 m .38916 .51847 L .36286 .52665 L p .544 .324 .532 r
F P
0 g
s
.36286 .52665 m .36164 .55233 L .38814 .54421 L p .544 .324 .532 r
F P
0 g
s
.32046 .51974 m .34666 .51149 L .36286 .52665 L p .652 .756 .926 r
F P
0 g
s
.34666 .51149 m .36286 .52665 L .36164 .55233 L p .952 .687 .499 r
F P
0 g
s
.38916 .51847 m .36286 .52665 L .34666 .51149 L p .652 .756 .926 r
F P
0 g
s
.85619 .44341 m .88501 .43479 L .89639 .45064 L p .656 .751 .92 r
F P
0 g
s
.89639 .45064 m .88501 .43479 L .88232 .40995 L p .975 .668 .327 r
F P
0 g
s
.77479 .42877 m .77292 .40389 L .74476 .41263 L p .556 .341 .544 r
F P
0 g
s
.74476 .41263 m .74641 .43745 L .77479 .42877 L p .556 .341 .544 r
F P
0 g
s
.74476 .41263 m .73201 .39644 L .73046 .37189 L p .976 .68 .386 r
F P
0 g
s
.77292 .40389 m .74476 .41263 L .73201 .39644 L p .658 .749 .917 r
F P
0 g
s
.77479 .42877 m .77292 .40389 L .74476 .41263 L p .556 .341 .544 r
F P
0 g
s
.74476 .41263 m .74641 .43745 L .77479 .42877 L p .556 .341 .544 r
F P
0 g
s
.70393 .40524 m .73201 .39644 L .74476 .41263 L p .658 .749 .917 r
F P
0 g
s
.73201 .39644 m .74476 .41263 L .74641 .43745 L p .976 .68 .386 r
F P
0 g
s
.77292 .40389 m .74476 .41263 L .73201 .39644 L p .658 .749 .917 r
F P
0 g
s
.73201 .39644 m .74476 .41263 L .74641 .43745 L p .976 .68 .386 r
F P
0 g
s
.62127 .39029 m .62054 .3657 L .59312 .37462 L p .547 .329 .535 r
F P
0 g
s
.59312 .37462 m .59364 .39916 L .62127 .39029 L p .547 .329 .535 r
F P
0 g
s
.62054 .3657 m .59312 .37462 L .57901 .35809 L p .66 .747 .915 r
F P
0 g
s
.62127 .39029 m .62054 .3657 L .59312 .37462 L p .547 .329 .535 r
F P
0 g
s
.59312 .37462 m .59364 .39916 L .62127 .39029 L p .547 .329 .535 r
F P
0 g
s
.55167 .36708 m .57901 .35809 L .59312 .37462 L p .66 .747 .915 r
F P
0 g
s
.57901 .35809 m .59312 .37462 L .59364 .39916 L p .971 .686 .432 r
F P
0 g
s
.57901 .35809 m .59312 .37462 L .59364 .39916 L p .971 .686 .432 r
F P
0 g
s
.81563 .52603 m .80352 .51085 L .80143 .48544 L p .976 .678 .372 r
F P
0 g
s
.81563 .52603 m .80352 .51085 L .80143 .48544 L p .976 .678 .372 r
F P
0 g
s
.84415 .51784 m .81563 .52603 L .80352 .51085 L p .652 .756 .926 r
F P
0 g
s
.77508 .5191 m .80352 .51085 L .81563 .52603 L p .652 .756 .926 r
F P
0 g
s
.77508 .5191 m .80352 .51085 L .81563 .52603 L p .652 .756 .926 r
F P
0 g
s
.80352 .51085 m .81563 .52603 L .81782 .55171 L p .976 .678 .372 r
F P
0 g
s
.66394 .488 m .65045 .47249 L .64951 .44736 L p .972 .685 .422 r
F P
0 g
s
.69171 .47963 m .66394 .488 L .65045 .47249 L p .654 .754 .923 r
F P
0 g
s
.69298 .50509 m .69171 .47963 L .66394 .488 L p .556 .341 .544 r
F P
0 g
s
.66394 .488 m .66498 .5134 L .69298 .50509 L p .556 .341 .544 r
F P
0 g
s
.62276 .48093 m .65045 .47249 L .66394 .488 L p .654 .754 .923 r
F P
0 g
s
.65045 .47249 m .66394 .488 L .66498 .5134 L p .972 .685 .422 r
F P
0 g
s
.69171 .47963 m .66394 .488 L .65045 .47249 L p .654 .754 .923 r
F P
0 g
s
.65045 .47249 m .66394 .488 L .66498 .5134 L p .972 .685 .422 r
F P
0 g
s
.53939 .46659 m .53928 .44143 L .51224 .44998 L p .547 .329 .535 r
F P
0 g
s
.51224 .44998 m .51215 .47509 L .53939 .46659 L p .547 .329 .535 r
F P
0 g
s
.51224 .44998 m .49739 .43412 L .4976 .40928 L p .964 .688 .461 r
F P
0 g
s
.51224 .44998 m .49739 .43412 L .4976 .40928 L p .964 .688 .461 r
F P
0 g
s
.53928 .44143 m .51224 .44998 L .49739 .43412 L p .656 .751 .92 r
F P
0 g
s
.53939 .46659 m .53928 .44143 L .51224 .44998 L p .547 .329 .535 r
F P
0 g
s
.51224 .44998 m .51215 .47509 L .53939 .46659 L p .547 .329 .535 r
F P
0 g
s
.47045 .44275 m .49739 .43412 L .51224 .44998 L p .656 .751 .92 r
F P
0 g
s
.47045 .44275 m .49739 .43412 L .51224 .44998 L p .656 .751 .92 r
F P
0 g
s
.49739 .43412 m .51224 .44998 L .51215 .47509 L p .964 .688 .461 r
F P
0 g
s
.53928 .44143 m .51224 .44998 L .49739 .43412 L p .656 .751 .92 r
F P
0 g
s
.49739 .43412 m .51224 .44998 L .51215 .47509 L p .964 .688 .461 r
F P
0 g
s
.38581 .4281 m .38685 .40322 L .36055 .41196 L p .537 .315 .524 r
F P
0 g
s
.36055 .41196 m .35932 .43678 L .38581 .4281 L p .537 .315 .524 r
F P
0 g
s
.36055 .41196 m .34433 .39576 L .34568 .3712 L p .954 .688 .492 r
F P
0 g
s
.38685 .40322 m .36055 .41196 L .34433 .39576 L p .658 .749 .917 r
F P
0 g
s
.38581 .4281 m .38685 .40322 L .36055 .41196 L p .537 .315 .524 r
F P
0 g
s
.36055 .41196 m .35932 .43678 L .38581 .4281 L p .537 .315 .524 r
F P
0 g
s
.31813 .40457 m .34433 .39576 L .36055 .41196 L p .658 .749 .917 r
F P
0 g
s
.31813 .40457 m .34433 .39576 L .36055 .41196 L p .658 .749 .917 r
F P
0 g
s
.34433 .39576 m .36055 .41196 L .35932 .43678 L p .954 .688 .492 r
F P
0 g
s
.34433 .39576 m .36055 .41196 L .35932 .43678 L p .954 .688 .492 r
F P
0 g
s
.23223 .3896 m .23442 .36501 L .20886 .37394 L p .526 .299 .513 r
F P
0 g
s
.20886 .37394 m .20649 .39848 L .23223 .3896 L p .526 .299 .513 r
F P
0 g
s
.23442 .36501 m .20886 .37394 L .19127 .35739 L p .66 .747 .915 r
F P
0 g
s
.23223 .3896 m .23442 .36501 L .20886 .37394 L p .526 .299 .513 r
F P
0 g
s
.20886 .37394 m .20649 .39848 L .23223 .3896 L p .526 .299 .513 r
F P
0 g
s
.16581 .36639 m .19127 .35739 L .20886 .37394 L p .66 .747 .915 r
F P
0 g
s
.19127 .35739 m .20886 .37394 L .20649 .39848 L p .943 .686 .517 r
F P
0 g
s
.19127 .35739 m .20886 .37394 L .20649 .39848 L p .943 .686 .517 r
F P
0 g
s
.58306 .56344 m .56884 .54859 L .56851 .52289 L p .966 .687 .452 r
F P
0 g
s
.58306 .56344 m .56884 .54859 L .56851 .52289 L p .966 .687 .452 r
F P
0 g
s
.61045 .55543 m .58306 .56344 L .56884 .54859 L p .649 .759 .929 r
F P
0 g
s
.54153 .55667 m .56884 .54859 L .58306 .56344 L p .649 .759 .929 r
F P
0 g
s
.45746 .54296 m .45796 .51721 L .43131 .5254 L p .547 .329 .535 r
F P
0 g
s
.43131 .5254 m .4306 .55108 L .45746 .54296 L p .547 .329 .535 r
F P
0 g
s
.38916 .51847 m .41572 .51021 L .43131 .5254 L p .652 .756 .926 r
F P
0 g
s
.43131 .5254 m .41572 .51021 L .41653 .48479 L p .957 .688 .485 r
F P
0 g
s
.69076 .38892 m .68952 .36432 L .66174 .37325 L p .55 .333 .538 r
F P
0 g
s
.66174 .37325 m .66277 .3978 L .69076 .38892 L p .55 .333 .538 r
F P
0 g
s
.73263 .48672 m .71976 .47118 L .7183 .44604 L p .975 .682 .398 r
F P
0 g
s
.73263 .48672 m .71976 .47118 L .7183 .44604 L p .975 .682 .398 r
F P
0 g
s
.76077 .47834 m .73263 .48672 L .71976 .47118 L p .654 .754 .923 r
F P
0 g
s
.69171 .47963 m .71976 .47118 L .73263 .48672 L p .654 .754 .923 r
F P
0 g
s
.69171 .47963 m .71976 .47118 L .73263 .48672 L p .654 .754 .923 r
F P
0 g
s
.71976 .47118 m .73263 .48672 L .7342 .51213 L p .975 .682 .398 r
F P
0 g
s
.60885 .46528 m .60822 .4401 L .58083 .44867 L p .55 .333 .538 r
F P
0 g
s
.58083 .44867 m .58125 .47379 L .60885 .46528 L p .55 .333 .538 r
F P
0 g
s
.58083 .44867 m .56659 .43279 L .56627 .40794 L p .969 .687 .442 r
F P
0 g
s
.58083 .44867 m .56659 .43279 L .56627 .40794 L p .969 .687 .442 r
F P
0 g
s
.60822 .4401 m .58083 .44867 L .56659 .43279 L p .656 .751 .92 r
F P
0 g
s
.60885 .46528 m .60822 .4401 L .58083 .44867 L p .55 .333 .538 r
F P
0 g
s
.58083 .44867 m .58125 .47379 L .60885 .46528 L p .55 .333 .538 r
F P
0 g
s
.53928 .44143 m .56659 .43279 L .58083 .44867 L p .656 .751 .92 r
F P
0 g
s
.53928 .44143 m .56659 .43279 L .58083 .44867 L p .656 .751 .92 r
F P
0 g
s
.56659 .43279 m .58083 .44867 L .58125 .47379 L p .969 .687 .442 r
F P
0 g
s
.60822 .4401 m .58083 .44867 L .56659 .43279 L p .656 .751 .92 r
F P
0 g
s
.56659 .43279 m .58083 .44867 L .58125 .47379 L p .969 .687 .442 r
F P
0 g
s
.45515 .42675 m .45568 .40187 L .42902 .41062 L p .541 .319 .528 r
F P
0 g
s
.42902 .41062 m .4283 .43545 L .45515 .42675 L p .541 .319 .528 r
F P
0 g
s
.42902 .41062 m .41341 .39439 L .41424 .36983 L p .959 .688 .477 r
F P
0 g
s
.42902 .41062 m .41341 .39439 L .41424 .36983 L p .959 .688 .477 r
F P
0 g
s
.45568 .40187 m .42902 .41062 L .41341 .39439 L p .658 .749 .917 r
F P
0 g
s
.45515 .42675 m .45568 .40187 L .42902 .41062 L p .541 .319 .528 r
F P
0 g
s
.42902 .41062 m .4283 .43545 L .45515 .42675 L p .541 .319 .528 r
F P
0 g
s
.38685 .40322 m .41341 .39439 L .42902 .41062 L p .658 .749 .917 r
F P
0 g
s
.41341 .39439 m .42902 .41062 L .4283 .43545 L p .959 .688 .477 r
F P
0 g
s
.45568 .40187 m .42902 .41062 L .41341 .39439 L p .658 .749 .917 r
F P
0 g
s
.30313 .36363 m .27722 .37257 L .26023 .356 L p .66 .747 .915 r
F P
0 g
s
.30146 .38823 m .30313 .36363 L .27722 .37257 L p .53 .304 .517 r
F P
0 g
s
.27722 .37257 m .27536 .39712 L .30146 .38823 L p .53 .304 .517 r
F P
0 g
s
.26023 .356 m .27722 .37257 L .27536 .39712 L p .949 .687 .505 r
F P
0 g
s
.61045 .55543 m .63811 .54734 L .65172 .56221 L p .649 .759 .929 r
F P
0 g
s
.65172 .56221 m .63811 .54734 L .63726 .52163 L p .971 .686 .432 r
F P
0 g
s
.52688 .5417 m .52686 .51594 L .49986 .52414 L p .55 .333 .538 r
F P
0 g
s
.49986 .52414 m .49967 .54984 L .52688 .5417 L p .55 .333 .538 r
F P
0 g
s
.49986 .52414 m .48488 .50894 L .48517 .48351 L p .962 .688 .469 r
F P
0 g
s
.49986 .52414 m .48488 .50894 L .48517 .48351 L p .962 .688 .469 r
F P
0 g
s
.52686 .51594 m .49986 .52414 L .48488 .50894 L p .652 .756 .926 r
F P
0 g
s
.45796 .51721 m .48488 .50894 L .49986 .52414 L p .652 .756 .926 r
F P
0 g
s
.45796 .51721 m .48488 .50894 L .49986 .52414 L p .652 .756 .926 r
F P
0 g
s
.48488 .50894 m .49986 .52414 L .49967 .54984 L p .962 .688 .469 r
F P
0 g
s
.37312 .50316 m .37426 .47769 L .34799 .48608 L p .541 .319 .528 r
F P
0 g
s
.34799 .48608 m .34666 .51149 L .37312 .50316 L p .541 .319 .528 r
F P
0 g
s
.34799 .48608 m .33164 .47053 L .33308 .44539 L p .952 .687 .499 r
F P
0 g
s
.37426 .47769 m .34799 .48608 L .33164 .47053 L p .654 .754 .923 r
F P
0 g
s
.37312 .50316 m .37426 .47769 L .34799 .48608 L p .541 .319 .528 r
F P
0 g
s
.34799 .48608 m .34666 .51149 L .37312 .50316 L p .541 .319 .528 r
F P
0 g
s
.30547 .47899 m .33164 .47053 L .34799 .48608 L p .654 .754 .923 r
F P
0 g
s
.30547 .47899 m .33164 .47053 L .34799 .48608 L p .654 .754 .923 r
F P
0 g
s
.33164 .47053 m .34799 .48608 L .34666 .51149 L p .952 .687 .499 r
F P
0 g
s
.33164 .47053 m .34799 .48608 L .34666 .51149 L p .952 .687 .499 r
F P
0 g
s
.88232 .40995 m .8708 .39371 L .86821 .36914 L p .975 .668 .327 r
F P
0 g
s
.88232 .40995 m .8708 .39371 L .86821 .36914 L p .975 .668 .327 r
F P
0 g
s
.9112 .40119 m .88232 .40995 L .8708 .39371 L p .658 .749 .917 r
F P
0 g
s
.84201 .40254 m .8708 .39371 L .88232 .40995 L p .658 .749 .917 r
F P
0 g
s
.76036 .38754 m .75859 .36294 L .73046 .37189 L p .553 .337 .541 r
F P
0 g
s
.73046 .37189 m .73201 .39644 L .76036 .38754 L p .553 .337 .541 r
F P
0 g
s
.83223 .50252 m .82992 .47704 L .80143 .48544 L p .561 .349 .55 r
F P
0 g
s
.80143 .48544 m .80352 .51085 L .83223 .50252 L p .561 .349 .55 r
F P
0 g
s
.80143 .48544 m .78918 .46987 L .7872 .44473 L p .976 .678 .372 r
F P
0 g
s
.82992 .47704 m .80143 .48544 L .78918 .46987 L p .654 .754 .923 r
F P
0 g
s
.83223 .50252 m .82992 .47704 L .80143 .48544 L p .561 .349 .55 r
F P
0 g
s
.80143 .48544 m .80352 .51085 L .83223 .50252 L p .561 .349 .55 r
F P
0 g
s
.76077 .47834 m .78918 .46987 L .80143 .48544 L p .654 .754 .923 r
F P
0 g
s
.78918 .46987 m .80143 .48544 L .80352 .51085 L p .976 .678 .372 r
F P
0 g
s
.82992 .47704 m .80143 .48544 L .78918 .46987 L p .654 .754 .923 r
F P
0 g
s
.78918 .46987 m .80143 .48544 L .80352 .51085 L p .976 .678 .372 r
F P
0 g
s
.67842 .46396 m .67726 .43878 L .64951 .44736 L p .553 .337 .541 r
F P
0 g
s
.64951 .44736 m .65045 .47249 L .67842 .46396 L p .553 .337 .541 r
F P
0 g
s
.64951 .44736 m .63588 .43145 L .63505 .40659 L p .972 .685 .422 r
F P
0 g
s
.64951 .44736 m .63588 .43145 L .63505 .40659 L p .972 .685 .422 r
F P
0 g
s
.67726 .43878 m .64951 .44736 L .63588 .43145 L p .656 .751 .92 r
F P
0 g
s
.60822 .4401 m .63588 .43145 L .64951 .44736 L p .656 .751 .92 r
F P
0 g
s
.60822 .4401 m .63588 .43145 L .64951 .44736 L p .656 .751 .92 r
F P
0 g
s
.63588 .43145 m .64951 .44736 L .65045 .47249 L p .972 .685 .422 r
F P
0 g
s
.5246 .42541 m .5246 .40051 L .4976 .40928 L p .544 .324 .532 r
F P
0 g
s
.4976 .40928 m .49739 .43412 L .5246 .42541 L p .544 .324 .532 r
F P
0 g
s
.4976 .40928 m .48259 .39303 L .4829 .36846 L p .964 .688 .461 r
F P
0 g
s
.4976 .40928 m .48259 .39303 L .4829 .36846 L p .964 .688 .461 r
F P
0 g
s
.5246 .40051 m .4976 .40928 L .48259 .39303 L p .658 .749 .917 r
F P
0 g
s
.5246 .42541 m .5246 .40051 L .4976 .40928 L p .544 .324 .532 r
F P
0 g
s
.4976 .40928 m .49739 .43412 L .5246 .42541 L p .544 .324 .532 r
F P
0 g
s
.45568 .40187 m .48259 .39303 L .4976 .40928 L p .658 .749 .917 r
F P
0 g
s
.45568 .40187 m .48259 .39303 L .4976 .40928 L p .658 .749 .917 r
F P
0 g
s
.48259 .39303 m .4976 .40928 L .49739 .43412 L p .964 .688 .461 r
F P
0 g
s
.5246 .40051 m .4976 .40928 L .48259 .39303 L p .658 .749 .917 r
F P
0 g
s
.48259 .39303 m .4976 .40928 L .49739 .43412 L p .964 .688 .461 r
F P
0 g
s
.30313 .36363 m .3293 .3546 L .34568 .3712 L p .66 .747 .915 r
F P
0 g
s
.3293 .3546 m .34568 .3712 L .34433 .39576 L p .954 .688 .492 r
F P
0 g
s
.72048 .56098 m .70749 .54609 L .70612 .52037 L p .974 .684 .41 r
F P
0 g
s
.72048 .56098 m .70749 .54609 L .70612 .52037 L p .974 .684 .41 r
F P
0 g
s
.74859 .55295 m .72048 .56098 L .70749 .54609 L p .649 .759 .929 r
F P
0 g
s
.67947 .55419 m .70749 .54609 L .72048 .56098 L p .649 .759 .929 r
F P
0 g
s
.59641 .54044 m .59587 .51467 L .56851 .52289 L p .553 .337 .541 r
F P
0 g
s
.56851 .52289 m .56884 .54859 L .59641 .54044 L p .553 .337 .541 r
F P
0 g
s
.56851 .52289 m .55414 .50766 L .55392 .48222 L p .966 .687 .452 r
F P
0 g
s
.56851 .52289 m .55414 .50766 L .55392 .48222 L p .966 .687 .452 r
F P
0 g
s
.59587 .51467 m .56851 .52289 L .55414 .50766 L p .652 .756 .926 r
F P
0 g
s
.52686 .51594 m .55414 .50766 L .56851 .52289 L p .652 .756 .926 r
F P
0 g
s
.41653 .48479 m .40079 .46922 L .40171 .44407 L p .957 .688 .485 r
F P
0 g
s
.41653 .48479 m .40079 .46922 L .40171 .44407 L p .957 .688 .485 r
F P
0 g
s
.44315 .47639 m .41653 .48479 L .40079 .46922 L p .654 .754 .923 r
F P
0 g
s
.44254 .50187 m .44315 .47639 L .41653 .48479 L p .544 .324 .532 r
F P
0 g
s
.41653 .48479 m .41572 .51021 L .44254 .50187 L p .544 .324 .532 r
F P
0 g
s
.37426 .47769 m .40079 .46922 L .41653 .48479 L p .654 .754 .923 r
F P
0 g
s
.37426 .47769 m .40079 .46922 L .41653 .48479 L p .654 .754 .923 r
F P
0 g
s
.40079 .46922 m .41653 .48479 L .41572 .51021 L p .957 .688 .485 r
F P
0 g
s
.44315 .47639 m .41653 .48479 L .40079 .46922 L p .654 .754 .923 r
F P
0 g
s
.40079 .46922 m .41653 .48479 L .41572 .51021 L p .957 .688 .485 r
F P
0 g
s
.74809 .46264 m .74641 .43745 L .7183 .44604 L p .556 .341 .544 r
F P
0 g
s
.7183 .44604 m .71976 .47118 L .74809 .46264 L p .556 .341 .544 r
F P
0 g
s
.7183 .44604 m .70528 .43011 L .70393 .40524 L p .975 .682 .398 r
F P
0 g
s
.74641 .43745 m .7183 .44604 L .70528 .43011 L p .656 .751 .92 r
F P
0 g
s
.74809 .46264 m .74641 .43745 L .7183 .44604 L p .556 .341 .544 r
F P
0 g
s
.7183 .44604 m .71976 .47118 L .74809 .46264 L p .556 .341 .544 r
F P
0 g
s
.67726 .43878 m .70528 .43011 L .7183 .44604 L p .656 .751 .92 r
F P
0 g
s
.70528 .43011 m .7183 .44604 L .71976 .47118 L p .975 .682 .398 r
F P
0 g
s
.74641 .43745 m .7183 .44604 L .70528 .43011 L p .656 .751 .92 r
F P
0 g
s
.70528 .43011 m .7183 .44604 L .71976 .47118 L p .975 .682 .398 r
F P
0 g
s
.59416 .42406 m .59364 .39916 L .56627 .40794 L p .547 .329 .535 r
F P
0 g
s
.56627 .40794 m .56659 .43279 L .59416 .42406 L p .547 .329 .535 r
F P
0 g
s
.56627 .40794 m .55188 .39166 L .55167 .36708 L p .969 .687 .442 r
F P
0 g
s
.56627 .40794 m .55188 .39166 L .55167 .36708 L p .969 .687 .442 r
F P
0 g
s
.59364 .39916 m .56627 .40794 L .55188 .39166 L p .658 .749 .917 r
F P
0 g
s
.59416 .42406 m .59364 .39916 L .56627 .40794 L p .547 .329 .535 r
F P
0 g
s
.56627 .40794 m .56659 .43279 L .59416 .42406 L p .547 .329 .535 r
F P
0 g
s
.5246 .40051 m .55188 .39166 L .56627 .40794 L p .658 .749 .917 r
F P
0 g
s
.5246 .40051 m .55188 .39166 L .56627 .40794 L p .658 .749 .917 r
F P
0 g
s
.55188 .39166 m .56627 .40794 L .56659 .43279 L p .969 .687 .442 r
F P
0 g
s
.59364 .39916 m .56627 .40794 L .55188 .39166 L p .658 .749 .917 r
F P
0 g
s
.55188 .39166 m .56627 .40794 L .56659 .43279 L p .969 .687 .442 r
F P
0 g
s
.44023 .38548 m .44086 .36086 L .41424 .36983 L p .537 .315 .524 r
F P
0 g
s
.41424 .36983 m .41341 .39439 L .44023 .38548 L p .537 .315 .524 r
F P
0 g
s
.44086 .36086 m .41424 .36983 L .39847 .35321 L p .66 .747 .915 r
F P
0 g
s
.44023 .38548 m .44086 .36086 L .41424 .36983 L p .537 .315 .524 r
F P
0 g
s
.41424 .36983 m .41341 .39439 L .44023 .38548 L p .537 .315 .524 r
F P
0 g
s
.37194 .36225 m .39847 .35321 L .41424 .36983 L p .66 .747 .915 r
F P
0 g
s
.39847 .35321 m .41424 .36983 L .41341 .39439 L p .959 .688 .477 r
F P
0 g
s
.39847 .35321 m .41424 .36983 L .41341 .39439 L p .959 .688 .477 r
F P
0 g
s
.78935 .55975 m .77697 .54484 L .77508 .5191 L p .976 .68 .386 r
F P
0 g
s
.78935 .55975 m .77697 .54484 L .77508 .5191 L p .976 .68 .386 r
F P
0 g
s
.81782 .55171 m .78935 .55975 L .77697 .54484 L p .649 .759 .929 r
F P
0 g
s
.74859 .55295 m .77697 .54484 L .78935 .55975 L p .649 .759 .929 r
F P
0 g
s
.63726 .52163 m .6235 .50637 L .62276 .48093 L p .971 .686 .432 r
F P
0 g
s
.63726 .52163 m .6235 .50637 L .62276 .48093 L p .971 .686 .432 r
F P
0 g
s
.66498 .5134 m .63726 .52163 L .6235 .50637 L p .652 .756 .926 r
F P
0 g
s
.59587 .51467 m .6235 .50637 L .63726 .52163 L p .652 .756 .926 r
F P
0 g
s
.59587 .51467 m .6235 .50637 L .63726 .52163 L p .652 .756 .926 r
F P
0 g
s
.6235 .50637 m .63726 .52163 L .63811 .54734 L p .971 .686 .432 r
F P
0 g
s
.51206 .50058 m .51215 .47509 L .48517 .48351 L p .547 .329 .535 r
F P
0 g
s
.48517 .48351 m .48488 .50894 L .51206 .50058 L p .547 .329 .535 r
F P
0 g
s
.48517 .48351 m .47004 .46791 L .47045 .44275 L p .962 .688 .469 r
F P
0 g
s
.51215 .47509 m .48517 .48351 L .47004 .46791 L p .654 .754 .923 r
F P
0 g
s
.51206 .50058 m .51215 .47509 L .48517 .48351 L p .547 .329 .535 r
F P
0 g
s
.48517 .48351 m .48488 .50894 L .51206 .50058 L p .547 .329 .535 r
F P
0 g
s
.44315 .47639 m .47004 .46791 L .48517 .48351 L p .654 .754 .923 r
F P
0 g
s
.47004 .46791 m .48517 .48351 L .48488 .50894 L p .962 .688 .469 r
F P
0 g
s
.51215 .47509 m .48517 .48351 L .47004 .46791 L p .654 .754 .923 r
F P
0 g
s
.47004 .46791 m .48517 .48351 L .48488 .50894 L p .962 .688 .469 r
F P
0 g
s
.33308 .44539 m .31657 .42944 L .31813 .40457 L p .952 .687 .499 r
F P
0 g
s
.35932 .43678 m .33308 .44539 L .31657 .42944 L p .656 .751 .92 r
F P
0 g
s
.29044 .43811 m .31657 .42944 L .33308 .44539 L p .656 .751 .92 r
F P
0 g
s
.31657 .42944 m .33308 .44539 L .33164 .47053 L p .952 .687 .499 r
F P
0 g
s
.18099 .40726 m .1631 .39097 L .16581 .36639 L p .941 .685 .523 r
F P
0 g
s
.20649 .39848 m .18099 .40726 L .1631 .39097 L p .658 .749 .917 r
F P
0 g
s
.89988 .38479 m .89706 .36017 L .86821 .36914 L p .558 .345 .547 r
F P
0 g
s
.86821 .36914 m .8708 .39371 L .89988 .38479 L p .558 .345 .547 r
F P
0 g
s
.81786 .46132 m .81566 .43612 L .7872 .44473 L p .558 .345 .547 r
F P
0 g
s
.7872 .44473 m .78918 .46987 L .81786 .46132 L p .558 .345 .547 r
F P
0 g
s
.7872 .44473 m .77479 .42877 L .77292 .40389 L p .976 .678 .372 r
F P
0 g
s
.81566 .43612 m .7872 .44473 L .77479 .42877 L p .656 .751 .92 r
F P
0 g
s
.81786 .46132 m .81566 .43612 L .7872 .44473 L p .558 .345 .547 r
F P
0 g
s
.7872 .44473 m .78918 .46987 L .81786 .46132 L p .558 .345 .547 r
F P
0 g
s
.74641 .43745 m .77479 .42877 L .7872 .44473 L p .656 .751 .92 r
F P
0 g
s
.77479 .42877 m .7872 .44473 L .78918 .46987 L p .976 .678 .372 r
F P
0 g
s
.66382 .42271 m .66277 .3978 L .63505 .40659 L p .55 .333 .538 r
F P
0 g
s
.63505 .40659 m .63588 .43145 L .66382 .42271 L p .55 .333 .538 r
F P
0 g
s
.63505 .40659 m .62127 .39029 L .62054 .3657 L p .972 .685 .422 r
F P
0 g
s
.66277 .3978 m .63505 .40659 L .62127 .39029 L p .658 .749 .917 r
F P
0 g
s
.66382 .42271 m .66277 .3978 L .63505 .40659 L p .55 .333 .538 r
F P
0 g
s
.63505 .40659 m .63588 .43145 L .66382 .42271 L p .55 .333 .538 r
F P
0 g
s
.59364 .39916 m .62127 .39029 L .63505 .40659 L p .658 .749 .917 r
F P
0 g
s
.59364 .39916 m .62127 .39029 L .63505 .40659 L p .658 .749 .917 r
F P
0 g
s
.62127 .39029 m .63505 .40659 L .63588 .43145 L p .972 .685 .422 r
F P
0 g
s
.62127 .39029 m .63505 .40659 L .63588 .43145 L p .972 .685 .422 r
F P
0 g
s
.50977 .3841 m .50988 .35948 L .4829 .36846 L p .541 .319 .528 r
F P
0 g
s
.4829 .36846 m .48259 .39303 L .50977 .3841 L p .541 .319 .528 r
F P
0 g
s
.50988 .35948 m .4829 .36846 L .46774 .35181 L p .66 .747 .915 r
F P
0 g
s
.50977 .3841 m .50988 .35948 L .4829 .36846 L p .541 .319 .528 r
F P
0 g
s
.4829 .36846 m .48259 .39303 L .50977 .3841 L p .541 .319 .528 r
F P
0 g
s
.46774 .35181 m .4829 .36846 L .48259 .39303 L p .964 .688 .461 r
F P
0 g
s
.73579 .53792 m .7342 .51213 L .70612 .52037 L p .558 .345 .547 r
F P
0 g
s
.70612 .52037 m .70749 .54609 L .73579 .53792 L p .558 .345 .547 r
F P
0 g
s
.70612 .52037 m .69298 .50509 L .69171 .47963 L p .974 .684 .41 r
F P
0 g
s
.7342 .51213 m .70612 .52037 L .69298 .50509 L p .652 .756 .926 r
F P
0 g
s
.73579 .53792 m .7342 .51213 L .70612 .52037 L p .558 .345 .547 r
F P
0 g
s
.70612 .52037 m .70749 .54609 L .73579 .53792 L p .558 .345 .547 r
F P
0 g
s
.66498 .5134 m .69298 .50509 L .70612 .52037 L p .652 .756 .926 r
F P
0 g
s
.69298 .50509 m .70612 .52037 L .70749 .54609 L p .974 .684 .41 r
F P
0 g
s
.7342 .51213 m .70612 .52037 L .69298 .50509 L p .652 .756 .926 r
F P
0 g
s
.69298 .50509 m .70612 .52037 L .70749 .54609 L p .974 .684 .41 r
F P
0 g
s
.58168 .49929 m .58125 .47379 L .55392 .48222 L p .55 .333 .538 r
F P
0 g
s
.55392 .48222 m .55414 .50766 L .58168 .49929 L p .55 .333 .538 r
F P
0 g
s
.55392 .48222 m .53939 .46659 L .53928 .44143 L p .966 .687 .452 r
F P
0 g
s
.55392 .48222 m .53939 .46659 L .53928 .44143 L p .966 .687 .452 r
F P
0 g
s
.58125 .47379 m .55392 .48222 L .53939 .46659 L p .654 .754 .923 r
F P
0 g
s
.58168 .49929 m .58125 .47379 L .55392 .48222 L p .55 .333 .538 r
F P
0 g
s
.55392 .48222 m .55414 .50766 L .58168 .49929 L p .55 .333 .538 r
F P
0 g
s
.51215 .47509 m .53939 .46659 L .55392 .48222 L p .654 .754 .923 r
F P
0 g
s
.51215 .47509 m .53939 .46659 L .55392 .48222 L p .654 .754 .923 r
F P
0 g
s
.53939 .46659 m .55392 .48222 L .55414 .50766 L p .966 .687 .452 r
F P
0 g
s
.58125 .47379 m .55392 .48222 L .53939 .46659 L p .654 .754 .923 r
F P
0 g
s
.53939 .46659 m .55392 .48222 L .55414 .50766 L p .966 .687 .452 r
F P
0 g
s
.42757 .46066 m .4283 .43545 L .40171 .44407 L p .541 .319 .528 r
F P
0 g
s
.40171 .44407 m .40079 .46922 L .42757 .46066 L p .541 .319 .528 r
F P
0 g
s
.40171 .44407 m .38581 .4281 L .38685 .40322 L p .957 .688 .485 r
F P
0 g
s
.4283 .43545 m .40171 .44407 L .38581 .4281 L p .656 .751 .92 r
F P
0 g
s
.42757 .46066 m .4283 .43545 L .40171 .44407 L p .541 .319 .528 r
F P
0 g
s
.40171 .44407 m .40079 .46922 L .42757 .46066 L p .541 .319 .528 r
F P
0 g
s
.35932 .43678 m .38581 .4281 L .40171 .44407 L p .656 .751 .92 r
F P
0 g
s
.35932 .43678 m .38581 .4281 L .40171 .44407 L p .656 .751 .92 r
F P
0 g
s
.38581 .4281 m .40171 .44407 L .40079 .46922 L p .957 .688 .485 r
F P
0 g
s
.38581 .4281 m .40171 .44407 L .40079 .46922 L p .957 .688 .485 r
F P
0 g
s
.20649 .39848 m .23223 .3896 L .24951 .40592 L p .658 .749 .917 r
F P
0 g
s
.24951 .40592 m .23223 .3896 L .23442 .36501 L p .946 .686 .511 r
F P
0 g
s
.47272 .5579 m .45746 .54296 L .45796 .51721 L p .959 .688 .477 r
F P
0 g
s
.47272 .5579 m .45746 .54296 L .45796 .51721 L p .959 .688 .477 r
F P
0 g
s
.49967 .54984 m .47272 .5579 L .45746 .54296 L p .649 .759 .929 r
F P
0 g
s
.4306 .55108 m .45746 .54296 L .47272 .5579 L p .649 .759 .929 r
F P
0 g
s
.32046 .51974 m .30382 .50445 L .30547 .47899 L p .949 .687 .505 r
F P
0 g
s
.34666 .51149 m .32046 .51974 L .30382 .50445 L p .652 .756 .926 r
F P
0 g
s
.73358 .42136 m .73201 .39644 L .70393 .40524 L p .553 .337 .541 r
F P
0 g
s
.70393 .40524 m .70528 .43011 L .73358 .42136 L p .553 .337 .541 r
F P
0 g
s
.70393 .40524 m .69076 .38892 L .68952 .36432 L p .975 .682 .398 r
F P
0 g
s
.73201 .39644 m .70393 .40524 L .69076 .38892 L p .658 .749 .917 r
F P
0 g
s
.73358 .42136 m .73201 .39644 L .70393 .40524 L p .553 .337 .541 r
F P
0 g
s
.70393 .40524 m .70528 .43011 L .73358 .42136 L p .553 .337 .541 r
F P
0 g
s
.66277 .3978 m .69076 .38892 L .70393 .40524 L p .658 .749 .917 r
F P
0 g
s
.69076 .38892 m .70393 .40524 L .70528 .43011 L p .975 .682 .398 r
F P
0 g
s
.57942 .38272 m .57901 .35809 L .55167 .36708 L p .544 .324 .532 r
F P
0 g
s
.55167 .36708 m .55188 .39166 L .57942 .38272 L p .544 .324 .532 r
F P
0 g
s
.57901 .35809 m .55167 .36708 L .53712 .35041 L p .66 .747 .915 r
F P
0 g
s
.57942 .38272 m .57901 .35809 L .55167 .36708 L p .544 .324 .532 r
F P
0 g
s
.55167 .36708 m .55188 .39166 L .57942 .38272 L p .544 .324 .532 r
F P
0 g
s
.50988 .35948 m .53712 .35041 L .55167 .36708 L p .66 .747 .915 r
F P
0 g
s
.53712 .35041 m .55167 .36708 L .55188 .39166 L p .969 .687 .442 r
F P
0 g
s
.53712 .35041 m .55167 .36708 L .55188 .39166 L p .969 .687 .442 r
F P
0 g
s
.80563 .53665 m .80352 .51085 L .77508 .5191 L p .561 .349 .55 r
F P
0 g
s
.77508 .5191 m .77697 .54484 L .80563 .53665 L p .561 .349 .55 r
F P
0 g
s
.77508 .5191 m .76255 .5038 L .76077 .47834 L p .976 .68 .386 r
F P
0 g
s
.80352 .51085 m .77508 .5191 L .76255 .5038 L p .652 .756 .926 r
F P
0 g
s
.80563 .53665 m .80352 .51085 L .77508 .5191 L p .561 .349 .55 r
F P
0 g
s
.77508 .5191 m .77697 .54484 L .80563 .53665 L p .561 .349 .55 r
F P
0 g
s
.7342 .51213 m .76255 .5038 L .77508 .5191 L p .652 .756 .926 r
F P
0 g
s
.76255 .5038 m .77508 .5191 L .77697 .54484 L p .976 .68 .386 r
F P
0 g
s
.80352 .51085 m .77508 .5191 L .76255 .5038 L p .652 .756 .926 r
F P
0 g
s
.76255 .5038 m .77508 .5191 L .77697 .54484 L p .976 .68 .386 r
F P
0 g
s
.65141 .49799 m .65045 .47249 L .62276 .48093 L p .553 .337 .541 r
F P
0 g
s
.62276 .48093 m .6235 .50637 L .65141 .49799 L p .553 .337 .541 r
F P
0 g
s
.62276 .48093 m .60885 .46528 L .60822 .4401 L p .971 .686 .432 r
F P
0 g
s
.62276 .48093 m .60885 .46528 L .60822 .4401 L p .971 .686 .432 r
F P
0 g
s
.65045 .47249 m .62276 .48093 L .60885 .46528 L p .654 .754 .923 r
F P
0 g
s
.65141 .49799 m .65045 .47249 L .62276 .48093 L p .553 .337 .541 r
F P
0 g
s
.62276 .48093 m .6235 .50637 L .65141 .49799 L p .553 .337 .541 r
F P
0 g
s
.58125 .47379 m .60885 .46528 L .62276 .48093 L p .654 .754 .923 r
F P
0 g
s
.58125 .47379 m .60885 .46528 L .62276 .48093 L p .654 .754 .923 r
F P
0 g
s
.60885 .46528 m .62276 .48093 L .6235 .50637 L p .971 .686 .432 r
F P
0 g
s
.65045 .47249 m .62276 .48093 L .60885 .46528 L p .654 .754 .923 r
F P
0 g
s
.60885 .46528 m .62276 .48093 L .6235 .50637 L p .971 .686 .432 r
F P
0 g
s
.49719 .45934 m .49739 .43412 L .47045 .44275 L p .544 .324 .532 r
F P
0 g
s
.47045 .44275 m .47004 .46791 L .49719 .45934 L p .544 .324 .532 r
F P
0 g
s
.47045 .44275 m .45515 .42675 L .45568 .40187 L p .962 .688 .469 r
F P
0 g
s
.47045 .44275 m .45515 .42675 L .45568 .40187 L p .962 .688 .469 r
F P
0 g
s
.49739 .43412 m .47045 .44275 L .45515 .42675 L p .656 .751 .92 r
F P
0 g
s
.49719 .45934 m .49739 .43412 L .47045 .44275 L p .544 .324 .532 r
F P
0 g
s
.47045 .44275 m .47004 .46791 L .49719 .45934 L p .544 .324 .532 r
F P
0 g
s
.4283 .43545 m .45515 .42675 L .47045 .44275 L p .656 .751 .92 r
F P
0 g
s
.45515 .42675 m .47045 .44275 L .47004 .46791 L p .962 .688 .469 r
F P
0 g
s
.49739 .43412 m .47045 .44275 L .45515 .42675 L p .656 .751 .92 r
F P
0 g
s
.34296 .42068 m .34433 .39576 L .31813 .40457 L p .534 .309 .521 r
F P
0 g
s
.31813 .40457 m .31657 .42944 L .34296 .42068 L p .534 .309 .521 r
F P
0 g
s
.31813 .40457 m .30146 .38823 L .30313 .36363 L p .952 .687 .499 r
F P
0 g
s
.34433 .39576 m .31813 .40457 L .30146 .38823 L p .658 .749 .917 r
F P
0 g
s
.34296 .42068 m .34433 .39576 L .31813 .40457 L p .534 .309 .521 r
F P
0 g
s
.31813 .40457 m .31657 .42944 L .34296 .42068 L p .534 .309 .521 r
F P
0 g
s
.30146 .38823 m .31813 .40457 L .31657 .42944 L p .952 .687 .499 r
F P
0 g
s
.34433 .39576 m .31813 .40457 L .30146 .38823 L p .658 .749 .917 r
F P
0 g
s
.18874 .38203 m .19127 .35739 L .16581 .36639 L p .522 .293 .509 r
F P
0 g
s
.16581 .36639 m .1631 .39097 L .18874 .38203 L p .522 .293 .509 r
F P
0 g
s
.49967 .54984 m .52688 .5417 L .54153 .55667 L p .649 .759 .929 r
F P
0 g
s
.54153 .55667 m .52688 .5417 L .52686 .51594 L p .964 .688 .461 r
F P
0 g
s
.38916 .51847 m .37312 .50316 L .37426 .47769 L p .954 .688 .492 r
F P
0 g
s
.38916 .51847 m .37312 .50316 L .37426 .47769 L p .954 .688 .492 r
F P
0 g
s
.41572 .51021 m .38916 .51847 L .37312 .50316 L p .652 .756 .926 r
F P
0 g
s
.41489 .53602 m .41572 .51021 L .38916 .51847 L p .544 .324 .532 r
F P
0 g
s
.38916 .51847 m .38814 .54421 L .41489 .53602 L p .544 .324 .532 r
F P
0 g
s
.34666 .51149 m .37312 .50316 L .38916 .51847 L p .652 .756 .926 r
F P
0 g
s
.34666 .51149 m .37312 .50316 L .38916 .51847 L p .652 .756 .926 r
F P
0 g
s
.37312 .50316 m .38916 .51847 L .38814 .54421 L p .954 .688 .492 r
F P
0 g
s
.41572 .51021 m .38916 .51847 L .37312 .50316 L p .652 .756 .926 r
F P
0 g
s
.37312 .50316 m .38916 .51847 L .38814 .54421 L p .954 .688 .492 r
F P
0 g
s
.73201 .39644 m .76036 .38754 L .77292 .40389 L p .658 .749 .917 r
F P
0 g
s
.73201 .39644 m .76036 .38754 L .77292 .40389 L p .658 .749 .917 r
F P
0 g
s
.76036 .38754 m .77292 .40389 L .77479 .42877 L p .976 .678 .372 r
F P
0 g
s
.77292 .40389 m .76036 .38754 L .75859 .36294 L p .976 .678 .372 r
F P
0 g
s
.64823 .35669 m .62054 .3657 L .60661 .349 L p .66 .747 .915 r
F P
0 g
s
.64917 .38133 m .64823 .35669 L .62054 .3657 L p .547 .329 .535 r
F P
0 g
s
.62054 .3657 m .62127 .39029 L .64917 .38133 L p .547 .329 .535 r
F P
0 g
s
.57901 .35809 m .60661 .349 L .62054 .3657 L p .66 .747 .915 r
F P
0 g
s
.60661 .349 m .62054 .3657 L .62127 .39029 L p .972 .685 .422 r
F P
0 g
s
.60661 .349 m .62054 .3657 L .62127 .39029 L p .972 .685 .422 r
F P
0 g
s
.80352 .51085 m .83223 .50252 L .84415 .51784 L p .652 .756 .926 r
F P
0 g
s
.84415 .51784 m .83223 .50252 L .82992 .47704 L p .976 .675 .358 r
F P
0 g
s
.72124 .4967 m .71976 .47118 L .69171 .47963 L p .556 .341 .544 r
F P
0 g
s
.69171 .47963 m .69298 .50509 L .72124 .4967 L p .556 .341 .544 r
F P
0 g
s
.69171 .47963 m .67842 .46396 L .67726 .43878 L p .974 .684 .41 r
F P
0 g
s
.69171 .47963 m .67842 .46396 L .67726 .43878 L p .974 .684 .41 r
F P
0 g
s
.71976 .47118 m .69171 .47963 L .67842 .46396 L p .654 .754 .923 r
F P
0 g
s
.65045 .47249 m .67842 .46396 L .69171 .47963 L p .654 .754 .923 r
F P
0 g
s
.65045 .47249 m .67842 .46396 L .69171 .47963 L p .654 .754 .923 r
F P
0 g
s
.67842 .46396 m .69171 .47963 L .69298 .50509 L p .974 .684 .41 r
F P
0 g
s
.5669 .45801 m .56659 .43279 L .53928 .44143 L p .547 .329 .535 r
F P
0 g
s
.53928 .44143 m .53939 .46659 L .5669 .45801 L p .547 .329 .535 r
F P
0 g
s
.53928 .44143 m .5246 .42541 L .5246 .40051 L p .966 .687 .452 r
F P
0 g
s
.53928 .44143 m .5246 .42541 L .5246 .40051 L p .966 .687 .452 r
F P
0 g
s
.56659 .43279 m .53928 .44143 L .5246 .42541 L p .656 .751 .92 r
F P
0 g
s
.5669 .45801 m .56659 .43279 L .53928 .44143 L p .547 .329 .535 r
F P
0 g
s
.53928 .44143 m .53939 .46659 L .5669 .45801 L p .547 .329 .535 r
F P
0 g
s
.49739 .43412 m .5246 .42541 L .53928 .44143 L p .656 .751 .92 r
F P
0 g
s
.49739 .43412 m .5246 .42541 L .53928 .44143 L p .656 .751 .92 r
F P
0 g
s
.5246 .42541 m .53928 .44143 L .53939 .46659 L p .966 .687 .452 r
F P
0 g
s
.56659 .43279 m .53928 .44143 L .5246 .42541 L p .656 .751 .92 r
F P
0 g
s
.5246 .42541 m .53928 .44143 L .53939 .46659 L p .966 .687 .452 r
F P
0 g
s
.38685 .40322 m .37079 .38686 L .37194 .36225 L p .957 .688 .485 r
F P
0 g
s
.41341 .39439 m .38685 .40322 L .37079 .38686 L p .658 .749 .917 r
F P
0 g
s
.34433 .39576 m .37079 .38686 L .38685 .40322 L p .658 .749 .917 r
F P
0 g
s
.37079 .38686 m .38685 .40322 L .38581 .4281 L p .957 .688 .485 r
F P
0 g
s
.26023 .356 m .23442 .36501 L .21697 .3483 L p .66 .747 .915 r
F P
0 g
s
.25822 .38064 m .26023 .356 L .23442 .36501 L p .526 .299 .513 r
F P
0 g
s
.23442 .36501 m .23223 .3896 L .25822 .38064 L p .526 .299 .513 r
F P
0 g
s
.19127 .35739 m .21697 .3483 L .23442 .36501 L p .66 .747 .915 r
F P
0 g
s
.21697 .3483 m .23442 .36501 L .23223 .3896 L p .946 .686 .511 r
F P
0 g
s
.21697 .3483 m .23442 .36501 L .23223 .3896 L p .946 .686 .511 r
F P
0 g
s
.61045 .55543 m .59641 .54044 L .59587 .51467 L p .969 .687 .442 r
F P
0 g
s
.61045 .55543 m .59641 .54044 L .59587 .51467 L p .969 .687 .442 r
F P
0 g
s
.63811 .54734 m .61045 .55543 L .59641 .54044 L p .649 .759 .929 r
F P
0 g
s
.56884 .54859 m .59641 .54044 L .61045 .55543 L p .649 .759 .929 r
F P
0 g
s
.48457 .53475 m .48488 .50894 L .45796 .51721 L p .547 .329 .535 r
F P
0 g
s
.45796 .51721 m .45746 .54296 L .48457 .53475 L p .547 .329 .535 r
F P
0 g
s
.45796 .51721 m .44254 .50187 L .44315 .47639 L p .959 .688 .477 r
F P
0 g
s
.48488 .50894 m .45796 .51721 L .44254 .50187 L p .652 .756 .926 r
F P
0 g
s
.48457 .53475 m .48488 .50894 L .45796 .51721 L p .547 .329 .535 r
F P
0 g
s
.45796 .51721 m .45746 .54296 L .48457 .53475 L p .547 .329 .535 r
F P
0 g
s
.44254 .50187 m .45796 .51721 L .45746 .54296 L p .959 .688 .477 r
F P
0 g
s
.48488 .50894 m .45796 .51721 L .44254 .50187 L p .652 .756 .926 r
F P
0 g
s
.33018 .49605 m .33164 .47053 L .30547 .47899 L p .537 .315 .524 r
F P
0 g
s
.30547 .47899 m .30382 .50445 L .33018 .49605 L p .537 .315 .524 r
F P
0 g
s
.30547 .47899 m .28867 .4633 L .29044 .43811 L p .949 .687 .505 r
F P
0 g
s
.33164 .47053 m .30547 .47899 L .28867 .4633 L p .654 .754 .923 r
F P
0 g
s
.33018 .49605 m .33164 .47053 L .30547 .47899 L p .537 .315 .524 r
F P
0 g
s
.30547 .47899 m .30382 .50445 L .33018 .49605 L p .537 .315 .524 r
F P
0 g
s
.28867 .4633 m .30547 .47899 L .30382 .50445 L p .949 .687 .505 r
F P
0 g
s
.33164 .47053 m .30547 .47899 L .28867 .4633 L p .654 .754 .923 r
F P
0 g
s
.79118 .4954 m .78918 .46987 L .76077 .47834 L p .558 .345 .547 r
F P
0 g
s
.76077 .47834 m .76255 .5038 L .79118 .4954 L p .558 .345 .547 r
F P
0 g
s
.76077 .47834 m .74809 .46264 L .74641 .43745 L p .976 .68 .386 r
F P
0 g
s
.78918 .46987 m .76077 .47834 L .74809 .46264 L p .654 .754 .923 r
F P
0 g
s
.79118 .4954 m .78918 .46987 L .76077 .47834 L p .558 .345 .547 r
F P
0 g
s
.76077 .47834 m .76255 .5038 L .79118 .4954 L p .558 .345 .547 r
F P
0 g
s
.71976 .47118 m .74809 .46264 L .76077 .47834 L p .654 .754 .923 r
F P
0 g
s
.74809 .46264 m .76077 .47834 L .76255 .5038 L p .976 .68 .386 r
F P
0 g
s
.63673 .45669 m .63588 .43145 L .60822 .4401 L p .55 .333 .538 r
F P
0 g
s
.60822 .4401 m .60885 .46528 L .63673 .45669 L p .55 .333 .538 r
F P
0 g
s
.60822 .4401 m .59416 .42406 L .59364 .39916 L p .971 .686 .432 r
F P
0 g
s
.60822 .4401 m .59416 .42406 L .59364 .39916 L p .971 .686 .432 r
F P
0 g
s
.63588 .43145 m .60822 .4401 L .59416 .42406 L p .656 .751 .92 r
F P
0 g
s
.63673 .45669 m .63588 .43145 L .60822 .4401 L p .55 .333 .538 r
F P
0 g
s
.60822 .4401 m .60885 .46528 L .63673 .45669 L p .55 .333 .538 r
F P
0 g
s
.56659 .43279 m .59416 .42406 L .60822 .4401 L p .656 .751 .92 r
F P
0 g
s
.56659 .43279 m .59416 .42406 L .60822 .4401 L p .656 .751 .92 r
F P
0 g
s
.59416 .42406 m .60822 .4401 L .60885 .46528 L p .971 .686 .432 r
F P
0 g
s
.63588 .43145 m .60822 .4401 L .59416 .42406 L p .656 .751 .92 r
F P
0 g
s
.59416 .42406 m .60822 .4401 L .60885 .46528 L p .971 .686 .432 r
F P
0 g
s
.48227 .41797 m .48259 .39303 L .45568 .40187 L p .541 .319 .528 r
F P
0 g
s
.45568 .40187 m .45515 .42675 L .48227 .41797 L p .541 .319 .528 r
F P
0 g
s
.45568 .40187 m .44023 .38548 L .44086 .36086 L p .962 .688 .469 r
F P
0 g
s
.48259 .39303 m .45568 .40187 L .44023 .38548 L p .658 .749 .917 r
F P
0 g
s
.48227 .41797 m .48259 .39303 L .45568 .40187 L p .541 .319 .528 r
F P
0 g
s
.45568 .40187 m .45515 .42675 L .48227 .41797 L p .541 .319 .528 r
F P
0 g
s
.41341 .39439 m .44023 .38548 L .45568 .40187 L p .658 .749 .917 r
F P
0 g
s
.41341 .39439 m .44023 .38548 L .45568 .40187 L p .658 .749 .917 r
F P
0 g
s
.44023 .38548 m .45568 .40187 L .45515 .42675 L p .962 .688 .469 r
F P
0 g
s
.44023 .38548 m .45568 .40187 L .45515 .42675 L p .962 .688 .469 r
F P
0 g
s
.32781 .37926 m .3293 .3546 L .30313 .36363 L p .53 .304 .517 r
F P
0 g
s
.30313 .36363 m .30146 .38823 L .32781 .37926 L p .53 .304 .517 r
F P
0 g
s
.26023 .356 m .2863 .3469 L .30313 .36363 L p .66 .747 .915 r
F P
0 g
s
.2863 .3469 m .30313 .36363 L .30146 .38823 L p .952 .687 .499 r
F P
0 g
s
.67947 .55419 m .66605 .53918 L .66498 .5134 L p .972 .685 .422 r
F P
0 g
s
.70749 .54609 m .67947 .55419 L .66605 .53918 L p .649 .759 .929 r
F P
0 g
s
.52686 .51594 m .51206 .50058 L .51215 .47509 L p .964 .688 .461 r
F P
0 g
s
.52686 .51594 m .51206 .50058 L .51215 .47509 L p .964 .688 .461 r
F P
0 g
s
.55414 .50766 m .52686 .51594 L .51206 .50058 L p .652 .756 .926 r
F P
0 g
s
.55436 .53348 m .55414 .50766 L .52686 .51594 L p .55 .333 .538 r
F P
0 g
s
.52686 .51594 m .52688 .5417 L .55436 .53348 L p .55 .333 .538 r
F P
0 g
s
.48488 .50894 m .51206 .50058 L .52686 .51594 L p .652 .756 .926 r
F P
0 g
s
.51206 .50058 m .52686 .51594 L .52688 .5417 L p .964 .688 .461 r
F P
0 g
s
.55414 .50766 m .52686 .51594 L .51206 .50058 L p .652 .756 .926 r
F P
0 g
s
.39985 .49475 m .40079 .46922 L .37426 .47769 L p .541 .319 .528 r
F P
0 g
s
.37426 .47769 m .37312 .50316 L .39985 .49475 L p .541 .319 .528 r
F P
0 g
s
.37426 .47769 m .35807 .46198 L .35932 .43678 L p .954 .688 .492 r
F P
0 g
s
.40079 .46922 m .37426 .47769 L .35807 .46198 L p .654 .754 .923 r
F P
0 g
s
.33164 .47053 m .35807 .46198 L .37426 .47769 L p .654 .754 .923 r
F P
0 g
s
.35807 .46198 m .37426 .47769 L .37312 .50316 L p .954 .688 .492 r
F P
0 g
s
.8708 .39371 m .89988 .38479 L .9112 .40119 L p .658 .749 .917 r
F P
0 g
s
.9112 .40119 m .89988 .38479 L .89706 .36017 L p .973 .663 .31 r
F P
0 g
s
.787 .35391 m .75859 .36294 L .74589 .34619 L p .66 .747 .915 r
F P
0 g
s
.789 .37856 m .787 .35391 L .75859 .36294 L p .553 .337 .541 r
F P
0 g
s
.75859 .36294 m .76036 .38754 L .789 .37856 L p .553 .337 .541 r
F P
0 g
s
.74589 .34619 m .75859 .36294 L .76036 .38754 L p .976 .678 .372 r
F P
0 g
s
.78918 .46987 m .81786 .46132 L .82992 .47704 L p .654 .754 .923 r
F P
0 g
s
.78918 .46987 m .81786 .46132 L .82992 .47704 L p .654 .754 .923 r
F P
0 g
s
.81786 .46132 m .82992 .47704 L .83223 .50252 L p .976 .675 .358 r
F P
0 g
s
.82992 .47704 m .81786 .46132 L .81566 .43612 L p .976 .675 .358 r
F P
0 g
s
.70666 .45536 m .70528 .43011 L .67726 .43878 L p .553 .337 .541 r
F P
0 g
s
.67726 .43878 m .67842 .46396 L .70666 .45536 L p .553 .337 .541 r
F P
0 g
s
.67726 .43878 m .66382 .42271 L .66277 .3978 L p .974 .684 .41 r
F P
0 g
s
.70528 .43011 m .67726 .43878 L .66382 .42271 L p .656 .751 .92 r
F P
0 g
s
.70666 .45536 m .70528 .43011 L .67726 .43878 L p .553 .337 .541 r
F P
0 g
s
.67726 .43878 m .67842 .46396 L .70666 .45536 L p .553 .337 .541 r
F P
0 g
s
.63588 .43145 m .66382 .42271 L .67726 .43878 L p .656 .751 .92 r
F P
0 g
s
.66382 .42271 m .67726 .43878 L .67842 .46396 L p .974 .684 .41 r
F P
0 g
s
.55208 .41661 m .55188 .39166 L .5246 .40051 L p .544 .324 .532 r
F P
0 g
s
.5246 .40051 m .5246 .42541 L .55208 .41661 L p .544 .324 .532 r
F P
0 g
s
.5246 .40051 m .50977 .3841 L .50988 .35948 L p .966 .687 .452 r
F P
0 g
s
.5246 .40051 m .50977 .3841 L .50988 .35948 L p .966 .687 .452 r
F P
0 g
s
.55188 .39166 m .5246 .40051 L .50977 .3841 L p .658 .749 .917 r
F P
0 g
s
.55208 .41661 m .55188 .39166 L .5246 .40051 L p .544 .324 .532 r
F P
0 g
s
.5246 .40051 m .5246 .42541 L .55208 .41661 L p .544 .324 .532 r
F P
0 g
s
.48259 .39303 m .50977 .3841 L .5246 .40051 L p .658 .749 .917 r
F P
0 g
s
.48259 .39303 m .50977 .3841 L .5246 .40051 L p .658 .749 .917 r
F P
0 g
s
.50977 .3841 m .5246 .40051 L .5246 .42541 L p .966 .687 .452 r
F P
0 g
s
.55188 .39166 m .5246 .40051 L .50977 .3841 L p .658 .749 .917 r
F P
0 g
s
.50977 .3841 m .5246 .40051 L .5246 .42541 L p .966 .687 .452 r
F P
0 g
s
.39751 .37787 m .39847 .35321 L .37194 .36225 L p .534 .309 .521 r
F P
0 g
s
.37194 .36225 m .37079 .38686 L .39751 .37787 L p .534 .309 .521 r
F P
0 g
s
.39847 .35321 m .37194 .36225 L .35572 .34549 L p .66 .747 .915 r
F P
0 g
s
.39751 .37787 m .39847 .35321 L .37194 .36225 L p .534 .309 .521 r
F P
0 g
s
.37194 .36225 m .37079 .38686 L .39751 .37787 L p .534 .309 .521 r
F P
0 g
s
.35572 .34549 m .37194 .36225 L .37079 .38686 L p .957 .688 .485 r
F P
0 g
s
.74859 .55295 m .73579 .53792 L .7342 .51213 L p .975 .682 .398 r
F P
0 g
s
.74859 .55295 m .73579 .53792 L .7342 .51213 L p .975 .682 .398 r
F P
0 g
s
.77697 .54484 m .74859 .55295 L .73579 .53792 L p .649 .759 .929 r
F P
0 g
s
.70749 .54609 m .73579 .53792 L .74859 .55295 L p .649 .759 .929 r
F P
0 g
s
.62426 .53221 m .6235 .50637 L .59587 .51467 L p .553 .337 .541 r
F P
0 g
s
.59587 .51467 m .59641 .54044 L .62426 .53221 L p .553 .337 .541 r
F P
0 g
s
.59587 .51467 m .58168 .49929 L .58125 .47379 L p .969 .687 .442 r
F P
0 g
s
.59587 .51467 m .58168 .49929 L .58125 .47379 L p .969 .687 .442 r
F P
0 g
s
.6235 .50637 m .59587 .51467 L .58168 .49929 L p .652 .756 .926 r
F P
0 g
s
.55414 .50766 m .58168 .49929 L .59587 .51467 L p .652 .756 .926 r
F P
0 g
s
.46962 .49345 m .47004 .46791 L .44315 .47639 L p .544 .324 .532 r
F P
0 g
s
.44315 .47639 m .44254 .50187 L .46962 .49345 L p .544 .324 .532 r
F P
0 g
s
.44315 .47639 m .42757 .46066 L .4283 .43545 L p .959 .688 .477 r
F P
0 g
s
.47004 .46791 m .44315 .47639 L .42757 .46066 L p .654 .754 .923 r
F P
0 g
s
.46962 .49345 m .47004 .46791 L .44315 .47639 L p .544 .324 .532 r
F P
0 g
s
.44315 .47639 m .44254 .50187 L .46962 .49345 L p .544 .324 .532 r
F P
0 g
s
.40079 .46922 m .42757 .46066 L .44315 .47639 L p .654 .754 .923 r
F P
0 g
s
.40079 .46922 m .42757 .46066 L .44315 .47639 L p .654 .754 .923 r
F P
0 g
s
.42757 .46066 m .44315 .47639 L .44254 .50187 L p .959 .688 .477 r
F P
0 g
s
.42757 .46066 m .44315 .47639 L .44254 .50187 L p .959 .688 .477 r
F P
0 g
s
.31499 .45469 m .31657 .42944 L .29044 .43811 L p .534 .309 .521 r
F P
0 g
s
.29044 .43811 m .28867 .4633 L .31499 .45469 L p .534 .309 .521 r
F P
0 g
s
.31657 .42944 m .29044 .43811 L .27347 .42204 L p .656 .751 .92 r
F P
0 g
s
.31499 .45469 m .31657 .42944 L .29044 .43811 L p .534 .309 .521 r
F P
0 g
s
.29044 .43811 m .28867 .4633 L .31499 .45469 L p .534 .309 .521 r
F P
0 g
s
.27347 .42204 m .29044 .43811 L .28867 .4633 L p .949 .687 .505 r
F P
0 g
s
.36164 .55233 m .34532 .53728 L .34666 .51149 L p .952 .687 .499 r
F P
0 g
s
.38814 .54421 m .36164 .55233 L .34532 .53728 L p .649 .759 .929 r
F P
0 g
s
.74641 .43745 m .73358 .42136 L .73201 .39644 L p .976 .68 .386 r
F P
0 g
s
.74641 .43745 m .73358 .42136 L .73201 .39644 L p .976 .68 .386 r
F P
0 g
s
.77479 .42877 m .74641 .43745 L .73358 .42136 L p .656 .751 .92 r
F P
0 g
s
.70528 .43011 m .73358 .42136 L .74641 .43745 L p .656 .751 .92 r
F P
0 g
s
.70528 .43011 m .73358 .42136 L .74641 .43745 L p .656 .751 .92 r
F P
0 g
s
.73358 .42136 m .74641 .43745 L .74809 .46264 L p .976 .68 .386 r
F P
0 g
s
.622 .41525 m .62127 .39029 L .59364 .39916 L p .547 .329 .535 r
F P
0 g
s
.59364 .39916 m .59416 .42406 L .622 .41525 L p .547 .329 .535 r
F P
0 g
s
.59364 .39916 m .57942 .38272 L .57901 .35809 L p .971 .686 .432 r
F P
0 g
s
.59364 .39916 m .57942 .38272 L .57901 .35809 L p .971 .686 .432 r
F P
0 g
s
.62127 .39029 m .59364 .39916 L .57942 .38272 L p .658 .749 .917 r
F P
0 g
s
.622 .41525 m .62127 .39029 L .59364 .39916 L p .547 .329 .535 r
F P
0 g
s
.59364 .39916 m .59416 .42406 L .622 .41525 L p .547 .329 .535 r
F P
0 g
s
.55188 .39166 m .57942 .38272 L .59364 .39916 L p .658 .749 .917 r
F P
0 g
s
.55188 .39166 m .57942 .38272 L .59364 .39916 L p .658 .749 .917 r
F P
0 g
s
.57942 .38272 m .59364 .39916 L .59416 .42406 L p .971 .686 .432 r
F P
0 g
s
.62127 .39029 m .59364 .39916 L .57942 .38272 L p .658 .749 .917 r
F P
0 g
s
.57942 .38272 m .59364 .39916 L .59416 .42406 L p .971 .686 .432 r
F P
0 g
s
.46774 .35181 m .44086 .36086 L .42525 .34408 L p .66 .747 .915 r
F P
0 g
s
.46731 .37648 m .46774 .35181 L .44086 .36086 L p .537 .315 .524 r
F P
0 g
s
.44086 .36086 m .44023 .38548 L .46731 .37648 L p .537 .315 .524 r
F P
0 g
s
.39847 .35321 m .42525 .34408 L .44086 .36086 L p .66 .747 .915 r
F P
0 g
s
.42525 .34408 m .44086 .36086 L .44023 .38548 L p .962 .688 .469 r
F P
0 g
s
.42525 .34408 m .44086 .36086 L .44023 .38548 L p .962 .688 .469 r
F P
0 g
s
.77697 .54484 m .80563 .53665 L .81782 .55171 L p .649 .759 .929 r
F P
0 g
s
.81782 .55171 m .80563 .53665 L .80352 .51085 L p .976 .678 .372 r
F P
0 g
s
.69426 .53093 m .69298 .50509 L .66498 .5134 L p .556 .341 .544 r
F P
0 g
s
.66498 .5134 m .66605 .53918 L .69426 .53093 L p .556 .341 .544 r
F P
0 g
s
.66498 .5134 m .65141 .49799 L .65045 .47249 L p .972 .685 .422 r
F P
0 g
s
.66498 .5134 m .65141 .49799 L .65045 .47249 L p .972 .685 .422 r
F P
0 g
s
.69298 .50509 m .66498 .5134 L .65141 .49799 L p .652 .756 .926 r
F P
0 g
s
.69426 .53093 m .69298 .50509 L .66498 .5134 L p .556 .341 .544 r
F P
0 g
s
.66498 .5134 m .66605 .53918 L .69426 .53093 L p .556 .341 .544 r
F P
0 g
s
.6235 .50637 m .65141 .49799 L .66498 .5134 L p .652 .756 .926 r
F P
0 g
s
.65141 .49799 m .66498 .5134 L .66605 .53918 L p .972 .685 .422 r
F P
0 g
s
.69298 .50509 m .66498 .5134 L .65141 .49799 L p .652 .756 .926 r
F P
0 g
s
.53951 .49215 m .53939 .46659 L .51215 .47509 L p .547 .329 .535 r
F P
0 g
s
.51215 .47509 m .51206 .50058 L .53951 .49215 L p .547 .329 .535 r
F P
0 g
s
.51215 .47509 m .49719 .45934 L .49739 .43412 L p .964 .688 .461 r
F P
0 g
s
.51215 .47509 m .49719 .45934 L .49739 .43412 L p .964 .688 .461 r
F P
0 g
s
.53939 .46659 m .51215 .47509 L .49719 .45934 L p .654 .754 .923 r
F P
0 g
s
.53951 .49215 m .53939 .46659 L .51215 .47509 L p .547 .329 .535 r
F P
0 g
s
.51215 .47509 m .51206 .50058 L .53951 .49215 L p .547 .329 .535 r
F P
0 g
s
.47004 .46791 m .49719 .45934 L .51215 .47509 L p .654 .754 .923 r
F P
0 g
s
.47004 .46791 m .49719 .45934 L .51215 .47509 L p .654 .754 .923 r
F P
0 g
s
.49719 .45934 m .51215 .47509 L .51206 .50058 L p .964 .688 .461 r
F P
0 g
s
.53939 .46659 m .51215 .47509 L .49719 .45934 L p .654 .754 .923 r
F P
0 g
s
.49719 .45934 m .51215 .47509 L .51206 .50058 L p .964 .688 .461 r
F P
0 g
s
.38475 .45336 m .38581 .4281 L .35932 .43678 L p .537 .315 .524 r
F P
0 g
s
.35932 .43678 m .35807 .46198 L .38475 .45336 L p .537 .315 .524 r
F P
0 g
s
.35932 .43678 m .34296 .42068 L .34433 .39576 L p .954 .688 .492 r
F P
0 g
s
.35932 .43678 m .34296 .42068 L .34433 .39576 L p .954 .688 .492 r
F P
0 g
s
.38581 .4281 m .35932 .43678 L .34296 .42068 L p .656 .751 .92 r
F P
0 g
s
.38475 .45336 m .38581 .4281 L .35932 .43678 L p .537 .315 .524 r
F P
0 g
s
.35932 .43678 m .35807 .46198 L .38475 .45336 L p .537 .315 .524 r
F P
0 g
s
.31657 .42944 m .34296 .42068 L .35932 .43678 L p .656 .751 .92 r
F P
0 g
s
.34296 .42068 m .35932 .43678 L .35807 .46198 L p .954 .688 .492 r
F P
0 g
s
.38581 .4281 m .35932 .43678 L .34296 .42068 L p .656 .751 .92 r
F P
0 g
s
.20649 .39848 m .18874 .38203 L .19127 .35739 L p .943 .686 .517 r
F P
0 g
s
.20649 .39848 m .18874 .38203 L .19127 .35739 L p .943 .686 .517 r
F P
0 g
s
.23223 .3896 m .20649 .39848 L .18874 .38203 L p .658 .749 .917 r
F P
0 g
s
.23 .41457 m .23223 .3896 L .20649 .39848 L p .526 .299 .513 r
F P
0 g
s
.20649 .39848 m .20408 .42339 L .23 .41457 L p .526 .299 .513 r
F P
0 g
s
.1631 .39097 m .18874 .38203 L .20649 .39848 L p .658 .749 .917 r
F P
0 g
s
.18874 .38203 m .20649 .39848 L .20408 .42339 L p .943 .686 .517 r
F P
0 g
s
.23223 .3896 m .20649 .39848 L .18874 .38203 L p .658 .749 .917 r
F P
0 g
s
.77479 .42877 m .80345 .42001 L .81566 .43612 L p .656 .751 .92 r
F P
0 g
s
.80345 .42001 m .81566 .43612 L .81786 .46132 L p .976 .675 .358 r
F P
0 g
s
.69076 .38892 m .66277 .3978 L .64917 .38133 L p .658 .749 .917 r
F P
0 g
s
.69203 .41389 m .69076 .38892 L .66277 .3978 L p .55 .333 .538 r
F P
0 g
s
.66277 .3978 m .66382 .42271 L .69203 .41389 L p .55 .333 .538 r
F P
0 g
s
.62127 .39029 m .64917 .38133 L .66277 .3978 L p .658 .749 .917 r
F P
0 g
s
.64917 .38133 m .66277 .3978 L .66382 .42271 L p .974 .684 .41 r
F P
0 g
s
.64917 .38133 m .66277 .3978 L .66382 .42271 L p .974 .684 .41 r
F P
0 g
s
.53722 .37508 m .53712 .35041 L .50988 .35948 L p .541 .319 .528 r
F P
0 g
s
.50988 .35948 m .50977 .3841 L .53722 .37508 L p .541 .319 .528 r
F P
0 g
s
.53712 .35041 m .50988 .35948 L .49489 .34266 L p .66 .747 .915 r
F P
0 g
s
.53722 .37508 m .53712 .35041 L .50988 .35948 L p .541 .319 .528 r
F P
0 g
s
.50988 .35948 m .50977 .3841 L .53722 .37508 L p .541 .319 .528 r
F P
0 g
s
.46774 .35181 m .49489 .34266 L .50988 .35948 L p .66 .747 .915 r
F P
0 g
s
.49489 .34266 m .50988 .35948 L .50977 .3841 L p .966 .687 .452 r
F P
0 g
s
.49489 .34266 m .50988 .35948 L .50977 .3841 L p .966 .687 .452 r
F P
0 g
s
.76436 .52966 m .76255 .5038 L .7342 .51213 L p .558 .345 .547 r
F P
0 g
s
.7342 .51213 m .73579 .53792 L .76436 .52966 L p .558 .345 .547 r
F P
0 g
s
.7342 .51213 m .72124 .4967 L .71976 .47118 L p .975 .682 .398 r
F P
0 g
s
.76255 .5038 m .7342 .51213 L .72124 .4967 L p .652 .756 .926 r
F P
0 g
s
.76436 .52966 m .76255 .5038 L .7342 .51213 L p .558 .345 .547 r
F P
0 g
s
.7342 .51213 m .73579 .53792 L .76436 .52966 L p .558 .345 .547 r
F P
0 g
s
.69298 .50509 m .72124 .4967 L .7342 .51213 L p .652 .756 .926 r
F P
0 g
s
.69298 .50509 m .72124 .4967 L .7342 .51213 L p .652 .756 .926 r
F P
0 g
s
.72124 .4967 m .7342 .51213 L .73579 .53792 L p .975 .682 .398 r
F P
0 g
s
.72124 .4967 m .7342 .51213 L .73579 .53792 L p .975 .682 .398 r
F P
0 g
s
.60949 .49084 m .60885 .46528 L .58125 .47379 L p .55 .333 .538 r
F P
0 g
s
.58125 .47379 m .58168 .49929 L .60949 .49084 L p .55 .333 .538 r
F P
0 g
s
.58125 .47379 m .5669 .45801 L .56659 .43279 L p .969 .687 .442 r
F P
0 g
s
.58125 .47379 m .5669 .45801 L .56659 .43279 L p .969 .687 .442 r
F P
0 g
s
.60885 .46528 m .58125 .47379 L .5669 .45801 L p .654 .754 .923 r
F P
0 g
s
.60949 .49084 m .60885 .46528 L .58125 .47379 L p .55 .333 .538 r
F P
0 g
s
.58125 .47379 m .58168 .49929 L .60949 .49084 L p .55 .333 .538 r
F P
0 g
s
.53939 .46659 m .5669 .45801 L .58125 .47379 L p .654 .754 .923 r
F P
0 g
s
.53939 .46659 m .5669 .45801 L .58125 .47379 L p .654 .754 .923 r
F P
0 g
s
.5669 .45801 m .58125 .47379 L .58168 .49929 L p .969 .687 .442 r
F P
0 g
s
.60885 .46528 m .58125 .47379 L .5669 .45801 L p .654 .754 .923 r
F P
0 g
s
.5669 .45801 m .58125 .47379 L .58168 .49929 L p .969 .687 .442 r
F P
0 g
s
.4283 .43545 m .41256 .41933 L .41341 .39439 L p .959 .688 .477 r
F P
0 g
s
.45515 .42675 m .4283 .43545 L .41256 .41933 L p .656 .751 .92 r
F P
0 g
s
.38581 .4281 m .41256 .41933 L .4283 .43545 L p .656 .751 .92 r
F P
0 g
s
.41256 .41933 m .4283 .43545 L .42757 .46066 L p .959 .688 .477 r
F P
0 g
s
.27536 .39712 m .25822 .38064 L .26023 .356 L p .949 .687 .505 r
F P
0 g
s
.30146 .38823 m .27536 .39712 L .25822 .38064 L p .658 .749 .917 r
F P
0 g
s
.45746 .54296 m .48457 .53475 L .49967 .54984 L p .649 .759 .929 r
F P
0 g
s
.49967 .54984 m .48457 .53475 L .48488 .50894 L p .962 .688 .469 r
F P
0 g
s
.37197 .52902 m .37312 .50316 L .34666 .51149 L p .541 .319 .528 r
F P
0 g
s
.34666 .51149 m .34532 .53728 L .37197 .52902 L p .541 .319 .528 r
F P
0 g
s
.34666 .51149 m .33018 .49605 L .33164 .47053 L p .952 .687 .499 r
F P
0 g
s
.34666 .51149 m .33018 .49605 L .33164 .47053 L p .952 .687 .499 r
F P
0 g
s
.37312 .50316 m .34666 .51149 L .33018 .49605 L p .652 .756 .926 r
F P
0 g
s
.37197 .52902 m .37312 .50316 L .34666 .51149 L p .541 .319 .528 r
F P
0 g
s
.34666 .51149 m .34532 .53728 L .37197 .52902 L p .541 .319 .528 r
F P
0 g
s
.30382 .50445 m .33018 .49605 L .34666 .51149 L p .652 .756 .926 r
F P
0 g
s
.33018 .49605 m .34666 .51149 L .34532 .53728 L p .952 .687 .499 r
F P
0 g
s
.37312 .50316 m .34666 .51149 L .33018 .49605 L p .652 .756 .926 r
F P
0 g
s
.76216 .41252 m .76036 .38754 L .73201 .39644 L p .553 .337 .541 r
F P
0 g
s
.73201 .39644 m .73358 .42136 L .76216 .41252 L p .553 .337 .541 r
F P
0 g
s
.76036 .38754 m .73201 .39644 L .71903 .37995 L p .658 .749 .917 r
F P
0 g
s
.76216 .41252 m .76036 .38754 L .73201 .39644 L p .553 .337 .541 r
F P
0 g
s
.73201 .39644 m .73358 .42136 L .76216 .41252 L p .553 .337 .541 r
F P
0 g
s
.69076 .38892 m .71903 .37995 L .73201 .39644 L p .658 .749 .917 r
F P
0 g
s
.71903 .37995 m .73201 .39644 L .73358 .42136 L p .976 .68 .386 r
F P
0 g
s
.71903 .37995 m .73201 .39644 L .73358 .42136 L p .976 .68 .386 r
F P
0 g
s
.60723 .37369 m .60661 .349 L .57901 .35809 L p .544 .324 .532 r
F P
0 g
s
.57901 .35809 m .57942 .38272 L .60723 .37369 L p .544 .324 .532 r
F P
0 g
s
.60661 .349 m .57901 .35809 L .56463 .34125 L p .66 .747 .915 r
F P
0 g
s
.60723 .37369 m .60661 .349 L .57901 .35809 L p .544 .324 .532 r
F P
0 g
s
.57901 .35809 m .57942 .38272 L .60723 .37369 L p .544 .324 .532 r
F P
0 g
s
.53712 .35041 m .56463 .34125 L .57901 .35809 L p .66 .747 .915 r
F P
0 g
s
.56463 .34125 m .57901 .35809 L .57942 .38272 L p .971 .686 .432 r
F P
0 g
s
.56463 .34125 m .57901 .35809 L .57942 .38272 L p .971 .686 .432 r
F P
0 g
s
.80352 .51085 m .79118 .4954 L .78918 .46987 L p .976 .678 .372 r
F P
0 g
s
.80352 .51085 m .79118 .4954 L .78918 .46987 L p .976 .678 .372 r
F P
0 g
s
.83223 .50252 m .80352 .51085 L .79118 .4954 L p .652 .756 .926 r
F P
0 g
s
.76255 .5038 m .79118 .4954 L .80352 .51085 L p .652 .756 .926 r
F P
0 g
s
.76255 .5038 m .79118 .4954 L .80352 .51085 L p .652 .756 .926 r
F P
0 g
s
.79118 .4954 m .80352 .51085 L .80563 .53665 L p .976 .678 .372 r
F P
0 g
s
.67959 .48953 m .67842 .46396 L .65045 .47249 L p .553 .337 .541 r
F P
0 g
s
.65045 .47249 m .65141 .49799 L .67959 .48953 L p .553 .337 .541 r
F P
0 g
s
.65045 .47249 m .63673 .45669 L .63588 .43145 L p .972 .685 .422 r
F P
0 g
s
.67842 .46396 m .65045 .47249 L .63673 .45669 L p .654 .754 .923 r
F P
0 g
s
.67959 .48953 m .67842 .46396 L .65045 .47249 L p .553 .337 .541 r
F P
0 g
s
.65045 .47249 m .65141 .49799 L .67959 .48953 L p .553 .337 .541 r
F P
0 g
s
.60885 .46528 m .63673 .45669 L .65045 .47249 L p .654 .754 .923 r
F P
0 g
s
.60885 .46528 m .63673 .45669 L .65045 .47249 L p .654 .754 .923 r
F P
0 g
s
.63673 .45669 m .65045 .47249 L .65141 .49799 L p .972 .685 .422 r
F P
0 g
s
.63673 .45669 m .65045 .47249 L .65141 .49799 L p .972 .685 .422 r
F P
0 g
s
.5246 .45069 m .5246 .42541 L .49739 .43412 L p .544 .324 .532 r
F P
0 g
s
.49739 .43412 m .49719 .45934 L .5246 .45069 L p .544 .324 .532 r
F P
0 g
s
.49739 .43412 m .48227 .41797 L .48259 .39303 L p .964 .688 .461 r
F P
0 g
s
.49739 .43412 m .48227 .41797 L .48259 .39303 L p .964 .688 .461 r
F P
0 g
s
.5246 .42541 m .49739 .43412 L .48227 .41797 L p .656 .751 .92 r
F P
0 g
s
.5246 .45069 m .5246 .42541 L .49739 .43412 L p .544 .324 .532 r
F P
0 g
s
.49739 .43412 m .49719 .45934 L .5246 .45069 L p .544 .324 .532 r
F P
0 g
s
.45515 .42675 m .48227 .41797 L .49739 .43412 L p .656 .751 .92 r
F P
0 g
s
.45515 .42675 m .48227 .41797 L .49739 .43412 L p .656 .751 .92 r
F P
0 g
s
.48227 .41797 m .49739 .43412 L .49719 .45934 L p .964 .688 .461 r
F P
0 g
s
.5246 .42541 m .49739 .43412 L .48227 .41797 L p .656 .751 .92 r
F P
0 g
s
.48227 .41797 m .49739 .43412 L .49719 .45934 L p .964 .688 .461 r
F P
0 g
s
.36962 .41184 m .37079 .38686 L .34433 .39576 L p .534 .309 .521 r
F P
0 g
s
.34433 .39576 m .34296 .42068 L .36962 .41184 L p .534 .309 .521 r
F P
0 g
s
.34433 .39576 m .32781 .37926 L .3293 .3546 L p .954 .688 .492 r
F P
0 g
s
.37079 .38686 m .34433 .39576 L .32781 .37926 L p .658 .749 .917 r
F P
0 g
s
.36962 .41184 m .37079 .38686 L .34433 .39576 L p .534 .309 .521 r
F P
0 g
s
.34433 .39576 m .34296 .42068 L .36962 .41184 L p .534 .309 .521 r
F P
0 g
s
.30146 .38823 m .32781 .37926 L .34433 .39576 L p .658 .749 .917 r
F P
0 g
s
.30146 .38823 m .32781 .37926 L .34433 .39576 L p .658 .749 .917 r
F P
0 g
s
.32781 .37926 m .34433 .39576 L .34296 .42068 L p .954 .688 .492 r
F P
0 g
s
.32781 .37926 m .34433 .39576 L .34296 .42068 L p .954 .688 .492 r
F P
0 g
s
.21463 .37299 m .21697 .3483 L .19127 .35739 L p .522 .293 .509 r
F P
0 g
s
.19127 .35739 m .18874 .38203 L .21463 .37299 L p .522 .293 .509 r
F P
0 g
s
.21697 .3483 m .19127 .35739 L .17336 .34054 L p .66 .747 .915 r
F P
0 g
s
.21463 .37299 m .21697 .3483 L .19127 .35739 L p .522 .293 .509 r
F P
0 g
s
.19127 .35739 m .18874 .38203 L .21463 .37299 L p .522 .293 .509 r
F P
0 g
s
.17336 .34054 m .19127 .35739 L .18874 .38203 L p .943 .686 .517 r
F P
0 g
s
.41572 .51021 m .39985 .49475 L .40079 .46922 L p .957 .688 .485 r
F P
0 g
s
.41572 .51021 m .39985 .49475 L .40079 .46922 L p .957 .688 .485 r
F P
0 g
s
.44254 .50187 m .41572 .51021 L .39985 .49475 L p .652 .756 .926 r
F P
0 g
s
.44191 .52774 m .44254 .50187 L .41572 .51021 L p .544 .324 .532 r
F P
0 g
s
.41572 .51021 m .41489 .53602 L .44191 .52774 L p .544 .324 .532 r
F P
0 g
s
.37312 .50316 m .39985 .49475 L .41572 .51021 L p .652 .756 .926 r
F P
0 g
s
.37312 .50316 m .39985 .49475 L .41572 .51021 L p .652 .756 .926 r
F P
0 g
s
.39985 .49475 m .41572 .51021 L .41489 .53602 L p .957 .688 .485 r
F P
0 g
s
.44254 .50187 m .41572 .51021 L .39985 .49475 L p .652 .756 .926 r
F P
0 g
s
.39985 .49475 m .41572 .51021 L .41489 .53602 L p .957 .688 .485 r
F P
0 g
s
.6762 .3476 m .64823 .35669 L .63448 .33983 L p .66 .747 .915 r
F P
0 g
s
.67735 .37229 m .6762 .3476 L .64823 .35669 L p .547 .329 .535 r
F P
0 g
s
.64823 .35669 m .64917 .38133 L .67735 .37229 L p .547 .329 .535 r
F P
0 g
s
.60661 .349 m .63448 .33983 L .64823 .35669 L p .66 .747 .915 r
F P
0 g
s
.63448 .33983 m .64823 .35669 L .64917 .38133 L p .974 .684 .41 r
F P
0 g
s
.63448 .33983 m .64823 .35669 L .64917 .38133 L p .974 .684 .41 r
F P
0 g
s
.71976 .47118 m .70666 .45536 L .70528 .43011 L p .975 .682 .398 r
F P
0 g
s
.71976 .47118 m .70666 .45536 L .70528 .43011 L p .975 .682 .398 r
F P
0 g
s
.74809 .46264 m .71976 .47118 L .70666 .45536 L p .654 .754 .923 r
F P
0 g
s
.74979 .48822 m .74809 .46264 L .71976 .47118 L p .556 .341 .544 r
F P
0 g
s
.71976 .47118 m .72124 .4967 L .74979 .48822 L p .556 .341 .544 r
F P
0 g
s
.67842 .46396 m .70666 .45536 L .71976 .47118 L p .654 .754 .923 r
F P
0 g
s
.70666 .45536 m .71976 .47118 L .72124 .4967 L p .975 .682 .398 r
F P
0 g
s
.74809 .46264 m .71976 .47118 L .70666 .45536 L p .654 .754 .923 r
F P
0 g
s
.59469 .44935 m .59416 .42406 L .56659 .43279 L p .547 .329 .535 r
F P
0 g
s
.56659 .43279 m .5669 .45801 L .59469 .44935 L p .547 .329 .535 r
F P
0 g
s
.56659 .43279 m .55208 .41661 L .55188 .39166 L p .969 .687 .442 r
F P
0 g
s
.56659 .43279 m .55208 .41661 L .55188 .39166 L p .969 .687 .442 r
F P
0 g
s
.59416 .42406 m .56659 .43279 L .55208 .41661 L p .656 .751 .92 r
F P
0 g
s
.59469 .44935 m .59416 .42406 L .56659 .43279 L p .547 .329 .535 r
F P
0 g
s
.56659 .43279 m .5669 .45801 L .59469 .44935 L p .547 .329 .535 r
F P
0 g
s
.5246 .42541 m .55208 .41661 L .56659 .43279 L p .656 .751 .92 r
F P
0 g
s
.5246 .42541 m .55208 .41661 L .56659 .43279 L p .656 .751 .92 r
F P
0 g
s
.55208 .41661 m .56659 .43279 L .5669 .45801 L p .969 .687 .442 r
F P
0 g
s
.59416 .42406 m .56659 .43279 L .55208 .41661 L p .656 .751 .92 r
F P
0 g
s
.55208 .41661 m .56659 .43279 L .5669 .45801 L p .969 .687 .442 r
F P
0 g
s
.43958 .41047 m .44023 .38548 L .41341 .39439 L p .537 .315 .524 r
F P
0 g
s
.41341 .39439 m .41256 .41933 L .43958 .41047 L p .537 .315 .524 r
F P
0 g
s
.41341 .39439 m .39751 .37787 L .39847 .35321 L p .959 .688 .477 r
F P
0 g
s
.41341 .39439 m .39751 .37787 L .39847 .35321 L p .959 .688 .477 r
F P
0 g
s
.44023 .38548 m .41341 .39439 L .39751 .37787 L p .658 .749 .917 r
F P
0 g
s
.37079 .38686 m .39751 .37787 L .41341 .39439 L p .658 .749 .917 r
F P
0 g
s
.28448 .37159 m .2863 .3469 L .26023 .356 L p .526 .299 .513 r
F P
0 g
s
.26023 .356 m .25822 .38064 L .28448 .37159 L p .526 .299 .513 r
F P
0 g
s
.21697 .3483 m .24293 .33912 L .26023 .356 L p .66 .747 .915 r
F P
0 g
s
.24293 .33912 m .26023 .356 L .25822 .38064 L p .949 .687 .505 r
F P
0 g
s
.59641 .54044 m .62426 .53221 L .63811 .54734 L p .649 .759 .929 r
F P
0 g
s
.63811 .54734 m .62426 .53221 L .6235 .50637 L p .971 .686 .432 r
F P
0 g
s
.48488 .50894 m .46962 .49345 L .47004 .46791 L p .962 .688 .469 r
F P
0 g
s
.48488 .50894 m .46962 .49345 L .47004 .46791 L p .962 .688 .469 r
F P
0 g
s
.51206 .50058 m .48488 .50894 L .46962 .49345 L p .652 .756 .926 r
F P
0 g
s
.44254 .50187 m .46962 .49345 L .48488 .50894 L p .652 .756 .926 r
F P
0 g
s
.44254 .50187 m .46962 .49345 L .48488 .50894 L p .652 .756 .926 r
F P
0 g
s
.46962 .49345 m .48488 .50894 L .48457 .53475 L p .962 .688 .469 r
F P
0 g
s
.3568 .48757 m .35807 .46198 L .33164 .47053 L p .537 .315 .524 r
F P
0 g
s
.33164 .47053 m .33018 .49605 L .3568 .48757 L p .537 .315 .524 r
F P
0 g
s
.33164 .47053 m .31499 .45469 L .31657 .42944 L p .952 .687 .499 r
F P
0 g
s
.35807 .46198 m .33164 .47053 L .31499 .45469 L p .654 .754 .923 r
F P
0 g
s
.3568 .48757 m .35807 .46198 L .33164 .47053 L p .537 .315 .524 r
F P
0 g
s
.33164 .47053 m .33018 .49605 L .3568 .48757 L p .537 .315 .524 r
F P
0 g
s
.28867 .4633 m .31499 .45469 L .33164 .47053 L p .654 .754 .923 r
F P
0 g
s
.28867 .4633 m .31499 .45469 L .33164 .47053 L p .654 .754 .923 r
F P
0 g
s
.31499 .45469 m .33164 .47053 L .33018 .49605 L p .952 .687 .499 r
F P
0 g
s
.31499 .45469 m .33164 .47053 L .33018 .49605 L p .952 .687 .499 r
F P
0 g
s
.8201 .48691 m .81786 .46132 L .78918 .46987 L p .558 .345 .547 r
F P
0 g
s
.78918 .46987 m .79118 .4954 L .8201 .48691 L p .558 .345 .547 r
F P
0 g
s
.78918 .46987 m .77669 .45402 L .77479 .42877 L p .976 .678 .372 r
F P
0 g
s
.81786 .46132 m .78918 .46987 L .77669 .45402 L p .654 .754 .923 r
F P
0 g
s
.8201 .48691 m .81786 .46132 L .78918 .46987 L p .558 .345 .547 r
F P
0 g
s
.78918 .46987 m .79118 .4954 L .8201 .48691 L p .558 .345 .547 r
F P
0 g
s
.74809 .46264 m .77669 .45402 L .78918 .46987 L p .654 .754 .923 r
F P
0 g
s
.77669 .45402 m .78918 .46987 L .79118 .4954 L p .976 .678 .372 r
F P
0 g
s
.81786 .46132 m .78918 .46987 L .77669 .45402 L p .654 .754 .923 r
F P
0 g
s
.77669 .45402 m .78918 .46987 L .79118 .4954 L p .976 .678 .372 r
F P
0 g
s
.63588 .43145 m .622 .41525 L .62127 .39029 L p .972 .685 .422 r
F P
0 g
s
.63588 .43145 m .622 .41525 L .62127 .39029 L p .972 .685 .422 r
F P
0 g
s
.66382 .42271 m .63588 .43145 L .622 .41525 L p .656 .751 .92 r
F P
0 g
s
.59416 .42406 m .622 .41525 L .63588 .43145 L p .656 .751 .92 r
F P
0 g
s
.59416 .42406 m .622 .41525 L .63588 .43145 L p .656 .751 .92 r
F P
0 g
s
.622 .41525 m .63588 .43145 L .63673 .45669 L p .972 .685 .422 r
F P
0 g
s
.50966 .4091 m .50977 .3841 L .48259 .39303 L p .541 .319 .528 r
F P
0 g
s
.48259 .39303 m .48227 .41797 L .50966 .4091 L p .541 .319 .528 r
F P
0 g
s
.48259 .39303 m .46731 .37648 L .46774 .35181 L p .964 .688 .461 r
F P
0 g
s
.50977 .3841 m .48259 .39303 L .46731 .37648 L p .658 .749 .917 r
F P
0 g
s
.50966 .4091 m .50977 .3841 L .48259 .39303 L p .541 .319 .528 r
F P
0 g
s
.48259 .39303 m .48227 .41797 L .50966 .4091 L p .541 .319 .528 r
F P
0 g
s
.44023 .38548 m .46731 .37648 L .48259 .39303 L p .658 .749 .917 r
F P
0 g
s
.46731 .37648 m .48259 .39303 L .48227 .41797 L p .964 .688 .461 r
F P
0 g
s
.50977 .3841 m .48259 .39303 L .46731 .37648 L p .658 .749 .917 r
F P
0 g
s
.46731 .37648 m .48259 .39303 L .48227 .41797 L p .964 .688 .461 r
F P
0 g
s
.35572 .34549 m .3293 .3546 L .31262 .3377 L p .66 .747 .915 r
F P
0 g
s
.35443 .37019 m .35572 .34549 L .3293 .3546 L p .53 .304 .517 r
F P
0 g
s
.3293 .3546 m .32781 .37926 L .35443 .37019 L p .53 .304 .517 r
F P
0 g
s
.31262 .3377 m .3293 .3546 L .32781 .37926 L p .954 .688 .492 r
F P
0 g
s
.70749 .54609 m .69426 .53093 L .69298 .50509 L p .974 .684 .41 r
F P
0 g
s
.70749 .54609 m .69426 .53093 L .69298 .50509 L p .974 .684 .41 r
F P
0 g
s
.73579 .53792 m .70749 .54609 L .69426 .53093 L p .649 .759 .929 r
F P
0 g
s
.66605 .53918 m .69426 .53093 L .70749 .54609 L p .649 .759 .929 r
F P
0 g
s
.55414 .50766 m .53951 .49215 L .53939 .46659 L p .966 .687 .452 r
F P
0 g
s
.55414 .50766 m .53951 .49215 L .53939 .46659 L p .966 .687 .452 r
F P
0 g
s
.58168 .49929 m .55414 .50766 L .53951 .49215 L p .652 .756 .926 r
F P
0 g
s
.58212 .52518 m .58168 .49929 L .55414 .50766 L p .55 .333 .538 r
F P
0 g
s
.55414 .50766 m .55436 .53348 L .58212 .52518 L p .55 .333 .538 r
F P
0 g
s
.51206 .50058 m .53951 .49215 L .55414 .50766 L p .652 .756 .926 r
F P
0 g
s
.51206 .50058 m .53951 .49215 L .55414 .50766 L p .652 .756 .926 r
F P
0 g
s
.53951 .49215 m .55414 .50766 L .55436 .53348 L p .966 .687 .452 r
F P
0 g
s
.58168 .49929 m .55414 .50766 L .53951 .49215 L p .652 .756 .926 r
F P
0 g
s
.53951 .49215 m .55414 .50766 L .55436 .53348 L p .966 .687 .452 r
F P
0 g
s
.42683 .48626 m .42757 .46066 L .40079 .46922 L p .541 .319 .528 r
F P
0 g
s
.40079 .46922 m .39985 .49475 L .42683 .48626 L p .541 .319 .528 r
F P
0 g
s
.40079 .46922 m .38475 .45336 L .38581 .4281 L p .957 .688 .485 r
F P
0 g
s
.40079 .46922 m .38475 .45336 L .38581 .4281 L p .957 .688 .485 r
F P
0 g
s
.42757 .46066 m .40079 .46922 L .38475 .45336 L p .654 .754 .923 r
F P
0 g
s
.35807 .46198 m .38475 .45336 L .40079 .46922 L p .654 .754 .923 r
F P
0 g
s
.81569 .34478 m .787 .35391 L .7745 .33699 L p .66 .747 .915 r
F P
0 g
s
.81791 .36949 m .81569 .34478 L .787 .35391 L p .553 .337 .541 r
F P
0 g
s
.787 .35391 m .789 .37856 L .81791 .36949 L p .553 .337 .541 r
F P
0 g
s
.74589 .34619 m .7745 .33699 L .787 .35391 L p .66 .747 .915 r
F P
0 g
s
.7745 .33699 m .787 .35391 L .789 .37856 L p .976 .675 .358 r
F P
0 g
s
.7745 .33699 m .787 .35391 L .789 .37856 L p .976 .675 .358 r
F P
0 g
s
.73518 .44666 m .73358 .42136 L .70528 .43011 L p .553 .337 .541 r
F P
0 g
s
.70528 .43011 m .70666 .45536 L .73518 .44666 L p .553 .337 .541 r
F P
0 g
s
.70528 .43011 m .69203 .41389 L .69076 .38892 L p .975 .682 .398 r
F P
0 g
s
.73358 .42136 m .70528 .43011 L .69203 .41389 L p .656 .751 .92 r
F P
0 g
s
.73518 .44666 m .73358 .42136 L .70528 .43011 L p .553 .337 .541 r
F P
0 g
s
.70528 .43011 m .70666 .45536 L .73518 .44666 L p .553 .337 .541 r
F P
0 g
s
.66382 .42271 m .69203 .41389 L .70528 .43011 L p .656 .751 .92 r
F P
0 g
s
.69203 .41389 m .70528 .43011 L .70666 .45536 L p .975 .682 .398 r
F P
0 g
s
.73358 .42136 m .70528 .43011 L .69203 .41389 L p .656 .751 .92 r
F P
0 g
s
.69203 .41389 m .70528 .43011 L .70666 .45536 L p .975 .682 .398 r
F P
0 g
s
.57984 .40773 m .57942 .38272 L .55188 .39166 L p .544 .324 .532 r
F P
0 g
s
.55188 .39166 m .55208 .41661 L .57984 .40773 L p .544 .324 .532 r
F P
0 g
s
.55188 .39166 m .53722 .37508 L .53712 .35041 L p .969 .687 .442 r
F P
0 g
s
.55188 .39166 m .53722 .37508 L .53712 .35041 L p .969 .687 .442 r
F P
0 g
s
.57942 .38272 m .55188 .39166 L .53722 .37508 L p .658 .749 .917 r
F P
0 g
s
.57984 .40773 m .57942 .38272 L .55188 .39166 L p .544 .324 .532 r
F P
0 g
s
.55188 .39166 m .55208 .41661 L .57984 .40773 L p .544 .324 .532 r
F P
0 g
s
.50977 .3841 m .53722 .37508 L .55188 .39166 L p .658 .749 .917 r
F P
0 g
s
.50977 .3841 m .53722 .37508 L .55188 .39166 L p .658 .749 .917 r
F P
0 g
s
.53722 .37508 m .55188 .39166 L .55208 .41661 L p .969 .687 .442 r
F P
0 g
s
.57942 .38272 m .55188 .39166 L .53722 .37508 L p .658 .749 .917 r
F P
0 g
s
.53722 .37508 m .55188 .39166 L .55208 .41661 L p .969 .687 .442 r
F P
0 g
s
.42449 .36879 m .42525 .34408 L .39847 .35321 L p .534 .309 .521 r
F P
0 g
s
.39847 .35321 m .39751 .37787 L .42449 .36879 L p .534 .309 .521 r
F P
0 g
s
.42525 .34408 m .39847 .35321 L .38241 .33628 L p .66 .747 .915 r
F P
0 g
s
.42449 .36879 m .42525 .34408 L .39847 .35321 L p .534 .309 .521 r
F P
0 g
s
.39847 .35321 m .39751 .37787 L .42449 .36879 L p .534 .309 .521 r
F P
0 g
s
.35572 .34549 m .38241 .33628 L .39847 .35321 L p .66 .747 .915 r
F P
0 g
s
.38241 .33628 m .39847 .35321 L .39751 .37787 L p .959 .688 .477 r
F P
0 g
s
.38241 .33628 m .39847 .35321 L .39751 .37787 L p .959 .688 .477 r
F P
0 g
s
.77697 .54484 m .76436 .52966 L .76255 .5038 L p .976 .68 .386 r
F P
0 g
s
.77697 .54484 m .76436 .52966 L .76255 .5038 L p .976 .68 .386 r
F P
0 g
s
.80563 .53665 m .77697 .54484 L .76436 .52966 L p .649 .759 .929 r
F P
0 g
s
.73579 .53792 m .76436 .52966 L .77697 .54484 L p .649 .759 .929 r
F P
0 g
s
.6235 .50637 m .60949 .49084 L .60885 .46528 L p .971 .686 .432 r
F P
0 g
s
.6235 .50637 m .60949 .49084 L .60885 .46528 L p .971 .686 .432 r
F P
0 g
s
.65141 .49799 m .6235 .50637 L .60949 .49084 L p .652 .756 .926 r
F P
0 g
s
.65238 .52389 m .65141 .49799 L .6235 .50637 L p .553 .337 .541 r
F P
0 g
s
.6235 .50637 m .62426 .53221 L .65238 .52389 L p .553 .337 .541 r
F P
0 g
s
.58168 .49929 m .60949 .49084 L .6235 .50637 L p .652 .756 .926 r
F P
0 g
s
.60949 .49084 m .6235 .50637 L .62426 .53221 L p .971 .686 .432 r
F P
0 g
s
.65141 .49799 m .6235 .50637 L .60949 .49084 L p .652 .756 .926 r
F P
0 g
s
.49698 .48494 m .49719 .45934 L .47004 .46791 L p .544 .324 .532 r
F P
0 g
s
.47004 .46791 m .46962 .49345 L .49698 .48494 L p .544 .324 .532 r
F P
0 g
s
.47004 .46791 m .45463 .45202 L .45515 .42675 L p .962 .688 .469 r
F P
0 g
s
.49719 .45934 m .47004 .46791 L .45463 .45202 L p .654 .754 .923 r
F P
0 g
s
.49698 .48494 m .49719 .45934 L .47004 .46791 L p .544 .324 .532 r
F P
0 g
s
.47004 .46791 m .46962 .49345 L .49698 .48494 L p .544 .324 .532 r
F P
0 g
s
.42757 .46066 m .45463 .45202 L .47004 .46791 L p .654 .754 .923 r
F P
0 g
s
.45463 .45202 m .47004 .46791 L .46962 .49345 L p .962 .688 .469 r
F P
0 g
s
.49719 .45934 m .47004 .46791 L .45463 .45202 L p .654 .754 .923 r
F P
0 g
s
.45463 .45202 m .47004 .46791 L .46962 .49345 L p .962 .688 .469 r
F P
0 g
s
.31657 .42944 m .29976 .4132 L .30146 .38823 L p .952 .687 .499 r
F P
0 g
s
.34296 .42068 m .31657 .42944 L .29976 .4132 L p .656 .751 .92 r
F P
0 g
s
.27347 .42204 m .29976 .4132 L .31657 .42944 L p .656 .751 .92 r
F P
0 g
s
.29976 .4132 m .31657 .42944 L .31499 .45469 L p .952 .687 .499 r
F P
0 g
s
.38814 .54421 m .37197 .52902 L .37312 .50316 L p .954 .688 .492 r
F P
0 g
s
.38814 .54421 m .37197 .52902 L .37312 .50316 L p .954 .688 .492 r
F P
0 g
s
.41489 .53602 m .38814 .54421 L .37197 .52902 L p .649 .759 .929 r
F P
0 g
s
.34532 .53728 m .37197 .52902 L .38814 .54421 L p .649 .759 .929 r
F P
0 g
s
.80558 .44532 m .80345 .42001 L .77479 .42877 L p .556 .341 .544 r
F P
0 g
s
.77479 .42877 m .77669 .45402 L .80558 .44532 L p .556 .341 .544 r
F P
0 g
s
.77479 .42877 m .76216 .41252 L .76036 .38754 L p .976 .678 .372 r
F P
0 g
s
.80345 .42001 m .77479 .42877 L .76216 .41252 L p .656 .751 .92 r
F P
0 g
s
.80558 .44532 m .80345 .42001 L .77479 .42877 L p .556 .341 .544 r
F P
0 g
s
.77479 .42877 m .77669 .45402 L .80558 .44532 L p .556 .341 .544 r
F P
0 g
s
.73358 .42136 m .76216 .41252 L .77479 .42877 L p .656 .751 .92 r
F P
0 g
s
.76216 .41252 m .77479 .42877 L .77669 .45402 L p .976 .678 .372 r
F P
0 g
s
.65012 .40635 m .64917 .38133 L .62127 .39029 L p .547 .329 .535 r
F P
0 g
s
.62127 .39029 m .622 .41525 L .65012 .40635 L p .547 .329 .535 r
F P
0 g
s
.62127 .39029 m .60723 .37369 L .60661 .349 L p .972 .685 .422 r
F P
0 g
s
.62127 .39029 m .60723 .37369 L .60661 .349 L p .972 .685 .422 r
F P
0 g
s
.64917 .38133 m .62127 .39029 L .60723 .37369 L p .658 .749 .917 r
F P
0 g
s
.65012 .40635 m .64917 .38133 L .62127 .39029 L p .547 .329 .535 r
F P
0 g
s
.62127 .39029 m .622 .41525 L .65012 .40635 L p .547 .329 .535 r
F P
0 g
s
.57942 .38272 m .60723 .37369 L .62127 .39029 L p .658 .749 .917 r
F P
0 g
s
.57942 .38272 m .60723 .37369 L .62127 .39029 L p .658 .749 .917 r
F P
0 g
s
.60723 .37369 m .62127 .39029 L .622 .41525 L p .972 .685 .422 r
F P
0 g
s
.64917 .38133 m .62127 .39029 L .60723 .37369 L p .658 .749 .917 r
F P
0 g
s
.60723 .37369 m .62127 .39029 L .622 .41525 L p .972 .685 .422 r
F P
0 g
s
.49466 .36739 m .49489 .34266 L .46774 .35181 L p .537 .315 .524 r
F P
0 g
s
.46774 .35181 m .46731 .37648 L .49466 .36739 L p .537 .315 .524 r
F P
0 g
s
.42525 .34408 m .4523 .33486 L .46774 .35181 L p .66 .747 .915 r
F P
0 g
s
.4523 .33486 m .46774 .35181 L .46731 .37648 L p .964 .688 .461 r
F P
0 g
s
.72275 .52261 m .72124 .4967 L .69298 .50509 L p .556 .341 .544 r
F P
0 g
s
.69298 .50509 m .69426 .53093 L .72275 .52261 L p .556 .341 .544 r
F P
0 g
s
.69298 .50509 m .67959 .48953 L .67842 .46396 L p .974 .684 .41 r
F P
0 g
s
.72124 .4967 m .69298 .50509 L .67959 .48953 L p .652 .756 .926 r
F P
0 g
s
.72275 .52261 m .72124 .4967 L .69298 .50509 L p .556 .341 .544 r
F P
0 g
s
.69298 .50509 m .69426 .53093 L .72275 .52261 L p .556 .341 .544 r
F P
0 g
s
.65141 .49799 m .67959 .48953 L .69298 .50509 L p .652 .756 .926 r
F P
0 g
s
.65141 .49799 m .67959 .48953 L .69298 .50509 L p .652 .756 .926 r
F P
0 g
s
.67959 .48953 m .69298 .50509 L .69426 .53093 L p .974 .684 .41 r
F P
0 g
s
.67959 .48953 m .69298 .50509 L .69426 .53093 L p .974 .684 .41 r
F P
0 g
s
.56723 .48363 m .5669 .45801 L .53939 .46659 L p .547 .329 .535 r
F P
0 g
s
.53939 .46659 m .53951 .49215 L .56723 .48363 L p .547 .329 .535 r
F P
0 g
s
.53939 .46659 m .5246 .45069 L .5246 .42541 L p .966 .687 .452 r
F P
0 g
s
.53939 .46659 m .5246 .45069 L .5246 .42541 L p .966 .687 .452 r
F P
0 g
s
.5669 .45801 m .53939 .46659 L .5246 .45069 L p .654 .754 .923 r
F P
0 g
s
.56723 .48363 m .5669 .45801 L .53939 .46659 L p .547 .329 .535 r
F P
0 g
s
.53939 .46659 m .53951 .49215 L .56723 .48363 L p .547 .329 .535 r
F P
0 g
s
.49719 .45934 m .5246 .45069 L .53939 .46659 L p .654 .754 .923 r
F P
0 g
s
.49719 .45934 m .5246 .45069 L .53939 .46659 L p .654 .754 .923 r
F P
0 g
s
.5246 .45069 m .53939 .46659 L .53951 .49215 L p .966 .687 .452 r
F P
0 g
s
.5669 .45801 m .53939 .46659 L .5246 .45069 L p .654 .754 .923 r
F P
0 g
s
.5246 .45069 m .53939 .46659 L .53951 .49215 L p .966 .687 .452 r
F P
0 g
s
.41171 .44464 m .41256 .41933 L .38581 .4281 L p .537 .315 .524 r
F P
0 g
s
.38581 .4281 m .38475 .45336 L .41171 .44464 L p .537 .315 .524 r
F P
0 g
s
.38581 .4281 m .36962 .41184 L .37079 .38686 L p .957 .688 .485 r
F P
0 g
s
.41256 .41933 m .38581 .4281 L .36962 .41184 L p .656 .751 .92 r
F P
0 g
s
.41171 .44464 m .41256 .41933 L .38581 .4281 L p .537 .315 .524 r
F P
0 g
s
.38581 .4281 m .38475 .45336 L .41171 .44464 L p .537 .315 .524 r
F P
0 g
s
.34296 .42068 m .36962 .41184 L .38581 .4281 L p .656 .751 .92 r
F P
0 g
s
.34296 .42068 m .36962 .41184 L .38581 .4281 L p .656 .751 .92 r
F P
0 g
s
.36962 .41184 m .38581 .4281 L .38475 .45336 L p .957 .688 .485 r
F P
0 g
s
.36962 .41184 m .38581 .4281 L .38475 .45336 L p .957 .688 .485 r
F P
0 g
s
.23223 .3896 m .21463 .37299 L .21697 .3483 L p .946 .686 .511 r
F P
0 g
s
.23223 .3896 m .21463 .37299 L .21697 .3483 L p .946 .686 .511 r
F P
0 g
s
.25822 .38064 m .23223 .3896 L .21463 .37299 L p .658 .749 .917 r
F P
0 g
s
.25619 .40566 m .25822 .38064 L .23223 .3896 L p .526 .299 .513 r
F P
0 g
s
.23223 .3896 m .23 .41457 L .25619 .40566 L p .526 .299 .513 r
F P
0 g
s
.18874 .38203 m .21463 .37299 L .23223 .3896 L p .658 .749 .917 r
F P
0 g
s
.18874 .38203 m .21463 .37299 L .23223 .3896 L p .658 .749 .917 r
F P
0 g
s
.21463 .37299 m .23223 .3896 L .23 .41457 L p .946 .686 .511 r
F P
0 g
s
.25822 .38064 m .23223 .3896 L .21463 .37299 L p .658 .749 .917 r
F P
0 g
s
.21463 .37299 m .23223 .3896 L .23 .41457 L p .946 .686 .511 r
F P
0 g
s
.45746 .54296 m .44191 .52774 L .44254 .50187 L p .959 .688 .477 r
F P
0 g
s
.48457 .53475 m .45746 .54296 L .44191 .52774 L p .649 .759 .929 r
F P
0 g
s
.30382 .50445 m .28687 .48888 L .28867 .4633 L p .949 .687 .505 r
F P
0 g
s
.33018 .49605 m .30382 .50445 L .28687 .48888 L p .652 .756 .926 r
F P
0 g
s
.72052 .40497 m .71903 .37995 L .69076 .38892 L p .55 .333 .538 r
F P
0 g
s
.69076 .38892 m .69203 .41389 L .72052 .40497 L p .55 .333 .538 r
F P
0 g
s
.71903 .37995 m .69076 .38892 L .67735 .37229 L p .658 .749 .917 r
F P
0 g
s
.72052 .40497 m .71903 .37995 L .69076 .38892 L p .55 .333 .538 r
F P
0 g
s
.69076 .38892 m .69203 .41389 L .72052 .40497 L p .55 .333 .538 r
F P
0 g
s
.64917 .38133 m .67735 .37229 L .69076 .38892 L p .658 .749 .917 r
F P
0 g
s
.67735 .37229 m .69076 .38892 L .69203 .41389 L p .975 .682 .398 r
F P
0 g
s
.67735 .37229 m .69076 .38892 L .69203 .41389 L p .975 .682 .398 r
F P
0 g
s
.56494 .36598 m .56463 .34125 L .53712 .35041 L p .541 .319 .528 r
F P
0 g
s
.53712 .35041 m .53722 .37508 L .56494 .36598 L p .541 .319 .528 r
F P
0 g
s
.56463 .34125 m .53712 .35041 L .52231 .33343 L p .66 .747 .915 r
F P
0 g
s
.56494 .36598 m .56463 .34125 L .53712 .35041 L p .541 .319 .528 r
F P
0 g
s
.53712 .35041 m .53722 .37508 L .56494 .36598 L p .541 .319 .528 r
F P
0 g
s
.49489 .34266 m .52231 .33343 L .53712 .35041 L p .66 .747 .915 r
F P
0 g
s
.52231 .33343 m .53712 .35041 L .53722 .37508 L p .969 .687 .442 r
F P
0 g
s
.52231 .33343 m .53712 .35041 L .53722 .37508 L p .969 .687 .442 r
F P
0 g
s
.79322 .52132 m .79118 .4954 L .76255 .5038 L p .558 .345 .547 r
F P
0 g
s
.76255 .5038 m .76436 .52966 L .79322 .52132 L p .558 .345 .547 r
F P
0 g
s
.76255 .5038 m .74979 .48822 L .74809 .46264 L p .976 .68 .386 r
F P
0 g
s
.79118 .4954 m .76255 .5038 L .74979 .48822 L p .652 .756 .926 r
F P
0 g
s
.72124 .4967 m .74979 .48822 L .76255 .5038 L p .652 .756 .926 r
F P
0 g
s
.74979 .48822 m .76255 .5038 L .76436 .52966 L p .976 .68 .386 r
F P
0 g
s
.63759 .48231 m .63673 .45669 L .60885 .46528 L p .55 .333 .538 r
F P
0 g
s
.60885 .46528 m .60949 .49084 L .63759 .48231 L p .55 .333 .538 r
F P
0 g
s
.60885 .46528 m .59469 .44935 L .59416 .42406 L p .971 .686 .432 r
F P
0 g
s
.60885 .46528 m .59469 .44935 L .59416 .42406 L p .971 .686 .432 r
F P
0 g
s
.63673 .45669 m .60885 .46528 L .59469 .44935 L p .654 .754 .923 r
F P
0 g
s
.63759 .48231 m .63673 .45669 L .60885 .46528 L p .55 .333 .538 r
F P
0 g
s
.60885 .46528 m .60949 .49084 L .63759 .48231 L p .55 .333 .538 r
F P
0 g
s
.5669 .45801 m .59469 .44935 L .60885 .46528 L p .654 .754 .923 r
F P
0 g
s
.5669 .45801 m .59469 .44935 L .60885 .46528 L p .654 .754 .923 r
F P
0 g
s
.59469 .44935 m .60885 .46528 L .60949 .49084 L p .971 .686 .432 r
F P
0 g
s
.63673 .45669 m .60885 .46528 L .59469 .44935 L p .654 .754 .923 r
F P
0 g
s
.59469 .44935 m .60885 .46528 L .60949 .49084 L p .971 .686 .432 r
F P
0 g
s
.48195 .4433 m .48227 .41797 L .45515 .42675 L p .541 .319 .528 r
F P
0 g
s
.45515 .42675 m .45463 .45202 L .48195 .4433 L p .541 .319 .528 r
F P
0 g
s
.45515 .42675 m .43958 .41047 L .44023 .38548 L p .962 .688 .469 r
F P
0 g
s
.45515 .42675 m .43958 .41047 L .44023 .38548 L p .962 .688 .469 r
F P
0 g
s
.48227 .41797 m .45515 .42675 L .43958 .41047 L p .656 .751 .92 r
F P
0 g
s
.48195 .4433 m .48227 .41797 L .45515 .42675 L p .541 .319 .528 r
F P
0 g
s
.45515 .42675 m .45463 .45202 L .48195 .4433 L p .541 .319 .528 r
F P
0 g
s
.41256 .41933 m .43958 .41047 L .45515 .42675 L p .656 .751 .92 r
F P
0 g
s
.43958 .41047 m .45515 .42675 L .45463 .45202 L p .962 .688 .469 r
F P
0 g
s
.48227 .41797 m .45515 .42675 L .43958 .41047 L p .656 .751 .92 r
F P
0 g
s
.32631 .40429 m .32781 .37926 L .30146 .38823 L p .53 .304 .517 r
F P
0 g
s
.30146 .38823 m .29976 .4132 L .32631 .40429 L p .53 .304 .517 r
F P
0 g
s
.30146 .38823 m .28448 .37159 L .2863 .3469 L p .952 .687 .499 r
F P
0 g
s
.32781 .37926 m .30146 .38823 L .28448 .37159 L p .658 .749 .917 r
F P
0 g
s
.32631 .40429 m .32781 .37926 L .30146 .38823 L p .53 .304 .517 r
F P
0 g
s
.30146 .38823 m .29976 .4132 L .32631 .40429 L p .53 .304 .517 r
F P
0 g
s
.25822 .38064 m .28448 .37159 L .30146 .38823 L p .658 .749 .917 r
F P
0 g
s
.28448 .37159 m .30146 .38823 L .29976 .4132 L p .952 .687 .499 r
F P
0 g
s
.52688 .5417 m .51196 .52646 L .51206 .50058 L p .964 .688 .461 r
F P
0 g
s
.55436 .53348 m .52688 .5417 L .51196 .52646 L p .649 .759 .929 r
F P
0 g
s
.39889 .52067 m .39985 .49475 L .37312 .50316 L p .541 .319 .528 r
F P
0 g
s
.37312 .50316 m .37197 .52902 L .39889 .52067 L p .541 .319 .528 r
F P
0 g
s
.37312 .50316 m .3568 .48757 L .35807 .46198 L p .954 .688 .492 r
F P
0 g
s
.39985 .49475 m .37312 .50316 L .3568 .48757 L p .652 .756 .926 r
F P
0 g
s
.39889 .52067 m .39985 .49475 L .37312 .50316 L p .541 .319 .528 r
F P
0 g
s
.37312 .50316 m .37197 .52902 L .39889 .52067 L p .541 .319 .528 r
F P
0 g
s
.33018 .49605 m .3568 .48757 L .37312 .50316 L p .652 .756 .926 r
F P
0 g
s
.33018 .49605 m .3568 .48757 L .37312 .50316 L p .652 .756 .926 r
F P
0 g
s
.3568 .48757 m .37312 .50316 L .37197 .52902 L p .954 .688 .492 r
F P
0 g
s
.3568 .48757 m .37312 .50316 L .37197 .52902 L p .954 .688 .492 r
F P
0 g
s
.76036 .38754 m .74758 .37089 L .74589 .34619 L p .976 .678 .372 r
F P
0 g
s
.789 .37856 m .76036 .38754 L .74758 .37089 L p .658 .749 .917 r
F P
0 g
s
.71903 .37995 m .74758 .37089 L .76036 .38754 L p .658 .749 .917 r
F P
0 g
s
.74758 .37089 m .76036 .38754 L .76216 .41252 L p .976 .678 .372 r
F P
0 g
s
.63532 .36457 m .63448 .33983 L .60661 .349 L p .544 .324 .532 r
F P
0 g
s
.60661 .349 m .60723 .37369 L .63532 .36457 L p .544 .324 .532 r
F P
0 g
s
.56463 .34125 m .59242 .332 L .60661 .349 L p .66 .747 .915 r
F P
0 g
s
.59242 .332 m .60661 .349 L .60723 .37369 L p .972 .685 .422 r
F P
0 g
s
.79118 .4954 m .8201 .48691 L .83223 .50252 L p .652 .756 .926 r
F P
0 g
s
.83223 .50252 m .8201 .48691 L .81786 .46132 L p .976 .675 .358 r
F P
0 g
s
.67842 .46396 m .66488 .44801 L .66382 .42271 L p .974 .684 .41 r
F P
0 g
s
.70666 .45536 m .67842 .46396 L .66488 .44801 L p .654 .754 .923 r
F P
0 g
s
.63673 .45669 m .66488 .44801 L .67842 .46396 L p .654 .754 .923 r
F P
0 g
s
.66488 .44801 m .67842 .46396 L .67959 .48953 L p .974 .684 .41 r
F P
0 g
s
.55229 .44195 m .55208 .41661 L .5246 .42541 L p .544 .324 .532 r
F P
0 g
s
.5246 .42541 m .5246 .45069 L .55229 .44195 L p .544 .324 .532 r
F P
0 g
s
.5246 .42541 m .50966 .4091 L .50977 .3841 L p .966 .687 .452 r
F P
0 g
s
.5246 .42541 m .50966 .4091 L .50977 .3841 L p .966 .687 .452 r
F P
0 g
s
.55208 .41661 m .5246 .42541 L .50966 .4091 L p .656 .751 .92 r
F P
0 g
s
.55229 .44195 m .55208 .41661 L .5246 .42541 L p .544 .324 .532 r
F P
0 g
s
.5246 .42541 m .5246 .45069 L .55229 .44195 L p .544 .324 .532 r
F P
0 g
s
.48227 .41797 m .50966 .4091 L .5246 .42541 L p .656 .751 .92 r
F P
0 g
s
.48227 .41797 m .50966 .4091 L .5246 .42541 L p .656 .751 .92 r
F P
0 g
s
.50966 .4091 m .5246 .42541 L .5246 .45069 L p .966 .687 .452 r
F P
0 g
s
.55208 .41661 m .5246 .42541 L .50966 .4091 L p .656 .751 .92 r
F P
0 g
s
.50966 .4091 m .5246 .42541 L .5246 .45069 L p .966 .687 .452 r
F P
0 g
s
.37079 .38686 m .35443 .37019 L .35572 .34549 L p .957 .688 .485 r
F P
0 g
s
.39751 .37787 m .37079 .38686 L .35443 .37019 L p .658 .749 .917 r
F P
0 g
s
.39654 .40291 m .39751 .37787 L .37079 .38686 L p .534 .309 .521 r
F P
0 g
s
.37079 .38686 m .36962 .41184 L .39654 .40291 L p .534 .309 .521 r
F P
0 g
s
.32781 .37926 m .35443 .37019 L .37079 .38686 L p .658 .749 .917 r
F P
0 g
s
.35443 .37019 m .37079 .38686 L .36962 .41184 L p .957 .688 .485 r
F P
0 g
s
.39751 .37787 m .37079 .38686 L .35443 .37019 L p .658 .749 .917 r
F P
0 g
s
.35443 .37019 m .37079 .38686 L .36962 .41184 L p .957 .688 .485 r
F P
0 g
s
.24078 .36386 m .24293 .33912 L .21697 .3483 L p .522 .293 .509 r
F P
0 g
s
.21697 .3483 m .21463 .37299 L .24078 .36386 L p .522 .293 .509 r
F P
0 g
s
.24293 .33912 m .21697 .3483 L .19921 .33129 L p .66 .747 .915 r
F P
0 g
s
.24078 .36386 m .24293 .33912 L .21697 .3483 L p .522 .293 .509 r
F P
0 g
s
.21697 .3483 m .21463 .37299 L .24078 .36386 L p .522 .293 .509 r
F P
0 g
s
.17336 .34054 m .19921 .33129 L .21697 .3483 L p .66 .747 .915 r
F P
0 g
s
.19921 .33129 m .21697 .3483 L .21463 .37299 L p .946 .686 .511 r
F P
0 g
s
.19921 .33129 m .21697 .3483 L .21463 .37299 L p .946 .686 .511 r
F P
0 g
s
.4692 .51938 m .46962 .49345 L .44254 .50187 L p .544 .324 .532 r
F P
0 g
s
.44254 .50187 m .44191 .52774 L .4692 .51938 L p .544 .324 .532 r
F P
0 g
s
.44254 .50187 m .42683 .48626 L .42757 .46066 L p .959 .688 .477 r
F P
0 g
s
.44254 .50187 m .42683 .48626 L .42757 .46066 L p .959 .688 .477 r
F P
0 g
s
.46962 .49345 m .44254 .50187 L .42683 .48626 L p .652 .756 .926 r
F P
0 g
s
.4692 .51938 m .46962 .49345 L .44254 .50187 L p .544 .324 .532 r
F P
0 g
s
.44254 .50187 m .44191 .52774 L .4692 .51938 L p .544 .324 .532 r
F P
0 g
s
.39985 .49475 m .42683 .48626 L .44254 .50187 L p .652 .756 .926 r
F P
0 g
s
.39985 .49475 m .42683 .48626 L .44254 .50187 L p .652 .756 .926 r
F P
0 g
s
.42683 .48626 m .44254 .50187 L .44191 .52774 L p .959 .688 .477 r
F P
0 g
s
.46962 .49345 m .44254 .50187 L .42683 .48626 L p .652 .756 .926 r
F P
0 g
s
.42683 .48626 m .44254 .50187 L .44191 .52774 L p .959 .688 .477 r
F P
0 g
s
.31338 .48033 m .31499 .45469 L .28867 .4633 L p .534 .309 .521 r
F P
0 g
s
.28867 .4633 m .28687 .48888 L .31338 .48033 L p .534 .309 .521 r
F P
0 g
s
.28867 .4633 m .27155 .44733 L .27347 .42204 L p .949 .687 .505 r
F P
0 g
s
.31499 .45469 m .28867 .4633 L .27155 .44733 L p .654 .754 .923 r
F P
0 g
s
.31338 .48033 m .31499 .45469 L .28867 .4633 L p .534 .309 .521 r
F P
0 g
s
.28867 .4633 m .28687 .48888 L .31338 .48033 L p .534 .309 .521 r
F P
0 g
s
.27155 .44733 m .28867 .4633 L .28687 .48888 L p .949 .687 .505 r
F P
0 g
s
.31499 .45469 m .28867 .4633 L .27155 .44733 L p .654 .754 .923 r
F P
0 g
s
.70444 .33841 m .6762 .3476 L .66263 .33057 L p .66 .747 .915 r
F P
0 g
s
.70581 .36316 m .70444 .33841 L .6762 .3476 L p .547 .329 .535 r
F P
0 g
s
.6762 .3476 m .67735 .37229 L .70581 .36316 L p .547 .329 .535 r
F P
0 g
s
.63448 .33983 m .66263 .33057 L .6762 .3476 L p .66 .747 .915 r
F P
0 g
s
.66263 .33057 m .6762 .3476 L .67735 .37229 L p .975 .682 .398 r
F P
0 g
s
.66263 .33057 m .6762 .3476 L .67735 .37229 L p .975 .682 .398 r
F P
0 g
s
.77863 .47966 m .77669 .45402 L .74809 .46264 L p .556 .341 .544 r
F P
0 g
s
.74809 .46264 m .74979 .48822 L .77863 .47966 L p .556 .341 .544 r
F P
0 g
s
.74809 .46264 m .73518 .44666 L .73358 .42136 L p .976 .68 .386 r
F P
0 g
s
.77669 .45402 m .74809 .46264 L .73518 .44666 L p .654 .754 .923 r
F P
0 g
s
.77863 .47966 m .77669 .45402 L .74809 .46264 L p .556 .341 .544 r
F P
0 g
s
.74809 .46264 m .74979 .48822 L .77863 .47966 L p .556 .341 .544 r
F P
0 g
s
.70666 .45536 m .73518 .44666 L .74809 .46264 L p .654 .754 .923 r
F P
0 g
s
.70666 .45536 m .73518 .44666 L .74809 .46264 L p .654 .754 .923 r
F P
0 g
s
.73518 .44666 m .74809 .46264 L .74979 .48822 L p .976 .68 .386 r
F P
0 g
s
.73518 .44666 m .74809 .46264 L .74979 .48822 L p .976 .68 .386 r
F P
0 g
s
.62275 .44059 m .622 .41525 L .59416 .42406 L p .547 .329 .535 r
F P
0 g
s
.59416 .42406 m .59469 .44935 L .62275 .44059 L p .547 .329 .535 r
F P
0 g
s
.59416 .42406 m .57984 .40773 L .57942 .38272 L p .971 .686 .432 r
F P
0 g
s
.59416 .42406 m .57984 .40773 L .57942 .38272 L p .971 .686 .432 r
F P
0 g
s
.622 .41525 m .59416 .42406 L .57984 .40773 L p .656 .751 .92 r
F P
0 g
s
.62275 .44059 m .622 .41525 L .59416 .42406 L p .547 .329 .535 r
F P
0 g
s
.59416 .42406 m .59469 .44935 L .62275 .44059 L p .547 .329 .535 r
F P
0 g
s
.55208 .41661 m .57984 .40773 L .59416 .42406 L p .656 .751 .92 r
F P
0 g
s
.55208 .41661 m .57984 .40773 L .59416 .42406 L p .656 .751 .92 r
F P
0 g
s
.57984 .40773 m .59416 .42406 L .59469 .44935 L p .971 .686 .432 r
F P
0 g
s
.622 .41525 m .59416 .42406 L .57984 .40773 L p .656 .751 .92 r
F P
0 g
s
.57984 .40773 m .59416 .42406 L .59469 .44935 L p .971 .686 .432 r
F P
0 g
s
.46687 .40152 m .46731 .37648 L .44023 .38548 L p .537 .315 .524 r
F P
0 g
s
.44023 .38548 m .43958 .41047 L .46687 .40152 L p .537 .315 .524 r
F P
0 g
s
.44023 .38548 m .42449 .36879 L .42525 .34408 L p .962 .688 .469 r
F P
0 g
s
.44023 .38548 m .42449 .36879 L .42525 .34408 L p .962 .688 .469 r
F P
0 g
s
.46731 .37648 m .44023 .38548 L .42449 .36879 L p .658 .749 .917 r
F P
0 g
s
.46687 .40152 m .46731 .37648 L .44023 .38548 L p .537 .315 .524 r
F P
0 g
s
.44023 .38548 m .43958 .41047 L .46687 .40152 L p .537 .315 .524 r
F P
0 g
s
.39751 .37787 m .42449 .36879 L .44023 .38548 L p .658 .749 .917 r
F P
0 g
s
.42449 .36879 m .44023 .38548 L .43958 .41047 L p .962 .688 .469 r
F P
0 g
s
.46731 .37648 m .44023 .38548 L .42449 .36879 L p .658 .749 .917 r
F P
0 g
s
.66605 .53918 m .65238 .52389 L .65141 .49799 L p .972 .685 .422 r
F P
0 g
s
.69426 .53093 m .66605 .53918 L .65238 .52389 L p .649 .759 .929 r
F P
0 g
s
.53962 .51809 m .53951 .49215 L .51206 .50058 L p .547 .329 .535 r
F P
0 g
s
.51206 .50058 m .51196 .52646 L .53962 .51809 L p .547 .329 .535 r
F P
0 g
s
.51206 .50058 m .49698 .48494 L .49719 .45934 L p .964 .688 .461 r
F P
0 g
s
.51206 .50058 m .49698 .48494 L .49719 .45934 L p .964 .688 .461 r
F P
0 g
s
.53951 .49215 m .51206 .50058 L .49698 .48494 L p .652 .756 .926 r
F P
0 g
s
.53962 .51809 m .53951 .49215 L .51206 .50058 L p .547 .329 .535 r
F P
0 g
s
.51206 .50058 m .51196 .52646 L .53962 .51809 L p .547 .329 .535 r
F P
0 g
s
.46962 .49345 m .49698 .48494 L .51206 .50058 L p .652 .756 .926 r
F P
0 g
s
.49698 .48494 m .51206 .50058 L .51196 .52646 L p .964 .688 .461 r
F P
0 g
s
.53951 .49215 m .51206 .50058 L .49698 .48494 L p .652 .756 .926 r
F P
0 g
s
.35807 .46198 m .34158 .44599 L .34296 .42068 L p .954 .688 .492 r
F P
0 g
s
.38475 .45336 m .35807 .46198 L .34158 .44599 L p .654 .754 .923 r
F P
0 g
s
.38368 .479 m .38475 .45336 L .35807 .46198 L p .537 .315 .524 r
F P
0 g
s
.35807 .46198 m .3568 .48757 L .38368 .479 L p .537 .315 .524 r
F P
0 g
s
.31499 .45469 m .34158 .44599 L .35807 .46198 L p .654 .754 .923 r
F P
0 g
s
.34158 .44599 m .35807 .46198 L .3568 .48757 L p .954 .688 .492 r
F P
0 g
s
.38475 .45336 m .35807 .46198 L .34158 .44599 L p .654 .754 .923 r
F P
0 g
s
.34158 .44599 m .35807 .46198 L .3568 .48757 L p .954 .688 .492 r
F P
0 g
s
.20408 .42339 m .18617 .40704 L .18874 .38203 L p .943 .686 .517 r
F P
0 g
s
.23 .41457 m .20408 .42339 L .18617 .40704 L p .656 .751 .92 r
F P
0 g
s
.77641 .36175 m .7745 .33699 L .74589 .34619 L p .55 .333 .538 r
F P
0 g
s
.74589 .34619 m .74758 .37089 L .77641 .36175 L p .55 .333 .538 r
F P
0 g
s
.7745 .33699 m .74589 .34619 L .73296 .32914 L p .66 .747 .915 r
F P
0 g
s
.77641 .36175 m .7745 .33699 L .74589 .34619 L p .55 .333 .538 r
F P
0 g
s
.74589 .34619 m .74758 .37089 L .77641 .36175 L p .55 .333 .538 r
F P
0 g
s
.73296 .32914 m .74589 .34619 L .74758 .37089 L p .976 .678 .372 r
F P
0 g
s
.77669 .45402 m .80558 .44532 L .81786 .46132 L p .654 .754 .923 r
F P
0 g
s
.77669 .45402 m .80558 .44532 L .81786 .46132 L p .654 .754 .923 r
F P
0 g
s
.80558 .44532 m .81786 .46132 L .8201 .48691 L p .976 .675 .358 r
F P
0 g
s
.81786 .46132 m .80558 .44532 L .80345 .42001 L p .976 .675 .358 r
F P
0 g
s
.69331 .43924 m .69203 .41389 L .66382 .42271 L p .55 .333 .538 r
F P
0 g
s
.66382 .42271 m .66488 .44801 L .69331 .43924 L p .55 .333 .538 r
F P
0 g
s
.66382 .42271 m .65012 .40635 L .64917 .38133 L p .974 .684 .41 r
F P
0 g
s
.66382 .42271 m .65012 .40635 L .64917 .38133 L p .974 .684 .41 r
F P
0 g
s
.69203 .41389 m .66382 .42271 L .65012 .40635 L p .656 .751 .92 r
F P
0 g
s
.69331 .43924 m .69203 .41389 L .66382 .42271 L p .55 .333 .538 r
F P
0 g
s
.66382 .42271 m .66488 .44801 L .69331 .43924 L p .55 .333 .538 r
F P
0 g
s
.622 .41525 m .65012 .40635 L .66382 .42271 L p .656 .751 .92 r
F P
0 g
s
.65012 .40635 m .66382 .42271 L .66488 .44801 L p .974 .684 .41 r
F P
0 g
s
.69203 .41389 m .66382 .42271 L .65012 .40635 L p .656 .751 .92 r
F P
0 g
s
.53731 .40014 m .53722 .37508 L .50977 .3841 L p .541 .319 .528 r
F P
0 g
s
.50977 .3841 m .50966 .4091 L .53731 .40014 L p .541 .319 .528 r
F P
0 g
s
.50977 .3841 m .49466 .36739 L .49489 .34266 L p .966 .687 .452 r
F P
0 g
s
.50977 .3841 m .49466 .36739 L .49489 .34266 L p .966 .687 .452 r
F P
0 g
s
.53722 .37508 m .50977 .3841 L .49466 .36739 L p .658 .749 .917 r
F P
0 g
s
.53731 .40014 m .53722 .37508 L .50977 .3841 L p .541 .319 .528 r
F P
0 g
s
.50977 .3841 m .50966 .4091 L .53731 .40014 L p .541 .319 .528 r
F P
0 g
s
.46731 .37648 m .49466 .36739 L .50977 .3841 L p .658 .749 .917 r
F P
0 g
s
.46731 .37648 m .49466 .36739 L .50977 .3841 L p .658 .749 .917 r
F P
0 g
s
.49466 .36739 m .50977 .3841 L .50966 .4091 L p .966 .687 .452 r
F P
0 g
s
.53722 .37508 m .50977 .3841 L .49466 .36739 L p .658 .749 .917 r
F P
0 g
s
.49466 .36739 m .50977 .3841 L .50966 .4091 L p .966 .687 .452 r
F P
0 g
s
.38132 .36104 m .38241 .33628 L .35572 .34549 L p .53 .304 .517 r
F P
0 g
s
.35572 .34549 m .35443 .37019 L .38132 .36104 L p .53 .304 .517 r
F P
0 g
s
.31262 .3377 m .3392 .32842 L .35572 .34549 L p .66 .747 .915 r
F P
0 g
s
.3392 .32842 m .35572 .34549 L .35443 .37019 L p .957 .688 .485 r
F P
0 g
s
.73579 .53792 m .72275 .52261 L .72124 .4967 L p .975 .682 .398 r
F P
0 g
s
.73579 .53792 m .72275 .52261 L .72124 .4967 L p .975 .682 .398 r
F P
0 g
s
.76436 .52966 m .73579 .53792 L .72275 .52261 L p .649 .759 .929 r
F P
0 g
s
.69426 .53093 m .72275 .52261 L .73579 .53792 L p .649 .759 .929 r
F P
0 g
s
.58168 .49929 m .56723 .48363 L .5669 .45801 L p .969 .687 .442 r
F P
0 g
s
.58168 .49929 m .56723 .48363 L .5669 .45801 L p .969 .687 .442 r
F P
0 g
s
.60949 .49084 m .58168 .49929 L .56723 .48363 L p .652 .756 .926 r
F P
0 g
s
.61015 .51679 m .60949 .49084 L .58168 .49929 L p .55 .333 .538 r
F P
0 g
s
.58168 .49929 m .58212 .52518 L .61015 .51679 L p .55 .333 .538 r
F P
0 g
s
.53951 .49215 m .56723 .48363 L .58168 .49929 L p .652 .756 .926 r
F P
0 g
s
.53951 .49215 m .56723 .48363 L .58168 .49929 L p .652 .756 .926 r
F P
0 g
s
.56723 .48363 m .58168 .49929 L .58212 .52518 L p .969 .687 .442 r
F P
0 g
s
.60949 .49084 m .58168 .49929 L .56723 .48363 L p .652 .756 .926 r
F P
0 g
s
.56723 .48363 m .58168 .49929 L .58212 .52518 L p .969 .687 .442 r
F P
0 g
s
.45409 .47768 m .45463 .45202 L .42757 .46066 L p .541 .319 .528 r
F P
0 g
s
.42757 .46066 m .42683 .48626 L .45409 .47768 L p .541 .319 .528 r
F P
0 g
s
.42757 .46066 m .41171 .44464 L .41256 .41933 L p .959 .688 .477 r
F P
0 g
s
.45463 .45202 m .42757 .46066 L .41171 .44464 L p .654 .754 .923 r
F P
0 g
s
.45409 .47768 m .45463 .45202 L .42757 .46066 L p .541 .319 .528 r
F P
0 g
s
.42757 .46066 m .42683 .48626 L .45409 .47768 L p .541 .319 .528 r
F P
0 g
s
.38475 .45336 m .41171 .44464 L .42757 .46066 L p .654 .754 .923 r
F P
0 g
s
.41171 .44464 m .42757 .46066 L .42683 .48626 L p .959 .688 .477 r
F P
0 g
s
.29803 .43856 m .29976 .4132 L .27347 .42204 L p .53 .304 .517 r
F P
0 g
s
.27347 .42204 m .27155 .44733 L .29803 .43856 L p .53 .304 .517 r
F P
0 g
s
.29976 .4132 m .27347 .42204 L .25619 .40566 L p .656 .751 .92 r
F P
0 g
s
.29803 .43856 m .29976 .4132 L .27347 .42204 L p .53 .304 .517 r
F P
0 g
s
.27347 .42204 m .27155 .44733 L .29803 .43856 L p .53 .304 .517 r
F P
0 g
s
.25619 .40566 m .27347 .42204 L .27155 .44733 L p .949 .687 .505 r
F P
0 g
s
.7745 .33699 m .80339 .3277 L .81569 .34478 L p .66 .747 .915 r
F P
0 g
s
.80339 .3277 m .81569 .34478 L .81791 .36949 L p .976 .672 .343 r
F P
0 g
s
.34532 .53728 m .32869 .52196 L .33018 .49605 L p .952 .687 .499 r
F P
0 g
s
.37197 .52902 m .34532 .53728 L .32869 .52196 L p .649 .759 .929 r
F P
0 g
s
.73358 .42136 m .72052 .40497 L .71903 .37995 L p .976 .68 .386 r
F P
0 g
s
.73358 .42136 m .72052 .40497 L .71903 .37995 L p .976 .68 .386 r
F P
0 g
s
.76216 .41252 m .73358 .42136 L .72052 .40497 L p .656 .751 .92 r
F P
0 g
s
.69203 .41389 m .72052 .40497 L .73358 .42136 L p .656 .751 .92 r
F P
0 g
s
.69203 .41389 m .72052 .40497 L .73358 .42136 L p .656 .751 .92 r
F P
0 g
s
.72052 .40497 m .73358 .42136 L .73518 .44666 L p .976 .68 .386 r
F P
0 g
s
.60787 .39875 m .60723 .37369 L .57942 .38272 L p .544 .324 .532 r
F P
0 g
s
.57942 .38272 m .57984 .40773 L .60787 .39875 L p .544 .324 .532 r
F P
0 g
s
.57942 .38272 m .56494 .36598 L .56463 .34125 L p .971 .686 .432 r
F P
0 g
s
.57942 .38272 m .56494 .36598 L .56463 .34125 L p .971 .686 .432 r
F P
0 g
s
.60723 .37369 m .57942 .38272 L .56494 .36598 L p .658 .749 .917 r
F P
0 g
s
.60787 .39875 m .60723 .37369 L .57942 .38272 L p .544 .324 .532 r
F P
0 g
s
.57942 .38272 m .57984 .40773 L .60787 .39875 L p .544 .324 .532 r
F P
0 g
s
.53722 .37508 m .56494 .36598 L .57942 .38272 L p .658 .749 .917 r
F P
0 g
s
.53722 .37508 m .56494 .36598 L .57942 .38272 L p .658 .749 .917 r
F P
0 g
s
.56494 .36598 m .57942 .38272 L .57984 .40773 L p .971 .686 .432 r
F P
0 g
s
.60723 .37369 m .57942 .38272 L .56494 .36598 L p .658 .749 .917 r
F P
0 g
s
.56494 .36598 m .57942 .38272 L .57984 .40773 L p .971 .686 .432 r
F P
0 g
s
.45175 .35962 m .4523 .33486 L .42525 .34408 L p .534 .309 .521 r
F P
0 g
s
.42525 .34408 m .42449 .36879 L .45175 .35962 L p .534 .309 .521 r
F P
0 g
s
.4523 .33486 m .42525 .34408 L .40936 .32698 L p .66 .747 .915 r
F P
0 g
s
.45175 .35962 m .4523 .33486 L .42525 .34408 L p .534 .309 .521 r
F P
0 g
s
.42525 .34408 m .42449 .36879 L .45175 .35962 L p .534 .309 .521 r
F P
0 g
s
.38241 .33628 m .40936 .32698 L .42525 .34408 L p .66 .747 .915 r
F P
0 g
s
.40936 .32698 m .42525 .34408 L .42449 .36879 L p .962 .688 .469 r
F P
0 g
s
.40936 .32698 m .42525 .34408 L .42449 .36879 L p .962 .688 .469 r
F P
0 g
s
.36843 .4372 m .36962 .41184 L .34296 .42068 L p .534 .309 .521 r
F P
0 g
s
.34296 .42068 m .34158 .44599 L .36843 .4372 L p .534 .309 .521 r
F P
0 g
s
.34296 .42068 m .32631 .40429 L .32781 .37926 L p .954 .688 .492 r
F P
0 g
s
.34296 .42068 m .32631 .40429 L .32781 .37926 L p .954 .688 .492 r
F P
0 g
s
.36962 .41184 m .34296 .42068 L .32631 .40429 L p .656 .751 .92 r
F P
0 g
s
.36843 .4372 m .36962 .41184 L .34296 .42068 L p .534 .309 .521 r
F P
0 g
s
.34296 .42068 m .34158 .44599 L .36843 .4372 L p .534 .309 .521 r
F P
0 g
s
.29976 .4132 m .32631 .40429 L .34296 .42068 L p .656 .751 .92 r
F P
0 g
s
.32631 .40429 m .34296 .42068 L .34158 .44599 L p .954 .688 .492 r
F P
0 g
s
.36962 .41184 m .34296 .42068 L .32631 .40429 L p .656 .751 .92 r
F P
0 g
s
.21225 .39806 m .21463 .37299 L .18874 .38203 L p .522 .293 .509 r
F P
0 g
s
.18874 .38203 m .18617 .40704 L .21225 .39806 L p .522 .293 .509 r
F P
0 g
s
.18874 .38203 m .17067 .36527 L .17336 .34054 L p .943 .686 .517 r
F P
0 g
s
.21463 .37299 m .18874 .38203 L .17067 .36527 L p .658 .749 .917 r
F P
0 g
s
.21225 .39806 m .21463 .37299 L .18874 .38203 L p .522 .293 .509 r
F P
0 g
s
.18874 .38203 m .18617 .40704 L .21225 .39806 L p .522 .293 .509 r
F P
0 g
s
.17067 .36527 m .18874 .38203 L .18617 .40704 L p .943 .686 .517 r
F P
0 g
s
.21463 .37299 m .18874 .38203 L .17067 .36527 L p .658 .749 .917 r
F P
0 g
s
.76436 .52966 m .79322 .52132 L .80563 .53665 L p .649 .759 .929 r
F P
0 g
s
.80563 .53665 m .79322 .52132 L .79118 .4954 L p .976 .678 .372 r
F P
0 g
s
.68078 .5155 m .67959 .48953 L .65141 .49799 L p .553 .337 .541 r
F P
0 g
s
.65141 .49799 m .65238 .52389 L .68078 .5155 L p .553 .337 .541 r
F P
0 g
s
.65141 .49799 m .63759 .48231 L .63673 .45669 L p .972 .685 .422 r
F P
0 g
s
.65141 .49799 m .63759 .48231 L .63673 .45669 L p .972 .685 .422 r
F P
0 g
s
.67959 .48953 m .65141 .49799 L .63759 .48231 L p .652 .756 .926 r
F P
0 g
s
.60949 .49084 m .63759 .48231 L .65141 .49799 L p .652 .756 .926 r
F P
0 g
s
.60949 .49084 m .63759 .48231 L .65141 .49799 L p .652 .756 .926 r
F P
0 g
s
.63759 .48231 m .65141 .49799 L .65238 .52389 L p .972 .685 .422 r
F P
0 g
s
.5246 .47635 m .5246 .45069 L .49719 .45934 L p .544 .324 .532 r
F P
0 g
s
.49719 .45934 m .49698 .48494 L .5246 .47635 L p .544 .324 .532 r
F P
0 g
s
.49719 .45934 m .48195 .4433 L .48227 .41797 L p .964 .688 .461 r
F P
0 g
s
.49719 .45934 m .48195 .4433 L .48227 .41797 L p .964 .688 .461 r
F P
0 g
s
.5246 .45069 m .49719 .45934 L .48195 .4433 L p .654 .754 .923 r
F P
0 g
s
.5246 .47635 m .5246 .45069 L .49719 .45934 L p .544 .324 .532 r
F P
0 g
s
.49719 .45934 m .49698 .48494 L .5246 .47635 L p .544 .324 .532 r
F P
0 g
s
.45463 .45202 m .48195 .4433 L .49719 .45934 L p .654 .754 .923 r
F P
0 g
s
.45463 .45202 m .48195 .4433 L .49719 .45934 L p .654 .754 .923 r
F P
0 g
s
.48195 .4433 m .49719 .45934 L .49698 .48494 L p .964 .688 .461 r
F P
0 g
s
.5246 .45069 m .49719 .45934 L .48195 .4433 L p .654 .754 .923 r
F P
0 g
s
.48195 .4433 m .49719 .45934 L .49698 .48494 L p .964 .688 .461 r
F P
0 g
s
.41489 .53602 m .39889 .52067 L .39985 .49475 L p .957 .688 .485 r
F P
0 g
s
.41489 .53602 m .39889 .52067 L .39985 .49475 L p .957 .688 .485 r
F P
0 g
s
.44191 .52774 m .41489 .53602 L .39889 .52067 L p .649 .759 .929 r
F P
0 g
s
.37197 .52902 m .39889 .52067 L .41489 .53602 L p .649 .759 .929 r
F P
0 g
s
.76216 .41252 m .79102 .4036 L .80345 .42001 L p .656 .751 .92 r
F P
0 g
s
.79102 .4036 m .80345 .42001 L .80558 .44532 L p .976 .675 .358 r
F P
0 g
s
.67853 .39736 m .67735 .37229 L .64917 .38133 L p .547 .329 .535 r
F P
0 g
s
.64917 .38133 m .65012 .40635 L .67853 .39736 L p .547 .329 .535 r
F P
0 g
s
.64917 .38133 m .63532 .36457 L .63448 .33983 L p .974 .684 .41 r
F P
0 g
s
.64917 .38133 m .63532 .36457 L .63448 .33983 L p .974 .684 .41 r
F P
0 g
s
.67735 .37229 m .64917 .38133 L .63532 .36457 L p .658 .749 .917 r
F P
0 g
s
.67853 .39736 m .67735 .37229 L .64917 .38133 L p .547 .329 .535 r
F P
0 g
s
.64917 .38133 m .65012 .40635 L .67853 .39736 L p .547 .329 .535 r
F P
0 g
s
.60723 .37369 m .63532 .36457 L .64917 .38133 L p .658 .749 .917 r
F P
0 g
s
.60723 .37369 m .63532 .36457 L .64917 .38133 L p .658 .749 .917 r
F P
0 g
s
.63532 .36457 m .64917 .38133 L .65012 .40635 L p .974 .684 .41 r
F P
0 g
s
.67735 .37229 m .64917 .38133 L .63532 .36457 L p .658 .749 .917 r
F P
0 g
s
.63532 .36457 m .64917 .38133 L .65012 .40635 L p .974 .684 .41 r
F P
0 g
s
.52229 .3582 m .52231 .33343 L .49489 .34266 L p .537 .315 .524 r
F P
0 g
s
.49489 .34266 m .49466 .36739 L .52229 .3582 L p .537 .315 .524 r
F P
0 g
s
.52231 .33343 m .49489 .34266 L .47962 .32554 L p .66 .747 .915 r
F P
0 g
s
.52229 .3582 m .52231 .33343 L .49489 .34266 L p .537 .315 .524 r
F P
0 g
s
.49489 .34266 m .49466 .36739 L .52229 .3582 L p .537 .315 .524 r
F P
0 g
s
.47962 .32554 m .49489 .34266 L .49466 .36739 L p .966 .687 .452 r
F P
0 g
s
.75152 .5142 m .74979 .48822 L .72124 .4967 L p .556 .341 .544 r
F P
0 g
s
.72124 .4967 m .72275 .52261 L .75152 .5142 L p .556 .341 .544 r
F P
0 g
s
.72124 .4967 m .70805 .48099 L .70666 .45536 L p .975 .682 .398 r
F P
0 g
s
.74979 .48822 m .72124 .4967 L .70805 .48099 L p .652 .756 .926 r
F P
0 g
s
.75152 .5142 m .74979 .48822 L .72124 .4967 L p .556 .341 .544 r
F P
0 g
s
.72124 .4967 m .72275 .52261 L .75152 .5142 L p .556 .341 .544 r
F P
0 g
s
.67959 .48953 m .70805 .48099 L .72124 .4967 L p .652 .756 .926 r
F P
0 g
s
.70805 .48099 m .72124 .4967 L .72275 .52261 L p .975 .682 .398 r
F P
0 g
s
.74979 .48822 m .72124 .4967 L .70805 .48099 L p .652 .756 .926 r
F P
0 g
s
.70805 .48099 m .72124 .4967 L .72275 .52261 L p .975 .682 .398 r
F P
0 g
s
.59523 .47502 m .59469 .44935 L .5669 .45801 L p .547 .329 .535 r
F P
0 g
s
.5669 .45801 m .56723 .48363 L .59523 .47502 L p .547 .329 .535 r
F P
0 g
s
.5669 .45801 m .55229 .44195 L .55208 .41661 L p .969 .687 .442 r
F P
0 g
s
.5669 .45801 m .55229 .44195 L .55208 .41661 L p .969 .687 .442 r
F P
0 g
s
.59469 .44935 m .5669 .45801 L .55229 .44195 L p .654 .754 .923 r
F P
0 g
s
.59523 .47502 m .59469 .44935 L .5669 .45801 L p .547 .329 .535 r
F P
0 g
s
.5669 .45801 m .56723 .48363 L .59523 .47502 L p .547 .329 .535 r
F P
0 g
s
.5246 .45069 m .55229 .44195 L .5669 .45801 L p .654 .754 .923 r
F P
0 g
s
.5246 .45069 m .55229 .44195 L .5669 .45801 L p .654 .754 .923 r
F P
0 g
s
.55229 .44195 m .5669 .45801 L .56723 .48363 L p .969 .687 .442 r
F P
0 g
s
.59469 .44935 m .5669 .45801 L .55229 .44195 L p .654 .754 .923 r
F P
0 g
s
.55229 .44195 m .5669 .45801 L .56723 .48363 L p .969 .687 .442 r
F P
0 g
s
.43958 .41047 m .41256 .41933 L .39654 .40291 L p .656 .751 .92 r
F P
0 g
s
.43893 .43584 m .43958 .41047 L .41256 .41933 L p .537 .315 .524 r
F P
0 g
s
.41256 .41933 m .41171 .44464 L .43893 .43584 L p .537 .315 .524 r
F P
0 g
s
.36962 .41184 m .39654 .40291 L .41256 .41933 L p .656 .751 .92 r
F P
0 g
s
.39654 .40291 m .41256 .41933 L .41171 .44464 L p .959 .688 .477 r
F P
0 g
s
.39654 .40291 m .41256 .41933 L .41171 .44464 L p .959 .688 .477 r
F P
0 g
s
.25822 .38064 m .24078 .36386 L .24293 .33912 L p .949 .687 .505 r
F P
0 g
s
.28448 .37159 m .25822 .38064 L .24078 .36386 L p .658 .749 .917 r
F P
0 g
s
.28263 .39667 m .28448 .37159 L .25822 .38064 L p .526 .299 .513 r
F P
0 g
s
.25822 .38064 m .25619 .40566 L .28263 .39667 L p .526 .299 .513 r
F P
0 g
s
.21463 .37299 m .24078 .36386 L .25822 .38064 L p .658 .749 .917 r
F P
0 g
s
.21463 .37299 m .24078 .36386 L .25822 .38064 L p .658 .749 .917 r
F P
0 g
s
.24078 .36386 m .25822 .38064 L .25619 .40566 L p .949 .687 .505 r
F P
0 g
s
.24078 .36386 m .25822 .38064 L .25619 .40566 L p .949 .687 .505 r
F P
0 g
s
.44191 .52774 m .4692 .51938 L .48457 .53475 L p .649 .759 .929 r
F P
0 g
s
.48457 .53475 m .4692 .51938 L .46962 .49345 L p .962 .688 .469 r
F P
0 g
s
.35551 .51355 m .3568 .48757 L .33018 .49605 L p .537 .315 .524 r
F P
0 g
s
.33018 .49605 m .32869 .52196 L .35551 .51355 L p .537 .315 .524 r
F P
0 g
s
.33018 .49605 m .31338 .48033 L .31499 .45469 L p .952 .687 .499 r
F P
0 g
s
.33018 .49605 m .31338 .48033 L .31499 .45469 L p .952 .687 .499 r
F P
0 g
s
.3568 .48757 m .33018 .49605 L .31338 .48033 L p .652 .756 .926 r
F P
0 g
s
.28687 .48888 m .31338 .48033 L .33018 .49605 L p .652 .756 .926 r
F P
0 g
s
.74929 .39597 m .74758 .37089 L .71903 .37995 L p .55 .333 .538 r
F P
0 g
s
.71903 .37995 m .72052 .40497 L .74929 .39597 L p .55 .333 .538 r
F P
0 g
s
.74758 .37089 m .71903 .37995 L .70581 .36316 L p .658 .749 .917 r
F P
0 g
s
.74929 .39597 m .74758 .37089 L .71903 .37995 L p .55 .333 .538 r
F P
0 g
s
.71903 .37995 m .72052 .40497 L .74929 .39597 L p .55 .333 .538 r
F P
0 g
s
.67735 .37229 m .70581 .36316 L .71903 .37995 L p .658 .749 .917 r
F P
0 g
s
.70581 .36316 m .71903 .37995 L .72052 .40497 L p .976 .68 .386 r
F P
0 g
s
.70581 .36316 m .71903 .37995 L .72052 .40497 L p .976 .68 .386 r
F P
0 g
s
.59294 .35678 m .59242 .332 L .56463 .34125 L p .541 .319 .528 r
F P
0 g
s
.56463 .34125 m .56494 .36598 L .59294 .35678 L p .541 .319 .528 r
F P
0 g
s
.52231 .33343 m .55 .3241 L .56463 .34125 L p .66 .747 .915 r
F P
0 g
s
.55 .3241 m .56463 .34125 L .56494 .36598 L p .971 .686 .432 r
F P
0 g
s
.79118 .4954 m .77863 .47966 L .77669 .45402 L p .976 .678 .372 r
F P
0 g
s
.79118 .4954 m .77863 .47966 L .77669 .45402 L p .976 .678 .372 r
F P
0 g
s
.8201 .48691 m .79118 .4954 L .77863 .47966 L p .652 .756 .926 r
F P
0 g
s
.74979 .48822 m .77863 .47966 L .79118 .4954 L p .652 .756 .926 r
F P
0 g
s
.66596 .47369 m .66488 .44801 L .63673 .45669 L p .55 .333 .538 r
F P
0 g
s
.63673 .45669 m .63759 .48231 L .66596 .47369 L p .55 .333 .538 r
F P
0 g
s
.63673 .45669 m .62275 .44059 L .622 .41525 L p .972 .685 .422 r
F P
0 g
s
.66488 .44801 m .63673 .45669 L .62275 .44059 L p .654 .754 .923 r
F P
0 g
s
.66596 .47369 m .66488 .44801 L .63673 .45669 L p .55 .333 .538 r
F P
0 g
s
.63673 .45669 m .63759 .48231 L .66596 .47369 L p .55 .333 .538 r
F P
0 g
s
.59469 .44935 m .62275 .44059 L .63673 .45669 L p .654 .754 .923 r
F P
0 g
s
.59469 .44935 m .62275 .44059 L .63673 .45669 L p .654 .754 .923 r
F P
0 g
s
.62275 .44059 m .63673 .45669 L .63759 .48231 L p .972 .685 .422 r
F P
0 g
s
.62275 .44059 m .63673 .45669 L .63759 .48231 L p .972 .685 .422 r
F P
0 g
s
.50954 .43448 m .50966 .4091 L .48227 .41797 L p .541 .319 .528 r
F P
0 g
s
.48227 .41797 m .48195 .4433 L .50954 .43448 L p .541 .319 .528 r
F P
0 g
s
.48227 .41797 m .46687 .40152 L .46731 .37648 L p .964 .688 .461 r
F P
0 g
s
.48227 .41797 m .46687 .40152 L .46731 .37648 L p .964 .688 .461 r
F P
0 g
s
.50966 .4091 m .48227 .41797 L .46687 .40152 L p .656 .751 .92 r
F P
0 g
s
.50954 .43448 m .50966 .4091 L .48227 .41797 L p .541 .319 .528 r
F P
0 g
s
.48227 .41797 m .48195 .4433 L .50954 .43448 L p .541 .319 .528 r
F P
0 g
s
.43958 .41047 m .46687 .40152 L .48227 .41797 L p .656 .751 .92 r
F P
0 g
s
.43958 .41047 m .46687 .40152 L .48227 .41797 L p .656 .751 .92 r
F P
0 g
s
.46687 .40152 m .48227 .41797 L .48195 .4433 L p .964 .688 .461 r
F P
0 g
s
.50966 .4091 m .48227 .41797 L .46687 .40152 L p .656 .751 .92 r
F P
0 g
s
.46687 .40152 m .48227 .41797 L .48195 .4433 L p .964 .688 .461 r
F P
0 g
s
.35312 .39528 m .35443 .37019 L .32781 .37926 L p .53 .304 .517 r
F P
0 g
s
.32781 .37926 m .32631 .40429 L .35312 .39528 L p .53 .304 .517 r
F P
0 g
s
.32781 .37926 m .31099 .36245 L .31262 .3377 L p .954 .688 .492 r
F P
0 g
s
.35443 .37019 m .32781 .37926 L .31099 .36245 L p .658 .749 .917 r
F P
0 g
s
.35312 .39528 m .35443 .37019 L .32781 .37926 L p .53 .304 .517 r
F P
0 g
s
.32781 .37926 m .32631 .40429 L .35312 .39528 L p .53 .304 .517 r
F P
0 g
s
.28448 .37159 m .31099 .36245 L .32781 .37926 L p .658 .749 .917 r
F P
0 g
s
.31099 .36245 m .32781 .37926 L .32631 .40429 L p .954 .688 .492 r
F P
0 g
s
.35443 .37019 m .32781 .37926 L .31099 .36245 L p .658 .749 .917 r
F P
0 g
s
.31099 .36245 m .32781 .37926 L .32631 .40429 L p .954 .688 .492 r
F P
0 g
s
.19671 .35607 m .19921 .33129 L .17336 .34054 L p .518 .287 .504 r
F P
0 g
s
.17336 .34054 m .17067 .36527 L .19671 .35607 L p .518 .287 .504 r
F P
0 g
s
.19921 .33129 m .17336 .34054 L .15512 .32338 L p .66 .747 .915 r
F P
0 g
s
.19671 .35607 m .19921 .33129 L .17336 .34054 L p .518 .287 .504 r
F P
0 g
s
.17336 .34054 m .17067 .36527 L .19671 .35607 L p .518 .287 .504 r
F P
0 g
s
.15512 .32338 m .17336 .34054 L .17067 .36527 L p .943 .686 .517 r
F P
0 g
s
.55436 .53348 m .53962 .51809 L .53951 .49215 L p .966 .687 .452 r
F P
0 g
s
.55436 .53348 m .53962 .51809 L .53951 .49215 L p .966 .687 .452 r
F P
0 g
s
.58212 .52518 m .55436 .53348 L .53962 .51809 L p .649 .759 .929 r
F P
0 g
s
.51196 .52646 m .53962 .51809 L .55436 .53348 L p .649 .759 .929 r
F P
0 g
s
.42608 .51224 m .42683 .48626 L .39985 .49475 L p .541 .319 .528 r
F P
0 g
s
.39985 .49475 m .39889 .52067 L .42608 .51224 L p .541 .319 .528 r
F P
0 g
s
.3568 .48757 m .38368 .479 L .39985 .49475 L p .652 .756 .926 r
F P
0 g
s
.38368 .479 m .39985 .49475 L .39889 .52067 L p .957 .688 .485 r
F P
0 g
s
.789 .37856 m .77641 .36175 L .7745 .33699 L p .976 .675 .358 r
F P
0 g
s
.789 .37856 m .77641 .36175 L .7745 .33699 L p .976 .675 .358 r
F P
0 g
s
.81791 .36949 m .789 .37856 L .77641 .36175 L p .658 .749 .917 r
F P
0 g
s
.74758 .37089 m .77641 .36175 L .789 .37856 L p .658 .749 .917 r
F P
0 g
s
.66369 .35536 m .66263 .33057 L .63448 .33983 L p .544 .324 .532 r
F P
0 g
s
.63448 .33983 m .63532 .36457 L .66369 .35536 L p .544 .324 .532 r
F P
0 g
s
.7368 .47236 m .73518 .44666 L .70666 .45536 L p .553 .337 .541 r
F P
0 g
s
.70666 .45536 m .70805 .48099 L .7368 .47236 L p .553 .337 .541 r
F P
0 g
s
.70666 .45536 m .69331 .43924 L .69203 .41389 L p .975 .682 .398 r
F P
0 g
s
.70666 .45536 m .69331 .43924 L .69203 .41389 L p .975 .682 .398 r
F P
0 g
s
.73518 .44666 m .70666 .45536 L .69331 .43924 L p .654 .754 .923 r
F P
0 g
s
.66488 .44801 m .69331 .43924 L .70666 .45536 L p .654 .754 .923 r
F P
0 g
s
.58026 .43312 m .57984 .40773 L .55208 .41661 L p .544 .324 .532 r
F P
0 g
s
.55208 .41661 m .55229 .44195 L .58026 .43312 L p .544 .324 .532 r
F P
0 g
s
.55208 .41661 m .53731 .40014 L .53722 .37508 L p .969 .687 .442 r
F P
0 g
s
.55208 .41661 m .53731 .40014 L .53722 .37508 L p .969 .687 .442 r
F P
0 g
s
.57984 .40773 m .55208 .41661 L .53731 .40014 L p .656 .751 .92 r
F P
0 g
s
.58026 .43312 m .57984 .40773 L .55208 .41661 L p .544 .324 .532 r
F P
0 g
s
.55208 .41661 m .55229 .44195 L .58026 .43312 L p .544 .324 .532 r
F P
0 g
s
.50966 .4091 m .53731 .40014 L .55208 .41661 L p .656 .751 .92 r
F P
0 g
s
.50966 .4091 m .53731 .40014 L .55208 .41661 L p .656 .751 .92 r
F P
0 g
s
.53731 .40014 m .55208 .41661 L .55229 .44195 L p .969 .687 .442 r
F P
0 g
s
.57984 .40773 m .55208 .41661 L .53731 .40014 L p .656 .751 .92 r
F P
0 g
s
.53731 .40014 m .55208 .41661 L .55229 .44195 L p .969 .687 .442 r
F P
0 g
s
.39751 .37787 m .38132 .36104 L .38241 .33628 L p .959 .688 .477 r
F P
0 g
s
.39751 .37787 m .38132 .36104 L .38241 .33628 L p .959 .688 .477 r
F P
0 g
s
.42449 .36879 m .39751 .37787 L .38132 .36104 L p .658 .749 .917 r
F P
0 g
s
.35443 .37019 m .38132 .36104 L .39751 .37787 L p .658 .749 .917 r
F P
0 g
s
.35443 .37019 m .38132 .36104 L .39751 .37787 L p .658 .749 .917 r
F P
0 g
s
.38132 .36104 m .39751 .37787 L .39654 .40291 L p .959 .688 .477 r
F P
0 g
s
.26915 .32985 m .24293 .33912 L .22532 .32194 L p .66 .747 .915 r
F P
0 g
s
.26719 .35465 m .26915 .32985 L .24293 .33912 L p .522 .293 .509 r
F P
0 g
s
.24293 .33912 m .24078 .36386 L .26719 .35465 L p .522 .293 .509 r
F P
0 g
s
.19921 .33129 m .22532 .32194 L .24293 .33912 L p .66 .747 .915 r
F P
0 g
s
.22532 .32194 m .24293 .33912 L .24078 .36386 L p .949 .687 .505 r
F P
0 g
s
.22532 .32194 m .24293 .33912 L .24078 .36386 L p .949 .687 .505 r
F P
0 g
s
.62426 .53221 m .61015 .51679 L .60949 .49084 L p .971 .686 .432 r
F P
0 g
s
.65238 .52389 m .62426 .53221 L .61015 .51679 L p .649 .759 .929 r
F P
0 g
s
.46962 .49345 m .45409 .47768 L .45463 .45202 L p .962 .688 .469 r
F P
0 g
s
.46962 .49345 m .45409 .47768 L .45463 .45202 L p .962 .688 .469 r
F P
0 g
s
.49698 .48494 m .46962 .49345 L .45409 .47768 L p .652 .756 .926 r
F P
0 g
s
.42683 .48626 m .45409 .47768 L .46962 .49345 L p .652 .756 .926 r
F P
0 g
s
.42683 .48626 m .45409 .47768 L .46962 .49345 L p .652 .756 .926 r
F P
0 g
s
.45409 .47768 m .46962 .49345 L .4692 .51938 L p .962 .688 .469 r
F P
0 g
s
.34017 .47169 m .34158 .44599 L .31499 .45469 L p .534 .309 .521 r
F P
0 g
s
.31499 .45469 m .31338 .48033 L .34017 .47169 L p .534 .309 .521 r
F P
0 g
s
.31499 .45469 m .29803 .43856 L .29976 .4132 L p .952 .687 .499 r
F P
0 g
s
.34158 .44599 m .31499 .45469 L .29803 .43856 L p .654 .754 .923 r
F P
0 g
s
.34017 .47169 m .34158 .44599 L .31499 .45469 L p .534 .309 .521 r
F P
0 g
s
.31499 .45469 m .31338 .48033 L .34017 .47169 L p .534 .309 .521 r
F P
0 g
s
.27155 .44733 m .29803 .43856 L .31499 .45469 L p .654 .754 .923 r
F P
0 g
s
.27155 .44733 m .29803 .43856 L .31499 .45469 L p .654 .754 .923 r
F P
0 g
s
.29803 .43856 m .31499 .45469 L .31338 .48033 L p .952 .687 .499 r
F P
0 g
s
.29803 .43856 m .31499 .45469 L .31338 .48033 L p .952 .687 .499 r
F P
0 g
s
.73296 .32914 m .70444 .33841 L .69106 .32121 L p .66 .747 .915 r
F P
0 g
s
.73456 .35393 m .73296 .32914 L .70444 .33841 L p .547 .329 .535 r
F P
0 g
s
.70444 .33841 m .70581 .36316 L .73456 .35393 L p .547 .329 .535 r
F P
0 g
s
.66263 .33057 m .69106 .32121 L .70444 .33841 L p .66 .747 .915 r
F P
0 g
s
.69106 .32121 m .70444 .33841 L .70581 .36316 L p .976 .68 .386 r
F P
0 g
s
.69106 .32121 m .70444 .33841 L .70581 .36316 L p .976 .68 .386 r
F P
0 g
s
.80775 .47102 m .80558 .44532 L .77669 .45402 L p .556 .341 .544 r
F P
0 g
s
.77669 .45402 m .77863 .47966 L .80775 .47102 L p .556 .341 .544 r
F P
0 g
s
.77669 .45402 m .76398 .43788 L .76216 .41252 L p .976 .678 .372 r
F P
0 g
s
.80558 .44532 m .77669 .45402 L .76398 .43788 L p .654 .754 .923 r
F P
0 g
s
.80775 .47102 m .80558 .44532 L .77669 .45402 L p .556 .341 .544 r
F P
0 g
s
.77669 .45402 m .77863 .47966 L .80775 .47102 L p .556 .341 .544 r
F P
0 g
s
.73518 .44666 m .76398 .43788 L .77669 .45402 L p .654 .754 .923 r
F P
0 g
s
.76398 .43788 m .77669 .45402 L .77863 .47966 L p .976 .678 .372 r
F P
0 g
s
.80558 .44532 m .77669 .45402 L .76398 .43788 L p .654 .754 .923 r
F P
0 g
s
.76398 .43788 m .77669 .45402 L .77863 .47966 L p .976 .678 .372 r
F P
0 g
s
.622 .41525 m .60787 .39875 L .60723 .37369 L p .972 .685 .422 r
F P
0 g
s
.622 .41525 m .60787 .39875 L .60723 .37369 L p .972 .685 .422 r
F P
0 g
s
.65012 .40635 m .622 .41525 L .60787 .39875 L p .656 .751 .92 r
F P
0 g
s
.57984 .40773 m .60787 .39875 L .622 .41525 L p .656 .751 .92 r
F P
0 g
s
.57984 .40773 m .60787 .39875 L .622 .41525 L p .656 .751 .92 r
F P
0 g
s
.60787 .39875 m .622 .41525 L .62275 .44059 L p .972 .685 .422 r
F P
0 g
s
.49443 .39249 m .49466 .36739 L .46731 .37648 L p .537 .315 .524 r
F P
0 g
s
.46731 .37648 m .46687 .40152 L .49443 .39249 L p .537 .315 .524 r
F P
0 g
s
.46731 .37648 m .45175 .35962 L .4523 .33486 L p .964 .688 .461 r
F P
0 g
s
.49466 .36739 m .46731 .37648 L .45175 .35962 L p .658 .749 .917 r
F P
0 g
s
.49443 .39249 m .49466 .36739 L .46731 .37648 L p .537 .315 .524 r
F P
0 g
s
.46731 .37648 m .46687 .40152 L .49443 .39249 L p .537 .315 .524 r
F P
0 g
s
.42449 .36879 m .45175 .35962 L .46731 .37648 L p .658 .749 .917 r
F P
0 g
s
.42449 .36879 m .45175 .35962 L .46731 .37648 L p .658 .749 .917 r
F P
0 g
s
.45175 .35962 m .46731 .37648 L .46687 .40152 L p .964 .688 .461 r
F P
0 g
s
.45175 .35962 m .46731 .37648 L .46687 .40152 L p .964 .688 .461 r
F P
0 g
s
.33777 .35322 m .3392 .32842 L .31262 .3377 L p .526 .299 .513 r
F P
0 g
s
.31262 .3377 m .31099 .36245 L .33777 .35322 L p .526 .299 .513 r
F P
0 g
s
.56756 .50963 m .56723 .48363 L .53951 .49215 L p .547 .329 .535 r
F P
0 g
s
.53951 .49215 m .53962 .51809 L .56756 .50963 L p .547 .329 .535 r
F P
0 g
s
.53951 .49215 m .5246 .47635 L .5246 .45069 L p .966 .687 .452 r
F P
0 g
s
.53951 .49215 m .5246 .47635 L .5246 .45069 L p .966 .687 .452 r
F P
0 g
s
.56723 .48363 m .53951 .49215 L .5246 .47635 L p .652 .756 .926 r
F P
0 g
s
.56756 .50963 m .56723 .48363 L .53951 .49215 L p .547 .329 .535 r
F P
0 g
s
.53951 .49215 m .53962 .51809 L .56756 .50963 L p .547 .329 .535 r
F P
0 g
s
.49698 .48494 m .5246 .47635 L .53951 .49215 L p .652 .756 .926 r
F P
0 g
s
.49698 .48494 m .5246 .47635 L .53951 .49215 L p .652 .756 .926 r
F P
0 g
s
.5246 .47635 m .53951 .49215 L .53962 .51809 L p .966 .687 .452 r
F P
0 g
s
.56723 .48363 m .53951 .49215 L .5246 .47635 L p .652 .756 .926 r
F P
0 g
s
.5246 .47635 m .53951 .49215 L .53962 .51809 L p .966 .687 .452 r
F P
0 g
s
.38475 .45336 m .36843 .4372 L .36962 .41184 L p .957 .688 .485 r
F P
0 g
s
.38475 .45336 m .36843 .4372 L .36962 .41184 L p .957 .688 .485 r
F P
0 g
s
.41171 .44464 m .38475 .45336 L .36843 .4372 L p .654 .754 .923 r
F P
0 g
s
.34158 .44599 m .36843 .4372 L .38475 .45336 L p .654 .754 .923 r
F P
0 g
s
.34158 .44599 m .36843 .4372 L .38475 .45336 L p .654 .754 .923 r
F P
0 g
s
.36843 .4372 m .38475 .45336 L .38368 .479 L p .957 .688 .485 r
F P
0 g
s
.23 .41457 m .21225 .39806 L .21463 .37299 L p .946 .686 .511 r
F P
0 g
s
.23 .41457 m .21225 .39806 L .21463 .37299 L p .946 .686 .511 r
F P
0 g
s
.25619 .40566 m .23 .41457 L .21225 .39806 L p .656 .751 .92 r
F P
0 g
s
.18617 .40704 m .21225 .39806 L .23 .41457 L p .656 .751 .92 r
F P
0 g
s
.69426 .53093 m .68078 .5155 L .67959 .48953 L p .974 .684 .41 r
F P
0 g
s
.69426 .53093 m .68078 .5155 L .67959 .48953 L p .974 .684 .41 r
F P
0 g
s
.72275 .52261 m .69426 .53093 L .68078 .5155 L p .649 .759 .929 r
F P
0 g
s
.65238 .52389 m .68078 .5155 L .69426 .53093 L p .649 .759 .929 r
F P
0 g
s
.80553 .35251 m .80339 .3277 L .7745 .33699 L p .55 .333 .538 r
F P
0 g
s
.7745 .33699 m .77641 .36175 L .80553 .35251 L p .55 .333 .538 r
F P
0 g
s
.80339 .3277 m .7745 .33699 L .76176 .31977 L p .66 .747 .915 r
F P
0 g
s
.80553 .35251 m .80339 .3277 L .7745 .33699 L p .55 .333 .538 r
F P
0 g
s
.7745 .33699 m .77641 .36175 L .80553 .35251 L p .55 .333 .538 r
F P
0 g
s
.73296 .32914 m .76176 .31977 L .7745 .33699 L p .66 .747 .915 r
F P
0 g
s
.76176 .31977 m .7745 .33699 L .77641 .36175 L p .976 .675 .358 r
F P
0 g
s
.76176 .31977 m .7745 .33699 L .77641 .36175 L p .976 .675 .358 r
F P
0 g
s
.72203 .43039 m .72052 .40497 L .69203 .41389 L p .55 .333 .538 r
F P
0 g
s
.69203 .41389 m .69331 .43924 L .72203 .43039 L p .55 .333 .538 r
F P
0 g
s
.69203 .41389 m .67853 .39736 L .67735 .37229 L p .975 .682 .398 r
F P
0 g
s
.69203 .41389 m .67853 .39736 L .67735 .37229 L p .975 .682 .398 r
F P
0 g
s
.72052 .40497 m .69203 .41389 L .67853 .39736 L p .656 .751 .92 r
F P
0 g
s
.72203 .43039 m .72052 .40497 L .69203 .41389 L p .55 .333 .538 r
F P
0 g
s
.69203 .41389 m .69331 .43924 L .72203 .43039 L p .55 .333 .538 r
F P
0 g
s
.65012 .40635 m .67853 .39736 L .69203 .41389 L p .656 .751 .92 r
F P
0 g
s
.65012 .40635 m .67853 .39736 L .69203 .41389 L p .656 .751 .92 r
F P
0 g
s
.67853 .39736 m .69203 .41389 L .69331 .43924 L p .975 .682 .398 r
F P
0 g
s
.72052 .40497 m .69203 .41389 L .67853 .39736 L p .656 .751 .92 r
F P
0 g
s
.67853 .39736 m .69203 .41389 L .69331 .43924 L p .975 .682 .398 r
F P
0 g
s
.56525 .39109 m .56494 .36598 L .53722 .37508 L p .541 .319 .528 r
F P
0 g
s
.53722 .37508 m .53731 .40014 L .56525 .39109 L p .541 .319 .528 r
F P
0 g
s
.53722 .37508 m .52229 .3582 L .52231 .33343 L p .969 .687 .442 r
F P
0 g
s
.53722 .37508 m .52229 .3582 L .52231 .33343 L p .969 .687 .442 r
F P
0 g
s
.56494 .36598 m .53722 .37508 L .52229 .3582 L p .658 .749 .917 r
F P
0 g
s
.56525 .39109 m .56494 .36598 L .53722 .37508 L p .541 .319 .528 r
F P
0 g
s
.53722 .37508 m .53731 .40014 L .56525 .39109 L p .541 .319 .528 r
F P
0 g
s
.49466 .36739 m .52229 .3582 L .53722 .37508 L p .658 .749 .917 r
F P
0 g
s
.49466 .36739 m .52229 .3582 L .53722 .37508 L p .658 .749 .917 r
F P
0 g
s
.52229 .3582 m .53722 .37508 L .53731 .40014 L p .969 .687 .442 r
F P
0 g
s
.56494 .36598 m .53722 .37508 L .52229 .3582 L p .658 .749 .917 r
F P
0 g
s
.52229 .3582 m .53722 .37508 L .53731 .40014 L p .969 .687 .442 r
F P
0 g
s
.40847 .35179 m .40936 .32698 L .38241 .33628 L p .53 .304 .517 r
F P
0 g
s
.38241 .33628 m .38132 .36104 L .40847 .35179 L p .53 .304 .517 r
F P
0 g
s
.72275 .52261 m .75152 .5142 L .76436 .52966 L p .649 .759 .929 r
F P
0 g
s
.76436 .52966 m .75152 .5142 L .74979 .48822 L p .976 .68 .386 r
F P
0 g
s
.63846 .50832 m .63759 .48231 L .60949 .49084 L p .55 .333 .538 r
F P
0 g
s
.60949 .49084 m .61015 .51679 L .63846 .50832 L p .55 .333 .538 r
F P
0 g
s
.60949 .49084 m .59523 .47502 L .59469 .44935 L p .971 .686 .432 r
F P
0 g
s
.60949 .49084 m .59523 .47502 L .59469 .44935 L p .971 .686 .432 r
F P
0 g
s
.63759 .48231 m .60949 .49084 L .59523 .47502 L p .652 .756 .926 r
F P
0 g
s
.56723 .48363 m .59523 .47502 L .60949 .49084 L p .652 .756 .926 r
F P
0 g
s
.56723 .48363 m .59523 .47502 L .60949 .49084 L p .652 .756 .926 r
F P
0 g
s
.59523 .47502 m .60949 .49084 L .61015 .51679 L p .971 .686 .432 r
F P
0 g
s
.48162 .46901 m .48195 .4433 L .45463 .45202 L p .541 .319 .528 r
F P
0 g
s
.45463 .45202 m .45409 .47768 L .48162 .46901 L p .541 .319 .528 r
F P
0 g
s
.45463 .45202 m .43893 .43584 L .43958 .41047 L p .962 .688 .469 r
F P
0 g
s
.48195 .4433 m .45463 .45202 L .43893 .43584 L p .654 .754 .923 r
F P
0 g
s
.48162 .46901 m .48195 .4433 L .45463 .45202 L p .541 .319 .528 r
F P
0 g
s
.45463 .45202 m .45409 .47768 L .48162 .46901 L p .541 .319 .528 r
F P
0 g
s
.41171 .44464 m .43893 .43584 L .45463 .45202 L p .654 .754 .923 r
F P
0 g
s
.43893 .43584 m .45463 .45202 L .45409 .47768 L p .962 .688 .469 r
F P
0 g
s
.48195 .4433 m .45463 .45202 L .43893 .43584 L p .654 .754 .923 r
F P
0 g
s
.43893 .43584 m .45463 .45202 L .45409 .47768 L p .962 .688 .469 r
F P
0 g
s
.29976 .4132 m .28263 .39667 L .28448 .37159 L p .952 .687 .499 r
F P
0 g
s
.32631 .40429 m .29976 .4132 L .28263 .39667 L p .656 .751 .92 r
F P
0 g
s
.25619 .40566 m .28263 .39667 L .29976 .4132 L p .656 .751 .92 r
F P
0 g
s
.28263 .39667 m .29976 .4132 L .29803 .43856 L p .952 .687 .499 r
F P
0 g
s
.37197 .52902 m .35551 .51355 L .3568 .48757 L p .954 .688 .492 r
F P
0 g
s
.37197 .52902 m .35551 .51355 L .3568 .48757 L p .954 .688 .492 r
F P
0 g
s
.39889 .52067 m .37197 .52902 L .35551 .51355 L p .649 .759 .929 r
F P
0 g
s
.32869 .52196 m .35551 .51355 L .37197 .52902 L p .649 .759 .929 r
F P
0 g
s
.79308 .42902 m .79102 .4036 L .76216 .41252 L p .553 .337 .541 r
F P
0 g
s
.76216 .41252 m .76398 .43788 L .79308 .42902 L p .553 .337 .541 r
F P
0 g
s
.76216 .41252 m .74929 .39597 L .74758 .37089 L p .976 .678 .372 r
F P
0 g
s
.79102 .4036 m .76216 .41252 L .74929 .39597 L p .656 .751 .92 r
F P
0 g
s
.79308 .42902 m .79102 .4036 L .76216 .41252 L p .553 .337 .541 r
F P
0 g
s
.76216 .41252 m .76398 .43788 L .79308 .42902 L p .553 .337 .541 r
F P
0 g
s
.72052 .40497 m .74929 .39597 L .76216 .41252 L p .656 .751 .92 r
F P
0 g
s
.74929 .39597 m .76216 .41252 L .76398 .43788 L p .976 .678 .372 r
F P
0 g
s
.63618 .38969 m .63532 .36457 L .60723 .37369 L p .544 .324 .532 r
F P
0 g
s
.60723 .37369 m .60787 .39875 L .63618 .38969 L p .544 .324 .532 r
F P
0 g
s
.60723 .37369 m .59294 .35678 L .59242 .332 L p .972 .685 .422 r
F P
0 g
s
.63532 .36457 m .60723 .37369 L .59294 .35678 L p .658 .749 .917 r
F P
0 g
s
.63618 .38969 m .63532 .36457 L .60723 .37369 L p .544 .324 .532 r
F P
0 g
s
.60723 .37369 m .60787 .39875 L .63618 .38969 L p .544 .324 .532 r
F P
0 g
s
.56494 .36598 m .59294 .35678 L .60723 .37369 L p .658 .749 .917 r
F P
0 g
s
.56494 .36598 m .59294 .35678 L .60723 .37369 L p .658 .749 .917 r
F P
0 g
s
.59294 .35678 m .60723 .37369 L .60787 .39875 L p .972 .685 .422 r
F P
0 g
s
.59294 .35678 m .60723 .37369 L .60787 .39875 L p .972 .685 .422 r
F P
0 g
s
.40936 .32698 m .43658 .31759 L .4523 .33486 L p .66 .747 .915 r
F P
0 g
s
.43658 .31759 m .4523 .33486 L .45175 .35962 L p .964 .688 .461 r
F P
0 g
s
.70947 .50701 m .70805 .48099 L .67959 .48953 L p .553 .337 .541 r
F P
0 g
s
.67959 .48953 m .68078 .5155 L .70947 .50701 L p .553 .337 .541 r
F P
0 g
s
.63759 .48231 m .66596 .47369 L .67959 .48953 L p .652 .756 .926 r
F P
0 g
s
.67959 .48953 m .66596 .47369 L .66488 .44801 L p .974 .684 .41 r
F P
0 g
s
.55251 .46767 m .55229 .44195 L .5246 .45069 L p .544 .324 .532 r
F P
0 g
s
.5246 .45069 m .5246 .47635 L .55251 .46767 L p .544 .324 .532 r
F P
0 g
s
.5246 .45069 m .50954 .43448 L .50966 .4091 L p .966 .687 .452 r
F P
0 g
s
.5246 .45069 m .50954 .43448 L .50966 .4091 L p .966 .687 .452 r
F P
0 g
s
.55229 .44195 m .5246 .45069 L .50954 .43448 L p .654 .754 .923 r
F P
0 g
s
.55251 .46767 m .55229 .44195 L .5246 .45069 L p .544 .324 .532 r
F P
0 g
s
.5246 .45069 m .5246 .47635 L .55251 .46767 L p .544 .324 .532 r
F P
0 g
s
.48195 .4433 m .50954 .43448 L .5246 .45069 L p .654 .754 .923 r
F P
0 g
s
.48195 .4433 m .50954 .43448 L .5246 .45069 L p .654 .754 .923 r
F P
0 g
s
.50954 .43448 m .5246 .45069 L .5246 .47635 L p .966 .687 .452 r
F P
0 g
s
.55229 .44195 m .5246 .45069 L .50954 .43448 L p .654 .754 .923 r
F P
0 g
s
.50954 .43448 m .5246 .45069 L .5246 .47635 L p .966 .687 .452 r
F P
0 g
s
.39555 .42833 m .39654 .40291 L .36962 .41184 L p .534 .309 .521 r
F P
0 g
s
.36962 .41184 m .36843 .4372 L .39555 .42833 L p .534 .309 .521 r
F P
0 g
s
.36962 .41184 m .35312 .39528 L .35443 .37019 L p .957 .688 .485 r
F P
0 g
s
.36962 .41184 m .35312 .39528 L .35443 .37019 L p .957 .688 .485 r
F P
0 g
s
.39654 .40291 m .36962 .41184 L .35312 .39528 L p .656 .751 .92 r
F P
0 g
s
.39555 .42833 m .39654 .40291 L .36962 .41184 L p .534 .309 .521 r
F P
0 g
s
.36962 .41184 m .36843 .4372 L .39555 .42833 L p .534 .309 .521 r
F P
0 g
s
.32631 .40429 m .35312 .39528 L .36962 .41184 L p .656 .751 .92 r
F P
0 g
s
.32631 .40429 m .35312 .39528 L .36962 .41184 L p .656 .751 .92 r
F P
0 g
s
.35312 .39528 m .36962 .41184 L .36843 .4372 L p .957 .688 .485 r
F P
0 g
s
.39654 .40291 m .36962 .41184 L .35312 .39528 L p .656 .751 .92 r
F P
0 g
s
.35312 .39528 m .36962 .41184 L .36843 .4372 L p .957 .688 .485 r
F P
0 g
s
.23859 .38899 m .24078 .36386 L .21463 .37299 L p .522 .293 .509 r
F P
0 g
s
.21463 .37299 m .21225 .39806 L .23859 .38899 L p .522 .293 .509 r
F P
0 g
s
.21463 .37299 m .19671 .35607 L .19921 .33129 L p .946 .686 .511 r
F P
0 g
s
.21463 .37299 m .19671 .35607 L .19921 .33129 L p .946 .686 .511 r
F P
0 g
s
.24078 .36386 m .21463 .37299 L .19671 .35607 L p .658 .749 .917 r
F P
0 g
s
.23859 .38899 m .24078 .36386 L .21463 .37299 L p .522 .293 .509 r
F P
0 g
s
.21463 .37299 m .21225 .39806 L .23859 .38899 L p .522 .293 .509 r
F P
0 g
s
.17067 .36527 m .19671 .35607 L .21463 .37299 L p .658 .749 .917 r
F P
0 g
s
.17067 .36527 m .19671 .35607 L .21463 .37299 L p .658 .749 .917 r
F P
0 g
s
.19671 .35607 m .21463 .37299 L .21225 .39806 L p .946 .686 .511 r
F P
0 g
s
.24078 .36386 m .21463 .37299 L .19671 .35607 L p .658 .749 .917 r
F P
0 g
s
.19671 .35607 m .21463 .37299 L .21225 .39806 L p .946 .686 .511 r
F P
0 g
s
.44191 .52774 m .42608 .51224 L .42683 .48626 L p .959 .688 .477 r
F P
0 g
s
.44191 .52774 m .42608 .51224 L .42683 .48626 L p .959 .688 .477 r
F P
0 g
s
.4692 .51938 m .44191 .52774 L .42608 .51224 L p .649 .759 .929 r
F P
0 g
s
.39889 .52067 m .42608 .51224 L .44191 .52774 L p .649 .759 .929 r
F P
0 g
s
.28687 .48888 m .2696 .47302 L .27155 .44733 L p .949 .687 .505 r
F P
0 g
s
.31338 .48033 m .28687 .48888 L .2696 .47302 L p .652 .756 .926 r
F P
0 g
s
.70721 .38829 m .70581 .36316 L .67735 .37229 L p .547 .329 .535 r
F P
0 g
s
.67735 .37229 m .67853 .39736 L .70721 .38829 L p .547 .329 .535 r
F P
0 g
s
.67735 .37229 m .66369 .35536 L .66263 .33057 L p .975 .682 .398 r
F P
0 g
s
.67735 .37229 m .66369 .35536 L .66263 .33057 L p .975 .682 .398 r
F P
0 g
s
.70581 .36316 m .67735 .37229 L .66369 .35536 L p .658 .749 .917 r
F P
0 g
s
.70721 .38829 m .70581 .36316 L .67735 .37229 L p .547 .329 .535 r
F P
0 g
s
.67735 .37229 m .67853 .39736 L .70721 .38829 L p .547 .329 .535 r
F P
0 g
s
.63532 .36457 m .66369 .35536 L .67735 .37229 L p .658 .749 .917 r
F P
0 g
s
.63532 .36457 m .66369 .35536 L .67735 .37229 L p .658 .749 .917 r
F P
0 g
s
.66369 .35536 m .67735 .37229 L .67853 .39736 L p .975 .682 .398 r
F P
0 g
s
.70581 .36316 m .67735 .37229 L .66369 .35536 L p .658 .749 .917 r
F P
0 g
s
.66369 .35536 m .67735 .37229 L .67853 .39736 L p .975 .682 .398 r
F P
0 g
s
.55019 .34893 m .55 .3241 L .52231 .33343 L p .537 .315 .524 r
F P
0 g
s
.52231 .33343 m .52229 .3582 L .55019 .34893 L p .537 .315 .524 r
F P
0 g
s
.47962 .32554 m .50722 .31614 L .52231 .33343 L p .66 .747 .915 r
F P
0 g
s
.50722 .31614 m .52231 .33343 L .52229 .3582 L p .969 .687 .442 r
F P
0 g
s
.74979 .48822 m .7368 .47236 L .73518 .44666 L p .976 .68 .386 r
F P
0 g
s
.74979 .48822 m .7368 .47236 L .73518 .44666 L p .976 .68 .386 r
F P
0 g
s
.77863 .47966 m .74979 .48822 L .7368 .47236 L p .652 .756 .926 r
F P
0 g
s
.70805 .48099 m .7368 .47236 L .74979 .48822 L p .652 .756 .926 r
F P
0 g
s
.70805 .48099 m .7368 .47236 L .74979 .48822 L p .652 .756 .926 r
F P
0 g
s
.7368 .47236 m .74979 .48822 L .75152 .5142 L p .976 .68 .386 r
F P
0 g
s
.62351 .46633 m .62275 .44059 L .59469 .44935 L p .547 .329 .535 r
F P
0 g
s
.59469 .44935 m .59523 .47502 L .62351 .46633 L p .547 .329 .535 r
F P
0 g
s
.59469 .44935 m .58026 .43312 L .57984 .40773 L p .971 .686 .432 r
F P
0 g
s
.59469 .44935 m .58026 .43312 L .57984 .40773 L p .971 .686 .432 r
F P
0 g
s
.62275 .44059 m .59469 .44935 L .58026 .43312 L p .654 .754 .923 r
F P
0 g
s
.62351 .46633 m .62275 .44059 L .59469 .44935 L p .547 .329 .535 r
F P
0 g
s
.59469 .44935 m .59523 .47502 L .62351 .46633 L p .547 .329 .535 r
F P
0 g
s
.55229 .44195 m .58026 .43312 L .59469 .44935 L p .654 .754 .923 r
F P
0 g
s
.55229 .44195 m .58026 .43312 L .59469 .44935 L p .654 .754 .923 r
F P
0 g
s
.58026 .43312 m .59469 .44935 L .59523 .47502 L p .971 .686 .432 r
F P
0 g
s
.62275 .44059 m .59469 .44935 L .58026 .43312 L p .654 .754 .923 r
F P
0 g
s
.58026 .43312 m .59469 .44935 L .59523 .47502 L p .971 .686 .432 r
F P
0 g
s
.46643 .42696 m .46687 .40152 L .43958 .41047 L p .537 .315 .524 r
F P
0 g
s
.43958 .41047 m .43893 .43584 L .46643 .42696 L p .537 .315 .524 r
F P
0 g
s
.43958 .41047 m .42372 .39388 L .42449 .36879 L p .962 .688 .469 r
F P
0 g
s
.46687 .40152 m .43958 .41047 L .42372 .39388 L p .656 .751 .92 r
F P
0 g
s
.39654 .40291 m .42372 .39388 L .43958 .41047 L p .656 .751 .92 r
F P
0 g
s
.42372 .39388 m .43958 .41047 L .43893 .43584 L p .962 .688 .469 r
F P
0 g
s
.30934 .38758 m .31099 .36245 L .28448 .37159 L p .526 .299 .513 r
F P
0 g
s
.28448 .37159 m .28263 .39667 L .30934 .38758 L p .526 .299 .513 r
F P
0 g
s
.31099 .36245 m .28448 .37159 L .26719 .35465 L p .658 .749 .917 r
F P
0 g
s
.30934 .38758 m .31099 .36245 L .28448 .37159 L p .526 .299 .513 r
F P
0 g
s
.28448 .37159 m .28263 .39667 L .30934 .38758 L p .526 .299 .513 r
F P
0 g
s
.24078 .36386 m .26719 .35465 L .28448 .37159 L p .658 .749 .917 r
F P
0 g
s
.26719 .35465 m .28448 .37159 L .28263 .39667 L p .952 .687 .499 r
F P
0 g
s
.26719 .35465 m .28448 .37159 L .28263 .39667 L p .952 .687 .499 r
F P
0 g
s
.15512 .32338 m .12937 .33272 L .11065 .31541 L p .66 .747 .915 r
F P
0 g
s
.15226 .34821 m .15512 .32338 L .12937 .33272 L p .514 .281 .5 r
F P
0 g
s
.12937 .33272 m .12634 .35749 L .15226 .34821 L p .514 .281 .5 r
F P
0 g
s
.11065 .31541 m .12937 .33272 L .12634 .35749 L p .941 .685 .523 r
F P
0 g
s
.51196 .52646 m .49676 .51094 L .49698 .48494 L p .964 .688 .461 r
F P
0 g
s
.53962 .51809 m .51196 .52646 L .49676 .51094 L p .649 .759 .929 r
F P
0 g
s
.38259 .50504 m .38368 .479 L .3568 .48757 L p .537 .315 .524 r
F P
0 g
s
.3568 .48757 m .35551 .51355 L .38259 .50504 L p .537 .315 .524 r
F P
0 g
s
.3568 .48757 m .34017 .47169 L .34158 .44599 L p .954 .688 .492 r
F P
0 g
s
.3568 .48757 m .34017 .47169 L .34158 .44599 L p .954 .688 .492 r
F P
0 g
s
.38368 .479 m .3568 .48757 L .34017 .47169 L p .652 .756 .926 r
F P
0 g
s
.38259 .50504 m .38368 .479 L .3568 .48757 L p .537 .315 .524 r
F P
0 g
s
.3568 .48757 m .35551 .51355 L .38259 .50504 L p .537 .315 .524 r
F P
0 g
s
.31338 .48033 m .34017 .47169 L .3568 .48757 L p .652 .756 .926 r
F P
0 g
s
.34017 .47169 m .3568 .48757 L .35551 .51355 L p .954 .688 .492 r
F P
0 g
s
.38368 .479 m .3568 .48757 L .34017 .47169 L p .652 .756 .926 r
F P
0 g
s
.74758 .37089 m .73456 .35393 L .73296 .32914 L p .976 .678 .372 r
F P
0 g
s
.77641 .36175 m .74758 .37089 L .73456 .35393 L p .658 .749 .917 r
F P
0 g
s
.77836 .38688 m .77641 .36175 L .74758 .37089 L p .55 .333 .538 r
F P
0 g
s
.74758 .37089 m .74929 .39597 L .77836 .38688 L p .55 .333 .538 r
F P
0 g
s
.70581 .36316 m .73456 .35393 L .74758 .37089 L p .658 .749 .917 r
F P
0 g
s
.73456 .35393 m .74758 .37089 L .74929 .39597 L p .976 .678 .372 r
F P
0 g
s
.77641 .36175 m .74758 .37089 L .73456 .35393 L p .658 .749 .917 r
F P
0 g
s
.73456 .35393 m .74758 .37089 L .74929 .39597 L p .976 .678 .372 r
F P
0 g
s
.62048 .32266 m .59242 .332 L .57796 .31468 L p .66 .747 .915 r
F P
0 g
s
.62122 .34749 m .62048 .32266 L .59242 .332 L p .541 .319 .528 r
F P
0 g
s
.59242 .332 m .59294 .35678 L .62122 .34749 L p .541 .319 .528 r
F P
0 g
s
.57796 .31468 m .59242 .332 L .59294 .35678 L p .972 .685 .422 r
F P
0 g
s
.77863 .47966 m .80775 .47102 L .8201 .48691 L p .652 .756 .926 r
F P
0 g
s
.8201 .48691 m .80775 .47102 L .80558 .44532 L p .976 .675 .358 r
F P
0 g
s
.66488 .44801 m .65109 .43175 L .65012 .40635 L p .974 .684 .41 r
F P
0 g
s
.69331 .43924 m .66488 .44801 L .65109 .43175 L p .654 .754 .923 r
F P
0 g
s
.69461 .46498 m .69331 .43924 L .66488 .44801 L p .55 .333 .538 r
F P
0 g
s
.66488 .44801 m .66596 .47369 L .69461 .46498 L p .55 .333 .538 r
F P
0 g
s
.62275 .44059 m .65109 .43175 L .66488 .44801 L p .654 .754 .923 r
F P
0 g
s
.65109 .43175 m .66488 .44801 L .66596 .47369 L p .974 .684 .41 r
F P
0 g
s
.69331 .43924 m .66488 .44801 L .65109 .43175 L p .654 .754 .923 r
F P
0 g
s
.65109 .43175 m .66488 .44801 L .66596 .47369 L p .974 .684 .41 r
F P
0 g
s
.53741 .42558 m .53731 .40014 L .50966 .4091 L p .541 .319 .528 r
F P
0 g
s
.50966 .4091 m .50954 .43448 L .53741 .42558 L p .541 .319 .528 r
F P
0 g
s
.50966 .4091 m .49443 .39249 L .49466 .36739 L p .966 .687 .452 r
F P
0 g
s
.50966 .4091 m .49443 .39249 L .49466 .36739 L p .966 .687 .452 r
F P
0 g
s
.53731 .40014 m .50966 .4091 L .49443 .39249 L p .656 .751 .92 r
F P
0 g
s
.53741 .42558 m .53731 .40014 L .50966 .4091 L p .541 .319 .528 r
F P
0 g
s
.50966 .4091 m .50954 .43448 L .53741 .42558 L p .541 .319 .528 r
F P
0 g
s
.46687 .40152 m .49443 .39249 L .50966 .4091 L p .656 .751 .92 r
F P
0 g
s
.46687 .40152 m .49443 .39249 L .50966 .4091 L p .656 .751 .92 r
F P
0 g
s
.49443 .39249 m .50966 .4091 L .50954 .43448 L p .966 .687 .452 r
F P
0 g
s
.53731 .40014 m .50966 .4091 L .49443 .39249 L p .656 .751 .92 r
F P
0 g
s
.49443 .39249 m .50966 .4091 L .50954 .43448 L p .966 .687 .452 r
F P
0 g
s
.38021 .38618 m .38132 .36104 L .35443 .37019 L p .53 .304 .517 r
F P
0 g
s
.35443 .37019 m .35312 .39528 L .38021 .38618 L p .53 .304 .517 r
F P
0 g
s
.35443 .37019 m .33777 .35322 L .3392 .32842 L p .957 .688 .485 r
F P
0 g
s
.38132 .36104 m .35443 .37019 L .33777 .35322 L p .658 .749 .917 r
F P
0 g
s
.38021 .38618 m .38132 .36104 L .35443 .37019 L p .53 .304 .517 r
F P
0 g
s
.35443 .37019 m .35312 .39528 L .38021 .38618 L p .53 .304 .517 r
F P
0 g
s
.31099 .36245 m .33777 .35322 L .35443 .37019 L p .658 .749 .917 r
F P
0 g
s
.31099 .36245 m .33777 .35322 L .35443 .37019 L p .658 .749 .917 r
F P
0 g
s
.33777 .35322 m .35443 .37019 L .35312 .39528 L p .957 .688 .485 r
F P
0 g
s
.33777 .35322 m .35443 .37019 L .35312 .39528 L p .957 .688 .485 r
F P
0 g
s
.22301 .34678 m .22532 .32194 L .19921 .33129 L p .518 .287 .504 r
F P
0 g
s
.19921 .33129 m .19671 .35607 L .22301 .34678 L p .518 .287 .504 r
F P
0 g
s
.22532 .32194 m .19921 .33129 L .18112 .31395 L p .66 .747 .915 r
F P
0 g
s
.22301 .34678 m .22532 .32194 L .19921 .33129 L p .518 .287 .504 r
F P
0 g
s
.19921 .33129 m .19671 .35607 L .22301 .34678 L p .518 .287 .504 r
F P
0 g
s
.15512 .32338 m .18112 .31395 L .19921 .33129 L p .66 .747 .915 r
F P
0 g
s
.18112 .31395 m .19921 .33129 L .19671 .35607 L p .946 .686 .511 r
F P
0 g
s
.18112 .31395 m .19921 .33129 L .19671 .35607 L p .946 .686 .511 r
F P
0 g
s
.58212 .52518 m .56756 .50963 L .56723 .48363 L p .969 .687 .442 r
F P
0 g
s
.58212 .52518 m .56756 .50963 L .56723 .48363 L p .969 .687 .442 r
F P
0 g
s
.61015 .51679 m .58212 .52518 L .56756 .50963 L p .649 .759 .929 r
F P
0 g
s
.53962 .51809 m .56756 .50963 L .58212 .52518 L p .649 .759 .929 r
F P
0 g
s
.45354 .50373 m .45409 .47768 L .42683 .48626 L p .541 .319 .528 r
F P
0 g
s
.42683 .48626 m .42608 .51224 L .45354 .50373 L p .541 .319 .528 r
F P
0 g
s
.42683 .48626 m .41084 .47035 L .41171 .44464 L p .959 .688 .477 r
F P
0 g
s
.45409 .47768 m .42683 .48626 L .41084 .47035 L p .652 .756 .926 r
F P
0 g
s
.29628 .46431 m .29803 .43856 L .27155 .44733 L p .53 .304 .517 r
F P
0 g
s
.27155 .44733 m .2696 .47302 L .29628 .46431 L p .53 .304 .517 r
F P
0 g
s
.27155 .44733 m .25412 .43107 L .25619 .40566 L p .949 .687 .505 r
F P
0 g
s
.29803 .43856 m .27155 .44733 L .25412 .43107 L p .654 .754 .923 r
F P
0 g
s
.29628 .46431 m .29803 .43856 L .27155 .44733 L p .53 .304 .517 r
F P
0 g
s
.27155 .44733 m .2696 .47302 L .29628 .46431 L p .53 .304 .517 r
F P
0 g
s
.25412 .43107 m .27155 .44733 L .2696 .47302 L p .949 .687 .505 r
F P
0 g
s
.29803 .43856 m .27155 .44733 L .25412 .43107 L p .654 .754 .923 r
F P
0 g
s
.77641 .36175 m .80553 .35251 L .81791 .36949 L p .658 .749 .917 r
F P
0 g
s
.81791 .36949 m .80553 .35251 L .80339 .3277 L p .976 .672 .343 r
F P
0 g
s
.69235 .34606 m .69106 .32121 L .66263 .33057 L p .544 .324 .532 r
F P
0 g
s
.66263 .33057 m .66369 .35536 L .69235 .34606 L p .544 .324 .532 r
F P
0 g
s
.45119 .38477 m .45175 .35962 L .42449 .36879 L p .534 .309 .521 r
F P
0 g
s
.42449 .36879 m .42372 .39388 L .45119 .38477 L p .534 .309 .521 r
F P
0 g
s
.42449 .36879 m .40847 .35179 L .40936 .32698 L p .962 .688 .469 r
F P
0 g
s
.42449 .36879 m .40847 .35179 L .40936 .32698 L p .962 .688 .469 r
F P
0 g
s
.45175 .35962 m .42449 .36879 L .40847 .35179 L p .658 .749 .917 r
F P
0 g
s
.38132 .36104 m .40847 .35179 L .42449 .36879 L p .658 .749 .917 r
F P
0 g
s
.22532 .32194 m .25169 .3125 L .26915 .32985 L p .66 .747 .915 r
F P
0 g
s
.25169 .3125 m .26915 .32985 L .26719 .35465 L p .952 .687 .499 r
F P
0 g
s
.76583 .46364 m .76398 .43788 L .73518 .44666 L p .553 .337 .541 r
F P
0 g
s
.73518 .44666 m .7368 .47236 L .76583 .46364 L p .553 .337 .541 r
F P
0 g
s
.73518 .44666 m .72203 .43039 L .72052 .40497 L p .976 .68 .386 r
F P
0 g
s
.76398 .43788 m .73518 .44666 L .72203 .43039 L p .654 .754 .923 r
F P
0 g
s
.76583 .46364 m .76398 .43788 L .73518 .44666 L p .553 .337 .541 r
F P
0 g
s
.73518 .44666 m .7368 .47236 L .76583 .46364 L p .553 .337 .541 r
F P
0 g
s
.69331 .43924 m .72203 .43039 L .73518 .44666 L p .654 .754 .923 r
F P
0 g
s
.72203 .43039 m .73518 .44666 L .7368 .47236 L p .976 .68 .386 r
F P
0 g
s
.60851 .4242 m .60787 .39875 L .57984 .40773 L p .544 .324 .532 r
F P
0 g
s
.57984 .40773 m .58026 .43312 L .60851 .4242 L p .544 .324 .532 r
F P
0 g
s
.57984 .40773 m .56525 .39109 L .56494 .36598 L p .971 .686 .432 r
F P
0 g
s
.57984 .40773 m .56525 .39109 L .56494 .36598 L p .971 .686 .432 r
F P
0 g
s
.60787 .39875 m .57984 .40773 L .56525 .39109 L p .656 .751 .92 r
F P
0 g
s
.60851 .4242 m .60787 .39875 L .57984 .40773 L p .544 .324 .532 r
F P
0 g
s
.57984 .40773 m .58026 .43312 L .60851 .4242 L p .544 .324 .532 r
F P
0 g
s
.53731 .40014 m .56525 .39109 L .57984 .40773 L p .656 .751 .92 r
F P
0 g
s
.53731 .40014 m .56525 .39109 L .57984 .40773 L p .656 .751 .92 r
F P
0 g
s
.56525 .39109 m .57984 .40773 L .58026 .43312 L p .971 .686 .432 r
F P
0 g
s
.60787 .39875 m .57984 .40773 L .56525 .39109 L p .656 .751 .92 r
F P
0 g
s
.56525 .39109 m .57984 .40773 L .58026 .43312 L p .971 .686 .432 r
F P
0 g
s
.61015 .51679 m .63846 .50832 L .65238 .52389 L p .649 .759 .929 r
F P
0 g
s
.65238 .52389 m .63846 .50832 L .63759 .48231 L p .972 .685 .422 r
F P
0 g
s
.5246 .50241 m .5246 .47635 L .49698 .48494 L p .544 .324 .532 r
F P
0 g
s
.49698 .48494 m .49676 .51094 L .5246 .50241 L p .544 .324 .532 r
F P
0 g
s
.49698 .48494 m .48162 .46901 L .48195 .4433 L p .964 .688 .461 r
F P
0 g
s
.49698 .48494 m .48162 .46901 L .48195 .4433 L p .964 .688 .461 r
F P
0 g
s
.5246 .47635 m .49698 .48494 L .48162 .46901 L p .652 .756 .926 r
F P
0 g
s
.5246 .50241 m .5246 .47635 L .49698 .48494 L p .544 .324 .532 r
F P
0 g
s
.49698 .48494 m .49676 .51094 L .5246 .50241 L p .544 .324 .532 r
F P
0 g
s
.45409 .47768 m .48162 .46901 L .49698 .48494 L p .652 .756 .926 r
F P
0 g
s
.48162 .46901 m .49698 .48494 L .49676 .51094 L p .964 .688 .461 r
F P
0 g
s
.5246 .47635 m .49698 .48494 L .48162 .46901 L p .652 .756 .926 r
F P
0 g
s
.36722 .46296 m .36843 .4372 L .34158 .44599 L p .534 .309 .521 r
F P
0 g
s
.34158 .44599 m .34017 .47169 L .36722 .46296 L p .534 .309 .521 r
F P
0 g
s
.34158 .44599 m .32478 .4297 L .32631 .40429 L p .954 .688 .492 r
F P
0 g
s
.36843 .4372 m .34158 .44599 L .32478 .4297 L p .654 .754 .923 r
F P
0 g
s
.29803 .43856 m .32478 .4297 L .34158 .44599 L p .654 .754 .923 r
F P
0 g
s
.32478 .4297 m .34158 .44599 L .34017 .47169 L p .954 .688 .492 r
F P
0 g
s
.18617 .40704 m .16794 .39039 L .17067 .36527 L p .943 .686 .517 r
F P
0 g
s
.21225 .39806 m .18617 .40704 L .16794 .39039 L p .656 .751 .92 r
F P
0 g
s
.7636 .34462 m .76176 .31977 L .73296 .32914 L p .547 .329 .535 r
F P
0 g
s
.73296 .32914 m .73456 .35393 L .7636 .34462 L p .547 .329 .535 r
F P
0 g
s
.76176 .31977 m .73296 .32914 L .71978 .31177 L p .66 .747 .915 r
F P
0 g
s
.7636 .34462 m .76176 .31977 L .73296 .32914 L p .547 .329 .535 r
F P
0 g
s
.73296 .32914 m .73456 .35393 L .7636 .34462 L p .547 .329 .535 r
F P
0 g
s
.69106 .32121 m .71978 .31177 L .73296 .32914 L p .66 .747 .915 r
F P
0 g
s
.71978 .31177 m .73296 .32914 L .73456 .35393 L p .976 .678 .372 r
F P
0 g
s
.71978 .31177 m .73296 .32914 L .73456 .35393 L p .976 .678 .372 r
F P
0 g
s
.76398 .43788 m .79308 .42902 L .80558 .44532 L p .654 .754 .923 r
F P
0 g
s
.76398 .43788 m .79308 .42902 L .80558 .44532 L p .654 .754 .923 r
F P
0 g
s
.79308 .42902 m .80558 .44532 L .80775 .47102 L p .976 .675 .358 r
F P
0 g
s
.80558 .44532 m .79308 .42902 L .79102 .4036 L p .976 .675 .358 r
F P
0 g
s
.67972 .42282 m .67853 .39736 L .65012 .40635 L p .547 .329 .535 r
F P
0 g
s
.65012 .40635 m .65109 .43175 L .67972 .42282 L p .547 .329 .535 r
F P
0 g
s
.65012 .40635 m .63618 .38969 L .63532 .36457 L p .974 .684 .41 r
F P
0 g
s
.65012 .40635 m .63618 .38969 L .63532 .36457 L p .974 .684 .41 r
F P
0 g
s
.67853 .39736 m .65012 .40635 L .63618 .38969 L p .656 .751 .92 r
F P
0 g
s
.60787 .39875 m .63618 .38969 L .65012 .40635 L p .656 .751 .92 r
F P
0 g
s
.52227 .38336 m .52229 .3582 L .49466 .36739 L p .537 .315 .524 r
F P
0 g
s
.49466 .36739 m .49443 .39249 L .52227 .38336 L p .537 .315 .524 r
F P
0 g
s
.49466 .36739 m .47928 .35036 L .47962 .32554 L p .966 .687 .452 r
F P
0 g
s
.52229 .3582 m .49466 .36739 L .47928 .35036 L p .658 .749 .917 r
F P
0 g
s
.52227 .38336 m .52229 .3582 L .49466 .36739 L p .537 .315 .524 r
F P
0 g
s
.49466 .36739 m .49443 .39249 L .52227 .38336 L p .537 .315 .524 r
F P
0 g
s
.45175 .35962 m .47928 .35036 L .49466 .36739 L p .658 .749 .917 r
F P
0 g
s
.47928 .35036 m .49466 .36739 L .49443 .39249 L p .966 .687 .452 r
F P
0 g
s
.52229 .3582 m .49466 .36739 L .47928 .35036 L p .658 .749 .917 r
F P
0 g
s
.47928 .35036 m .49466 .36739 L .49443 .39249 L p .966 .687 .452 r
F P
0 g
s
.36605 .31904 m .3392 .32842 L .32238 .31103 L p .66 .747 .915 r
F P
0 g
s
.36483 .3439 m .36605 .31904 L .3392 .32842 L p .526 .299 .513 r
F P
0 g
s
.3392 .32842 m .33777 .35322 L .36483 .3439 L p .526 .299 .513 r
F P
0 g
s
.32238 .31103 m .3392 .32842 L .33777 .35322 L p .957 .688 .485 r
F P
0 g
s
.72275 .52261 m .70947 .50701 L .70805 .48099 L p .975 .682 .398 r
F P
0 g
s
.72275 .52261 m .70947 .50701 L .70805 .48099 L p .975 .682 .398 r
F P
0 g
s
.75152 .5142 m .72275 .52261 L .70947 .50701 L p .649 .759 .929 r
F P
0 g
s
.68078 .5155 m .70947 .50701 L .72275 .52261 L p .649 .759 .929 r
F P
0 g
s
.59577 .50109 m .59523 .47502 L .56723 .48363 L p .547 .329 .535 r
F P
0 g
s
.56723 .48363 m .56756 .50963 L .59577 .50109 L p .547 .329 .535 r
F P
0 g
s
.56723 .48363 m .55251 .46767 L .55229 .44195 L p .969 .687 .442 r
F P
0 g
s
.56723 .48363 m .55251 .46767 L .55229 .44195 L p .969 .687 .442 r
F P
0 g
s
.59523 .47502 m .56723 .48363 L .55251 .46767 L p .652 .756 .926 r
F P
0 g
s
.59577 .50109 m .59523 .47502 L .56723 .48363 L p .547 .329 .535 r
F P
0 g
s
.56723 .48363 m .56756 .50963 L .59577 .50109 L p .547 .329 .535 r
F P
0 g
s
.5246 .47635 m .55251 .46767 L .56723 .48363 L p .652 .756 .926 r
F P
0 g
s
.5246 .47635 m .55251 .46767 L .56723 .48363 L p .652 .756 .926 r
F P
0 g
s
.55251 .46767 m .56723 .48363 L .56756 .50963 L p .969 .687 .442 r
F P
0 g
s
.59523 .47502 m .56723 .48363 L .55251 .46767 L p .652 .756 .926 r
F P
0 g
s
.55251 .46767 m .56723 .48363 L .56756 .50963 L p .969 .687 .442 r
F P
0 g
s
.43827 .46161 m .43893 .43584 L .41171 .44464 L p .537 .315 .524 r
F P
0 g
s
.41171 .44464 m .41084 .47035 L .43827 .46161 L p .537 .315 .524 r
F P
0 g
s
.41171 .44464 m .39555 .42833 L .39654 .40291 L p .959 .688 .477 r
F P
0 g
s
.41171 .44464 m .39555 .42833 L .39654 .40291 L p .959 .688 .477 r
F P
0 g
s
.43893 .43584 m .41171 .44464 L .39555 .42833 L p .654 .754 .923 r
F P
0 g
s
.43827 .46161 m .43893 .43584 L .41171 .44464 L p .537 .315 .524 r
F P
0 g
s
.41171 .44464 m .41084 .47035 L .43827 .46161 L p .537 .315 .524 r
F P
0 g
s
.36843 .4372 m .39555 .42833 L .41171 .44464 L p .654 .754 .923 r
F P
0 g
s
.39555 .42833 m .41171 .44464 L .41084 .47035 L p .959 .688 .477 r
F P
0 g
s
.43893 .43584 m .41171 .44464 L .39555 .42833 L p .654 .754 .923 r
F P
0 g
s
.28076 .42213 m .28263 .39667 L .25619 .40566 L p .526 .299 .513 r
F P
0 g
s
.25619 .40566 m .25412 .43107 L .28076 .42213 L p .526 .299 .513 r
F P
0 g
s
.25619 .40566 m .23859 .38899 L .24078 .36386 L p .949 .687 .505 r
F P
0 g
s
.25619 .40566 m .23859 .38899 L .24078 .36386 L p .949 .687 .505 r
F P
0 g
s
.28263 .39667 m .25619 .40566 L .23859 .38899 L p .656 .751 .92 r
F P
0 g
s
.28076 .42213 m .28263 .39667 L .25619 .40566 L p .526 .299 .513 r
F P
0 g
s
.25619 .40566 m .25412 .43107 L .28076 .42213 L p .526 .299 .513 r
F P
0 g
s
.21225 .39806 m .23859 .38899 L .25619 .40566 L p .656 .751 .92 r
F P
0 g
s
.23859 .38899 m .25619 .40566 L .25412 .43107 L p .949 .687 .505 r
F P
0 g
s
.28263 .39667 m .25619 .40566 L .23859 .38899 L p .656 .751 .92 r
F P
0 g
s
.76176 .31977 m .79085 .3103 L .80339 .3277 L p .66 .747 .915 r
F P
0 g
s
.79085 .3103 m .80339 .3277 L .80553 .35251 L p .976 .672 .343 r
F P
0 g
s
.72052 .40497 m .70721 .38829 L .70581 .36316 L p .976 .68 .386 r
F P
0 g
s
.72052 .40497 m .70721 .38829 L .70581 .36316 L p .976 .68 .386 r
F P
0 g
s
.74929 .39597 m .72052 .40497 L .70721 .38829 L p .656 .751 .92 r
F P
0 g
s
.67853 .39736 m .70721 .38829 L .72052 .40497 L p .656 .751 .92 r
F P
0 g
s
.67853 .39736 m .70721 .38829 L .72052 .40497 L p .656 .751 .92 r
F P
0 g
s
.70721 .38829 m .72052 .40497 L .72203 .43039 L p .976 .68 .386 r
F P
0 g
s
.59347 .38195 m .59294 .35678 L .56494 .36598 L p .541 .319 .528 r
F P
0 g
s
.56494 .36598 m .56525 .39109 L .59347 .38195 L p .541 .319 .528 r
F P
0 g
s
.56494 .36598 m .55019 .34893 L .55 .3241 L p .971 .686 .432 r
F P
0 g
s
.59294 .35678 m .56494 .36598 L .55019 .34893 L p .658 .749 .917 r
F P
0 g
s
.59347 .38195 m .59294 .35678 L .56494 .36598 L p .541 .319 .528 r
F P
0 g
s
.56494 .36598 m .56525 .39109 L .59347 .38195 L p .541 .319 .528 r
F P
0 g
s
.52229 .3582 m .55019 .34893 L .56494 .36598 L p .658 .749 .917 r
F P
0 g
s
.52229 .3582 m .55019 .34893 L .56494 .36598 L p .658 .749 .917 r
F P
0 g
s
.55019 .34893 m .56494 .36598 L .56525 .39109 L p .971 .686 .432 r
F P
0 g
s
.55019 .34893 m .56494 .36598 L .56525 .39109 L p .971 .686 .432 r
F P
0 g
s
.4359 .34245 m .43658 .31759 L .40936 .32698 L p .53 .304 .517 r
F P
0 g
s
.40936 .32698 m .40847 .35179 L .4359 .34245 L p .53 .304 .517 r
F P
0 g
s
.63759 .48231 m .62351 .46633 L .62275 .44059 L p .972 .685 .422 r
F P
0 g
s
.63759 .48231 m .62351 .46633 L .62275 .44059 L p .972 .685 .422 r
F P
0 g
s
.66596 .47369 m .63759 .48231 L .62351 .46633 L p .652 .756 .926 r
F P
0 g
s
.66705 .49977 m .66596 .47369 L .63759 .48231 L p .55 .333 .538 r
F P
0 g
s
.63759 .48231 m .63846 .50832 L .66705 .49977 L p .55 .333 .538 r
F P
0 g
s
.59523 .47502 m .62351 .46633 L .63759 .48231 L p .652 .756 .926 r
F P
0 g
s
.62351 .46633 m .63759 .48231 L .63846 .50832 L p .972 .685 .422 r
F P
0 g
s
.66596 .47369 m .63759 .48231 L .62351 .46633 L p .652 .756 .926 r
F P
0 g
s
.50942 .46026 m .50954 .43448 L .48195 .4433 L p .541 .319 .528 r
F P
0 g
s
.48195 .4433 m .48162 .46901 L .50942 .46026 L p .541 .319 .528 r
F P
0 g
s
.48195 .4433 m .46643 .42696 L .46687 .40152 L p .964 .688 .461 r
F P
0 g
s
.48195 .4433 m .46643 .42696 L .46687 .40152 L p .964 .688 .461 r
F P
0 g
s
.50954 .43448 m .48195 .4433 L .46643 .42696 L p .654 .754 .923 r
F P
0 g
s
.50942 .46026 m .50954 .43448 L .48195 .4433 L p .541 .319 .528 r
F P
0 g
s
.48195 .4433 m .48162 .46901 L .50942 .46026 L p .541 .319 .528 r
F P
0 g
s
.43893 .43584 m .46643 .42696 L .48195 .4433 L p .654 .754 .923 r
F P
0 g
s
.43893 .43584 m .46643 .42696 L .48195 .4433 L p .654 .754 .923 r
F P
0 g
s
.46643 .42696 m .48195 .4433 L .48162 .46901 L p .964 .688 .461 r
F P
0 g
s
.50954 .43448 m .48195 .4433 L .46643 .42696 L p .654 .754 .923 r
F P
0 g
s
.46643 .42696 m .48195 .4433 L .48162 .46901 L p .964 .688 .461 r
F P
0 g
s
.3518 .42075 m .35312 .39528 L .32631 .40429 L p .53 .304 .517 r
F P
0 g
s
.32631 .40429 m .32478 .4297 L .3518 .42075 L p .53 .304 .517 r
F P
0 g
s
.32631 .40429 m .30934 .38758 L .31099 .36245 L p .954 .688 .492 r
F P
0 g
s
.32631 .40429 m .30934 .38758 L .31099 .36245 L p .954 .688 .492 r
F P
0 g
s
.35312 .39528 m .32631 .40429 L .30934 .38758 L p .656 .751 .92 r
F P
0 g
s
.3518 .42075 m .35312 .39528 L .32631 .40429 L p .53 .304 .517 r
F P
0 g
s
.32631 .40429 m .32478 .4297 L .3518 .42075 L p .53 .304 .517 r
F P
0 g
s
.28263 .39667 m .30934 .38758 L .32631 .40429 L p .656 .751 .92 r
F P
0 g
s
.30934 .38758 m .32631 .40429 L .32478 .4297 L p .954 .688 .492 r
F P
0 g
s
.35312 .39528 m .32631 .40429 L .30934 .38758 L p .656 .751 .92 r
F P
0 g
s
.19417 .38124 m .19671 .35607 L .17067 .36527 L p .518 .287 .504 r
F P
0 g
s
.17067 .36527 m .16794 .39039 L .19417 .38124 L p .518 .287 .504 r
F P
0 g
s
.17067 .36527 m .15226 .34821 L .15512 .32338 L p .943 .686 .517 r
F P
0 g
s
.19671 .35607 m .17067 .36527 L .15226 .34821 L p .658 .749 .917 r
F P
0 g
s
.19417 .38124 m .19671 .35607 L .17067 .36527 L p .518 .287 .504 r
F P
0 g
s
.17067 .36527 m .16794 .39039 L .19417 .38124 L p .518 .287 .504 r
F P
0 g
s
.15226 .34821 m .17067 .36527 L .16794 .39039 L p .943 .686 .517 r
F P
0 g
s
.19671 .35607 m .17067 .36527 L .15226 .34821 L p .658 .749 .917 r
F P
0 g
s
.35551 .51355 m .38259 .50504 L .39889 .52067 L p .649 .759 .929 r
F P
0 g
s
.39889 .52067 m .38259 .50504 L .38368 .479 L p .957 .688 .485 r
F P
0 g
s
.74929 .39597 m .77836 .38688 L .79102 .4036 L p .656 .751 .92 r
F P
0 g
s
.77836 .38688 m .79102 .4036 L .79308 .42902 L p .976 .675 .358 r
F P
0 g
s
.66477 .38053 m .66369 .35536 L .63532 .36457 L p .544 .324 .532 r
F P
0 g
s
.63532 .36457 m .63618 .38969 L .66477 .38053 L p .544 .324 .532 r
F P
0 g
s
.66369 .35536 m .63532 .36457 L .62122 .34749 L p .658 .749 .917 r
F P
0 g
s
.66477 .38053 m .66369 .35536 L .63532 .36457 L p .544 .324 .532 r
F P
0 g
s
.63532 .36457 m .63618 .38969 L .66477 .38053 L p .544 .324 .532 r
F P
0 g
s
.59294 .35678 m .62122 .34749 L .63532 .36457 L p .658 .749 .917 r
F P
0 g
s
.62122 .34749 m .63532 .36457 L .63618 .38969 L p .974 .684 .41 r
F P
0 g
s
.62122 .34749 m .63532 .36457 L .63618 .38969 L p .974 .684 .41 r
F P
0 g
s
.50708 .34101 m .50722 .31614 L .47962 .32554 L p .534 .309 .521 r
F P
0 g
s
.47962 .32554 m .47928 .35036 L .50708 .34101 L p .534 .309 .521 r
F P
0 g
s
.50722 .31614 m .47962 .32554 L .46407 .30811 L p .66 .747 .915 r
F P
0 g
s
.50708 .34101 m .50722 .31614 L .47962 .32554 L p .534 .309 .521 r
F P
0 g
s
.47962 .32554 m .47928 .35036 L .50708 .34101 L p .534 .309 .521 r
F P
0 g
s
.46407 .30811 m .47962 .32554 L .47928 .35036 L p .966 .687 .452 r
F P
0 g
s
.73844 .49845 m .7368 .47236 L .70805 .48099 L p .553 .337 .541 r
F P
0 g
s
.70805 .48099 m .70947 .50701 L .73844 .49845 L p .553 .337 .541 r
F P
0 g
s
.7368 .47236 m .70805 .48099 L .69461 .46498 L p .652 .756 .926 r
F P
0 g
s
.73844 .49845 m .7368 .47236 L .70805 .48099 L p .553 .337 .541 r
F P
0 g
s
.70805 .48099 m .70947 .50701 L .73844 .49845 L p .553 .337 .541 r
F P
0 g
s
.69461 .46498 m .70805 .48099 L .70947 .50701 L p .975 .682 .398 r
F P
0 g
s
.58069 .45891 m .58026 .43312 L .55229 .44195 L p .544 .324 .532 r
F P
0 g
s
.55229 .44195 m .55251 .46767 L .58069 .45891 L p .544 .324 .532 r
F P
0 g
s
.55229 .44195 m .53741 .42558 L .53731 .40014 L p .969 .687 .442 r
F P
0 g
s
.55229 .44195 m .53741 .42558 L .53731 .40014 L p .969 .687 .442 r
F P
0 g
s
.58026 .43312 m .55229 .44195 L .53741 .42558 L p .654 .754 .923 r
F P
0 g
s
.58069 .45891 m .58026 .43312 L .55229 .44195 L p .544 .324 .532 r
F P
0 g
s
.55229 .44195 m .55251 .46767 L .58069 .45891 L p .544 .324 .532 r
F P
0 g
s
.50954 .43448 m .53741 .42558 L .55229 .44195 L p .654 .754 .923 r
F P
0 g
s
.50954 .43448 m .53741 .42558 L .55229 .44195 L p .654 .754 .923 r
F P
0 g
s
.53741 .42558 m .55229 .44195 L .55251 .46767 L p .969 .687 .442 r
F P
0 g
s
.58026 .43312 m .55229 .44195 L .53741 .42558 L p .654 .754 .923 r
F P
0 g
s
.53741 .42558 m .55229 .44195 L .55251 .46767 L p .969 .687 .442 r
F P
0 g
s
.42294 .41937 m .42372 .39388 L .39654 .40291 L p .534 .309 .521 r
F P
0 g
s
.39654 .40291 m .39555 .42833 L .42294 .41937 L p .534 .309 .521 r
F P
0 g
s
.39654 .40291 m .38021 .38618 L .38132 .36104 L p .959 .688 .477 r
F P
0 g
s
.42372 .39388 m .39654 .40291 L .38021 .38618 L p .656 .751 .92 r
F P
0 g
s
.42294 .41937 m .42372 .39388 L .39654 .40291 L p .534 .309 .521 r
F P
0 g
s
.39654 .40291 m .39555 .42833 L .42294 .41937 L p .534 .309 .521 r
F P
0 g
s
.35312 .39528 m .38021 .38618 L .39654 .40291 L p .656 .751 .92 r
F P
0 g
s
.35312 .39528 m .38021 .38618 L .39654 .40291 L p .656 .751 .92 r
F P
0 g
s
.38021 .38618 m .39654 .40291 L .39555 .42833 L p .959 .688 .477 r
F P
0 g
s
.38021 .38618 m .39654 .40291 L .39555 .42833 L p .959 .688 .477 r
F P
0 g
s
.26519 .37983 m .26719 .35465 L .24078 .36386 L p .522 .293 .509 r
F P
0 g
s
.24078 .36386 m .23859 .38899 L .26519 .37983 L p .522 .293 .509 r
F P
0 g
s
.24078 .36386 m .22301 .34678 L .22532 .32194 L p .949 .687 .505 r
F P
0 g
s
.24078 .36386 m .22301 .34678 L .22532 .32194 L p .949 .687 .505 r
F P
0 g
s
.26719 .35465 m .24078 .36386 L .22301 .34678 L p .658 .749 .917 r
F P
0 g
s
.26519 .37983 m .26719 .35465 L .24078 .36386 L p .522 .293 .509 r
F P
0 g
s
.24078 .36386 m .23859 .38899 L .26519 .37983 L p .522 .293 .509 r
F P
0 g
s
.19671 .35607 m .22301 .34678 L .24078 .36386 L p .658 .749 .917 r
F P
0 g
s
.19671 .35607 m .22301 .34678 L .24078 .36386 L p .658 .749 .917 r
F P
0 g
s
.22301 .34678 m .24078 .36386 L .23859 .38899 L p .949 .687 .505 r
F P
0 g
s
.26719 .35465 m .24078 .36386 L .22301 .34678 L p .658 .749 .917 r
F P
0 g
s
.22301 .34678 m .24078 .36386 L .23859 .38899 L p .949 .687 .505 r
F P
0 g
s
.42608 .51224 m .45354 .50373 L .4692 .51938 L p .649 .759 .929 r
F P
0 g
s
.4692 .51938 m .45354 .50373 L .45409 .47768 L p .962 .688 .469 r
F P
0 g
s
.31338 .48033 m .29628 .46431 L .29803 .43856 L p .952 .687 .499 r
F P
0 g
s
.31338 .48033 m .29628 .46431 L .29803 .43856 L p .952 .687 .499 r
F P
0 g
s
.34017 .47169 m .31338 .48033 L .29628 .46431 L p .652 .756 .926 r
F P
0 g
s
.2696 .47302 m .29628 .46431 L .31338 .48033 L p .652 .756 .926 r
F P
0 g
s
.73619 .37912 m .73456 .35393 L .70581 .36316 L p .547 .329 .535 r
F P
0 g
s
.70581 .36316 m .70721 .38829 L .73619 .37912 L p .547 .329 .535 r
F P
0 g
s
.70581 .36316 m .69235 .34606 L .69106 .32121 L p .976 .68 .386 r
F P
0 g
s
.70581 .36316 m .69235 .34606 L .69106 .32121 L p .976 .68 .386 r
F P
0 g
s
.73456 .35393 m .70581 .36316 L .69235 .34606 L p .658 .749 .917 r
F P
0 g
s
.73619 .37912 m .73456 .35393 L .70581 .36316 L p .547 .329 .535 r
F P
0 g
s
.70581 .36316 m .70721 .38829 L .73619 .37912 L p .547 .329 .535 r
F P
0 g
s
.66369 .35536 m .69235 .34606 L .70581 .36316 L p .658 .749 .917 r
F P
0 g
s
.66369 .35536 m .69235 .34606 L .70581 .36316 L p .658 .749 .917 r
F P
0 g
s
.69235 .34606 m .70581 .36316 L .70721 .38829 L p .976 .68 .386 r
F P
0 g
s
.73456 .35393 m .70581 .36316 L .69235 .34606 L p .658 .749 .917 r
F P
0 g
s
.69235 .34606 m .70581 .36316 L .70721 .38829 L p .976 .68 .386 r
F P
0 g
s
.57796 .31468 m .55 .3241 L .53509 .30664 L p .66 .747 .915 r
F P
0 g
s
.57838 .33956 m .57796 .31468 L .55 .3241 L p .537 .315 .524 r
F P
0 g
s
.55 .3241 m .55019 .34893 L .57838 .33956 L p .537 .315 .524 r
F P
0 g
s
.53509 .30664 m .55 .3241 L .55019 .34893 L p .971 .686 .432 r
F P
0 g
s
.65207 .45755 m .65109 .43175 L .62275 .44059 L p .547 .329 .535 r
F P
0 g
s
.62275 .44059 m .62351 .46633 L .65207 .45755 L p .547 .329 .535 r
F P
0 g
s
.62275 .44059 m .60851 .4242 L .60787 .39875 L p .972 .685 .422 r
F P
0 g
s
.65109 .43175 m .62275 .44059 L .60851 .4242 L p .654 .754 .923 r
F P
0 g
s
.65207 .45755 m .65109 .43175 L .62275 .44059 L p .547 .329 .535 r
F P
0 g
s
.62275 .44059 m .62351 .46633 L .65207 .45755 L p .547 .329 .535 r
F P
0 g
s
.58026 .43312 m .60851 .4242 L .62275 .44059 L p .654 .754 .923 r
F P
0 g
s
.58026 .43312 m .60851 .4242 L .62275 .44059 L p .654 .754 .923 r
F P
0 g
s
.60851 .4242 m .62275 .44059 L .62351 .46633 L p .972 .685 .422 r
F P
0 g
s
.60851 .4242 m .62275 .44059 L .62351 .46633 L p .972 .685 .422 r
F P
0 g
s
.4942 .41798 m .49443 .39249 L .46687 .40152 L p .537 .315 .524 r
F P
0 g
s
.46687 .40152 m .46643 .42696 L .4942 .41798 L p .537 .315 .524 r
F P
0 g
s
.46687 .40152 m .45119 .38477 L .45175 .35962 L p .964 .688 .461 r
F P
0 g
s
.46687 .40152 m .45119 .38477 L .45175 .35962 L p .964 .688 .461 r
F P
0 g
s
.49443 .39249 m .46687 .40152 L .45119 .38477 L p .656 .751 .92 r
F P
0 g
s
.42372 .39388 m .45119 .38477 L .46687 .40152 L p .656 .751 .92 r
F P
0 g
s
.33632 .37841 m .33777 .35322 L .31099 .36245 L p .526 .299 .513 r
F P
0 g
s
.31099 .36245 m .30934 .38758 L .33632 .37841 L p .526 .299 .513 r
F P
0 g
s
.33777 .35322 m .31099 .36245 L .29386 .34534 L p .658 .749 .917 r
F P
0 g
s
.33632 .37841 m .33777 .35322 L .31099 .36245 L p .526 .299 .513 r
F P
0 g
s
.31099 .36245 m .30934 .38758 L .33632 .37841 L p .526 .299 .513 r
F P
0 g
s
.26719 .35465 m .29386 .34534 L .31099 .36245 L p .658 .749 .917 r
F P
0 g
s
.29386 .34534 m .31099 .36245 L .30934 .38758 L p .954 .688 .492 r
F P
0 g
s
.29386 .34534 m .31099 .36245 L .30934 .38758 L p .954 .688 .492 r
F P
0 g
s
.17845 .33884 m .18112 .31395 L .15512 .32338 L p .514 .281 .5 r
F P
0 g
s
.15512 .32338 m .15226 .34821 L .17845 .33884 L p .514 .281 .5 r
F P
0 g
s
.18112 .31395 m .15512 .32338 L .13654 .3059 L p .66 .747 .915 r
F P
0 g
s
.17845 .33884 m .18112 .31395 L .15512 .32338 L p .514 .281 .5 r
F P
0 g
s
.15512 .32338 m .15226 .34821 L .17845 .33884 L p .514 .281 .5 r
F P
0 g
s
.11065 .31541 m .13654 .3059 L .15512 .32338 L p .66 .747 .915 r
F P
0 g
s
.13654 .3059 m .15512 .32338 L .15226 .34821 L p .943 .686 .517 r
F P
0 g
s
.13654 .3059 m .15512 .32338 L .15226 .34821 L p .943 .686 .517 r
F P
0 g
s
.77863 .47966 m .76583 .46364 L .76398 .43788 L p .976 .678 .372 r
F P
0 g
s
.77863 .47966 m .76583 .46364 L .76398 .43788 L p .976 .678 .372 r
F P
0 g
s
.80775 .47102 m .77863 .47966 L .76583 .46364 L p .652 .756 .926 r
F P
0 g
s
.7368 .47236 m .76583 .46364 L .77863 .47966 L p .652 .756 .926 r
F P
0 g
s
.53962 .51809 m .5246 .50241 L .5246 .47635 L p .966 .687 .452 r
F P
0 g
s
.53962 .51809 m .5246 .50241 L .5246 .47635 L p .966 .687 .452 r
F P
0 g
s
.56756 .50963 m .53962 .51809 L .5246 .50241 L p .649 .759 .929 r
F P
0 g
s
.49676 .51094 m .5246 .50241 L .53962 .51809 L p .649 .759 .929 r
F P
0 g
s
.38368 .479 m .36722 .46296 L .36843 .4372 L p .957 .688 .485 r
F P
0 g
s
.41084 .47035 m .38368 .479 L .36722 .46296 L p .652 .756 .926 r
F P
0 g
s
.40995 .49646 m .41084 .47035 L .38368 .479 L p .537 .315 .524 r
F P
0 g
s
.38368 .479 m .38259 .50504 L .40995 .49646 L p .537 .315 .524 r
F P
0 g
s
.34017 .47169 m .36722 .46296 L .38368 .479 L p .652 .756 .926 r
F P
0 g
s
.34017 .47169 m .36722 .46296 L .38368 .479 L p .652 .756 .926 r
F P
0 g
s
.36722 .46296 m .38368 .479 L .38259 .50504 L p .957 .688 .485 r
F P
0 g
s
.36722 .46296 m .38368 .479 L .38259 .50504 L p .957 .688 .485 r
F P
0 g
s
.77641 .36175 m .7636 .34462 L .76176 .31977 L p .976 .675 .358 r
F P
0 g
s
.77641 .36175 m .7636 .34462 L .76176 .31977 L p .976 .675 .358 r
F P
0 g
s
.80553 .35251 m .77641 .36175 L .7636 .34462 L p .658 .749 .917 r
F P
0 g
s
.73456 .35393 m .7636 .34462 L .77641 .36175 L p .658 .749 .917 r
F P
0 g
s
.73456 .35393 m .7636 .34462 L .77641 .36175 L p .658 .749 .917 r
F P
0 g
s
.7636 .34462 m .77641 .36175 L .77836 .38688 L p .976 .675 .358 r
F P
0 g
s
.64882 .31323 m .62048 .32266 L .60621 .30517 L p .66 .747 .915 r
F P
0 g
s
.64978 .33811 m .64882 .31323 L .62048 .32266 L p .541 .319 .528 r
F P
0 g
s
.62048 .32266 m .62122 .34749 L .64978 .33811 L p .541 .319 .528 r
F P
0 g
s
.57796 .31468 m .60621 .30517 L .62048 .32266 L p .66 .747 .915 r
F P
0 g
s
.60621 .30517 m .62048 .32266 L .62122 .34749 L p .974 .684 .41 r
F P
0 g
s
.60621 .30517 m .62048 .32266 L .62122 .34749 L p .974 .684 .41 r
F P
0 g
s
.69331 .43924 m .67972 .42282 L .67853 .39736 L p .975 .682 .398 r
F P
0 g
s
.69331 .43924 m .67972 .42282 L .67853 .39736 L p .975 .682 .398 r
F P
0 g
s
.72203 .43039 m .69331 .43924 L .67972 .42282 L p .654 .754 .923 r
F P
0 g
s
.72356 .45619 m .72203 .43039 L .69331 .43924 L p .55 .333 .538 r
F P
0 g
s
.69331 .43924 m .69461 .46498 L .72356 .45619 L p .55 .333 .538 r
F P
0 g
s
.65109 .43175 m .67972 .42282 L .69331 .43924 L p .654 .754 .923 r
F P
0 g
s
.65109 .43175 m .67972 .42282 L .69331 .43924 L p .654 .754 .923 r
F P
0 g
s
.67972 .42282 m .69331 .43924 L .69461 .46498 L p .975 .682 .398 r
F P
0 g
s
.72203 .43039 m .69331 .43924 L .67972 .42282 L p .654 .754 .923 r
F P
0 g
s
.67972 .42282 m .69331 .43924 L .69461 .46498 L p .975 .682 .398 r
F P
0 g
s
.56557 .41659 m .56525 .39109 L .53731 .40014 L p .541 .319 .528 r
F P
0 g
s
.53731 .40014 m .53741 .42558 L .56557 .41659 L p .541 .319 .528 r
F P
0 g
s
.53731 .40014 m .52227 .38336 L .52229 .3582 L p .969 .687 .442 r
F P
0 g
s
.53731 .40014 m .52227 .38336 L .52229 .3582 L p .969 .687 .442 r
F P
0 g
s
.56525 .39109 m .53731 .40014 L .52227 .38336 L p .656 .751 .92 r
F P
0 g
s
.56557 .41659 m .56525 .39109 L .53731 .40014 L p .541 .319 .528 r
F P
0 g
s
.53731 .40014 m .53741 .42558 L .56557 .41659 L p .541 .319 .528 r
F P
0 g
s
.49443 .39249 m .52227 .38336 L .53731 .40014 L p .656 .751 .92 r
F P
0 g
s
.49443 .39249 m .52227 .38336 L .53731 .40014 L p .656 .751 .92 r
F P
0 g
s
.52227 .38336 m .53731 .40014 L .53741 .42558 L p .969 .687 .442 r
F P
0 g
s
.56525 .39109 m .53731 .40014 L .52227 .38336 L p .656 .751 .92 r
F P
0 g
s
.52227 .38336 m .53731 .40014 L .53741 .42558 L p .969 .687 .442 r
F P
0 g
s
.40847 .35179 m .38132 .36104 L .36483 .3439 L p .658 .749 .917 r
F P
0 g
s
.40757 .37699 m .40847 .35179 L .38132 .36104 L p .53 .304 .517 r
F P
0 g
s
.38132 .36104 m .38021 .38618 L .40757 .37699 L p .53 .304 .517 r
F P
0 g
s
.33777 .35322 m .36483 .3439 L .38132 .36104 L p .658 .749 .917 r
F P
0 g
s
.36483 .3439 m .38132 .36104 L .38021 .38618 L p .959 .688 .477 r
F P
0 g
s
.36483 .3439 m .38132 .36104 L .38021 .38618 L p .959 .688 .477 r
F P
0 g
s
.24957 .33739 m .25169 .3125 L .22532 .32194 L p .518 .287 .504 r
F P
0 g
s
.22532 .32194 m .22301 .34678 L .24957 .33739 L p .518 .287 .504 r
F P
0 g
s
.25169 .3125 m .22532 .32194 L .20738 .30443 L p .66 .747 .915 r
F P
0 g
s
.24957 .33739 m .25169 .3125 L .22532 .32194 L p .518 .287 .504 r
F P
0 g
s
.22532 .32194 m .22301 .34678 L .24957 .33739 L p .518 .287 .504 r
F P
0 g
s
.18112 .31395 m .20738 .30443 L .22532 .32194 L p .66 .747 .915 r
F P
0 g
s
.20738 .30443 m .22532 .32194 L .22301 .34678 L p .949 .687 .505 r
F P
0 g
s
.20738 .30443 m .22532 .32194 L .22301 .34678 L p .949 .687 .505 r
F P
0 g
s
.56756 .50963 m .59577 .50109 L .61015 .51679 L p .649 .759 .929 r
F P
0 g
s
.61015 .51679 m .59577 .50109 L .59523 .47502 L p .971 .686 .432 r
F P
0 g
s
.45409 .47768 m .43827 .46161 L .43893 .43584 L p .962 .688 .469 r
F P
0 g
s
.45409 .47768 m .43827 .46161 L .43893 .43584 L p .962 .688 .469 r
F P
0 g
s
.48162 .46901 m .45409 .47768 L .43827 .46161 L p .652 .756 .926 r
F P
0 g
s
.48128 .49513 m .48162 .46901 L .45409 .47768 L p .541 .319 .528 r
F P
0 g
s
.45409 .47768 m .45354 .50373 L .48128 .49513 L p .541 .319 .528 r
F P
0 g
s
.41084 .47035 m .43827 .46161 L .45409 .47768 L p .652 .756 .926 r
F P
0 g
s
.43827 .46161 m .45409 .47768 L .45354 .50373 L p .962 .688 .469 r
F P
0 g
s
.48162 .46901 m .45409 .47768 L .43827 .46161 L p .652 .756 .926 r
F P
0 g
s
.32323 .45551 m .32478 .4297 L .29803 .43856 L p .53 .304 .517 r
F P
0 g
s
.29803 .43856 m .29628 .46431 L .32323 .45551 L p .53 .304 .517 r
F P
0 g
s
.29803 .43856 m .28076 .42213 L .28263 .39667 L p .952 .687 .499 r
F P
0 g
s
.32478 .4297 m .29803 .43856 L .28076 .42213 L p .654 .754 .923 r
F P
0 g
s
.32323 .45551 m .32478 .4297 L .29803 .43856 L p .53 .304 .517 r
F P
0 g
s
.29803 .43856 m .29628 .46431 L .32323 .45551 L p .53 .304 .517 r
F P
0 g
s
.25412 .43107 m .28076 .42213 L .29803 .43856 L p .654 .754 .923 r
F P
0 g
s
.25412 .43107 m .28076 .42213 L .29803 .43856 L p .654 .754 .923 r
F P
0 g
s
.28076 .42213 m .29803 .43856 L .29628 .46431 L p .952 .687 .499 r
F P
0 g
s
.28076 .42213 m .29803 .43856 L .29628 .46431 L p .952 .687 .499 r
F P
0 g
s
.7213 .33666 m .71978 .31177 L .69106 .32121 L p .544 .324 .532 r
F P
0 g
s
.69106 .32121 m .69235 .34606 L .7213 .33666 L p .544 .324 .532 r
F P
0 g
s
.79516 .45483 m .79308 .42902 L .76398 .43788 L p .553 .337 .541 r
F P
0 g
s
.76398 .43788 m .76583 .46364 L .79516 .45483 L p .553 .337 .541 r
F P
0 g
s
.76398 .43788 m .75103 .42144 L .74929 .39597 L p .976 .678 .372 r
F P
0 g
s
.79308 .42902 m .76398 .43788 L .75103 .42144 L p .654 .754 .923 r
F P
0 g
s
.79516 .45483 m .79308 .42902 L .76398 .43788 L p .553 .337 .541 r
F P
0 g
s
.76398 .43788 m .76583 .46364 L .79516 .45483 L p .553 .337 .541 r
F P
0 g
s
.72203 .43039 m .75103 .42144 L .76398 .43788 L p .654 .754 .923 r
F P
0 g
s
.75103 .42144 m .76398 .43788 L .76583 .46364 L p .976 .678 .372 r
F P
0 g
s
.79308 .42902 m .76398 .43788 L .75103 .42144 L p .654 .754 .923 r
F P
0 g
s
.75103 .42144 m .76398 .43788 L .76583 .46364 L p .976 .678 .372 r
F P
0 g
s
.60787 .39875 m .59347 .38195 L .59294 .35678 L p .972 .685 .422 r
F P
0 g
s
.60787 .39875 m .59347 .38195 L .59294 .35678 L p .972 .685 .422 r
F P
0 g
s
.63618 .38969 m .60787 .39875 L .59347 .38195 L p .656 .751 .92 r
F P
0 g
s
.56525 .39109 m .59347 .38195 L .60787 .39875 L p .656 .751 .92 r
F P
0 g
s
.56525 .39109 m .59347 .38195 L .60787 .39875 L p .656 .751 .92 r
F P
0 g
s
.59347 .38195 m .60787 .39875 L .60851 .4242 L p .972 .685 .422 r
F P
0 g
s
.47892 .37557 m .47928 .35036 L .45175 .35962 L p .534 .309 .521 r
F P
0 g
s
.45175 .35962 m .45119 .38477 L .47892 .37557 L p .534 .309 .521 r
F P
0 g
s
.45175 .35962 m .4359 .34245 L .43658 .31759 L p .964 .688 .461 r
F P
0 g
s
.47928 .35036 m .45175 .35962 L .4359 .34245 L p .658 .749 .917 r
F P
0 g
s
.47892 .37557 m .47928 .35036 L .45175 .35962 L p .534 .309 .521 r
F P
0 g
s
.45175 .35962 m .45119 .38477 L .47892 .37557 L p .534 .309 .521 r
F P
0 g
s
.40847 .35179 m .4359 .34245 L .45175 .35962 L p .658 .749 .917 r
F P
0 g
s
.4359 .34245 m .45175 .35962 L .45119 .38477 L p .964 .688 .461 r
F P
0 g
s
.32238 .31103 m .29563 .32049 L .27833 .30296 L p .66 .747 .915 r
F P
0 g
s
.32081 .33593 m .32238 .31103 L .29563 .32049 L p .522 .293 .509 r
F P
0 g
s
.29563 .32049 m .29386 .34534 L .32081 .33593 L p .522 .293 .509 r
F P
0 g
s
.27833 .30296 m .29563 .32049 L .29386 .34534 L p .954 .688 .492 r
F P
0 g
s
.55272 .4938 m .55251 .46767 L .5246 .47635 L p .544 .324 .532 r
F P
0 g
s
.5246 .47635 m .5246 .50241 L .55272 .4938 L p .544 .324 .532 r
F P
0 g
s
.5246 .47635 m .50942 .46026 L .50954 .43448 L p .966 .687 .452 r
F P
0 g
s
.5246 .47635 m .50942 .46026 L .50954 .43448 L p .966 .687 .452 r
F P
0 g
s
.55251 .46767 m .5246 .47635 L .50942 .46026 L p .652 .756 .926 r
F P
0 g
s
.55272 .4938 m .55251 .46767 L .5246 .47635 L p .544 .324 .532 r
F P
0 g
s
.5246 .47635 m .5246 .50241 L .55272 .4938 L p .544 .324 .532 r
F P
0 g
s
.48162 .46901 m .50942 .46026 L .5246 .47635 L p .652 .756 .926 r
F P
0 g
s
.48162 .46901 m .50942 .46026 L .5246 .47635 L p .652 .756 .926 r
F P
0 g
s
.50942 .46026 m .5246 .47635 L .5246 .50241 L p .966 .687 .452 r
F P
0 g
s
.55251 .46767 m .5246 .47635 L .50942 .46026 L p .652 .756 .926 r
F P
0 g
s
.50942 .46026 m .5246 .47635 L .5246 .50241 L p .966 .687 .452 r
F P
0 g
s
.36843 .4372 m .3518 .42075 L .35312 .39528 L p .957 .688 .485 r
F P
0 g
s
.36843 .4372 m .3518 .42075 L .35312 .39528 L p .957 .688 .485 r
F P
0 g
s
.39555 .42833 m .36843 .4372 L .3518 .42075 L p .654 .754 .923 r
F P
0 g
s
.39454 .45415 m .39555 .42833 L .36843 .4372 L p .534 .309 .521 r
F P
0 g
s
.36843 .4372 m .36722 .46296 L .39454 .45415 L p .534 .309 .521 r
F P
0 g
s
.32478 .4297 m .3518 .42075 L .36843 .4372 L p .654 .754 .923 r
F P
0 g
s
.3518 .42075 m .36843 .4372 L .36722 .46296 L p .957 .688 .485 r
F P
0 g
s
.39555 .42833 m .36843 .4372 L .3518 .42075 L p .654 .754 .923 r
F P
0 g
s
.21225 .39806 m .19417 .38124 L .19671 .35607 L p .946 .686 .511 r
F P
0 g
s
.21225 .39806 m .19417 .38124 L .19671 .35607 L p .946 .686 .511 r
F P
0 g
s
.23859 .38899 m .21225 .39806 L .19417 .38124 L p .656 .751 .92 r
F P
0 g
s
.23636 .4145 m .23859 .38899 L .21225 .39806 L p .522 .293 .509 r
F P
0 g
s
.21225 .39806 m .20983 .42351 L .23636 .4145 L p .522 .293 .509 r
F P
0 g
s
.16794 .39039 m .19417 .38124 L .21225 .39806 L p .656 .751 .92 r
F P
0 g
s
.19417 .38124 m .21225 .39806 L .20983 .42351 L p .946 .686 .511 r
F P
0 g
s
.23859 .38899 m .21225 .39806 L .19417 .38124 L p .656 .751 .92 r
F P
0 g
s
.79292 .33521 m .79085 .3103 L .76176 .31977 L p .547 .329 .535 r
F P
0 g
s
.76176 .31977 m .7636 .34462 L .79292 .33521 L p .547 .329 .535 r
F P
0 g
s
.71978 .31177 m .74879 .30222 L .76176 .31977 L p .66 .747 .915 r
F P
0 g
s
.74879 .30222 m .76176 .31977 L .7636 .34462 L p .976 .675 .358 r
F P
0 g
s
.70863 .4138 m .70721 .38829 L .67853 .39736 L p .547 .329 .535 r
F P
0 g
s
.67853 .39736 m .67972 .42282 L .70863 .4138 L p .547 .329 .535 r
F P
0 g
s
.67853 .39736 m .66477 .38053 L .66369 .35536 L p .975 .682 .398 r
F P
0 g
s
.67853 .39736 m .66477 .38053 L .66369 .35536 L p .975 .682 .398 r
F P
0 g
s
.70721 .38829 m .67853 .39736 L .66477 .38053 L p .656 .751 .92 r
F P
0 g
s
.63618 .38969 m .66477 .38053 L .67853 .39736 L p .656 .751 .92 r
F P
0 g
s
.55039 .37414 m .55019 .34893 L .52229 .3582 L p .537 .315 .524 r
F P
0 g
s
.52229 .3582 m .52227 .38336 L .55039 .37414 L p .537 .315 .524 r
F P
0 g
s
.52229 .3582 m .50708 .34101 L .50722 .31614 L p .969 .687 .442 r
F P
0 g
s
.55019 .34893 m .52229 .3582 L .50708 .34101 L p .658 .749 .917 r
F P
0 g
s
.55039 .37414 m .55019 .34893 L .52229 .3582 L p .537 .315 .524 r
F P
0 g
s
.52229 .3582 m .52227 .38336 L .55039 .37414 L p .537 .315 .524 r
F P
0 g
s
.47928 .35036 m .50708 .34101 L .52229 .3582 L p .658 .749 .917 r
F P
0 g
s
.47928 .35036 m .50708 .34101 L .52229 .3582 L p .658 .749 .917 r
F P
0 g
s
.50708 .34101 m .52229 .3582 L .52227 .38336 L p .969 .687 .442 r
F P
0 g
s
.50708 .34101 m .52229 .3582 L .52227 .38336 L p .969 .687 .442 r
F P
0 g
s
.39317 .30957 m .36605 .31904 L .34939 .30148 L p .66 .747 .915 r
F P
0 g
s
.39215 .33448 m .39317 .30957 L .36605 .31904 L p .526 .299 .513 r
F P
0 g
s
.36605 .31904 m .36483 .3439 L .39215 .33448 L p .526 .299 .513 r
F P
0 g
s
.32238 .31103 m .34939 .30148 L .36605 .31904 L p .66 .747 .915 r
F P
0 g
s
.34939 .30148 m .36605 .31904 L .36483 .3439 L p .959 .688 .477 r
F P
0 g
s
.34939 .30148 m .36605 .31904 L .36483 .3439 L p .959 .688 .477 r
F P
0 g
s
.70947 .50701 m .73844 .49845 L .75152 .5142 L p .649 .759 .929 r
F P
0 g
s
.75152 .5142 m .73844 .49845 L .7368 .47236 L p .976 .68 .386 r
F P
0 g
s
.59523 .47502 m .58069 .45891 L .58026 .43312 L p .971 .686 .432 r
F P
0 g
s
.59523 .47502 m .58069 .45891 L .58026 .43312 L p .971 .686 .432 r
F P
0 g
s
.62351 .46633 m .59523 .47502 L .58069 .45891 L p .652 .756 .926 r
F P
0 g
s
.55251 .46767 m .58069 .45891 L .59523 .47502 L p .652 .756 .926 r
F P
0 g
s
.55251 .46767 m .58069 .45891 L .59523 .47502 L p .652 .756 .926 r
F P
0 g
s
.58069 .45891 m .59523 .47502 L .59577 .50109 L p .971 .686 .432 r
F P
0 g
s
.46597 .45279 m .46643 .42696 L .43893 .43584 L p .537 .315 .524 r
F P
0 g
s
.43893 .43584 m .43827 .46161 L .46597 .45279 L p .537 .315 .524 r
F P
0 g
s
.43893 .43584 m .42294 .41937 L .42372 .39388 L p .962 .688 .469 r
F P
0 g
s
.46643 .42696 m .43893 .43584 L .42294 .41937 L p .654 .754 .923 r
F P
0 g
s
.46597 .45279 m .46643 .42696 L .43893 .43584 L p .537 .315 .524 r
F P
0 g
s
.43893 .43584 m .43827 .46161 L .46597 .45279 L p .537 .315 .524 r
F P
0 g
s
.39555 .42833 m .42294 .41937 L .43893 .43584 L p .654 .754 .923 r
F P
0 g
s
.39555 .42833 m .42294 .41937 L .43893 .43584 L p .654 .754 .923 r
F P
0 g
s
.42294 .41937 m .43893 .43584 L .43827 .46161 L p .962 .688 .469 r
F P
0 g
s
.42294 .41937 m .43893 .43584 L .43827 .46161 L p .962 .688 .469 r
F P
0 g
s
.28263 .39667 m .26519 .37983 L .26719 .35465 L p .952 .687 .499 r
F P
0 g
s
.28263 .39667 m .26519 .37983 L .26719 .35465 L p .952 .687 .499 r
F P
0 g
s
.30934 .38758 m .28263 .39667 L .26519 .37983 L p .656 .751 .92 r
F P
0 g
s
.23859 .38899 m .26519 .37983 L .28263 .39667 L p .656 .751 .92 r
F P
0 g
s
.23859 .38899 m .26519 .37983 L .28263 .39667 L p .656 .751 .92 r
F P
0 g
s
.26519 .37983 m .28263 .39667 L .28076 .42213 L p .952 .687 .499 r
F P
0 g
s
.12634 .35749 m .10744 .34029 L .11065 .31541 L p .941 .685 .523 r
F P
0 g
s
.15226 .34821 m .12634 .35749 L .10744 .34029 L p .658 .749 .917 r
F P
0 g
s
.35551 .51355 m .33874 .49778 L .34017 .47169 L p .954 .688 .492 r
F P
0 g
s
.38259 .50504 m .35551 .51355 L .33874 .49778 L p .649 .759 .929 r
F P
0 g
s
.78033 .41241 m .77836 .38688 L .74929 .39597 L p .55 .333 .538 r
F P
0 g
s
.74929 .39597 m .75103 .42144 L .78033 .41241 L p .55 .333 .538 r
F P
0 g
s
.74929 .39597 m .73619 .37912 L .73456 .35393 L p .976 .678 .372 r
F P
0 g
s
.74929 .39597 m .73619 .37912 L .73456 .35393 L p .976 .678 .372 r
F P
0 g
s
.77836 .38688 m .74929 .39597 L .73619 .37912 L p .656 .751 .92 r
F P
0 g
s
.78033 .41241 m .77836 .38688 L .74929 .39597 L p .55 .333 .538 r
F P
0 g
s
.74929 .39597 m .75103 .42144 L .78033 .41241 L p .55 .333 .538 r
F P
0 g
s
.70721 .38829 m .73619 .37912 L .74929 .39597 L p .656 .751 .92 r
F P
0 g
s
.73619 .37912 m .74929 .39597 L .75103 .42144 L p .976 .678 .372 r
F P
0 g
s
.77836 .38688 m .74929 .39597 L .73619 .37912 L p .656 .751 .92 r
F P
0 g
s
.62197 .37271 m .62122 .34749 L .59294 .35678 L p .541 .319 .528 r
F P
0 g
s
.59294 .35678 m .59347 .38195 L .62197 .37271 L p .541 .319 .528 r
F P
0 g
s
.59294 .35678 m .57838 .33956 L .57796 .31468 L p .972 .685 .422 r
F P
0 g
s
.62122 .34749 m .59294 .35678 L .57838 .33956 L p .658 .749 .917 r
F P
0 g
s
.62197 .37271 m .62122 .34749 L .59294 .35678 L p .541 .319 .528 r
F P
0 g
s
.59294 .35678 m .59347 .38195 L .62197 .37271 L p .541 .319 .528 r
F P
0 g
s
.55019 .34893 m .57838 .33956 L .59294 .35678 L p .658 .749 .917 r
F P
0 g
s
.57838 .33956 m .59294 .35678 L .59347 .38195 L p .972 .685 .422 r
F P
0 g
s
.62122 .34749 m .59294 .35678 L .57838 .33956 L p .658 .749 .917 r
F P
0 g
s
.57838 .33956 m .59294 .35678 L .59347 .38195 L p .972 .685 .422 r
F P
0 g
s
.66596 .47369 m .65207 .45755 L .65109 .43175 L p .974 .684 .41 r
F P
0 g
s
.66596 .47369 m .65207 .45755 L .65109 .43175 L p .974 .684 .41 r
F P
0 g
s
.69461 .46498 m .66596 .47369 L .65207 .45755 L p .652 .756 .926 r
F P
0 g
s
.69594 .49113 m .69461 .46498 L .66596 .47369 L p .55 .333 .538 r
F P
0 g
s
.66596 .47369 m .66705 .49977 L .69594 .49113 L p .55 .333 .538 r
F P
0 g
s
.62351 .46633 m .65207 .45755 L .66596 .47369 L p .652 .756 .926 r
F P
0 g
s
.62351 .46633 m .65207 .45755 L .66596 .47369 L p .652 .756 .926 r
F P
0 g
s
.65207 .45755 m .66596 .47369 L .66705 .49977 L p .974 .684 .41 r
F P
0 g
s
.69461 .46498 m .66596 .47369 L .65207 .45755 L p .652 .756 .926 r
F P
0 g
s
.65207 .45755 m .66596 .47369 L .66705 .49977 L p .974 .684 .41 r
F P
0 g
s
.53751 .45142 m .53741 .42558 L .50954 .43448 L p .541 .319 .528 r
F P
0 g
s
.50954 .43448 m .50942 .46026 L .53751 .45142 L p .541 .319 .528 r
F P
0 g
s
.50954 .43448 m .4942 .41798 L .49443 .39249 L p .966 .687 .452 r
F P
0 g
s
.50954 .43448 m .4942 .41798 L .49443 .39249 L p .966 .687 .452 r
F P
0 g
s
.53741 .42558 m .50954 .43448 L .4942 .41798 L p .654 .754 .923 r
F P
0 g
s
.53751 .45142 m .53741 .42558 L .50954 .43448 L p .541 .319 .528 r
F P
0 g
s
.50954 .43448 m .50942 .46026 L .53751 .45142 L p .541 .319 .528 r
F P
0 g
s
.46643 .42696 m .4942 .41798 L .50954 .43448 L p .654 .754 .923 r
F P
0 g
s
.46643 .42696 m .4942 .41798 L .50954 .43448 L p .654 .754 .923 r
F P
0 g
s
.4942 .41798 m .50954 .43448 L .50942 .46026 L p .966 .687 .452 r
F P
0 g
s
.53741 .42558 m .50954 .43448 L .4942 .41798 L p .654 .754 .923 r
F P
0 g
s
.4942 .41798 m .50954 .43448 L .50942 .46026 L p .966 .687 .452 r
F P
0 g
s
.37909 .41171 m .38021 .38618 L .35312 .39528 L p .53 .304 .517 r
F P
0 g
s
.35312 .39528 m .3518 .42075 L .37909 .41171 L p .53 .304 .517 r
F P
0 g
s
.35312 .39528 m .33632 .37841 L .33777 .35322 L p .957 .688 .485 r
F P
0 g
s
.35312 .39528 m .33632 .37841 L .33777 .35322 L p .957 .688 .485 r
F P
0 g
s
.38021 .38618 m .35312 .39528 L .33632 .37841 L p .656 .751 .92 r
F P
0 g
s
.37909 .41171 m .38021 .38618 L .35312 .39528 L p .53 .304 .517 r
F P
0 g
s
.35312 .39528 m .3518 .42075 L .37909 .41171 L p .53 .304 .517 r
F P
0 g
s
.30934 .38758 m .33632 .37841 L .35312 .39528 L p .656 .751 .92 r
F P
0 g
s
.30934 .38758 m .33632 .37841 L .35312 .39528 L p .656 .751 .92 r
F P
0 g
s
.33632 .37841 m .35312 .39528 L .3518 .42075 L p .957 .688 .485 r
F P
0 g
s
.38021 .38618 m .35312 .39528 L .33632 .37841 L p .656 .751 .92 r
F P
0 g
s
.33632 .37841 m .35312 .39528 L .3518 .42075 L p .957 .688 .485 r
F P
0 g
s
.22066 .372 m .22301 .34678 L .19671 .35607 L p .518 .287 .504 r
F P
0 g
s
.19671 .35607 m .19417 .38124 L .22066 .372 L p .518 .287 .504 r
F P
0 g
s
.19671 .35607 m .17845 .33884 L .18112 .31395 L p .946 .686 .511 r
F P
0 g
s
.19671 .35607 m .17845 .33884 L .18112 .31395 L p .946 .686 .511 r
F P
0 g
s
.22301 .34678 m .19671 .35607 L .17845 .33884 L p .658 .749 .917 r
F P
0 g
s
.22066 .372 m .22301 .34678 L .19671 .35607 L p .518 .287 .504 r
F P
0 g
s
.19671 .35607 m .19417 .38124 L .22066 .372 L p .518 .287 .504 r
F P
0 g
s
.15226 .34821 m .17845 .33884 L .19671 .35607 L p .658 .749 .917 r
F P
0 g
s
.15226 .34821 m .17845 .33884 L .19671 .35607 L p .658 .749 .917 r
F P
0 g
s
.17845 .33884 m .19671 .35607 L .19417 .38124 L p .946 .686 .511 r
F P
0 g
s
.22301 .34678 m .19671 .35607 L .17845 .33884 L p .658 .749 .917 r
F P
0 g
s
.17845 .33884 m .19671 .35607 L .19417 .38124 L p .946 .686 .511 r
F P
0 g
s
.2696 .47302 m .25202 .45687 L .25412 .43107 L p .949 .687 .505 r
F P
0 g
s
.29628 .46431 m .2696 .47302 L .25202 .45687 L p .652 .756 .926 r
F P
0 g
s
.46407 .30811 m .49185 .29853 L .50722 .31614 L p .66 .747 .915 r
F P
0 g
s
.49185 .29853 m .50722 .31614 L .50708 .34101 L p .969 .687 .442 r
F P
0 g
s
.69366 .37129 m .69235 .34606 L .66369 .35536 L p .544 .324 .532 r
F P
0 g
s
.66369 .35536 m .66477 .38053 L .69366 .37129 L p .544 .324 .532 r
F P
0 g
s
.69235 .34606 m .66369 .35536 L .64978 .33811 L p .658 .749 .917 r
F P
0 g
s
.69366 .37129 m .69235 .34606 L .66369 .35536 L p .544 .324 .532 r
F P
0 g
s
.66369 .35536 m .66477 .38053 L .69366 .37129 L p .544 .324 .532 r
F P
0 g
s
.62122 .34749 m .64978 .33811 L .66369 .35536 L p .658 .749 .917 r
F P
0 g
s
.64978 .33811 m .66369 .35536 L .66477 .38053 L p .975 .682 .398 r
F P
0 g
s
.64978 .33811 m .66369 .35536 L .66477 .38053 L p .975 .682 .398 r
F P
0 g
s
.13351 .33083 m .13654 .3059 L .11065 .31541 L p .509 .275 .495 r
F P
0 g
s
.11065 .31541 m .10744 .34029 L .13351 .33083 L p .509 .275 .495 r
F P
0 g
s
.13654 .3059 m .11065 .31541 L .09158 .29778 L p .66 .747 .915 r
F P
0 g
s
.13351 .33083 m .13654 .3059 L .11065 .31541 L p .509 .275 .495 r
F P
0 g
s
.11065 .31541 m .10744 .34029 L .13351 .33083 L p .509 .275 .495 r
F P
0 g
s
.09158 .29778 m .11065 .31541 L .10744 .34029 L p .941 .685 .523 r
F P
0 g
s
.7368 .47236 m .72356 .45619 L .72203 .43039 L p .976 .68 .386 r
F P
0 g
s
.76583 .46364 m .7368 .47236 L .72356 .45619 L p .652 .756 .926 r
F P
0 g
s
.76771 .48979 m .76583 .46364 L .7368 .47236 L p .553 .337 .541 r
F P
0 g
s
.7368 .47236 m .73844 .49845 L .76771 .48979 L p .553 .337 .541 r
F P
0 g
s
.69461 .46498 m .72356 .45619 L .7368 .47236 L p .652 .756 .926 r
F P
0 g
s
.72356 .45619 m .7368 .47236 L .73844 .49845 L p .976 .68 .386 r
F P
0 g
s
.76583 .46364 m .7368 .47236 L .72356 .45619 L p .652 .756 .926 r
F P
0 g
s
.72356 .45619 m .7368 .47236 L .73844 .49845 L p .976 .68 .386 r
F P
0 g
s
.60916 .45005 m .60851 .4242 L .58026 .43312 L p .544 .324 .532 r
F P
0 g
s
.58026 .43312 m .58069 .45891 L .60916 .45005 L p .544 .324 .532 r
F P
0 g
s
.58026 .43312 m .56557 .41659 L .56525 .39109 L p .971 .686 .432 r
F P
0 g
s
.58026 .43312 m .56557 .41659 L .56525 .39109 L p .971 .686 .432 r
F P
0 g
s
.60851 .4242 m .58026 .43312 L .56557 .41659 L p .654 .754 .923 r
F P
0 g
s
.60916 .45005 m .60851 .4242 L .58026 .43312 L p .544 .324 .532 r
F P
0 g
s
.58026 .43312 m .58069 .45891 L .60916 .45005 L p .544 .324 .532 r
F P
0 g
s
.53741 .42558 m .56557 .41659 L .58026 .43312 L p .654 .754 .923 r
F P
0 g
s
.53741 .42558 m .56557 .41659 L .58026 .43312 L p .654 .754 .923 r
F P
0 g
s
.56557 .41659 m .58026 .43312 L .58069 .45891 L p .971 .686 .432 r
F P
0 g
s
.60851 .4242 m .58026 .43312 L .56557 .41659 L p .654 .754 .923 r
F P
0 g
s
.56557 .41659 m .58026 .43312 L .58069 .45891 L p .971 .686 .432 r
F P
0 g
s
.45119 .38477 m .42372 .39388 L .40757 .37699 L p .656 .751 .92 r
F P
0 g
s
.45061 .41031 m .45119 .38477 L .42372 .39388 L p .534 .309 .521 r
F P
0 g
s
.42372 .39388 m .42294 .41937 L .45061 .41031 L p .534 .309 .521 r
F P
0 g
s
.38021 .38618 m .40757 .37699 L .42372 .39388 L p .656 .751 .92 r
F P
0 g
s
.40757 .37699 m .42372 .39388 L .42294 .41937 L p .962 .688 .469 r
F P
0 g
s
.40757 .37699 m .42372 .39388 L .42294 .41937 L p .962 .688 .469 r
F P
0 g
s
.29206 .37057 m .29386 .34534 L .26719 .35465 L p .522 .293 .509 r
F P
0 g
s
.26719 .35465 m .26519 .37983 L .29206 .37057 L p .522 .293 .509 r
F P
0 g
s
.26719 .35465 m .24957 .33739 L .25169 .3125 L p .952 .687 .499 r
F P
0 g
s
.29386 .34534 m .26719 .35465 L .24957 .33739 L p .658 .749 .917 r
F P
0 g
s
.29206 .37057 m .29386 .34534 L .26719 .35465 L p .522 .293 .509 r
F P
0 g
s
.26719 .35465 m .26519 .37983 L .29206 .37057 L p .522 .293 .509 r
F P
0 g
s
.22301 .34678 m .24957 .33739 L .26719 .35465 L p .658 .749 .917 r
F P
0 g
s
.22301 .34678 m .24957 .33739 L .26719 .35465 L p .658 .749 .917 r
F P
0 g
s
.24957 .33739 m .26719 .35465 L .26519 .37983 L p .952 .687 .499 r
F P
0 g
s
.24957 .33739 m .26719 .35465 L .26519 .37983 L p .952 .687 .499 r
F P
0 g
s
.49676 .51094 m .48128 .49513 L .48162 .46901 L p .964 .688 .461 r
F P
0 g
s
.5246 .50241 m .49676 .51094 L .48128 .49513 L p .649 .759 .929 r
F P
0 g
s
.36599 .48912 m .36722 .46296 L .34017 .47169 L p .534 .309 .521 r
F P
0 g
s
.34017 .47169 m .33874 .49778 L .36599 .48912 L p .534 .309 .521 r
F P
0 g
s
.34017 .47169 m .32323 .45551 L .32478 .4297 L p .954 .688 .492 r
F P
0 g
s
.36722 .46296 m .34017 .47169 L .32323 .45551 L p .652 .756 .926 r
F P
0 g
s
.36599 .48912 m .36722 .46296 L .34017 .47169 L p .534 .309 .521 r
F P
0 g
s
.34017 .47169 m .33874 .49778 L .36599 .48912 L p .534 .309 .521 r
F P
0 g
s
.29628 .46431 m .32323 .45551 L .34017 .47169 L p .652 .756 .926 r
F P
0 g
s
.32323 .45551 m .34017 .47169 L .33874 .49778 L p .954 .688 .492 r
F P
0 g
s
.76546 .36985 m .7636 .34462 L .73456 .35393 L p .547 .329 .535 r
F P
0 g
s
.73456 .35393 m .73619 .37912 L .76546 .36985 L p .547 .329 .535 r
F P
0 g
s
.73456 .35393 m .7213 .33666 L .71978 .31177 L p .976 .678 .372 r
F P
0 g
s
.73456 .35393 m .7213 .33666 L .71978 .31177 L p .976 .678 .372 r
F P
0 g
s
.7636 .34462 m .73456 .35393 L .7213 .33666 L p .658 .749 .917 r
F P
0 g
s
.76546 .36985 m .7636 .34462 L .73456 .35393 L p .547 .329 .535 r
F P
0 g
s
.73456 .35393 m .73619 .37912 L .76546 .36985 L p .547 .329 .535 r
F P
0 g
s
.69235 .34606 m .7213 .33666 L .73456 .35393 L p .658 .749 .917 r
F P
0 g
s
.69235 .34606 m .7213 .33666 L .73456 .35393 L p .658 .749 .917 r
F P
0 g
s
.7213 .33666 m .73456 .35393 L .73619 .37912 L p .976 .678 .372 r
F P
0 g
s
.7636 .34462 m .73456 .35393 L .7213 .33666 L p .658 .749 .917 r
F P
0 g
s
.7213 .33666 m .73456 .35393 L .73619 .37912 L p .976 .678 .372 r
F P
0 g
s
.60685 .3301 m .60621 .30517 L .57796 .31468 L p .537 .315 .524 r
F P
0 g
s
.57796 .31468 m .57838 .33956 L .60685 .3301 L p .537 .315 .524 r
F P
0 g
s
.60621 .30517 m .57796 .31468 L .56324 .29704 L p .66 .747 .915 r
F P
0 g
s
.60685 .3301 m .60621 .30517 L .57796 .31468 L p .537 .315 .524 r
F P
0 g
s
.57796 .31468 m .57838 .33956 L .60685 .3301 L p .537 .315 .524 r
F P
0 g
s
.53509 .30664 m .56324 .29704 L .57796 .31468 L p .66 .747 .915 r
F P
0 g
s
.56324 .29704 m .57796 .31468 L .57838 .33956 L p .972 .685 .422 r
F P
0 g
s
.56324 .29704 m .57796 .31468 L .57838 .33956 L p .972 .685 .422 r
F P
0 g
s
.76583 .46364 m .79516 .45483 L .80775 .47102 L p .652 .756 .926 r
F P
0 g
s
.80775 .47102 m .79516 .45483 L .79308 .42902 L p .976 .675 .358 r
F P
0 g
s
.68093 .44868 m .67972 .42282 L .65109 .43175 L p .547 .329 .535 r
F P
0 g
s
.65109 .43175 m .65207 .45755 L .68093 .44868 L p .547 .329 .535 r
F P
0 g
s
.60851 .4242 m .63704 .4152 L .65109 .43175 L p .654 .754 .923 r
F P
0 g
s
.63704 .4152 m .65109 .43175 L .65207 .45755 L p .974 .684 .41 r
F P
0 g
s
.52225 .40891 m .52227 .38336 L .49443 .39249 L p .537 .315 .524 r
F P
0 g
s
.49443 .39249 m .4942 .41798 L .52225 .40891 L p .537 .315 .524 r
F P
0 g
s
.49443 .39249 m .47892 .37557 L .47928 .35036 L p .966 .687 .452 r
F P
0 g
s
.49443 .39249 m .47892 .37557 L .47928 .35036 L p .966 .687 .452 r
F P
0 g
s
.52227 .38336 m .49443 .39249 L .47892 .37557 L p .656 .751 .92 r
F P
0 g
s
.45119 .38477 m .47892 .37557 L .49443 .39249 L p .656 .751 .92 r
F P
0 g
s
.36358 .36914 m .36483 .3439 L .33777 .35322 L p .526 .299 .513 r
F P
0 g
s
.33777 .35322 m .33632 .37841 L .36358 .36914 L p .526 .299 .513 r
F P
0 g
s
.33777 .35322 m .32081 .33593 L .32238 .31103 L p .957 .688 .485 r
F P
0 g
s
.36483 .3439 m .33777 .35322 L .32081 .33593 L p .658 .749 .917 r
F P
0 g
s
.36358 .36914 m .36483 .3439 L .33777 .35322 L p .526 .299 .513 r
F P
0 g
s
.33777 .35322 m .33632 .37841 L .36358 .36914 L p .526 .299 .513 r
F P
0 g
s
.29386 .34534 m .32081 .33593 L .33777 .35322 L p .658 .749 .917 r
F P
0 g
s
.32081 .33593 m .33777 .35322 L .33632 .37841 L p .957 .688 .485 r
F P
0 g
s
.36483 .3439 m .33777 .35322 L .32081 .33593 L p .658 .749 .917 r
F P
0 g
s
.32081 .33593 m .33777 .35322 L .33632 .37841 L p .957 .688 .485 r
F P
0 g
s
.2049 .32937 m .20738 .30443 L .18112 .31395 L p .514 .281 .5 r
F P
0 g
s
.18112 .31395 m .17845 .33884 L .2049 .32937 L p .514 .281 .5 r
F P
0 g
s
.20738 .30443 m .18112 .31395 L .16269 .2963 L p .66 .747 .915 r
F P
0 g
s
.2049 .32937 m .20738 .30443 L .18112 .31395 L p .514 .281 .5 r
F P
0 g
s
.18112 .31395 m .17845 .33884 L .2049 .32937 L p .514 .281 .5 r
F P
0 g
s
.13654 .3059 m .16269 .2963 L .18112 .31395 L p .66 .747 .915 r
F P
0 g
s
.16269 .2963 m .18112 .31395 L .17845 .33884 L p .946 .686 .511 r
F P
0 g
s
.16269 .2963 m .18112 .31395 L .17845 .33884 L p .946 .686 .511 r
F P
0 g
s
.56756 .50963 m .55272 .4938 L .55251 .46767 L p .969 .687 .442 r
F P
0 g
s
.56756 .50963 m .55272 .4938 L .55251 .46767 L p .969 .687 .442 r
F P
0 g
s
.59577 .50109 m .56756 .50963 L .55272 .4938 L p .649 .759 .929 r
F P
0 g
s
.5246 .50241 m .55272 .4938 L .56756 .50963 L p .649 .759 .929 r
F P
0 g
s
.41084 .47035 m .39454 .45415 L .39555 .42833 L p .959 .688 .477 r
F P
0 g
s
.43827 .46161 m .41084 .47035 L .39454 .45415 L p .652 .756 .926 r
F P
0 g
s
.43759 .48778 m .43827 .46161 L .41084 .47035 L p .537 .315 .524 r
F P
0 g
s
.41084 .47035 m .40995 .49646 L .43759 .48778 L p .537 .315 .524 r
F P
0 g
s
.36722 .46296 m .39454 .45415 L .41084 .47035 L p .652 .756 .926 r
F P
0 g
s
.39454 .45415 m .41084 .47035 L .40995 .49646 L p .959 .688 .477 r
F P
0 g
s
.43827 .46161 m .41084 .47035 L .39454 .45415 L p .652 .756 .926 r
F P
0 g
s
.39454 .45415 m .41084 .47035 L .40995 .49646 L p .959 .688 .477 r
F P
0 g
s
.27886 .448 m .28076 .42213 L .25412 .43107 L p .526 .299 .513 r
F P
0 g
s
.25412 .43107 m .25202 .45687 L .27886 .448 L p .526 .299 .513 r
F P
0 g
s
.25412 .43107 m .23636 .4145 L .23859 .38899 L p .949 .687 .505 r
F P
0 g
s
.28076 .42213 m .25412 .43107 L .23636 .4145 L p .654 .754 .923 r
F P
0 g
s
.27886 .448 m .28076 .42213 L .25412 .43107 L p .526 .299 .513 r
F P
0 g
s
.25412 .43107 m .25202 .45687 L .27886 .448 L p .526 .299 .513 r
F P
0 g
s
.23636 .4145 m .25412 .43107 L .25202 .45687 L p .949 .687 .505 r
F P
0 g
s
.28076 .42213 m .25412 .43107 L .23636 .4145 L p .654 .754 .923 r
F P
0 g
s
.7636 .34462 m .79292 .33521 L .80553 .35251 L p .658 .749 .917 r
F P
0 g
s
.80553 .35251 m .79292 .33521 L .79085 .3103 L p .976 .672 .343 r
F P
0 g
s
.60621 .30517 m .63474 .29556 L .64882 .31323 L p .66 .747 .915 r
F P
0 g
s
.63474 .29556 m .64882 .31323 L .64978 .33811 L p .975 .682 .398 r
F P
0 g
s
.7528 .44731 m .75103 .42144 L .72203 .43039 L p .55 .333 .538 r
F P
0 g
s
.72203 .43039 m .72356 .45619 L .7528 .44731 L p .55 .333 .538 r
F P
0 g
s
.72203 .43039 m .70863 .4138 L .70721 .38829 L p .976 .68 .386 r
F P
0 g
s
.75103 .42144 m .72203 .43039 L .70863 .4138 L p .654 .754 .923 r
F P
0 g
s
.7528 .44731 m .75103 .42144 L .72203 .43039 L p .55 .333 .538 r
F P
0 g
s
.72203 .43039 m .72356 .45619 L .7528 .44731 L p .55 .333 .538 r
F P
0 g
s
.67972 .42282 m .70863 .4138 L .72203 .43039 L p .654 .754 .923 r
F P
0 g
s
.67972 .42282 m .70863 .4138 L .72203 .43039 L p .654 .754 .923 r
F P
0 g
s
.70863 .4138 m .72203 .43039 L .72356 .45619 L p .976 .68 .386 r
F P
0 g
s
.70863 .4138 m .72203 .43039 L .72356 .45619 L p .976 .68 .386 r
F P
0 g
s
.594 .40751 m .59347 .38195 L .56525 .39109 L p .541 .319 .528 r
F P
0 g
s
.56525 .39109 m .56557 .41659 L .594 .40751 L p .541 .319 .528 r
F P
0 g
s
.56525 .39109 m .55039 .37414 L .55019 .34893 L p .971 .686 .432 r
F P
0 g
s
.56525 .39109 m .55039 .37414 L .55019 .34893 L p .971 .686 .432 r
F P
0 g
s
.59347 .38195 m .56525 .39109 L .55039 .37414 L p .656 .751 .92 r
F P
0 g
s
.594 .40751 m .59347 .38195 L .56525 .39109 L p .541 .319 .528 r
F P
0 g
s
.56525 .39109 m .56557 .41659 L .594 .40751 L p .541 .319 .528 r
F P
0 g
s
.52227 .38336 m .55039 .37414 L .56525 .39109 L p .656 .751 .92 r
F P
0 g
s
.52227 .38336 m .55039 .37414 L .56525 .39109 L p .656 .751 .92 r
F P
0 g
s
.55039 .37414 m .56525 .39109 L .56557 .41659 L p .971 .686 .432 r
F P
0 g
s
.59347 .38195 m .56525 .39109 L .55039 .37414 L p .656 .751 .92 r
F P
0 g
s
.55039 .37414 m .56525 .39109 L .56557 .41659 L p .971 .686 .432 r
F P
0 g
s
.4359 .34245 m .40847 .35179 L .39215 .33448 L p .658 .749 .917 r
F P
0 g
s
.43521 .3677 m .4359 .34245 L .40847 .35179 L p .53 .304 .517 r
F P
0 g
s
.40847 .35179 m .40757 .37699 L .43521 .3677 L p .53 .304 .517 r
F P
0 g
s
.36483 .3439 m .39215 .33448 L .40847 .35179 L p .658 .749 .917 r
F P
0 g
s
.39215 .33448 m .40847 .35179 L .40757 .37699 L p .962 .688 .469 r
F P
0 g
s
.39215 .33448 m .40847 .35179 L .40757 .37699 L p .962 .688 .469 r
F P
0 g
s
.27833 .30296 m .25169 .3125 L .23391 .29481 L p .66 .747 .915 r
F P
0 g
s
.27641 .3279 m .27833 .30296 L .25169 .3125 L p .518 .287 .504 r
F P
0 g
s
.25169 .3125 m .24957 .33739 L .27641 .3279 L p .518 .287 .504 r
F P
0 g
s
.20738 .30443 m .23391 .29481 L .25169 .3125 L p .66 .747 .915 r
F P
0 g
s
.23391 .29481 m .25169 .3125 L .24957 .33739 L p .952 .687 .499 r
F P
0 g
s
.23391 .29481 m .25169 .3125 L .24957 .33739 L p .952 .687 .499 r
F P
0 g
s
.63846 .50832 m .62428 .49246 L .62351 .46633 L p .972 .685 .422 r
F P
0 g
s
.66705 .49977 m .63846 .50832 L .62428 .49246 L p .649 .759 .929 r
F P
0 g
s
.50931 .48644 m .50942 .46026 L .48162 .46901 L p .541 .319 .528 r
F P
0 g
s
.48162 .46901 m .48128 .49513 L .50931 .48644 L p .541 .319 .528 r
F P
0 g
s
.48162 .46901 m .46597 .45279 L .46643 .42696 L p .964 .688 .461 r
F P
0 g
s
.48162 .46901 m .46597 .45279 L .46643 .42696 L p .964 .688 .461 r
F P
0 g
s
.50942 .46026 m .48162 .46901 L .46597 .45279 L p .652 .756 .926 r
F P
0 g
s
.43827 .46161 m .46597 .45279 L .48162 .46901 L p .652 .756 .926 r
F P
0 g
s
.43827 .46161 m .46597 .45279 L .48162 .46901 L p .652 .756 .926 r
F P
0 g
s
.46597 .45279 m .48162 .46901 L .48128 .49513 L p .964 .688 .461 r
F P
0 g
s
.32478 .4297 m .30767 .41311 L .30934 .38758 L p .954 .688 .492 r
F P
0 g
s
.3518 .42075 m .32478 .4297 L .30767 .41311 L p .654 .754 .923 r
F P
0 g
s
.28076 .42213 m .30767 .41311 L .32478 .4297 L p .654 .754 .923 r
F P
0 g
s
.30767 .41311 m .32478 .4297 L .32323 .45551 L p .954 .688 .492 r
F P
0 g
s
.16794 .39039 m .14937 .37343 L .15226 .34821 L p .943 .686 .517 r
F P
0 g
s
.19417 .38124 m .16794 .39039 L .14937 .37343 L p .656 .751 .92 r
F P
0 g
s
.75054 .32717 m .74879 .30222 L .71978 .31177 L p .544 .324 .532 r
F P
0 g
s
.71978 .31177 m .7213 .33666 L .75054 .32717 L p .544 .324 .532 r
F P
0 g
s
.74879 .30222 m .71978 .31177 L .70636 .29407 L p .66 .747 .915 r
F P
0 g
s
.75054 .32717 m .74879 .30222 L .71978 .31177 L p .544 .324 .532 r
F P
0 g
s
.71978 .31177 m .7213 .33666 L .75054 .32717 L p .544 .324 .532 r
F P
0 g
s
.70636 .29407 m .71978 .31177 L .7213 .33666 L p .976 .678 .372 r
F P
0 g
s
.75103 .42144 m .78033 .41241 L .79308 .42902 L p .654 .754 .923 r
F P
0 g
s
.75103 .42144 m .78033 .41241 L .79308 .42902 L p .654 .754 .923 r
F P
0 g
s
.78033 .41241 m .79308 .42902 L .79516 .45483 L p .976 .675 .358 r
F P
0 g
s
.79308 .42902 m .78033 .41241 L .77836 .38688 L p .976 .675 .358 r
F P
0 g
s
.63618 .38969 m .62197 .37271 L .62122 .34749 L p .974 .684 .41 r
F P
0 g
s
.63618 .38969 m .62197 .37271 L .62122 .34749 L p .974 .684 .41 r
F P
0 g
s
.66477 .38053 m .63618 .38969 L .62197 .37271 L p .656 .751 .92 r
F P
0 g
s
.66587 .4061 m .66477 .38053 L .63618 .38969 L p .544 .324 .532 r
F P
0 g
s
.63618 .38969 m .63704 .4152 L .66587 .4061 L p .544 .324 .532 r
F P
0 g
s
.59347 .38195 m .62197 .37271 L .63618 .38969 L p .656 .751 .92 r
F P
0 g
s
.62197 .37271 m .63618 .38969 L .63704 .4152 L p .974 .684 .41 r
F P
0 g
s
.66477 .38053 m .63618 .38969 L .62197 .37271 L p .656 .751 .92 r
F P
0 g
s
.50695 .36627 m .50708 .34101 L .47928 .35036 L p .534 .309 .521 r
F P
0 g
s
.47928 .35036 m .47892 .37557 L .50695 .36627 L p .534 .309 .521 r
F P
0 g
s
.47928 .35036 m .4636 .33302 L .46407 .30811 L p .966 .687 .452 r
F P
0 g
s
.50708 .34101 m .47928 .35036 L .4636 .33302 L p .658 .749 .917 r
F P
0 g
s
.50695 .36627 m .50708 .34101 L .47928 .35036 L p .534 .309 .521 r
F P
0 g
s
.47928 .35036 m .47892 .37557 L .50695 .36627 L p .534 .309 .521 r
F P
0 g
s
.4359 .34245 m .4636 .33302 L .47928 .35036 L p .658 .749 .917 r
F P
0 g
s
.4636 .33302 m .47928 .35036 L .47892 .37557 L p .966 .687 .452 r
F P
0 g
s
.50708 .34101 m .47928 .35036 L .4636 .33302 L p .658 .749 .917 r
F P
0 g
s
.4636 .33302 m .47928 .35036 L .47892 .37557 L p .966 .687 .452 r
F P
0 g
s
.34802 .32643 m .34939 .30148 L .32238 .31103 L p .522 .293 .509 r
F P
0 g
s
.32238 .31103 m .32081 .33593 L .34802 .32643 L p .522 .293 .509 r
F P
0 g
s
.27833 .30296 m .30524 .29333 L .32238 .31103 L p .66 .747 .915 r
F P
0 g
s
.30524 .29333 m .32238 .31103 L .32081 .33593 L p .957 .688 .485 r
F P
0 g
s
.70947 .50701 m .69594 .49113 L .69461 .46498 L p .975 .682 .398 r
F P
0 g
s
.73844 .49845 m .70947 .50701 L .69594 .49113 L p .649 .759 .929 r
F P
0 g
s
.58113 .4851 m .58069 .45891 L .55251 .46767 L p .544 .324 .532 r
F P
0 g
s
.55251 .46767 m .55272 .4938 L .58113 .4851 L p .544 .324 .532 r
F P
0 g
s
.55251 .46767 m .53751 .45142 L .53741 .42558 L p .969 .687 .442 r
F P
0 g
s
.55251 .46767 m .53751 .45142 L .53741 .42558 L p .969 .687 .442 r
F P
0 g
s
.58069 .45891 m .55251 .46767 L .53751 .45142 L p .652 .756 .926 r
F P
0 g
s
.58113 .4851 m .58069 .45891 L .55251 .46767 L p .544 .324 .532 r
F P
0 g
s
.55251 .46767 m .55272 .4938 L .58113 .4851 L p .544 .324 .532 r
F P
0 g
s
.50942 .46026 m .53751 .45142 L .55251 .46767 L p .652 .756 .926 r
F P
0 g
s
.50942 .46026 m .53751 .45142 L .55251 .46767 L p .652 .756 .926 r
F P
0 g
s
.53751 .45142 m .55251 .46767 L .55272 .4938 L p .969 .687 .442 r
F P
0 g
s
.58069 .45891 m .55251 .46767 L .53751 .45142 L p .652 .756 .926 r
F P
0 g
s
.53751 .45142 m .55251 .46767 L .55272 .4938 L p .969 .687 .442 r
F P
0 g
s
.42215 .44525 m .42294 .41937 L .39555 .42833 L p .534 .309 .521 r
F P
0 g
s
.39555 .42833 m .39454 .45415 L .42215 .44525 L p .534 .309 .521 r
F P
0 g
s
.39555 .42833 m .37909 .41171 L .38021 .38618 L p .959 .688 .477 r
F P
0 g
s
.39555 .42833 m .37909 .41171 L .38021 .38618 L p .959 .688 .477 r
F P
0 g
s
.42294 .41937 m .39555 .42833 L .37909 .41171 L p .654 .754 .923 r
F P
0 g
s
.3518 .42075 m .37909 .41171 L .39555 .42833 L p .654 .754 .923 r
F P
0 g
s
.3518 .42075 m .37909 .41171 L .39555 .42833 L p .654 .754 .923 r
F P
0 g
s
.37909 .41171 m .39555 .42833 L .39454 .45415 L p .959 .688 .477 r
F P
0 g
s
.26316 .4054 m .26519 .37983 L .23859 .38899 L p .522 .293 .509 r
F P
0 g
s
.23859 .38899 m .23636 .4145 L .26316 .4054 L p .522 .293 .509 r
F P
0 g
s
.23859 .38899 m .22066 .372 L .22301 .34678 L p .949 .687 .505 r
F P
0 g
s
.23859 .38899 m .22066 .372 L .22301 .34678 L p .949 .687 .505 r
F P
0 g
s
.26519 .37983 m .23859 .38899 L .22066 .372 L p .656 .751 .92 r
F P
0 g
s
.26316 .4054 m .26519 .37983 L .23859 .38899 L p .522 .293 .509 r
F P
0 g
s
.23859 .38899 m .23636 .4145 L .26316 .4054 L p .522 .293 .509 r
F P
0 g
s
.19417 .38124 m .22066 .372 L .23859 .38899 L p .656 .751 .92 r
F P
0 g
s
.19417 .38124 m .22066 .372 L .23859 .38899 L p .656 .751 .92 r
F P
0 g
s
.22066 .372 m .23859 .38899 L .23636 .4145 L p .949 .687 .505 r
F P
0 g
s
.26519 .37983 m .23859 .38899 L .22066 .372 L p .656 .751 .92 r
F P
0 g
s
.22066 .372 m .23859 .38899 L .23636 .4145 L p .949 .687 .505 r
F P
0 g
s
.70721 .38829 m .69366 .37129 L .69235 .34606 L p .976 .68 .386 r
F P
0 g
s
.70721 .38829 m .69366 .37129 L .69235 .34606 L p .976 .68 .386 r
F P
0 g
s
.73619 .37912 m .70721 .38829 L .69366 .37129 L p .656 .751 .92 r
F P
0 g
s
.73784 .40469 m .73619 .37912 L .70721 .38829 L p .547 .329 .535 r
F P
0 g
s
.70721 .38829 m .70863 .4138 L .73784 .40469 L p .547 .329 .535 r
F P
0 g
s
.66477 .38053 m .69366 .37129 L .70721 .38829 L p .656 .751 .92 r
F P
0 g
s
.69366 .37129 m .70721 .38829 L .70863 .4138 L p .976 .68 .386 r
F P
0 g
s
.73619 .37912 m .70721 .38829 L .69366 .37129 L p .656 .751 .92 r
F P
0 g
s
.5788 .36483 m .57838 .33956 L .55019 .34893 L p .537 .315 .524 r
F P
0 g
s
.55019 .34893 m .55039 .37414 L .5788 .36483 L p .537 .315 .524 r
F P
0 g
s
.55019 .34893 m .53517 .33156 L .53509 .30664 L p .971 .686 .432 r
F P
0 g
s
.57838 .33956 m .55019 .34893 L .53517 .33156 L p .658 .749 .917 r
F P
0 g
s
.5788 .36483 m .57838 .33956 L .55019 .34893 L p .537 .315 .524 r
F P
0 g
s
.55019 .34893 m .55039 .37414 L .5788 .36483 L p .537 .315 .524 r
F P
0 g
s
.50708 .34101 m .53517 .33156 L .55019 .34893 L p .658 .749 .917 r
F P
0 g
s
.53517 .33156 m .55019 .34893 L .55039 .37414 L p .971 .686 .432 r
F P
0 g
s
.57838 .33956 m .55019 .34893 L .53517 .33156 L p .658 .749 .917 r
F P
0 g
s
.53517 .33156 m .55019 .34893 L .55039 .37414 L p .971 .686 .432 r
F P
0 g
s
.34939 .30148 m .37668 .29184 L .39317 .30957 L p .66 .747 .915 r
F P
0 g
s
.37668 .29184 m .39317 .30957 L .39215 .33448 L p .962 .688 .469 r
F P
0 g
s
.33485 .40399 m .33632 .37841 L .30934 .38758 L p .526 .299 .513 r
F P
0 g
s
.30934 .38758 m .30767 .41311 L .33485 .40399 L p .526 .299 .513 r
F P
0 g
s
.30934 .38758 m .29206 .37057 L .29386 .34534 L p .954 .688 .492 r
F P
0 g
s
.30934 .38758 m .29206 .37057 L .29386 .34534 L p .954 .688 .492 r
F P
0 g
s
.33632 .37841 m .30934 .38758 L .29206 .37057 L p .656 .751 .92 r
F P
0 g
s
.26519 .37983 m .29206 .37057 L .30934 .38758 L p .656 .751 .92 r
F P
0 g
s
.17574 .36411 m .17845 .33884 L .15226 .34821 L p .514 .281 .5 r
F P
0 g
s
.15226 .34821 m .14937 .37343 L .17574 .36411 L p .514 .281 .5 r
F P
0 g
s
.15226 .34821 m .13351 .33083 L .13654 .3059 L p .943 .686 .517 r
F P
0 g
s
.15226 .34821 m .13351 .33083 L .13654 .3059 L p .943 .686 .517 r
F P
0 g
s
.17845 .33884 m .15226 .34821 L .13351 .33083 L p .658 .749 .917 r
F P
0 g
s
.17574 .36411 m .17845 .33884 L .15226 .34821 L p .514 .281 .5 r
F P
0 g
s
.15226 .34821 m .14937 .37343 L .17574 .36411 L p .514 .281 .5 r
F P
0 g
s
.10744 .34029 m .13351 .33083 L .15226 .34821 L p .658 .749 .917 r
F P
0 g
s
.13351 .33083 m .15226 .34821 L .14937 .37343 L p .943 .686 .517 r
F P
0 g
s
.17845 .33884 m .15226 .34821 L .13351 .33083 L p .658 .749 .917 r
F P
0 g
s
.65307 .48375 m .65207 .45755 L .62351 .46633 L p .547 .329 .535 r
F P
0 g
s
.62351 .46633 m .62428 .49246 L .65307 .48375 L p .547 .329 .535 r
F P
0 g
s
.62351 .46633 m .60916 .45005 L .60851 .4242 L p .972 .685 .422 r
F P
0 g
s
.62351 .46633 m .60916 .45005 L .60851 .4242 L p .972 .685 .422 r
F P
0 g
s
.65207 .45755 m .62351 .46633 L .60916 .45005 L p .652 .756 .926 r
F P
0 g
s
.65307 .48375 m .65207 .45755 L .62351 .46633 L p .547 .329 .535 r
F P
0 g
s
.62351 .46633 m .62428 .49246 L .65307 .48375 L p .547 .329 .535 r
F P
0 g
s
.58069 .45891 m .60916 .45005 L .62351 .46633 L p .652 .756 .926 r
F P
0 g
s
.60916 .45005 m .62351 .46633 L .62428 .49246 L p .972 .685 .422 r
F P
0 g
s
.65207 .45755 m .62351 .46633 L .60916 .45005 L p .652 .756 .926 r
F P
0 g
s
.49396 .44387 m .4942 .41798 L .46643 .42696 L p .537 .315 .524 r
F P
0 g
s
.46643 .42696 m .46597 .45279 L .49396 .44387 L p .537 .315 .524 r
F P
0 g
s
.4942 .41798 m .46643 .42696 L .45061 .41031 L p .654 .754 .923 r
F P
0 g
s
.49396 .44387 m .4942 .41798 L .46643 .42696 L p .537 .315 .524 r
F P
0 g
s
.46643 .42696 m .46597 .45279 L .49396 .44387 L p .537 .315 .524 r
F P
0 g
s
.42294 .41937 m .45061 .41031 L .46643 .42696 L p .654 .754 .923 r
F P
0 g
s
.45061 .41031 m .46643 .42696 L .46597 .45279 L p .964 .688 .461 r
F P
0 g
s
.45061 .41031 m .46643 .42696 L .46597 .45279 L p .964 .688 .461 r
F P
0 g
s
.38259 .50504 m .36599 .48912 L .36722 .46296 L p .957 .688 .485 r
F P
0 g
s
.38259 .50504 m .36599 .48912 L .36722 .46296 L p .957 .688 .485 r
F P
0 g
s
.40995 .49646 m .38259 .50504 L .36599 .48912 L p .649 .759 .929 r
F P
0 g
s
.33874 .49778 m .36599 .48912 L .38259 .50504 L p .649 .759 .929 r
F P
0 g
s
.73619 .37912 m .76546 .36985 L .77836 .38688 L p .656 .751 .92 r
F P
0 g
s
.73619 .37912 m .76546 .36985 L .77836 .38688 L p .656 .751 .92 r
F P
0 g
s
.76546 .36985 m .77836 .38688 L .78033 .41241 L p .976 .675 .358 r
F P
0 g
s
.77836 .38688 m .76546 .36985 L .7636 .34462 L p .976 .675 .358 r
F P
0 g
s
.65076 .36339 m .64978 .33811 L .62122 .34749 L p .541 .319 .528 r
F P
0 g
s
.62122 .34749 m .62197 .37271 L .65076 .36339 L p .541 .319 .528 r
F P
0 g
s
.62122 .34749 m .60685 .3301 L .60621 .30517 L p .974 .684 .41 r
F P
0 g
s
.62122 .34749 m .60685 .3301 L .60621 .30517 L p .974 .684 .41 r
F P
0 g
s
.64978 .33811 m .62122 .34749 L .60685 .3301 L p .658 .749 .917 r
F P
0 g
s
.57838 .33956 m .60685 .3301 L .62122 .34749 L p .658 .749 .917 r
F P
0 g
s
.57838 .33956 m .60685 .3301 L .62122 .34749 L p .658 .749 .917 r
F P
0 g
s
.60685 .3301 m .62122 .34749 L .62197 .37271 L p .974 .684 .41 r
F P
0 g
s
.49159 .32349 m .49185 .29853 L .46407 .30811 L p .53 .304 .517 r
F P
0 g
s
.46407 .30811 m .4636 .33302 L .49159 .32349 L p .53 .304 .517 r
F P
0 g
s
.49185 .29853 m .46407 .30811 L .44823 .29034 L p .66 .747 .915 r
F P
0 g
s
.49159 .32349 m .49185 .29853 L .46407 .30811 L p .53 .304 .517 r
F P
0 g
s
.46407 .30811 m .4636 .33302 L .49159 .32349 L p .53 .304 .517 r
F P
0 g
s
.44823 .29034 m .46407 .30811 L .4636 .33302 L p .966 .687 .452 r
F P
0 g
s
.72512 .4824 m .72356 .45619 L .69461 .46498 L p .55 .333 .538 r
F P
0 g
s
.69461 .46498 m .69594 .49113 L .72512 .4824 L p .55 .333 .538 r
F P
0 g
s
.69461 .46498 m .68093 .44868 L .67972 .42282 L p .975 .682 .398 r
F P
0 g
s
.69461 .46498 m .68093 .44868 L .67972 .42282 L p .975 .682 .398 r
F P
0 g
s
.72356 .45619 m .69461 .46498 L .68093 .44868 L p .652 .756 .926 r
F P
0 g
s
.72512 .4824 m .72356 .45619 L .69461 .46498 L p .55 .333 .538 r
F P
0 g
s
.69461 .46498 m .69594 .49113 L .72512 .4824 L p .55 .333 .538 r
F P
0 g
s
.65207 .45755 m .68093 .44868 L .69461 .46498 L p .652 .756 .926 r
F P
0 g
s
.65207 .45755 m .68093 .44868 L .69461 .46498 L p .652 .756 .926 r
F P
0 g
s
.68093 .44868 m .69461 .46498 L .69594 .49113 L p .975 .682 .398 r
F P
0 g
s
.72356 .45619 m .69461 .46498 L .68093 .44868 L p .652 .756 .926 r
F P
0 g
s
.68093 .44868 m .69461 .46498 L .69594 .49113 L p .975 .682 .398 r
F P
0 g
s
.56589 .44249 m .56557 .41659 L .53741 .42558 L p .541 .319 .528 r
F P
0 g
s
.53741 .42558 m .53751 .45142 L .56589 .44249 L p .541 .319 .528 r
F P
0 g
s
.53741 .42558 m .52225 .40891 L .52227 .38336 L p .969 .687 .442 r
F P
0 g
s
.53741 .42558 m .52225 .40891 L .52227 .38336 L p .969 .687 .442 r
F P
0 g
s
.56557 .41659 m .53741 .42558 L .52225 .40891 L p .654 .754 .923 r
F P
0 g
s
.56589 .44249 m .56557 .41659 L .53741 .42558 L p .541 .319 .528 r
F P
0 g
s
.53741 .42558 m .53751 .45142 L .56589 .44249 L p .541 .319 .528 r
F P
0 g
s
.4942 .41798 m .52225 .40891 L .53741 .42558 L p .654 .754 .923 r
F P
0 g
s
.4942 .41798 m .52225 .40891 L .53741 .42558 L p .654 .754 .923 r
F P
0 g
s
.52225 .40891 m .53741 .42558 L .53751 .45142 L p .969 .687 .442 r
F P
0 g
s
.56557 .41659 m .53741 .42558 L .52225 .40891 L p .654 .754 .923 r
F P
0 g
s
.52225 .40891 m .53741 .42558 L .53751 .45142 L p .969 .687 .442 r
F P
0 g
s
.40665 .40258 m .40757 .37699 L .38021 .38618 L p .53 .304 .517 r
F P
0 g
s
.38021 .38618 m .37909 .41171 L .40665 .40258 L p .53 .304 .517 r
F P
0 g
s
.38021 .38618 m .36358 .36914 L .36483 .3439 L p .959 .688 .477 r
F P
0 g
s
.38021 .38618 m .36358 .36914 L .36483 .3439 L p .959 .688 .477 r
F P
0 g
s
.40757 .37699 m .38021 .38618 L .36358 .36914 L p .656 .751 .92 r
F P
0 g
s
.40665 .40258 m .40757 .37699 L .38021 .38618 L p .53 .304 .517 r
F P
0 g
s
.38021 .38618 m .37909 .41171 L .40665 .40258 L p .53 .304 .517 r
F P
0 g
s
.33632 .37841 m .36358 .36914 L .38021 .38618 L p .656 .751 .92 r
F P
0 g
s
.33632 .37841 m .36358 .36914 L .38021 .38618 L p .656 .751 .92 r
F P
0 g
s
.36358 .36914 m .38021 .38618 L .37909 .41171 L p .959 .688 .477 r
F P
0 g
s
.40757 .37699 m .38021 .38618 L .36358 .36914 L p .656 .751 .92 r
F P
0 g
s
.36358 .36914 m .38021 .38618 L .37909 .41171 L p .959 .688 .477 r
F P
0 g
s
.24742 .36267 m .24957 .33739 L .22301 .34678 L p .518 .287 .504 r
F P
0 g
s
.22301 .34678 m .22066 .372 L .24742 .36267 L p .518 .287 .504 r
F P
0 g
s
.22301 .34678 m .2049 .32937 L .20738 .30443 L p .949 .687 .505 r
F P
0 g
s
.22301 .34678 m .2049 .32937 L .20738 .30443 L p .949 .687 .505 r
F P
0 g
s
.24957 .33739 m .22301 .34678 L .2049 .32937 L p .658 .749 .917 r
F P
0 g
s
.24742 .36267 m .24957 .33739 L .22301 .34678 L p .518 .287 .504 r
F P
0 g
s
.22301 .34678 m .22066 .372 L .24742 .36267 L p .518 .287 .504 r
F P
0 g
s
.17845 .33884 m .2049 .32937 L .22301 .34678 L p .658 .749 .917 r
F P
0 g
s
.17845 .33884 m .2049 .32937 L .22301 .34678 L p .658 .749 .917 r
F P
0 g
s
.2049 .32937 m .22301 .34678 L .22066 .372 L p .949 .687 .505 r
F P
0 g
s
.24957 .33739 m .22301 .34678 L .2049 .32937 L p .658 .749 .917 r
F P
0 g
s
.2049 .32937 m .22301 .34678 L .22066 .372 L p .949 .687 .505 r
F P
0 g
s
.45354 .50373 m .43759 .48778 L .43827 .46161 L p .962 .688 .469 r
F P
0 g
s
.48128 .49513 m .45354 .50373 L .43759 .48778 L p .649 .759 .929 r
F P
0 g
s
.29628 .46431 m .27886 .448 L .28076 .42213 L p .952 .687 .499 r
F P
0 g
s
.29628 .46431 m .27886 .448 L .28076 .42213 L p .952 .687 .499 r
F P
0 g
s
.32323 .45551 m .29628 .46431 L .27886 .448 L p .652 .756 .926 r
F P
0 g
s
.32165 .48173 m .32323 .45551 L .29628 .46431 L p .53 .304 .517 r
F P
0 g
s
.29628 .46431 m .2945 .49046 L .32165 .48173 L p .53 .304 .517 r
F P
0 g
s
.25202 .45687 m .27886 .448 L .29628 .46431 L p .652 .756 .926 r
F P
0 g
s
.27886 .448 m .29628 .46431 L .2945 .49046 L p .952 .687 .499 r
F P
0 g
s
.32323 .45551 m .29628 .46431 L .27886 .448 L p .652 .756 .926 r
F P
0 g
s
.72284 .36194 m .7213 .33666 L .69235 .34606 L p .544 .324 .532 r
F P
0 g
s
.69235 .34606 m .69366 .37129 L .72284 .36194 L p .544 .324 .532 r
F P
0 g
s
.7213 .33666 m .69235 .34606 L .67864 .32863 L p .658 .749 .917 r
F P
0 g
s
.72284 .36194 m .7213 .33666 L .69235 .34606 L p .544 .324 .532 r
F P
0 g
s
.69235 .34606 m .69366 .37129 L .72284 .36194 L p .544 .324 .532 r
F P
0 g
s
.64978 .33811 m .67864 .32863 L .69235 .34606 L p .658 .749 .917 r
F P
0 g
s
.67864 .32863 m .69235 .34606 L .69366 .37129 L p .976 .68 .386 r
F P
0 g
s
.67864 .32863 m .69235 .34606 L .69366 .37129 L p .976 .68 .386 r
F P
0 g
s
.56354 .32202 m .56324 .29704 L .53509 .30664 L p .534 .309 .521 r
F P
0 g
s
.53509 .30664 m .53517 .33156 L .56354 .32202 L p .534 .309 .521 r
F P
0 g
s
.56324 .29704 m .53509 .30664 L .5199 .28885 L p .66 .747 .915 r
F P
0 g
s
.56354 .32202 m .56324 .29704 L .53509 .30664 L p .534 .309 .521 r
F P
0 g
s
.53509 .30664 m .53517 .33156 L .56354 .32202 L p .534 .309 .521 r
F P
0 g
s
.5199 .28885 m .53509 .30664 L .53517 .33156 L p .971 .686 .432 r
F P
0 g
s
.76583 .46364 m .7528 .44731 L .75103 .42144 L p .976 .678 .372 r
F P
0 g
s
.76583 .46364 m .7528 .44731 L .75103 .42144 L p .976 .678 .372 r
F P
0 g
s
.79516 .45483 m .76583 .46364 L .7528 .44731 L p .652 .756 .926 r
F P
0 g
s
.72356 .45619 m .7528 .44731 L .76583 .46364 L p .652 .756 .926 r
F P
0 g
s
.72356 .45619 m .7528 .44731 L .76583 .46364 L p .652 .756 .926 r
F P
0 g
s
.7528 .44731 m .76583 .46364 L .76771 .48979 L p .976 .678 .372 r
F P
0 g
s
.63792 .44111 m .63704 .4152 L .60851 .4242 L p .544 .324 .532 r
F P
0 g
s
.60851 .4242 m .60916 .45005 L .63792 .44111 L p .544 .324 .532 r
F P
0 g
s
.60851 .4242 m .594 .40751 L .59347 .38195 L p .972 .685 .422 r
F P
0 g
s
.63704 .4152 m .60851 .4242 L .594 .40751 L p .654 .754 .923 r
F P
0 g
s
.63792 .44111 m .63704 .4152 L .60851 .4242 L p .544 .324 .532 r
F P
0 g
s
.60851 .4242 m .60916 .45005 L .63792 .44111 L p .544 .324 .532 r
F P
0 g
s
.56557 .41659 m .594 .40751 L .60851 .4242 L p .654 .754 .923 r
F P
0 g
s
.56557 .41659 m .594 .40751 L .60851 .4242 L p .654 .754 .923 r
F P
0 g
s
.594 .40751 m .60851 .4242 L .60916 .45005 L p .972 .685 .422 r
F P
0 g
s
.594 .40751 m .60851 .4242 L .60916 .45005 L p .972 .685 .422 r
F P
0 g
s
.45119 .38477 m .43521 .3677 L .4359 .34245 L p .964 .688 .461 r
F P
0 g
s
.47892 .37557 m .45119 .38477 L .43521 .3677 L p .656 .751 .92 r
F P
0 g
s
.47857 .40116 m .47892 .37557 L .45119 .38477 L p .534 .309 .521 r
F P
0 g
s
.45119 .38477 m .45061 .41031 L .47857 .40116 L p .534 .309 .521 r
F P
0 g
s
.40757 .37699 m .43521 .3677 L .45119 .38477 L p .656 .751 .92 r
F P
0 g
s
.43521 .3677 m .45119 .38477 L .45061 .41031 L p .964 .688 .461 r
F P
0 g
s
.47892 .37557 m .45119 .38477 L .43521 .3677 L p .656 .751 .92 r
F P
0 g
s
.43521 .3677 m .45119 .38477 L .45061 .41031 L p .964 .688 .461 r
F P
0 g
s
.31921 .36122 m .32081 .33593 L .29386 .34534 L p .522 .293 .509 r
F P
0 g
s
.29386 .34534 m .29206 .37057 L .31921 .36122 L p .522 .293 .509 r
F P
0 g
s
.29386 .34534 m .27641 .3279 L .27833 .30296 L p .954 .688 .492 r
F P
0 g
s
.32081 .33593 m .29386 .34534 L .27641 .3279 L p .658 .749 .917 r
F P
0 g
s
.24957 .33739 m .27641 .3279 L .29386 .34534 L p .658 .749 .917 r
F P
0 g
s
.27641 .3279 m .29386 .34534 L .29206 .37057 L p .954 .688 .492 r
F P
0 g
s
.15985 .32128 m .16269 .2963 L .13654 .3059 L p .509 .275 .495 r
F P
0 g
s
.13654 .3059 m .13351 .33083 L .15985 .32128 L p .509 .275 .495 r
F P
0 g
s
.16269 .2963 m .13654 .3059 L .11761 .2881 L p .66 .747 .915 r
F P
0 g
s
.15985 .32128 m .16269 .2963 L .13654 .3059 L p .509 .275 .495 r
F P
0 g
s
.13654 .3059 m .13351 .33083 L .15985 .32128 L p .509 .275 .495 r
F P
0 g
s
.09158 .29778 m .11761 .2881 L .13654 .3059 L p .66 .747 .915 r
F P
0 g
s
.11761 .2881 m .13654 .3059 L .13351 .33083 L p .943 .686 .517 r
F P
0 g
s
.11761 .2881 m .13654 .3059 L .13351 .33083 L p .943 .686 .517 r
F P
0 g
s
.5246 .50241 m .50931 .48644 L .50942 .46026 L p .966 .687 .452 r
F P
0 g
s
.5246 .50241 m .50931 .48644 L .50942 .46026 L p .966 .687 .452 r
F P
0 g
s
.55272 .4938 m .5246 .50241 L .50931 .48644 L p .649 .759 .929 r
F P
0 g
s
.48128 .49513 m .50931 .48644 L .5246 .50241 L p .649 .759 .929 r
F P
0 g
s
.39352 .48037 m .39454 .45415 L .36722 .46296 L p .534 .309 .521 r
F P
0 g
s
.36722 .46296 m .36599 .48912 L .39352 .48037 L p .534 .309 .521 r
F P
0 g
s
.36722 .46296 m .35045 .44662 L .3518 .42075 L p .957 .688 .485 r
F P
0 g
s
.39454 .45415 m .36722 .46296 L .35045 .44662 L p .652 .756 .926 r
F P
0 g
s
.39352 .48037 m .39454 .45415 L .36722 .46296 L p .534 .309 .521 r
F P
0 g
s
.36722 .46296 m .36599 .48912 L .39352 .48037 L p .534 .309 .521 r
F P
0 g
s
.32323 .45551 m .35045 .44662 L .36722 .46296 L p .652 .756 .926 r
F P
0 g
s
.35045 .44662 m .36722 .46296 L .36599 .48912 L p .957 .688 .485 r
F P
0 g
s
.39454 .45415 m .36722 .46296 L .35045 .44662 L p .652 .756 .926 r
F P
0 g
s
.35045 .44662 m .36722 .46296 L .36599 .48912 L p .957 .688 .485 r
F P
0 g
s
.20983 .42351 m .19159 .4068 L .19417 .38124 L p .946 .686 .511 r
F P
0 g
s
.23636 .4145 m .20983 .42351 L .19159 .4068 L p .654 .754 .923 r
F P
0 g
s
.7213 .33666 m .75054 .32717 L .7636 .34462 L p .658 .749 .917 r
F P
0 g
s
.7213 .33666 m .75054 .32717 L .7636 .34462 L p .658 .749 .917 r
F P
0 g
s
.75054 .32717 m .7636 .34462 L .76546 .36985 L p .976 .675 .358 r
F P
0 g
s
.7636 .34462 m .75054 .32717 L .74879 .30222 L p .976 .675 .358 r
F P
0 g
s
.63561 .32054 m .63474 .29556 L .60621 .30517 L p .537 .315 .524 r
F P
0 g
s
.60621 .30517 m .60685 .3301 L .63561 .32054 L p .537 .315 .524 r
F P
0 g
s
.63474 .29556 m .60621 .30517 L .59168 .28735 L p .66 .747 .915 r
F P
0 g
s
.63561 .32054 m .63474 .29556 L .60621 .30517 L p .537 .315 .524 r
F P
0 g
s
.60621 .30517 m .60685 .3301 L .63561 .32054 L p .537 .315 .524 r
F P
0 g
s
.56324 .29704 m .59168 .28735 L .60621 .30517 L p .66 .747 .915 r
F P
0 g
s
.59168 .28735 m .60621 .30517 L .60685 .3301 L p .974 .684 .41 r
F P
0 g
s
.59168 .28735 m .60621 .30517 L .60685 .3301 L p .974 .684 .41 r
F P
0 g
s
.71008 .43972 m .70863 .4138 L .67972 .42282 L p .547 .329 .535 r
F P
0 g
s
.67972 .42282 m .68093 .44868 L .71008 .43972 L p .547 .329 .535 r
F P
0 g
s
.70863 .4138 m .67972 .42282 L .66587 .4061 L p .654 .754 .923 r
F P
0 g
s
.71008 .43972 m .70863 .4138 L .67972 .42282 L p .547 .329 .535 r
F P
0 g
s
.67972 .42282 m .68093 .44868 L .71008 .43972 L p .547 .329 .535 r
F P
0 g
s
.66587 .4061 m .67972 .42282 L .68093 .44868 L p .975 .682 .398 r
F P
0 g
s
.55059 .39975 m .55039 .37414 L .52227 .38336 L p .537 .315 .524 r
F P
0 g
s
.52227 .38336 m .52225 .40891 L .55059 .39975 L p .537 .315 .524 r
F P
0 g
s
.52227 .38336 m .50695 .36627 L .50708 .34101 L p .969 .687 .442 r
F P
0 g
s
.52227 .38336 m .50695 .36627 L .50708 .34101 L p .969 .687 .442 r
F P
0 g
s
.55039 .37414 m .52227 .38336 L .50695 .36627 L p .656 .751 .92 r
F P
0 g
s
.47892 .37557 m .50695 .36627 L .52227 .38336 L p .656 .751 .92 r
F P
0 g
s
.39111 .35977 m .39215 .33448 L .36483 .3439 L p .526 .299 .513 r
F P
0 g
s
.36483 .3439 m .36358 .36914 L .39111 .35977 L p .526 .299 .513 r
F P
0 g
s
.36483 .3439 m .34802 .32643 L .34939 .30148 L p .959 .688 .477 r
F P
0 g
s
.36483 .3439 m .34802 .32643 L .34939 .30148 L p .959 .688 .477 r
F P
0 g
s
.39215 .33448 m .36483 .3439 L .34802 .32643 L p .658 .749 .917 r
F P
0 g
s
.39111 .35977 m .39215 .33448 L .36483 .3439 L p .526 .299 .513 r
F P
0 g
s
.36483 .3439 m .36358 .36914 L .39111 .35977 L p .526 .299 .513 r
F P
0 g
s
.32081 .33593 m .34802 .32643 L .36483 .3439 L p .658 .749 .917 r
F P
0 g
s
.32081 .33593 m .34802 .32643 L .36483 .3439 L p .658 .749 .917 r
F P
0 g
s
.34802 .32643 m .36483 .3439 L .36358 .36914 L p .959 .688 .477 r
F P
0 g
s
.39215 .33448 m .36483 .3439 L .34802 .32643 L p .658 .749 .917 r
F P
0 g
s
.34802 .32643 m .36483 .3439 L .36358 .36914 L p .959 .688 .477 r
F P
0 g
s
.23163 .3198 m .23391 .29481 L .20738 .30443 L p .514 .281 .5 r
F P
0 g
s
.20738 .30443 m .2049 .32937 L .23163 .3198 L p .514 .281 .5 r
F P
0 g
s
.23391 .29481 m .20738 .30443 L .1891 .2866 L p .66 .747 .915 r
F P
0 g
s
.23163 .3198 m .23391 .29481 L .20738 .30443 L p .514 .281 .5 r
F P
0 g
s
.20738 .30443 m .2049 .32937 L .23163 .3198 L p .514 .281 .5 r
F P
0 g
s
.16269 .2963 m .1891 .2866 L .20738 .30443 L p .66 .747 .915 r
F P
0 g
s
.1891 .2866 m .20738 .30443 L .2049 .32937 L p .949 .687 .505 r
F P
0 g
s
.1891 .2866 m .20738 .30443 L .2049 .32937 L p .949 .687 .505 r
F P
0 g
s
.55272 .4938 m .58113 .4851 L .59577 .50109 L p .649 .759 .929 r
F P
0 g
s
.59577 .50109 m .58113 .4851 L .58069 .45891 L p .971 .686 .432 r
F P
0 g
s
.46551 .47902 m .46597 .45279 L .43827 .46161 L p .537 .315 .524 r
F P
0 g
s
.43827 .46161 m .43759 .48778 L .46551 .47902 L p .537 .315 .524 r
F P
0 g
s
.43827 .46161 m .42215 .44525 L .42294 .41937 L p .962 .688 .469 r
F P
0 g
s
.43827 .46161 m .42215 .44525 L .42294 .41937 L p .962 .688 .469 r
F P
0 g
s
.46597 .45279 m .43827 .46161 L .42215 .44525 L p .652 .756 .926 r
F P
0 g
s
.39454 .45415 m .42215 .44525 L .43827 .46161 L p .652 .756 .926 r
F P
0 g
s
.39454 .45415 m .42215 .44525 L .43827 .46161 L p .652 .756 .926 r
F P
0 g
s
.42215 .44525 m .43827 .46161 L .43759 .48778 L p .962 .688 .469 r
F P
0 g
s
.30597 .43903 m .30767 .41311 L .28076 .42213 L p .526 .299 .513 r
F P
0 g
s
.28076 .42213 m .27886 .448 L .30597 .43903 L p .526 .299 .513 r
F P
0 g
s
.28076 .42213 m .26316 .4054 L .26519 .37983 L p .952 .687 .499 r
F P
0 g
s
.30767 .41311 m .28076 .42213 L .26316 .4054 L p .654 .754 .923 r
F P
0 g
s
.30597 .43903 m .30767 .41311 L .28076 .42213 L p .526 .299 .513 r
F P
0 g
s
.28076 .42213 m .27886 .448 L .30597 .43903 L p .526 .299 .513 r
F P
0 g
s
.23636 .4145 m .26316 .4054 L .28076 .42213 L p .654 .754 .923 r
F P
0 g
s
.23636 .4145 m .26316 .4054 L .28076 .42213 L p .654 .754 .923 r
F P
0 g
s
.26316 .4054 m .28076 .42213 L .27886 .448 L p .952 .687 .499 r
F P
0 g
s
.26316 .4054 m .28076 .42213 L .27886 .448 L p .952 .687 .499 r
F P
0 g
s
.78234 .43834 m .78033 .41241 L .75103 .42144 L p .55 .333 .538 r
F P
0 g
s
.75103 .42144 m .7528 .44731 L .78234 .43834 L p .55 .333 .538 r
F P
0 g
s
.75103 .42144 m .73784 .40469 L .73619 .37912 L p .976 .678 .372 r
F P
0 g
s
.78033 .41241 m .75103 .42144 L .73784 .40469 L p .654 .754 .923 r
F P
0 g
s
.78234 .43834 m .78033 .41241 L .75103 .42144 L p .55 .333 .538 r
F P
0 g
s
.75103 .42144 m .7528 .44731 L .78234 .43834 L p .55 .333 .538 r
F P
0 g
s
.70863 .4138 m .73784 .40469 L .75103 .42144 L p .654 .754 .923 r
F P
0 g
s
.73784 .40469 m .75103 .42144 L .7528 .44731 L p .976 .678 .372 r
F P
0 g
s
.78033 .41241 m .75103 .42144 L .73784 .40469 L p .654 .754 .923 r
F P
0 g
s
.73784 .40469 m .75103 .42144 L .7528 .44731 L p .976 .678 .372 r
F P
0 g
s
.59347 .38195 m .5788 .36483 L .57838 .33956 L p .972 .685 .422 r
F P
0 g
s
.59347 .38195 m .5788 .36483 L .57838 .33956 L p .972 .685 .422 r
F P
0 g
s
.62197 .37271 m .59347 .38195 L .5788 .36483 L p .656 .751 .92 r
F P
0 g
s
.55039 .37414 m .5788 .36483 L .59347 .38195 L p .656 .751 .92 r
F P
0 g
s
.55039 .37414 m .5788 .36483 L .59347 .38195 L p .656 .751 .92 r
F P
0 g
s
.5788 .36483 m .59347 .38195 L .594 .40751 L p .972 .685 .422 r
F P
0 g
s
.46312 .35833 m .4636 .33302 L .4359 .34245 L p .53 .304 .517 r
F P
0 g
s
.4359 .34245 m .43521 .3677 L .46312 .35833 L p .53 .304 .517 r
F P
0 g
s
.4636 .33302 m .4359 .34245 L .41975 .32496 L p .658 .749 .917 r
F P
0 g
s
.46312 .35833 m .4636 .33302 L .4359 .34245 L p .53 .304 .517 r
F P
0 g
s
.4359 .34245 m .43521 .3677 L .46312 .35833 L p .53 .304 .517 r
F P
0 g
s
.39215 .33448 m .41975 .32496 L .4359 .34245 L p .658 .749 .917 r
F P
0 g
s
.41975 .32496 m .4359 .34245 L .43521 .3677 L p .964 .688 .461 r
F P
0 g
s
.41975 .32496 m .4359 .34245 L .43521 .3677 L p .964 .688 .461 r
F P
0 g
s
.30352 .31832 m .30524 .29333 L .27833 .30296 L p .518 .287 .504 r
F P
0 g
s
.27833 .30296 m .27641 .3279 L .30352 .31832 L p .518 .287 .504 r
F P
0 g
s
.23391 .29481 m .2607 .2851 L .27833 .30296 L p .66 .747 .915 r
F P
0 g
s
.2607 .2851 m .27833 .30296 L .27641 .3279 L p .954 .688 .492 r
F P
0 g
s
.53761 .47766 m .53751 .45142 L .50942 .46026 L p .541 .319 .528 r
F P
0 g
s
.50942 .46026 m .50931 .48644 L .53761 .47766 L p .541 .319 .528 r
F P
0 g
s
.50942 .46026 m .49396 .44387 L .4942 .41798 L p .966 .687 .452 r
F P
0 g
s
.50942 .46026 m .49396 .44387 L .4942 .41798 L p .966 .687 .452 r
F P
0 g
s
.53751 .45142 m .50942 .46026 L .49396 .44387 L p .652 .756 .926 r
F P
0 g
s
.46597 .45279 m .49396 .44387 L .50942 .46026 L p .652 .756 .926 r
F P
0 g
s
.37794 .43764 m .37909 .41171 L .3518 .42075 L p .53 .304 .517 r
F P
0 g
s
.3518 .42075 m .35045 .44662 L .37794 .43764 L p .53 .304 .517 r
F P
0 g
s
.3518 .42075 m .33485 .40399 L .33632 .37841 L p .957 .688 .485 r
F P
0 g
s
.3518 .42075 m .33485 .40399 L .33632 .37841 L p .957 .688 .485 r
F P
0 g
s
.37909 .41171 m .3518 .42075 L .33485 .40399 L p .654 .754 .923 r
F P
0 g
s
.30767 .41311 m .33485 .40399 L .3518 .42075 L p .654 .754 .923 r
F P
0 g
s
.21827 .39762 m .22066 .372 L .19417 .38124 L p .518 .287 .504 r
F P
0 g
s
.19417 .38124 m .19159 .4068 L .21827 .39762 L p .518 .287 .504 r
F P
0 g
s
.19417 .38124 m .17574 .36411 L .17845 .33884 L p .946 .686 .511 r
F P
0 g
s
.19417 .38124 m .17574 .36411 L .17845 .33884 L p .946 .686 .511 r
F P
0 g
s
.22066 .372 m .19417 .38124 L .17574 .36411 L p .656 .751 .92 r
F P
0 g
s
.21827 .39762 m .22066 .372 L .19417 .38124 L p .518 .287 .504 r
F P
0 g
s
.19417 .38124 m .19159 .4068 L .21827 .39762 L p .518 .287 .504 r
F P
0 g
s
.14937 .37343 m .17574 .36411 L .19417 .38124 L p .656 .751 .92 r
F P
0 g
s
.17574 .36411 m .19417 .38124 L .19159 .4068 L p .946 .686 .511 r
F P
0 g
s
.22066 .372 m .19417 .38124 L .17574 .36411 L p .656 .751 .92 r
F P
0 g
s
.66705 .49977 m .65307 .48375 L .65207 .45755 L p .974 .684 .41 r
F P
0 g
s
.66705 .49977 m .65307 .48375 L .65207 .45755 L p .974 .684 .41 r
F P
0 g
s
.69594 .49113 m .66705 .49977 L .65307 .48375 L p .649 .759 .929 r
F P
0 g
s
.62428 .49246 m .65307 .48375 L .66705 .49977 L p .649 .759 .929 r
F P
0 g
s
.77809 .29258 m .74879 .30222 L .73557 .28435 L p .66 .747 .915 r
F P
0 g
s
.78008 .31758 m .77809 .29258 L .74879 .30222 L p .544 .324 .532 r
F P
0 g
s
.74879 .30222 m .75054 .32717 L .78008 .31758 L p .544 .324 .532 r
F P
0 g
s
.70636 .29407 m .73557 .28435 L .74879 .30222 L p .66 .747 .915 r
F P
0 g
s
.73557 .28435 m .74879 .30222 L .75054 .32717 L p .976 .675 .358 r
F P
0 g
s
.73557 .28435 m .74879 .30222 L .75054 .32717 L p .976 .675 .358 r
F P
0 g
s
.37552 .31684 m .37668 .29184 L .34939 .30148 L p .522 .293 .509 r
F P
0 g
s
.34939 .30148 m .34802 .32643 L .37552 .31684 L p .522 .293 .509 r
F P
0 g
s
.66477 .38053 m .65076 .36339 L .64978 .33811 L p .975 .682 .398 r
F P
0 g
s
.66477 .38053 m .65076 .36339 L .64978 .33811 L p .975 .682 .398 r
F P
0 g
s
.69366 .37129 m .66477 .38053 L .65076 .36339 L p .656 .751 .92 r
F P
0 g
s
.69499 .39691 m .69366 .37129 L .66477 .38053 L p .544 .324 .532 r
F P
0 g
s
.66477 .38053 m .66587 .4061 L .69499 .39691 L p .544 .324 .532 r
F P
0 g
s
.62197 .37271 m .65076 .36339 L .66477 .38053 L p .656 .751 .92 r
F P
0 g
s
.62197 .37271 m .65076 .36339 L .66477 .38053 L p .656 .751 .92 r
F P
0 g
s
.65076 .36339 m .66477 .38053 L .66587 .4061 L p .975 .682 .398 r
F P
0 g
s
.69366 .37129 m .66477 .38053 L .65076 .36339 L p .656 .751 .92 r
F P
0 g
s
.65076 .36339 m .66477 .38053 L .66587 .4061 L p .975 .682 .398 r
F P
0 g
s
.53525 .35687 m .53517 .33156 L .50708 .34101 L p .534 .309 .521 r
F P
0 g
s
.50708 .34101 m .50695 .36627 L .53525 .35687 L p .534 .309 .521 r
F P
0 g
s
.50708 .34101 m .49159 .32349 L .49185 .29853 L p .969 .687 .442 r
F P
0 g
s
.53517 .33156 m .50708 .34101 L .49159 .32349 L p .658 .749 .917 r
F P
0 g
s
.53525 .35687 m .53517 .33156 L .50708 .34101 L p .534 .309 .521 r
F P
0 g
s
.50708 .34101 m .50695 .36627 L .53525 .35687 L p .534 .309 .521 r
F P
0 g
s
.4636 .33302 m .49159 .32349 L .50708 .34101 L p .658 .749 .917 r
F P
0 g
s
.4636 .33302 m .49159 .32349 L .50708 .34101 L p .658 .749 .917 r
F P
0 g
s
.49159 .32349 m .50708 .34101 L .50695 .36627 L p .969 .687 .442 r
F P
0 g
s
.49159 .32349 m .50708 .34101 L .50695 .36627 L p .969 .687 .442 r
F P
0 g
s
.73844 .49845 m .72512 .4824 L .72356 .45619 L p .976 .68 .386 r
F P
0 g
s
.73844 .49845 m .72512 .4824 L .72356 .45619 L p .976 .68 .386 r
F P
0 g
s
.76771 .48979 m .73844 .49845 L .72512 .4824 L p .649 .759 .929 r
F P
0 g
s
.69594 .49113 m .72512 .4824 L .73844 .49845 L p .649 .759 .929 r
F P
0 g
s
.58069 .45891 m .56589 .44249 L .56557 .41659 L p .971 .686 .432 r
F P
0 g
s
.58069 .45891 m .56589 .44249 L .56557 .41659 L p .971 .686 .432 r
F P
0 g
s
.60916 .45005 m .58069 .45891 L .56589 .44249 L p .652 .756 .926 r
F P
0 g
s
.53751 .45142 m .56589 .44249 L .58069 .45891 L p .652 .756 .926 r
F P
0 g
s
.53751 .45142 m .56589 .44249 L .58069 .45891 L p .652 .756 .926 r
F P
0 g
s
.56589 .44249 m .58069 .45891 L .58113 .4851 L p .971 .686 .432 r
F P
0 g
s
.45003 .43625 m .45061 .41031 L .42294 .41937 L p .534 .309 .521 r
F P
0 g
s
.42294 .41937 m .42215 .44525 L .45003 .43625 L p .534 .309 .521 r
F P
0 g
s
.42294 .41937 m .40665 .40258 L .40757 .37699 L p .962 .688 .469 r
F P
0 g
s
.42294 .41937 m .40665 .40258 L .40757 .37699 L p .962 .688 .469 r
F P
0 g
s
.45061 .41031 m .42294 .41937 L .40665 .40258 L p .654 .754 .923 r
F P
0 g
s
.37909 .41171 m .40665 .40258 L .42294 .41937 L p .654 .754 .923 r
F P
0 g
s
.26519 .37983 m .24742 .36267 L .24957 .33739 L p .952 .687 .499 r
F P
0 g
s
.26519 .37983 m .24742 .36267 L .24957 .33739 L p .952 .687 .499 r
F P
0 g
s
.29206 .37057 m .26519 .37983 L .24742 .36267 L p .656 .751 .92 r
F P
0 g
s
.29024 .3962 m .29206 .37057 L .26519 .37983 L p .522 .293 .509 r
F P
0 g
s
.26519 .37983 m .26316 .4054 L .29024 .3962 L p .522 .293 .509 r
F P
0 g
s
.22066 .372 m .24742 .36267 L .26519 .37983 L p .656 .751 .92 r
F P
0 g
s
.22066 .372 m .24742 .36267 L .26519 .37983 L p .656 .751 .92 r
F P
0 g
s
.24742 .36267 m .26519 .37983 L .26316 .4054 L p .952 .687 .499 r
F P
0 g
s
.29206 .37057 m .26519 .37983 L .24742 .36267 L p .656 .751 .92 r
F P
0 g
s
.24742 .36267 m .26519 .37983 L .26316 .4054 L p .952 .687 .499 r
F P
0 g
s
.10744 .34029 m .08819 .32275 L .09158 .29778 L p .941 .685 .523 r
F P
0 g
s
.13351 .33083 m .10744 .34029 L .08819 .32275 L p .658 .749 .917 r
F P
0 g
s
.33874 .49778 m .32165 .48173 L .32323 .45551 L p .954 .688 .492 r
F P
0 g
s
.36599 .48912 m .33874 .49778 L .32165 .48173 L p .649 .759 .929 r
F P
0 g
s
.76735 .39549 m .76546 .36985 L .73619 .37912 L p .547 .329 .535 r
F P
0 g
s
.73619 .37912 m .73784 .40469 L .76735 .39549 L p .547 .329 .535 r
F P
0 g
s
.73619 .37912 m .72284 .36194 L .7213 .33666 L p .976 .678 .372 r
F P
0 g
s
.73619 .37912 m .72284 .36194 L .7213 .33666 L p .976 .678 .372 r
F P
0 g
s
.76546 .36985 m .73619 .37912 L .72284 .36194 L p .656 .751 .92 r
F P
0 g
s
.76735 .39549 m .76546 .36985 L .73619 .37912 L p .547 .329 .535 r
F P
0 g
s
.73619 .37912 m .73784 .40469 L .76735 .39549 L p .547 .329 .535 r
F P
0 g
s
.69366 .37129 m .72284 .36194 L .73619 .37912 L p .656 .751 .92 r
F P
0 g
s
.69366 .37129 m .72284 .36194 L .73619 .37912 L p .656 .751 .92 r
F P
0 g
s
.72284 .36194 m .73619 .37912 L .73784 .40469 L p .976 .678 .372 r
F P
0 g
s
.76546 .36985 m .73619 .37912 L .72284 .36194 L p .656 .751 .92 r
F P
0 g
s
.72284 .36194 m .73619 .37912 L .73784 .40469 L p .976 .678 .372 r
F P
0 g
s
.60749 .35542 m .60685 .3301 L .57838 .33956 L p .537 .315 .524 r
F P
0 g
s
.57838 .33956 m .5788 .36483 L .60749 .35542 L p .537 .315 .524 r
F P
0 g
s
.57838 .33956 m .56354 .32202 L .56324 .29704 L p .972 .685 .422 r
F P
0 g
s
.57838 .33956 m .56354 .32202 L .56324 .29704 L p .972 .685 .422 r
F P
0 g
s
.60685 .3301 m .57838 .33956 L .56354 .32202 L p .658 .749 .917 r
F P
0 g
s
.53517 .33156 m .56354 .32202 L .57838 .33956 L p .658 .749 .917 r
F P
0 g
s
.53517 .33156 m .56354 .32202 L .57838 .33956 L p .658 .749 .917 r
F P
0 g
s
.56354 .32202 m .57838 .33956 L .5788 .36483 L p .972 .685 .422 r
F P
0 g
s
.68216 .47495 m .68093 .44868 L .65207 .45755 L p .547 .329 .535 r
F P
0 g
s
.65207 .45755 m .65307 .48375 L .68216 .47495 L p .547 .329 .535 r
F P
0 g
s
.60916 .45005 m .63792 .44111 L .65207 .45755 L p .652 .756 .926 r
F P
0 g
s
.60916 .45005 m .63792 .44111 L .65207 .45755 L p .652 .756 .926 r
F P
0 g
s
.63792 .44111 m .65207 .45755 L .65307 .48375 L p .974 .684 .41 r
F P
0 g
s
.65207 .45755 m .63792 .44111 L .63704 .4152 L p .974 .684 .41 r
F P
0 g
s
.52223 .43486 m .52225 .40891 L .4942 .41798 L p .537 .315 .524 r
F P
0 g
s
.4942 .41798 m .49396 .44387 L .52223 .43486 L p .537 .315 .524 r
F P
0 g
s
.52225 .40891 m .4942 .41798 L .47857 .40116 L p .654 .754 .923 r
F P
0 g
s
.52223 .43486 m .52225 .40891 L .4942 .41798 L p .537 .315 .524 r
F P
0 g
s
.4942 .41798 m .49396 .44387 L .52223 .43486 L p .537 .315 .524 r
F P
0 g
s
.45061 .41031 m .47857 .40116 L .4942 .41798 L p .654 .754 .923 r
F P
0 g
s
.47857 .40116 m .4942 .41798 L .49396 .44387 L p .966 .687 .452 r
F P
0 g
s
.47857 .40116 m .4942 .41798 L .49396 .44387 L p .966 .687 .452 r
F P
0 g
s
.36231 .39478 m .36358 .36914 L .33632 .37841 L p .526 .299 .513 r
F P
0 g
s
.33632 .37841 m .33485 .40399 L .36231 .39478 L p .526 .299 .513 r
F P
0 g
s
.33632 .37841 m .31921 .36122 L .32081 .33593 L p .957 .688 .485 r
F P
0 g
s
.33632 .37841 m .31921 .36122 L .32081 .33593 L p .957 .688 .485 r
F P
0 g
s
.36358 .36914 m .33632 .37841 L .31921 .36122 L p .656 .751 .92 r
F P
0 g
s
.29206 .37057 m .31921 .36122 L .33632 .37841 L p .656 .751 .92 r
F P
0 g
s
.20239 .35469 m .2049 .32937 L .17845 .33884 L p .514 .281 .5 r
F P
0 g
s
.17845 .33884 m .17574 .36411 L .20239 .35469 L p .514 .281 .5 r
F P
0 g
s
.17845 .33884 m .15985 .32128 L .16269 .2963 L p .946 .686 .511 r
F P
0 g
s
.17845 .33884 m .15985 .32128 L .16269 .2963 L p .946 .686 .511 r
F P
0 g
s
.2049 .32937 m .17845 .33884 L .15985 .32128 L p .658 .749 .917 r
F P
0 g
s
.20239 .35469 m .2049 .32937 L .17845 .33884 L p .514 .281 .5 r
F P
0 g
s
.17845 .33884 m .17574 .36411 L .20239 .35469 L p .514 .281 .5 r
F P
0 g
s
.13351 .33083 m .15985 .32128 L .17845 .33884 L p .658 .749 .917 r
F P
0 g
s
.13351 .33083 m .15985 .32128 L .17845 .33884 L p .658 .749 .917 r
F P
0 g
s
.15985 .32128 m .17845 .33884 L .17574 .36411 L p .946 .686 .511 r
F P
0 g
s
.2049 .32937 m .17845 .33884 L .15985 .32128 L p .658 .749 .917 r
F P
0 g
s
.15985 .32128 m .17845 .33884 L .17574 .36411 L p .946 .686 .511 r
F P
0 g
s
.40995 .49646 m .39352 .48037 L .39454 .45415 L p .959 .688 .477 r
F P
0 g
s
.40995 .49646 m .39352 .48037 L .39454 .45415 L p .959 .688 .477 r
F P
0 g
s
.43759 .48778 m .40995 .49646 L .39352 .48037 L p .649 .759 .929 r
F P
0 g
s
.36599 .48912 m .39352 .48037 L .40995 .49646 L p .649 .759 .929 r
F P
0 g
s
.25202 .45687 m .2341 .44042 L .23636 .4145 L p .949 .687 .505 r
F P
0 g
s
.27886 .448 m .25202 .45687 L .2341 .44042 L p .652 .756 .926 r
F P
0 g
s
.67985 .35396 m .67864 .32863 L .64978 .33811 L p .541 .319 .528 r
F P
0 g
s
.64978 .33811 m .65076 .36339 L .67985 .35396 L p .541 .319 .528 r
F P
0 g
s
.64978 .33811 m .63561 .32054 L .63474 .29556 L p .975 .682 .398 r
F P
0 g
s
.67864 .32863 m .64978 .33811 L .63561 .32054 L p .658 .749 .917 r
F P
0 g
s
.67985 .35396 m .67864 .32863 L .64978 .33811 L p .541 .319 .528 r
F P
0 g
s
.64978 .33811 m .65076 .36339 L .67985 .35396 L p .541 .319 .528 r
F P
0 g
s
.60685 .3301 m .63561 .32054 L .64978 .33811 L p .658 .749 .917 r
F P
0 g
s
.63561 .32054 m .64978 .33811 L .65076 .36339 L p .975 .682 .398 r
F P
0 g
s
.44823 .29034 m .47619 .28058 L .49185 .29853 L p .66 .747 .915 r
F P
0 g
s
.47619 .28058 m .49185 .29853 L .49159 .32349 L p .969 .687 .442 r
F P
0 g
s
.7546 .47358 m .7528 .44731 L .72356 .45619 L p .55 .333 .538 r
F P
0 g
s
.72356 .45619 m .72512 .4824 L .7546 .47358 L p .55 .333 .538 r
F P
0 g
s
.72356 .45619 m .71008 .43972 L .70863 .4138 L p .976 .68 .386 r
F P
0 g
s
.72356 .45619 m .71008 .43972 L .70863 .4138 L p .976 .68 .386 r
F P
0 g
s
.7528 .44731 m .72356 .45619 L .71008 .43972 L p .652 .756 .926 r
F P
0 g
s
.7546 .47358 m .7528 .44731 L .72356 .45619 L p .55 .333 .538 r
F P
0 g
s
.72356 .45619 m .72512 .4824 L .7546 .47358 L p .55 .333 .538 r
F P
0 g
s
.68093 .44868 m .71008 .43972 L .72356 .45619 L p .652 .756 .926 r
F P
0 g
s
.68093 .44868 m .71008 .43972 L .72356 .45619 L p .652 .756 .926 r
F P
0 g
s
.71008 .43972 m .72356 .45619 L .72512 .4824 L p .976 .68 .386 r
F P
0 g
s
.7528 .44731 m .72356 .45619 L .71008 .43972 L p .652 .756 .926 r
F P
0 g
s
.71008 .43972 m .72356 .45619 L .72512 .4824 L p .976 .68 .386 r
F P
0 g
s
.59455 .43347 m .594 .40751 L .56557 .41659 L p .541 .319 .528 r
F P
0 g
s
.56557 .41659 m .56589 .44249 L .59455 .43347 L p .541 .319 .528 r
F P
0 g
s
.56557 .41659 m .55059 .39975 L .55039 .37414 L p .971 .686 .432 r
F P
0 g
s
.56557 .41659 m .55059 .39975 L .55039 .37414 L p .971 .686 .432 r
F P
0 g
s
.594 .40751 m .56557 .41659 L .55059 .39975 L p .654 .754 .923 r
F P
0 g
s
.59455 .43347 m .594 .40751 L .56557 .41659 L p .541 .319 .528 r
F P
0 g
s
.56557 .41659 m .56589 .44249 L .59455 .43347 L p .541 .319 .528 r
F P
0 g
s
.52225 .40891 m .55059 .39975 L .56557 .41659 L p .654 .754 .923 r
F P
0 g
s
.52225 .40891 m .55059 .39975 L .56557 .41659 L p .654 .754 .923 r
F P
0 g
s
.55059 .39975 m .56557 .41659 L .56589 .44249 L p .971 .686 .432 r
F P
0 g
s
.594 .40751 m .56557 .41659 L .55059 .39975 L p .654 .754 .923 r
F P
0 g
s
.55059 .39975 m .56557 .41659 L .56589 .44249 L p .971 .686 .432 r
F P
0 g
s
.4345 .39335 m .43521 .3677 L .40757 .37699 L p .53 .304 .517 r
F P
0 g
s
.40757 .37699 m .40665 .40258 L .4345 .39335 L p .53 .304 .517 r
F P
0 g
s
.40757 .37699 m .39111 .35977 L .39215 .33448 L p .962 .688 .469 r
F P
0 g
s
.40757 .37699 m .39111 .35977 L .39215 .33448 L p .962 .688 .469 r
F P
0 g
s
.43521 .3677 m .40757 .37699 L .39111 .35977 L p .656 .751 .92 r
F P
0 g
s
.4345 .39335 m .43521 .3677 L .40757 .37699 L p .53 .304 .517 r
F P
0 g
s
.40757 .37699 m .40665 .40258 L .4345 .39335 L p .53 .304 .517 r
F P
0 g
s
.36358 .36914 m .39111 .35977 L .40757 .37699 L p .656 .751 .92 r
F P
0 g
s
.36358 .36914 m .39111 .35977 L .40757 .37699 L p .656 .751 .92 r
F P
0 g
s
.39111 .35977 m .40757 .37699 L .40665 .40258 L p .962 .688 .469 r
F P
0 g
s
.43521 .3677 m .40757 .37699 L .39111 .35977 L p .656 .751 .92 r
F P
0 g
s
.39111 .35977 m .40757 .37699 L .40665 .40258 L p .962 .688 .469 r
F P
0 g
s
.27446 .35324 m .27641 .3279 L .24957 .33739 L p .518 .287 .504 r
F P
0 g
s
.24957 .33739 m .24742 .36267 L .27446 .35324 L p .518 .287 .504 r
F P
0 g
s
.24957 .33739 m .23163 .3198 L .23391 .29481 L p .952 .687 .499 r
F P
0 g
s
.24957 .33739 m .23163 .3198 L .23391 .29481 L p .952 .687 .499 r
F P
0 g
s
.27641 .3279 m .24957 .33739 L .23163 .3198 L p .658 .749 .917 r
F P
0 g
s
.27446 .35324 m .27641 .3279 L .24957 .33739 L p .518 .287 .504 r
F P
0 g
s
.24957 .33739 m .24742 .36267 L .27446 .35324 L p .518 .287 .504 r
F P
0 g
s
.2049 .32937 m .23163 .3198 L .24957 .33739 L p .658 .749 .917 r
F P
0 g
s
.2049 .32937 m .23163 .3198 L .24957 .33739 L p .658 .749 .917 r
F P
0 g
s
.23163 .3198 m .24957 .33739 L .24742 .36267 L p .952 .687 .499 r
F P
0 g
s
.27641 .3279 m .24957 .33739 L .23163 .3198 L p .658 .749 .917 r
F P
0 g
s
.23163 .3198 m .24957 .33739 L .24742 .36267 L p .952 .687 .499 r
F P
0 g
s
.11441 .31312 m .11761 .2881 L .09158 .29778 L p .504 .268 .49 r
F P
0 g
s
.09158 .29778 m .08819 .32275 L .11441 .31312 L p .504 .268 .49 r
F P
0 g
s
.43759 .48778 m .46551 .47902 L .48128 .49513 L p .649 .759 .929 r
F P
0 g
s
.48128 .49513 m .46551 .47902 L .46597 .45279 L p .964 .688 .461 r
F P
0 g
s
.34908 .4729 m .35045 .44662 L .32323 .45551 L p .53 .304 .517 r
F P
0 g
s
.32323 .45551 m .32165 .48173 L .34908 .4729 L p .53 .304 .517 r
F P
0 g
s
.32323 .45551 m .30597 .43903 L .30767 .41311 L p .954 .688 .492 r
F P
0 g
s
.35045 .44662 m .32323 .45551 L .30597 .43903 L p .652 .756 .926 r
F P
0 g
s
.34908 .4729 m .35045 .44662 L .32323 .45551 L p .53 .304 .517 r
F P
0 g
s
.32323 .45551 m .32165 .48173 L .34908 .4729 L p .53 .304 .517 r
F P
0 g
s
.27886 .448 m .30597 .43903 L .32323 .45551 L p .652 .756 .926 r
F P
0 g
s
.27886 .448 m .30597 .43903 L .32323 .45551 L p .652 .756 .926 r
F P
0 g
s
.30597 .43903 m .32323 .45551 L .32165 .48173 L p .954 .688 .492 r
F P
0 g
s
.30597 .43903 m .32323 .45551 L .32165 .48173 L p .954 .688 .492 r
F P
0 g
s
.75232 .35251 m .75054 .32717 L .7213 .33666 L p .544 .324 .532 r
F P
0 g
s
.7213 .33666 m .72284 .36194 L .75232 .35251 L p .544 .324 .532 r
F P
0 g
s
.7213 .33666 m .70778 .31906 L .70636 .29407 L p .976 .678 .372 r
F P
0 g
s
.75054 .32717 m .7213 .33666 L .70778 .31906 L p .658 .749 .917 r
F P
0 g
s
.75232 .35251 m .75054 .32717 L .7213 .33666 L p .544 .324 .532 r
F P
0 g
s
.7213 .33666 m .72284 .36194 L .75232 .35251 L p .544 .324 .532 r
F P
0 g
s
.67864 .32863 m .70778 .31906 L .7213 .33666 L p .658 .749 .917 r
F P
0 g
s
.70778 .31906 m .7213 .33666 L .72284 .36194 L p .976 .678 .372 r
F P
0 g
s
.75054 .32717 m .7213 .33666 L .70778 .31906 L p .658 .749 .917 r
F P
0 g
s
.70778 .31906 m .7213 .33666 L .72284 .36194 L p .976 .678 .372 r
F P
0 g
s
.59221 .31237 m .59168 .28735 L .56324 .29704 L p .534 .309 .521 r
F P
0 g
s
.56324 .29704 m .56354 .32202 L .59221 .31237 L p .534 .309 .521 r
F P
0 g
s
.59168 .28735 m .56324 .29704 L .54824 .27907 L p .66 .747 .915 r
F P
0 g
s
.59221 .31237 m .59168 .28735 L .56324 .29704 L p .534 .309 .521 r
F P
0 g
s
.56324 .29704 m .56354 .32202 L .59221 .31237 L p .534 .309 .521 r
F P
0 g
s
.5199 .28885 m .54824 .27907 L .56324 .29704 L p .66 .747 .915 r
F P
0 g
s
.54824 .27907 m .56324 .29704 L .56354 .32202 L p .972 .685 .422 r
F P
0 g
s
.54824 .27907 m .56324 .29704 L .56354 .32202 L p .972 .685 .422 r
F P
0 g
s
.7528 .44731 m .78234 .43834 L .79516 .45483 L p .652 .756 .926 r
F P
0 g
s
.79516 .45483 m .78234 .43834 L .78033 .41241 L p .976 .675 .358 r
F P
0 g
s
.63704 .4152 m .62273 .39833 L .62197 .37271 L p .974 .684 .41 r
F P
0 g
s
.66587 .4061 m .63704 .4152 L .62273 .39833 L p .654 .754 .923 r
F P
0 g
s
.66698 .43207 m .66587 .4061 L .63704 .4152 L p .544 .324 .532 r
F P
0 g
s
.63704 .4152 m .63792 .44111 L .66698 .43207 L p .544 .324 .532 r
F P
0 g
s
.594 .40751 m .62273 .39833 L .63704 .4152 L p .654 .754 .923 r
F P
0 g
s
.62273 .39833 m .63704 .4152 L .63792 .44111 L p .974 .684 .41 r
F P
0 g
s
.66587 .4061 m .63704 .4152 L .62273 .39833 L p .654 .754 .923 r
F P
0 g
s
.62273 .39833 m .63704 .4152 L .63792 .44111 L p .974 .684 .41 r
F P
0 g
s
.47892 .37557 m .46312 .35833 L .4636 .33302 L p .966 .687 .452 r
F P
0 g
s
.47892 .37557 m .46312 .35833 L .4636 .33302 L p .966 .687 .452 r
F P
0 g
s
.50695 .36627 m .47892 .37557 L .46312 .35833 L p .656 .751 .92 r
F P
0 g
s
.43521 .3677 m .46312 .35833 L .47892 .37557 L p .656 .751 .92 r
F P
0 g
s
.43521 .3677 m .46312 .35833 L .47892 .37557 L p .656 .751 .92 r
F P
0 g
s
.46312 .35833 m .47892 .37557 L .47857 .40116 L p .966 .687 .452 r
F P
0 g
s
.34663 .35178 m .34802 .32643 L .32081 .33593 L p .522 .293 .509 r
F P
0 g
s
.32081 .33593 m .31921 .36122 L .34663 .35178 L p .522 .293 .509 r
F P
0 g
s
.27641 .3279 m .30352 .31832 L .32081 .33593 L p .658 .749 .917 r
F P
0 g
s
.32081 .33593 m .30352 .31832 L .30524 .29333 L p .957 .688 .485 r
F P
0 g
s
.18646 .31163 m .1891 .2866 L .16269 .2963 L p .509 .275 .495 r
F P
0 g
s
.16269 .2963 m .15985 .32128 L .18646 .31163 L p .509 .275 .495 r
F P
0 g
s
.11761 .2881 m .14391 .27831 L .16269 .2963 L p .66 .747 .915 r
F P
0 g
s
.14391 .27831 m .16269 .2963 L .15985 .32128 L p .946 .686 .511 r
F P
0 g
s
.55272 .4938 m .53761 .47766 L .53751 .45142 L p .969 .687 .442 r
F P
0 g
s
.55272 .4938 m .53761 .47766 L .53751 .45142 L p .969 .687 .442 r
F P
0 g
s
.58113 .4851 m .55272 .4938 L .53761 .47766 L p .649 .759 .929 r
F P
0 g
s
.50931 .48644 m .53761 .47766 L .55272 .4938 L p .649 .759 .929 r
F P
0 g
s
.42134 .47154 m .42215 .44525 L .39454 .45415 L p .534 .309 .521 r
F P
0 g
s
.39454 .45415 m .39352 .48037 L .42134 .47154 L p .534 .309 .521 r
F P
0 g
s
.39454 .45415 m .37794 .43764 L .37909 .41171 L p .959 .688 .477 r
F P
0 g
s
.42215 .44525 m .39454 .45415 L .37794 .43764 L p .652 .756 .926 r
F P
0 g
s
.42134 .47154 m .42215 .44525 L .39454 .45415 L p .534 .309 .521 r
F P
0 g
s
.39454 .45415 m .39352 .48037 L .42134 .47154 L p .534 .309 .521 r
F P
0 g
s
.35045 .44662 m .37794 .43764 L .39454 .45415 L p .652 .756 .926 r
F P
0 g
s
.35045 .44662 m .37794 .43764 L .39454 .45415 L p .652 .756 .926 r
F P
0 g
s
.37794 .43764 m .39454 .45415 L .39352 .48037 L p .959 .688 .477 r
F P
0 g
s
.37794 .43764 m .39454 .45415 L .39352 .48037 L p .959 .688 .477 r
F P
0 g
s
.2611 .43137 m .26316 .4054 L .23636 .4145 L p .522 .293 .509 r
F P
0 g
s
.23636 .4145 m .2341 .44042 L .2611 .43137 L p .522 .293 .509 r
F P
0 g
s
.23636 .4145 m .21827 .39762 L .22066 .372 L p .949 .687 .505 r
F P
0 g
s
.23636 .4145 m .21827 .39762 L .22066 .372 L p .949 .687 .505 r
F P
0 g
s
.26316 .4054 m .23636 .4145 L .21827 .39762 L p .654 .754 .923 r
F P
0 g
s
.2611 .43137 m .26316 .4054 L .23636 .4145 L p .522 .293 .509 r
F P
0 g
s
.23636 .4145 m .2341 .44042 L .2611 .43137 L p .522 .293 .509 r
F P
0 g
s
.19159 .4068 m .21827 .39762 L .23636 .4145 L p .654 .754 .923 r
F P
0 g
s
.21827 .39762 m .23636 .4145 L .2341 .44042 L p .949 .687 .505 r
F P
0 g
s
.26316 .4054 m .23636 .4145 L .21827 .39762 L p .654 .754 .923 r
F P
0 g
s
.59168 .28735 m .62041 .27756 L .63474 .29556 L p .66 .747 .915 r
F P
0 g
s
.62041 .27756 m .63474 .29556 L .63561 .32054 L p .975 .682 .398 r
F P
0 g
s
.41892 .35031 m .41975 .32496 L .39215 .33448 L p .526 .299 .513 r
F P
0 g
s
.39215 .33448 m .39111 .35977 L .41892 .35031 L p .526 .299 .513 r
F P
0 g
s
.39215 .33448 m .37552 .31684 L .37668 .29184 L p .962 .688 .469 r
F P
0 g
s
.41975 .32496 m .39215 .33448 L .37552 .31684 L p .658 .749 .917 r
F P
0 g
s
.41892 .35031 m .41975 .32496 L .39215 .33448 L p .526 .299 .513 r
F P
0 g
s
.39215 .33448 m .39111 .35977 L .41892 .35031 L p .526 .299 .513 r
F P
0 g
s
.34802 .32643 m .37552 .31684 L .39215 .33448 L p .658 .749 .917 r
F P
0 g
s
.34802 .32643 m .37552 .31684 L .39215 .33448 L p .658 .749 .917 r
F P
0 g
s
.37552 .31684 m .39215 .33448 L .39111 .35977 L p .962 .688 .469 r
F P
0 g
s
.37552 .31684 m .39215 .33448 L .39111 .35977 L p .962 .688 .469 r
F P
0 g
s
.25863 .31014 m .2607 .2851 L .23391 .29481 L p .514 .281 .5 r
F P
0 g
s
.23391 .29481 m .23163 .3198 L .25863 .31014 L p .514 .281 .5 r
F P
0 g
s
.2607 .2851 m .23391 .29481 L .21579 .2768 L p .66 .747 .915 r
F P
0 g
s
.25863 .31014 m .2607 .2851 L .23391 .29481 L p .514 .281 .5 r
F P
0 g
s
.23391 .29481 m .23163 .3198 L .25863 .31014 L p .514 .281 .5 r
F P
0 g
s
.1891 .2866 m .21579 .2768 L .23391 .29481 L p .66 .747 .915 r
F P
0 g
s
.21579 .2768 m .23391 .29481 L .23163 .3198 L p .952 .687 .499 r
F P
0 g
s
.21579 .2768 m .23391 .29481 L .23163 .3198 L p .952 .687 .499 r
F P
0 g
s
.73952 .43067 m .73784 .40469 L .70863 .4138 L p .547 .329 .535 r
F P
0 g
s
.70863 .4138 m .71008 .43972 L .73952 .43067 L p .547 .329 .535 r
F P
0 g
s
.70863 .4138 m .69499 .39691 L .69366 .37129 L p .976 .68 .386 r
F P
0 g
s
.73784 .40469 m .70863 .4138 L .69499 .39691 L p .654 .754 .923 r
F P
0 g
s
.73952 .43067 m .73784 .40469 L .70863 .4138 L p .547 .329 .535 r
F P
0 g
s
.70863 .4138 m .71008 .43972 L .73952 .43067 L p .547 .329 .535 r
F P
0 g
s
.66587 .4061 m .69499 .39691 L .70863 .4138 L p .654 .754 .923 r
F P
0 g
s
.69499 .39691 m .70863 .4138 L .71008 .43972 L p .976 .68 .386 r
F P
0 g
s
.73784 .40469 m .70863 .4138 L .69499 .39691 L p .654 .754 .923 r
F P
0 g
s
.69499 .39691 m .70863 .4138 L .71008 .43972 L p .976 .68 .386 r
F P
0 g
s
.57922 .39049 m .5788 .36483 L .55039 .37414 L p .537 .315 .524 r
F P
0 g
s
.55039 .37414 m .55059 .39975 L .57922 .39049 L p .537 .315 .524 r
F P
0 g
s
.55039 .37414 m .53525 .35687 L .53517 .33156 L p .971 .686 .432 r
F P
0 g
s
.55039 .37414 m .53525 .35687 L .53517 .33156 L p .971 .686 .432 r
F P
0 g
s
.5788 .36483 m .55039 .37414 L .53525 .35687 L p .656 .751 .92 r
F P
0 g
s
.50695 .36627 m .53525 .35687 L .55039 .37414 L p .656 .751 .92 r
F P
0 g
s
.62428 .49246 m .60983 .47631 L .60916 .45005 L p .972 .685 .422 r
F P
0 g
s
.65307 .48375 m .62428 .49246 L .60983 .47631 L p .649 .759 .929 r
F P
0 g
s
.46597 .45279 m .45003 .43625 L .45061 .41031 L p .964 .688 .461 r
F P
0 g
s
.46597 .45279 m .45003 .43625 L .45061 .41031 L p .964 .688 .461 r
F P
0 g
s
.49396 .44387 m .46597 .45279 L .45003 .43625 L p .652 .756 .926 r
F P
0 g
s
.49372 .47017 m .49396 .44387 L .46597 .45279 L p .537 .315 .524 r
F P
0 g
s
.46597 .45279 m .46551 .47902 L .49372 .47017 L p .537 .315 .524 r
F P
0 g
s
.42215 .44525 m .45003 .43625 L .46597 .45279 L p .652 .756 .926 r
F P
0 g
s
.45003 .43625 m .46597 .45279 L .46551 .47902 L p .964 .688 .461 r
F P
0 g
s
.49396 .44387 m .46597 .45279 L .45003 .43625 L p .652 .756 .926 r
F P
0 g
s
.33485 .40399 m .30767 .41311 L .29024 .3962 L p .654 .754 .923 r
F P
0 g
s
.33336 .42997 m .33485 .40399 L .30767 .41311 L p .526 .299 .513 r
F P
0 g
s
.30767 .41311 m .30597 .43903 L .33336 .42997 L p .526 .299 .513 r
F P
0 g
s
.26316 .4054 m .29024 .3962 L .30767 .41311 L p .654 .754 .923 r
F P
0 g
s
.29024 .3962 m .30767 .41311 L .30597 .43903 L p .954 .688 .492 r
F P
0 g
s
.29024 .3962 m .30767 .41311 L .30597 .43903 L p .954 .688 .492 r
F P
0 g
s
.14937 .37343 m .13044 .35615 L .13351 .33083 L p .943 .686 .517 r
F P
0 g
s
.17574 .36411 m .14937 .37343 L .13044 .35615 L p .656 .751 .92 r
F P
0 g
s
.73723 .30939 m .73557 .28435 L .70636 .29407 L p .541 .319 .528 r
F P
0 g
s
.70636 .29407 m .70778 .31906 L .73723 .30939 L p .541 .319 .528 r
F P
0 g
s
.73557 .28435 m .70636 .29407 L .69268 .27604 L p .66 .747 .915 r
F P
0 g
s
.73723 .30939 m .73557 .28435 L .70636 .29407 L p .541 .319 .528 r
F P
0 g
s
.70636 .29407 m .70778 .31906 L .73723 .30939 L p .541 .319 .528 r
F P
0 g
s
.69268 .27604 m .70636 .29407 L .70778 .31906 L p .976 .678 .372 r
F P
0 g
s
.73784 .40469 m .76735 .39549 L .78033 .41241 L p .654 .754 .923 r
F P
0 g
s
.73784 .40469 m .76735 .39549 L .78033 .41241 L p .654 .754 .923 r
F P
0 g
s
.76735 .39549 m .78033 .41241 L .78234 .43834 L p .976 .675 .358 r
F P
0 g
s
.78033 .41241 m .76735 .39549 L .76546 .36985 L p .976 .675 .358 r
F P
0 g
s
.65176 .38906 m .65076 .36339 L .62197 .37271 L p .541 .319 .528 r
F P
0 g
s
.62197 .37271 m .62273 .39833 L .65176 .38906 L p .541 .319 .528 r
F P
0 g
s
.62197 .37271 m .60749 .35542 L .60685 .3301 L p .974 .684 .41 r
F P
0 g
s
.65076 .36339 m .62197 .37271 L .60749 .35542 L p .656 .751 .92 r
F P
0 g
s
.65176 .38906 m .65076 .36339 L .62197 .37271 L p .541 .319 .528 r
F P
0 g
s
.62197 .37271 m .62273 .39833 L .65176 .38906 L p .541 .319 .528 r
F P
0 g
s
.5788 .36483 m .60749 .35542 L .62197 .37271 L p .656 .751 .92 r
F P
0 g
s
.60749 .35542 m .62197 .37271 L .62273 .39833 L p .974 .684 .41 r
F P
0 g
s
.49133 .34885 m .49159 .32349 L .4636 .33302 L p .53 .304 .517 r
F P
0 g
s
.4636 .33302 m .46312 .35833 L .49133 .34885 L p .53 .304 .517 r
F P
0 g
s
.4636 .33302 m .44763 .31535 L .44823 .29034 L p .966 .687 .452 r
F P
0 g
s
.49159 .32349 m .4636 .33302 L .44763 .31535 L p .658 .749 .917 r
F P
0 g
s
.49133 .34885 m .49159 .32349 L .4636 .33302 L p .53 .304 .517 r
F P
0 g
s
.4636 .33302 m .46312 .35833 L .49133 .34885 L p .53 .304 .517 r
F P
0 g
s
.41975 .32496 m .44763 .31535 L .4636 .33302 L p .658 .749 .917 r
F P
0 g
s
.44763 .31535 m .4636 .33302 L .46312 .35833 L p .966 .687 .452 r
F P
0 g
s
.49159 .32349 m .4636 .33302 L .44763 .31535 L p .658 .749 .917 r
F P
0 g
s
.44763 .31535 m .4636 .33302 L .46312 .35833 L p .966 .687 .452 r
F P
0 g
s
.69594 .49113 m .68216 .47495 L .68093 .44868 L p .975 .682 .398 r
F P
0 g
s
.69594 .49113 m .68216 .47495 L .68093 .44868 L p .975 .682 .398 r
F P
0 g
s
.72512 .4824 m .69594 .49113 L .68216 .47495 L p .649 .759 .929 r
F P
0 g
s
.65307 .48375 m .68216 .47495 L .69594 .49113 L p .649 .759 .929 r
F P
0 g
s
.56621 .4688 m .56589 .44249 L .53751 .45142 L p .541 .319 .528 r
F P
0 g
s
.53751 .45142 m .53761 .47766 L .56621 .4688 L p .541 .319 .528 r
F P
0 g
s
.53751 .45142 m .52223 .43486 L .52225 .40891 L p .969 .687 .442 r
F P
0 g
s
.53751 .45142 m .52223 .43486 L .52225 .40891 L p .969 .687 .442 r
F P
0 g
s
.56589 .44249 m .53751 .45142 L .52223 .43486 L p .652 .756 .926 r
F P
0 g
s
.49396 .44387 m .52223 .43486 L .53751 .45142 L p .652 .756 .926 r
F P
0 g
s
.37909 .41171 m .36231 .39478 L .36358 .36914 L p .959 .688 .477 r
F P
0 g
s
.37909 .41171 m .36231 .39478 L .36358 .36914 L p .959 .688 .477 r
F P
0 g
s
.40665 .40258 m .37909 .41171 L .36231 .39478 L p .654 .754 .923 r
F P
0 g
s
.40572 .42857 m .40665 .40258 L .37909 .41171 L p .53 .304 .517 r
F P
0 g
s
.37909 .41171 m .37794 .43764 L .40572 .42857 L p .53 .304 .517 r
F P
0 g
s
.33485 .40399 m .36231 .39478 L .37909 .41171 L p .654 .754 .923 r
F P
0 g
s
.36231 .39478 m .37909 .41171 L .37794 .43764 L p .959 .688 .477 r
F P
0 g
s
.40665 .40258 m .37909 .41171 L .36231 .39478 L p .654 .754 .923 r
F P
0 g
s
.24523 .38834 m .24742 .36267 L .22066 .372 L p .518 .287 .504 r
F P
0 g
s
.22066 .372 m .21827 .39762 L .24523 .38834 L p .518 .287 .504 r
F P
0 g
s
.22066 .372 m .20239 .35469 L .2049 .32937 L p .949 .687 .505 r
F P
0 g
s
.22066 .372 m .20239 .35469 L .2049 .32937 L p .949 .687 .505 r
F P
0 g
s
.24742 .36267 m .22066 .372 L .20239 .35469 L p .656 .751 .92 r
F P
0 g
s
.24523 .38834 m .24742 .36267 L .22066 .372 L p .518 .287 .504 r
F P
0 g
s
.22066 .372 m .21827 .39762 L .24523 .38834 L p .518 .287 .504 r
F P
0 g
s
.17574 .36411 m .20239 .35469 L .22066 .372 L p .656 .751 .92 r
F P
0 g
s
.17574 .36411 m .20239 .35469 L .22066 .372 L p .656 .751 .92 r
F P
0 g
s
.20239 .35469 m .22066 .372 L .21827 .39762 L p .949 .687 .505 r
F P
0 g
s
.24742 .36267 m .22066 .372 L .20239 .35469 L p .656 .751 .92 r
F P
0 g
s
.20239 .35469 m .22066 .372 L .21827 .39762 L p .949 .687 .505 r
F P
0 g
s
.73557 .28435 m .76508 .27452 L .77809 .29258 L p .66 .747 .915 r
F P
0 g
s
.76508 .27452 m .77809 .29258 L .78008 .31758 L p .976 .672 .343 r
F P
0 g
s
.2945 .49046 m .27692 .47426 L .27886 .448 L p .952 .687 .499 r
F P
0 g
s
.32165 .48173 m .2945 .49046 L .27692 .47426 L p .649 .759 .929 r
F P
0 g
s
.7244 .38763 m .72284 .36194 L .69366 .37129 L p .544 .324 .532 r
F P
0 g
s
.69366 .37129 m .69499 .39691 L .7244 .38763 L p .544 .324 .532 r
F P
0 g
s
.69366 .37129 m .67985 .35396 L .67864 .32863 L p .976 .68 .386 r
F P
0 g
s
.69366 .37129 m .67985 .35396 L .67864 .32863 L p .976 .68 .386 r
F P
0 g
s
.72284 .36194 m .69366 .37129 L .67985 .35396 L p .656 .751 .92 r
F P
0 g
s
.65076 .36339 m .67985 .35396 L .69366 .37129 L p .656 .751 .92 r
F P
0 g
s
.65076 .36339 m .67985 .35396 L .69366 .37129 L p .656 .751 .92 r
F P
0 g
s
.67985 .35396 m .69366 .37129 L .69499 .39691 L p .976 .68 .386 r
F P
0 g
s
.56385 .34738 m .56354 .32202 L .53517 .33156 L p .534 .309 .521 r
F P
0 g
s
.53517 .33156 m .53525 .35687 L .56385 .34738 L p .534 .309 .521 r
F P
0 g
s
.53517 .33156 m .51986 .31386 L .5199 .28885 L p .971 .686 .432 r
F P
0 g
s
.56354 .32202 m .53517 .33156 L .51986 .31386 L p .658 .749 .917 r
F P
0 g
s
.49159 .32349 m .51986 .31386 L .53517 .33156 L p .658 .749 .917 r
F P
0 g
s
.51986 .31386 m .53517 .33156 L .53525 .35687 L p .971 .686 .432 r
F P
0 g
s
.40425 .28209 m .37668 .29184 L .35988 .27376 L p .66 .747 .915 r
F P
0 g
s
.4033 .30714 m .40425 .28209 L .37668 .29184 L p .522 .293 .509 r
F P
0 g
s
.37668 .29184 m .37552 .31684 L .4033 .30714 L p .522 .293 .509 r
F P
0 g
s
.35988 .27376 m .37668 .29184 L .37552 .31684 L p .962 .688 .469 r
F P
0 g
s
.72512 .4824 m .7546 .47358 L .76771 .48979 L p .649 .759 .929 r
F P
0 g
s
.76771 .48979 m .7546 .47358 L .7528 .44731 L p .976 .678 .372 r
F P
0 g
s
.63882 .46743 m .63792 .44111 L .60916 .45005 L p .544 .324 .532 r
F P
0 g
s
.60916 .45005 m .60983 .47631 L .63882 .46743 L p .544 .324 .532 r
F P
0 g
s
.60916 .45005 m .59455 .43347 L .594 .40751 L p .972 .685 .422 r
F P
0 g
s
.60916 .45005 m .59455 .43347 L .594 .40751 L p .972 .685 .422 r
F P
0 g
s
.63792 .44111 m .60916 .45005 L .59455 .43347 L p .652 .756 .926 r
F P
0 g
s
.63882 .46743 m .63792 .44111 L .60916 .45005 L p .544 .324 .532 r
F P
0 g
s
.60916 .45005 m .60983 .47631 L .63882 .46743 L p .544 .324 .532 r
F P
0 g
s
.56589 .44249 m .59455 .43347 L .60916 .45005 L p .652 .756 .926 r
F P
0 g
s
.59455 .43347 m .60916 .45005 L .60983 .47631 L p .972 .685 .422 r
F P
0 g
s
.63792 .44111 m .60916 .45005 L .59455 .43347 L p .652 .756 .926 r
F P
0 g
s
.4782 .42717 m .47857 .40116 L .45061 .41031 L p .534 .309 .521 r
F P
0 g
s
.45061 .41031 m .45003 .43625 L .4782 .42717 L p .534 .309 .521 r
F P
0 g
s
.45061 .41031 m .4345 .39335 L .43521 .3677 L p .964 .688 .461 r
F P
0 g
s
.45061 .41031 m .4345 .39335 L .43521 .3677 L p .964 .688 .461 r
F P
0 g
s
.47857 .40116 m .45061 .41031 L .4345 .39335 L p .654 .754 .923 r
F P
0 g
s
.4782 .42717 m .47857 .40116 L .45061 .41031 L p .534 .309 .521 r
F P
0 g
s
.45061 .41031 m .45003 .43625 L .4782 .42717 L p .534 .309 .521 r
F P
0 g
s
.40665 .40258 m .4345 .39335 L .45061 .41031 L p .654 .754 .923 r
F P
0 g
s
.4345 .39335 m .45061 .41031 L .45003 .43625 L p .964 .688 .461 r
F P
0 g
s
.47857 .40116 m .45061 .41031 L .4345 .39335 L p .654 .754 .923 r
F P
0 g
s
.29206 .37057 m .27446 .35324 L .27641 .3279 L p .954 .688 .492 r
F P
0 g
s
.31921 .36122 m .29206 .37057 L .27446 .35324 L p .656 .751 .92 r
F P
0 g
s
.31759 .38691 m .31921 .36122 L .29206 .37057 L p .522 .293 .509 r
F P
0 g
s
.29206 .37057 m .29024 .3962 L .31759 .38691 L p .522 .293 .509 r
F P
0 g
s
.24742 .36267 m .27446 .35324 L .29206 .37057 L p .656 .751 .92 r
F P
0 g
s
.24742 .36267 m .27446 .35324 L .29206 .37057 L p .656 .751 .92 r
F P
0 g
s
.27446 .35324 m .29206 .37057 L .29024 .3962 L p .954 .688 .492 r
F P
0 g
s
.27446 .35324 m .29206 .37057 L .29024 .3962 L p .954 .688 .492 r
F P
0 g
s
.15697 .34665 m .15985 .32128 L .13351 .33083 L p .509 .275 .495 r
F P
0 g
s
.13351 .33083 m .13044 .35615 L .15697 .34665 L p .509 .275 .495 r
F P
0 g
s
.13351 .33083 m .11441 .31312 L .11761 .2881 L p .943 .686 .517 r
F P
0 g
s
.13351 .33083 m .11441 .31312 L .11761 .2881 L p .943 .686 .517 r
F P
0 g
s
.15985 .32128 m .13351 .33083 L .11441 .31312 L p .658 .749 .917 r
F P
0 g
s
.08819 .32275 m .11441 .31312 L .13351 .33083 L p .658 .749 .917 r
F P
0 g
s
.36599 .48912 m .34908 .4729 L .35045 .44662 L p .957 .688 .485 r
F P
0 g
s
.36599 .48912 m .34908 .4729 L .35045 .44662 L p .957 .688 .485 r
F P
0 g
s
.39352 .48037 m .36599 .48912 L .34908 .4729 L p .649 .759 .929 r
F P
0 g
s
.32165 .48173 m .34908 .4729 L .36599 .48912 L p .649 .759 .929 r
F P
0 g
s
.72284 .36194 m .75232 .35251 L .76546 .36985 L p .656 .751 .92 r
F P
0 g
s
.72284 .36194 m .75232 .35251 L .76546 .36985 L p .656 .751 .92 r
F P
0 g
s
.75232 .35251 m .76546 .36985 L .76735 .39549 L p .976 .675 .358 r
F P
0 g
s
.76546 .36985 m .75232 .35251 L .75054 .32717 L p .976 .675 .358 r
F P
0 g
s
.60685 .3301 m .59221 .31237 L .59168 .28735 L p .974 .684 .41 r
F P
0 g
s
.60685 .3301 m .59221 .31237 L .59168 .28735 L p .974 .684 .41 r
F P
0 g
s
.63561 .32054 m .60685 .3301 L .59221 .31237 L p .658 .749 .917 r
F P
0 g
s
.56354 .32202 m .59221 .31237 L .60685 .3301 L p .658 .749 .917 r
F P
0 g
s
.4758 .30564 m .47619 .28058 L .44823 .29034 L p .526 .299 .513 r
F P
0 g
s
.44823 .29034 m .44763 .31535 L .4758 .30564 L p .526 .299 .513 r
F P
0 g
s
.47619 .28058 m .44823 .29034 L .4321 .27224 L p .66 .747 .915 r
F P
0 g
s
.4758 .30564 m .47619 .28058 L .44823 .29034 L p .526 .299 .513 r
F P
0 g
s
.44823 .29034 m .44763 .31535 L .4758 .30564 L p .526 .299 .513 r
F P
0 g
s
.4321 .27224 m .44823 .29034 L .44763 .31535 L p .966 .687 .452 r
F P
0 g
s
.71154 .46605 m .71008 .43972 L .68093 .44868 L p .547 .329 .535 r
F P
0 g
s
.68093 .44868 m .68216 .47495 L .71154 .46605 L p .547 .329 .535 r
F P
0 g
s
.68093 .44868 m .66698 .43207 L .66587 .4061 L p .975 .682 .398 r
F P
0 g
s
.71008 .43972 m .68093 .44868 L .66698 .43207 L p .652 .756 .926 r
F P
0 g
s
.5508 .42576 m .55059 .39975 L .52225 .40891 L p .537 .315 .524 r
F P
0 g
s
.52225 .40891 m .52223 .43486 L .5508 .42576 L p .537 .315 .524 r
F P
0 g
s
.55059 .39975 m .52225 .40891 L .50681 .39192 L p .654 .754 .923 r
F P
0 g
s
.5508 .42576 m .55059 .39975 L .52225 .40891 L p .537 .315 .524 r
F P
0 g
s
.52225 .40891 m .52223 .43486 L .5508 .42576 L p .537 .315 .524 r
F P
0 g
s
.47857 .40116 m .50681 .39192 L .52225 .40891 L p .654 .754 .923 r
F P
0 g
s
.50681 .39192 m .52225 .40891 L .52223 .43486 L p .969 .687 .442 r
F P
0 g
s
.50681 .39192 m .52225 .40891 L .52223 .43486 L p .969 .687 .442 r
F P
0 g
s
.39006 .38547 m .39111 .35977 L .36358 .36914 L p .526 .299 .513 r
F P
0 g
s
.36358 .36914 m .36231 .39478 L .39006 .38547 L p .526 .299 .513 r
F P
0 g
s
.36358 .36914 m .34663 .35178 L .34802 .32643 L p .959 .688 .477 r
F P
0 g
s
.36358 .36914 m .34663 .35178 L .34802 .32643 L p .959 .688 .477 r
F P
0 g
s
.39111 .35977 m .36358 .36914 L .34663 .35178 L p .656 .751 .92 r
F P
0 g
s
.31921 .36122 m .34663 .35178 L .36358 .36914 L p .656 .751 .92 r
F P
0 g
s
.22931 .34518 m .23163 .3198 L .2049 .32937 L p .514 .281 .5 r
F P
0 g
s
.2049 .32937 m .20239 .35469 L .22931 .34518 L p .514 .281 .5 r
F P
0 g
s
.2049 .32937 m .18646 .31163 L .1891 .2866 L p .949 .687 .505 r
F P
0 g
s
.2049 .32937 m .18646 .31163 L .1891 .2866 L p .949 .687 .505 r
F P
0 g
s
.23163 .3198 m .2049 .32937 L .18646 .31163 L p .658 .749 .917 r
F P
0 g
s
.22931 .34518 m .23163 .3198 L .2049 .32937 L p .514 .281 .5 r
F P
0 g
s
.2049 .32937 m .20239 .35469 L .22931 .34518 L p .514 .281 .5 r
F P
0 g
s
.15985 .32128 m .18646 .31163 L .2049 .32937 L p .658 .749 .917 r
F P
0 g
s
.15985 .32128 m .18646 .31163 L .2049 .32937 L p .658 .749 .917 r
F P
0 g
s
.18646 .31163 m .2049 .32937 L .20239 .35469 L p .949 .687 .505 r
F P
0 g
s
.23163 .3198 m .2049 .32937 L .18646 .31163 L p .658 .749 .917 r
F P
0 g
s
.18646 .31163 m .2049 .32937 L .20239 .35469 L p .949 .687 .505 r
F P
0 g
s
.39352 .48037 m .42134 .47154 L .43759 .48778 L p .649 .759 .929 r
F P
0 g
s
.43759 .48778 m .42134 .47154 L .42215 .44525 L p .962 .688 .469 r
F P
0 g
s
.30424 .46536 m .30597 .43903 L .27886 .448 L p .526 .299 .513 r
F P
0 g
s
.27886 .448 m .27692 .47426 L .30424 .46536 L p .526 .299 .513 r
F P
0 g
s
.27886 .448 m .2611 .43137 L .26316 .4054 L p .952 .687 .499 r
F P
0 g
s
.27886 .448 m .2611 .43137 L .26316 .4054 L p .952 .687 .499 r
F P
0 g
s
.30597 .43903 m .27886 .448 L .2611 .43137 L p .652 .756 .926 r
F P
0 g
s
.30424 .46536 m .30597 .43903 L .27886 .448 L p .526 .299 .513 r
F P
0 g
s
.27886 .448 m .27692 .47426 L .30424 .46536 L p .526 .299 .513 r
F P
0 g
s
.2341 .44042 m .2611 .43137 L .27886 .448 L p .652 .756 .926 r
F P
0 g
s
.2611 .43137 m .27886 .448 L .27692 .47426 L p .952 .687 .499 r
F P
0 g
s
.30597 .43903 m .27886 .448 L .2611 .43137 L p .652 .756 .926 r
F P
0 g
s
.70923 .34444 m .70778 .31906 L .67864 .32863 L p .541 .319 .528 r
F P
0 g
s
.67864 .32863 m .67985 .35396 L .70923 .34444 L p .541 .319 .528 r
F P
0 g
s
.70778 .31906 m .67864 .32863 L .66466 .31088 L p .658 .749 .917 r
F P
0 g
s
.70923 .34444 m .70778 .31906 L .67864 .32863 L p .541 .319 .528 r
F P
0 g
s
.67864 .32863 m .67985 .35396 L .70923 .34444 L p .541 .319 .528 r
F P
0 g
s
.63561 .32054 m .66466 .31088 L .67864 .32863 L p .658 .749 .917 r
F P
0 g
s
.66466 .31088 m .67864 .32863 L .67985 .35396 L p .976 .68 .386 r
F P
0 g
s
.66466 .31088 m .67864 .32863 L .67985 .35396 L p .976 .68 .386 r
F P
0 g
s
.54843 .30414 m .54824 .27907 L .5199 .28885 L p .53 .304 .517 r
F P
0 g
s
.5199 .28885 m .51986 .31386 L .54843 .30414 L p .53 .304 .517 r
F P
0 g
s
.7528 .44731 m .73952 .43067 L .73784 .40469 L p .976 .678 .372 r
F P
0 g
s
.7528 .44731 m .73952 .43067 L .73784 .40469 L p .976 .678 .372 r
F P
0 g
s
.78234 .43834 m .7528 .44731 L .73952 .43067 L p .652 .756 .926 r
F P
0 g
s
.71008 .43972 m .73952 .43067 L .7528 .44731 L p .652 .756 .926 r
F P
0 g
s
.71008 .43972 m .73952 .43067 L .7528 .44731 L p .652 .756 .926 r
F P
0 g
s
.73952 .43067 m .7528 .44731 L .7546 .47358 L p .976 .678 .372 r
F P
0 g
s
.62351 .42435 m .62273 .39833 L .594 .40751 L p .541 .319 .528 r
F P
0 g
s
.594 .40751 m .59455 .43347 L .62351 .42435 L p .541 .319 .528 r
F P
0 g
s
.594 .40751 m .57922 .39049 L .5788 .36483 L p .972 .685 .422 r
F P
0 g
s
.62273 .39833 m .594 .40751 L .57922 .39049 L p .654 .754 .923 r
F P
0 g
s
.62351 .42435 m .62273 .39833 L .594 .40751 L p .541 .319 .528 r
F P
0 g
s
.594 .40751 m .59455 .43347 L .62351 .42435 L p .541 .319 .528 r
F P
0 g
s
.55059 .39975 m .57922 .39049 L .594 .40751 L p .654 .754 .923 r
F P
0 g
s
.55059 .39975 m .57922 .39049 L .594 .40751 L p .654 .754 .923 r
F P
0 g
s
.57922 .39049 m .594 .40751 L .59455 .43347 L p .972 .685 .422 r
F P
0 g
s
.57922 .39049 m .594 .40751 L .59455 .43347 L p .972 .685 .422 r
F P
0 g
s
.46264 .38403 m .46312 .35833 L .43521 .3677 L p .53 .304 .517 r
F P
0 g
s
.43521 .3677 m .4345 .39335 L .46264 .38403 L p .53 .304 .517 r
F P
0 g
s
.43521 .3677 m .41892 .35031 L .41975 .32496 L p .964 .688 .461 r
F P
0 g
s
.43521 .3677 m .41892 .35031 L .41975 .32496 L p .964 .688 .461 r
F P
0 g
s
.46312 .35833 m .43521 .3677 L .41892 .35031 L p .656 .751 .92 r
F P
0 g
s
.46264 .38403 m .46312 .35833 L .43521 .3677 L p .53 .304 .517 r
F P
0 g
s
.43521 .3677 m .4345 .39335 L .46264 .38403 L p .53 .304 .517 r
F P
0 g
s
.39111 .35977 m .41892 .35031 L .43521 .3677 L p .656 .751 .92 r
F P
0 g
s
.39111 .35977 m .41892 .35031 L .43521 .3677 L p .656 .751 .92 r
F P
0 g
s
.41892 .35031 m .43521 .3677 L .4345 .39335 L p .964 .688 .461 r
F P
0 g
s
.46312 .35833 m .43521 .3677 L .41892 .35031 L p .656 .751 .92 r
F P
0 g
s
.41892 .35031 m .43521 .3677 L .4345 .39335 L p .964 .688 .461 r
F P
0 g
s
.23163 .3198 m .25863 .31014 L .27641 .3279 L p .658 .749 .917 r
F P
0 g
s
.23163 .3198 m .25863 .31014 L .27641 .3279 L p .658 .749 .917 r
F P
0 g
s
.25863 .31014 m .27641 .3279 L .27446 .35324 L p .954 .688 .492 r
F P
0 g
s
.27641 .3279 m .25863 .31014 L .2607 .2851 L p .954 .688 .492 r
F P
0 g
s
.1409 .30339 m .14391 .27831 L .11761 .2881 L p .504 .268 .49 r
F P
0 g
s
.11761 .2881 m .11441 .31312 L .1409 .30339 L p .504 .268 .49 r
F P
0 g
s
.37678 .46399 m .37794 .43764 L .35045 .44662 L p .53 .304 .517 r
F P
0 g
s
.35045 .44662 m .34908 .4729 L .37678 .46399 L p .53 .304 .517 r
F P
0 g
s
.37794 .43764 m .35045 .44662 L .33336 .42997 L p .652 .756 .926 r
F P
0 g
s
.37678 .46399 m .37794 .43764 L .35045 .44662 L p .53 .304 .517 r
F P
0 g
s
.35045 .44662 m .34908 .4729 L .37678 .46399 L p .53 .304 .517 r
F P
0 g
s
.30597 .43903 m .33336 .42997 L .35045 .44662 L p .652 .756 .926 r
F P
0 g
s
.33336 .42997 m .35045 .44662 L .34908 .4729 L p .957 .688 .485 r
F P
0 g
s
.33336 .42997 m .35045 .44662 L .34908 .4729 L p .957 .688 .485 r
F P
0 g
s
.19159 .4068 m .17299 .38978 L .17574 .36411 L p .946 .686 .511 r
F P
0 g
s
.21827 .39762 m .19159 .4068 L .17299 .38978 L p .654 .754 .923 r
F P
0 g
s
.75054 .32717 m .73723 .30939 L .73557 .28435 L p .976 .675 .358 r
F P
0 g
s
.75054 .32717 m .73723 .30939 L .73557 .28435 L p .976 .675 .358 r
F P
0 g
s
.78008 .31758 m .75054 .32717 L .73723 .30939 L p .658 .749 .917 r
F P
0 g
s
.70778 .31906 m .73723 .30939 L .75054 .32717 L p .658 .749 .917 r
F P
0 g
s
.70778 .31906 m .73723 .30939 L .75054 .32717 L p .658 .749 .917 r
F P
0 g
s
.73723 .30939 m .75054 .32717 L .75232 .35251 L p .976 .675 .358 r
F P
0 g
s
.62116 .30263 m .62041 .27756 L .59168 .28735 L p .534 .309 .521 r
F P
0 g
s
.59168 .28735 m .59221 .31237 L .62116 .30263 L p .534 .309 .521 r
F P
0 g
s
.62041 .27756 m .59168 .28735 L .57687 .26919 L p .66 .747 .915 r
F P
0 g
s
.62116 .30263 m .62041 .27756 L .59168 .28735 L p .534 .309 .521 r
F P
0 g
s
.59168 .28735 m .59221 .31237 L .62116 .30263 L p .534 .309 .521 r
F P
0 g
s
.54824 .27907 m .57687 .26919 L .59168 .28735 L p .66 .747 .915 r
F P
0 g
s
.57687 .26919 m .59168 .28735 L .59221 .31237 L p .974 .684 .41 r
F P
0 g
s
.57687 .26919 m .59168 .28735 L .59221 .31237 L p .974 .684 .41 r
F P
0 g
s
.69633 .42294 m .69499 .39691 L .66587 .4061 L p .544 .324 .532 r
F P
0 g
s
.66587 .4061 m .66698 .43207 L .69633 .42294 L p .544 .324 .532 r
F P
0 g
s
.66587 .4061 m .65176 .38906 L .65076 .36339 L p .975 .682 .398 r
F P
0 g
s
.66587 .4061 m .65176 .38906 L .65076 .36339 L p .975 .682 .398 r
F P
0 g
s
.69499 .39691 m .66587 .4061 L .65176 .38906 L p .654 .754 .923 r
F P
0 g
s
.69633 .42294 m .69499 .39691 L .66587 .4061 L p .544 .324 .532 r
F P
0 g
s
.66587 .4061 m .66698 .43207 L .69633 .42294 L p .544 .324 .532 r
F P
0 g
s
.62273 .39833 m .65176 .38906 L .66587 .4061 L p .654 .754 .923 r
F P
0 g
s
.62273 .39833 m .65176 .38906 L .66587 .4061 L p .654 .754 .923 r
F P
0 g
s
.65176 .38906 m .66587 .4061 L .66698 .43207 L p .975 .682 .398 r
F P
0 g
s
.69499 .39691 m .66587 .4061 L .65176 .38906 L p .654 .754 .923 r
F P
0 g
s
.65176 .38906 m .66587 .4061 L .66698 .43207 L p .975 .682 .398 r
F P
0 g
s
.50695 .36627 m .49133 .34885 L .49159 .32349 L p .969 .687 .442 r
F P
0 g
s
.50695 .36627 m .49133 .34885 L .49159 .32349 L p .969 .687 .442 r
F P
0 g
s
.53525 .35687 m .50695 .36627 L .49133 .34885 L p .656 .751 .92 r
F P
0 g
s
.53534 .38259 m .53525 .35687 L .50695 .36627 L p .534 .309 .521 r
F P
0 g
s
.50695 .36627 m .50681 .39192 L .53534 .38259 L p .534 .309 .521 r
F P
0 g
s
.46312 .35833 m .49133 .34885 L .50695 .36627 L p .656 .751 .92 r
F P
0 g
s
.49133 .34885 m .50695 .36627 L .50681 .39192 L p .969 .687 .442 r
F P
0 g
s
.53525 .35687 m .50695 .36627 L .49133 .34885 L p .656 .751 .92 r
F P
0 g
s
.37434 .34223 m .37552 .31684 L .34802 .32643 L p .522 .293 .509 r
F P
0 g
s
.34802 .32643 m .34663 .35178 L .37434 .34223 L p .522 .293 .509 r
F P
0 g
s
.21334 .30188 m .21579 .2768 L .1891 .2866 L p .509 .275 .495 r
F P
0 g
s
.1891 .2866 m .18646 .31163 L .21334 .30188 L p .509 .275 .495 r
F P
0 g
s
.53761 .47766 m .56621 .4688 L .58113 .4851 L p .649 .759 .929 r
F P
0 g
s
.58113 .4851 m .56621 .4688 L .56589 .44249 L p .971 .686 .432 r
F P
0 g
s
.37794 .43764 m .40572 .42857 L .42215 .44525 L p .652 .756 .926 r
F P
0 g
s
.40572 .42857 m .42215 .44525 L .42134 .47154 L p .962 .688 .469 r
F P
0 g
s
.28838 .42224 m .29024 .3962 L .26316 .4054 L p .522 .293 .509 r
F P
0 g
s
.26316 .4054 m .2611 .43137 L .28838 .42224 L p .522 .293 .509 r
F P
0 g
s
.26316 .4054 m .24523 .38834 L .24742 .36267 L p .952 .687 .499 r
F P
0 g
s
.26316 .4054 m .24523 .38834 L .24742 .36267 L p .952 .687 .499 r
F P
0 g
s
.29024 .3962 m .26316 .4054 L .24523 .38834 L p .654 .754 .923 r
F P
0 g
s
.28838 .42224 m .29024 .3962 L .26316 .4054 L p .522 .293 .509 r
F P
0 g
s
.26316 .4054 m .2611 .43137 L .28838 .42224 L p .522 .293 .509 r
F P
0 g
s
.21827 .39762 m .24523 .38834 L .26316 .4054 L p .654 .754 .923 r
F P
0 g
s
.21827 .39762 m .24523 .38834 L .26316 .4054 L p .654 .754 .923 r
F P
0 g
s
.24523 .38834 m .26316 .4054 L .2611 .43137 L p .952 .687 .499 r
F P
0 g
s
.29024 .3962 m .26316 .4054 L .24523 .38834 L p .654 .754 .923 r
F P
0 g
s
.24523 .38834 m .26316 .4054 L .2611 .43137 L p .952 .687 .499 r
F P
0 g
s
.69268 .27604 m .66357 .28585 L .64943 .26766 L p .66 .747 .915 r
F P
0 g
s
.69402 .30113 m .69268 .27604 L .66357 .28585 L p .537 .315 .524 r
F P
0 g
s
.66357 .28585 m .66466 .31088 L .69402 .30113 L p .537 .315 .524 r
F P
0 g
s
.64943 .26766 m .66357 .28585 L .66466 .31088 L p .976 .68 .386 r
F P
0 g
s
.76927 .42153 m .76735 .39549 L .73784 .40469 L p .547 .329 .535 r
F P
0 g
s
.73784 .40469 m .73952 .43067 L .76927 .42153 L p .547 .329 .535 r
F P
0 g
s
.73784 .40469 m .7244 .38763 L .72284 .36194 L p .976 .678 .372 r
F P
0 g
s
.73784 .40469 m .7244 .38763 L .72284 .36194 L p .976 .678 .372 r
F P
0 g
s
.76735 .39549 m .73784 .40469 L .7244 .38763 L p .654 .754 .923 r
F P
0 g
s
.76927 .42153 m .76735 .39549 L .73784 .40469 L p .547 .329 .535 r
F P
0 g
s
.73784 .40469 m .73952 .43067 L .76927 .42153 L p .547 .329 .535 r
F P
0 g
s
.69499 .39691 m .7244 .38763 L .73784 .40469 L p .654 .754 .923 r
F P
0 g
s
.69499 .39691 m .7244 .38763 L .73784 .40469 L p .654 .754 .923 r
F P
0 g
s
.7244 .38763 m .73784 .40469 L .73952 .43067 L p .976 .678 .372 r
F P
0 g
s
.76735 .39549 m .73784 .40469 L .7244 .38763 L p .654 .754 .923 r
F P
0 g
s
.7244 .38763 m .73784 .40469 L .73952 .43067 L p .976 .678 .372 r
F P
0 g
s
.5788 .36483 m .56385 .34738 L .56354 .32202 L p .972 .685 .422 r
F P
0 g
s
.60749 .35542 m .5788 .36483 L .56385 .34738 L p .656 .751 .92 r
F P
0 g
s
.60815 .38114 m .60749 .35542 L .5788 .36483 L p .537 .315 .524 r
F P
0 g
s
.5788 .36483 m .57922 .39049 L .60815 .38114 L p .537 .315 .524 r
F P
0 g
s
.53525 .35687 m .56385 .34738 L .5788 .36483 L p .656 .751 .92 r
F P
0 g
s
.56385 .34738 m .5788 .36483 L .57922 .39049 L p .972 .685 .422 r
F P
0 g
s
.44702 .34076 m .44763 .31535 L .41975 .32496 L p .526 .299 .513 r
F P
0 g
s
.41975 .32496 m .41892 .35031 L .44702 .34076 L p .526 .299 .513 r
F P
0 g
s
.44763 .31535 m .41975 .32496 L .4033 .30714 L p .658 .749 .917 r
F P
0 g
s
.44702 .34076 m .44763 .31535 L .41975 .32496 L p .526 .299 .513 r
F P
0 g
s
.41975 .32496 m .41892 .35031 L .44702 .34076 L p .526 .299 .513 r
F P
0 g
s
.37552 .31684 m .4033 .30714 L .41975 .32496 L p .658 .749 .917 r
F P
0 g
s
.4033 .30714 m .41975 .32496 L .41892 .35031 L p .964 .688 .461 r
F P
0 g
s
.4033 .30714 m .41975 .32496 L .41892 .35031 L p .964 .688 .461 r
F P
0 g
s
.28778 .27528 m .2607 .2851 L .24274 .2669 L p .66 .747 .915 r
F P
0 g
s
.2859 .30037 m .28778 .27528 L .2607 .2851 L p .514 .281 .5 r
F P
0 g
s
.2607 .2851 m .25863 .31014 L .2859 .30037 L p .514 .281 .5 r
F P
0 g
s
.21579 .2768 m .24274 .2669 L .2607 .2851 L p .66 .747 .915 r
F P
0 g
s
.24274 .2669 m .2607 .2851 L .25863 .31014 L p .954 .688 .492 r
F P
0 g
s
.24274 .2669 m .2607 .2851 L .25863 .31014 L p .954 .688 .492 r
F P
0 g
s
.60983 .47631 m .63882 .46743 L .65307 .48375 L p .649 .759 .929 r
F P
0 g
s
.65307 .48375 m .63882 .46743 L .63792 .44111 L p .974 .684 .41 r
F P
0 g
s
.49396 .44387 m .4782 .42717 L .47857 .40116 L p .966 .687 .452 r
F P
0 g
s
.49396 .44387 m .4782 .42717 L .47857 .40116 L p .966 .687 .452 r
F P
0 g
s
.52223 .43486 m .49396 .44387 L .4782 .42717 L p .652 .756 .926 r
F P
0 g
s
.52222 .46122 m .52223 .43486 L .49396 .44387 L p .537 .315 .524 r
F P
0 g
s
.49396 .44387 m .49372 .47017 L .52222 .46122 L p .537 .315 .524 r
F P
0 g
s
.45003 .43625 m .4782 .42717 L .49396 .44387 L p .652 .756 .926 r
F P
0 g
s
.45003 .43625 m .4782 .42717 L .49396 .44387 L p .652 .756 .926 r
F P
0 g
s
.4782 .42717 m .49396 .44387 L .49372 .47017 L p .966 .687 .452 r
F P
0 g
s
.52223 .43486 m .49396 .44387 L .4782 .42717 L p .652 .756 .926 r
F P
0 g
s
.4782 .42717 m .49396 .44387 L .49372 .47017 L p .966 .687 .452 r
F P
0 g
s
.36231 .39478 m .33485 .40399 L .31759 .38691 L p .654 .754 .923 r
F P
0 g
s
.36103 .42082 m .36231 .39478 L .33485 .40399 L p .526 .299 .513 r
F P
0 g
s
.33485 .40399 m .33336 .42997 L .36103 .42082 L p .526 .299 .513 r
F P
0 g
s
.29024 .3962 m .31759 .38691 L .33485 .40399 L p .654 .754 .923 r
F P
0 g
s
.31759 .38691 m .33485 .40399 L .33336 .42997 L p .957 .688 .485 r
F P
0 g
s
.31759 .38691 m .33485 .40399 L .33336 .42997 L p .957 .688 .485 r
F P
0 g
s
.19984 .38042 m .20239 .35469 L .17574 .36411 L p .514 .281 .5 r
F P
0 g
s
.17574 .36411 m .17299 .38978 L .19984 .38042 L p .514 .281 .5 r
F P
0 g
s
.17574 .36411 m .15697 .34665 L .15985 .32128 L p .946 .686 .511 r
F P
0 g
s
.17574 .36411 m .15697 .34665 L .15985 .32128 L p .946 .686 .511 r
F P
0 g
s
.20239 .35469 m .17574 .36411 L .15697 .34665 L p .656 .751 .92 r
F P
0 g
s
.13044 .35615 m .15697 .34665 L .17574 .36411 L p .656 .751 .92 r
F P
0 g
s
.76698 .29962 m .76508 .27452 L .73557 .28435 L p .541 .319 .528 r
F P
0 g
s
.73557 .28435 m .73723 .30939 L .76698 .29962 L p .541 .319 .528 r
F P
0 g
s
.76508 .27452 m .73557 .28435 L .7221 .26613 L p .66 .747 .915 r
F P
0 g
s
.76698 .29962 m .76508 .27452 L .73557 .28435 L p .541 .319 .528 r
F P
0 g
s
.73557 .28435 m .73723 .30939 L .76698 .29962 L p .541 .319 .528 r
F P
0 g
s
.69268 .27604 m .7221 .26613 L .73557 .28435 L p .66 .747 .915 r
F P
0 g
s
.7221 .26613 m .73557 .28435 L .73723 .30939 L p .976 .675 .358 r
F P
0 g
s
.7221 .26613 m .73557 .28435 L .73723 .30939 L p .976 .675 .358 r
F P
0 g
s
.68108 .3797 m .67985 .35396 L .65076 .36339 L p .541 .319 .528 r
F P
0 g
s
.65076 .36339 m .65176 .38906 L .68108 .3797 L p .541 .319 .528 r
F P
0 g
s
.65076 .36339 m .63648 .34592 L .63561 .32054 L p .975 .682 .398 r
F P
0 g
s
.67985 .35396 m .65076 .36339 L .63648 .34592 L p .656 .751 .92 r
F P
0 g
s
.68108 .3797 m .67985 .35396 L .65076 .36339 L p .541 .319 .528 r
F P
0 g
s
.65076 .36339 m .65176 .38906 L .68108 .3797 L p .541 .319 .528 r
F P
0 g
s
.60749 .35542 m .63648 .34592 L .65076 .36339 L p .656 .751 .92 r
F P
0 g
s
.63648 .34592 m .65076 .36339 L .65176 .38906 L p .975 .682 .398 r
F P
0 g
s
.67985 .35396 m .65076 .36339 L .63648 .34592 L p .656 .751 .92 r
F P
0 g
s
.63648 .34592 m .65076 .36339 L .65176 .38906 L p .975 .682 .398 r
F P
0 g
s
.51983 .33928 m .51986 .31386 L .49159 .32349 L p .53 .304 .517 r
F P
0 g
s
.49159 .32349 m .49133 .34885 L .51983 .33928 L p .53 .304 .517 r
F P
0 g
s
.49159 .32349 m .4758 .30564 L .47619 .28058 L p .969 .687 .442 r
F P
0 g
s
.51986 .31386 m .49159 .32349 L .4758 .30564 L p .658 .749 .917 r
F P
0 g
s
.51983 .33928 m .51986 .31386 L .49159 .32349 L p .53 .304 .517 r
F P
0 g
s
.49159 .32349 m .49133 .34885 L .51983 .33928 L p .53 .304 .517 r
F P
0 g
s
.44763 .31535 m .4758 .30564 L .49159 .32349 L p .658 .749 .917 r
F P
0 g
s
.44763 .31535 m .4758 .30564 L .49159 .32349 L p .658 .749 .917 r
F P
0 g
s
.4758 .30564 m .49159 .32349 L .49133 .34885 L p .969 .687 .442 r
F P
0 g
s
.4758 .30564 m .49159 .32349 L .49133 .34885 L p .969 .687 .442 r
F P
0 g
s
.72512 .4824 m .71154 .46605 L .71008 .43972 L p .976 .68 .386 r
F P
0 g
s
.72512 .4824 m .71154 .46605 L .71008 .43972 L p .976 .68 .386 r
F P
0 g
s
.7546 .47358 m .72512 .4824 L .71154 .46605 L p .649 .759 .929 r
F P
0 g
s
.68216 .47495 m .71154 .46605 L .72512 .4824 L p .649 .759 .929 r
F P
0 g
s
.56589 .44249 m .5508 .42576 L .55059 .39975 L p .971 .686 .432 r
F P
0 g
s
.56589 .44249 m .5508 .42576 L .55059 .39975 L p .971 .686 .432 r
F P
0 g
s
.59455 .43347 m .56589 .44249 L .5508 .42576 L p .652 .756 .926 r
F P
0 g
s
.5951 .45984 m .59455 .43347 L .56589 .44249 L p .541 .319 .528 r
F P
0 g
s
.56589 .44249 m .56621 .4688 L .5951 .45984 L p .541 .319 .528 r
F P
0 g
s
.52223 .43486 m .5508 .42576 L .56589 .44249 L p .652 .756 .926 r
F P
0 g
s
.5508 .42576 m .56589 .44249 L .56621 .4688 L p .971 .686 .432 r
F P
0 g
s
.59455 .43347 m .56589 .44249 L .5508 .42576 L p .652 .756 .926 r
F P
0 g
s
.40665 .40258 m .39006 .38547 L .39111 .35977 L p .962 .688 .469 r
F P
0 g
s
.40665 .40258 m .39006 .38547 L .39111 .35977 L p .962 .688 .469 r
F P
0 g
s
.4345 .39335 m .40665 .40258 L .39006 .38547 L p .654 .754 .923 r
F P
0 g
s
.36231 .39478 m .39006 .38547 L .40665 .40258 L p .654 .754 .923 r
F P
0 g
s
.36231 .39478 m .39006 .38547 L .40665 .40258 L p .654 .754 .923 r
F P
0 g
s
.39006 .38547 m .40665 .40258 L .40572 .42857 L p .962 .688 .469 r
F P
0 g
s
.27247 .37897 m .27446 .35324 L .24742 .36267 L p .518 .287 .504 r
F P
0 g
s
.24742 .36267 m .24523 .38834 L .27247 .37897 L p .518 .287 .504 r
F P
0 g
s
.24742 .36267 m .22931 .34518 L .23163 .3198 L p .952 .687 .499 r
F P
0 g
s
.24742 .36267 m .22931 .34518 L .23163 .3198 L p .952 .687 .499 r
F P
0 g
s
.27446 .35324 m .24742 .36267 L .22931 .34518 L p .656 .751 .92 r
F P
0 g
s
.20239 .35469 m .22931 .34518 L .24742 .36267 L p .656 .751 .92 r
F P
0 g
s
.20239 .35469 m .22931 .34518 L .24742 .36267 L p .656 .751 .92 r
F P
0 g
s
.22931 .34518 m .24742 .36267 L .24523 .38834 L p .952 .687 .499 r
F P
0 g
s
.32165 .48173 m .30424 .46536 L .30597 .43903 L p .954 .688 .492 r
F P
0 g
s
.32165 .48173 m .30424 .46536 L .30597 .43903 L p .954 .688 .492 r
F P
0 g
s
.34908 .4729 m .32165 .48173 L .30424 .46536 L p .649 .759 .929 r
F P
0 g
s
.27692 .47426 m .30424 .46536 L .32165 .48173 L p .649 .759 .929 r
F P
0 g
s
.75412 .37825 m .75232 .35251 L .72284 .36194 L p .544 .324 .532 r
F P
0 g
s
.72284 .36194 m .7244 .38763 L .75412 .37825 L p .544 .324 .532 r
F P
0 g
s
.72284 .36194 m .70923 .34444 L .70778 .31906 L p .976 .678 .372 r
F P
0 g
s
.72284 .36194 m .70923 .34444 L .70778 .31906 L p .976 .678 .372 r
F P
0 g
s
.75232 .35251 m .72284 .36194 L .70923 .34444 L p .656 .751 .92 r
F P
0 g
s
.75412 .37825 m .75232 .35251 L .72284 .36194 L p .544 .324 .532 r
F P
0 g
s
.72284 .36194 m .7244 .38763 L .75412 .37825 L p .544 .324 .532 r
F P
0 g
s
.67985 .35396 m .70923 .34444 L .72284 .36194 L p .656 .751 .92 r
F P
0 g
s
.70923 .34444 m .72284 .36194 L .7244 .38763 L p .976 .678 .372 r
F P
0 g
s
.75232 .35251 m .72284 .36194 L .70923 .34444 L p .656 .751 .92 r
F P
0 g
s
.56354 .32202 m .54843 .30414 L .54824 .27907 L p .972 .685 .422 r
F P
0 g
s
.56354 .32202 m .54843 .30414 L .54824 .27907 L p .972 .685 .422 r
F P
0 g
s
.59221 .31237 m .56354 .32202 L .54843 .30414 L p .658 .749 .917 r
F P
0 g
s
.51986 .31386 m .54843 .30414 L .56354 .32202 L p .658 .749 .917 r
F P
0 g
s
.4321 .27224 m .40425 .28209 L .38762 .26383 L p .66 .747 .915 r
F P
0 g
s
.43136 .29735 m .4321 .27224 L .40425 .28209 L p .522 .293 .509 r
F P
0 g
s
.40425 .28209 m .4033 .30714 L .43136 .29735 L p .522 .293 .509 r
F P
0 g
s
.35988 .27376 m .38762 .26383 L .40425 .28209 L p .66 .747 .915 r
F P
0 g
s
.38762 .26383 m .40425 .28209 L .4033 .30714 L p .964 .688 .461 r
F P
0 g
s
.38762 .26383 m .40425 .28209 L .4033 .30714 L p .964 .688 .461 r
F P
0 g
s
.63792 .44111 m .62351 .42435 L .62273 .39833 L p .974 .684 .41 r
F P
0 g
s
.63792 .44111 m .62351 .42435 L .62273 .39833 L p .974 .684 .41 r
F P
0 g
s
.66698 .43207 m .63792 .44111 L .62351 .42435 L p .652 .756 .926 r
F P
0 g
s
.66811 .45845 m .66698 .43207 L .63792 .44111 L p .544 .324 .532 r
F P
0 g
s
.63792 .44111 m .63882 .46743 L .66811 .45845 L p .544 .324 .532 r
F P
0 g
s
.59455 .43347 m .62351 .42435 L .63792 .44111 L p .652 .756 .926 r
F P
0 g
s
.59455 .43347 m .62351 .42435 L .63792 .44111 L p .652 .756 .926 r
F P
0 g
s
.62351 .42435 m .63792 .44111 L .63882 .46743 L p .974 .684 .41 r
F P
0 g
s
.66698 .43207 m .63792 .44111 L .62351 .42435 L p .652 .756 .926 r
F P
0 g
s
.62351 .42435 m .63792 .44111 L .63882 .46743 L p .974 .684 .41 r
F P
0 g
s
.50667 .41799 m .50681 .39192 L .47857 .40116 L p .534 .309 .521 r
F P
0 g
s
.47857 .40116 m .4782 .42717 L .50667 .41799 L p .534 .309 .521 r
F P
0 g
s
.4345 .39335 m .46264 .38403 L .47857 .40116 L p .654 .754 .923 r
F P
0 g
s
.4345 .39335 m .46264 .38403 L .47857 .40116 L p .654 .754 .923 r
F P
0 g
s
.46264 .38403 m .47857 .40116 L .4782 .42717 L p .966 .687 .452 r
F P
0 g
s
.47857 .40116 m .46264 .38403 L .46312 .35833 L p .966 .687 .452 r
F P
0 g
s
.34663 .35178 m .31921 .36122 L .30177 .34371 L p .656 .751 .92 r
F P
0 g
s
.34522 .37752 m .34663 .35178 L .31921 .36122 L p .522 .293 .509 r
F P
0 g
s
.31921 .36122 m .31759 .38691 L .34522 .37752 L p .522 .293 .509 r
F P
0 g
s
.27446 .35324 m .30177 .34371 L .31921 .36122 L p .656 .751 .92 r
F P
0 g
s
.30177 .34371 m .31921 .36122 L .31759 .38691 L p .957 .688 .485 r
F P
0 g
s
.30177 .34371 m .31921 .36122 L .31759 .38691 L p .957 .688 .485 r
F P
0 g
s
.18378 .33706 m .18646 .31163 L .15985 .32128 L p .509 .275 .495 r
F P
0 g
s
.15985 .32128 m .15697 .34665 L .18378 .33706 L p .509 .275 .495 r
F P
0 g
s
.11441 .31312 m .1409 .30339 L .15985 .32128 L p .658 .749 .917 r
F P
0 g
s
.15985 .32128 m .1409 .30339 L .14391 .27831 L p .946 .686 .511 r
F P
0 g
s
.39352 .48037 m .37678 .46399 L .37794 .43764 L p .959 .688 .477 r
F P
0 g
s
.39352 .48037 m .37678 .46399 L .37794 .43764 L p .959 .688 .477 r
F P
0 g
s
.42134 .47154 m .39352 .48037 L .37678 .46399 L p .649 .759 .929 r
F P
0 g
s
.34908 .4729 m .37678 .46399 L .39352 .48037 L p .649 .759 .929 r
F P
0 g
s
.2341 .44042 m .21585 .42365 L .21827 .39762 L p .949 .687 .505 r
F P
0 g
s
.2611 .43137 m .2341 .44042 L .21585 .42365 L p .652 .756 .926 r
F P
0 g
s
.4321 .27224 m .46023 .2623 L .47619 .28058 L p .66 .747 .915 r
F P
0 g
s
.46023 .2623 m .47619 .28058 L .4758 .30564 L p .969 .687 .442 r
F P
0 g
s
.66577 .33631 m .66466 .31088 L .63561 .32054 L p .537 .315 .524 r
F P
0 g
s
.63561 .32054 m .63648 .34592 L .66577 .33631 L p .537 .315 .524 r
F P
0 g
s
.63561 .32054 m .62116 .30263 L .62041 .27756 L p .975 .682 .398 r
F P
0 g
s
.66466 .31088 m .63561 .32054 L .62116 .30263 L p .658 .749 .917 r
F P
0 g
s
.66577 .33631 m .66466 .31088 L .63561 .32054 L p .537 .315 .524 r
F P
0 g
s
.63561 .32054 m .63648 .34592 L .66577 .33631 L p .537 .315 .524 r
F P
0 g
s
.59221 .31237 m .62116 .30263 L .63561 .32054 L p .658 .749 .917 r
F P
0 g
s
.62116 .30263 m .63561 .32054 L .63648 .34592 L p .975 .682 .398 r
F P
0 g
s
.74123 .45707 m .73952 .43067 L .71008 .43972 L p .547 .329 .535 r
F P
0 g
s
.71008 .43972 m .71154 .46605 L .74123 .45707 L p .547 .329 .535 r
F P
0 g
s
.71008 .43972 m .69633 .42294 L .69499 .39691 L p .976 .68 .386 r
F P
0 g
s
.71008 .43972 m .69633 .42294 L .69499 .39691 L p .976 .68 .386 r
F P
0 g
s
.73952 .43067 m .71008 .43972 L .69633 .42294 L p .652 .756 .926 r
F P
0 g
s
.66698 .43207 m .69633 .42294 L .71008 .43972 L p .652 .756 .926 r
F P
0 g
s
.57966 .41657 m .57922 .39049 L .55059 .39975 L p .537 .315 .524 r
F P
0 g
s
.55059 .39975 m .5508 .42576 L .57966 .41657 L p .537 .315 .524 r
F P
0 g
s
.57922 .39049 m .55059 .39975 L .53534 .38259 L p .654 .754 .923 r
F P
0 g
s
.57966 .41657 m .57922 .39049 L .55059 .39975 L p .537 .315 .524 r
F P
0 g
s
.55059 .39975 m .5508 .42576 L .57966 .41657 L p .537 .315 .524 r
F P
0 g
s
.50681 .39192 m .53534 .38259 L .55059 .39975 L p .654 .754 .923 r
F P
0 g
s
.53534 .38259 m .55059 .39975 L .5508 .42576 L p .971 .686 .432 r
F P
0 g
s
.53534 .38259 m .55059 .39975 L .5508 .42576 L p .971 .686 .432 r
F P
0 g
s
.41809 .37607 m .41892 .35031 L .39111 .35977 L p .526 .299 .513 r
F P
0 g
s
.39111 .35977 m .39006 .38547 L .41809 .37607 L p .526 .299 .513 r
F P
0 g
s
.39111 .35977 m .37434 .34223 L .37552 .31684 L p .962 .688 .469 r
F P
0 g
s
.39111 .35977 m .37434 .34223 L .37552 .31684 L p .962 .688 .469 r
F P
0 g
s
.41892 .35031 m .39111 .35977 L .37434 .34223 L p .656 .751 .92 r
F P
0 g
s
.34663 .35178 m .37434 .34223 L .39111 .35977 L p .656 .751 .92 r
F P
0 g
s
.25651 .33557 m .25863 .31014 L .23163 .3198 L p .514 .281 .5 r
F P
0 g
s
.23163 .3198 m .22931 .34518 L .25651 .33557 L p .514 .281 .5 r
F P
0 g
s
.23163 .3198 m .21334 .30188 L .21579 .2768 L p .952 .687 .499 r
F P
0 g
s
.23163 .3198 m .21334 .30188 L .21579 .2768 L p .952 .687 .499 r
F P
0 g
s
.25863 .31014 m .23163 .3198 L .21334 .30188 L p .658 .749 .917 r
F P
0 g
s
.25651 .33557 m .25863 .31014 L .23163 .3198 L p .514 .281 .5 r
F P
0 g
s
.23163 .3198 m .22931 .34518 L .25651 .33557 L p .514 .281 .5 r
F P
0 g
s
.18646 .31163 m .21334 .30188 L .23163 .3198 L p .658 .749 .917 r
F P
0 g
s
.18646 .31163 m .21334 .30188 L .23163 .3198 L p .658 .749 .917 r
F P
0 g
s
.21334 .30188 m .23163 .3198 L .22931 .34518 L p .952 .687 .499 r
F P
0 g
s
.25863 .31014 m .23163 .3198 L .21334 .30188 L p .658 .749 .917 r
F P
0 g
s
.21334 .30188 m .23163 .3198 L .22931 .34518 L p .952 .687 .499 r
F P
0 g
s
.46551 .47902 m .44944 .46261 L .45003 .43625 L p .964 .688 .461 r
F P
0 g
s
.49372 .47017 m .46551 .47902 L .44944 .46261 L p .649 .759 .929 r
F P
0 g
s
.33184 .45637 m .33336 .42997 L .30597 .43903 L p .526 .299 .513 r
F P
0 g
s
.30597 .43903 m .30424 .46536 L .33184 .45637 L p .526 .299 .513 r
F P
0 g
s
.30597 .43903 m .28838 .42224 L .29024 .3962 L p .954 .688 .492 r
F P
0 g
s
.30597 .43903 m .28838 .42224 L .29024 .3962 L p .954 .688 .492 r
F P
0 g
s
.33336 .42997 m .30597 .43903 L .28838 .42224 L p .652 .756 .926 r
F P
0 g
s
.33184 .45637 m .33336 .42997 L .30597 .43903 L p .526 .299 .513 r
F P
0 g
s
.30597 .43903 m .30424 .46536 L .33184 .45637 L p .526 .299 .513 r
F P
0 g
s
.2611 .43137 m .28838 .42224 L .30597 .43903 L p .652 .756 .926 r
F P
0 g
s
.2611 .43137 m .28838 .42224 L .30597 .43903 L p .652 .756 .926 r
F P
0 g
s
.28838 .42224 m .30597 .43903 L .30424 .46536 L p .954 .688 .492 r
F P
0 g
s
.33336 .42997 m .30597 .43903 L .28838 .42224 L p .652 .756 .926 r
F P
0 g
s
.28838 .42224 m .30597 .43903 L .30424 .46536 L p .954 .688 .492 r
F P
0 g
s
.73892 .33483 m .73723 .30939 L .70778 .31906 L p .541 .319 .528 r
F P
0 g
s
.70778 .31906 m .70923 .34444 L .73892 .33483 L p .541 .319 .528 r
F P
0 g
s
.70778 .31906 m .69402 .30113 L .69268 .27604 L p .976 .678 .372 r
F P
0 g
s
.73723 .30939 m .70778 .31906 L .69402 .30113 L p .658 .749 .917 r
F P
0 g
s
.66466 .31088 m .69402 .30113 L .70778 .31906 L p .658 .749 .917 r
F P
0 g
s
.69402 .30113 m .70778 .31906 L .70923 .34444 L p .976 .678 .372 r
F P
0 g
s
.57729 .29431 m .57687 .26919 L .54824 .27907 L p .53 .304 .517 r
F P
0 g
s
.54824 .27907 m .54843 .30414 L .57729 .29431 L p .53 .304 .517 r
F P
0 g
s
.73952 .43067 m .76927 .42153 L .78234 .43834 L p .652 .756 .926 r
F P
0 g
s
.78234 .43834 m .76927 .42153 L .76735 .39549 L p .976 .675 .358 r
F P
0 g
s
.65277 .41514 m .65176 .38906 L .62273 .39833 L p .541 .319 .528 r
F P
0 g
s
.62273 .39833 m .62351 .42435 L .65277 .41514 L p .541 .319 .528 r
F P
0 g
s
.62273 .39833 m .60815 .38114 L .60749 .35542 L p .974 .684 .41 r
F P
0 g
s
.65176 .38906 m .62273 .39833 L .60815 .38114 L p .654 .754 .923 r
F P
0 g
s
.57922 .39049 m .60815 .38114 L .62273 .39833 L p .654 .754 .923 r
F P
0 g
s
.60815 .38114 m .62273 .39833 L .62351 .42435 L p .974 .684 .41 r
F P
0 g
s
.46312 .35833 m .44702 .34076 L .44763 .31535 L p .966 .687 .452 r
F P
0 g
s
.46312 .35833 m .44702 .34076 L .44763 .31535 L p .966 .687 .452 r
F P
0 g
s
.49133 .34885 m .46312 .35833 L .44702 .34076 L p .656 .751 .92 r
F P
0 g
s
.41892 .35031 m .44702 .34076 L .46312 .35833 L p .656 .751 .92 r
F P
0 g
s
.41892 .35031 m .44702 .34076 L .46312 .35833 L p .656 .751 .92 r
F P
0 g
s
.44702 .34076 m .46312 .35833 L .46264 .38403 L p .966 .687 .452 r
F P
0 g
s
.40478 .45498 m .40572 .42857 L .37794 .43764 L p .53 .304 .517 r
F P
0 g
s
.37794 .43764 m .37678 .46399 L .40478 .45498 L p .53 .304 .517 r
F P
0 g
s
.37794 .43764 m .36103 .42082 L .36231 .39478 L p .959 .688 .477 r
F P
0 g
s
.40572 .42857 m .37794 .43764 L .36103 .42082 L p .652 .756 .926 r
F P
0 g
s
.40478 .45498 m .40572 .42857 L .37794 .43764 L p .53 .304 .517 r
F P
0 g
s
.37794 .43764 m .37678 .46399 L .40478 .45498 L p .53 .304 .517 r
F P
0 g
s
.33336 .42997 m .36103 .42082 L .37794 .43764 L p .652 .756 .926 r
F P
0 g
s
.36103 .42082 m .37794 .43764 L .37678 .46399 L p .959 .688 .477 r
F P
0 g
s
.40572 .42857 m .37794 .43764 L .36103 .42082 L p .652 .756 .926 r
F P
0 g
s
.36103 .42082 m .37794 .43764 L .37678 .46399 L p .959 .688 .477 r
F P
0 g
s
.24301 .41443 m .24523 .38834 L .21827 .39762 L p .518 .287 .504 r
F P
0 g
s
.21827 .39762 m .21585 .42365 L .24301 .41443 L p .518 .287 .504 r
F P
0 g
s
.21827 .39762 m .19984 .38042 L .20239 .35469 L p .949 .687 .505 r
F P
0 g
s
.21827 .39762 m .19984 .38042 L .20239 .35469 L p .949 .687 .505 r
F P
0 g
s
.24523 .38834 m .21827 .39762 L .19984 .38042 L p .654 .754 .923 r
F P
0 g
s
.17299 .38978 m .19984 .38042 L .21827 .39762 L p .654 .754 .923 r
F P
0 g
s
.73723 .30939 m .76698 .29962 L .78008 .31758 L p .658 .749 .917 r
F P
0 g
s
.78008 .31758 m .76698 .29962 L .76508 .27452 L p .976 .672 .343 r
F P
0 g
s
.57687 .26919 m .60579 .25921 L .62041 .27756 L p .66 .747 .915 r
F P
0 g
s
.60579 .25921 m .62041 .27756 L .62116 .30263 L p .975 .682 .398 r
F P
0 g
s
.72599 .41372 m .7244 .38763 L .69499 .39691 L p .544 .324 .532 r
F P
0 g
s
.69499 .39691 m .69633 .42294 L .72599 .41372 L p .544 .324 .532 r
F P
0 g
s
.69499 .39691 m .68108 .3797 L .67985 .35396 L p .976 .68 .386 r
F P
0 g
s
.7244 .38763 m .69499 .39691 L .68108 .3797 L p .654 .754 .923 r
F P
0 g
s
.72599 .41372 m .7244 .38763 L .69499 .39691 L p .544 .324 .532 r
F P
0 g
s
.69499 .39691 m .69633 .42294 L .72599 .41372 L p .544 .324 .532 r
F P
0 g
s
.65176 .38906 m .68108 .3797 L .69499 .39691 L p .654 .754 .923 r
F P
0 g
s
.65176 .38906 m .68108 .3797 L .69499 .39691 L p .654 .754 .923 r
F P
0 g
s
.68108 .3797 m .69499 .39691 L .69633 .42294 L p .976 .68 .386 r
F P
0 g
s
.68108 .3797 m .69499 .39691 L .69633 .42294 L p .976 .68 .386 r
F P
0 g
s
.53525 .35687 m .51983 .33928 L .51986 .31386 L p .971 .686 .432 r
F P
0 g
s
.56385 .34738 m .53525 .35687 L .51983 .33928 L p .656 .751 .92 r
F P
0 g
s
.56416 .37316 m .56385 .34738 L .53525 .35687 L p .534 .309 .521 r
F P
0 g
s
.53525 .35687 m .53534 .38259 L .56416 .37316 L p .534 .309 .521 r
F P
0 g
s
.49133 .34885 m .51983 .33928 L .53525 .35687 L p .656 .751 .92 r
F P
0 g
s
.49133 .34885 m .51983 .33928 L .53525 .35687 L p .656 .751 .92 r
F P
0 g
s
.51983 .33928 m .53525 .35687 L .53534 .38259 L p .971 .686 .432 r
F P
0 g
s
.51983 .33928 m .53525 .35687 L .53534 .38259 L p .971 .686 .432 r
F P
0 g
s
.40233 .33259 m .4033 .30714 L .37552 .31684 L p .522 .293 .509 r
F P
0 g
s
.37552 .31684 m .37434 .34223 L .40233 .33259 L p .522 .293 .509 r
F P
0 g
s
.37552 .31684 m .35857 .29886 L .35988 .27376 L p .962 .688 .469 r
F P
0 g
s
.4033 .30714 m .37552 .31684 L .35857 .29886 L p .658 .749 .917 r
F P
0 g
s
.2405 .29203 m .24274 .2669 L .21579 .2768 L p .509 .275 .495 r
F P
0 g
s
.21579 .2768 m .21334 .30188 L .2405 .29203 L p .509 .275 .495 r
F P
0 g
s
.24274 .2669 m .21579 .2768 L .19732 .25844 L p .66 .747 .915 r
F P
0 g
s
.2405 .29203 m .24274 .2669 L .21579 .2768 L p .509 .275 .495 r
F P
0 g
s
.21579 .2768 m .21334 .30188 L .2405 .29203 L p .509 .275 .495 r
F P
0 g
s
.19732 .25844 m .21579 .2768 L .21334 .30188 L p .952 .687 .499 r
F P
0 g
s
.60983 .47631 m .5951 .45984 L .59455 .43347 L p .972 .685 .422 r
F P
0 g
s
.63882 .46743 m .60983 .47631 L .5951 .45984 L p .649 .759 .929 r
F P
0 g
s
.47783 .45358 m .4782 .42717 L .45003 .43625 L p .534 .309 .521 r
F P
0 g
s
.45003 .43625 m .44944 .46261 L .47783 .45358 L p .534 .309 .521 r
F P
0 g
s
.45003 .43625 m .43379 .41941 L .4345 .39335 L p .964 .688 .461 r
F P
0 g
s
.4782 .42717 m .45003 .43625 L .43379 .41941 L p .652 .756 .926 r
F P
0 g
s
.47783 .45358 m .4782 .42717 L .45003 .43625 L p .534 .309 .521 r
F P
0 g
s
.45003 .43625 m .44944 .46261 L .47783 .45358 L p .534 .309 .521 r
F P
0 g
s
.43379 .41941 m .45003 .43625 L .44944 .46261 L p .964 .688 .461 r
F P
0 g
s
.4782 .42717 m .45003 .43625 L .43379 .41941 L p .652 .756 .926 r
F P
0 g
s
.31594 .41301 m .31759 .38691 L .29024 .3962 L p .522 .293 .509 r
F P
0 g
s
.29024 .3962 m .28838 .42224 L .31594 .41301 L p .522 .293 .509 r
F P
0 g
s
.29024 .3962 m .27247 .37897 L .27446 .35324 L p .954 .688 .492 r
F P
0 g
s
.29024 .3962 m .27247 .37897 L .27446 .35324 L p .954 .688 .492 r
F P
0 g
s
.31759 .38691 m .29024 .3962 L .27247 .37897 L p .654 .754 .923 r
F P
0 g
s
.31594 .41301 m .31759 .38691 L .29024 .3962 L p .522 .293 .509 r
F P
0 g
s
.29024 .3962 m .28838 .42224 L .31594 .41301 L p .522 .293 .509 r
F P
0 g
s
.24523 .38834 m .27247 .37897 L .29024 .3962 L p .654 .754 .923 r
F P
0 g
s
.24523 .38834 m .27247 .37897 L .29024 .3962 L p .654 .754 .923 r
F P
0 g
s
.27247 .37897 m .29024 .3962 L .28838 .42224 L p .954 .688 .492 r
F P
0 g
s
.31759 .38691 m .29024 .3962 L .27247 .37897 L p .654 .754 .923 r
F P
0 g
s
.27247 .37897 m .29024 .3962 L .28838 .42224 L p .954 .688 .492 r
F P
0 g
s
.72367 .29127 m .7221 .26613 L .69268 .27604 L p .537 .315 .524 r
F P
0 g
s
.69268 .27604 m .69402 .30113 L .72367 .29127 L p .537 .315 .524 r
F P
0 g
s
.64943 .26766 m .67875 .25767 L .69268 .27604 L p .66 .747 .915 r
F P
0 g
s
.67875 .25767 m .69268 .27604 L .69402 .30113 L p .976 .678 .372 r
F P
0 g
s
.7244 .38763 m .75412 .37825 L .76735 .39549 L p .654 .754 .923 r
F P
0 g
s
.7244 .38763 m .75412 .37825 L .76735 .39549 L p .654 .754 .923 r
F P
0 g
s
.75412 .37825 m .76735 .39549 L .76927 .42153 L p .976 .675 .358 r
F P
0 g
s
.76735 .39549 m .75412 .37825 L .75232 .35251 L p .976 .675 .358 r
F P
0 g
s
.63737 .3717 m .63648 .34592 L .60749 .35542 L p .537 .315 .524 r
F P
0 g
s
.60749 .35542 m .60815 .38114 L .63737 .3717 L p .537 .315 .524 r
F P
0 g
s
.63648 .34592 m .60749 .35542 L .59274 .3378 L p .656 .751 .92 r
F P
0 g
s
.63737 .3717 m .63648 .34592 L .60749 .35542 L p .537 .315 .524 r
F P
0 g
s
.60749 .35542 m .60815 .38114 L .63737 .3717 L p .537 .315 .524 r
F P
0 g
s
.56385 .34738 m .59274 .3378 L .60749 .35542 L p .656 .751 .92 r
F P
0 g
s
.59274 .3378 m .60749 .35542 L .60815 .38114 L p .974 .684 .41 r
F P
0 g
s
.59274 .3378 m .60749 .35542 L .60815 .38114 L p .974 .684 .41 r
F P
0 g
s
.47542 .3311 m .4758 .30564 L .44763 .31535 L p .526 .299 .513 r
F P
0 g
s
.44763 .31535 m .44702 .34076 L .47542 .3311 L p .526 .299 .513 r
F P
0 g
s
.44763 .31535 m .43136 .29735 L .4321 .27224 L p .966 .687 .452 r
F P
0 g
s
.4758 .30564 m .44763 .31535 L .43136 .29735 L p .658 .749 .917 r
F P
0 g
s
.47542 .3311 m .4758 .30564 L .44763 .31535 L p .526 .299 .513 r
F P
0 g
s
.44763 .31535 m .44702 .34076 L .47542 .3311 L p .526 .299 .513 r
F P
0 g
s
.4033 .30714 m .43136 .29735 L .44763 .31535 L p .658 .749 .917 r
F P
0 g
s
.43136 .29735 m .44763 .31535 L .44702 .34076 L p .966 .687 .452 r
F P
0 g
s
.4758 .30564 m .44763 .31535 L .43136 .29735 L p .658 .749 .917 r
F P
0 g
s
.43136 .29735 m .44763 .31535 L .44702 .34076 L p .966 .687 .452 r
F P
0 g
s
.24274 .2669 m .26998 .2569 L .28778 .27528 L p .66 .747 .915 r
F P
0 g
s
.26998 .2569 m .28778 .27528 L .2859 .30037 L p .957 .688 .485 r
F P
0 g
s
.52223 .43486 m .50667 .41799 L .50681 .39192 L p .969 .687 .442 r
F P
0 g
s
.52223 .43486 m .50667 .41799 L .50681 .39192 L p .969 .687 .442 r
F P
0 g
s
.5508 .42576 m .52223 .43486 L .50667 .41799 L p .652 .756 .926 r
F P
0 g
s
.55101 .45219 m .5508 .42576 L .52223 .43486 L p .537 .315 .524 r
F P
0 g
s
.52223 .43486 m .52222 .46122 L .55101 .45219 L p .537 .315 .524 r
F P
0 g
s
.4782 .42717 m .50667 .41799 L .52223 .43486 L p .652 .756 .926 r
F P
0 g
s
.4782 .42717 m .50667 .41799 L .52223 .43486 L p .652 .756 .926 r
F P
0 g
s
.50667 .41799 m .52223 .43486 L .52222 .46122 L p .969 .687 .442 r
F P
0 g
s
.5508 .42576 m .52223 .43486 L .50667 .41799 L p .652 .756 .926 r
F P
0 g
s
.50667 .41799 m .52223 .43486 L .52222 .46122 L p .969 .687 .442 r
F P
0 g
s
.38898 .41158 m .39006 .38547 L .36231 .39478 L p .526 .299 .513 r
F P
0 g
s
.36231 .39478 m .36103 .42082 L .38898 .41158 L p .526 .299 .513 r
F P
0 g
s
.39006 .38547 m .36231 .39478 L .34522 .37752 L p .654 .754 .923 r
F P
0 g
s
.38898 .41158 m .39006 .38547 L .36231 .39478 L p .526 .299 .513 r
F P
0 g
s
.36231 .39478 m .36103 .42082 L .38898 .41158 L p .526 .299 .513 r
F P
0 g
s
.31759 .38691 m .34522 .37752 L .36231 .39478 L p .654 .754 .923 r
F P
0 g
s
.34522 .37752 m .36231 .39478 L .36103 .42082 L p .959 .688 .477 r
F P
0 g
s
.34522 .37752 m .36231 .39478 L .36103 .42082 L p .959 .688 .477 r
F P
0 g
s
.22696 .37097 m .22931 .34518 L .20239 .35469 L p .514 .281 .5 r
F P
0 g
s
.20239 .35469 m .19984 .38042 L .22696 .37097 L p .514 .281 .5 r
F P
0 g
s
.20239 .35469 m .18378 .33706 L .18646 .31163 L p .949 .687 .505 r
F P
0 g
s
.20239 .35469 m .18378 .33706 L .18646 .31163 L p .949 .687 .505 r
F P
0 g
s
.22931 .34518 m .20239 .35469 L .18378 .33706 L p .656 .751 .92 r
F P
0 g
s
.15697 .34665 m .18378 .33706 L .20239 .35469 L p .656 .751 .92 r
F P
0 g
s
.7221 .26613 m .75182 .25612 L .76508 .27452 L p .66 .747 .915 r
F P
0 g
s
.75182 .25612 m .76508 .27452 L .76698 .29962 L p .976 .672 .343 r
F P
0 g
s
.27692 .47426 m .25901 .45776 L .2611 .43137 L p .952 .687 .499 r
F P
0 g
s
.30424 .46536 m .27692 .47426 L .25901 .45776 L p .649 .759 .929 r
F P
0 g
s
.67985 .35396 m .66577 .33631 L .66466 .31088 L p .976 .68 .386 r
F P
0 g
s
.67985 .35396 m .66577 .33631 L .66466 .31088 L p .976 .68 .386 r
F P
0 g
s
.70923 .34444 m .67985 .35396 L .66577 .33631 L p .656 .751 .92 r
F P
0 g
s
.63648 .34592 m .66577 .33631 L .67985 .35396 L p .656 .751 .92 r
F P
0 g
s
.63648 .34592 m .66577 .33631 L .67985 .35396 L p .656 .751 .92 r
F P
0 g
s
.66577 .33631 m .67985 .35396 L .68108 .3797 L p .976 .68 .386 r
F P
0 g
s
.54843 .30414 m .51986 .31386 L .50427 .29583 L p .658 .749 .917 r
F P
0 g
s
.54862 .32961 m .54843 .30414 L .51986 .31386 L p .53 .304 .517 r
F P
0 g
s
.51986 .31386 m .51983 .33928 L .54862 .32961 L p .53 .304 .517 r
F P
0 g
s
.4758 .30564 m .50427 .29583 L .51986 .31386 L p .658 .749 .917 r
F P
0 g
s
.50427 .29583 m .51986 .31386 L .51983 .33928 L p .971 .686 .432 r
F P
0 g
s
.50427 .29583 m .51986 .31386 L .51983 .33928 L p .971 .686 .432 r
F P
0 g
s
.38653 .28898 m .38762 .26383 L .35988 .27376 L p .518 .287 .504 r
F P
0 g
s
.35988 .27376 m .35857 .29886 L .38653 .28898 L p .518 .287 .504 r
F P
0 g
s
.38762 .26383 m .35988 .27376 L .34276 .25535 L p .66 .747 .915 r
F P
0 g
s
.38653 .28898 m .38762 .26383 L .35988 .27376 L p .518 .287 .504 r
F P
0 g
s
.35988 .27376 m .35857 .29886 L .38653 .28898 L p .518 .287 .504 r
F P
0 g
s
.34276 .25535 m .35988 .27376 L .35857 .29886 L p .962 .688 .469 r
F P
0 g
s
.46214 .41015 m .46264 .38403 L .4345 .39335 L p .53 .304 .517 r
F P
0 g
s
.4345 .39335 m .43379 .41941 L .46214 .41015 L p .53 .304 .517 r
F P
0 g
s
.4345 .39335 m .41809 .37607 L .41892 .35031 L p .964 .688 .461 r
F P
0 g
s
.4345 .39335 m .41809 .37607 L .41892 .35031 L p .964 .688 .461 r
F P
0 g
s
.46264 .38403 m .4345 .39335 L .41809 .37607 L p .654 .754 .923 r
F P
0 g
s
.46214 .41015 m .46264 .38403 L .4345 .39335 L p .53 .304 .517 r
F P
0 g
s
.4345 .39335 m .43379 .41941 L .46214 .41015 L p .53 .304 .517 r
F P
0 g
s
.39006 .38547 m .41809 .37607 L .4345 .39335 L p .654 .754 .923 r
F P
0 g
s
.41809 .37607 m .4345 .39335 L .43379 .41941 L p .964 .688 .461 r
F P
0 g
s
.46264 .38403 m .4345 .39335 L .41809 .37607 L p .654 .754 .923 r
F P
0 g
s
.29999 .3695 m .30177 .34371 L .27446 .35324 L p .518 .287 .504 r
F P
0 g
s
.27446 .35324 m .27247 .37897 L .29999 .3695 L p .518 .287 .504 r
F P
0 g
s
.22931 .34518 m .25651 .33557 L .27446 .35324 L p .656 .751 .92 r
F P
0 g
s
.27446 .35324 m .25651 .33557 L .25863 .31014 L p .954 .688 .492 r
F P
0 g
s
.71154 .46605 m .74123 .45707 L .7546 .47358 L p .649 .759 .929 r
F P
0 g
s
.7546 .47358 m .74123 .45707 L .73952 .43067 L p .976 .678 .372 r
F P
0 g
s
.6243 .45079 m .62351 .42435 L .59455 .43347 L p .541 .319 .528 r
F P
0 g
s
.59455 .43347 m .5951 .45984 L .6243 .45079 L p .541 .319 .528 r
F P
0 g
s
.59455 .43347 m .57966 .41657 L .57922 .39049 L p .972 .685 .422 r
F P
0 g
s
.59455 .43347 m .57966 .41657 L .57922 .39049 L p .972 .685 .422 r
F P
0 g
s
.62351 .42435 m .59455 .43347 L .57966 .41657 L p .652 .756 .926 r
F P
0 g
s
.5508 .42576 m .57966 .41657 L .59455 .43347 L p .652 .756 .926 r
F P
0 g
s
.5508 .42576 m .57966 .41657 L .59455 .43347 L p .652 .756 .926 r
F P
0 g
s
.57966 .41657 m .59455 .43347 L .5951 .45984 L p .972 .685 .422 r
F P
0 g
s
.34908 .4729 m .33184 .45637 L .33336 .42997 L p .957 .688 .485 r
F P
0 g
s
.34908 .4729 m .33184 .45637 L .33336 .42997 L p .957 .688 .485 r
F P
0 g
s
.37678 .46399 m .34908 .4729 L .33184 .45637 L p .649 .759 .929 r
F P
0 g
s
.30424 .46536 m .33184 .45637 L .34908 .4729 L p .649 .759 .929 r
F P
0 g
s
.70923 .34444 m .73892 .33483 L .75232 .35251 L p .656 .751 .92 r
F P
0 g
s
.70923 .34444 m .73892 .33483 L .75232 .35251 L p .656 .751 .92 r
F P
0 g
s
.73892 .33483 m .75232 .35251 L .75412 .37825 L p .976 .675 .358 r
F P
0 g
s
.75232 .35251 m .73892 .33483 L .73723 .30939 L p .976 .675 .358 r
F P
0 g
s
.59221 .31237 m .57729 .29431 L .57687 .26919 L p .974 .684 .41 r
F P
0 g
s
.59221 .31237 m .57729 .29431 L .57687 .26919 L p .974 .684 .41 r
F P
0 g
s
.62116 .30263 m .59221 .31237 L .57729 .29431 L p .658 .749 .917 r
F P
0 g
s
.62193 .32811 m .62116 .30263 L .59221 .31237 L p .534 .309 .521 r
F P
0 g
s
.59221 .31237 m .59274 .3378 L .62193 .32811 L p .534 .309 .521 r
F P
0 g
s
.54843 .30414 m .57729 .29431 L .59221 .31237 L p .658 .749 .917 r
F P
0 g
s
.57729 .29431 m .59221 .31237 L .59274 .3378 L p .974 .684 .41 r
F P
0 g
s
.62116 .30263 m .59221 .31237 L .57729 .29431 L p .658 .749 .917 r
F P
0 g
s
.45972 .28745 m .46023 .2623 L .4321 .27224 L p .522 .293 .509 r
F P
0 g
s
.4321 .27224 m .43136 .29735 L .45972 .28745 L p .522 .293 .509 r
F P
0 g
s
.46023 .2623 m .4321 .27224 L .41565 .2538 L p .66 .747 .915 r
F P
0 g
s
.45972 .28745 m .46023 .2623 L .4321 .27224 L p .522 .293 .509 r
F P
0 g
s
.4321 .27224 m .43136 .29735 L .45972 .28745 L p .522 .293 .509 r
F P
0 g
s
.38762 .26383 m .41565 .2538 L .4321 .27224 L p .66 .747 .915 r
F P
0 g
s
.41565 .2538 m .4321 .27224 L .43136 .29735 L p .966 .687 .452 r
F P
0 g
s
.41565 .2538 m .4321 .27224 L .43136 .29735 L p .966 .687 .452 r
F P
0 g
s
.66698 .43207 m .65277 .41514 L .65176 .38906 L p .975 .682 .398 r
F P
0 g
s
.66698 .43207 m .65277 .41514 L .65176 .38906 L p .975 .682 .398 r
F P
0 g
s
.69633 .42294 m .66698 .43207 L .65277 .41514 L p .652 .756 .926 r
F P
0 g
s
.6977 .44939 m .69633 .42294 L .66698 .43207 L p .544 .324 .532 r
F P
0 g
s
.66698 .43207 m .66811 .45845 L .6977 .44939 L p .544 .324 .532 r
F P
0 g
s
.62351 .42435 m .65277 .41514 L .66698 .43207 L p .652 .756 .926 r
F P
0 g
s
.62351 .42435 m .65277 .41514 L .66698 .43207 L p .652 .756 .926 r
F P
0 g
s
.65277 .41514 m .66698 .43207 L .66811 .45845 L p .975 .682 .398 r
F P
0 g
s
.69633 .42294 m .66698 .43207 L .65277 .41514 L p .652 .756 .926 r
F P
0 g
s
.65277 .41514 m .66698 .43207 L .66811 .45845 L p .975 .682 .398 r
F P
0 g
s
.53542 .40871 m .53534 .38259 L .50681 .39192 L p .534 .309 .521 r
F P
0 g
s
.50681 .39192 m .50667 .41799 L .53542 .40871 L p .534 .309 .521 r
F P
0 g
s
.50681 .39192 m .49107 .37461 L .49133 .34885 L p .969 .687 .442 r
F P
0 g
s
.53534 .38259 m .50681 .39192 L .49107 .37461 L p .654 .754 .923 r
F P
0 g
s
.53542 .40871 m .53534 .38259 L .50681 .39192 L p .534 .309 .521 r
F P
0 g
s
.50681 .39192 m .50667 .41799 L .53542 .40871 L p .534 .309 .521 r
F P
0 g
s
.49107 .37461 m .50681 .39192 L .50667 .41799 L p .969 .687 .442 r
F P
0 g
s
.53534 .38259 m .50681 .39192 L .49107 .37461 L p .654 .754 .923 r
F P
0 g
s
.37434 .34223 m .34663 .35178 L .32936 .33408 L p .656 .751 .92 r
F P
0 g
s
.37314 .36804 m .37434 .34223 L .34663 .35178 L p .522 .293 .509 r
F P
0 g
s
.34663 .35178 m .34522 .37752 L .37314 .36804 L p .522 .293 .509 r
F P
0 g
s
.30177 .34371 m .32936 .33408 L .34663 .35178 L p .656 .751 .92 r
F P
0 g
s
.32936 .33408 m .34663 .35178 L .34522 .37752 L p .959 .688 .477 r
F P
0 g
s
.32936 .33408 m .34663 .35178 L .34522 .37752 L p .959 .688 .477 r
F P
0 g
s
.21086 .32736 m .21334 .30188 L .18646 .31163 L p .509 .275 .495 r
F P
0 g
s
.18646 .31163 m .18378 .33706 L .21086 .32736 L p .509 .275 .495 r
F P
0 g
s
.37678 .46399 m .40478 .45498 L .42134 .47154 L p .649 .759 .929 r
F P
0 g
s
.42134 .47154 m .40478 .45498 L .40572 .42857 L p .962 .688 .469 r
F P
0 g
s
.2865 .44869 m .28838 .42224 L .2611 .43137 L p .522 .293 .509 r
F P
0 g
s
.2611 .43137 m .25901 .45776 L .2865 .44869 L p .522 .293 .509 r
F P
0 g
s
.2611 .43137 m .24301 .41443 L .24523 .38834 L p .952 .687 .499 r
F P
0 g
s
.2611 .43137 m .24301 .41443 L .24523 .38834 L p .952 .687 .499 r
F P
0 g
s
.28838 .42224 m .2611 .43137 L .24301 .41443 L p .652 .756 .926 r
F P
0 g
s
.21585 .42365 m .24301 .41443 L .2611 .43137 L p .652 .756 .926 r
F P
0 g
s
.69537 .32661 m .69402 .30113 L .66466 .31088 L p .537 .315 .524 r
F P
0 g
s
.66466 .31088 m .66577 .33631 L .69537 .32661 L p .537 .315 .524 r
F P
0 g
s
.66466 .31088 m .65042 .29279 L .64943 .26766 L p .976 .68 .386 r
F P
0 g
s
.69402 .30113 m .66466 .31088 L .65042 .29279 L p .658 .749 .917 r
F P
0 g
s
.69537 .32661 m .69402 .30113 L .66466 .31088 L p .537 .315 .524 r
F P
0 g
s
.66466 .31088 m .66577 .33631 L .69537 .32661 L p .537 .315 .524 r
F P
0 g
s
.62116 .30263 m .65042 .29279 L .66466 .31088 L p .658 .749 .917 r
F P
0 g
s
.65042 .29279 m .66466 .31088 L .66577 .33631 L p .976 .68 .386 r
F P
0 g
s
.69402 .30113 m .66466 .31088 L .65042 .29279 L p .658 .749 .917 r
F P
0 g
s
.65042 .29279 m .66466 .31088 L .66577 .33631 L p .976 .68 .386 r
F P
0 g
s
.73952 .43067 m .72599 .41372 L .7244 .38763 L p .976 .678 .372 r
F P
0 g
s
.73952 .43067 m .72599 .41372 L .7244 .38763 L p .976 .678 .372 r
F P
0 g
s
.76927 .42153 m .73952 .43067 L .72599 .41372 L p .652 .756 .926 r
F P
0 g
s
.69633 .42294 m .72599 .41372 L .73952 .43067 L p .652 .756 .926 r
F P
0 g
s
.60882 .40728 m .60815 .38114 L .57922 .39049 L p .537 .315 .524 r
F P
0 g
s
.57922 .39049 m .57966 .41657 L .60882 .40728 L p .537 .315 .524 r
F P
0 g
s
.57922 .39049 m .56416 .37316 L .56385 .34738 L p .972 .685 .422 r
F P
0 g
s
.60815 .38114 m .57922 .39049 L .56416 .37316 L p .654 .754 .923 r
F P
0 g
s
.60882 .40728 m .60815 .38114 L .57922 .39049 L p .537 .315 .524 r
F P
0 g
s
.57922 .39049 m .57966 .41657 L .60882 .40728 L p .537 .315 .524 r
F P
0 g
s
.53534 .38259 m .56416 .37316 L .57922 .39049 L p .654 .754 .923 r
F P
0 g
s
.56416 .37316 m .57922 .39049 L .57966 .41657 L p .972 .685 .422 r
F P
0 g
s
.60815 .38114 m .57922 .39049 L .56416 .37316 L p .654 .754 .923 r
F P
0 g
s
.56416 .37316 m .57922 .39049 L .57966 .41657 L p .972 .685 .422 r
F P
0 g
s
.44641 .36657 m .44702 .34076 L .41892 .35031 L p .526 .299 .513 r
F P
0 g
s
.41892 .35031 m .41809 .37607 L .44641 .36657 L p .526 .299 .513 r
F P
0 g
s
.41892 .35031 m .40233 .33259 L .4033 .30714 L p .964 .688 .461 r
F P
0 g
s
.41892 .35031 m .40233 .33259 L .4033 .30714 L p .964 .688 .461 r
F P
0 g
s
.44702 .34076 m .41892 .35031 L .40233 .33259 L p .656 .751 .92 r
F P
0 g
s
.37434 .34223 m .40233 .33259 L .41892 .35031 L p .656 .751 .92 r
F P
0 g
s
.25863 .31014 m .2405 .29203 L .24274 .2669 L p .954 .688 .492 r
F P
0 g
s
.25863 .31014 m .2405 .29203 L .24274 .2669 L p .954 .688 .492 r
F P
0 g
s
.2859 .30037 m .25863 .31014 L .2405 .29203 L p .658 .749 .917 r
F P
0 g
s
.21334 .30188 m .2405 .29203 L .25863 .31014 L p .658 .749 .917 r
F P
0 g
s
.21334 .30188 m .2405 .29203 L .25863 .31014 L p .658 .749 .917 r
F P
0 g
s
.2405 .29203 m .25863 .31014 L .25651 .33557 L p .954 .688 .492 r
F P
0 g
s
.49372 .47017 m .47783 .45358 L .4782 .42717 L p .966 .687 .452 r
F P
0 g
s
.49372 .47017 m .47783 .45358 L .4782 .42717 L p .966 .687 .452 r
F P
0 g
s
.52222 .46122 m .49372 .47017 L .47783 .45358 L p .649 .759 .929 r
F P
0 g
s
.44944 .46261 m .47783 .45358 L .49372 .47017 L p .649 .759 .929 r
F P
0 g
s
.35972 .44728 m .36103 .42082 L .33336 .42997 L p .526 .299 .513 r
F P
0 g
s
.33336 .42997 m .33184 .45637 L .35972 .44728 L p .526 .299 .513 r
F P
0 g
s
.33336 .42997 m .31594 .41301 L .31759 .38691 L p .957 .688 .485 r
F P
0 g
s
.33336 .42997 m .31594 .41301 L .31759 .38691 L p .957 .688 .485 r
F P
0 g
s
.36103 .42082 m .33336 .42997 L .31594 .41301 L p .652 .756 .926 r
F P
0 g
s
.28838 .42224 m .31594 .41301 L .33336 .42997 L p .652 .756 .926 r
F P
0 g
s
.28838 .42224 m .31594 .41301 L .33336 .42997 L p .652 .756 .926 r
F P
0 g
s
.31594 .41301 m .33336 .42997 L .33184 .45637 L p .957 .688 .485 r
F P
0 g
s
.73723 .30939 m .72367 .29127 L .7221 .26613 L p .976 .675 .358 r
F P
0 g
s
.73723 .30939 m .72367 .29127 L .7221 .26613 L p .976 .675 .358 r
F P
0 g
s
.76698 .29962 m .73723 .30939 L .72367 .29127 L p .658 .749 .917 r
F P
0 g
s
.69402 .30113 m .72367 .29127 L .73723 .30939 L p .658 .749 .917 r
F P
0 g
s
.60644 .28438 m .60579 .25921 L .57687 .26919 L p .53 .304 .517 r
F P
0 g
s
.57687 .26919 m .57729 .29431 L .60644 .28438 L p .53 .304 .517 r
F P
0 g
s
.68233 .40584 m .68108 .3797 L .65176 .38906 L p .541 .319 .528 r
F P
0 g
s
.65176 .38906 m .65277 .41514 L .68233 .40584 L p .541 .319 .528 r
F P
0 g
s
.65176 .38906 m .63737 .3717 L .63648 .34592 L p .975 .682 .398 r
F P
0 g
s
.65176 .38906 m .63737 .3717 L .63648 .34592 L p .975 .682 .398 r
F P
0 g
s
.68108 .3797 m .65176 .38906 L .63737 .3717 L p .654 .754 .923 r
F P
0 g
s
.60815 .38114 m .63737 .3717 L .65176 .38906 L p .654 .754 .923 r
F P
0 g
s
.51979 .3651 m .51983 .33928 L .49133 .34885 L p .53 .304 .517 r
F P
0 g
s
.49133 .34885 m .49107 .37461 L .51979 .3651 L p .53 .304 .517 r
F P
0 g
s
.49133 .34885 m .47542 .3311 L .4758 .30564 L p .969 .687 .442 r
F P
0 g
s
.49133 .34885 m .47542 .3311 L .4758 .30564 L p .969 .687 .442 r
F P
0 g
s
.51983 .33928 m .49133 .34885 L .47542 .3311 L p .656 .751 .92 r
F P
0 g
s
.51979 .3651 m .51983 .33928 L .49133 .34885 L p .53 .304 .517 r
F P
0 g
s
.49133 .34885 m .49107 .37461 L .51979 .3651 L p .53 .304 .517 r
F P
0 g
s
.44702 .34076 m .47542 .3311 L .49133 .34885 L p .656 .751 .92 r
F P
0 g
s
.47542 .3311 m .49133 .34885 L .49107 .37461 L p .969 .687 .442 r
F P
0 g
s
.51983 .33928 m .49133 .34885 L .47542 .3311 L p .656 .751 .92 r
F P
0 g
s
.56621 .4688 m .55101 .45219 L .5508 .42576 L p .971 .686 .432 r
F P
0 g
s
.5951 .45984 m .56621 .4688 L .55101 .45219 L p .649 .759 .929 r
F P
0 g
s
.40572 .42857 m .38898 .41158 L .39006 .38547 L p .962 .688 .469 r
F P
0 g
s
.43379 .41941 m .40572 .42857 L .38898 .41158 L p .652 .756 .926 r
F P
0 g
s
.43306 .44588 m .43379 .41941 L .40572 .42857 L p .53 .304 .517 r
F P
0 g
s
.40572 .42857 m .40478 .45498 L .43306 .44588 L p .53 .304 .517 r
F P
0 g
s
.36103 .42082 m .38898 .41158 L .40572 .42857 L p .652 .756 .926 r
F P
0 g
s
.36103 .42082 m .38898 .41158 L .40572 .42857 L p .652 .756 .926 r
F P
0 g
s
.38898 .41158 m .40572 .42857 L .40478 .45498 L p .962 .688 .469 r
F P
0 g
s
.38898 .41158 m .40572 .42857 L .40478 .45498 L p .962 .688 .469 r
F P
0 g
s
.27046 .40512 m .27247 .37897 L .24523 .38834 L p .518 .287 .504 r
F P
0 g
s
.24523 .38834 m .24301 .41443 L .27046 .40512 L p .518 .287 .504 r
F P
0 g
s
.19984 .38042 m .22696 .37097 L .24523 .38834 L p .654 .754 .923 r
F P
0 g
s
.24523 .38834 m .22696 .37097 L .22931 .34518 L p .952 .687 .499 r
F P
0 g
s
.67998 .28285 m .67875 .25767 L .64943 .26766 L p .534 .309 .521 r
F P
0 g
s
.64943 .26766 m .65042 .29279 L .67998 .28285 L p .534 .309 .521 r
F P
0 g
s
.67875 .25767 m .64943 .26766 L .63502 .24913 L p .66 .747 .915 r
F P
0 g
s
.67998 .28285 m .67875 .25767 L .64943 .26766 L p .534 .309 .521 r
F P
0 g
s
.64943 .26766 m .65042 .29279 L .67998 .28285 L p .534 .309 .521 r
F P
0 g
s
.63502 .24913 m .64943 .26766 L .65042 .29279 L p .976 .68 .386 r
F P
0 g
s
.75596 .4044 m .75412 .37825 L .7244 .38763 L p .544 .324 .532 r
F P
0 g
s
.7244 .38763 m .72599 .41372 L .75596 .4044 L p .544 .324 .532 r
F P
0 g
s
.7244 .38763 m .7107 .37023 L .70923 .34444 L p .976 .678 .372 r
F P
0 g
s
.75412 .37825 m .7244 .38763 L .7107 .37023 L p .654 .754 .923 r
F P
0 g
s
.75596 .4044 m .75412 .37825 L .7244 .38763 L p .544 .324 .532 r
F P
0 g
s
.7244 .38763 m .72599 .41372 L .75596 .4044 L p .544 .324 .532 r
F P
0 g
s
.68108 .3797 m .7107 .37023 L .7244 .38763 L p .654 .754 .923 r
F P
0 g
s
.7107 .37023 m .7244 .38763 L .72599 .41372 L p .976 .678 .372 r
F P
0 g
s
.75412 .37825 m .7244 .38763 L .7107 .37023 L p .654 .754 .923 r
F P
0 g
s
.7107 .37023 m .7244 .38763 L .72599 .41372 L p .976 .678 .372 r
F P
0 g
s
.59329 .36363 m .59274 .3378 L .56385 .34738 L p .534 .309 .521 r
F P
0 g
s
.56385 .34738 m .56416 .37316 L .59329 .36363 L p .534 .309 .521 r
F P
0 g
s
.59274 .3378 m .56385 .34738 L .54862 .32961 L p .656 .751 .92 r
F P
0 g
s
.59329 .36363 m .59274 .3378 L .56385 .34738 L p .534 .309 .521 r
F P
0 g
s
.56385 .34738 m .56416 .37316 L .59329 .36363 L p .534 .309 .521 r
F P
0 g
s
.51983 .33928 m .54862 .32961 L .56385 .34738 L p .656 .751 .92 r
F P
0 g
s
.54862 .32961 m .56385 .34738 L .56416 .37316 L p .972 .685 .422 r
F P
0 g
s
.54862 .32961 m .56385 .34738 L .56416 .37316 L p .972 .685 .422 r
F P
0 g
s
.43062 .32285 m .43136 .29735 L .4033 .30714 L p .522 .293 .509 r
F P
0 g
s
.4033 .30714 m .40233 .33259 L .43062 .32285 L p .522 .293 .509 r
F P
0 g
s
.4033 .30714 m .38653 .28898 L .38762 .26383 L p .964 .688 .461 r
F P
0 g
s
.4033 .30714 m .38653 .28898 L .38762 .26383 L p .964 .688 .461 r
F P
0 g
s
.43136 .29735 m .4033 .30714 L .38653 .28898 L p .658 .749 .917 r
F P
0 g
s
.43062 .32285 m .43136 .29735 L .4033 .30714 L p .522 .293 .509 r
F P
0 g
s
.4033 .30714 m .40233 .33259 L .43062 .32285 L p .522 .293 .509 r
F P
0 g
s
.35857 .29886 m .38653 .28898 L .4033 .30714 L p .658 .749 .917 r
F P
0 g
s
.38653 .28898 m .4033 .30714 L .40233 .33259 L p .964 .688 .461 r
F P
0 g
s
.43136 .29735 m .4033 .30714 L .38653 .28898 L p .658 .749 .917 r
F P
0 g
s
.26794 .28208 m .26998 .2569 L .24274 .2669 L p .509 .275 .495 r
F P
0 g
s
.24274 .2669 m .2405 .29203 L .26794 .28208 L p .509 .275 .495 r
F P
0 g
s
.26998 .2569 m .24274 .2669 L .22444 .24835 L p .66 .747 .915 r
F P
0 g
s
.26794 .28208 m .26998 .2569 L .24274 .2669 L p .509 .275 .495 r
F P
0 g
s
.24274 .2669 m .2405 .29203 L .26794 .28208 L p .509 .275 .495 r
F P
0 g
s
.19732 .25844 m .22444 .24835 L .24274 .2669 L p .66 .747 .915 r
F P
0 g
s
.22444 .24835 m .24274 .2669 L .2405 .29203 L p .954 .688 .492 r
F P
0 g
s
.22444 .24835 m .24274 .2669 L .2405 .29203 L p .954 .688 .492 r
F P
0 g
s
.50652 .44447 m .50667 .41799 L .4782 .42717 L p .534 .309 .521 r
F P
0 g
s
.4782 .42717 m .47783 .45358 L .50652 .44447 L p .534 .309 .521 r
F P
0 g
s
.43379 .41941 m .46214 .41015 L .4782 .42717 L p .652 .756 .926 r
F P
0 g
s
.43379 .41941 m .46214 .41015 L .4782 .42717 L p .652 .756 .926 r
F P
0 g
s
.46214 .41015 m .4782 .42717 L .47783 .45358 L p .966 .687 .452 r
F P
0 g
s
.4782 .42717 m .46214 .41015 L .46264 .38403 L p .966 .687 .452 r
F P
0 g
s
.34379 .40368 m .34522 .37752 L .31759 .38691 L p .522 .293 .509 r
F P
0 g
s
.31759 .38691 m .31594 .41301 L .34379 .40368 L p .522 .293 .509 r
F P
0 g
s
.31759 .38691 m .29999 .3695 L .30177 .34371 L p .957 .688 .485 r
F P
0 g
s
.31759 .38691 m .29999 .3695 L .30177 .34371 L p .957 .688 .485 r
F P
0 g
s
.34522 .37752 m .31759 .38691 L .29999 .3695 L p .654 .754 .923 r
F P
0 g
s
.34379 .40368 m .34522 .37752 L .31759 .38691 L p .522 .293 .509 r
F P
0 g
s
.31759 .38691 m .31594 .41301 L .34379 .40368 L p .522 .293 .509 r
F P
0 g
s
.27247 .37897 m .29999 .3695 L .31759 .38691 L p .654 .754 .923 r
F P
0 g
s
.27247 .37897 m .29999 .3695 L .31759 .38691 L p .654 .754 .923 r
F P
0 g
s
.29999 .3695 m .31759 .38691 L .31594 .41301 L p .957 .688 .485 r
F P
0 g
s
.34522 .37752 m .31759 .38691 L .29999 .3695 L p .654 .754 .923 r
F P
0 g
s
.29999 .3695 m .31759 .38691 L .31594 .41301 L p .957 .688 .485 r
F P
0 g
s
.63882 .46743 m .6243 .45079 L .62351 .42435 L p .974 .684 .41 r
F P
0 g
s
.63882 .46743 m .6243 .45079 L .62351 .42435 L p .974 .684 .41 r
F P
0 g
s
.66811 .45845 m .63882 .46743 L .6243 .45079 L p .649 .759 .929 r
F P
0 g
s
.5951 .45984 m .6243 .45079 L .63882 .46743 L p .649 .759 .929 r
F P
0 g
s
.75364 .28131 m .75182 .25612 L .7221 .26613 L p .537 .315 .524 r
F P
0 g
s
.7221 .26613 m .72367 .29127 L .75364 .28131 L p .537 .315 .524 r
F P
0 g
s
.6669 .36215 m .66577 .33631 L .63648 .34592 L p .537 .315 .524 r
F P
0 g
s
.63648 .34592 m .63737 .3717 L .6669 .36215 L p .537 .315 .524 r
F P
0 g
s
.63648 .34592 m .62193 .32811 L .62116 .30263 L p .975 .682 .398 r
F P
0 g
s
.66577 .33631 m .63648 .34592 L .62193 .32811 L p .656 .751 .92 r
F P
0 g
s
.6669 .36215 m .66577 .33631 L .63648 .34592 L p .537 .315 .524 r
F P
0 g
s
.63648 .34592 m .63737 .3717 L .6669 .36215 L p .537 .315 .524 r
F P
0 g
s
.59274 .3378 m .62193 .32811 L .63648 .34592 L p .656 .751 .92 r
F P
0 g
s
.62193 .32811 m .63648 .34592 L .63737 .3717 L p .975 .682 .398 r
F P
0 g
s
.66577 .33631 m .63648 .34592 L .62193 .32811 L p .656 .751 .92 r
F P
0 g
s
.62193 .32811 m .63648 .34592 L .63737 .3717 L p .975 .682 .398 r
F P
0 g
s
.5041 .32134 m .50427 .29583 L .4758 .30564 L p .526 .299 .513 r
F P
0 g
s
.4758 .30564 m .47542 .3311 L .5041 .32134 L p .526 .299 .513 r
F P
0 g
s
.4758 .30564 m .45972 .28745 L .46023 .2623 L p .969 .687 .442 r
F P
0 g
s
.50427 .29583 m .4758 .30564 L .45972 .28745 L p .658 .749 .917 r
F P
0 g
s
.5041 .32134 m .50427 .29583 L .4758 .30564 L p .526 .299 .513 r
F P
0 g
s
.4758 .30564 m .47542 .3311 L .5041 .32134 L p .526 .299 .513 r
F P
0 g
s
.43136 .29735 m .45972 .28745 L .4758 .30564 L p .658 .749 .917 r
F P
0 g
s
.43136 .29735 m .45972 .28745 L .4758 .30564 L p .658 .749 .917 r
F P
0 g
s
.45972 .28745 m .4758 .30564 L .47542 .3311 L p .969 .687 .442 r
F P
0 g
s
.45972 .28745 m .4758 .30564 L .47542 .3311 L p .969 .687 .442 r
F P
0 g
s
.5801 .44306 m .57966 .41657 L .5508 .42576 L p .537 .315 .524 r
F P
0 g
s
.5508 .42576 m .55101 .45219 L .5801 .44306 L p .537 .315 .524 r
F P
0 g
s
.5508 .42576 m .53542 .40871 L .53534 .38259 L p .971 .686 .432 r
F P
0 g
s
.5508 .42576 m .53542 .40871 L .53534 .38259 L p .971 .686 .432 r
F P
0 g
s
.57966 .41657 m .5508 .42576 L .53542 .40871 L p .652 .756 .926 r
F P
0 g
s
.50667 .41799 m .53542 .40871 L .5508 .42576 L p .652 .756 .926 r
F P
0 g
s
.50667 .41799 m .53542 .40871 L .5508 .42576 L p .652 .756 .926 r
F P
0 g
s
.53542 .40871 m .5508 .42576 L .55101 .45219 L p .971 .686 .432 r
F P
0 g
s
.41809 .37607 m .39006 .38547 L .37314 .36804 L p .654 .754 .923 r
F P
0 g
s
.41723 .40223 m .41809 .37607 L .39006 .38547 L p .526 .299 .513 r
F P
0 g
s
.39006 .38547 m .38898 .41158 L .41723 .40223 L p .526 .299 .513 r
F P
0 g
s
.34522 .37752 m .37314 .36804 L .39006 .38547 L p .654 .754 .923 r
F P
0 g
s
.37314 .36804 m .39006 .38547 L .38898 .41158 L p .962 .688 .469 r
F P
0 g
s
.37314 .36804 m .39006 .38547 L .38898 .41158 L p .962 .688 .469 r
F P
0 g
s
.22931 .34518 m .21086 .32736 L .21334 .30188 L p .952 .687 .499 r
F P
0 g
s
.22931 .34518 m .21086 .32736 L .21334 .30188 L p .952 .687 .499 r
F P
0 g
s
.25651 .33557 m .22931 .34518 L .21086 .32736 L p .656 .751 .92 r
F P
0 g
s
.18378 .33706 m .21086 .32736 L .22931 .34518 L p .656 .751 .92 r
F P
0 g
s
.30424 .46536 m .2865 .44869 L .28838 .42224 L p .954 .688 .492 r
F P
0 g
s
.30424 .46536 m .2865 .44869 L .28838 .42224 L p .954 .688 .492 r
F P
0 g
s
.33184 .45637 m .30424 .46536 L .2865 .44869 L p .649 .759 .929 r
F P
0 g
s
.25901 .45776 m .2865 .44869 L .30424 .46536 L p .649 .759 .929 r
F P
0 g
s
.74064 .36067 m .73892 .33483 L .70923 .34444 L p .541 .319 .528 r
F P
0 g
s
.70923 .34444 m .7107 .37023 L .74064 .36067 L p .541 .319 .528 r
F P
0 g
s
.70923 .34444 m .69537 .32661 L .69402 .30113 L p .976 .678 .372 r
F P
0 g
s
.73892 .33483 m .70923 .34444 L .69537 .32661 L p .656 .751 .92 r
F P
0 g
s
.74064 .36067 m .73892 .33483 L .70923 .34444 L p .541 .319 .528 r
F P
0 g
s
.70923 .34444 m .7107 .37023 L .74064 .36067 L p .541 .319 .528 r
F P
0 g
s
.66577 .33631 m .69537 .32661 L .70923 .34444 L p .656 .751 .92 r
F P
0 g
s
.69537 .32661 m .70923 .34444 L .7107 .37023 L p .976 .678 .372 r
F P
0 g
s
.57729 .29431 m .54843 .30414 L .53302 .28592 L p .658 .749 .917 r
F P
0 g
s
.57771 .31983 m .57729 .29431 L .54843 .30414 L p .53 .304 .517 r
F P
0 g
s
.54843 .30414 m .54862 .32961 L .57771 .31983 L p .53 .304 .517 r
F P
0 g
s
.50427 .29583 m .53302 .28592 L .54843 .30414 L p .658 .749 .917 r
F P
0 g
s
.53302 .28592 m .54843 .30414 L .54862 .32961 L p .972 .685 .422 r
F P
0 g
s
.53302 .28592 m .54843 .30414 L .54862 .32961 L p .972 .685 .422 r
F P
0 g
s
.41478 .279 m .41565 .2538 L .38762 .26383 L p .518 .287 .504 r
F P
0 g
s
.38762 .26383 m .38653 .28898 L .41478 .279 L p .518 .287 .504 r
F P
0 g
s
.41565 .2538 m .38762 .26383 L .37068 .24523 L p .66 .747 .915 r
F P
0 g
s
.41478 .279 m .41565 .2538 L .38762 .26383 L p .518 .287 .504 r
F P
0 g
s
.38762 .26383 m .38653 .28898 L .41478 .279 L p .518 .287 .504 r
F P
0 g
s
.34276 .25535 m .37068 .24523 L .38762 .26383 L p .66 .747 .915 r
F P
0 g
s
.37068 .24523 m .38762 .26383 L .38653 .28898 L p .964 .688 .461 r
F P
0 g
s
.37068 .24523 m .38762 .26383 L .38653 .28898 L p .964 .688 .461 r
F P
0 g
s
.65379 .44164 m .65277 .41514 L .62351 .42435 L p .541 .319 .528 r
F P
0 g
s
.62351 .42435 m .6243 .45079 L .65379 .44164 L p .541 .319 .528 r
F P
0 g
s
.57966 .41657 m .60882 .40728 L .62351 .42435 L p .652 .756 .926 r
F P
0 g
s
.62351 .42435 m .60882 .40728 L .60815 .38114 L p .974 .684 .41 r
F P
0 g
s
.46264 .38403 m .44641 .36657 L .44702 .34076 L p .966 .687 .452 r
F P
0 g
s
.49107 .37461 m .46264 .38403 L .44641 .36657 L p .654 .754 .923 r
F P
0 g
s
.4908 .40079 m .49107 .37461 L .46264 .38403 L p .53 .304 .517 r
F P
0 g
s
.46264 .38403 m .46214 .41015 L .4908 .40079 L p .53 .304 .517 r
F P
0 g
s
.41809 .37607 m .44641 .36657 L .46264 .38403 L p .654 .754 .923 r
F P
0 g
s
.41809 .37607 m .44641 .36657 L .46264 .38403 L p .654 .754 .923 r
F P
0 g
s
.44641 .36657 m .46264 .38403 L .46214 .41015 L p .966 .687 .452 r
F P
0 g
s
.44641 .36657 m .46264 .38403 L .46214 .41015 L p .966 .687 .452 r
F P
0 g
s
.3278 .35993 m .32936 .33408 L .30177 .34371 L p .518 .287 .504 r
F P
0 g
s
.30177 .34371 m .29999 .3695 L .3278 .35993 L p .518 .287 .504 r
F P
0 g
s
.37678 .46399 m .35972 .44728 L .36103 .42082 L p .959 .688 .477 r
F P
0 g
s
.37678 .46399 m .35972 .44728 L .36103 .42082 L p .959 .688 .477 r
F P
0 g
s
.40478 .45498 m .37678 .46399 L .35972 .44728 L p .649 .759 .929 r
F P
0 g
s
.33184 .45637 m .35972 .44728 L .37678 .46399 L p .649 .759 .929 r
F P
0 g
s
.65143 .31832 m .65042 .29279 L .62116 .30263 L p .534 .309 .521 r
F P
0 g
s
.62116 .30263 m .62193 .32811 L .65143 .31832 L p .534 .309 .521 r
F P
0 g
s
.62116 .30263 m .60644 .28438 L .60579 .25921 L p .975 .682 .398 r
F P
0 g
s
.65042 .29279 m .62116 .30263 L .60644 .28438 L p .658 .749 .917 r
F P
0 g
s
.65143 .31832 m .65042 .29279 L .62116 .30263 L p .534 .309 .521 r
F P
0 g
s
.62116 .30263 m .62193 .32811 L .65143 .31832 L p .534 .309 .521 r
F P
0 g
s
.57729 .29431 m .60644 .28438 L .62116 .30263 L p .658 .749 .917 r
F P
0 g
s
.57729 .29431 m .60644 .28438 L .62116 .30263 L p .658 .749 .917 r
F P
0 g
s
.60644 .28438 m .62116 .30263 L .62193 .32811 L p .975 .682 .398 r
F P
0 g
s
.60644 .28438 m .62116 .30263 L .62193 .32811 L p .975 .682 .398 r
F P
0 g
s
.48866 .25224 m .46023 .2623 L .44397 .24366 L p .66 .747 .915 r
F P
0 g
s
.48837 .27745 m .48866 .25224 L .46023 .2623 L p .522 .293 .509 r
F P
0 g
s
.46023 .2623 m .45972 .28745 L .48837 .27745 L p .522 .293 .509 r
F P
0 g
s
.41565 .2538 m .44397 .24366 L .46023 .2623 L p .66 .747 .915 r
F P
0 g
s
.44397 .24366 m .46023 .2623 L .45972 .28745 L p .969 .687 .442 r
F P
0 g
s
.44397 .24366 m .46023 .2623 L .45972 .28745 L p .969 .687 .442 r
F P
0 g
s
.69633 .42294 m .68233 .40584 L .68108 .3797 L p .976 .68 .386 r
F P
0 g
s
.69633 .42294 m .68233 .40584 L .68108 .3797 L p .976 .68 .386 r
F P
0 g
s
.72599 .41372 m .69633 .42294 L .68233 .40584 L p .652 .756 .926 r
F P
0 g
s
.72761 .44023 m .72599 .41372 L .69633 .42294 L p .544 .324 .532 r
F P
0 g
s
.69633 .42294 m .6977 .44939 L .72761 .44023 L p .544 .324 .532 r
F P
0 g
s
.65277 .41514 m .68233 .40584 L .69633 .42294 L p .652 .756 .926 r
F P
0 g
s
.65277 .41514 m .68233 .40584 L .69633 .42294 L p .652 .756 .926 r
F P
0 g
s
.68233 .40584 m .69633 .42294 L .6977 .44939 L p .976 .68 .386 r
F P
0 g
s
.72599 .41372 m .69633 .42294 L .68233 .40584 L p .652 .756 .926 r
F P
0 g
s
.68233 .40584 m .69633 .42294 L .6977 .44939 L p .976 .68 .386 r
F P
0 g
s
.56448 .39934 m .56416 .37316 L .53534 .38259 L p .534 .309 .521 r
F P
0 g
s
.53534 .38259 m .53542 .40871 L .56448 .39934 L p .534 .309 .521 r
F P
0 g
s
.53534 .38259 m .51979 .3651 L .51983 .33928 L p .971 .686 .432 r
F P
0 g
s
.53534 .38259 m .51979 .3651 L .51983 .33928 L p .971 .686 .432 r
F P
0 g
s
.56416 .37316 m .53534 .38259 L .51979 .3651 L p .654 .754 .923 r
F P
0 g
s
.49107 .37461 m .51979 .3651 L .53534 .38259 L p .654 .754 .923 r
F P
0 g
s
.49107 .37461 m .51979 .3651 L .53534 .38259 L p .654 .754 .923 r
F P
0 g
s
.51979 .3651 m .53534 .38259 L .53542 .40871 L p .971 .686 .432 r
F P
0 g
s
.40233 .33259 m .37434 .34223 L .35725 .32436 L p .656 .751 .92 r
F P
0 g
s
.40135 .35845 m .40233 .33259 L .37434 .34223 L p .522 .293 .509 r
F P
0 g
s
.37434 .34223 m .37314 .36804 L .40135 .35845 L p .522 .293 .509 r
F P
0 g
s
.32936 .33408 m .35725 .32436 L .37434 .34223 L p .656 .751 .92 r
F P
0 g
s
.35725 .32436 m .37434 .34223 L .37314 .36804 L p .962 .688 .469 r
F P
0 g
s
.35725 .32436 m .37434 .34223 L .37314 .36804 L p .962 .688 .469 r
F P
0 g
s
.23822 .31756 m .2405 .29203 L .21334 .30188 L p .509 .275 .495 r
F P
0 g
s
.21334 .30188 m .21086 .32736 L .23822 .31756 L p .509 .275 .495 r
F P
0 g
s
.21334 .30188 m .19471 .28362 L .19732 .25844 L p .952 .687 .499 r
F P
0 g
s
.2405 .29203 m .21334 .30188 L .19471 .28362 L p .658 .749 .917 r
F P
0 g
s
.44944 .46261 m .43306 .44588 L .43379 .41941 L p .964 .688 .461 r
F P
0 g
s
.47783 .45358 m .44944 .46261 L .43306 .44588 L p .649 .759 .929 r
F P
0 g
s
.31427 .43952 m .31594 .41301 L .28838 .42224 L p .522 .293 .509 r
F P
0 g
s
.28838 .42224 m .2865 .44869 L .31427 .43952 L p .522 .293 .509 r
F P
0 g
s
.28838 .42224 m .27046 .40512 L .27247 .37897 L p .954 .688 .492 r
F P
0 g
s
.28838 .42224 m .27046 .40512 L .27247 .37897 L p .954 .688 .492 r
F P
0 g
s
.31594 .41301 m .28838 .42224 L .27046 .40512 L p .652 .756 .926 r
F P
0 g
s
.24301 .41443 m .27046 .40512 L .28838 .42224 L p .652 .756 .926 r
F P
0 g
s
.65042 .29279 m .67998 .28285 L .69402 .30113 L p .658 .749 .917 r
F P
0 g
s
.65042 .29279 m .67998 .28285 L .69402 .30113 L p .658 .749 .917 r
F P
0 g
s
.67998 .28285 m .69402 .30113 L .69537 .32661 L p .976 .678 .372 r
F P
0 g
s
.69402 .30113 m .67998 .28285 L .67875 .25767 L p .976 .678 .372 r
F P
0 g
s
.56178 .25069 m .53295 .26076 L .51738 .24209 L p .66 .747 .915 r
F P
0 g
s
.56208 .2759 m .56178 .25069 L .53295 .26076 L p .526 .299 .513 r
F P
0 g
s
.53295 .26076 m .53302 .28592 L .56208 .2759 L p .526 .299 .513 r
F P
0 g
s
.51738 .24209 m .53295 .26076 L .53302 .28592 L p .972 .685 .422 r
F P
0 g
s
.72599 .41372 m .75596 .4044 L .76927 .42153 L p .652 .756 .926 r
F P
0 g
s
.76927 .42153 m .75596 .4044 L .75412 .37825 L p .976 .675 .358 r
F P
0 g
s
.60815 .38114 m .59329 .36363 L .59274 .3378 L p .974 .684 .41 r
F P
0 g
s
.60815 .38114 m .59329 .36363 L .59274 .3378 L p .974 .684 .41 r
F P
0 g
s
.63737 .3717 m .60815 .38114 L .59329 .36363 L p .654 .754 .923 r
F P
0 g
s
.56416 .37316 m .59329 .36363 L .60815 .38114 L p .654 .754 .923 r
F P
0 g
s
.56416 .37316 m .59329 .36363 L .60815 .38114 L p .654 .754 .923 r
F P
0 g
s
.59329 .36363 m .60815 .38114 L .60882 .40728 L p .974 .684 .41 r
F P
0 g
s
.44702 .34076 m .43062 .32285 L .43136 .29735 L p .966 .687 .452 r
F P
0 g
s
.44702 .34076 m .43062 .32285 L .43136 .29735 L p .966 .687 .452 r
F P
0 g
s
.47542 .3311 m .44702 .34076 L .43062 .32285 L p .656 .751 .92 r
F P
0 g
s
.47502 .35697 m .47542 .3311 L .44702 .34076 L p .526 .299 .513 r
F P
0 g
s
.44702 .34076 m .44641 .36657 L .47502 .35697 L p .526 .299 .513 r
F P
0 g
s
.40233 .33259 m .43062 .32285 L .44702 .34076 L p .656 .751 .92 r
F P
0 g
s
.43062 .32285 m .44702 .34076 L .44641 .36657 L p .966 .687 .452 r
F P
0 g
s
.47542 .3311 m .44702 .34076 L .43062 .32285 L p .656 .751 .92 r
F P
0 g
s
.2405 .29203 m .26794 .28208 L .2859 .30037 L p .658 .749 .917 r
F P
0 g
s
.2859 .30037 m .26794 .28208 L .26998 .2569 L p .957 .688 .485 r
F P
0 g
s
.52222 .46122 m .50652 .44447 L .50667 .41799 L p .969 .687 .442 r
F P
0 g
s
.52222 .46122 m .50652 .44447 L .50667 .41799 L p .969 .687 .442 r
F P
0 g
s
.55101 .45219 m .52222 .46122 L .50652 .44447 L p .649 .759 .929 r
F P
0 g
s
.47783 .45358 m .50652 .44447 L .52222 .46122 L p .649 .759 .929 r
F P
0 g
s
.3879 .4381 m .38898 .41158 L .36103 .42082 L p .526 .299 .513 r
F P
0 g
s
.36103 .42082 m .35972 .44728 L .3879 .4381 L p .526 .299 .513 r
F P
0 g
s
.36103 .42082 m .34379 .40368 L .34522 .37752 L p .959 .688 .477 r
F P
0 g
s
.36103 .42082 m .34379 .40368 L .34522 .37752 L p .959 .688 .477 r
F P
0 g
s
.38898 .41158 m .36103 .42082 L .34379 .40368 L p .652 .756 .926 r
F P
0 g
s
.31594 .41301 m .34379 .40368 L .36103 .42082 L p .652 .756 .926 r
F P
0 g
s
.72367 .29127 m .75364 .28131 L .76698 .29962 L p .658 .749 .917 r
F P
0 g
s
.76698 .29962 m .75364 .28131 L .75182 .25612 L p .976 .672 .343 r
F P
0 g
s
.63502 .24913 m .60579 .25921 L .5909 .24052 L p .66 .747 .915 r
F P
0 g
s
.63591 .27435 m .63502 .24913 L .60579 .25921 L p .53 .304 .517 r
F P
0 g
s
.60579 .25921 m .60644 .28438 L .63591 .27435 L p .53 .304 .517 r
F P
0 g
s
.5909 .24052 m .60579 .25921 L .60644 .28438 L p .975 .682 .398 r
F P
0 g
s
.54881 .35548 m .54862 .32961 L .51983 .33928 L p .53 .304 .517 r
F P
0 g
s
.51983 .33928 m .51979 .3651 L .54881 .35548 L p .53 .304 .517 r
F P
0 g
s
.51983 .33928 m .5041 .32134 L .50427 .29583 L p .971 .686 .432 r
F P
0 g
s
.51983 .33928 m .5041 .32134 L .50427 .29583 L p .971 .686 .432 r
F P
0 g
s
.54862 .32961 m .51983 .33928 L .5041 .32134 L p .656 .751 .92 r
F P
0 g
s
.54881 .35548 m .54862 .32961 L .51983 .33928 L p .53 .304 .517 r
F P
0 g
s
.51983 .33928 m .51979 .3651 L .54881 .35548 L p .53 .304 .517 r
F P
0 g
s
.47542 .3311 m .5041 .32134 L .51983 .33928 L p .656 .751 .92 r
F P
0 g
s
.47542 .3311 m .5041 .32134 L .51983 .33928 L p .656 .751 .92 r
F P
0 g
s
.5041 .32134 m .51983 .33928 L .51979 .3651 L p .971 .686 .432 r
F P
0 g
s
.54862 .32961 m .51983 .33928 L .5041 .32134 L p .656 .751 .92 r
F P
0 g
s
.5041 .32134 m .51983 .33928 L .51979 .3651 L p .971 .686 .432 r
F P
0 g
s
.35857 .29886 m .3413 .28054 L .34276 .25535 L p .962 .688 .469 r
F P
0 g
s
.38653 .28898 m .35857 .29886 L .3413 .28054 L p .658 .749 .917 r
F P
0 g
s
.22203 .27358 m .22444 .24835 L .19732 .25844 L p .504 .268 .49 r
F P
0 g
s
.19732 .25844 m .19471 .28362 L .22203 .27358 L p .504 .268 .49 r
F P
0 g
s
.7122 .39644 m .7107 .37023 L .68108 .3797 L p .541 .319 .528 r
F P
0 g
s
.68108 .3797 m .68233 .40584 L .7122 .39644 L p .541 .319 .528 r
F P
0 g
s
.68108 .3797 m .6669 .36215 L .66577 .33631 L p .976 .68 .386 r
F P
0 g
s
.7107 .37023 m .68108 .3797 L .6669 .36215 L p .654 .754 .923 r
F P
0 g
s
.7122 .39644 m .7107 .37023 L .68108 .3797 L p .541 .319 .528 r
F P
0 g
s
.68108 .3797 m .68233 .40584 L .7122 .39644 L p .541 .319 .528 r
F P
0 g
s
.63737 .3717 m .6669 .36215 L .68108 .3797 L p .654 .754 .923 r
F P
0 g
s
.6669 .36215 m .68108 .3797 L .68233 .40584 L p .976 .68 .386 r
F P
0 g
s
.55101 .45219 m .5801 .44306 L .5951 .45984 L p .649 .759 .929 r
F P
0 g
s
.5951 .45984 m .5801 .44306 L .57966 .41657 L p .972 .685 .422 r
F P
0 g
s
.46164 .43668 m .46214 .41015 L .43379 .41941 L p .53 .304 .517 r
F P
0 g
s
.43379 .41941 m .43306 .44588 L .46164 .43668 L p .53 .304 .517 r
F P
0 g
s
.43379 .41941 m .41723 .40223 L .41809 .37607 L p .964 .688 .461 r
F P
0 g
s
.46214 .41015 m .43379 .41941 L .41723 .40223 L p .652 .756 .926 r
F P
0 g
s
.46164 .43668 m .46214 .41015 L .43379 .41941 L p .53 .304 .517 r
F P
0 g
s
.43379 .41941 m .43306 .44588 L .46164 .43668 L p .53 .304 .517 r
F P
0 g
s
.38898 .41158 m .41723 .40223 L .43379 .41941 L p .652 .756 .926 r
F P
0 g
s
.41723 .40223 m .43379 .41941 L .43306 .44588 L p .964 .688 .461 r
F P
0 g
s
.46214 .41015 m .43379 .41941 L .41723 .40223 L p .652 .756 .926 r
F P
0 g
s
.41723 .40223 m .43379 .41941 L .43306 .44588 L p .964 .688 .461 r
F P
0 g
s
.29819 .39571 m .29999 .3695 L .27247 .37897 L p .518 .287 .504 r
F P
0 g
s
.27247 .37897 m .27046 .40512 L .29819 .39571 L p .518 .287 .504 r
F P
0 g
s
.63502 .24913 m .66455 .23894 L .67875 .25767 L p .66 .747 .915 r
F P
0 g
s
.66455 .23894 m .67875 .25767 L .67998 .28285 L p .976 .678 .372 r
F P
0 g
s
.7107 .37023 m .74064 .36067 L .75412 .37825 L p .654 .754 .923 r
F P
0 g
s
.7107 .37023 m .74064 .36067 L .75412 .37825 L p .654 .754 .923 r
F P
0 g
s
.74064 .36067 m .75412 .37825 L .75596 .4044 L p .976 .675 .358 r
F P
0 g
s
.75412 .37825 m .74064 .36067 L .73892 .33483 L p .976 .675 .358 r
F P
0 g
s
.62272 .354 m .62193 .32811 L .59274 .3378 L p .534 .309 .521 r
F P
0 g
s
.59274 .3378 m .59329 .36363 L .62272 .354 L p .534 .309 .521 r
F P
0 g
s
.59274 .3378 m .57771 .31983 L .57729 .29431 L p .974 .684 .41 r
F P
0 g
s
.62193 .32811 m .59274 .3378 L .57771 .31983 L p .656 .751 .92 r
F P
0 g
s
.62272 .354 m .62193 .32811 L .59274 .3378 L p .534 .309 .521 r
F P
0 g
s
.59274 .3378 m .59329 .36363 L .62272 .354 L p .534 .309 .521 r
F P
0 g
s
.54862 .32961 m .57771 .31983 L .59274 .3378 L p .656 .751 .92 r
F P
0 g
s
.57771 .31983 m .59274 .3378 L .59329 .36363 L p .974 .684 .41 r
F P
0 g
s
.62193 .32811 m .59274 .3378 L .57771 .31983 L p .656 .751 .92 r
F P
0 g
s
.57771 .31983 m .59274 .3378 L .59329 .36363 L p .974 .684 .41 r
F P
0 g
s
.4592 .31301 m .45972 .28745 L .43136 .29735 L p .522 .293 .509 r
F P
0 g
s
.43136 .29735 m .43062 .32285 L .4592 .31301 L p .522 .293 .509 r
F P
0 g
s
.43136 .29735 m .41478 .279 L .41565 .2538 L p .966 .687 .452 r
F P
0 g
s
.43136 .29735 m .41478 .279 L .41565 .2538 L p .966 .687 .452 r
F P
0 g
s
.45972 .28745 m .43136 .29735 L .41478 .279 L p .658 .749 .917 r
F P
0 g
s
.4592 .31301 m .45972 .28745 L .43136 .29735 L p .522 .293 .509 r
F P
0 g
s
.43136 .29735 m .43062 .32285 L .4592 .31301 L p .522 .293 .509 r
F P
0 g
s
.38653 .28898 m .41478 .279 L .43136 .29735 L p .658 .749 .917 r
F P
0 g
s
.38653 .28898 m .41478 .279 L .43136 .29735 L p .658 .749 .917 r
F P
0 g
s
.41478 .279 m .43136 .29735 L .43062 .32285 L p .966 .687 .452 r
F P
0 g
s
.45972 .28745 m .43136 .29735 L .41478 .279 L p .658 .749 .917 r
F P
0 g
s
.41478 .279 m .43136 .29735 L .43062 .32285 L p .966 .687 .452 r
F P
0 g
s
.22444 .24835 m .25184 .23816 L .26998 .2569 L p .66 .747 .915 r
F P
0 g
s
.25184 .23816 m .26998 .2569 L .26794 .28208 L p .957 .688 .485 r
F P
0 g
s
.66811 .45845 m .65379 .44164 L .65277 .41514 L p .975 .682 .398 r
F P
0 g
s
.66811 .45845 m .65379 .44164 L .65277 .41514 L p .975 .682 .398 r
F P
0 g
s
.6977 .44939 m .66811 .45845 L .65379 .44164 L p .649 .759 .929 r
F P
0 g
s
.6243 .45079 m .65379 .44164 L .66811 .45845 L p .649 .759 .929 r
F P
0 g
s
.53551 .43526 m .53542 .40871 L .50667 .41799 L p .534 .309 .521 r
F P
0 g
s
.50667 .41799 m .50652 .44447 L .53551 .43526 L p .534 .309 .521 r
F P
0 g
s
.50667 .41799 m .4908 .40079 L .49107 .37461 L p .969 .687 .442 r
F P
0 g
s
.53542 .40871 m .50667 .41799 L .4908 .40079 L p .652 .756 .926 r
F P
0 g
s
.53551 .43526 m .53542 .40871 L .50667 .41799 L p .534 .309 .521 r
F P
0 g
s
.50667 .41799 m .50652 .44447 L .53551 .43526 L p .534 .309 .521 r
F P
0 g
s
.4908 .40079 m .50667 .41799 L .50652 .44447 L p .969 .687 .442 r
F P
0 g
s
.53542 .40871 m .50667 .41799 L .4908 .40079 L p .652 .756 .926 r
F P
0 g
s
.37192 .39425 m .37314 .36804 L .34522 .37752 L p .522 .293 .509 r
F P
0 g
s
.34522 .37752 m .34379 .40368 L .37192 .39425 L p .522 .293 .509 r
F P
0 g
s
.34522 .37752 m .3278 .35993 L .32936 .33408 L p .959 .688 .477 r
F P
0 g
s
.34522 .37752 m .3278 .35993 L .32936 .33408 L p .959 .688 .477 r
F P
0 g
s
.37314 .36804 m .34522 .37752 L .3278 .35993 L p .654 .754 .923 r
F P
0 g
s
.37192 .39425 m .37314 .36804 L .34522 .37752 L p .522 .293 .509 r
F P
0 g
s
.34522 .37752 m .34379 .40368 L .37192 .39425 L p .522 .293 .509 r
F P
0 g
s
.29999 .3695 m .3278 .35993 L .34522 .37752 L p .654 .754 .923 r
F P
0 g
s
.29999 .3695 m .3278 .35993 L .34522 .37752 L p .654 .754 .923 r
F P
0 g
s
.3278 .35993 m .34522 .37752 L .34379 .40368 L p .959 .688 .477 r
F P
0 g
s
.37314 .36804 m .34522 .37752 L .3278 .35993 L p .654 .754 .923 r
F P
0 g
s
.3278 .35993 m .34522 .37752 L .34379 .40368 L p .959 .688 .477 r
F P
0 g
s
.66577 .33631 m .65143 .31832 L .65042 .29279 L p .976 .68 .386 r
F P
0 g
s
.66577 .33631 m .65143 .31832 L .65042 .29279 L p .976 .68 .386 r
F P
0 g
s
.69537 .32661 m .66577 .33631 L .65143 .31832 L p .656 .751 .92 r
F P
0 g
s
.62193 .32811 m .65143 .31832 L .66577 .33631 L p .656 .751 .92 r
F P
0 g
s
.62193 .32811 m .65143 .31832 L .66577 .33631 L p .656 .751 .92 r
F P
0 g
s
.65143 .31832 m .66577 .33631 L .6669 .36215 L p .976 .68 .386 r
F P
0 g
s
.53309 .31149 m .53302 .28592 L .50427 .29583 L p .526 .299 .513 r
F P
0 g
s
.50427 .29583 m .5041 .32134 L .53309 .31149 L p .526 .299 .513 r
F P
0 g
s
.53302 .28592 m .50427 .29583 L .48837 .27745 L p .658 .749 .917 r
F P
0 g
s
.53309 .31149 m .53302 .28592 L .50427 .29583 L p .526 .299 .513 r
F P
0 g
s
.50427 .29583 m .5041 .32134 L .53309 .31149 L p .526 .299 .513 r
F P
0 g
s
.45972 .28745 m .48837 .27745 L .50427 .29583 L p .658 .749 .917 r
F P
0 g
s
.48837 .27745 m .50427 .29583 L .5041 .32134 L p .971 .686 .432 r
F P
0 g
s
.48837 .27745 m .50427 .29583 L .5041 .32134 L p .971 .686 .432 r
F P
0 g
s
.36944 .27047 m .37068 .24523 L .34276 .25535 L p .514 .281 .5 r
F P
0 g
s
.34276 .25535 m .3413 .28054 L .36944 .27047 L p .514 .281 .5 r
F P
0 g
s
.57966 .41657 m .56448 .39934 L .56416 .37316 L p .972 .685 .422 r
F P
0 g
s
.57966 .41657 m .56448 .39934 L .56416 .37316 L p .972 .685 .422 r
F P
0 g
s
.60882 .40728 m .57966 .41657 L .56448 .39934 L p .652 .756 .926 r
F P
0 g
s
.60949 .43383 m .60882 .40728 L .57966 .41657 L p .537 .315 .524 r
F P
0 g
s
.57966 .41657 m .5801 .44306 L .60949 .43383 L p .537 .315 .524 r
F P
0 g
s
.53542 .40871 m .56448 .39934 L .57966 .41657 L p .652 .756 .926 r
F P
0 g
s
.56448 .39934 m .57966 .41657 L .5801 .44306 L p .972 .685 .422 r
F P
0 g
s
.60882 .40728 m .57966 .41657 L .56448 .39934 L p .652 .756 .926 r
F P
0 g
s
.44578 .3928 m .44641 .36657 L .41809 .37607 L p .526 .299 .513 r
F P
0 g
s
.41809 .37607 m .41723 .40223 L .44578 .3928 L p .526 .299 .513 r
F P
0 g
s
.44641 .36657 m .41809 .37607 L .40135 .35845 L p .654 .754 .923 r
F P
0 g
s
.44578 .3928 m .44641 .36657 L .41809 .37607 L p .526 .299 .513 r
F P
0 g
s
.41809 .37607 m .41723 .40223 L .44578 .3928 L p .526 .299 .513 r
F P
0 g
s
.37314 .36804 m .40135 .35845 L .41809 .37607 L p .654 .754 .923 r
F P
0 g
s
.40135 .35845 m .41809 .37607 L .41723 .40223 L p .964 .688 .461 r
F P
0 g
s
.40135 .35845 m .41809 .37607 L .41723 .40223 L p .964 .688 .461 r
F P
0 g
s
.21086 .32736 m .23822 .31756 L .25651 .33557 L p .656 .751 .92 r
F P
0 g
s
.25651 .33557 m .23822 .31756 L .2405 .29203 L p .954 .688 .492 r
F P
0 g
s
.2865 .44869 m .31427 .43952 L .33184 .45637 L p .649 .759 .929 r
F P
0 g
s
.33184 .45637 m .31427 .43952 L .31594 .41301 L p .957 .688 .485 r
F P
0 g
s
.69537 .32661 m .72527 .31681 L .73892 .33483 L p .656 .751 .92 r
F P
0 g
s
.72527 .31681 m .73892 .33483 L .74064 .36067 L p .976 .675 .358 r
F P
0 g
s
.6071 .30996 m .60644 .28438 L .57729 .29431 L p .53 .304 .517 r
F P
0 g
s
.57729 .29431 m .57771 .31983 L .6071 .30996 L p .53 .304 .517 r
F P
0 g
s
.60644 .28438 m .57729 .29431 L .56208 .2759 L p .658 .749 .917 r
F P
0 g
s
.6071 .30996 m .60644 .28438 L .57729 .29431 L p .53 .304 .517 r
F P
0 g
s
.57729 .29431 m .57771 .31983 L .6071 .30996 L p .53 .304 .517 r
F P
0 g
s
.53302 .28592 m .56208 .2759 L .57729 .29431 L p .658 .749 .917 r
F P
0 g
s
.56208 .2759 m .57729 .29431 L .57771 .31983 L p .974 .684 .41 r
F P
0 g
s
.56208 .2759 m .57729 .29431 L .57771 .31983 L p .974 .684 .41 r
F P
0 g
s
.44332 .26891 m .44397 .24366 L .41565 .2538 L p .518 .287 .504 r
F P
0 g
s
.41565 .2538 m .41478 .279 L .44332 .26891 L p .518 .287 .504 r
F P
0 g
s
.37068 .24523 m .39888 .235 L .41565 .2538 L p .66 .747 .915 r
F P
0 g
s
.39888 .235 m .41565 .2538 L .41478 .279 L p .966 .687 .452 r
F P
0 g
s
.6836 .4324 m .68233 .40584 L .65277 .41514 L p .541 .319 .528 r
F P
0 g
s
.65277 .41514 m .65379 .44164 L .6836 .4324 L p .541 .319 .528 r
F P
0 g
s
.68233 .40584 m .65277 .41514 L .63828 .39789 L p .652 .756 .926 r
F P
0 g
s
.6836 .4324 m .68233 .40584 L .65277 .41514 L p .541 .319 .528 r
F P
0 g
s
.65277 .41514 m .65379 .44164 L .6836 .4324 L p .541 .319 .528 r
F P
0 g
s
.63828 .39789 m .65277 .41514 L .65379 .44164 L p .975 .682 .398 r
F P
0 g
s
.51975 .39133 m .51979 .3651 L .49107 .37461 L p .53 .304 .517 r
F P
0 g
s
.49107 .37461 m .4908 .40079 L .51975 .39133 L p .53 .304 .517 r
F P
0 g
s
.49107 .37461 m .47502 .35697 L .47542 .3311 L p .969 .687 .442 r
F P
0 g
s
.51979 .3651 m .49107 .37461 L .47502 .35697 L p .654 .754 .923 r
F P
0 g
s
.51975 .39133 m .51979 .3651 L .49107 .37461 L p .53 .304 .517 r
F P
0 g
s
.49107 .37461 m .4908 .40079 L .51975 .39133 L p .53 .304 .517 r
F P
0 g
s
.44641 .36657 m .47502 .35697 L .49107 .37461 L p .654 .754 .923 r
F P
0 g
s
.47502 .35697 m .49107 .37461 L .4908 .40079 L p .969 .687 .442 r
F P
0 g
s
.51979 .3651 m .49107 .37461 L .47502 .35697 L p .654 .754 .923 r
F P
0 g
s
.47502 .35697 m .49107 .37461 L .4908 .40079 L p .969 .687 .442 r
F P
0 g
s
.3559 .35027 m .35725 .32436 L .32936 .33408 L p .518 .287 .504 r
F P
0 g
s
.32936 .33408 m .3278 .35993 L .3559 .35027 L p .518 .287 .504 r
F P
0 g
s
.40478 .45498 m .3879 .4381 L .38898 .41158 L p .962 .688 .469 r
F P
0 g
s
.40478 .45498 m .3879 .4381 L .38898 .41158 L p .962 .688 .469 r
F P
0 g
s
.43306 .44588 m .40478 .45498 L .3879 .4381 L p .649 .759 .929 r
F P
0 g
s
.35972 .44728 m .3879 .4381 L .40478 .45498 L p .649 .759 .929 r
F P
0 g
s
.68123 .30843 m .67998 .28285 L .65042 .29279 L p .534 .309 .521 r
F P
0 g
s
.65042 .29279 m .65143 .31832 L .68123 .30843 L p .534 .309 .521 r
F P
0 g
s
.65042 .29279 m .63591 .27435 L .63502 .24913 L p .976 .68 .386 r
F P
0 g
s
.67998 .28285 m .65042 .29279 L .63591 .27435 L p .658 .749 .917 r
F P
0 g
s
.68123 .30843 m .67998 .28285 L .65042 .29279 L p .534 .309 .521 r
F P
0 g
s
.65042 .29279 m .65143 .31832 L .68123 .30843 L p .534 .309 .521 r
F P
0 g
s
.60644 .28438 m .63591 .27435 L .65042 .29279 L p .658 .749 .917 r
F P
0 g
s
.63591 .27435 m .65042 .29279 L .65143 .31832 L p .976 .68 .386 r
F P
0 g
s
.67998 .28285 m .65042 .29279 L .63591 .27435 L p .658 .749 .917 r
F P
0 g
s
.63591 .27435 m .65042 .29279 L .65143 .31832 L p .976 .68 .386 r
F P
0 g
s
.51738 .24209 m .48866 .25224 L .47258 .23342 L p .66 .747 .915 r
F P
0 g
s
.51732 .26735 m .51738 .24209 L .48866 .25224 L p .522 .293 .509 r
F P
0 g
s
.48866 .25224 m .48837 .27745 L .51732 .26735 L p .522 .293 .509 r
F P
0 g
s
.44397 .24366 m .47258 .23342 L .48866 .25224 L p .66 .747 .915 r
F P
0 g
s
.47258 .23342 m .48866 .25224 L .48837 .27745 L p .971 .686 .432 r
F P
0 g
s
.47258 .23342 m .48866 .25224 L .48837 .27745 L p .971 .686 .432 r
F P
0 g
s
.59384 .38987 m .59329 .36363 L .56416 .37316 L p .534 .309 .521 r
F P
0 g
s
.56416 .37316 m .56448 .39934 L .59384 .38987 L p .534 .309 .521 r
F P
0 g
s
.56416 .37316 m .54881 .35548 L .54862 .32961 L p .972 .685 .422 r
F P
0 g
s
.56416 .37316 m .54881 .35548 L .54862 .32961 L p .972 .685 .422 r
F P
0 g
s
.59329 .36363 m .56416 .37316 L .54881 .35548 L p .654 .754 .923 r
F P
0 g
s
.51979 .3651 m .54881 .35548 L .56416 .37316 L p .654 .754 .923 r
F P
0 g
s
.40233 .33259 m .38542 .31453 L .38653 .28898 L p .964 .688 .461 r
F P
0 g
s
.43062 .32285 m .40233 .33259 L .38542 .31453 L p .656 .751 .92 r
F P
0 g
s
.42986 .34877 m .43062 .32285 L .40233 .33259 L p .522 .293 .509 r
F P
0 g
s
.40233 .33259 m .40135 .35845 L .42986 .34877 L p .522 .293 .509 r
F P
0 g
s
.35725 .32436 m .38542 .31453 L .40233 .33259 L p .656 .751 .92 r
F P
0 g
s
.38542 .31453 m .40233 .33259 L .40135 .35845 L p .964 .688 .461 r
F P
0 g
s
.43062 .32285 m .40233 .33259 L .38542 .31453 L p .656 .751 .92 r
F P
0 g
s
.38542 .31453 m .40233 .33259 L .40135 .35845 L p .964 .688 .461 r
F P
0 g
s
.2405 .29203 m .22203 .27358 L .22444 .24835 L p .954 .688 .492 r
F P
0 g
s
.2405 .29203 m .22203 .27358 L .22444 .24835 L p .954 .688 .492 r
F P
0 g
s
.26794 .28208 m .2405 .29203 L .22203 .27358 L p .658 .749 .917 r
F P
0 g
s
.19471 .28362 m .22203 .27358 L .2405 .29203 L p .658 .749 .917 r
F P
0 g
s
.72599 .41372 m .7122 .39644 L .7107 .37023 L p .976 .678 .372 r
F P
0 g
s
.72599 .41372 m .7122 .39644 L .7107 .37023 L p .976 .678 .372 r
F P
0 g
s
.75596 .4044 m .72599 .41372 L .7122 .39644 L p .652 .756 .926 r
F P
0 g
s
.68233 .40584 m .7122 .39644 L .72599 .41372 L p .652 .756 .926 r
F P
0 g
s
.68233 .40584 m .7122 .39644 L .72599 .41372 L p .652 .756 .926 r
F P
0 g
s
.7122 .39644 m .72599 .41372 L .72761 .44023 L p .976 .678 .372 r
F P
0 g
s
.43306 .44588 m .46164 .43668 L .47783 .45358 L p .649 .759 .929 r
F P
0 g
s
.47783 .45358 m .46164 .43668 L .46214 .41015 L p .966 .687 .452 r
F P
0 g
s
.31594 .41301 m .29819 .39571 L .29999 .3695 L p .957 .688 .485 r
F P
0 g
s
.31594 .41301 m .29819 .39571 L .29999 .3695 L p .957 .688 .485 r
F P
0 g
s
.34379 .40368 m .31594 .41301 L .29819 .39571 L p .652 .756 .926 r
F P
0 g
s
.27046 .40512 m .29819 .39571 L .31594 .41301 L p .652 .756 .926 r
F P
0 g
s
.5909 .24052 m .56178 .25069 L .5464 .23183 L p .66 .747 .915 r
F P
0 g
s
.59144 .26578 m .5909 .24052 L .56178 .25069 L p .526 .299 .513 r
F P
0 g
s
.56178 .25069 m .56208 .2759 L .59144 .26578 L p .526 .299 .513 r
F P
0 g
s
.51738 .24209 m .5464 .23183 L .56178 .25069 L p .66 .747 .915 r
F P
0 g
s
.5464 .23183 m .56178 .25069 L .56208 .2759 L p .974 .684 .41 r
F P
0 g
s
.5464 .23183 m .56178 .25069 L .56208 .2759 L p .974 .684 .41 r
F P
0 g
s
.63737 .3717 m .62272 .354 L .62193 .32811 L p .975 .682 .398 r
F P
0 g
s
.63737 .3717 m .62272 .354 L .62193 .32811 L p .975 .682 .398 r
F P
0 g
s
.6669 .36215 m .63737 .3717 L .62272 .354 L p .654 .754 .923 r
F P
0 g
s
.66805 .38841 m .6669 .36215 L .63737 .3717 L p .537 .315 .524 r
F P
0 g
s
.63737 .3717 m .63828 .39789 L .66805 .38841 L p .537 .315 .524 r
F P
0 g
s
.59329 .36363 m .62272 .354 L .63737 .3717 L p .654 .754 .923 r
F P
0 g
s
.62272 .354 m .63737 .3717 L .63828 .39789 L p .975 .682 .398 r
F P
0 g
s
.6669 .36215 m .63737 .3717 L .62272 .354 L p .654 .754 .923 r
F P
0 g
s
.50394 .34727 m .5041 .32134 L .47542 .3311 L p .526 .299 .513 r
F P
0 g
s
.47542 .3311 m .47502 .35697 L .50394 .34727 L p .526 .299 .513 r
F P
0 g
s
.47542 .3311 m .4592 .31301 L .45972 .28745 L p .969 .687 .442 r
F P
0 g
s
.47542 .3311 m .4592 .31301 L .45972 .28745 L p .969 .687 .442 r
F P
0 g
s
.5041 .32134 m .47542 .3311 L .4592 .31301 L p .656 .751 .92 r
F P
0 g
s
.43062 .32285 m .4592 .31301 L .47542 .3311 L p .656 .751 .92 r
F P
0 g
s
.43062 .32285 m .4592 .31301 L .47542 .3311 L p .656 .751 .92 r
F P
0 g
s
.4592 .31301 m .47542 .3311 L .47502 .35697 L p .969 .687 .442 r
F P
0 g
s
.50652 .44447 m .53551 .43526 L .55101 .45219 L p .649 .759 .929 r
F P
0 g
s
.55101 .45219 m .53551 .43526 L .53542 .40871 L p .971 .686 .432 r
F P
0 g
s
.41637 .42882 m .41723 .40223 L .38898 .41158 L p .526 .299 .513 r
F P
0 g
s
.38898 .41158 m .3879 .4381 L .41637 .42882 L p .526 .299 .513 r
F P
0 g
s
.38898 .41158 m .37192 .39425 L .37314 .36804 L p .962 .688 .469 r
F P
0 g
s
.38898 .41158 m .37192 .39425 L .37314 .36804 L p .962 .688 .469 r
F P
0 g
s
.41723 .40223 m .38898 .41158 L .37192 .39425 L p .652 .756 .926 r
F P
0 g
s
.41637 .42882 m .41723 .40223 L .38898 .41158 L p .526 .299 .513 r
F P
0 g
s
.38898 .41158 m .3879 .4381 L .41637 .42882 L p .526 .299 .513 r
F P
0 g
s
.34379 .40368 m .37192 .39425 L .38898 .41158 L p .652 .756 .926 r
F P
0 g
s
.37192 .39425 m .38898 .41158 L .3879 .4381 L p .962 .688 .469 r
F P
0 g
s
.41723 .40223 m .38898 .41158 L .37192 .39425 L p .652 .756 .926 r
F P
0 g
s
.66568 .26422 m .66455 .23894 L .63502 .24913 L p .53 .304 .517 r
F P
0 g
s
.63502 .24913 m .63591 .27435 L .66568 .26422 L p .53 .304 .517 r
F P
0 g
s
.5909 .24052 m .62033 .23024 L .63502 .24913 L p .66 .747 .915 r
F P
0 g
s
.62033 .23024 m .63502 .24913 L .63591 .27435 L p .976 .68 .386 r
F P
0 g
s
.74238 .38694 m .74064 .36067 L .7107 .37023 L p .541 .319 .528 r
F P
0 g
s
.7107 .37023 m .7122 .39644 L .74238 .38694 L p .541 .319 .528 r
F P
0 g
s
.7107 .37023 m .69674 .35251 L .69537 .32661 L p .976 .678 .372 r
F P
0 g
s
.74064 .36067 m .7107 .37023 L .69674 .35251 L p .654 .754 .923 r
F P
0 g
s
.74238 .38694 m .74064 .36067 L .7107 .37023 L p .541 .319 .528 r
F P
0 g
s
.7107 .37023 m .7122 .39644 L .74238 .38694 L p .541 .319 .528 r
F P
0 g
s
.6669 .36215 m .69674 .35251 L .7107 .37023 L p .654 .754 .923 r
F P
0 g
s
.69674 .35251 m .7107 .37023 L .7122 .39644 L p .976 .678 .372 r
F P
0 g
s
.74064 .36067 m .7107 .37023 L .69674 .35251 L p .654 .754 .923 r
F P
0 g
s
.69674 .35251 m .7107 .37023 L .7122 .39644 L p .976 .678 .372 r
F P
0 g
s
.57814 .34577 m .57771 .31983 L .54862 .32961 L p .53 .304 .517 r
F P
0 g
s
.54862 .32961 m .54881 .35548 L .57814 .34577 L p .53 .304 .517 r
F P
0 g
s
.54862 .32961 m .53309 .31149 L .53302 .28592 L p .972 .685 .422 r
F P
0 g
s
.54862 .32961 m .53309 .31149 L .53302 .28592 L p .972 .685 .422 r
F P
0 g
s
.57771 .31983 m .54862 .32961 L .53309 .31149 L p .656 .751 .92 r
F P
0 g
s
.57814 .34577 m .57771 .31983 L .54862 .32961 L p .53 .304 .517 r
F P
0 g
s
.54862 .32961 m .54881 .35548 L .57814 .34577 L p .53 .304 .517 r
F P
0 g
s
.5041 .32134 m .53309 .31149 L .54862 .32961 L p .656 .751 .92 r
F P
0 g
s
.5041 .32134 m .53309 .31149 L .54862 .32961 L p .656 .751 .92 r
F P
0 g
s
.53309 .31149 m .54862 .32961 L .54881 .35548 L p .972 .685 .422 r
F P
0 g
s
.57771 .31983 m .54862 .32961 L .53309 .31149 L p .656 .751 .92 r
F P
0 g
s
.53309 .31149 m .54862 .32961 L .54881 .35548 L p .972 .685 .422 r
F P
0 g
s
.41389 .3046 m .41478 .279 L .38653 .28898 L p .518 .287 .504 r
F P
0 g
s
.38653 .28898 m .38542 .31453 L .41389 .3046 L p .518 .287 .504 r
F P
0 g
s
.38653 .28898 m .36944 .27047 L .37068 .24523 L p .964 .688 .461 r
F P
0 g
s
.38653 .28898 m .36944 .27047 L .37068 .24523 L p .964 .688 .461 r
F P
0 g
s
.41478 .279 m .38653 .28898 L .36944 .27047 L p .658 .749 .917 r
F P
0 g
s
.3413 .28054 m .36944 .27047 L .38653 .28898 L p .658 .749 .917 r
F P
0 g
s
.24964 .26343 m .25184 .23816 L .22444 .24835 L p .504 .268 .49 r
F P
0 g
s
.22444 .24835 m .22203 .27358 L .24964 .26343 L p .504 .268 .49 r
F P
0 g
s
.46214 .41015 m .44578 .3928 L .44641 .36657 L p .966 .687 .452 r
F P
0 g
s
.46214 .41015 m .44578 .3928 L .44641 .36657 L p .966 .687 .452 r
F P
0 g
s
.4908 .40079 m .46214 .41015 L .44578 .3928 L p .652 .756 .926 r
F P
0 g
s
.41723 .40223 m .44578 .3928 L .46214 .41015 L p .652 .756 .926 r
F P
0 g
s
.41723 .40223 m .44578 .3928 L .46214 .41015 L p .652 .756 .926 r
F P
0 g
s
.44578 .3928 m .46214 .41015 L .46164 .43668 L p .966 .687 .452 r
F P
0 g
s
.32621 .3862 m .3278 .35993 L .29999 .3695 L p .518 .287 .504 r
F P
0 g
s
.29999 .3695 m .29819 .39571 L .32621 .3862 L p .518 .287 .504 r
F P
0 g
s
.65245 .34426 m .65143 .31832 L .62193 .32811 L p .534 .309 .521 r
F P
0 g
s
.62193 .32811 m .62272 .354 L .65245 .34426 L p .534 .309 .521 r
F P
0 g
s
.62193 .32811 m .6071 .30996 L .60644 .28438 L p .975 .682 .398 r
F P
0 g
s
.62193 .32811 m .6071 .30996 L .60644 .28438 L p .975 .682 .398 r
F P
0 g
s
.65143 .31832 m .62193 .32811 L .6071 .30996 L p .656 .751 .92 r
F P
0 g
s
.65245 .34426 m .65143 .31832 L .62193 .32811 L p .534 .309 .521 r
F P
0 g
s
.62193 .32811 m .62272 .354 L .65245 .34426 L p .534 .309 .521 r
F P
0 g
s
.57771 .31983 m .6071 .30996 L .62193 .32811 L p .656 .751 .92 r
F P
0 g
s
.57771 .31983 m .6071 .30996 L .62193 .32811 L p .656 .751 .92 r
F P
0 g
s
.6071 .30996 m .62193 .32811 L .62272 .354 L p .975 .682 .398 r
F P
0 g
s
.65143 .31832 m .62193 .32811 L .6071 .30996 L p .656 .751 .92 r
F P
0 g
s
.6071 .30996 m .62193 .32811 L .62272 .354 L p .975 .682 .398 r
F P
0 g
s
.48807 .30306 m .48837 .27745 L .45972 .28745 L p .522 .293 .509 r
F P
0 g
s
.45972 .28745 m .4592 .31301 L .48807 .30306 L p .522 .293 .509 r
F P
0 g
s
.45972 .28745 m .44332 .26891 L .44397 .24366 L p .969 .687 .442 r
F P
0 g
s
.45972 .28745 m .44332 .26891 L .44397 .24366 L p .969 .687 .442 r
F P
0 g
s
.48837 .27745 m .45972 .28745 L .44332 .26891 L p .658 .749 .917 r
F P
0 g
s
.48807 .30306 m .48837 .27745 L .45972 .28745 L p .522 .293 .509 r
F P
0 g
s
.45972 .28745 m .4592 .31301 L .48807 .30306 L p .522 .293 .509 r
F P
0 g
s
.41478 .279 m .44332 .26891 L .45972 .28745 L p .658 .749 .917 r
F P
0 g
s
.41478 .279 m .44332 .26891 L .45972 .28745 L p .658 .749 .917 r
F P
0 g
s
.44332 .26891 m .45972 .28745 L .4592 .31301 L p .969 .687 .442 r
F P
0 g
s
.48837 .27745 m .45972 .28745 L .44332 .26891 L p .658 .749 .917 r
F P
0 g
s
.44332 .26891 m .45972 .28745 L .4592 .31301 L p .969 .687 .442 r
F P
0 g
s
.6977 .44939 m .6836 .4324 L .68233 .40584 L p .976 .68 .386 r
F P
0 g
s
.6977 .44939 m .6836 .4324 L .68233 .40584 L p .976 .68 .386 r
F P
0 g
s
.72761 .44023 m .6977 .44939 L .6836 .4324 L p .649 .759 .929 r
F P
0 g
s
.65379 .44164 m .6836 .4324 L .6977 .44939 L p .649 .759 .929 r
F P
0 g
s
.4908 .40079 m .51975 .39133 L .53542 .40871 L p .652 .756 .926 r
F P
0 g
s
.4908 .40079 m .51975 .39133 L .53542 .40871 L p .652 .756 .926 r
F P
0 g
s
.51975 .39133 m .53542 .40871 L .53551 .43526 L p .971 .686 .432 r
F P
0 g
s
.53542 .40871 m .51975 .39133 L .51979 .3651 L p .971 .686 .432 r
F P
0 g
s
.40036 .38473 m .40135 .35845 L .37314 .36804 L p .522 .293 .509 r
F P
0 g
s
.37314 .36804 m .37192 .39425 L .40036 .38473 L p .522 .293 .509 r
F P
0 g
s
.37314 .36804 m .3559 .35027 L .35725 .32436 L p .962 .688 .469 r
F P
0 g
s
.37314 .36804 m .3559 .35027 L .35725 .32436 L p .962 .688 .469 r
F P
0 g
s
.40135 .35845 m .37314 .36804 L .3559 .35027 L p .654 .754 .923 r
F P
0 g
s
.40036 .38473 m .40135 .35845 L .37314 .36804 L p .522 .293 .509 r
F P
0 g
s
.37314 .36804 m .37192 .39425 L .40036 .38473 L p .522 .293 .509 r
F P
0 g
s
.3278 .35993 m .3559 .35027 L .37314 .36804 L p .654 .754 .923 r
F P
0 g
s
.3278 .35993 m .3559 .35027 L .37314 .36804 L p .654 .754 .923 r
F P
0 g
s
.3559 .35027 m .37314 .36804 L .37192 .39425 L p .962 .688 .469 r
F P
0 g
s
.40135 .35845 m .37314 .36804 L .3559 .35027 L p .654 .754 .923 r
F P
0 g
s
.3559 .35027 m .37314 .36804 L .37192 .39425 L p .962 .688 .469 r
F P
0 g
s
.72689 .34276 m .72527 .31681 L .69537 .32661 L p .537 .315 .524 r
F P
0 g
s
.69537 .32661 m .69674 .35251 L .72689 .34276 L p .537 .315 .524 r
F P
0 g
s
.69537 .32661 m .68123 .30843 L .67998 .28285 L p .976 .678 .372 r
F P
0 g
s
.72527 .31681 m .69537 .32661 L .68123 .30843 L p .656 .751 .92 r
F P
0 g
s
.72689 .34276 m .72527 .31681 L .69537 .32661 L p .537 .315 .524 r
F P
0 g
s
.69537 .32661 m .69674 .35251 L .72689 .34276 L p .537 .315 .524 r
F P
0 g
s
.65143 .31832 m .68123 .30843 L .69537 .32661 L p .656 .751 .92 r
F P
0 g
s
.68123 .30843 m .69537 .32661 L .69674 .35251 L p .976 .678 .372 r
F P
0 g
s
.56238 .30152 m .56208 .2759 L .53302 .28592 L p .526 .299 .513 r
F P
0 g
s
.53302 .28592 m .53309 .31149 L .56238 .30152 L p .526 .299 .513 r
F P
0 g
s
.53302 .28592 m .51732 .26735 L .51738 .24209 L p .972 .685 .422 r
F P
0 g
s
.56208 .2759 m .53302 .28592 L .51732 .26735 L p .658 .749 .917 r
F P
0 g
s
.56238 .30152 m .56208 .2759 L .53302 .28592 L p .526 .299 .513 r
F P
0 g
s
.53302 .28592 m .53309 .31149 L .56238 .30152 L p .526 .299 .513 r
F P
0 g
s
.48837 .27745 m .51732 .26735 L .53302 .28592 L p .658 .749 .917 r
F P
0 g
s
.51732 .26735 m .53302 .28592 L .53309 .31149 L p .972 .685 .422 r
F P
0 g
s
.56208 .2759 m .53302 .28592 L .51732 .26735 L p .658 .749 .917 r
F P
0 g
s
.51732 .26735 m .53302 .28592 L .53309 .31149 L p .972 .685 .422 r
F P
0 g
s
.39787 .26029 m .39888 .235 L .37068 .24523 L p .514 .281 .5 r
F P
0 g
s
.37068 .24523 m .36944 .27047 L .39787 .26029 L p .514 .281 .5 r
F P
0 g
s
.60882 .40728 m .59384 .38987 L .59329 .36363 L p .974 .684 .41 r
F P
0 g
s
.63828 .39789 m .60882 .40728 L .59384 .38987 L p .652 .756 .926 r
F P
0 g
s
.6392 .42451 m .63828 .39789 L .60882 .40728 L p .537 .315 .524 r
F P
0 g
s
.60882 .40728 m .60949 .43383 L .6392 .42451 L p .537 .315 .524 r
F P
0 g
s
.56448 .39934 m .59384 .38987 L .60882 .40728 L p .652 .756 .926 r
F P
0 g
s
.56448 .39934 m .59384 .38987 L .60882 .40728 L p .652 .756 .926 r
F P
0 g
s
.59384 .38987 m .60882 .40728 L .60949 .43383 L p .974 .684 .41 r
F P
0 g
s
.59384 .38987 m .60882 .40728 L .60949 .43383 L p .974 .684 .41 r
F P
0 g
s
.47462 .38326 m .47502 .35697 L .44641 .36657 L p .526 .299 .513 r
F P
0 g
s
.44641 .36657 m .44578 .3928 L .47462 .38326 L p .526 .299 .513 r
F P
0 g
s
.44641 .36657 m .42986 .34877 L .43062 .32285 L p .966 .687 .452 r
F P
0 g
s
.47502 .35697 m .44641 .36657 L .42986 .34877 L p .654 .754 .923 r
F P
0 g
s
.47462 .38326 m .47502 .35697 L .44641 .36657 L p .526 .299 .513 r
F P
0 g
s
.44641 .36657 m .44578 .3928 L .47462 .38326 L p .526 .299 .513 r
F P
0 g
s
.40135 .35845 m .42986 .34877 L .44641 .36657 L p .654 .754 .923 r
F P
0 g
s
.42986 .34877 m .44641 .36657 L .44578 .3928 L p .966 .687 .452 r
F P
0 g
s
.47502 .35697 m .44641 .36657 L .42986 .34877 L p .654 .754 .923 r
F P
0 g
s
.42986 .34877 m .44641 .36657 L .44578 .3928 L p .966 .687 .452 r
F P
0 g
s
.63681 .29998 m .63591 .27435 L .60644 .28438 L p .53 .304 .517 r
F P
0 g
s
.60644 .28438 m .6071 .30996 L .63681 .29998 L p .53 .304 .517 r
F P
0 g
s
.60644 .28438 m .59144 .26578 L .5909 .24052 L p .975 .682 .398 r
F P
0 g
s
.63591 .27435 m .60644 .28438 L .59144 .26578 L p .658 .749 .917 r
F P
0 g
s
.63681 .29998 m .63591 .27435 L .60644 .28438 L p .53 .304 .517 r
F P
0 g
s
.60644 .28438 m .6071 .30996 L .63681 .29998 L p .53 .304 .517 r
F P
0 g
s
.56208 .2759 m .59144 .26578 L .60644 .28438 L p .658 .749 .917 r
F P
0 g
s
.59144 .26578 m .60644 .28438 L .6071 .30996 L p .975 .682 .398 r
F P
0 g
s
.63591 .27435 m .60644 .28438 L .59144 .26578 L p .658 .749 .917 r
F P
0 g
s
.59144 .26578 m .60644 .28438 L .6071 .30996 L p .975 .682 .398 r
F P
0 g
s
.47216 .25871 m .47258 .23342 L .44397 .24366 L p .518 .287 .504 r
F P
0 g
s
.44397 .24366 m .44332 .26891 L .47216 .25871 L p .518 .287 .504 r
F P
0 g
s
.47258 .23342 m .44397 .24366 L .42739 .22466 L p .66 .747 .915 r
F P
0 g
s
.47216 .25871 m .47258 .23342 L .44397 .24366 L p .518 .287 .504 r
F P
0 g
s
.44397 .24366 m .44332 .26891 L .47216 .25871 L p .518 .287 .504 r
F P
0 g
s
.42739 .22466 m .44397 .24366 L .44332 .26891 L p .969 .687 .442 r
F P
0 g
s
.71372 .42307 m .7122 .39644 L .68233 .40584 L p .541 .319 .528 r
F P
0 g
s
.68233 .40584 m .6836 .4324 L .71372 .42307 L p .541 .319 .528 r
F P
0 g
s
.68233 .40584 m .66805 .38841 L .6669 .36215 L p .976 .68 .386 r
F P
0 g
s
.7122 .39644 m .68233 .40584 L .66805 .38841 L p .652 .756 .926 r
F P
0 g
s
.71372 .42307 m .7122 .39644 L .68233 .40584 L p .541 .319 .528 r
F P
0 g
s
.68233 .40584 m .6836 .4324 L .71372 .42307 L p .541 .319 .528 r
F P
0 g
s
.63828 .39789 m .66805 .38841 L .68233 .40584 L p .652 .756 .926 r
F P
0 g
s
.66805 .38841 m .68233 .40584 L .6836 .4324 L p .976 .68 .386 r
F P
0 g
s
.7122 .39644 m .68233 .40584 L .66805 .38841 L p .652 .756 .926 r
F P
0 g
s
.66805 .38841 m .68233 .40584 L .6836 .4324 L p .976 .68 .386 r
F P
0 g
s
.51979 .3651 m .50394 .34727 L .5041 .32134 L p .971 .686 .432 r
F P
0 g
s
.51979 .3651 m .50394 .34727 L .5041 .32134 L p .971 .686 .432 r
F P
0 g
s
.54881 .35548 m .51979 .3651 L .50394 .34727 L p .654 .754 .923 r
F P
0 g
s
.47502 .35697 m .50394 .34727 L .51979 .3651 L p .654 .754 .923 r
F P
0 g
s
.47502 .35697 m .50394 .34727 L .51979 .3651 L p .654 .754 .923 r
F P
0 g
s
.50394 .34727 m .51979 .3651 L .51975 .39133 L p .971 .686 .432 r
F P
0 g
s
.38429 .34049 m .38542 .31453 L .35725 .32436 L p .518 .287 .504 r
F P
0 g
s
.35725 .32436 m .3559 .35027 L .38429 .34049 L p .518 .287 .504 r
F P
0 g
s
.43306 .44588 m .41637 .42882 L .41723 .40223 L p .964 .688 .461 r
F P
0 g
s
.43306 .44588 m .41637 .42882 L .41723 .40223 L p .964 .688 .461 r
F P
0 g
s
.46164 .43668 m .43306 .44588 L .41637 .42882 L p .649 .759 .929 r
F P
0 g
s
.3879 .4381 m .41637 .42882 L .43306 .44588 L p .649 .759 .929 r
F P
0 g
s
.63591 .27435 m .66568 .26422 L .67998 .28285 L p .658 .749 .917 r
F P
0 g
s
.63591 .27435 m .66568 .26422 L .67998 .28285 L p .658 .749 .917 r
F P
0 g
s
.66568 .26422 m .67998 .28285 L .68123 .30843 L p .976 .678 .372 r
F P
0 g
s
.67998 .28285 m .66568 .26422 L .66455 .23894 L p .976 .678 .372 r
F P
0 g
s
.54657 .25713 m .5464 .23183 L .51738 .24209 L p .522 .293 .509 r
F P
0 g
s
.51738 .24209 m .51732 .26735 L .54657 .25713 L p .522 .293 .509 r
F P
0 g
s
.47258 .23342 m .5015 .22306 L .51738 .24209 L p .66 .747 .915 r
F P
0 g
s
.5015 .22306 m .51738 .24209 L .51732 .26735 L p .972 .685 .422 r
F P
0 g
s
.7122 .39644 m .74238 .38694 L .75596 .4044 L p .652 .756 .926 r
F P
0 g
s
.75596 .4044 m .74238 .38694 L .74064 .36067 L p .976 .675 .358 r
F P
0 g
s
.59329 .36363 m .57814 .34577 L .57771 .31983 L p .974 .684 .41 r
F P
0 g
s
.59329 .36363 m .57814 .34577 L .57771 .31983 L p .974 .684 .41 r
F P
0 g
s
.62272 .354 m .59329 .36363 L .57814 .34577 L p .654 .754 .923 r
F P
0 g
s
.62351 .3803 m .62272 .354 L .59329 .36363 L p .534 .309 .521 r
F P
0 g
s
.59329 .36363 m .59384 .38987 L .62351 .3803 L p .534 .309 .521 r
F P
0 g
s
.54881 .35548 m .57814 .34577 L .59329 .36363 L p .654 .754 .923 r
F P
0 g
s
.57814 .34577 m .59329 .36363 L .59384 .38987 L p .974 .684 .41 r
F P
0 g
s
.62272 .354 m .59329 .36363 L .57814 .34577 L p .654 .754 .923 r
F P
0 g
s
.45867 .33898 m .4592 .31301 L .43062 .32285 L p .522 .293 .509 r
F P
0 g
s
.43062 .32285 m .42986 .34877 L .45867 .33898 L p .522 .293 .509 r
F P
0 g
s
.43062 .32285 m .41389 .3046 L .41478 .279 L p .966 .687 .452 r
F P
0 g
s
.43062 .32285 m .41389 .3046 L .41478 .279 L p .966 .687 .452 r
F P
0 g
s
.4592 .31301 m .43062 .32285 L .41389 .3046 L p .656 .751 .92 r
F P
0 g
s
.45867 .33898 m .4592 .31301 L .43062 .32285 L p .522 .293 .509 r
F P
0 g
s
.43062 .32285 m .42986 .34877 L .45867 .33898 L p .522 .293 .509 r
F P
0 g
s
.38542 .31453 m .41389 .3046 L .43062 .32285 L p .656 .751 .92 r
F P
0 g
s
.38542 .31453 m .41389 .3046 L .43062 .32285 L p .656 .751 .92 r
F P
0 g
s
.41389 .3046 m .43062 .32285 L .42986 .34877 L p .966 .687 .452 r
F P
0 g
s
.4592 .31301 m .43062 .32285 L .41389 .3046 L p .656 .751 .92 r
F P
0 g
s
.41389 .3046 m .43062 .32285 L .42986 .34877 L p .966 .687 .452 r
F P
0 g
s
.22203 .27358 m .24964 .26343 L .26794 .28208 L p .658 .749 .917 r
F P
0 g
s
.26794 .28208 m .24964 .26343 L .25184 .23816 L p .957 .688 .485 r
F P
0 g
s
.50652 .44447 m .49052 .42739 L .4908 .40079 L p .969 .687 .442 r
F P
0 g
s
.53551 .43526 m .50652 .44447 L .49052 .42739 L p .649 .759 .929 r
F P
0 g
s
.34379 .40368 m .32621 .3862 L .3278 .35993 L p .959 .688 .477 r
F P
0 g
s
.34379 .40368 m .32621 .3862 L .3278 .35993 L p .959 .688 .477 r
F P
0 g
s
.37192 .39425 m .34379 .40368 L .32621 .3862 L p .652 .756 .926 r
F P
0 g
s
.29819 .39571 m .32621 .3862 L .34379 .40368 L p .652 .756 .926 r
F P
0 g
s
.62111 .25555 m .62033 .23024 L .5909 .24052 L p .526 .299 .513 r
F P
0 g
s
.5909 .24052 m .59144 .26578 L .62111 .25555 L p .526 .299 .513 r
F P
0 g
s
.5464 .23183 m .57572 .22146 L .5909 .24052 L p .66 .747 .915 r
F P
0 g
s
.57572 .22146 m .5909 .24052 L .59144 .26578 L p .975 .682 .398 r
F P
0 g
s
.69814 .37882 m .69674 .35251 L .6669 .36215 L p .537 .315 .524 r
F P
0 g
s
.6669 .36215 m .66805 .38841 L .69814 .37882 L p .537 .315 .524 r
F P
0 g
s
.6669 .36215 m .65245 .34426 L .65143 .31832 L p .976 .68 .386 r
F P
0 g
s
.69674 .35251 m .6669 .36215 L .65245 .34426 L p .654 .754 .923 r
F P
0 g
s
.69814 .37882 m .69674 .35251 L .6669 .36215 L p .537 .315 .524 r
F P
0 g
s
.6669 .36215 m .66805 .38841 L .69814 .37882 L p .537 .315 .524 r
F P
0 g
s
.62272 .354 m .65245 .34426 L .6669 .36215 L p .654 .754 .923 r
F P
0 g
s
.62272 .354 m .65245 .34426 L .6669 .36215 L p .654 .754 .923 r
F P
0 g
s
.65245 .34426 m .6669 .36215 L .66805 .38841 L p .976 .68 .386 r
F P
0 g
s
.65245 .34426 m .6669 .36215 L .66805 .38841 L p .976 .68 .386 r
F P
0 g
s
.53316 .33747 m .53309 .31149 L .5041 .32134 L p .526 .299 .513 r
F P
0 g
s
.5041 .32134 m .50394 .34727 L .53316 .33747 L p .526 .299 .513 r
F P
0 g
s
.5041 .32134 m .48807 .30306 L .48837 .27745 L p .971 .686 .432 r
F P
0 g
s
.5041 .32134 m .48807 .30306 L .48837 .27745 L p .971 .686 .432 r
F P
0 g
s
.53309 .31149 m .5041 .32134 L .48807 .30306 L p .656 .751 .92 r
F P
0 g
s
.4592 .31301 m .48807 .30306 L .5041 .32134 L p .656 .751 .92 r
F P
0 g
s
.5801 .44306 m .5648 .42595 L .56448 .39934 L p .972 .685 .422 r
F P
0 g
s
.60949 .43383 m .5801 .44306 L .5648 .42595 L p .649 .759 .929 r
F P
0 g
s
.44514 .41945 m .44578 .3928 L .41723 .40223 L p .526 .299 .513 r
F P
0 g
s
.41723 .40223 m .41637 .42882 L .44514 .41945 L p .526 .299 .513 r
F P
0 g
s
.41723 .40223 m .40036 .38473 L .40135 .35845 L p .964 .688 .461 r
F P
0 g
s
.41723 .40223 m .40036 .38473 L .40135 .35845 L p .964 .688 .461 r
F P
0 g
s
.44578 .3928 m .41723 .40223 L .40036 .38473 L p .652 .756 .926 r
F P
0 g
s
.44514 .41945 m .44578 .3928 L .41723 .40223 L p .526 .299 .513 r
F P
0 g
s
.41723 .40223 m .41637 .42882 L .44514 .41945 L p .526 .299 .513 r
F P
0 g
s
.37192 .39425 m .40036 .38473 L .41723 .40223 L p .652 .756 .926 r
F P
0 g
s
.37192 .39425 m .40036 .38473 L .41723 .40223 L p .652 .756 .926 r
F P
0 g
s
.40036 .38473 m .41723 .40223 L .41637 .42882 L p .964 .688 .461 r
F P
0 g
s
.44578 .3928 m .41723 .40223 L .40036 .38473 L p .652 .756 .926 r
F P
0 g
s
.40036 .38473 m .41723 .40223 L .41637 .42882 L p .964 .688 .461 r
F P
0 g
s
.69439 .22865 m .66455 .23894 L .65007 .21986 L p .66 .747 .915 r
F P
0 g
s
.69576 .25397 m .69439 .22865 L .66455 .23894 L p .53 .304 .517 r
F P
0 g
s
.66455 .23894 m .66568 .26422 L .69576 .25397 L p .53 .304 .517 r
F P
0 g
s
.65007 .21986 m .66455 .23894 L .66568 .26422 L p .976 .678 .372 r
F P
0 g
s
.69674 .35251 m .72689 .34276 L .74064 .36067 L p .654 .754 .923 r
F P
0 g
s
.69674 .35251 m .72689 .34276 L .74064 .36067 L p .654 .754 .923 r
F P
0 g
s
.72689 .34276 m .74064 .36067 L .74238 .38694 L p .976 .675 .358 r
F P
0 g
s
.74064 .36067 m .72689 .34276 L .72527 .31681 L p .976 .675 .358 r
F P
0 g
s
.60777 .33595 m .6071 .30996 L .57771 .31983 L p .53 .304 .517 r
F P
0 g
s
.57771 .31983 m .57814 .34577 L .60777 .33595 L p .53 .304 .517 r
F P
0 g
s
.57771 .31983 m .56238 .30152 L .56208 .2759 L p .974 .684 .41 r
F P
0 g
s
.57771 .31983 m .56238 .30152 L .56208 .2759 L p .974 .684 .41 r
F P
0 g
s
.6071 .30996 m .57771 .31983 L .56238 .30152 L p .656 .751 .92 r
F P
0 g
s
.60777 .33595 m .6071 .30996 L .57771 .31983 L p .53 .304 .517 r
F P
0 g
s
.57771 .31983 m .57814 .34577 L .60777 .33595 L p .53 .304 .517 r
F P
0 g
s
.53309 .31149 m .56238 .30152 L .57771 .31983 L p .656 .751 .92 r
F P
0 g
s
.53309 .31149 m .56238 .30152 L .57771 .31983 L p .656 .751 .92 r
F P
0 g
s
.56238 .30152 m .57771 .31983 L .57814 .34577 L p .974 .684 .41 r
F P
0 g
s
.6071 .30996 m .57771 .31983 L .56238 .30152 L p .656 .751 .92 r
F P
0 g
s
.56238 .30152 m .57771 .31983 L .57814 .34577 L p .974 .684 .41 r
F P
0 g
s
.44266 .29456 m .44332 .26891 L .41478 .279 L p .518 .287 .504 r
F P
0 g
s
.41478 .279 m .41389 .3046 L .44266 .29456 L p .518 .287 .504 r
F P
0 g
s
.36944 .27047 m .39787 .26029 L .41478 .279 L p .658 .749 .917 r
F P
0 g
s
.41478 .279 m .39787 .26029 L .39888 .235 L p .966 .687 .452 r
F P
0 g
s
.65379 .44164 m .6392 .42451 L .63828 .39789 L p .975 .682 .398 r
F P
0 g
s
.6836 .4324 m .65379 .44164 L .6392 .42451 L p .649 .759 .929 r
F P
0 g
s
.51971 .418 m .51975 .39133 L .4908 .40079 L p .53 .304 .517 r
F P
0 g
s
.4908 .40079 m .49052 .42739 L .51971 .418 L p .53 .304 .517 r
F P
0 g
s
.4908 .40079 m .47462 .38326 L .47502 .35697 L p .969 .687 .442 r
F P
0 g
s
.4908 .40079 m .47462 .38326 L .47502 .35697 L p .969 .687 .442 r
F P
0 g
s
.51975 .39133 m .4908 .40079 L .47462 .38326 L p .652 .756 .926 r
F P
0 g
s
.51971 .418 m .51975 .39133 L .4908 .40079 L p .53 .304 .517 r
F P
0 g
s
.4908 .40079 m .49052 .42739 L .51971 .418 L p .53 .304 .517 r
F P
0 g
s
.44578 .3928 m .47462 .38326 L .4908 .40079 L p .652 .756 .926 r
F P
0 g
s
.47462 .38326 m .4908 .40079 L .49052 .42739 L p .969 .687 .442 r
F P
0 g
s
.51975 .39133 m .4908 .40079 L .47462 .38326 L p .652 .756 .926 r
F P
0 g
s
.35453 .37659 m .3559 .35027 L .3278 .35993 L p .518 .287 .504 r
F P
0 g
s
.3278 .35993 m .32621 .3862 L .35453 .37659 L p .518 .287 .504 r
F P
0 g
s
.65143 .31832 m .63681 .29998 L .63591 .27435 L p .976 .68 .386 r
F P
0 g
s
.65143 .31832 m .63681 .29998 L .63591 .27435 L p .976 .68 .386 r
F P
0 g
s
.68123 .30843 m .65143 .31832 L .63681 .29998 L p .656 .751 .92 r
F P
0 g
s
.6071 .30996 m .63681 .29998 L .65143 .31832 L p .656 .751 .92 r
F P
0 g
s
.6071 .30996 m .63681 .29998 L .65143 .31832 L p .656 .751 .92 r
F P
0 g
s
.63681 .29998 m .65143 .31832 L .65245 .34426 L p .976 .68 .386 r
F P
0 g
s
.51726 .29301 m .51732 .26735 L .48837 .27745 L p .522 .293 .509 r
F P
0 g
s
.48837 .27745 m .48807 .30306 L .51726 .29301 L p .522 .293 .509 r
F P
0 g
s
.48837 .27745 m .47216 .25871 L .47258 .23342 L p .971 .686 .432 r
F P
0 g
s
.48837 .27745 m .47216 .25871 L .47258 .23342 L p .971 .686 .432 r
F P
0 g
s
.51732 .26735 m .48837 .27745 L .47216 .25871 L p .658 .749 .917 r
F P
0 g
s
.44332 .26891 m .47216 .25871 L .48837 .27745 L p .658 .749 .917 r
F P
0 g
s
.44332 .26891 m .47216 .25871 L .48837 .27745 L p .658 .749 .917 r
F P
0 g
s
.47216 .25871 m .48837 .27745 L .48807 .30306 L p .971 .686 .432 r
F P
0 g
s
.42909 .37511 m .42986 .34877 L .40135 .35845 L p .522 .293 .509 r
F P
0 g
s
.40135 .35845 m .40036 .38473 L .42909 .37511 L p .522 .293 .509 r
F P
0 g
s
.40135 .35845 m .38429 .34049 L .38542 .31453 L p .964 .688 .461 r
F P
0 g
s
.40135 .35845 m .38429 .34049 L .38542 .31453 L p .964 .688 .461 r
F P
0 g
s
.42986 .34877 m .40135 .35845 L .38429 .34049 L p .654 .754 .923 r
F P
0 g
s
.42909 .37511 m .42986 .34877 L .40135 .35845 L p .522 .293 .509 r
F P
0 g
s
.40135 .35845 m .40036 .38473 L .42909 .37511 L p .522 .293 .509 r
F P
0 g
s
.3559 .35027 m .38429 .34049 L .40135 .35845 L p .654 .754 .923 r
F P
0 g
s
.3559 .35027 m .38429 .34049 L .40135 .35845 L p .654 .754 .923 r
F P
0 g
s
.38429 .34049 m .40135 .35845 L .40036 .38473 L p .964 .688 .461 r
F P
0 g
s
.42986 .34877 m .40135 .35845 L .38429 .34049 L p .654 .754 .923 r
F P
0 g
s
.38429 .34049 m .40135 .35845 L .40036 .38473 L p .964 .688 .461 r
F P
0 g
s
.6836 .4324 m .71372 .42307 L .72761 .44023 L p .649 .759 .929 r
F P
0 g
s
.72761 .44023 m .71372 .42307 L .7122 .39644 L p .976 .678 .372 r
F P
0 g
s
.5944 .41654 m .59384 .38987 L .56448 .39934 L p .534 .309 .521 r
F P
0 g
s
.56448 .39934 m .5648 .42595 L .5944 .41654 L p .534 .309 .521 r
F P
0 g
s
.59384 .38987 m .56448 .39934 L .54901 .38178 L p .652 .756 .926 r
F P
0 g
s
.5944 .41654 m .59384 .38987 L .56448 .39934 L p .534 .309 .521 r
F P
0 g
s
.56448 .39934 m .5648 .42595 L .5944 .41654 L p .534 .309 .521 r
F P
0 g
s
.54901 .38178 m .56448 .39934 L .5648 .42595 L p .972 .685 .422 r
F P
0 g
s
.68123 .30843 m .71135 .29844 L .72527 .31681 L p .656 .751 .92 r
F P
0 g
s
.71135 .29844 m .72527 .31681 L .72689 .34276 L p .976 .675 .358 r
F P
0 g
s
.59198 .29146 m .59144 .26578 L .56208 .2759 L p .526 .299 .513 r
F P
0 g
s
.56208 .2759 m .56238 .30152 L .59198 .29146 L p .526 .299 .513 r
F P
0 g
s
.56208 .2759 m .54657 .25713 L .5464 .23183 L p .974 .684 .41 r
F P
0 g
s
.56208 .2759 m .54657 .25713 L .5464 .23183 L p .974 .684 .41 r
F P
0 g
s
.59144 .26578 m .56208 .2759 L .54657 .25713 L p .658 .749 .917 r
F P
0 g
s
.59198 .29146 m .59144 .26578 L .56208 .2759 L p .526 .299 .513 r
F P
0 g
s
.56208 .2759 m .56238 .30152 L .59198 .29146 L p .526 .299 .513 r
F P
0 g
s
.51732 .26735 m .54657 .25713 L .56208 .2759 L p .658 .749 .917 r
F P
0 g
s
.51732 .26735 m .54657 .25713 L .56208 .2759 L p .658 .749 .917 r
F P
0 g
s
.54657 .25713 m .56208 .2759 L .56238 .30152 L p .974 .684 .41 r
F P
0 g
s
.59144 .26578 m .56208 .2759 L .54657 .25713 L p .658 .749 .917 r
F P
0 g
s
.54657 .25713 m .56208 .2759 L .56238 .30152 L p .974 .684 .41 r
F P
0 g
s
.66922 .41509 m .66805 .38841 L .63828 .39789 L p .537 .315 .524 r
F P
0 g
s
.63828 .39789 m .6392 .42451 L .66922 .41509 L p .537 .315 .524 r
F P
0 g
s
.63828 .39789 m .62351 .3803 L .62272 .354 L p .975 .682 .398 r
F P
0 g
s
.66805 .38841 m .63828 .39789 L .62351 .3803 L p .652 .756 .926 r
F P
0 g
s
.66922 .41509 m .66805 .38841 L .63828 .39789 L p .537 .315 .524 r
F P
0 g
s
.63828 .39789 m .6392 .42451 L .66922 .41509 L p .537 .315 .524 r
F P
0 g
s
.59384 .38987 m .62351 .3803 L .63828 .39789 L p .652 .756 .926 r
F P
0 g
s
.62351 .3803 m .63828 .39789 L .6392 .42451 L p .975 .682 .398 r
F P
0 g
s
.66805 .38841 m .63828 .39789 L .62351 .3803 L p .652 .756 .926 r
F P
0 g
s
.62351 .3803 m .63828 .39789 L .6392 .42451 L p .975 .682 .398 r
F P
0 g
s
.50377 .37362 m .50394 .34727 L .47502 .35697 L p .526 .299 .513 r
F P
0 g
s
.47502 .35697 m .47462 .38326 L .50377 .37362 L p .526 .299 .513 r
F P
0 g
s
.47502 .35697 m .45867 .33898 L .4592 .31301 L p .969 .687 .442 r
F P
0 g
s
.50394 .34727 m .47502 .35697 L .45867 .33898 L p .654 .754 .923 r
F P
0 g
s
.50377 .37362 m .50394 .34727 L .47502 .35697 L p .526 .299 .513 r
F P
0 g
s
.47502 .35697 m .47462 .38326 L .50377 .37362 L p .526 .299 .513 r
F P
0 g
s
.42986 .34877 m .45867 .33898 L .47502 .35697 L p .654 .754 .923 r
F P
0 g
s
.42986 .34877 m .45867 .33898 L .47502 .35697 L p .654 .754 .923 r
F P
0 g
s
.45867 .33898 m .47502 .35697 L .47462 .38326 L p .969 .687 .442 r
F P
0 g
s
.45867 .33898 m .47502 .35697 L .47462 .38326 L p .969 .687 .442 r
F P
0 g
s
.3879 .4381 m .37068 .4209 L .37192 .39425 L p .962 .688 .469 r
F P
0 g
s
.41637 .42882 m .3879 .4381 L .37068 .4209 L p .649 .759 .929 r
F P
0 g
s
.66683 .2899 m .66568 .26422 L .63591 .27435 L p .53 .304 .517 r
F P
0 g
s
.63591 .27435 m .63681 .29998 L .66683 .2899 L p .53 .304 .517 r
F P
0 g
s
.63591 .27435 m .62111 .25555 L .62033 .23024 L p .976 .68 .386 r
F P
0 g
s
.66568 .26422 m .63591 .27435 L .62111 .25555 L p .658 .749 .917 r
F P
0 g
s
.66683 .2899 m .66568 .26422 L .63591 .27435 L p .53 .304 .517 r
F P
0 g
s
.63591 .27435 m .63681 .29998 L .66683 .2899 L p .53 .304 .517 r
F P
0 g
s
.59144 .26578 m .62111 .25555 L .63591 .27435 L p .658 .749 .917 r
F P
0 g
s
.59144 .26578 m .62111 .25555 L .63591 .27435 L p .658 .749 .917 r
F P
0 g
s
.62111 .25555 m .63591 .27435 L .63681 .29998 L p .976 .68 .386 r
F P
0 g
s
.62111 .25555 m .63591 .27435 L .63681 .29998 L p .976 .68 .386 r
F P
0 g
s
.50131 .24841 m .5015 .22306 L .47258 .23342 L p .518 .287 .504 r
F P
0 g
s
.47258 .23342 m .47216 .25871 L .50131 .24841 L p .518 .287 .504 r
F P
0 g
s
.5015 .22306 m .47258 .23342 L .4562 .21422 L p .66 .747 .915 r
F P
0 g
s
.50131 .24841 m .5015 .22306 L .47258 .23342 L p .518 .287 .504 r
F P
0 g
s
.47258 .23342 m .47216 .25871 L .50131 .24841 L p .518 .287 .504 r
F P
0 g
s
.42739 .22466 m .4562 .21422 L .47258 .23342 L p .66 .747 .915 r
F P
0 g
s
.4562 .21422 m .47258 .23342 L .47216 .25871 L p .971 .686 .432 r
F P
0 g
s
.4562 .21422 m .47258 .23342 L .47216 .25871 L p .971 .686 .432 r
F P
0 g
s
.7122 .39644 m .69814 .37882 L .69674 .35251 L p .976 .678 .372 r
F P
0 g
s
.7122 .39644 m .69814 .37882 L .69674 .35251 L p .976 .678 .372 r
F P
0 g
s
.74238 .38694 m .7122 .39644 L .69814 .37882 L p .652 .756 .926 r
F P
0 g
s
.66805 .38841 m .69814 .37882 L .7122 .39644 L p .652 .756 .926 r
F P
0 g
s
.66805 .38841 m .69814 .37882 L .7122 .39644 L p .652 .756 .926 r
F P
0 g
s
.69814 .37882 m .7122 .39644 L .71372 .42307 L p .976 .678 .372 r
F P
0 g
s
.54881 .35548 m .53316 .33747 L .53309 .31149 L p .972 .685 .422 r
F P
0 g
s
.54881 .35548 m .53316 .33747 L .53309 .31149 L p .972 .685 .422 r
F P
0 g
s
.57814 .34577 m .54881 .35548 L .53316 .33747 L p .654 .754 .923 r
F P
0 g
s
.57857 .37212 m .57814 .34577 L .54881 .35548 L p .53 .304 .517 r
F P
0 g
s
.54881 .35548 m .54901 .38178 L .57857 .37212 L p .53 .304 .517 r
F P
0 g
s
.50394 .34727 m .53316 .33747 L .54881 .35548 L p .654 .754 .923 r
F P
0 g
s
.53316 .33747 m .54881 .35548 L .54901 .38178 L p .972 .685 .422 r
F P
0 g
s
.57814 .34577 m .54881 .35548 L .53316 .33747 L p .654 .754 .923 r
F P
0 g
s
.41299 .33062 m .41389 .3046 L .38542 .31453 L p .518 .287 .504 r
F P
0 g
s
.38542 .31453 m .38429 .34049 L .41299 .33062 L p .518 .287 .504 r
F P
0 g
s
.41637 .42882 m .44514 .41945 L .46164 .43668 L p .649 .759 .929 r
F P
0 g
s
.46164 .43668 m .44514 .41945 L .44578 .3928 L p .966 .687 .452 r
F P
0 g
s
.57614 .24682 m .57572 .22146 L .5464 .23183 L p .522 .293 .509 r
F P
0 g
s
.5464 .23183 m .54657 .25713 L .57614 .24682 L p .522 .293 .509 r
F P
0 g
s
.6535 .37063 m .65245 .34426 L .62272 .354 L p .534 .309 .521 r
F P
0 g
s
.62272 .354 m .62351 .3803 L .6535 .37063 L p .534 .309 .521 r
F P
0 g
s
.62272 .354 m .60777 .33595 L .6071 .30996 L p .975 .682 .398 r
F P
0 g
s
.62272 .354 m .60777 .33595 L .6071 .30996 L p .975 .682 .398 r
F P
0 g
s
.65245 .34426 m .62272 .354 L .60777 .33595 L p .654 .754 .923 r
F P
0 g
s
.57814 .34577 m .60777 .33595 L .62272 .354 L p .654 .754 .923 r
F P
0 g
s
.57814 .34577 m .60777 .33595 L .62272 .354 L p .654 .754 .923 r
F P
0 g
s
.60777 .33595 m .62272 .354 L .62351 .3803 L p .975 .682 .398 r
F P
0 g
s
.4592 .31301 m .44266 .29456 L .44332 .26891 L p .969 .687 .442 r
F P
0 g
s
.4592 .31301 m .44266 .29456 L .44332 .26891 L p .969 .687 .442 r
F P
0 g
s
.48807 .30306 m .4592 .31301 L .44266 .29456 L p .656 .751 .92 r
F P
0 g
s
.48778 .32909 m .48807 .30306 L .4592 .31301 L p .522 .293 .509 r
F P
0 g
s
.4592 .31301 m .45867 .33898 L .48778 .32909 L p .522 .293 .509 r
F P
0 g
s
.41389 .3046 m .44266 .29456 L .4592 .31301 L p .656 .751 .92 r
F P
0 g
s
.41389 .3046 m .44266 .29456 L .4592 .31301 L p .656 .751 .92 r
F P
0 g
s
.44266 .29456 m .4592 .31301 L .45867 .33898 L p .969 .687 .442 r
F P
0 g
s
.48807 .30306 m .4592 .31301 L .44266 .29456 L p .656 .751 .92 r
F P
0 g
s
.44266 .29456 m .4592 .31301 L .45867 .33898 L p .969 .687 .442 r
F P
0 g
s
.49052 .42739 m .51971 .418 L .53551 .43526 L p .649 .759 .929 r
F P
0 g
s
.53551 .43526 m .51971 .418 L .51975 .39133 L p .971 .686 .432 r
F P
0 g
s
.39934 .41144 m .40036 .38473 L .37192 .39425 L p .522 .293 .509 r
F P
0 g
s
.37192 .39425 m .37068 .4209 L .39934 .41144 L p .522 .293 .509 r
F P
0 g
s
.37192 .39425 m .35453 .37659 L .3559 .35027 L p .962 .688 .469 r
F P
0 g
s
.37192 .39425 m .35453 .37659 L .3559 .35027 L p .962 .688 .469 r
F P
0 g
s
.40036 .38473 m .37192 .39425 L .35453 .37659 L p .652 .756 .926 r
F P
0 g
s
.32621 .3862 m .35453 .37659 L .37192 .39425 L p .652 .756 .926 r
F P
0 g
s
.72854 .36913 m .72689 .34276 L .69674 .35251 L p .537 .315 .524 r
F P
0 g
s
.69674 .35251 m .69814 .37882 L .72854 .36913 L p .537 .315 .524 r
F P
0 g
s
.69674 .35251 m .68251 .33443 L .68123 .30843 L p .976 .678 .372 r
F P
0 g
s
.72689 .34276 m .69674 .35251 L .68251 .33443 L p .654 .754 .923 r
F P
0 g
s
.72854 .36913 m .72689 .34276 L .69674 .35251 L p .537 .315 .524 r
F P
0 g
s
.69674 .35251 m .69814 .37882 L .72854 .36913 L p .537 .315 .524 r
F P
0 g
s
.65245 .34426 m .68251 .33443 L .69674 .35251 L p .654 .754 .923 r
F P
0 g
s
.68251 .33443 m .69674 .35251 L .69814 .37882 L p .976 .678 .372 r
F P
0 g
s
.72689 .34276 m .69674 .35251 L .68251 .33443 L p .654 .754 .923 r
F P
0 g
s
.68251 .33443 m .69674 .35251 L .69814 .37882 L p .976 .678 .372 r
F P
0 g
s
.56269 .32756 m .56238 .30152 L .53309 .31149 L p .526 .299 .513 r
F P
0 g
s
.53309 .31149 m .53316 .33747 L .56269 .32756 L p .526 .299 .513 r
F P
0 g
s
.53309 .31149 m .51726 .29301 L .51732 .26735 L p .972 .685 .422 r
F P
0 g
s
.53309 .31149 m .51726 .29301 L .51732 .26735 L p .972 .685 .422 r
F P
0 g
s
.56238 .30152 m .53309 .31149 L .51726 .29301 L p .656 .751 .92 r
F P
0 g
s
.48807 .30306 m .51726 .29301 L .53309 .31149 L p .656 .751 .92 r
F P
0 g
s
.60949 .43383 m .5944 .41654 L .59384 .38987 L p .974 .684 .41 r
F P
0 g
s
.60949 .43383 m .5944 .41654 L .59384 .38987 L p .974 .684 .41 r
F P
0 g
s
.6392 .42451 m .60949 .43383 L .5944 .41654 L p .649 .759 .929 r
F P
0 g
s
.5648 .42595 m .5944 .41654 L .60949 .43383 L p .649 .759 .929 r
F P
0 g
s
.44578 .3928 m .42909 .37511 L .42986 .34877 L p .966 .687 .452 r
F P
0 g
s
.44578 .3928 m .42909 .37511 L .42986 .34877 L p .966 .687 .452 r
F P
0 g
s
.47462 .38326 m .44578 .3928 L .42909 .37511 L p .652 .756 .926 r
F P
0 g
s
.40036 .38473 m .42909 .37511 L .44578 .3928 L p .652 .756 .926 r
F P
0 g
s
.40036 .38473 m .42909 .37511 L .44578 .3928 L p .652 .756 .926 r
F P
0 g
s
.42909 .37511 m .44578 .3928 L .44514 .41945 L p .966 .687 .452 r
F P
0 g
s
.65007 .21986 m .68012 .20936 L .69439 .22865 L p .66 .747 .915 r
F P
0 g
s
.68012 .20936 m .69439 .22865 L .69576 .25397 L p .976 .675 .358 r
F P
0 g
s
.47173 .28442 m .47216 .25871 L .44332 .26891 L p .518 .287 .504 r
F P
0 g
s
.44332 .26891 m .44266 .29456 L .47173 .28442 L p .518 .287 .504 r
F P
0 g
s
.44332 .26891 m .4266 .25 L .42739 .22466 L p .969 .687 .442 r
F P
0 g
s
.47216 .25871 m .44332 .26891 L .4266 .25 L p .658 .749 .917 r
F P
0 g
s
.63772 .32603 m .63681 .29998 L .6071 .30996 L p .53 .304 .517 r
F P
0 g
s
.6071 .30996 m .60777 .33595 L .63772 .32603 L p .53 .304 .517 r
F P
0 g
s
.6071 .30996 m .59198 .29146 L .59144 .26578 L p .975 .682 .398 r
F P
0 g
s
.6071 .30996 m .59198 .29146 L .59144 .26578 L p .975 .682 .398 r
F P
0 g
s
.63681 .29998 m .6071 .30996 L .59198 .29146 L p .656 .751 .92 r
F P
0 g
s
.63772 .32603 m .63681 .29998 L .6071 .30996 L p .53 .304 .517 r
F P
0 g
s
.6071 .30996 m .60777 .33595 L .63772 .32603 L p .53 .304 .517 r
F P
0 g
s
.56238 .30152 m .59198 .29146 L .6071 .30996 L p .656 .751 .92 r
F P
0 g
s
.56238 .30152 m .59198 .29146 L .6071 .30996 L p .656 .751 .92 r
F P
0 g
s
.59198 .29146 m .6071 .30996 L .60777 .33595 L p .975 .682 .398 r
F P
0 g
s
.63681 .29998 m .6071 .30996 L .59198 .29146 L p .656 .751 .92 r
F P
0 g
s
.59198 .29146 m .6071 .30996 L .60777 .33595 L p .975 .682 .398 r
F P
0 g
s
.6836 .4324 m .66922 .41509 L .66805 .38841 L p .976 .68 .386 r
F P
0 g
s
.6836 .4324 m .66922 .41509 L .66805 .38841 L p .976 .68 .386 r
F P
0 g
s
.71372 .42307 m .6836 .4324 L .66922 .41509 L p .649 .759 .929 r
F P
0 g
s
.6392 .42451 m .66922 .41509 L .6836 .4324 L p .649 .759 .929 r
F P
0 g
s
.51975 .39133 m .50377 .37362 L .50394 .34727 L p .971 .686 .432 r
F P
0 g
s
.54901 .38178 m .51975 .39133 L .50377 .37362 L p .652 .756 .926 r
F P
0 g
s
.5492 .40851 m .54901 .38178 L .51975 .39133 L p .53 .304 .517 r
F P
0 g
s
.51975 .39133 m .51971 .418 L .5492 .40851 L p .53 .304 .517 r
F P
0 g
s
.47462 .38326 m .50377 .37362 L .51975 .39133 L p .652 .756 .926 r
F P
0 g
s
.47462 .38326 m .50377 .37362 L .51975 .39133 L p .652 .756 .926 r
F P
0 g
s
.50377 .37362 m .51975 .39133 L .51971 .418 L p .971 .686 .432 r
F P
0 g
s
.50377 .37362 m .51975 .39133 L .51971 .418 L p .971 .686 .432 r
F P
0 g
s
.38315 .36688 m .38429 .34049 L .3559 .35027 L p .518 .287 .504 r
F P
0 g
s
.3559 .35027 m .35453 .37659 L .38315 .36688 L p .518 .287 .504 r
F P
0 g
s
.71288 .32449 m .71135 .29844 L .68123 .30843 L p .534 .309 .521 r
F P
0 g
s
.68123 .30843 m .68251 .33443 L .71288 .32449 L p .534 .309 .521 r
F P
0 g
s
.68123 .30843 m .66683 .2899 L .66568 .26422 L p .976 .678 .372 r
F P
0 g
s
.71135 .29844 m .68123 .30843 L .66683 .2899 L p .656 .751 .92 r
F P
0 g
s
.71288 .32449 m .71135 .29844 L .68123 .30843 L p .534 .309 .521 r
F P
0 g
s
.68123 .30843 m .68251 .33443 L .71288 .32449 L p .534 .309 .521 r
F P
0 g
s
.63681 .29998 m .66683 .2899 L .68123 .30843 L p .656 .751 .92 r
F P
0 g
s
.66683 .2899 m .68123 .30843 L .68251 .33443 L p .976 .678 .372 r
F P
0 g
s
.54675 .28285 m .54657 .25713 L .51732 .26735 L p .522 .293 .509 r
F P
0 g
s
.51732 .26735 m .51726 .29301 L .54675 .28285 L p .522 .293 .509 r
F P
0 g
s
.47216 .25871 m .50131 .24841 L .51732 .26735 L p .658 .749 .917 r
F P
0 g
s
.51732 .26735 m .50131 .24841 L .5015 .22306 L p .972 .685 .422 r
F P
0 g
s
.62432 .40704 m .62351 .3803 L .59384 .38987 L p .534 .309 .521 r
F P
0 g
s
.59384 .38987 m .5944 .41654 L .62432 .40704 L p .534 .309 .521 r
F P
0 g
s
.59384 .38987 m .57857 .37212 L .57814 .34577 L p .974 .684 .41 r
F P
0 g
s
.62351 .3803 m .59384 .38987 L .57857 .37212 L p .652 .756 .926 r
F P
0 g
s
.62432 .40704 m .62351 .3803 L .59384 .38987 L p .534 .309 .521 r
F P
0 g
s
.59384 .38987 m .5944 .41654 L .62432 .40704 L p .534 .309 .521 r
F P
0 g
s
.54901 .38178 m .57857 .37212 L .59384 .38987 L p .652 .756 .926 r
F P
0 g
s
.57857 .37212 m .59384 .38987 L .5944 .41654 L p .974 .684 .41 r
F P
0 g
s
.62351 .3803 m .59384 .38987 L .57857 .37212 L p .652 .756 .926 r
F P
0 g
s
.57857 .37212 m .59384 .38987 L .5944 .41654 L p .974 .684 .41 r
F P
0 g
s
.45813 .36538 m .45867 .33898 L .42986 .34877 L p .522 .293 .509 r
F P
0 g
s
.42986 .34877 m .42909 .37511 L .45813 .36538 L p .522 .293 .509 r
F P
0 g
s
.42986 .34877 m .41299 .33062 L .41389 .3046 L p .966 .687 .452 r
F P
0 g
s
.42986 .34877 m .41299 .33062 L .41389 .3046 L p .966 .687 .452 r
F P
0 g
s
.45867 .33898 m .42986 .34877 L .41299 .33062 L p .654 .754 .923 r
F P
0 g
s
.45813 .36538 m .45867 .33898 L .42986 .34877 L p .522 .293 .509 r
F P
0 g
s
.42986 .34877 m .42909 .37511 L .45813 .36538 L p .522 .293 .509 r
F P
0 g
s
.38429 .34049 m .41299 .33062 L .42986 .34877 L p .654 .754 .923 r
F P
0 g
s
.38429 .34049 m .41299 .33062 L .42986 .34877 L p .654 .754 .923 r
F P
0 g
s
.41299 .33062 m .42986 .34877 L .42909 .37511 L p .966 .687 .452 r
F P
0 g
s
.45867 .33898 m .42986 .34877 L .41299 .33062 L p .654 .754 .923 r
F P
0 g
s
.41299 .33062 m .42986 .34877 L .42909 .37511 L p .966 .687 .452 r
F P
0 g
s
.6219 .28128 m .62111 .25555 L .59144 .26578 L p .526 .299 .513 r
F P
0 g
s
.59144 .26578 m .59198 .29146 L .6219 .28128 L p .526 .299 .513 r
F P
0 g
s
.59144 .26578 m .57614 .24682 L .57572 .22146 L p .975 .682 .398 r
F P
0 g
s
.62111 .25555 m .59144 .26578 L .57614 .24682 L p .658 .749 .917 r
F P
0 g
s
.6219 .28128 m .62111 .25555 L .59144 .26578 L p .526 .299 .513 r
F P
0 g
s
.59144 .26578 m .59198 .29146 L .6219 .28128 L p .526 .299 .513 r
F P
0 g
s
.54657 .25713 m .57614 .24682 L .59144 .26578 L p .658 .749 .917 r
F P
0 g
s
.54657 .25713 m .57614 .24682 L .59144 .26578 L p .658 .749 .917 r
F P
0 g
s
.57614 .24682 m .59144 .26578 L .59198 .29146 L p .975 .682 .398 r
F P
0 g
s
.57614 .24682 m .59144 .26578 L .59198 .29146 L p .975 .682 .398 r
F P
0 g
s
.45564 .23961 m .4562 .21422 L .42739 .22466 L p .514 .281 .5 r
F P
0 g
s
.42739 .22466 m .4266 .25 L .45564 .23961 L p .514 .281 .5 r
F P
0 g
s
.69956 .40557 m .69814 .37882 L .66805 .38841 L p .537 .315 .524 r
F P
0 g
s
.66805 .38841 m .66922 .41509 L .69956 .40557 L p .537 .315 .524 r
F P
0 g
s
.66805 .38841 m .6535 .37063 L .65245 .34426 L p .976 .68 .386 r
F P
0 g
s
.66805 .38841 m .6535 .37063 L .65245 .34426 L p .976 .68 .386 r
F P
0 g
s
.69814 .37882 m .66805 .38841 L .6535 .37063 L p .652 .756 .926 r
F P
0 g
s
.62351 .3803 m .6535 .37063 L .66805 .38841 L p .652 .756 .926 r
F P
0 g
s
.62351 .3803 m .6535 .37063 L .66805 .38841 L p .652 .756 .926 r
F P
0 g
s
.6535 .37063 m .66805 .38841 L .66922 .41509 L p .976 .68 .386 r
F P
0 g
s
.53316 .33747 m .50394 .34727 L .48778 .32909 L p .654 .754 .923 r
F P
0 g
s
.53323 .36387 m .53316 .33747 L .50394 .34727 L p .526 .299 .513 r
F P
0 g
s
.50394 .34727 m .50377 .37362 L .53323 .36387 L p .526 .299 .513 r
F P
0 g
s
.45867 .33898 m .48778 .32909 L .50394 .34727 L p .654 .754 .923 r
F P
0 g
s
.48778 .32909 m .50394 .34727 L .50377 .37362 L p .971 .686 .432 r
F P
0 g
s
.48778 .32909 m .50394 .34727 L .50377 .37362 L p .971 .686 .432 r
F P
0 g
s
.41637 .42882 m .39934 .41144 L .40036 .38473 L p .964 .688 .461 r
F P
0 g
s
.41637 .42882 m .39934 .41144 L .40036 .38473 L p .964 .688 .461 r
F P
0 g
s
.44514 .41945 m .41637 .42882 L .39934 .41144 L p .649 .759 .929 r
F P
0 g
s
.37068 .4209 m .39934 .41144 L .41637 .42882 L p .649 .759 .929 r
F P
0 g
s
.66568 .26422 m .65109 .24522 L .65007 .21986 L p .976 .678 .372 r
F P
0 g
s
.69576 .25397 m .66568 .26422 L .65109 .24522 L p .658 .749 .917 r
F P
0 g
s
.62111 .25555 m .65109 .24522 L .66568 .26422 L p .658 .749 .917 r
F P
0 g
s
.65109 .24522 m .66568 .26422 L .66683 .2899 L p .976 .678 .372 r
F P
0 g
s
.4562 .21422 m .48531 .20366 L .5015 .22306 L p .66 .747 .915 r
F P
0 g
s
.48531 .20366 m .5015 .22306 L .50131 .24841 L p .972 .685 .422 r
F P
0 g
s
.69814 .37882 m .72854 .36913 L .74238 .38694 L p .652 .756 .926 r
F P
0 g
s
.74238 .38694 m .72854 .36913 L .72689 .34276 L p .976 .675 .358 r
F P
0 g
s
.60845 .36237 m .60777 .33595 L .57814 .34577 L p .53 .304 .517 r
F P
0 g
s
.57814 .34577 m .57857 .37212 L .60845 .36237 L p .53 .304 .517 r
F P
0 g
s
.57814 .34577 m .56269 .32756 L .56238 .30152 L p .974 .684 .41 r
F P
0 g
s
.57814 .34577 m .56269 .32756 L .56238 .30152 L p .974 .684 .41 r
F P
0 g
s
.60777 .33595 m .57814 .34577 L .56269 .32756 L p .654 .754 .923 r
F P
0 g
s
.53316 .33747 m .56269 .32756 L .57814 .34577 L p .654 .754 .923 r
F P
0 g
s
.53316 .33747 m .56269 .32756 L .57814 .34577 L p .654 .754 .923 r
F P
0 g
s
.56269 .32756 m .57814 .34577 L .57857 .37212 L p .974 .684 .41 r
F P
0 g
s
.44199 .32064 m .44266 .29456 L .41389 .3046 L p .518 .287 .504 r
F P
0 g
s
.41389 .3046 m .41299 .33062 L .44199 .32064 L p .518 .287 .504 r
F P
0 g
s
.49052 .42739 m .47421 .40997 L .47462 .38326 L p .969 .687 .442 r
F P
0 g
s
.51971 .418 m .49052 .42739 L .47421 .40997 L p .649 .759 .929 r
F P
0 g
s
.60536 .21098 m .57572 .22146 L .56025 .20203 L p .66 .747 .915 r
F P
0 g
s
.60602 .23639 m .60536 .21098 L .57572 .22146 L p .522 .293 .509 r
F P
0 g
s
.57572 .22146 m .57614 .24682 L .60602 .23639 L p .522 .293 .509 r
F P
0 g
s
.56025 .20203 m .57572 .22146 L .57614 .24682 L p .975 .682 .398 r
F P
0 g
s
.6838 .36086 m .68251 .33443 L .65245 .34426 L p .534 .309 .521 r
F P
0 g
s
.65245 .34426 m .6535 .37063 L .6838 .36086 L p .534 .309 .521 r
F P
0 g
s
.65245 .34426 m .63772 .32603 L .63681 .29998 L p .976 .68 .386 r
F P
0 g
s
.68251 .33443 m .65245 .34426 L .63772 .32603 L p .654 .754 .923 r
F P
0 g
s
.6838 .36086 m .68251 .33443 L .65245 .34426 L p .534 .309 .521 r
F P
0 g
s
.65245 .34426 m .6535 .37063 L .6838 .36086 L p .534 .309 .521 r
F P
0 g
s
.60777 .33595 m .63772 .32603 L .65245 .34426 L p .654 .754 .923 r
F P
0 g
s
.63772 .32603 m .65245 .34426 L .6535 .37063 L p .976 .68 .386 r
F P
0 g
s
.48807 .30306 m .47173 .28442 L .47216 .25871 L p .971 .686 .432 r
F P
0 g
s
.51726 .29301 m .48807 .30306 L .47173 .28442 L p .656 .751 .92 r
F P
0 g
s
.5172 .3191 m .51726 .29301 L .48807 .30306 L p .522 .293 .509 r
F P
0 g
s
.48807 .30306 m .48778 .32909 L .5172 .3191 L p .522 .293 .509 r
F P
0 g
s
.44266 .29456 m .47173 .28442 L .48807 .30306 L p .656 .751 .92 r
F P
0 g
s
.44266 .29456 m .47173 .28442 L .48807 .30306 L p .656 .751 .92 r
F P
0 g
s
.47173 .28442 m .48807 .30306 L .48778 .32909 L p .971 .686 .432 r
F P
0 g
s
.47173 .28442 m .48807 .30306 L .48778 .32909 L p .971 .686 .432 r
F P
0 g
s
.5648 .42595 m .5492 .40851 L .54901 .38178 L p .972 .685 .422 r
F P
0 g
s
.5944 .41654 m .5648 .42595 L .5492 .40851 L p .649 .759 .929 r
F P
0 g
s
.42831 .40188 m .42909 .37511 L .40036 .38473 L p .522 .293 .509 r
F P
0 g
s
.40036 .38473 m .39934 .41144 L .42831 .40188 L p .522 .293 .509 r
F P
0 g
s
.40036 .38473 m .38315 .36688 L .38429 .34049 L p .964 .688 .461 r
F P
0 g
s
.40036 .38473 m .38315 .36688 L .38429 .34049 L p .964 .688 .461 r
F P
0 g
s
.42909 .37511 m .40036 .38473 L .38315 .36688 L p .652 .756 .926 r
F P
0 g
s
.35453 .37659 m .38315 .36688 L .40036 .38473 L p .652 .756 .926 r
F P
0 g
s
.6814 .23477 m .68012 .20936 L .65007 .21986 L p .526 .299 .513 r
F P
0 g
s
.65007 .21986 m .65109 .24522 L .6814 .23477 L p .526 .299 .513 r
F P
0 g
s
.68251 .33443 m .71288 .32449 L .72689 .34276 L p .654 .754 .923 r
F P
0 g
s
.68251 .33443 m .71288 .32449 L .72689 .34276 L p .654 .754 .923 r
F P
0 g
s
.71288 .32449 m .72689 .34276 L .72854 .36913 L p .976 .675 .358 r
F P
0 g
s
.72689 .34276 m .71288 .32449 L .71135 .29844 L p .976 .675 .358 r
F P
0 g
s
.59253 .31755 m .59198 .29146 L .56238 .30152 L p .526 .299 .513 r
F P
0 g
s
.56238 .30152 m .56269 .32756 L .59253 .31755 L p .526 .299 .513 r
F P
0 g
s
.56238 .30152 m .54675 .28285 L .54657 .25713 L p .974 .684 .41 r
F P
0 g
s
.56238 .30152 m .54675 .28285 L .54657 .25713 L p .974 .684 .41 r
F P
0 g
s
.59198 .29146 m .56238 .30152 L .54675 .28285 L p .656 .751 .92 r
F P
0 g
s
.51726 .29301 m .54675 .28285 L .56238 .30152 L p .656 .751 .92 r
F P
0 g
s
.6392 .42451 m .62432 .40704 L .62351 .3803 L p .975 .682 .398 r
F P
0 g
s
.6392 .42451 m .62432 .40704 L .62351 .3803 L p .975 .682 .398 r
F P
0 g
s
.66922 .41509 m .6392 .42451 L .62432 .40704 L p .649 .759 .929 r
F P
0 g
s
.5944 .41654 m .62432 .40704 L .6392 .42451 L p .649 .759 .929 r
F P
0 g
s
.5036 .4004 m .50377 .37362 L .47462 .38326 L p .526 .299 .513 r
F P
0 g
s
.47462 .38326 m .47421 .40997 L .5036 .4004 L p .526 .299 .513 r
F P
0 g
s
.47462 .38326 m .45813 .36538 L .45867 .33898 L p .969 .687 .442 r
F P
0 g
s
.47462 .38326 m .45813 .36538 L .45867 .33898 L p .969 .687 .442 r
F P
0 g
s
.50377 .37362 m .47462 .38326 L .45813 .36538 L p .652 .756 .926 r
F P
0 g
s
.5036 .4004 m .50377 .37362 L .47462 .38326 L p .526 .299 .513 r
F P
0 g
s
.47462 .38326 m .47421 .40997 L .5036 .4004 L p .526 .299 .513 r
F P
0 g
s
.42909 .37511 m .45813 .36538 L .47462 .38326 L p .652 .756 .926 r
F P
0 g
s
.45813 .36538 m .47462 .38326 L .47421 .40997 L p .969 .687 .442 r
F P
0 g
s
.50377 .37362 m .47462 .38326 L .45813 .36538 L p .652 .756 .926 r
F P
0 g
s
.75501 .20774 m .72454 .21825 L .71049 .19875 L p .66 .747 .915 r
F P
0 g
s
.7569 .23316 m .75501 .20774 L .72454 .21825 L p .53 .304 .517 r
F P
0 g
s
.72454 .21825 m .72617 .24362 L .7569 .23316 L p .53 .304 .517 r
F P
0 g
s
.71049 .19875 m .72454 .21825 L .72617 .24362 L p .976 .672 .343 r
F P
0 g
s
.63681 .29998 m .6219 .28128 L .62111 .25555 L p .976 .68 .386 r
F P
0 g
s
.63681 .29998 m .6219 .28128 L .62111 .25555 L p .976 .68 .386 r
F P
0 g
s
.66683 .2899 m .63681 .29998 L .6219 .28128 L p .656 .751 .92 r
F P
0 g
s
.59198 .29146 m .6219 .28128 L .63681 .29998 L p .656 .751 .92 r
F P
0 g
s
.59198 .29146 m .6219 .28128 L .63681 .29998 L p .656 .751 .92 r
F P
0 g
s
.6219 .28128 m .63681 .29998 L .63772 .32603 L p .976 .68 .386 r
F P
0 g
s
.47216 .25871 m .45564 .23961 L .4562 .21422 L p .971 .686 .432 r
F P
0 g
s
.47216 .25871 m .45564 .23961 L .4562 .21422 L p .971 .686 .432 r
F P
0 g
s
.50131 .24841 m .47216 .25871 L .45564 .23961 L p .658 .749 .917 r
F P
0 g
s
.4266 .25 m .45564 .23961 L .47216 .25871 L p .658 .749 .917 r
F P
0 g
s
.66922 .41509 m .69956 .40557 L .71372 .42307 L p .649 .759 .929 r
F P
0 g
s
.71372 .42307 m .69956 .40557 L .69814 .37882 L p .976 .678 .372 r
F P
0 g
s
.57901 .39891 m .57857 .37212 L .54901 .38178 L p .53 .304 .517 r
F P
0 g
s
.54901 .38178 m .5492 .40851 L .57901 .39891 L p .53 .304 .517 r
F P
0 g
s
.54901 .38178 m .53323 .36387 L .53316 .33747 L p .972 .685 .422 r
F P
0 g
s
.57857 .37212 m .54901 .38178 L .53323 .36387 L p .652 .756 .926 r
F P
0 g
s
.57901 .39891 m .57857 .37212 L .54901 .38178 L p .53 .304 .517 r
F P
0 g
s
.54901 .38178 m .5492 .40851 L .57901 .39891 L p .53 .304 .517 r
F P
0 g
s
.50377 .37362 m .53323 .36387 L .54901 .38178 L p .652 .756 .926 r
F P
0 g
s
.53323 .36387 m .54901 .38178 L .5492 .40851 L p .972 .685 .422 r
F P
0 g
s
.57857 .37212 m .54901 .38178 L .53323 .36387 L p .652 .756 .926 r
F P
0 g
s
.53323 .36387 m .54901 .38178 L .5492 .40851 L p .972 .685 .422 r
F P
0 g
s
.41207 .35707 m .41299 .33062 L .38429 .34049 L p .518 .287 .504 r
F P
0 g
s
.38429 .34049 m .38315 .36688 L .41207 .35707 L p .518 .287 .504 r
F P
0 g
s
.66683 .2899 m .69716 .27971 L .71135 .29844 L p .656 .751 .92 r
F P
0 g
s
.69716 .27971 m .71135 .29844 L .71288 .32449 L p .976 .675 .358 r
F P
0 g
s
.57656 .27259 m .57614 .24682 L .54657 .25713 L p .522 .293 .509 r
F P
0 g
s
.54657 .25713 m .54675 .28285 L .57656 .27259 L p .522 .293 .509 r
F P
0 g
s
.65455 .39743 m .6535 .37063 L .62351 .3803 L p .534 .309 .521 r
F P
0 g
s
.62351 .3803 m .62432 .40704 L .65455 .39743 L p .534 .309 .521 r
F P
0 g
s
.62351 .3803 m .60845 .36237 L .60777 .33595 L p .975 .682 .398 r
F P
0 g
s
.6535 .37063 m .62351 .3803 L .60845 .36237 L p .652 .756 .926 r
F P
0 g
s
.65455 .39743 m .6535 .37063 L .62351 .3803 L p .534 .309 .521 r
F P
0 g
s
.62351 .3803 m .62432 .40704 L .65455 .39743 L p .534 .309 .521 r
F P
0 g
s
.57857 .37212 m .60845 .36237 L .62351 .3803 L p .652 .756 .926 r
F P
0 g
s
.57857 .37212 m .60845 .36237 L .62351 .3803 L p .652 .756 .926 r
F P
0 g
s
.60845 .36237 m .62351 .3803 L .62432 .40704 L p .975 .682 .398 r
F P
0 g
s
.60845 .36237 m .62351 .3803 L .62432 .40704 L p .975 .682 .398 r
F P
0 g
s
.48747 .35555 m .48778 .32909 L .45867 .33898 L p .522 .293 .509 r
F P
0 g
s
.45867 .33898 m .45813 .36538 L .48747 .35555 L p .522 .293 .509 r
F P
0 g
s
.45867 .33898 m .44199 .32064 L .44266 .29456 L p .969 .687 .442 r
F P
0 g
s
.45867 .33898 m .44199 .32064 L .44266 .29456 L p .969 .687 .442 r
F P
0 g
s
.48778 .32909 m .45867 .33898 L .44199 .32064 L p .654 .754 .923 r
F P
0 g
s
.48747 .35555 m .48778 .32909 L .45867 .33898 L p .522 .293 .509 r
F P
0 g
s
.45867 .33898 m .45813 .36538 L .48747 .35555 L p .522 .293 .509 r
F P
0 g
s
.41299 .33062 m .44199 .32064 L .45867 .33898 L p .654 .754 .923 r
F P
0 g
s
.41299 .33062 m .44199 .32064 L .45867 .33898 L p .654 .754 .923 r
F P
0 g
s
.44199 .32064 m .45867 .33898 L .45813 .36538 L p .969 .687 .442 r
F P
0 g
s
.48778 .32909 m .45867 .33898 L .44199 .32064 L p .654 .754 .923 r
F P
0 g
s
.44199 .32064 m .45867 .33898 L .45813 .36538 L p .969 .687 .442 r
F P
0 g
s
.65213 .271 m .65109 .24522 L .62111 .25555 L p .526 .299 .513 r
F P
0 g
s
.62111 .25555 m .6219 .28128 L .65213 .271 L p .526 .299 .513 r
F P
0 g
s
.65109 .24522 m .62111 .25555 L .60602 .23639 L p .658 .749 .917 r
F P
0 g
s
.65213 .271 m .65109 .24522 L .62111 .25555 L p .526 .299 .513 r
F P
0 g
s
.62111 .25555 m .6219 .28128 L .65213 .271 L p .526 .299 .513 r
F P
0 g
s
.57614 .24682 m .60602 .23639 L .62111 .25555 L p .658 .749 .917 r
F P
0 g
s
.60602 .23639 m .62111 .25555 L .6219 .28128 L p .976 .68 .386 r
F P
0 g
s
.60602 .23639 m .62111 .25555 L .6219 .28128 L p .976 .68 .386 r
F P
0 g
s
.48498 .2291 m .48531 .20366 L .4562 .21422 L p .514 .281 .5 r
F P
0 g
s
.4562 .21422 m .45564 .23961 L .48498 .2291 L p .514 .281 .5 r
F P
0 g
s
.69814 .37882 m .6838 .36086 L .68251 .33443 L p .976 .678 .372 r
F P
0 g
s
.69814 .37882 m .6838 .36086 L .68251 .33443 L p .976 .678 .372 r
F P
0 g
s
.72854 .36913 m .69814 .37882 L .6838 .36086 L p .652 .756 .926 r
F P
0 g
s
.6535 .37063 m .6838 .36086 L .69814 .37882 L p .652 .756 .926 r
F P
0 g
s
.563 .35403 m .56269 .32756 L .53316 .33747 L p .526 .299 .513 r
F P
0 g
s
.53316 .33747 m .53323 .36387 L .563 .35403 L p .526 .299 .513 r
F P
0 g
s
.56269 .32756 m .53316 .33747 L .5172 .3191 L p .654 .754 .923 r
F P
0 g
s
.563 .35403 m .56269 .32756 L .53316 .33747 L p .526 .299 .513 r
F P
0 g
s
.53316 .33747 m .53323 .36387 L .563 .35403 L p .526 .299 .513 r
F P
0 g
s
.48778 .32909 m .5172 .3191 L .53316 .33747 L p .654 .754 .923 r
F P
0 g
s
.5172 .3191 m .53316 .33747 L .53323 .36387 L p .972 .685 .422 r
F P
0 g
s
.5172 .3191 m .53316 .33747 L .53323 .36387 L p .972 .685 .422 r
F P
0 g
s
.39934 .41144 m .42831 .40188 L .44514 .41945 L p .649 .759 .929 r
F P
0 g
s
.44514 .41945 m .42831 .40188 L .42909 .37511 L p .966 .687 .452 r
F P
0 g
s
.65109 .24522 m .6814 .23477 L .69576 .25397 L p .658 .749 .917 r
F P
0 g
s
.69576 .25397 m .6814 .23477 L .68012 .20936 L p .976 .675 .358 r
F P
0 g
s
.60777 .33595 m .59253 .31755 L .59198 .29146 L p .975 .682 .398 r
F P
0 g
s
.60777 .33595 m .59253 .31755 L .59198 .29146 L p .975 .682 .398 r
F P
0 g
s
.63772 .32603 m .60777 .33595 L .59253 .31755 L p .654 .754 .923 r
F P
0 g
s
.56269 .32756 m .59253 .31755 L .60777 .33595 L p .654 .754 .923 r
F P
0 g
s
.4713 .31056 m .47173 .28442 L .44266 .29456 L p .518 .287 .504 r
F P
0 g
s
.44266 .29456 m .44199 .32064 L .4713 .31056 L p .518 .287 .504 r
F P
0 g
s
.51971 .418 m .5036 .4004 L .50377 .37362 L p .971 .686 .432 r
F P
0 g
s
.51971 .418 m .5036 .4004 L .50377 .37362 L p .971 .686 .432 r
F P
0 g
s
.5492 .40851 m .51971 .418 L .5036 .4004 L p .649 .759 .929 r
F P
0 g
s
.47421 .40997 m .5036 .4004 L .51971 .418 L p .649 .759 .929 r
F P
0 g
s
.56025 .20203 m .59009 .19135 L .60536 .21098 L p .66 .747 .915 r
F P
0 g
s
.59009 .19135 m .60536 .21098 L .60602 .23639 L p .976 .68 .386 r
F P
0 g
s
.71443 .35098 m .71288 .32449 L .68251 .33443 L p .534 .309 .521 r
F P
0 g
s
.68251 .33443 m .6838 .36086 L .71443 .35098 L p .534 .309 .521 r
F P
0 g
s
.68251 .33443 m .66799 .316 L .66683 .2899 L p .976 .678 .372 r
F P
0 g
s
.71288 .32449 m .68251 .33443 L .66799 .316 L p .654 .754 .923 r
F P
0 g
s
.71443 .35098 m .71288 .32449 L .68251 .33443 L p .534 .309 .521 r
F P
0 g
s
.68251 .33443 m .6838 .36086 L .71443 .35098 L p .534 .309 .521 r
F P
0 g
s
.63772 .32603 m .66799 .316 L .68251 .33443 L p .654 .754 .923 r
F P
0 g
s
.66799 .316 m .68251 .33443 L .6838 .36086 L p .976 .678 .372 r
F P
0 g
s
.71288 .32449 m .68251 .33443 L .66799 .316 L p .654 .754 .923 r
F P
0 g
s
.66799 .316 m .68251 .33443 L .6838 .36086 L p .976 .678 .372 r
F P
0 g
s
.54675 .28285 m .51726 .29301 L .50112 .27417 L p .656 .751 .92 r
F P
0 g
s
.54694 .309 m .54675 .28285 L .51726 .29301 L p .522 .293 .509 r
F P
0 g
s
.51726 .29301 m .5172 .3191 L .54694 .309 L p .522 .293 .509 r
F P
0 g
s
.47173 .28442 m .50112 .27417 L .51726 .29301 L p .656 .751 .92 r
F P
0 g
s
.50112 .27417 m .51726 .29301 L .5172 .3191 L p .972 .685 .422 r
F P
0 g
s
.50112 .27417 m .51726 .29301 L .5172 .3191 L p .972 .685 .422 r
F P
0 g
s
.5944 .41654 m .57901 .39891 L .57857 .37212 L p .974 .684 .41 r
F P
0 g
s
.5944 .41654 m .57901 .39891 L .57857 .37212 L p .974 .684 .41 r
F P
0 g
s
.62432 .40704 m .5944 .41654 L .57901 .39891 L p .649 .759 .929 r
F P
0 g
s
.5492 .40851 m .57901 .39891 L .5944 .41654 L p .649 .759 .929 r
F P
0 g
s
.42909 .37511 m .41207 .35707 L .41299 .33062 L p .966 .687 .452 r
F P
0 g
s
.42909 .37511 m .41207 .35707 L .41299 .33062 L p .966 .687 .452 r
F P
0 g
s
.45813 .36538 m .42909 .37511 L .41207 .35707 L p .652 .756 .926 r
F P
0 g
s
.38315 .36688 m .41207 .35707 L .42909 .37511 L p .652 .756 .926 r
F P
0 g
s
.71049 .19875 m .68012 .20936 L .66558 .18969 L p .66 .747 .915 r
F P
0 g
s
.71202 .22421 m .71049 .19875 L .68012 .20936 L p .526 .299 .513 r
F P
0 g
s
.68012 .20936 m .6814 .23477 L .71202 .22421 L p .526 .299 .513 r
F P
0 g
s
.66558 .18969 m .68012 .20936 L .6814 .23477 L p .976 .675 .358 r
F P
0 g
s
.6227 .30743 m .6219 .28128 L .59198 .29146 L p .526 .299 .513 r
F P
0 g
s
.59198 .29146 m .59253 .31755 L .6227 .30743 L p .526 .299 .513 r
F P
0 g
s
.59198 .29146 m .57656 .27259 L .57614 .24682 L p .975 .682 .398 r
F P
0 g
s
.59198 .29146 m .57656 .27259 L .57614 .24682 L p .975 .682 .398 r
F P
0 g
s
.6219 .28128 m .59198 .29146 L .57656 .27259 L p .656 .751 .92 r
F P
0 g
s
.54675 .28285 m .57656 .27259 L .59198 .29146 L p .656 .751 .92 r
F P
0 g
s
.62432 .40704 m .65455 .39743 L .66922 .41509 L p .649 .759 .929 r
F P
0 g
s
.66922 .41509 m .65455 .39743 L .6535 .37063 L p .976 .68 .386 r
F P
0 g
s
.5333 .39072 m .53323 .36387 L .50377 .37362 L p .526 .299 .513 r
F P
0 g
s
.50377 .37362 m .5036 .4004 L .5333 .39072 L p .526 .299 .513 r
F P
0 g
s
.50377 .37362 m .48747 .35555 L .48778 .32909 L p .971 .686 .432 r
F P
0 g
s
.50377 .37362 m .48747 .35555 L .48778 .32909 L p .971 .686 .432 r
F P
0 g
s
.53323 .36387 m .50377 .37362 L .48747 .35555 L p .652 .756 .926 r
F P
0 g
s
.5333 .39072 m .53323 .36387 L .50377 .37362 L p .526 .299 .513 r
F P
0 g
s
.50377 .37362 m .5036 .4004 L .5333 .39072 L p .526 .299 .513 r
F P
0 g
s
.45813 .36538 m .48747 .35555 L .50377 .37362 L p .652 .756 .926 r
F P
0 g
s
.45813 .36538 m .48747 .35555 L .50377 .37362 L p .652 .756 .926 r
F P
0 g
s
.48747 .35555 m .50377 .37362 L .5036 .4004 L p .971 .686 .432 r
F P
0 g
s
.53323 .36387 m .50377 .37362 L .48747 .35555 L p .652 .756 .926 r
F P
0 g
s
.48747 .35555 m .50377 .37362 L .5036 .4004 L p .971 .686 .432 r
F P
0 g
s
.7858 .19711 m .75501 .20774 L .74119 .18804 L p .66 .747 .915 r
F P
0 g
s
.78795 .22258 m .7858 .19711 L .75501 .20774 L p .53 .304 .517 r
F P
0 g
s
.75501 .20774 m .7569 .23316 L .78795 .22258 L p .53 .304 .517 r
F P
0 g
s
.71049 .19875 m .74119 .18804 L .75501 .20774 L p .66 .747 .915 r
F P
0 g
s
.74119 .18804 m .75501 .20774 L .7569 .23316 L p .975 .668 .327 r
F P
0 g
s
.74119 .18804 m .75501 .20774 L .7569 .23316 L p .975 .668 .327 r
F P
0 g
s
.69859 .30587 m .69716 .27971 L .66683 .2899 L p .53 .304 .517 r
F P
0 g
s
.66683 .2899 m .66799 .316 L .69859 .30587 L p .53 .304 .517 r
F P
0 g
s
.66683 .2899 m .65213 .271 L .65109 .24522 L p .976 .678 .372 r
F P
0 g
s
.69716 .27971 m .66683 .2899 L .65213 .271 L p .656 .751 .92 r
F P
0 g
s
.69859 .30587 m .69716 .27971 L .66683 .2899 L p .53 .304 .517 r
F P
0 g
s
.66683 .2899 m .66799 .316 L .69859 .30587 L p .53 .304 .517 r
F P
0 g
s
.6219 .28128 m .65213 .271 L .66683 .2899 L p .656 .751 .92 r
F P
0 g
s
.65213 .271 m .66683 .2899 L .66799 .316 L p .976 .678 .372 r
F P
0 g
s
.45564 .23961 m .48498 .2291 L .50131 .24841 L p .658 .749 .917 r
F P
0 g
s
.50131 .24841 m .48498 .2291 L .48531 .20366 L p .972 .685 .422 r
F P
0 g
s
.60914 .38922 m .60845 .36237 L .57857 .37212 L p .53 .304 .517 r
F P
0 g
s
.57857 .37212 m .57901 .39891 L .60914 .38922 L p .53 .304 .517 r
F P
0 g
s
.57857 .37212 m .563 .35403 L .56269 .32756 L p .974 .684 .41 r
F P
0 g
s
.60845 .36237 m .57857 .37212 L .563 .35403 L p .652 .756 .926 r
F P
0 g
s
.60914 .38922 m .60845 .36237 L .57857 .37212 L p .53 .304 .517 r
F P
0 g
s
.57857 .37212 m .57901 .39891 L .60914 .38922 L p .53 .304 .517 r
F P
0 g
s
.53323 .36387 m .563 .35403 L .57857 .37212 L p .652 .756 .926 r
F P
0 g
s
.53323 .36387 m .563 .35403 L .57857 .37212 L p .652 .756 .926 r
F P
0 g
s
.563 .35403 m .57857 .37212 L .57901 .39891 L p .974 .684 .41 r
F P
0 g
s
.563 .35403 m .57857 .37212 L .57901 .39891 L p .974 .684 .41 r
F P
0 g
s
.44131 .34715 m .44199 .32064 L .41299 .33062 L p .518 .287 .504 r
F P
0 g
s
.41299 .33062 m .41207 .35707 L .44131 .34715 L p .518 .287 .504 r
F P
0 g
s
.60669 .26221 m .60602 .23639 L .57614 .24682 L p .522 .293 .509 r
F P
0 g
s
.57614 .24682 m .57656 .27259 L .60669 .26221 L p .522 .293 .509 r
F P
0 g
s
.57614 .24682 m .56054 .22748 L .56025 .20203 L p .975 .682 .398 r
F P
0 g
s
.60602 .23639 m .57614 .24682 L .56054 .22748 L p .658 .749 .917 r
F P
0 g
s
.6535 .37063 m .63865 .3525 L .63772 .32603 L p .976 .68 .386 r
F P
0 g
s
.6838 .36086 m .6535 .37063 L .63865 .3525 L p .652 .756 .926 r
F P
0 g
s
.60845 .36237 m .63865 .3525 L .6535 .37063 L p .652 .756 .926 r
F P
0 g
s
.63865 .3525 m .6535 .37063 L .65455 .39743 L p .976 .68 .386 r
F P
0 g
s
.51714 .34561 m .5172 .3191 L .48778 .32909 L p .522 .293 .509 r
F P
0 g
s
.48778 .32909 m .48747 .35555 L .51714 .34561 L p .522 .293 .509 r
F P
0 g
s
.48778 .32909 m .4713 .31056 L .47173 .28442 L p .971 .686 .432 r
F P
0 g
s
.48778 .32909 m .4713 .31056 L .47173 .28442 L p .971 .686 .432 r
F P
0 g
s
.5172 .3191 m .48778 .32909 L .4713 .31056 L p .654 .754 .923 r
F P
0 g
s
.51714 .34561 m .5172 .3191 L .48778 .32909 L p .522 .293 .509 r
F P
0 g
s
.48778 .32909 m .48747 .35555 L .51714 .34561 L p .522 .293 .509 r
F P
0 g
s
.44199 .32064 m .4713 .31056 L .48778 .32909 L p .654 .754 .923 r
F P
0 g
s
.44199 .32064 m .4713 .31056 L .48778 .32909 L p .654 .754 .923 r
F P
0 g
s
.4713 .31056 m .48778 .32909 L .48747 .35555 L p .971 .686 .432 r
F P
0 g
s
.5172 .3191 m .48778 .32909 L .4713 .31056 L p .654 .754 .923 r
F P
0 g
s
.4713 .31056 m .48778 .32909 L .48747 .35555 L p .971 .686 .432 r
F P
0 g
s
.6814 .23477 m .65109 .24522 L .63622 .22585 L p .658 .749 .917 r
F P
0 g
s
.68269 .2606 m .6814 .23477 L .65109 .24522 L p .526 .299 .513 r
F P
0 g
s
.65109 .24522 m .65213 .271 L .68269 .2606 L p .526 .299 .513 r
F P
0 g
s
.60602 .23639 m .63622 .22585 L .65109 .24522 L p .658 .749 .917 r
F P
0 g
s
.63622 .22585 m .65109 .24522 L .65213 .271 L p .976 .678 .372 r
F P
0 g
s
.63622 .22585 m .65109 .24522 L .65213 .271 L p .976 .678 .372 r
F P
0 g
s
.6838 .36086 m .71443 .35098 L .72854 .36913 L p .652 .756 .926 r
F P
0 g
s
.72854 .36913 m .71443 .35098 L .71288 .32449 L p .976 .675 .358 r
F P
0 g
s
.59253 .31755 m .56269 .32756 L .54694 .309 L p .654 .754 .923 r
F P
0 g
s
.5931 .34408 m .59253 .31755 L .56269 .32756 L p .526 .299 .513 r
F P
0 g
s
.56269 .32756 m .563 .35403 L .5931 .34408 L p .526 .299 .513 r
F P
0 g
s
.5172 .3191 m .54694 .309 L .56269 .32756 L p .654 .754 .923 r
F P
0 g
s
.54694 .309 m .56269 .32756 L .563 .35403 L p .974 .684 .41 r
F P
0 g
s
.54694 .309 m .56269 .32756 L .563 .35403 L p .974 .684 .41 r
F P
0 g
s
.47421 .40997 m .45758 .39221 L .45813 .36538 L p .969 .687 .442 r
F P
0 g
s
.5036 .4004 m .47421 .40997 L .45758 .39221 L p .649 .759 .929 r
F P
0 g
s
.72617 .24362 m .71202 .22421 L .71049 .19875 L p .976 .672 .343 r
F P
0 g
s
.7569 .23316 m .72617 .24362 L .71202 .22421 L p .658 .749 .917 r
F P
0 g
s
.59063 .21684 m .59009 .19135 L .56025 .20203 L p .518 .287 .504 r
F P
0 g
s
.56025 .20203 m .56054 .22748 L .59063 .21684 L p .518 .287 .504 r
F P
0 g
s
.66918 .34254 m .66799 .316 L .63772 .32603 L p .53 .304 .517 r
F P
0 g
s
.63772 .32603 m .63865 .3525 L .66918 .34254 L p .53 .304 .517 r
F P
0 g
s
.63772 .32603 m .6227 .30743 L .6219 .28128 L p .976 .68 .386 r
F P
0 g
s
.66799 .316 m .63772 .32603 L .6227 .30743 L p .654 .754 .923 r
F P
0 g
s
.66918 .34254 m .66799 .316 L .63772 .32603 L p .53 .304 .517 r
F P
0 g
s
.63772 .32603 m .63865 .3525 L .66918 .34254 L p .53 .304 .517 r
F P
0 g
s
.59253 .31755 m .6227 .30743 L .63772 .32603 L p .654 .754 .923 r
F P
0 g
s
.6227 .30743 m .63772 .32603 L .63865 .3525 L p .976 .68 .386 r
F P
0 g
s
.50092 .30036 m .50112 .27417 L .47173 .28442 L p .518 .287 .504 r
F P
0 g
s
.47173 .28442 m .4713 .31056 L .50092 .30036 L p .518 .287 .504 r
F P
0 g
s
.5492 .40851 m .5333 .39072 L .53323 .36387 L p .972 .685 .422 r
F P
0 g
s
.5492 .40851 m .5333 .39072 L .53323 .36387 L p .972 .685 .422 r
F P
0 g
s
.57901 .39891 m .5492 .40851 L .5333 .39072 L p .649 .759 .929 r
F P
0 g
s
.5036 .4004 m .5333 .39072 L .5492 .40851 L p .649 .759 .929 r
F P
0 g
s
.66558 .18969 m .63531 .20039 L .62025 .18055 L p .66 .747 .915 r
F P
0 g
s
.66674 .21519 m .66558 .18969 L .63531 .20039 L p .522 .293 .509 r
F P
0 g
s
.63531 .20039 m .63622 .22585 L .66674 .21519 L p .522 .293 .509 r
F P
0 g
s
.62025 .18055 m .63531 .20039 L .63622 .22585 L p .976 .678 .372 r
F P
0 g
s
.66799 .316 m .69859 .30587 L .71288 .32449 L p .654 .754 .923 r
F P
0 g
s
.66799 .316 m .69859 .30587 L .71288 .32449 L p .654 .754 .923 r
F P
0 g
s
.69859 .30587 m .71288 .32449 L .71443 .35098 L p .976 .675 .358 r
F P
0 g
s
.71288 .32449 m .69859 .30587 L .69716 .27971 L p .976 .675 .358 r
F P
0 g
s
.57656 .27259 m .54675 .28285 L .53082 .26381 L p .656 .751 .92 r
F P
0 g
s
.57699 .29878 m .57656 .27259 L .54675 .28285 L p .522 .293 .509 r
F P
0 g
s
.54675 .28285 m .54694 .309 L .57699 .29878 L p .522 .293 .509 r
F P
0 g
s
.50112 .27417 m .53082 .26381 L .54675 .28285 L p .656 .751 .92 r
F P
0 g
s
.53082 .26381 m .54675 .28285 L .54694 .309 L p .974 .684 .41 r
F P
0 g
s
.53082 .26381 m .54675 .28285 L .54694 .309 L p .974 .684 .41 r
F P
0 g
s
.62432 .40704 m .60914 .38922 L .60845 .36237 L p .975 .682 .398 r
F P
0 g
s
.62432 .40704 m .60914 .38922 L .60845 .36237 L p .975 .682 .398 r
F P
0 g
s
.65455 .39743 m .62432 .40704 L .60914 .38922 L p .649 .759 .929 r
F P
0 g
s
.57901 .39891 m .60914 .38922 L .62432 .40704 L p .649 .759 .929 r
F P
0 g
s
.48717 .38245 m .48747 .35555 L .45813 .36538 L p .522 .293 .509 r
F P
0 g
s
.45813 .36538 m .45758 .39221 L .48717 .38245 L p .522 .293 .509 r
F P
0 g
s
.45813 .36538 m .44131 .34715 L .44199 .32064 L p .969 .687 .442 r
F P
0 g
s
.45813 .36538 m .44131 .34715 L .44199 .32064 L p .969 .687 .442 r
F P
0 g
s
.48747 .35555 m .45813 .36538 L .44131 .34715 L p .652 .756 .926 r
F P
0 g
s
.41207 .35707 m .44131 .34715 L .45813 .36538 L p .652 .756 .926 r
F P
0 g
s
.74298 .21354 m .74119 .18804 L .71049 .19875 L p .526 .299 .513 r
F P
0 g
s
.71049 .19875 m .71202 .22421 L .74298 .21354 L p .526 .299 .513 r
F P
0 g
s
.74119 .18804 m .71049 .19875 L .69617 .17887 L p .66 .747 .915 r
F P
0 g
s
.74298 .21354 m .74119 .18804 L .71049 .19875 L p .526 .299 .513 r
F P
0 g
s
.71049 .19875 m .71202 .22421 L .74298 .21354 L p .526 .299 .513 r
F P
0 g
s
.66558 .18969 m .69617 .17887 L .71049 .19875 L p .66 .747 .915 r
F P
0 g
s
.69617 .17887 m .71049 .19875 L .71202 .22421 L p .976 .672 .343 r
F P
0 g
s
.69617 .17887 m .71049 .19875 L .71202 .22421 L p .976 .672 .343 r
F P
0 g
s
.6219 .28128 m .60669 .26221 L .60602 .23639 L p .976 .68 .386 r
F P
0 g
s
.6219 .28128 m .60669 .26221 L .60602 .23639 L p .976 .68 .386 r
F P
0 g
s
.65213 .271 m .6219 .28128 L .60669 .26221 L p .656 .751 .92 r
F P
0 g
s
.57656 .27259 m .60669 .26221 L .6219 .28128 L p .656 .751 .92 r
F P
0 g
s
.56332 .38093 m .563 .35403 L .53323 .36387 L p .526 .299 .513 r
F P
0 g
s
.53323 .36387 m .5333 .39072 L .56332 .38093 L p .526 .299 .513 r
F P
0 g
s
.53323 .36387 m .51714 .34561 L .5172 .3191 L p .972 .685 .422 r
F P
0 g
s
.53323 .36387 m .51714 .34561 L .5172 .3191 L p .972 .685 .422 r
F P
0 g
s
.563 .35403 m .53323 .36387 L .51714 .34561 L p .652 .756 .926 r
F P
0 g
s
.48747 .35555 m .51714 .34561 L .53323 .36387 L p .652 .756 .926 r
F P
0 g
s
.48747 .35555 m .51714 .34561 L .53323 .36387 L p .652 .756 .926 r
F P
0 g
s
.51714 .34561 m .53323 .36387 L .5333 .39072 L p .972 .685 .422 r
F P
0 g
s
.74119 .18804 m .77221 .1772 L .7858 .19711 L p .66 .747 .915 r
F P
0 g
s
.77221 .1772 m .7858 .19711 L .78795 .22258 L p .973 .663 .31 r
F P
0 g
s
.65213 .271 m .68269 .2606 L .69716 .27971 L p .656 .751 .92 r
F P
0 g
s
.68269 .2606 m .69716 .27971 L .69859 .30587 L p .976 .675 .358 r
F P
0 g
s
.6396 .37942 m .63865 .3525 L .60845 .36237 L p .53 .304 .517 r
F P
0 g
s
.60845 .36237 m .60914 .38922 L .6396 .37942 L p .53 .304 .517 r
F P
0 g
s
.63865 .3525 m .60845 .36237 L .5931 .34408 L p .652 .756 .926 r
F P
0 g
s
.6396 .37942 m .63865 .3525 L .60845 .36237 L p .53 .304 .517 r
F P
0 g
s
.60845 .36237 m .60914 .38922 L .6396 .37942 L p .53 .304 .517 r
F P
0 g
s
.563 .35403 m .5931 .34408 L .60845 .36237 L p .652 .756 .926 r
F P
0 g
s
.5931 .34408 m .60845 .36237 L .60914 .38922 L p .975 .682 .398 r
F P
0 g
s
.5931 .34408 m .60845 .36237 L .60914 .38922 L p .975 .682 .398 r
F P
0 g
s
.47086 .33712 m .4713 .31056 L .44199 .32064 L p .518 .287 .504 r
F P
0 g
s
.44199 .32064 m .44131 .34715 L .47086 .33712 L p .518 .287 .504 r
F P
0 g
s
.63715 .25172 m .63622 .22585 L .60602 .23639 L p .522 .293 .509 r
F P
0 g
s
.60602 .23639 m .60669 .26221 L .63715 .25172 L p .522 .293 .509 r
F P
0 g
s
.60602 .23639 m .59063 .21684 L .59009 .19135 L p .976 .68 .386 r
F P
0 g
s
.63622 .22585 m .60602 .23639 L .59063 .21684 L p .658 .749 .917 r
F P
0 g
s
.63715 .25172 m .63622 .22585 L .60602 .23639 L p .522 .293 .509 r
F P
0 g
s
.60602 .23639 m .60669 .26221 L .63715 .25172 L p .522 .293 .509 r
F P
0 g
s
.56054 .22748 m .59063 .21684 L .60602 .23639 L p .658 .749 .917 r
F P
0 g
s
.59063 .21684 m .60602 .23639 L .60669 .26221 L p .976 .68 .386 r
F P
0 g
s
.6838 .36086 m .66918 .34254 L .66799 .316 L p .976 .678 .372 r
F P
0 g
s
.6838 .36086 m .66918 .34254 L .66799 .316 L p .976 .678 .372 r
F P
0 g
s
.71443 .35098 m .6838 .36086 L .66918 .34254 L p .652 .756 .926 r
F P
0 g
s
.63865 .3525 m .66918 .34254 L .6838 .36086 L p .652 .756 .926 r
F P
0 g
s
.54712 .33557 m .54694 .309 L .5172 .3191 L p .522 .293 .509 r
F P
0 g
s
.5172 .3191 m .51714 .34561 L .54712 .33557 L p .522 .293 .509 r
F P
0 g
s
.5172 .3191 m .50092 .30036 L .50112 .27417 L p .972 .685 .422 r
F P
0 g
s
.5172 .3191 m .50092 .30036 L .50112 .27417 L p .972 .685 .422 r
F P
0 g
s
.54694 .309 m .5172 .3191 L .50092 .30036 L p .654 .754 .923 r
F P
0 g
s
.54712 .33557 m .54694 .309 L .5172 .3191 L p .522 .293 .509 r
F P
0 g
s
.5172 .3191 m .51714 .34561 L .54712 .33557 L p .522 .293 .509 r
F P
0 g
s
.4713 .31056 m .50092 .30036 L .5172 .3191 L p .654 .754 .923 r
F P
0 g
s
.4713 .31056 m .50092 .30036 L .5172 .3191 L p .654 .754 .923 r
F P
0 g
s
.50092 .30036 m .5172 .3191 L .51714 .34561 L p .972 .685 .422 r
F P
0 g
s
.54694 .309 m .5172 .3191 L .50092 .30036 L p .654 .754 .923 r
F P
0 g
s
.50092 .30036 m .5172 .3191 L .51714 .34561 L p .972 .685 .422 r
F P
0 g
s
.6814 .23477 m .66674 .21519 L .66558 .18969 L p .976 .675 .358 r
F P
0 g
s
.71202 .22421 m .6814 .23477 L .66674 .21519 L p .658 .749 .917 r
F P
0 g
s
.71358 .2501 m .71202 .22421 L .6814 .23477 L p .526 .299 .513 r
F P
0 g
s
.6814 .23477 m .68269 .2606 L .71358 .2501 L p .526 .299 .513 r
F P
0 g
s
.63622 .22585 m .66674 .21519 L .6814 .23477 L p .658 .749 .917 r
F P
0 g
s
.66674 .21519 m .6814 .23477 L .68269 .2606 L p .976 .675 .358 r
F P
0 g
s
.71202 .22421 m .6814 .23477 L .66674 .21519 L p .658 .749 .917 r
F P
0 g
s
.66674 .21519 m .6814 .23477 L .68269 .2606 L p .976 .675 .358 r
F P
0 g
s
.6227 .30743 m .59253 .31755 L .57699 .29878 L p .654 .754 .923 r
F P
0 g
s
.62351 .33402 m .6227 .30743 L .59253 .31755 L p .526 .299 .513 r
F P
0 g
s
.59253 .31755 m .5931 .34408 L .62351 .33402 L p .526 .299 .513 r
F P
0 g
s
.54694 .309 m .57699 .29878 L .59253 .31755 L p .654 .754 .923 r
F P
0 g
s
.57699 .29878 m .59253 .31755 L .5931 .34408 L p .975 .682 .398 r
F P
0 g
s
.57699 .29878 m .59253 .31755 L .5931 .34408 L p .975 .682 .398 r
F P
0 g
s
.5036 .4004 m .48717 .38245 L .48747 .35555 L p .971 .686 .432 r
F P
0 g
s
.5036 .4004 m .48717 .38245 L .48747 .35555 L p .971 .686 .432 r
F P
0 g
s
.5333 .39072 m .5036 .4004 L .48717 .38245 L p .649 .759 .929 r
F P
0 g
s
.45758 .39221 m .48717 .38245 L .5036 .4004 L p .649 .759 .929 r
F P
0 g
s
.7569 .23316 m .74298 .21354 L .74119 .18804 L p .975 .668 .327 r
F P
0 g
s
.7569 .23316 m .74298 .21354 L .74119 .18804 L p .975 .668 .327 r
F P
0 g
s
.78795 .22258 m .7569 .23316 L .74298 .21354 L p .658 .749 .917 r
F P
0 g
s
.71202 .22421 m .74298 .21354 L .7569 .23316 L p .658 .749 .917 r
F P
0 g
s
.62025 .18055 m .59009 .19135 L .57452 .17132 L p .66 .747 .915 r
F P
0 g
s
.62105 .20609 m .62025 .18055 L .59009 .19135 L p .518 .287 .504 r
F P
0 g
s
.59009 .19135 m .59063 .21684 L .62105 .20609 L p .518 .287 .504 r
F P
0 g
s
.57452 .17132 m .59009 .19135 L .59063 .21684 L p .976 .68 .386 r
F P
0 g
s
.70003 .33246 m .69859 .30587 L .66799 .316 L p .53 .304 .517 r
F P
0 g
s
.66799 .316 m .66918 .34254 L .70003 .33246 L p .53 .304 .517 r
F P
0 g
s
.66799 .316 m .65319 .2972 L .65213 .271 L p .976 .678 .372 r
F P
0 g
s
.69859 .30587 m .66799 .316 L .65319 .2972 L p .654 .754 .923 r
F P
0 g
s
.70003 .33246 m .69859 .30587 L .66799 .316 L p .53 .304 .517 r
F P
0 g
s
.66799 .316 m .66918 .34254 L .70003 .33246 L p .53 .304 .517 r
F P
0 g
s
.6227 .30743 m .65319 .2972 L .66799 .316 L p .654 .754 .923 r
F P
0 g
s
.65319 .2972 m .66799 .316 L .66918 .34254 L p .976 .678 .372 r
F P
0 g
s
.69859 .30587 m .66799 .316 L .65319 .2972 L p .654 .754 .923 r
F P
0 g
s
.65319 .2972 m .66799 .316 L .66918 .34254 L p .976 .678 .372 r
F P
0 g
s
.53087 .29006 m .53082 .26381 L .50112 .27417 L p .518 .287 .504 r
F P
0 g
s
.50112 .27417 m .50092 .30036 L .53087 .29006 L p .518 .287 .504 r
F P
0 g
s
.57901 .39891 m .56332 .38093 L .563 .35403 L p .974 .684 .41 r
F P
0 g
s
.57901 .39891 m .56332 .38093 L .563 .35403 L p .974 .684 .41 r
F P
0 g
s
.60914 .38922 m .57901 .39891 L .56332 .38093 L p .649 .759 .929 r
F P
0 g
s
.5333 .39072 m .56332 .38093 L .57901 .39891 L p .649 .759 .929 r
F P
0 g
s
.6976 .20442 m .69617 .17887 L .66558 .18969 L p .522 .293 .509 r
F P
0 g
s
.66558 .18969 m .66674 .21519 L .6976 .20442 L p .522 .293 .509 r
F P
0 g
s
.69617 .17887 m .66558 .18969 L .65074 .16963 L p .66 .747 .915 r
F P
0 g
s
.6976 .20442 m .69617 .17887 L .66558 .18969 L p .522 .293 .509 r
F P
0 g
s
.66558 .18969 m .66674 .21519 L .6976 .20442 L p .522 .293 .509 r
F P
0 g
s
.62025 .18055 m .65074 .16963 L .66558 .18969 L p .66 .747 .915 r
F P
0 g
s
.65074 .16963 m .66558 .18969 L .66674 .21519 L p .976 .675 .358 r
F P
0 g
s
.65074 .16963 m .66558 .18969 L .66674 .21519 L p .976 .675 .358 r
F P
0 g
s
.60669 .26221 m .57656 .27259 L .56084 .25334 L p .656 .751 .92 r
F P
0 g
s
.60737 .28846 m .60669 .26221 L .57656 .27259 L p .522 .293 .509 r
F P
0 g
s
.57656 .27259 m .57699 .29878 L .60737 .28846 L p .522 .293 .509 r
F P
0 g
s
.53082 .26381 m .56084 .25334 L .57656 .27259 L p .656 .751 .92 r
F P
0 g
s
.56084 .25334 m .57656 .27259 L .57699 .29878 L p .975 .682 .398 r
F P
0 g
s
.56084 .25334 m .57656 .27259 L .57699 .29878 L p .975 .682 .398 r
F P
0 g
s
.60914 .38922 m .6396 .37942 L .65455 .39743 L p .649 .759 .929 r
F P
0 g
s
.65455 .39743 m .6396 .37942 L .63865 .3525 L p .976 .68 .386 r
F P
0 g
s
.51708 .37257 m .51714 .34561 L .48747 .35555 L p .522 .293 .509 r
F P
0 g
s
.48747 .35555 m .48717 .38245 L .51708 .37257 L p .522 .293 .509 r
F P
0 g
s
.48747 .35555 m .47086 .33712 L .4713 .31056 L p .971 .686 .432 r
F P
0 g
s
.48747 .35555 m .47086 .33712 L .4713 .31056 L p .971 .686 .432 r
F P
0 g
s
.51714 .34561 m .48747 .35555 L .47086 .33712 L p .652 .756 .926 r
F P
0 g
s
.44131 .34715 m .47086 .33712 L .48747 .35555 L p .652 .756 .926 r
F P
0 g
s
.77428 .20276 m .77221 .1772 L .74119 .18804 L p .526 .299 .513 r
F P
0 g
s
.74119 .18804 m .74298 .21354 L .77428 .20276 L p .526 .299 .513 r
F P
0 g
s
.77221 .1772 m .74119 .18804 L .7271 .16794 L p .66 .747 .915 r
F P
0 g
s
.77428 .20276 m .77221 .1772 L .74119 .18804 L p .526 .299 .513 r
F P
0 g
s
.74119 .18804 m .74298 .21354 L .77428 .20276 L p .526 .299 .513 r
F P
0 g
s
.69617 .17887 m .7271 .16794 L .74119 .18804 L p .66 .747 .915 r
F P
0 g
s
.7271 .16794 m .74119 .18804 L .74298 .21354 L p .975 .668 .327 r
F P
0 g
s
.7271 .16794 m .74119 .18804 L .74298 .21354 L p .975 .668 .327 r
F P
0 g
s
.68401 .28687 m .68269 .2606 L .65213 .271 L p .526 .299 .513 r
F P
0 g
s
.65213 .271 m .65319 .2972 L .68401 .28687 L p .526 .299 .513 r
F P
0 g
s
.65213 .271 m .63715 .25172 L .63622 .22585 L p .976 .678 .372 r
F P
0 g
s
.65213 .271 m .63715 .25172 L .63622 .22585 L p .976 .678 .372 r
F P
0 g
s
.68269 .2606 m .65213 .271 L .63715 .25172 L p .656 .751 .92 r
F P
0 g
s
.68401 .28687 m .68269 .2606 L .65213 .271 L p .526 .299 .513 r
F P
0 g
s
.65213 .271 m .65319 .2972 L .68401 .28687 L p .526 .299 .513 r
F P
0 g
s
.60669 .26221 m .63715 .25172 L .65213 .271 L p .656 .751 .92 r
F P
0 g
s
.63715 .25172 m .65213 .271 L .65319 .2972 L p .976 .678 .372 r
F P
0 g
s
.68269 .2606 m .65213 .271 L .63715 .25172 L p .656 .751 .92 r
F P
0 g
s
.59367 .37104 m .5931 .34408 L .563 .35403 L p .526 .299 .513 r
F P
0 g
s
.563 .35403 m .56332 .38093 L .59367 .37104 L p .526 .299 .513 r
F P
0 g
s
.563 .35403 m .54712 .33557 L .54694 .309 L p .974 .684 .41 r
F P
0 g
s
.563 .35403 m .54712 .33557 L .54694 .309 L p .974 .684 .41 r
F P
0 g
s
.5931 .34408 m .563 .35403 L .54712 .33557 L p .652 .756 .926 r
F P
0 g
s
.51714 .34561 m .54712 .33557 L .563 .35403 L p .652 .756 .926 r
F P
0 g
s
.63865 .3525 m .62351 .33402 L .6227 .30743 L p .976 .68 .386 r
F P
0 g
s
.66918 .34254 m .63865 .3525 L .62351 .33402 L p .652 .756 .926 r
F P
0 g
s
.67038 .36951 m .66918 .34254 L .63865 .3525 L p .53 .304 .517 r
F P
0 g
s
.63865 .3525 m .6396 .37942 L .67038 .36951 L p .53 .304 .517 r
F P
0 g
s
.5931 .34408 m .62351 .33402 L .63865 .3525 L p .652 .756 .926 r
F P
0 g
s
.62351 .33402 m .63865 .3525 L .6396 .37942 L p .976 .68 .386 r
F P
0 g
s
.66918 .34254 m .63865 .3525 L .62351 .33402 L p .652 .756 .926 r
F P
0 g
s
.62351 .33402 m .63865 .3525 L .6396 .37942 L p .976 .68 .386 r
F P
0 g
s
.50073 .32699 m .50092 .30036 L .4713 .31056 L p .518 .287 .504 r
F P
0 g
s
.4713 .31056 m .47086 .33712 L .50073 .32699 L p .518 .287 .504 r
F P
0 g
s
.66793 .24112 m .66674 .21519 L .63622 .22585 L p .522 .293 .509 r
F P
0 g
s
.63622 .22585 m .63715 .25172 L .66793 .24112 L p .522 .293 .509 r
F P
0 g
s
.63622 .22585 m .62105 .20609 L .62025 .18055 L p .976 .678 .372 r
F P
0 g
s
.66674 .21519 m .63622 .22585 L .62105 .20609 L p .658 .749 .917 r
F P
0 g
s
.66793 .24112 m .66674 .21519 L .63622 .22585 L p .522 .293 .509 r
F P
0 g
s
.63622 .22585 m .63715 .25172 L .66793 .24112 L p .522 .293 .509 r
F P
0 g
s
.59063 .21684 m .62105 .20609 L .63622 .22585 L p .658 .749 .917 r
F P
0 g
s
.62105 .20609 m .63622 .22585 L .63715 .25172 L p .976 .678 .372 r
F P
0 g
s
.66674 .21519 m .63622 .22585 L .62105 .20609 L p .658 .749 .917 r
F P
0 g
s
.62105 .20609 m .63622 .22585 L .63715 .25172 L p .976 .678 .372 r
F P
0 g
s
.66918 .34254 m .70003 .33246 L .71443 .35098 L p .652 .756 .926 r
F P
0 g
s
.71443 .35098 m .70003 .33246 L .69859 .30587 L p .976 .675 .358 r
F P
0 g
s
.57743 .32542 m .57699 .29878 L .54694 .309 L p .522 .293 .509 r
F P
0 g
s
.54694 .309 m .54712 .33557 L .57743 .32542 L p .522 .293 .509 r
F P
0 g
s
.54694 .309 m .53087 .29006 L .53082 .26381 L p .974 .684 .41 r
F P
0 g
s
.54694 .309 m .53087 .29006 L .53082 .26381 L p .974 .684 .41 r
F P
0 g
s
.57699 .29878 m .54694 .309 L .53087 .29006 L p .654 .754 .923 r
F P
0 g
s
.57743 .32542 m .57699 .29878 L .54694 .309 L p .522 .293 .509 r
F P
0 g
s
.54694 .309 m .54712 .33557 L .57743 .32542 L p .522 .293 .509 r
F P
0 g
s
.50092 .30036 m .53087 .29006 L .54694 .309 L p .654 .754 .923 r
F P
0 g
s
.50092 .30036 m .53087 .29006 L .54694 .309 L p .654 .754 .923 r
F P
0 g
s
.53087 .29006 m .54694 .309 L .54712 .33557 L p .974 .684 .41 r
F P
0 g
s
.57699 .29878 m .54694 .309 L .53087 .29006 L p .654 .754 .923 r
F P
0 g
s
.53087 .29006 m .54694 .309 L .54712 .33557 L p .974 .684 .41 r
F P
0 g
s
.71202 .22421 m .6976 .20442 L .69617 .17887 L p .976 .672 .343 r
F P
0 g
s
.71202 .22421 m .6976 .20442 L .69617 .17887 L p .976 .672 .343 r
F P
0 g
s
.74298 .21354 m .71202 .22421 L .6976 .20442 L p .658 .749 .917 r
F P
0 g
s
.74481 .23948 m .74298 .21354 L .71202 .22421 L p .526 .299 .513 r
F P
0 g
s
.71202 .22421 m .71358 .2501 L .74481 .23948 L p .526 .299 .513 r
F P
0 g
s
.66674 .21519 m .6976 .20442 L .71202 .22421 L p .658 .749 .917 r
F P
0 g
s
.66674 .21519 m .6976 .20442 L .71202 .22421 L p .658 .749 .917 r
F P
0 g
s
.6976 .20442 m .71202 .22421 L .71358 .2501 L p .976 .672 .343 r
F P
0 g
s
.74298 .21354 m .71202 .22421 L .6976 .20442 L p .658 .749 .917 r
F P
0 g
s
.6976 .20442 m .71202 .22421 L .71358 .2501 L p .976 .672 .343 r
F P
0 g
s
.57452 .17132 m .54446 .18222 L .52836 .162 L p .66 .747 .915 r
F P
0 g
s
.57494 .1969 m .57452 .17132 L .54446 .18222 L p .514 .281 .5 r
F P
0 g
s
.54446 .18222 m .54463 .20775 L .57494 .1969 L p .514 .281 .5 r
F P
0 g
s
.52836 .162 m .54446 .18222 L .54463 .20775 L p .975 .682 .398 r
F P
0 g
s
.65426 .32385 m .65319 .2972 L .6227 .30743 L p .526 .299 .513 r
F P
0 g
s
.6227 .30743 m .62351 .33402 L .65426 .32385 L p .526 .299 .513 r
F P
0 g
s
.65319 .2972 m .6227 .30743 L .60737 .28846 L p .654 .754 .923 r
F P
0 g
s
.65426 .32385 m .65319 .2972 L .6227 .30743 L p .526 .299 .513 r
F P
0 g
s
.6227 .30743 m .62351 .33402 L .65426 .32385 L p .526 .299 .513 r
F P
0 g
s
.57699 .29878 m .60737 .28846 L .6227 .30743 L p .654 .754 .923 r
F P
0 g
s
.60737 .28846 m .6227 .30743 L .62351 .33402 L p .976 .68 .386 r
F P
0 g
s
.60737 .28846 m .6227 .30743 L .62351 .33402 L p .976 .68 .386 r
F P
0 g
s
.48717 .38245 m .51708 .37257 L .5333 .39072 L p .649 .759 .929 r
F P
0 g
s
.5333 .39072 m .51708 .37257 L .51714 .34561 L p .972 .685 .422 r
F P
0 g
s
.74298 .21354 m .77428 .20276 L .78795 .22258 L p .658 .749 .917 r
F P
0 g
s
.78795 .22258 m .77428 .20276 L .77221 .1772 L p .973 .663 .31 r
F P
0 g
s
.6518 .19522 m .65074 .16963 L .62025 .18055 L p .518 .287 .504 r
F P
0 g
s
.62025 .18055 m .62105 .20609 L .6518 .19522 L p .518 .287 .504 r
F P
0 g
s
.65074 .16963 m .62025 .18055 L .6049 .1603 L p .66 .747 .915 r
F P
0 g
s
.6518 .19522 m .65074 .16963 L .62025 .18055 L p .518 .287 .504 r
F P
0 g
s
.62025 .18055 m .62105 .20609 L .6518 .19522 L p .518 .287 .504 r
F P
0 g
s
.57452 .17132 m .6049 .1603 L .62025 .18055 L p .66 .747 .915 r
F P
0 g
s
.6049 .1603 m .62025 .18055 L .62105 .20609 L p .976 .678 .372 r
F P
0 g
s
.6049 .1603 m .62025 .18055 L .62105 .20609 L p .976 .678 .372 r
F P
0 g
s
.65319 .2972 m .68401 .28687 L .69859 .30587 L p .654 .754 .923 r
F P
0 g
s
.65319 .2972 m .68401 .28687 L .69859 .30587 L p .654 .754 .923 r
F P
0 g
s
.68401 .28687 m .69859 .30587 L .70003 .33246 L p .976 .675 .358 r
F P
0 g
s
.69859 .30587 m .68401 .28687 L .68269 .2606 L p .976 .675 .358 r
F P
0 g
s
.56114 .27964 m .56084 .25334 L .53082 .26381 L p .518 .287 .504 r
F P
0 g
s
.53082 .26381 m .53087 .29006 L .56114 .27964 L p .518 .287 .504 r
F P
0 g
s
.60914 .38922 m .59367 .37104 L .5931 .34408 L p .975 .682 .398 r
F P
0 g
s
.60914 .38922 m .59367 .37104 L .5931 .34408 L p .975 .682 .398 r
F P
0 g
s
.6396 .37942 m .60914 .38922 L .59367 .37104 L p .649 .759 .929 r
F P
0 g
s
.56332 .38093 m .59367 .37104 L .60914 .38922 L p .649 .759 .929 r
F P
0 g
s
.72879 .19354 m .7271 .16794 L .69617 .17887 L p .522 .293 .509 r
F P
0 g
s
.69617 .17887 m .6976 .20442 L .72879 .19354 L p .522 .293 .509 r
F P
0 g
s
.7271 .16794 m .69617 .17887 L .68156 .1586 L p .66 .747 .915 r
F P
0 g
s
.72879 .19354 m .7271 .16794 L .69617 .17887 L p .522 .293 .509 r
F P
0 g
s
.69617 .17887 m .6976 .20442 L .72879 .19354 L p .522 .293 .509 r
F P
0 g
s
.65074 .16963 m .68156 .1586 L .69617 .17887 L p .66 .747 .915 r
F P
0 g
s
.68156 .1586 m .69617 .17887 L .6976 .20442 L p .976 .672 .343 r
F P
0 g
s
.68156 .1586 m .69617 .17887 L .6976 .20442 L p .976 .672 .343 r
F P
0 g
s
.60669 .26221 m .59118 .24276 L .59063 .21684 L p .976 .68 .386 r
F P
0 g
s
.63715 .25172 m .60669 .26221 L .59118 .24276 L p .656 .751 .92 r
F P
0 g
s
.63809 .27803 m .63715 .25172 L .60669 .26221 L p .522 .293 .509 r
F P
0 g
s
.60669 .26221 m .60737 .28846 L .63809 .27803 L p .522 .293 .509 r
F P
0 g
s
.56084 .25334 m .59118 .24276 L .60669 .26221 L p .656 .751 .92 r
F P
0 g
s
.59118 .24276 m .60669 .26221 L .60737 .28846 L p .976 .68 .386 r
F P
0 g
s
.63715 .25172 m .60669 .26221 L .59118 .24276 L p .656 .751 .92 r
F P
0 g
s
.59118 .24276 m .60669 .26221 L .60737 .28846 L p .976 .68 .386 r
F P
0 g
s
.51714 .34561 m .50073 .32699 L .50092 .30036 L p .972 .685 .422 r
F P
0 g
s
.51714 .34561 m .50073 .32699 L .50092 .30036 L p .972 .685 .422 r
F P
0 g
s
.54712 .33557 m .51714 .34561 L .50073 .32699 L p .652 .756 .926 r
F P
0 g
s
.47086 .33712 m .50073 .32699 L .51714 .34561 L p .652 .756 .926 r
F P
0 g
s
.7271 .16794 m .75835 .15689 L .77221 .1772 L p .66 .747 .915 r
F P
0 g
s
.75835 .15689 m .77221 .1772 L .77428 .20276 L p .973 .663 .31 r
F P
0 g
s
.68269 .2606 m .66793 .24112 L .66674 .21519 L p .976 .675 .358 r
F P
0 g
s
.68269 .2606 m .66793 .24112 L .66674 .21519 L p .976 .675 .358 r
F P
0 g
s
.71358 .2501 m .68269 .2606 L .66793 .24112 L p .656 .751 .92 r
F P
0 g
s
.63715 .25172 m .66793 .24112 L .68269 .2606 L p .656 .751 .92 r
F P
0 g
s
.63715 .25172 m .66793 .24112 L .68269 .2606 L p .656 .751 .92 r
F P
0 g
s
.66793 .24112 m .68269 .2606 L .68401 .28687 L p .976 .675 .358 r
F P
0 g
s
.62434 .36105 m .62351 .33402 L .5931 .34408 L p .526 .299 .513 r
F P
0 g
s
.5931 .34408 m .59367 .37104 L .62434 .36105 L p .526 .299 .513 r
F P
0 g
s
.5931 .34408 m .57743 .32542 L .57699 .29878 L p .975 .682 .398 r
F P
0 g
s
.5931 .34408 m .57743 .32542 L .57699 .29878 L p .975 .682 .398 r
F P
0 g
s
.62351 .33402 m .5931 .34408 L .57743 .32542 L p .652 .756 .926 r
F P
0 g
s
.62434 .36105 m .62351 .33402 L .5931 .34408 L p .526 .299 .513 r
F P
0 g
s
.5931 .34408 m .59367 .37104 L .62434 .36105 L p .526 .299 .513 r
F P
0 g
s
.54712 .33557 m .57743 .32542 L .5931 .34408 L p .652 .756 .926 r
F P
0 g
s
.57743 .32542 m .5931 .34408 L .59367 .37104 L p .975 .682 .398 r
F P
0 g
s
.62351 .33402 m .5931 .34408 L .57743 .32542 L p .652 .756 .926 r
F P
0 g
s
.62186 .23206 m .62105 .20609 L .59063 .21684 L p .518 .287 .504 r
F P
0 g
s
.59063 .21684 m .59118 .24276 L .62186 .23206 L p .518 .287 .504 r
F P
0 g
s
.59063 .21684 m .57494 .1969 L .57452 .17132 L p .976 .68 .386 r
F P
0 g
s
.62105 .20609 m .59063 .21684 L .57494 .1969 L p .658 .749 .917 r
F P
0 g
s
.62186 .23206 m .62105 .20609 L .59063 .21684 L p .518 .287 .504 r
F P
0 g
s
.59063 .21684 m .59118 .24276 L .62186 .23206 L p .518 .287 .504 r
F P
0 g
s
.57494 .1969 m .59063 .21684 L .59118 .24276 L p .976 .68 .386 r
F P
0 g
s
.62105 .20609 m .59063 .21684 L .57494 .1969 L p .658 .749 .917 r
F P
0 g
s
.66918 .34254 m .65426 .32385 L .65319 .2972 L p .976 .678 .372 r
F P
0 g
s
.66918 .34254 m .65426 .32385 L .65319 .2972 L p .976 .678 .372 r
F P
0 g
s
.70003 .33246 m .66918 .34254 L .65426 .32385 L p .652 .756 .926 r
F P
0 g
s
.62351 .33402 m .65426 .32385 L .66918 .34254 L p .652 .756 .926 r
F P
0 g
s
.62351 .33402 m .65426 .32385 L .66918 .34254 L p .652 .756 .926 r
F P
0 g
s
.65426 .32385 m .66918 .34254 L .67038 .36951 L p .976 .678 .372 r
F P
0 g
s
.53092 .31674 m .53087 .29006 L .50092 .30036 L p .518 .287 .504 r
F P
0 g
s
.50092 .30036 m .50073 .32699 L .53092 .31674 L p .518 .287 .504 r
F P
0 g
s
.69905 .2304 m .6976 .20442 L .66674 .21519 L p .522 .293 .509 r
F P
0 g
s
.66674 .21519 m .66793 .24112 L .69905 .2304 L p .522 .293 .509 r
F P
0 g
s
.66674 .21519 m .6518 .19522 L .65074 .16963 L p .976 .675 .358 r
F P
0 g
s
.66674 .21519 m .6518 .19522 L .65074 .16963 L p .976 .675 .358 r
F P
0 g
s
.6976 .20442 m .66674 .21519 L .6518 .19522 L p .658 .749 .917 r
F P
0 g
s
.69905 .2304 m .6976 .20442 L .66674 .21519 L p .522 .293 .509 r
F P
0 g
s
.66674 .21519 m .66793 .24112 L .69905 .2304 L p .522 .293 .509 r
F P
0 g
s
.62105 .20609 m .6518 .19522 L .66674 .21519 L p .658 .749 .917 r
F P
0 g
s
.62105 .20609 m .6518 .19522 L .66674 .21519 L p .658 .749 .917 r
F P
0 g
s
.6518 .19522 m .66674 .21519 L .66793 .24112 L p .976 .675 .358 r
F P
0 g
s
.6976 .20442 m .66674 .21519 L .6518 .19522 L p .658 .749 .917 r
F P
0 g
s
.6518 .19522 m .66674 .21519 L .66793 .24112 L p .976 .675 .358 r
F P
0 g
s
.60807 .31516 m .60737 .28846 L .57699 .29878 L p .522 .293 .509 r
F P
0 g
s
.57699 .29878 m .57743 .32542 L .60807 .31516 L p .522 .293 .509 r
F P
0 g
s
.57699 .29878 m .56114 .27964 L .56084 .25334 L p .975 .682 .398 r
F P
0 g
s
.57699 .29878 m .56114 .27964 L .56084 .25334 L p .975 .682 .398 r
F P
0 g
s
.60737 .28846 m .57699 .29878 L .56114 .27964 L p .654 .754 .923 r
F P
0 g
s
.60807 .31516 m .60737 .28846 L .57699 .29878 L p .522 .293 .509 r
F P
0 g
s
.57699 .29878 m .57743 .32542 L .60807 .31516 L p .522 .293 .509 r
F P
0 g
s
.53087 .29006 m .56114 .27964 L .57699 .29878 L p .654 .754 .923 r
F P
0 g
s
.53087 .29006 m .56114 .27964 L .57699 .29878 L p .654 .754 .923 r
F P
0 g
s
.56114 .27964 m .57699 .29878 L .57743 .32542 L p .975 .682 .398 r
F P
0 g
s
.60737 .28846 m .57699 .29878 L .56114 .27964 L p .654 .754 .923 r
F P
0 g
s
.56114 .27964 m .57699 .29878 L .57743 .32542 L p .975 .682 .398 r
F P
0 g
s
.74298 .21354 m .72879 .19354 L .7271 .16794 L p .975 .668 .327 r
F P
0 g
s
.74298 .21354 m .72879 .19354 L .7271 .16794 L p .975 .668 .327 r
F P
0 g
s
.77428 .20276 m .74298 .21354 L .72879 .19354 L p .658 .749 .917 r
F P
0 g
s
.6976 .20442 m .72879 .19354 L .74298 .21354 L p .658 .749 .917 r
F P
0 g
s
.6976 .20442 m .72879 .19354 L .74298 .21354 L p .658 .749 .917 r
F P
0 g
s
.72879 .19354 m .74298 .21354 L .74481 .23948 L p .975 .668 .327 r
F P
0 g
s
.60557 .18593 m .6049 .1603 L .57452 .17132 L p .514 .281 .5 r
F P
0 g
s
.57452 .17132 m .57494 .1969 L .60557 .18593 L p .514 .281 .5 r
F P
0 g
s
.6049 .1603 m .57452 .17132 L .55863 .15089 L p .66 .747 .915 r
F P
0 g
s
.60557 .18593 m .6049 .1603 L .57452 .17132 L p .514 .281 .5 r
F P
0 g
s
.57452 .17132 m .57494 .1969 L .60557 .18593 L p .514 .281 .5 r
F P
0 g
s
.52836 .162 m .55863 .15089 L .57452 .17132 L p .66 .747 .915 r
F P
0 g
s
.55863 .15089 m .57452 .17132 L .57494 .1969 L p .976 .68 .386 r
F P
0 g
s
.55863 .15089 m .57452 .17132 L .57494 .1969 L p .976 .68 .386 r
F P
0 g
s
.68535 .31357 m .68401 .28687 L .65319 .2972 L p .526 .299 .513 r
F P
0 g
s
.65319 .2972 m .65426 .32385 L .68535 .31357 L p .526 .299 .513 r
F P
0 g
s
.65319 .2972 m .63809 .27803 L .63715 .25172 L p .976 .678 .372 r
F P
0 g
s
.68401 .28687 m .65319 .2972 L .63809 .27803 L p .654 .754 .923 r
F P
0 g
s
.68535 .31357 m .68401 .28687 L .65319 .2972 L p .526 .299 .513 r
F P
0 g
s
.65319 .2972 m .65426 .32385 L .68535 .31357 L p .526 .299 .513 r
F P
0 g
s
.60737 .28846 m .63809 .27803 L .65319 .2972 L p .654 .754 .923 r
F P
0 g
s
.63809 .27803 m .65319 .2972 L .65426 .32385 L p .976 .678 .372 r
F P
0 g
s
.68401 .28687 m .65319 .2972 L .63809 .27803 L p .654 .754 .923 r
F P
0 g
s
.63809 .27803 m .65319 .2972 L .65426 .32385 L p .976 .678 .372 r
F P
0 g
s
.68288 .18423 m .68156 .1586 L .65074 .16963 L p .518 .287 .504 r
F P
0 g
s
.65074 .16963 m .6518 .19522 L .68288 .18423 L p .518 .287 .504 r
F P
0 g
s
.68156 .1586 m .65074 .16963 L .63561 .14917 L p .66 .747 .915 r
F P
0 g
s
.68288 .18423 m .68156 .1586 L .65074 .16963 L p .518 .287 .504 r
F P
0 g
s
.65074 .16963 m .6518 .19522 L .68288 .18423 L p .518 .287 .504 r
F P
0 g
s
.6049 .1603 m .63561 .14917 L .65074 .16963 L p .66 .747 .915 r
F P
0 g
s
.63561 .14917 m .65074 .16963 L .6518 .19522 L p .976 .675 .358 r
F P
0 g
s
.63561 .14917 m .65074 .16963 L .6518 .19522 L p .976 .675 .358 r
F P
0 g
s
.59174 .26911 m .59118 .24276 L .56084 .25334 L p .518 .287 .504 r
F P
0 g
s
.56084 .25334 m .56114 .27964 L .59174 .26911 L p .518 .287 .504 r
F P
0 g
s
.6396 .37942 m .62434 .36105 L .62351 .33402 L p .976 .68 .386 r
F P
0 g
s
.6396 .37942 m .62434 .36105 L .62351 .33402 L p .976 .68 .386 r
F P
0 g
s
.67038 .36951 m .6396 .37942 L .62434 .36105 L p .649 .759 .929 r
F P
0 g
s
.59367 .37104 m .62434 .36105 L .6396 .37942 L p .649 .759 .929 r
F P
0 g
s
.76032 .18253 m .75835 .15689 L .7271 .16794 L p .522 .293 .509 r
F P
0 g
s
.7271 .16794 m .72879 .19354 L .76032 .18253 L p .522 .293 .509 r
F P
0 g
s
.68156 .1586 m .71272 .14744 L .7271 .16794 L p .66 .747 .915 r
F P
0 g
s
.71272 .14744 m .7271 .16794 L .72879 .19354 L p .975 .668 .327 r
F P
0 g
s
.66914 .26748 m .66793 .24112 L .63715 .25172 L p .522 .293 .509 r
F P
0 g
s
.63715 .25172 m .63809 .27803 L .66914 .26748 L p .522 .293 .509 r
F P
0 g
s
.63715 .25172 m .62186 .23206 L .62105 .20609 L p .976 .678 .372 r
F P
0 g
s
.63715 .25172 m .62186 .23206 L .62105 .20609 L p .976 .678 .372 r
F P
0 g
s
.66793 .24112 m .63715 .25172 L .62186 .23206 L p .656 .751 .92 r
F P
0 g
s
.66914 .26748 m .66793 .24112 L .63715 .25172 L p .522 .293 .509 r
F P
0 g
s
.63715 .25172 m .63809 .27803 L .66914 .26748 L p .522 .293 .509 r
F P
0 g
s
.59118 .24276 m .62186 .23206 L .63715 .25172 L p .656 .751 .92 r
F P
0 g
s
.59118 .24276 m .62186 .23206 L .63715 .25172 L p .656 .751 .92 r
F P
0 g
s
.62186 .23206 m .63715 .25172 L .63809 .27803 L p .976 .678 .372 r
F P
0 g
s
.66793 .24112 m .63715 .25172 L .62186 .23206 L p .656 .751 .92 r
F P
0 g
s
.62186 .23206 m .63715 .25172 L .63809 .27803 L p .976 .678 .372 r
F P
0 g
s
.54712 .33557 m .53092 .31674 L .53087 .29006 L p .974 .684 .41 r
F P
0 g
s
.54712 .33557 m .53092 .31674 L .53087 .29006 L p .974 .684 .41 r
F P
0 g
s
.57743 .32542 m .54712 .33557 L .53092 .31674 L p .652 .756 .926 r
F P
0 g
s
.50073 .32699 m .53092 .31674 L .54712 .33557 L p .652 .756 .926 r
F P
0 g
s
.71358 .2501 m .69905 .2304 L .6976 .20442 L p .976 .672 .343 r
F P
0 g
s
.71358 .2501 m .69905 .2304 L .6976 .20442 L p .976 .672 .343 r
F P
0 g
s
.74481 .23948 m .71358 .2501 L .69905 .2304 L p .656 .751 .92 r
F P
0 g
s
.66793 .24112 m .69905 .2304 L .71358 .2501 L p .656 .751 .92 r
F P
0 g
s
.54463 .20775 m .5284 .18763 L .52836 .162 L p .975 .682 .398 r
F P
0 g
s
.57494 .1969 m .54463 .20775 L .5284 .18763 L p .658 .749 .917 r
F P
0 g
s
.65536 .35094 m .65426 .32385 L .62351 .33402 L p .526 .299 .513 r
F P
0 g
s
.62351 .33402 m .62434 .36105 L .65536 .35094 L p .526 .299 .513 r
F P
0 g
s
.62351 .33402 m .60807 .31516 L .60737 .28846 L p .976 .68 .386 r
F P
0 g
s
.62351 .33402 m .60807 .31516 L .60737 .28846 L p .976 .68 .386 r
F P
0 g
s
.65426 .32385 m .62351 .33402 L .60807 .31516 L p .652 .756 .926 r
F P
0 g
s
.65536 .35094 m .65426 .32385 L .62351 .33402 L p .526 .299 .513 r
F P
0 g
s
.62351 .33402 m .62434 .36105 L .65536 .35094 L p .526 .299 .513 r
F P
0 g
s
.57743 .32542 m .60807 .31516 L .62351 .33402 L p .652 .756 .926 r
F P
0 g
s
.57743 .32542 m .60807 .31516 L .62351 .33402 L p .652 .756 .926 r
F P
0 g
s
.60807 .31516 m .62351 .33402 L .62434 .36105 L p .976 .68 .386 r
F P
0 g
s
.65426 .32385 m .62351 .33402 L .60807 .31516 L p .652 .756 .926 r
F P
0 g
s
.60807 .31516 m .62351 .33402 L .62434 .36105 L p .976 .68 .386 r
F P
0 g
s
.65287 .22124 m .6518 .19522 L .62105 .20609 L p .518 .287 .504 r
F P
0 g
s
.62105 .20609 m .62186 .23206 L .65287 .22124 L p .518 .287 .504 r
F P
0 g
s
.62105 .20609 m .60557 .18593 L .6049 .1603 L p .976 .678 .372 r
F P
0 g
s
.62105 .20609 m .60557 .18593 L .6049 .1603 L p .976 .678 .372 r
F P
0 g
s
.6518 .19522 m .62105 .20609 L .60557 .18593 L p .658 .749 .917 r
F P
0 g
s
.65287 .22124 m .6518 .19522 L .62105 .20609 L p .518 .287 .504 r
F P
0 g
s
.62105 .20609 m .62186 .23206 L .65287 .22124 L p .518 .287 .504 r
F P
0 g
s
.57494 .1969 m .60557 .18593 L .62105 .20609 L p .658 .749 .917 r
F P
0 g
s
.57494 .1969 m .60557 .18593 L .62105 .20609 L p .658 .749 .917 r
F P
0 g
s
.60557 .18593 m .62105 .20609 L .62186 .23206 L p .976 .678 .372 r
F P
0 g
s
.6518 .19522 m .62105 .20609 L .60557 .18593 L p .658 .749 .917 r
F P
0 g
s
.60557 .18593 m .62105 .20609 L .62186 .23206 L p .976 .678 .372 r
F P
0 g
s
.65426 .32385 m .68535 .31357 L .70003 .33246 L p .652 .756 .926 r
F P
0 g
s
.70003 .33246 m .68535 .31357 L .68401 .28687 L p .976 .675 .358 r
F P
0 g
s
.56145 .30639 m .56114 .27964 L .53087 .29006 L p .518 .287 .504 r
F P
0 g
s
.53087 .29006 m .53092 .31674 L .56145 .30639 L p .518 .287 .504 r
F P
0 g
s
.73051 .21957 m .72879 .19354 L .6976 .20442 L p .522 .293 .509 r
F P
0 g
s
.6976 .20442 m .69905 .2304 L .73051 .21957 L p .522 .293 .509 r
F P
0 g
s
.6976 .20442 m .68288 .18423 L .68156 .1586 L p .976 .672 .343 r
F P
0 g
s
.6976 .20442 m .68288 .18423 L .68156 .1586 L p .976 .672 .343 r
F P
0 g
s
.72879 .19354 m .6976 .20442 L .68288 .18423 L p .658 .749 .917 r
F P
0 g
s
.73051 .21957 m .72879 .19354 L .6976 .20442 L p .522 .293 .509 r
F P
0 g
s
.6976 .20442 m .69905 .2304 L .73051 .21957 L p .522 .293 .509 r
F P
0 g
s
.6518 .19522 m .68288 .18423 L .6976 .20442 L p .658 .749 .917 r
F P
0 g
s
.6518 .19522 m .68288 .18423 L .6976 .20442 L p .658 .749 .917 r
F P
0 g
s
.68288 .18423 m .6976 .20442 L .69905 .2304 L p .976 .672 .343 r
F P
0 g
s
.72879 .19354 m .6976 .20442 L .68288 .18423 L p .658 .749 .917 r
F P
0 g
s
.68288 .18423 m .6976 .20442 L .69905 .2304 L p .976 .672 .343 r
F P
0 g
s
.55892 .17656 m .55863 .15089 L .52836 .162 L p .509 .275 .495 r
F P
0 g
s
.52836 .162 m .5284 .18763 L .55892 .17656 L p .509 .275 .495 r
F P
0 g
s
.55863 .15089 m .52836 .162 L .51194 .14139 L p .66 .747 .915 r
F P
0 g
s
.55892 .17656 m .55863 .15089 L .52836 .162 L p .509 .275 .495 r
F P
0 g
s
.52836 .162 m .5284 .18763 L .55892 .17656 L p .509 .275 .495 r
F P
0 g
s
.51194 .14139 m .52836 .162 L .5284 .18763 L p .975 .682 .398 r
F P
0 g
s
.63905 .30478 m .63809 .27803 L .60737 .28846 L p .522 .293 .509 r
F P
0 g
s
.60737 .28846 m .60807 .31516 L .63905 .30478 L p .522 .293 .509 r
F P
0 g
s
.60737 .28846 m .59174 .26911 L .59118 .24276 L p .976 .68 .386 r
F P
0 g
s
.60737 .28846 m .59174 .26911 L .59118 .24276 L p .976 .68 .386 r
F P
0 g
s
.63809 .27803 m .60737 .28846 L .59174 .26911 L p .654 .754 .923 r
F P
0 g
s
.63905 .30478 m .63809 .27803 L .60737 .28846 L p .522 .293 .509 r
F P
0 g
s
.60737 .28846 m .60807 .31516 L .63905 .30478 L p .522 .293 .509 r
F P
0 g
s
.56114 .27964 m .59174 .26911 L .60737 .28846 L p .654 .754 .923 r
F P
0 g
s
.56114 .27964 m .59174 .26911 L .60737 .28846 L p .654 .754 .923 r
F P
0 g
s
.59174 .26911 m .60737 .28846 L .60807 .31516 L p .976 .68 .386 r
F P
0 g
s
.63809 .27803 m .60737 .28846 L .59174 .26911 L p .654 .754 .923 r
F P
0 g
s
.59174 .26911 m .60737 .28846 L .60807 .31516 L p .976 .68 .386 r
F P
0 g
s
.72879 .19354 m .76032 .18253 L .77428 .20276 L p .658 .749 .917 r
F P
0 g
s
.77428 .20276 m .76032 .18253 L .75835 .15689 L p .973 .663 .31 r
F P
0 g
s
.63655 .17484 m .63561 .14917 L .6049 .1603 L p .514 .281 .5 r
F P
0 g
s
.6049 .1603 m .60557 .18593 L .63655 .17484 L p .514 .281 .5 r
F P
0 g
s
.63561 .14917 m .6049 .1603 L .58924 .13965 L p .66 .747 .915 r
F P
0 g
s
.63655 .17484 m .63561 .14917 L .6049 .1603 L p .514 .281 .5 r
F P
0 g
s
.6049 .1603 m .60557 .18593 L .63655 .17484 L p .514 .281 .5 r
F P
0 g
s
.55863 .15089 m .58924 .13965 L .6049 .1603 L p .66 .747 .915 r
F P
0 g
s
.58924 .13965 m .6049 .1603 L .60557 .18593 L p .976 .678 .372 r
F P
0 g
s
.58924 .13965 m .6049 .1603 L .60557 .18593 L p .976 .678 .372 r
F P
0 g
s
.63809 .27803 m .66914 .26748 L .68401 .28687 L p .654 .754 .923 r
F P
0 g
s
.63809 .27803 m .66914 .26748 L .68401 .28687 L p .654 .754 .923 r
F P
0 g
s
.66914 .26748 m .68401 .28687 L .68535 .31357 L p .976 .675 .358 r
F P
0 g
s
.68401 .28687 m .66914 .26748 L .66793 .24112 L p .976 .675 .358 r
F P
0 g
s
.59367 .37104 m .57787 .3525 L .57743 .32542 L p .975 .682 .398 r
F P
0 g
s
.62434 .36105 m .59367 .37104 L .57787 .3525 L p .649 .759 .929 r
F P
0 g
s
.71431 .17313 m .71272 .14744 L .68156 .1586 L p .518 .287 .504 r
F P
0 g
s
.68156 .1586 m .68288 .18423 L .71431 .17313 L p .518 .287 .504 r
F P
0 g
s
.71272 .14744 m .68156 .1586 L .66666 .13791 L p .66 .747 .915 r
F P
0 g
s
.71431 .17313 m .71272 .14744 L .68156 .1586 L p .518 .287 .504 r
F P
0 g
s
.68156 .1586 m .68288 .18423 L .71431 .17313 L p .518 .287 .504 r
F P
0 g
s
.63561 .14917 m .66666 .13791 L .68156 .1586 L p .66 .747 .915 r
F P
0 g
s
.66666 .13791 m .68156 .1586 L .68288 .18423 L p .976 .672 .343 r
F P
0 g
s
.66666 .13791 m .68156 .1586 L .68288 .18423 L p .976 .672 .343 r
F P
0 g
s
.62268 .25847 m .62186 .23206 L .59118 .24276 L p .518 .287 .504 r
F P
0 g
s
.59118 .24276 m .59174 .26911 L .62268 .25847 L p .518 .287 .504 r
F P
0 g
s
.59118 .24276 m .57536 .22291 L .57494 .1969 L p .976 .68 .386 r
F P
0 g
s
.62186 .23206 m .59118 .24276 L .57536 .22291 L p .656 .751 .92 r
F P
0 g
s
.62434 .36105 m .65536 .35094 L .67038 .36951 L p .649 .759 .929 r
F P
0 g
s
.67038 .36951 m .65536 .35094 L .65426 .32385 L p .976 .678 .372 r
F P
0 g
s
.66793 .24112 m .65287 .22124 L .6518 .19522 L p .976 .675 .358 r
F P
0 g
s
.66793 .24112 m .65287 .22124 L .6518 .19522 L p .976 .675 .358 r
F P
0 g
s
.69905 .2304 m .66793 .24112 L .65287 .22124 L p .656 .751 .92 r
F P
0 g
s
.70053 .25682 m .69905 .2304 L .66793 .24112 L p .522 .293 .509 r
F P
0 g
s
.66793 .24112 m .66914 .26748 L .70053 .25682 L p .522 .293 .509 r
F P
0 g
s
.62186 .23206 m .65287 .22124 L .66793 .24112 L p .656 .751 .92 r
F P
0 g
s
.62186 .23206 m .65287 .22124 L .66793 .24112 L p .656 .751 .92 r
F P
0 g
s
.65287 .22124 m .66793 .24112 L .66914 .26748 L p .976 .675 .358 r
F P
0 g
s
.69905 .2304 m .66793 .24112 L .65287 .22124 L p .656 .751 .92 r
F P
0 g
s
.65287 .22124 m .66793 .24112 L .66914 .26748 L p .976 .675 .358 r
F P
0 g
s
.60878 .3423 m .60807 .31516 L .57743 .32542 L p .522 .293 .509 r
F P
0 g
s
.57743 .32542 m .57787 .3525 L .60878 .3423 L p .522 .293 .509 r
F P
0 g
s
.57743 .32542 m .56145 .30639 L .56114 .27964 L p .975 .682 .398 r
F P
0 g
s
.57743 .32542 m .56145 .30639 L .56114 .27964 L p .975 .682 .398 r
F P
0 g
s
.60807 .31516 m .57743 .32542 L .56145 .30639 L p .652 .756 .926 r
F P
0 g
s
.53092 .31674 m .56145 .30639 L .57743 .32542 L p .652 .756 .926 r
F P
0 g
s
.69905 .2304 m .73051 .21957 L .74481 .23948 L p .656 .751 .92 r
F P
0 g
s
.74481 .23948 m .73051 .21957 L .72879 .19354 L p .975 .668 .327 r
F P
0 g
s
.60626 .21199 m .60557 .18593 L .57494 .1969 L p .514 .281 .5 r
F P
0 g
s
.57494 .1969 m .57536 .22291 L .60626 .21199 L p .514 .281 .5 r
F P
0 g
s
.57494 .1969 m .55892 .17656 L .55863 .15089 L p .976 .68 .386 r
F P
0 g
s
.57494 .1969 m .55892 .17656 L .55863 .15089 L p .976 .68 .386 r
F P
0 g
s
.60557 .18593 m .57494 .1969 L .55892 .17656 L p .658 .749 .917 r
F P
0 g
s
.60626 .21199 m .60557 .18593 L .57494 .1969 L p .514 .281 .5 r
F P
0 g
s
.57494 .1969 m .57536 .22291 L .60626 .21199 L p .514 .281 .5 r
F P
0 g
s
.5284 .18763 m .55892 .17656 L .57494 .1969 L p .658 .749 .917 r
F P
0 g
s
.55892 .17656 m .57494 .1969 L .57536 .22291 L p .976 .68 .386 r
F P
0 g
s
.60557 .18593 m .57494 .1969 L .55892 .17656 L p .658 .749 .917 r
F P
0 g
s
.65426 .32385 m .63905 .30478 L .63809 .27803 L p .976 .678 .372 r
F P
0 g
s
.65426 .32385 m .63905 .30478 L .63809 .27803 L p .976 .678 .372 r
F P
0 g
s
.68535 .31357 m .65426 .32385 L .63905 .30478 L p .652 .756 .926 r
F P
0 g
s
.60807 .31516 m .63905 .30478 L .65426 .32385 L p .652 .756 .926 r
F P
0 g
s
.60807 .31516 m .63905 .30478 L .65426 .32385 L p .652 .756 .926 r
F P
0 g
s
.63905 .30478 m .65426 .32385 L .65536 .35094 L p .976 .678 .372 r
F P
0 g
s
.68422 .2103 m .68288 .18423 L .6518 .19522 L p .518 .287 .504 r
F P
0 g
s
.6518 .19522 m .65287 .22124 L .68422 .2103 L p .518 .287 .504 r
F P
0 g
s
.6518 .19522 m .63655 .17484 L .63561 .14917 L p .976 .675 .358 r
F P
0 g
s
.6518 .19522 m .63655 .17484 L .63561 .14917 L p .976 .675 .358 r
F P
0 g
s
.68288 .18423 m .6518 .19522 L .63655 .17484 L p .658 .749 .917 r
F P
0 g
s
.68422 .2103 m .68288 .18423 L .6518 .19522 L p .518 .287 .504 r
F P
0 g
s
.6518 .19522 m .65287 .22124 L .68422 .2103 L p .518 .287 .504 r
F P
0 g
s
.60557 .18593 m .63655 .17484 L .6518 .19522 L p .658 .749 .917 r
F P
0 g
s
.60557 .18593 m .63655 .17484 L .6518 .19522 L p .658 .749 .917 r
F P
0 g
s
.63655 .17484 m .6518 .19522 L .65287 .22124 L p .976 .675 .358 r
F P
0 g
s
.68288 .18423 m .6518 .19522 L .63655 .17484 L p .658 .749 .917 r
F P
0 g
s
.63655 .17484 m .6518 .19522 L .65287 .22124 L p .976 .675 .358 r
F P
0 g
s
.59231 .29591 m .59174 .26911 L .56114 .27964 L p .518 .287 .504 r
F P
0 g
s
.56114 .27964 m .56145 .30639 L .59231 .29591 L p .518 .287 .504 r
F P
0 g
s
.68288 .18423 m .71431 .17313 L .72879 .19354 L p .658 .749 .917 r
F P
0 g
s
.68288 .18423 m .71431 .17313 L .72879 .19354 L p .658 .749 .917 r
F P
0 g
s
.71431 .17313 m .72879 .19354 L .73051 .21957 L p .975 .668 .327 r
F P
0 g
s
.72879 .19354 m .71431 .17313 L .71272 .14744 L p .975 .668 .327 r
F P
0 g
s
.58978 .16536 m .58924 .13965 L .55863 .15089 L p .509 .275 .495 r
F P
0 g
s
.55863 .15089 m .55892 .17656 L .58978 .16536 L p .509 .275 .495 r
F P
0 g
s
.58924 .13965 m .55863 .15089 L .54243 .13004 L p .66 .747 .915 r
F P
0 g
s
.58978 .16536 m .58924 .13965 L .55863 .15089 L p .509 .275 .495 r
F P
0 g
s
.55863 .15089 m .55892 .17656 L .58978 .16536 L p .509 .275 .495 r
F P
0 g
s
.51194 .14139 m .54243 .13004 L .55863 .15089 L p .66 .747 .915 r
F P
0 g
s
.54243 .13004 m .55863 .15089 L .55892 .17656 L p .976 .68 .386 r
F P
0 g
s
.54243 .13004 m .55863 .15089 L .55892 .17656 L p .976 .68 .386 r
F P
0 g
s
.67036 .29429 m .66914 .26748 L .63809 .27803 L p .522 .293 .509 r
F P
0 g
s
.63809 .27803 m .63905 .30478 L .67036 .29429 L p .522 .293 .509 r
F P
0 g
s
.63809 .27803 m .62268 .25847 L .62186 .23206 L p .976 .678 .372 r
F P
0 g
s
.63809 .27803 m .62268 .25847 L .62186 .23206 L p .976 .678 .372 r
F P
0 g
s
.66914 .26748 m .63809 .27803 L .62268 .25847 L p .654 .754 .923 r
F P
0 g
s
.67036 .29429 m .66914 .26748 L .63809 .27803 L p .522 .293 .509 r
F P
0 g
s
.63809 .27803 m .63905 .30478 L .67036 .29429 L p .522 .293 .509 r
F P
0 g
s
.59174 .26911 m .62268 .25847 L .63809 .27803 L p .654 .754 .923 r
F P
0 g
s
.59174 .26911 m .62268 .25847 L .63809 .27803 L p .654 .754 .923 r
F P
0 g
s
.62268 .25847 m .63809 .27803 L .63905 .30478 L p .976 .678 .372 r
F P
0 g
s
.66914 .26748 m .63809 .27803 L .62268 .25847 L p .654 .754 .923 r
F P
0 g
s
.62268 .25847 m .63809 .27803 L .63905 .30478 L p .976 .678 .372 r
F P
0 g
s
.66787 .16363 m .66666 .13791 L .63561 .14917 L p .514 .281 .5 r
F P
0 g
s
.63561 .14917 m .63655 .17484 L .66787 .16363 L p .514 .281 .5 r
F P
0 g
s
.66666 .13791 m .63561 .14917 L .62017 .12829 L p .66 .747 .915 r
F P
0 g
s
.66787 .16363 m .66666 .13791 L .63561 .14917 L p .514 .281 .5 r
F P
0 g
s
.63561 .14917 m .63655 .17484 L .66787 .16363 L p .514 .281 .5 r
F P
0 g
s
.58924 .13965 m .62017 .12829 L .63561 .14917 L p .66 .747 .915 r
F P
0 g
s
.62017 .12829 m .63561 .14917 L .63655 .17484 L p .976 .675 .358 r
F P
0 g
s
.62017 .12829 m .63561 .14917 L .63655 .17484 L p .976 .675 .358 r
F P
0 g
s
.66666 .13791 m .69805 .12653 L .71272 .14744 L p .66 .747 .915 r
F P
0 g
s
.69805 .12653 m .71272 .14744 L .71431 .17313 L p .975 .668 .327 r
F P
0 g
s
.62434 .36105 m .60878 .3423 L .60807 .31516 L p .976 .68 .386 r
F P
0 g
s
.62434 .36105 m .60878 .3423 L .60807 .31516 L p .976 .68 .386 r
F P
0 g
s
.65536 .35094 m .62434 .36105 L .60878 .3423 L p .649 .759 .929 r
F P
0 g
s
.57787 .3525 m .60878 .3423 L .62434 .36105 L p .649 .759 .929 r
F P
0 g
s
.65396 .2477 m .65287 .22124 L .62186 .23206 L p .518 .287 .504 r
F P
0 g
s
.62186 .23206 m .62268 .25847 L .65396 .2477 L p .518 .287 .504 r
F P
0 g
s
.62186 .23206 m .60626 .21199 L .60557 .18593 L p .976 .678 .372 r
F P
0 g
s
.62186 .23206 m .60626 .21199 L .60557 .18593 L p .976 .678 .372 r
F P
0 g
s
.65287 .22124 m .62186 .23206 L .60626 .21199 L p .656 .751 .92 r
F P
0 g
s
.65396 .2477 m .65287 .22124 L .62186 .23206 L p .518 .287 .504 r
F P
0 g
s
.62186 .23206 m .62268 .25847 L .65396 .2477 L p .518 .287 .504 r
F P
0 g
s
.57536 .22291 m .60626 .21199 L .62186 .23206 L p .656 .751 .92 r
F P
0 g
s
.60626 .21199 m .62186 .23206 L .62268 .25847 L p .976 .678 .372 r
F P
0 g
s
.65287 .22124 m .62186 .23206 L .60626 .21199 L p .656 .751 .92 r
F P
0 g
s
.69905 .2304 m .68422 .2103 L .68288 .18423 L p .976 .672 .343 r
F P
0 g
s
.69905 .2304 m .68422 .2103 L .68288 .18423 L p .976 .672 .343 r
F P
0 g
s
.73051 .21957 m .69905 .2304 L .68422 .2103 L p .656 .751 .92 r
F P
0 g
s
.65287 .22124 m .68422 .2103 L .69905 .2304 L p .656 .751 .92 r
F P
0 g
s
.65287 .22124 m .68422 .2103 L .69905 .2304 L p .656 .751 .92 r
F P
0 g
s
.68422 .2103 m .69905 .2304 L .70053 .25682 L p .976 .672 .343 r
F P
0 g
s
.5284 .18763 m .51183 .16709 L .51194 .14139 L p .975 .682 .398 r
F P
0 g
s
.55892 .17656 m .5284 .18763 L .51183 .16709 L p .658 .749 .917 r
F P
0 g
s
.64002 .33199 m .63905 .30478 L .60807 .31516 L p .522 .293 .509 r
F P
0 g
s
.60807 .31516 m .60878 .3423 L .64002 .33199 L p .522 .293 .509 r
F P
0 g
s
.60807 .31516 m .59231 .29591 L .59174 .26911 L p .976 .68 .386 r
F P
0 g
s
.60807 .31516 m .59231 .29591 L .59174 .26911 L p .976 .68 .386 r
F P
0 g
s
.63905 .30478 m .60807 .31516 L .59231 .29591 L p .652 .756 .926 r
F P
0 g
s
.56145 .30639 m .59231 .29591 L .60807 .31516 L p .652 .756 .926 r
F P
0 g
s
.6375 .20096 m .63655 .17484 L .60557 .18593 L p .514 .281 .5 r
F P
0 g
s
.60557 .18593 m .60626 .21199 L .6375 .20096 L p .514 .281 .5 r
F P
0 g
s
.60557 .18593 m .58978 .16536 L .58924 .13965 L p .976 .678 .372 r
F P
0 g
s
.60557 .18593 m .58978 .16536 L .58924 .13965 L p .976 .678 .372 r
F P
0 g
s
.63655 .17484 m .60557 .18593 L .58978 .16536 L p .658 .749 .917 r
F P
0 g
s
.6375 .20096 m .63655 .17484 L .60557 .18593 L p .514 .281 .5 r
F P
0 g
s
.60557 .18593 m .60626 .21199 L .6375 .20096 L p .514 .281 .5 r
F P
0 g
s
.55892 .17656 m .58978 .16536 L .60557 .18593 L p .658 .749 .917 r
F P
0 g
s
.55892 .17656 m .58978 .16536 L .60557 .18593 L p .658 .749 .917 r
F P
0 g
s
.58978 .16536 m .60557 .18593 L .60626 .21199 L p .976 .678 .372 r
F P
0 g
s
.63655 .17484 m .60557 .18593 L .58978 .16536 L p .658 .749 .917 r
F P
0 g
s
.58978 .16536 m .60557 .18593 L .60626 .21199 L p .976 .678 .372 r
F P
0 g
s
.63905 .30478 m .67036 .29429 L .68535 .31357 L p .652 .756 .926 r
F P
0 g
s
.68535 .31357 m .67036 .29429 L .66914 .26748 L p .976 .675 .358 r
F P
0 g
s
.71592 .19925 m .71431 .17313 L .68288 .18423 L p .518 .287 .504 r
F P
0 g
s
.68288 .18423 m .68422 .2103 L .71592 .19925 L p .518 .287 .504 r
F P
0 g
s
.68288 .18423 m .66787 .16363 L .66666 .13791 L p .976 .672 .343 r
F P
0 g
s
.68288 .18423 m .66787 .16363 L .66666 .13791 L p .976 .672 .343 r
F P
0 g
s
.71431 .17313 m .68288 .18423 L .66787 .16363 L p .658 .749 .917 r
F P
0 g
s
.71592 .19925 m .71431 .17313 L .68288 .18423 L p .518 .287 .504 r
F P
0 g
s
.68288 .18423 m .68422 .2103 L .71592 .19925 L p .518 .287 .504 r
F P
0 g
s
.63655 .17484 m .66787 .16363 L .68288 .18423 L p .658 .749 .917 r
F P
0 g
s
.63655 .17484 m .66787 .16363 L .68288 .18423 L p .658 .749 .917 r
F P
0 g
s
.66787 .16363 m .68288 .18423 L .68422 .2103 L p .976 .672 .343 r
F P
0 g
s
.71431 .17313 m .68288 .18423 L .66787 .16363 L p .658 .749 .917 r
F P
0 g
s
.66787 .16363 m .68288 .18423 L .68422 .2103 L p .976 .672 .343 r
F P
0 g
s
.54258 .1558 m .54243 .13004 L .51194 .14139 L p .504 .268 .49 r
F P
0 g
s
.51194 .14139 m .51183 .16709 L .54258 .1558 L p .504 .268 .49 r
F P
0 g
s
.62352 .28533 m .62268 .25847 L .59174 .26911 L p .518 .287 .504 r
F P
0 g
s
.59174 .26911 m .59231 .29591 L .62352 .28533 L p .518 .287 .504 r
F P
0 g
s
.62099 .15405 m .62017 .12829 L .58924 .13965 L p .509 .275 .495 r
F P
0 g
s
.58924 .13965 m .58978 .16536 L .62099 .15405 L p .509 .275 .495 r
F P
0 g
s
.54243 .13004 m .57325 .11858 L .58924 .13965 L p .66 .747 .915 r
F P
0 g
s
.57325 .11858 m .58924 .13965 L .58978 .16536 L p .976 .678 .372 r
F P
0 g
s
.66914 .26748 m .65396 .2477 L .65287 .22124 L p .976 .675 .358 r
F P
0 g
s
.66914 .26748 m .65396 .2477 L .65287 .22124 L p .976 .675 .358 r
F P
0 g
s
.70053 .25682 m .66914 .26748 L .65396 .2477 L p .654 .754 .923 r
F P
0 g
s
.62268 .25847 m .65396 .2477 L .66914 .26748 L p .654 .754 .923 r
F P
0 g
s
.62268 .25847 m .65396 .2477 L .66914 .26748 L p .654 .754 .923 r
F P
0 g
s
.65396 .2477 m .66914 .26748 L .67036 .29429 L p .976 .675 .358 r
F P
0 g
s
.69953 .1523 m .69805 .12653 L .66666 .13791 L p .514 .281 .5 r
F P
0 g
s
.66666 .13791 m .66787 .16363 L .69953 .1523 L p .514 .281 .5 r
F P
0 g
s
.69805 .12653 m .66666 .13791 L .65145 .1168 L p .66 .747 .915 r
F P
0 g
s
.69953 .1523 m .69805 .12653 L .66666 .13791 L p .514 .281 .5 r
F P
0 g
s
.66666 .13791 m .66787 .16363 L .69953 .1523 L p .514 .281 .5 r
F P
0 g
s
.62017 .12829 m .65145 .1168 L .66666 .13791 L p .66 .747 .915 r
F P
0 g
s
.65145 .1168 m .66666 .13791 L .66787 .16363 L p .976 .672 .343 r
F P
0 g
s
.65145 .1168 m .66666 .13791 L .66787 .16363 L p .976 .672 .343 r
F P
0 g
s
.57536 .22291 m .55921 .20266 L .55892 .17656 L p .976 .68 .386 r
F P
0 g
s
.60626 .21199 m .57536 .22291 L .55921 .20266 L p .656 .751 .92 r
F P
0 g
s
.60878 .3423 m .64002 .33199 L .65536 .35094 L p .649 .759 .929 r
F P
0 g
s
.65536 .35094 m .64002 .33199 L .63905 .30478 L p .976 .678 .372 r
F P
0 g
s
.68559 .23682 m .68422 .2103 L .65287 .22124 L p .518 .287 .504 r
F P
0 g
s
.65287 .22124 m .65396 .2477 L .68559 .23682 L p .518 .287 .504 r
F P
0 g
s
.65287 .22124 m .6375 .20096 L .63655 .17484 L p .976 .675 .358 r
F P
0 g
s
.65287 .22124 m .6375 .20096 L .63655 .17484 L p .976 .675 .358 r
F P
0 g
s
.68422 .2103 m .65287 .22124 L .6375 .20096 L p .656 .751 .92 r
F P
0 g
s
.68559 .23682 m .68422 .2103 L .65287 .22124 L p .518 .287 .504 r
F P
0 g
s
.65287 .22124 m .65396 .2477 L .68559 .23682 L p .518 .287 .504 r
F P
0 g
s
.60626 .21199 m .6375 .20096 L .65287 .22124 L p .656 .751 .92 r
F P
0 g
s
.60626 .21199 m .6375 .20096 L .65287 .22124 L p .656 .751 .92 r
F P
0 g
s
.6375 .20096 m .65287 .22124 L .65396 .2477 L p .976 .675 .358 r
F P
0 g
s
.68422 .2103 m .65287 .22124 L .6375 .20096 L p .656 .751 .92 r
F P
0 g
s
.6375 .20096 m .65287 .22124 L .65396 .2477 L p .976 .675 .358 r
F P
0 g
s
.68422 .2103 m .71592 .19925 L .73051 .21957 L p .656 .751 .92 r
F P
0 g
s
.73051 .21957 m .71592 .19925 L .71431 .17313 L p .975 .668 .327 r
F P
0 g
s
.59034 .19152 m .58978 .16536 L .55892 .17656 L p .509 .275 .495 r
F P
0 g
s
.55892 .17656 m .55921 .20266 L .59034 .19152 L p .509 .275 .495 r
F P
0 g
s
.55892 .17656 m .54258 .1558 L .54243 .13004 L p .976 .68 .386 r
F P
0 g
s
.55892 .17656 m .54258 .1558 L .54243 .13004 L p .976 .68 .386 r
F P
0 g
s
.58978 .16536 m .55892 .17656 L .54258 .1558 L p .658 .749 .917 r
F P
0 g
s
.51183 .16709 m .54258 .1558 L .55892 .17656 L p .658 .749 .917 r
F P
0 g
s
.63905 .30478 m .62352 .28533 L .62268 .25847 L p .976 .678 .372 r
F P
0 g
s
.63905 .30478 m .62352 .28533 L .62268 .25847 L p .976 .678 .372 r
F P
0 g
s
.67036 .29429 m .63905 .30478 L .62352 .28533 L p .652 .756 .926 r
F P
0 g
s
.59231 .29591 m .62352 .28533 L .63905 .30478 L p .652 .756 .926 r
F P
0 g
s
.66909 .18979 m .66787 .16363 L .63655 .17484 L p .514 .281 .5 r
F P
0 g
s
.63655 .17484 m .6375 .20096 L .66909 .18979 L p .514 .281 .5 r
F P
0 g
s
.63655 .17484 m .62099 .15405 L .62017 .12829 L p .976 .675 .358 r
F P
0 g
s
.63655 .17484 m .62099 .15405 L .62017 .12829 L p .976 .675 .358 r
F P
0 g
s
.66787 .16363 m .63655 .17484 L .62099 .15405 L p .658 .749 .917 r
F P
0 g
s
.66909 .18979 m .66787 .16363 L .63655 .17484 L p .514 .281 .5 r
F P
0 g
s
.63655 .17484 m .6375 .20096 L .66909 .18979 L p .514 .281 .5 r
F P
0 g
s
.58978 .16536 m .62099 .15405 L .63655 .17484 L p .658 .749 .917 r
F P
0 g
s
.58978 .16536 m .62099 .15405 L .63655 .17484 L p .658 .749 .917 r
F P
0 g
s
.62099 .15405 m .63655 .17484 L .6375 .20096 L p .976 .675 .358 r
F P
0 g
s
.66787 .16363 m .63655 .17484 L .62099 .15405 L p .658 .749 .917 r
F P
0 g
s
.62099 .15405 m .63655 .17484 L .6375 .20096 L p .976 .675 .358 r
F P
0 g
s
.66787 .16363 m .69953 .1523 L .71431 .17313 L p .658 .749 .917 r
F P
0 g
s
.66787 .16363 m .69953 .1523 L .71431 .17313 L p .658 .749 .917 r
F P
0 g
s
.69953 .1523 m .71431 .17313 L .71592 .19925 L p .975 .668 .327 r
F P
0 g
s
.71431 .17313 m .69953 .1523 L .69805 .12653 L p .975 .668 .327 r
F P
0 g
s
.57367 .14437 m .57325 .11858 L .54243 .13004 L p .504 .268 .49 r
F P
0 g
s
.54243 .13004 m .54258 .1558 L .57367 .14437 L p .504 .268 .49 r
F P
0 g
s
.65507 .27462 m .65396 .2477 L .62268 .25847 L p .518 .287 .504 r
F P
0 g
s
.62268 .25847 m .62352 .28533 L .65507 .27462 L p .518 .287 .504 r
F P
0 g
s
.62268 .25847 m .60696 .2385 L .60626 .21199 L p .976 .678 .372 r
F P
0 g
s
.65396 .2477 m .62268 .25847 L .60696 .2385 L p .654 .754 .923 r
F P
0 g
s
.65254 .14261 m .65145 .1168 L .62017 .12829 L p .509 .275 .495 r
F P
0 g
s
.62017 .12829 m .62099 .15405 L .65254 .14261 L p .509 .275 .495 r
F P
0 g
s
.65396 .2477 m .68559 .23682 L .70053 .25682 L p .654 .754 .923 r
F P
0 g
s
.70053 .25682 m .68559 .23682 L .68422 .2103 L p .976 .672 .343 r
F P
0 g
s
.72979 .11502 m .69805 .12653 L .68308 .10519 L p .66 .747 .915 r
F P
0 g
s
.73155 .14083 m .72979 .11502 L .69805 .12653 L p .514 .281 .5 r
F P
0 g
s
.69805 .12653 m .69953 .1523 L .73155 .14083 L p .514 .281 .5 r
F P
0 g
s
.65145 .1168 m .68308 .10519 L .69805 .12653 L p .66 .747 .915 r
F P
0 g
s
.68308 .10519 m .69805 .12653 L .69953 .1523 L p .975 .668 .327 r
F P
0 g
s
.68308 .10519 m .69805 .12653 L .69953 .1523 L p .975 .668 .327 r
F P
0 g
s
.63847 .22752 m .6375 .20096 L .60626 .21199 L p .514 .281 .5 r
F P
0 g
s
.60626 .21199 m .60696 .2385 L .63847 .22752 L p .514 .281 .5 r
F P
0 g
s
.60626 .21199 m .59034 .19152 L .58978 .16536 L p .976 .678 .372 r
F P
0 g
s
.60626 .21199 m .59034 .19152 L .58978 .16536 L p .976 .678 .372 r
F P
0 g
s
.6375 .20096 m .60626 .21199 L .59034 .19152 L p .656 .751 .92 r
F P
0 g
s
.55921 .20266 m .59034 .19152 L .60626 .21199 L p .656 .751 .92 r
F P
0 g
s
.68422 .2103 m .66909 .18979 L .66787 .16363 L p .976 .672 .343 r
F P
0 g
s
.68422 .2103 m .66909 .18979 L .66787 .16363 L p .976 .672 .343 r
F P
0 g
s
.71592 .19925 m .68422 .2103 L .66909 .18979 L p .656 .751 .92 r
F P
0 g
s
.6375 .20096 m .66909 .18979 L .68422 .2103 L p .656 .751 .92 r
F P
0 g
s
.6375 .20096 m .66909 .18979 L .68422 .2103 L p .656 .751 .92 r
F P
0 g
s
.66909 .18979 m .68422 .2103 L .68559 .23682 L p .976 .672 .343 r
F P
0 g
s
.62182 .18025 m .62099 .15405 L .58978 .16536 L p .509 .275 .495 r
F P
0 g
s
.58978 .16536 m .59034 .19152 L .62182 .18025 L p .509 .275 .495 r
F P
0 g
s
.54258 .1558 m .57367 .14437 L .58978 .16536 L p .658 .749 .917 r
F P
0 g
s
.58978 .16536 m .57367 .14437 L .57325 .11858 L p .976 .678 .372 r
F P
0 g
s
.62352 .28533 m .65507 .27462 L .67036 .29429 L p .652 .756 .926 r
F P
0 g
s
.67036 .29429 m .65507 .27462 L .65396 .2477 L p .976 .675 .358 r
F P
0 g
s
.70104 .17851 m .69953 .1523 L .66787 .16363 L p .514 .281 .5 r
F P
0 g
s
.66787 .16363 m .66909 .18979 L .70104 .17851 L p .514 .281 .5 r
F P
0 g
s
.66787 .16363 m .65254 .14261 L .65145 .1168 L p .976 .672 .343 r
F P
0 g
s
.66787 .16363 m .65254 .14261 L .65145 .1168 L p .976 .672 .343 r
F P
0 g
s
.69953 .1523 m .66787 .16363 L .65254 .14261 L p .658 .749 .917 r
F P
0 g
s
.70104 .17851 m .69953 .1523 L .66787 .16363 L p .514 .281 .5 r
F P
0 g
s
.66787 .16363 m .66909 .18979 L .70104 .17851 L p .514 .281 .5 r
F P
0 g
s
.62099 .15405 m .65254 .14261 L .66787 .16363 L p .658 .749 .917 r
F P
0 g
s
.62099 .15405 m .65254 .14261 L .66787 .16363 L p .658 .749 .917 r
F P
0 g
s
.65254 .14261 m .66787 .16363 L .66909 .18979 L p .976 .672 .343 r
F P
0 g
s
.69953 .1523 m .66787 .16363 L .65254 .14261 L p .658 .749 .917 r
F P
0 g
s
.65254 .14261 m .66787 .16363 L .66909 .18979 L p .976 .672 .343 r
F P
0 g
s
.65396 .2477 m .63847 .22752 L .6375 .20096 L p .976 .675 .358 r
F P
0 g
s
.65396 .2477 m .63847 .22752 L .6375 .20096 L p .976 .675 .358 r
F P
0 g
s
.68559 .23682 m .65396 .2477 L .63847 .22752 L p .654 .754 .923 r
F P
0 g
s
.60696 .2385 m .63847 .22752 L .65396 .2477 L p .654 .754 .923 r
F P
0 g
s
.68445 .13104 m .68308 .10519 L .65145 .1168 L p .509 .275 .495 r
F P
0 g
s
.65145 .1168 m .65254 .14261 L .68445 .13104 L p .509 .275 .495 r
F P
0 g
s
.68308 .10519 m .65145 .1168 L .63593 .09526 L p .66 .747 .915 r
F P
0 g
s
.68445 .13104 m .68308 .10519 L .65145 .1168 L p .509 .275 .495 r
F P
0 g
s
.65145 .1168 m .65254 .14261 L .68445 .13104 L p .509 .275 .495 r
F P
0 g
s
.63593 .09526 m .65145 .1168 L .65254 .14261 L p .976 .672 .343 r
F P
0 g
s
.68308 .10519 m .71506 .09344 L .72979 .11502 L p .66 .747 .915 r
F P
0 g
s
.71506 .09344 m .72979 .11502 L .73155 .14083 L p .973 .663 .31 r
F P
0 g
s
.67034 .21641 m .66909 .18979 L .6375 .20096 L p .514 .281 .5 r
F P
0 g
s
.6375 .20096 m .63847 .22752 L .67034 .21641 L p .514 .281 .5 r
F P
0 g
s
.6375 .20096 m .62182 .18025 L .62099 .15405 L p .976 .675 .358 r
F P
0 g
s
.6375 .20096 m .62182 .18025 L .62099 .15405 L p .976 .675 .358 r
F P
0 g
s
.66909 .18979 m .6375 .20096 L .62182 .18025 L p .656 .751 .92 r
F P
0 g
s
.59034 .19152 m .62182 .18025 L .6375 .20096 L p .656 .751 .92 r
F P
0 g
s
.66909 .18979 m .70104 .17851 L .71592 .19925 L p .656 .751 .92 r
F P
0 g
s
.71592 .19925 m .70104 .17851 L .69953 .1523 L p .975 .668 .327 r
F P
0 g
s
.65365 .16886 m .65254 .14261 L .62099 .15405 L p .509 .275 .495 r
F P
0 g
s
.62099 .15405 m .62182 .18025 L .65365 .16886 L p .509 .275 .495 r
F P
0 g
s
.69953 .1523 m .68445 .13104 L .68308 .10519 L p .975 .668 .327 r
F P
0 g
s
.69953 .1523 m .68445 .13104 L .68308 .10519 L p .975 .668 .327 r
F P
0 g
s
.73155 .14083 m .69953 .1523 L .68445 .13104 L p .658 .749 .917 r
F P
0 g
s
.65254 .14261 m .68445 .13104 L .69953 .1523 L p .658 .749 .917 r
F P
0 g
s
.65254 .14261 m .68445 .13104 L .69953 .1523 L p .658 .749 .917 r
F P
0 g
s
.68445 .13104 m .69953 .1523 L .70104 .17851 L p .975 .668 .327 r
F P
0 g
s
.63847 .22752 m .67034 .21641 L .68559 .23682 L p .654 .754 .923 r
F P
0 g
s
.68559 .23682 m .67034 .21641 L .66909 .18979 L p .976 .672 .343 r
F P
0 g
s
.71671 .11933 m .71506 .09344 L .68308 .10519 L p .509 .275 .495 r
F P
0 g
s
.68308 .10519 m .68445 .13104 L .71671 .11933 L p .509 .275 .495 r
F P
0 g
s
.71506 .09344 m .68308 .10519 L .6678 .0834 L p .66 .747 .915 r
F P
0 g
s
.71671 .11933 m .71506 .09344 L .68308 .10519 L p .509 .275 .495 r
F P
0 g
s
.68308 .10519 m .68445 .13104 L .71671 .11933 L p .509 .275 .495 r
F P
0 g
s
.63593 .09526 m .6678 .0834 L .68308 .10519 L p .66 .747 .915 r
F P
0 g
s
.6678 .0834 m .68308 .10519 L .68445 .13104 L p .975 .668 .327 r
F P
0 g
s
.6678 .0834 m .68308 .10519 L .68445 .13104 L p .975 .668 .327 r
F P
0 g
s
.66909 .18979 m .65365 .16886 L .65254 .14261 L p .976 .672 .343 r
F P
0 g
s
.66909 .18979 m .65365 .16886 L .65254 .14261 L p .976 .672 .343 r
F P
0 g
s
.70104 .17851 m .66909 .18979 L .65365 .16886 L p .656 .751 .92 r
F P
0 g
s
.62182 .18025 m .65365 .16886 L .66909 .18979 L p .656 .751 .92 r
F P
0 g
s
.68584 .15733 m .68445 .13104 L .65254 .14261 L p .509 .275 .495 r
F P
0 g
s
.65254 .14261 m .65365 .16886 L .68584 .15733 L p .509 .275 .495 r
F P
0 g
s
.65254 .14261 m .6369 .12114 L .63593 .09526 L p .976 .672 .343 r
F P
0 g
s
.68445 .13104 m .65254 .14261 L .6369 .12114 L p .658 .749 .917 r
F P
0 g
s
.68445 .13104 m .71671 .11933 L .73155 .14083 L p .658 .749 .917 r
F P
0 g
s
.73155 .14083 m .71671 .11933 L .71506 .09344 L p .973 .663 .31 r
F P
0 g
s
.66905 .10933 m .6678 .0834 L .63593 .09526 L p .504 .268 .49 r
F P
0 g
s
.63593 .09526 m .6369 .12114 L .66905 .10933 L p .504 .268 .49 r
F P
0 g
s
.6678 .0834 m .70003 .07141 L .71506 .09344 L p .66 .747 .915 r
F P
0 g
s
.70003 .07141 m .71506 .09344 L .71671 .11933 L p .973 .663 .31 r
F P
0 g
s
.65365 .16886 m .68584 .15733 L .70104 .17851 L p .656 .751 .92 r
F P
0 g
s
.70104 .17851 m .68584 .15733 L .68445 .13104 L p .975 .668 .327 r
F P
0 g
s
.68445 .13104 m .66905 .10933 L .6678 .0834 L p .975 .668 .327 r
F P
0 g
s
.68445 .13104 m .66905 .10933 L .6678 .0834 L p .975 .668 .327 r
F P
0 g
s
.71671 .11933 m .68445 .13104 L .66905 .10933 L p .658 .749 .917 r
F P
0 g
s
.6369 .12114 m .66905 .10933 L .68445 .13104 L p .658 .749 .917 r
F P
0 g
s
.70157 .09738 m .70003 .07141 L .6678 .0834 L p .504 .268 .49 r
F P
0 g
s
.6678 .0834 m .66905 .10933 L .70157 .09738 L p .504 .268 .49 r
F P
0 g
s
.66905 .10933 m .70157 .09738 L .71671 .11933 L p .658 .749 .917 r
F P
0 g
s
.71671 .11933 m .70157 .09738 L .70003 .07141 L p .973 .663 .31 r
F P
0 g
s
.25 Mabswid
.69249 0 m
.97887 .43151 L
s
.97887 .43151 m
1 .5861 L
s
1 .5861 m
.7023 .16913 L
s
.7023 .16913 m
.69249 0 L
s
.02561 .25675 m
0 .41836 L
s
0 .41836 m
.7023 .16913 L
s
.7023 .16913 m
.69249 0 L
s
.69249 0 m
.02561 .25675 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 215.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000ea000`40O003h00OaGoo0P00FGoo0033
Ool200000goo0000001HOol00<1oo`<000=oo`8005Qoo`00_Goo0`001Woo00<007oo0000Egoo002k
Ool20009Ool01000Oomoo`00EWoo002hOol3000;Ool01000Oomoo`00EWoo002fOol2000>Ool01@00
Oomoogoo0000EGoo002cOol3000@Ool00`00Oomoo`02Ool00`00Oomoo`1BOol00;5oo`8001=oo`03
001oogoo009oo`03001oogoo059oo`00[Woo0`005Woo00<007ooOol00Woo00<007ooOol0DGoo002[
Ool3000IOol00`00Oomoo`03Ool00`00Oomoo`1@Ool00:Uoo`8001aoo`03001oogoo00=oo`03001o
ogoo051oo`00YWoo0`007Woo00<007ooOol017oo00<007ooOol0Cgoo002TOol2000QOol00`00Oomo
o`05Ool00`00Oomoo`1>Ool00:5oo`<002=oo`03001oogoo00Eoo`03001oogoo04ioo`00WWoo0`00
9Woo00<007ooOol01Woo00<007ooOol0CGoo002LOol2000YOol00`00Oomoo`07Ool00`00Oomoo`1<
Ool009Uoo`<002]oo`03001oogoo00Moo`03001oogoo04aoo`00Ugoo0P00;Woo00<007ooOol027oo
00<007ooOol0Bgoo002DOol3000`Ool00`00Oomoo`09Ool00`00Oomoo`1:Ool0099oo`8003=oo`03
001oogoo00Uoo`03001oogoo04Yoo`00Sgoo0`00=Goo0P002goo00<007ooOol0BGoo002<Ool3000e
Ool6000;Ool00`00Oomoo`18Ool008Yoo`8003Eoo`<000=13`800003OZT007oo00Uoo`03001oogoo
04Qoo`00Qgoo0`00=7oo0`001T4?0P0000=nZ@00Ool02Woo00<007ooOol0Agoo0025Ool2000dOol3
00000d4?00113`07@@l200000gjY001oo`0:Ool00`00Oomoo`16Ool0089oo`<003=oo`<000A13`03
00113d4?00I13`80009nZ@03001oogoo00Qoo`03001oogoo04Ioo`00P7oo0P00=7oo0P001d4?00<0
044?@@l01T4?0P000gjY00<007ooOol027oo00<007ooOol0AGoo001mOol3000fOol00`00@@m13`06
@@l00`00@@m13`06@@l20003OZT2000:Ool00`00Oomoo`14Ool007Yoo`<003Uoo`0300113d4?00I1
3`0300113d4?00A13`<00004E_d007jYOZT2000:Ool00`00Oomoo`14Ool007Qoo`8003aoo`030011
3d4?00I13`0400113d4?@@l30002E_d00`00E_d00002OZT00`00OZT0000:Ool00`00Oomoo`13Ool0
07Eoo`<003ioo`0300113d4?00I13`0400113`000005E_d01P00E_eFo@00OZT0009nZ@03001oogoo
00Moo`03001oogoo04=oo`00Lgoo0P00@Goo00<0044?@@l01D4?0`001eKm00@005KmE_eFo@80009n
Z@03001oogoo00Qoo`03001oogoo049oo`00L7oo0`00@goo00<0044?@@l00T4?0`000UKm00<005Km
E_d01EKm00@005KmE_eFo@8000=nZ@03001oogoo00Qoo`03001oogoo045oo`00KGoo0`00<goo0P00
4Goo00<0044?00000P001UKm00<005KmE_d015Km00@005KmE_eFo@8000=nZ@03001oogoo00Qoo`03
001oogoo045oo`00Jgoo0P00<goo0`0000=13`00000047oo0P002EKm00<005KmE_d015Km00@005Km
0000009Fo@04001nZGjY000;Ool00`00Oomoo`10Ool006Qoo`<0039oo`<000A13`03001nZ`0000ao
o`<00003@@l005Km00UFo@03001FoEKm00=Fo@8000AFo@04001nZGjY000<Ool00`00Oomoo`0oOol0
06Ioo`80039oo`<000M13`03001nZ`0000Uoo`<000E13`03001FoEKm00QFo@03001FoEKm00<000IF
o@03001nZ@0000aoo`03001oogoo03moo`00Hgoo0`00<Woo0P0000=13`00@@l01d4?00@007j[OZ/0
00Ioo`800003@@l0044?00E13`03001FoEKm00QFo@<0009Fo@03001FoEKm00AFo@03001nZ@0000eo
o`03001oogoo03ioo`00HGoo0P00<goo0P000d4?00<0044?@@l01T4?00D007j[OZ]nZ`00009oo`<0
00=13`0300113d4?00E13`03001FoEKm00AFo@<00003@@l00000009Fo@03001FoEKm00EFo@8000io
o`03001oogoo03eoo`00GWoo0`00<goo0P001D4?00<0044?@@l01T4?00<007j[OZ/00Wj[0P001T4?
00<0044?@@l01T4?00<005KmE_d00`00144?0P000UKm00<005KmE_d01EKm0P003Woo00<007ooOol0
?Goo001KOol3000dOol20007@@l00`00@@m13`06@@l00`00OZ]nZ`02OZ/00`00@@m13`06@@l00`00
@@m13`05@@l30007@@l00`00OZX00002E_d00`00E_eFo@04E_d2000?Ool00`00Oomoo`0lOol005Uo
o`8003Moo`0300113d4?00I13`0300113d4?00E13`8000AnZ`0300113d4?00I13`0300113d4?0091
3`<00003@@l0044?00M13`06001nZWjZ001Fo@000eKm0`004Woo00<007ooOol0>goo001FOol3000i
Ool00`00@@m13`06@@l00`00@@m13`02@@l30002E_d01@00OZ]nZgj[0000244?00<0044?00000P00
144?00<0044?@@l01T4?00D007jZOZX005Km00D001Aoo`03001oogoo03]oo`00E7oo0P00?7oo00<0
044?@@l01T4?00<0044?00000P001UKm00@007j[OZ/000M13`<000M13`0300113d4?00I13`04001n
ZWjZOZX20002OZX2000EOol00`00Oomoo`0jOol0055oo`<003ioo`0300113d4?00E13`<000UFo@04
001nZgj[0005@@l200000d4?00113`07@@l00`00@@m13`05@@l20003OZX20002OZX00`00OZX00009
Ool2000:Ool00`00Oomoo`0iOol004ioo`<0045oo`0300113d4?00913`<0009Fo@03001FoEKm00QF
o@03001nZ`0000=13`8000=13`0300113d4?00I13`0300113d4?00=13`80009C7@03001nZWjZ0080
009nZP04001nZWjZ0005Ool300000d4`00000009Ool00`00Oomoo`0iOol004aoo`8004Aoo`030011
3`00008000IFo@03001FoEKm00QFo@800003@@l0000000E13`0300113d4?00I13`0400113d4?@@l2
0005Dad00`00OZX0000200001GjZ001nZWjZ00000Woo0`00144`0P002Woo00<007ooOol0>7oo0019
Ool30016Ool20009E_d00`00E_eFo@08E_d30007@@l00`00@@m13`06@@l01000@@l000001e<M00D0
07jZOZX007jZ008000=nZP8000M1<003001nZ@0000Yoo`03001oogoo03Moo`00Agoo0P00BWoo00<0
05KmE_d025Km00<005KmE_d015Km0`0000=13`00@@l01d4?00<0044?@@l01D4?0`002U<M0`0000=n
ZP0000000gjZ00<0044`@C001d4`00<007jY00002Goo00<007ooOol0=goo0014Ool3001=Ool00`00
E_eFo@08E_d00`00E_eFo@030004@@l00`00@@m13`06@@l00`00@@m13`02@@l30002Dad00`00DaeC
7@06Dad600000gjZ001nZP02OZX00`00@C11<007@C000`00OZT0000:Ool00`00Oomoo`0fOol0049o
o`80051oo`03001FoEKm00QFo@<000M13`0300113d4?00I13`0300113`00008000EC7@03001C7E<M
00=C7@<000=C7@<00003OZX00000009nZP030011<44`00M1<004001nZGjY000:Ool00`00Oomoo`0e
Ool003moo`<005=oo`03001FoEKm00AFo@<00003E_d0044?00M13`0300113d4?00E13`<000UC7@03
001C7E<M008000AC7@80009C7@<00004OZX007jZ0008@C020002OZT20009Ool00`00Oomoo`0eOol0
03aoo`<005Moo`03001FoEKm00<000AFo@0300113d4?00I13`0300113d4?00913`<0009C7@03001C
7E<M00MC7@<000=C7@<000AC7@05001nZP00OZX00002OZX00`00@C11<003@C020002E_d01000OZT0
00002Woo00<007ooOol0=7oo000jOol2001KOol20007E_d00`00@@m13`06@@l00`00@@l000020005
Dad00`00DaeC7@04Dad3000015<M001C7E<M0P0025<M00L007jZ001nZP00OZX00003@C020004E_d0
1@00OZT007jY00002Woo00<007ooOol0<goo000gOol3001NOol00`00E_eFo@05E_d00`00@@m13`05
@@l30009Dad00`00DaeC7@030004Dad3000;Dad20002OZX200000d4`00000007E_d01@00OZT007jY
00002Goo00<007ooOol0<goo000eOol2001ROol00`00E_eFo@04E_d00`00@@m13`02@@l30002Dad0
0`00DaeC7@07Dad30004Dad300000d4?0000000;Dad30002OZX2000:E_d200000gjY001oo`09Ool0
0`00Oomoo`0bOol0039oo`<006Aoo`03001FoEKm00AFo@0300113`00008000EC7@03001C7E<M00AC
7@<00004Dad005<MDad30004@@l00`00OZX0000:Dad200000gjZ001nZP02000:E_d20002OZT00`00
Oomoo`08Ool00`00Oomoo`0aOol0031oo`8006Qoo`03001FoEKm00=Fo@8000UC7@04001C7E<MDad2
0004Dad30007@@l01000OZYnZP001U<M0`000U<M0P0000AnZP00OZX000UFo@80009nZ@03001oogoo
00Qoo`03001oogoo035oo`00;Goo0`00FWoo0P003goo00<005KmE_d010002U<M0`000e<M0`0000=1
3`00@@l0244?00@007jZOZX0009C7@<000EC7@06001nZP00001nZP001UKm0`000UKm00<007jY0000
2goo00<007ooOol0<7oo000ZOol3001JOol300000d4?0000000?Ool20002Ool00`00@C000006Dad4
0002Dad30004@@l00`00@@m13`07@@l01000OZYnZWjZ0P002E<M00<007jZ00000WjZ00<005KmE_d0
0`001EKm00<007jY000037oo00<007ooOol0;goo000XOol2001JOol30004@@l00`00OZd0000BOol0
0`00@C000003Dad30003Dad30007@@l00`00@@m13`07@@l01000OZYnZWjZ0P002U<M0`000WjZ0P00
2EKm00<007jY00002goo00<007ooOol0;goo000UOol3001IOol30007@@l00`00OZd0000BOol00`00
@C11<0030004Dad200000e<M00113`08@@l00`00@@m13`05@@l20003OZX2000:Dad30002OZX2000:
E_d2000<Ool00`00Oomoo`0^Ool002=oo`8005Yoo`800003@@l0044?00M13`04001n[Gj]000AOol3
0000144`001C7E<M0`000e<M00<0044?@@l01d4?00<0044?@@l00T4?0`000U<M00H007jZOZX007jZ
0009Dad200000gjZ001nZP02000:E_d2000=Ool00`00Oomoo`0]Ool0021oo`<005Uoo`<000=13`03
00113d4?00I13`05001n[Gj]OZd0000>Ool300000d4`000000030006Dad00`00@@m13`07@@l00`00
@@l000020005Dad01000OZYnZP000WjZ00<005<MDad00e<M0`000U<M00H007jZ000005Km0009E_d2
000=Ool00`00Oomoo`0]Ool001eoo`<005Yoo`8000I13`0300113d4?00I13`04001n[Gj]OZd2000:
Ool30002Ool20004E_d00`00DaeC7@04Dad00`00@@m13`06@@l30009Dad00`00OZX00002OZX00`00
DaeC7@030005Dad01000OZX000000UKm00<005KmE_d00eKm0`0047oo00<007ooOol0;7oo000KOol2
001MOol00`00@@m13`05@@l00`00@@m13`05@@l20003OZd00`00OZd00006Ool30003Ool40004E_d0
0`00DaeC7@05Dad00`00@@m13`03@@l20002Dad00`00DaeC7@08Dad20003OZX20009Dad00`00OZX0
0002E_d00`00E_eFo@03000DOol00`00Oomoo`0[Ool001Qoo`<005moo`0300113d4?00E13`030011
3d4?00913`<0009Fo@06001n[Gj]001n[@000goo0`000goo0`00144`00<005KmE_d00UKm00<005<M
Dad015<M00@0044?@@m13`8000AC7@03001C7E<M00QC7@8000=nZP8000YC7@<00004E_d00000000G
Ool00`00Oomoo`0[Ool001Ioo`8002moo`8002Qoo`8000Moo`0300113d4?00E13`0300113`000080
00IFo@03001n[@00009n[@<000Aoo`800003@C00044`00A1<003001FoEKm00=Fo@03001C7E<M00=C
7@0400113`000007Dad00`00DaeC7@07Dad20003OZX2000:Dad4000KOol00`00Oomoo`0ZOol001=o
o`<002moo`800003@@l0000002=oo`@00003@@l0000000Ioo`0300113d4?00A13`<000UFo@03001n
[@0000800004OZd007ooOol30003@C000`00@C11<004@C000`00E_eFo@02E_d00`00DaeC7@05000:
Dad00`00DaeC7@03Dad30002Dad01P00OZYnZP00Dad000UC7@800003Ool007oo01]oo`03001oogoo
02Uoo`004Goo0P00;goo0`000d4?00<007[?00007Woo10001D4?00<007Z^00001Goo00<0044?@@l0
0T4?0P000UKm00<005KmE_d01eKm0`0017j]0P001T4`00<0044`@C001D4`00<005KmE_d01000144`
00<005<MDad025<M00<005<MDad00`001E<M00@007jZOZX0009C7@03001C7E<M00=C7@<000Aoo`03
001oogoo01Uoo`03001oogoo02Uoo`003Woo0`00;Woo0`001T4?00<007[?000077oo0P0000=13`00
@@l01T4?00@007Z^NZh000Aoo`0300113`00008000EFo@03001FoEKm00=Fo@<00003E_d0000000An
[@030011<44`00E1<0030011<44`00E1<0@00003@C00044`00E1<003001C7E<M00MC7@<000UC7@03
001nZP00009C7@03001C7E<M00<000Qoo`03001oogoo01Uoo`03001oogoo02Qoo`002goo0`00;goo
0P0000=13`00@@l01D4?00D007[?N/mjc`0001Qoo`<000=13`0300113d4?00E13`05001j[WZ^NZh0
0002Ool30009E_d00`00E_d000020002E_d20002E_d01@00OZen[Gj]00001d4`00<0044`@C000T4`
1000144`00<0044`@C00144`00<005<MDad015<M0`0000=1<00000002U<M0P000U<M0`002goo00<0
07ooOol06Woo00<007ooOol09goo0009Ool2000_Ool30003@@l00`00@@m13`04@@l00`00N/mjc`02
N/l00`00Oomoo`0COol20006@@l00`00@@m13`05@@l00`00NZij[P02NZh20002@C000`00E_eFo@06
E_d30002E_d30005E_d01000OZen[@001d4`00<0044`00000`001d4`00<0044`@C001D4`00<005<M
Dad00`00144`0P002U<M10003goo00<007ooOol06Goo00<007ooOol09goo0007Ool2000_Ool20006
@@l00`00@@m13`04@@l00`00N/mjc`03N/l00`00Oomoo`0BOol00`00@@m13`05@@l00`00@@m13`05
@@l00`00NZij[P02NZh00`00@C11<002@C000`00E_eFo@02E_d30002E_d30008E_d01000OZen[@00
1T4`100000=1<000@C001d4`00<0044`@C001D4`0`001d4`00<007j[00002E<M0P003Goo0P000goo
00<007ooOol06Goo00<007ooOol09Woo0007Ool2000_Ool00`00@@m13`04@@l00`00@@m13`05@@l0
0`00N/mjc`03N/l2000COol00`00@@m13`05@@l00`00@@m13`04@@l20004NZh00`00@C11<003@C04
0003E_d200000d4`00000009E_d00`00OZd00004@C040003@C000`00@C11<006@C000`00@C11<002
@C0300000d4`0011<007@C001000OZ]nZ`001E<M0`002goo100000=5D00000000goo00<007ooOol0
6Goo00<007ooOol09Goo0007Ool00`00Ool0000^Ool00`00@@m13`04@@l00`00@@m13`04@@l20005
N/l00`00N/l0000BOol00`00@@m13`05@@l00`00@@m13`02@@l20002E_d01@00NZij[WZ^0000144`
0`000UKm0`000d4`00<007j]00002EKm0P0000=1<00000000P001T4`00<0044`@C001T4`00<0044`
00000P00144`00<0044`@C001T4`00@007j[OZ/0009C7@@000Uoo`@000E5D003001nZP00009oo`03
001oogoo01Uoo`03001oogoo02Eoo`001goo00@007ooOol002eoo`0300113d4?00A13`0300113d4?
00913`80009Fo@03001jcg[?009jc`04001jcg[?000AOol00`00@@m13`05@@l00`00@@l000020005
E_d01@00NZij[P00@C000`000T4`0`001T4`00<007j]00002EKm100000=1<000@C001d4`00<0044`
@C00144`0`001d4`00<0044`@C001T4`00@007j[OZ]nZ`80009nZ`03001nZ`0000Eoo`<00003AE00
04E@00I5D003001nZP0000=oo`03001oogoo01Uoo`03001oogoo02Aoo`001Woo00<007ooOol00Woo
00<007ooOol0:Woo00<0044?@@l0144?00<0044?00000P001EKm00@007[?N/l000Ajc`03001oogoo
00ioo`0300113d4?00A13`<000UFo@@000=1<0800003@C00044`00I1<004001n[Gj]0006E_d30004
@C000`00@C11<006@C000`00@C11<002@C0200000d4`0011<007@C000`00@C11<006@C001000OZ]n
Zgj[0P000Wj[00D007j[OZ/007oo00<000A5D0030015D4E@00I5D003001nZP0000=oo`03001oogoo
01Uoo`03001oogoo02=oo`001Woo00<007ooOol00goo00<007ooOol0:Goo00<0044?@@l00d4?0`00
2EKm00<007[?00001G[?00<007ooOol03Goo00<0044?@@l00T4?0P000UKm00<005KmE_d01EKm1@00
00A1<000000000=1<0030011<44`00E1<005001n[Gj]OZd00002E_d30007@C000`00@C11<006@C00
0`00@C0000020003@C000`00@C11<006@C000`00@C11<005@C020003OZ/00`00OZ/00002OZ/01000
OZ]nZ`001dE@00<004E@AE001TE@00@007jZOZX0009oo`03001oogoo01Uoo`03001oogoo02=oo`00
1Woo00<007ooOol017oo0P006Goo0P003Woo00<0044?00000`000UKm00<005KmE_d025Km0P001G[?
00<007ooOol03Goo00<0044?00000P001EKm00@005KmE_eFo@<000=Fo@<000I1<0030011<44`00E1
<003001n[Gj]009n[@800003@C00044`00M1<0030011<44`00E1<0<000I1<0030011<44`00I1<003
0011<44`0091<0<0009C7@04001nZgj[0002OZ/00`00OZ/00003OZ/00`00AE15D004AE000`00AE15
D006AE000`00OZYnZP020002Ool00`00Oomoo`0IOol00`00Oomoo`0ROol000Ioo`03001oogoo00Io
o`03001oogoo01Aoo`800003@@l0000000eoo`8000MFo@03001FoEKm00MFo@8000Ejc`03001oogoo
00eoo`8000QFo@@000=Fo@<00003@C00044`00I1<0030011<44`00E1<003001n[@00008000=1<003
0011<44`00I1<0030011<44`0091<0<00003@C00044`00I1<0030011<44`00I1<0030011<0000080
00IC7@03001nZ`0000=nZ`8000=nZ`8000E5D0030015D4E@00E5D080009nZP03001nZP00009oo`03
001oogoo01Uoo`03001oogoo025oo`001Woo00<007ooOol01goo00<007ooOol047oo0`000d4?00<0
07Z`00002Goo1@0025Km0P001EKm0P000UKm00<007[?N/l00W[?00<007ooOol03Woo00<005KmE_d0
1EKm0`000UKm0`00144`00<0044`@C001D4`00<0044`@C00144`0`001T4`00<0044`@C001T4`00<0
044`00000P00144`00<0044`@C001D4`00<0044`@C001D4`0`002E<M00@007j[OZ/000=nZ`04001n
Zgj[OZ/20005AE000`00AE15D002AE030002E_d01@00OZX007jZ00000goo00<007ooOol067oo00<0
07ooOol08Goo0006Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool30006@@l01000N[1j/0001Woo0P00
00=13`00@@l00T4?00<005KmE_d01eKm00<005KmE_d00P001EKm00D007[?N/mjc`00015oo`04001F
oEKmE_d30002E_d30007@C000`00@C11<005@C000`00@C11<002@C0200000d4`0011<006@C000`00
@C11<005@C030007@C000`00@C11<005@C000`00@C11<002@C030002Dad00`00DaeC7@08Dad00`00
OZ/00003OZ/20002OZ/00`00OZ/00004AE000`00AE0000020006E_d01@00OZX007jZ00000Woo00<0
07ooOol06Goo00<007ooOol087oo0005Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool200000d4?0011
3`05@@l00`00N[1j/002N[000`00Oomoo`030003@@l01@00@@m13d4?00002EKm0`0025Km0P0000=j
c`00Ool00Woo0P0037oo10000eKm0P0000=Fo@00@C001T4`00<0044`@C001T4`00<0044`00000P00
0d4`00<0044`@C001D4`00<0044`@C000T4`0`0000=1<000@C001d4`00<0044`@C001D4`00<0044`
00000P001U<M00<005<MDad025<M0P000gj[0P000Wj[00@007j[OZ/00095D0<000UFo@03001nZP00
009nZP04001oogoo000KOol00`00Oomoo`0OOol000Eoo`03001oogoo00]oo`03001oogoo00Ioo`80
00=13`0300113d4?00A13`03001j/7Z`00=j/08000I13`0300113d4?00913`03001FoEKm00AFo@80
0003@@l0000000YFo@800004Ool00000@C020009Ool40002E_d30003E_d00`00@C11<005@C000`00
@C11<004@C040006@C000`00@C11<005@C000`00@C0000020004@C000`00@C11<006@C000`00@C11
<004@C030009Dad00`00DaeC7@08Dad20003OZ/01@00OZ/007j[00000Wj[0`000UKm00<005KmE_d0
25Km0P000WjZ00D007ooOomoo`0001Yoo`03001oogoo01moo`001Goo00<007ooOol037oo00<007oo
Ool00goo0P001D4?00<0044?@@l0144?00<007Z`N[000gZ`00<0044?@@l0144?00<0044?@@l0144?
00<005KmE_d00`000d4?00<007[?00002EKm0`000d4`00<007[?00001Goo0`0017oo0P001UKm00<0
044`@C001D4`00<0044`@C0010000T4`00<0044`@C001D4`00<0044`@C00144`0`001d4`00<0044`
@C001T4`00<0044`@C000T4`0P000U<M00<005<MDad025<M00<005<MDad015<M0`000U<M00@007j[
OZ/0009nZ`8000=nZ`03001FoEKm009Fo@03001FoEKm00MFo@80009nZP05001oogooOol0000KOol0
0`00Oomoo`0NOol000Eoo`03001oogoo00eoo`03001oogoo009oo`0300113d4?00=13`0300113d4?
00A13`8000Ej/00300113d4?00A13`0300113d4?00A13`<000I13`04001jcg[?0006E_d20006@C00
1000N/mjc`000Woo0P0017oo0`0000=1<000E_d01EKm00<0044`@C00144`10001T4`00<0044`@C00
1D4`00<0044`@C000T4`0P0000=1<000@C001d4`00<0044`@C001T4`00<0044`00000P001E<M00<0
05<MDad025<M00<005<MDad00`001U<M00<007j[00000Wj[0P000gj[0P000eKm00<005KmE_d015Km
0`000UKm00<007jZ000017oo00<007ooOol06Goo00<007ooOol07Goo0005Ool00`00Oomoo`0>Ool0
1@00Oomoogoo00001D4?00<0044?@@l00T4?0P000UKm00<007Z`N[000WZ`00<0044?@@l0144?00<0
044?@@l0100000=13`00@@l01D4?00<007[?N/l00W[?00<005KmE_d010001d4`00<007[?N/l00`00
0Woo100000=1<000@C000T4`00<005KmE_d00eKm00<0044`@C000T4`0P0000=1<000@C001d4`00<0
044`@C001D4`00<0044`00000P000d4`00<0044`@C001T4`00<0044`@C001D4`0`0025<M00<005<M
Dad025<M0`002E<M00<007j[00000gj[00L007j[OZ]nZ`00OZ/00003E_d00`00E_eFo@030005E_d0
0`00OZX00005Ool00`00Oomoo`0HOol00`00Oomoo`0MOol000Eoo`03001oogoo00moo`04001oogoo
0005@@l00`00@@l000020005E_d01@00N[1j/7Z`00001D4?10001D4?00<0044?@@l0144?00<007[?
N/l00g[?0P000g[?00<0044`@C001D4`0`000W[?0`001D4`00<0044`@C000T4`00<005KmE_d00UKm
00<0044`00000P000d4`00<0044`@C001D4`00<0044`@C001D4`0`001T4`00<0044`@C001T4`00<0
044`@C000T4`0`000U<M00<005<MDad01e<M00<005<MDad015<M0`0000=1<00000002U<M0P000gj[
0P000Wj[00<007j[00000eKm0`002EKm0P0000=oo`0000000goo00<007ooOol067oo00<007ooOol0
77oo0005Ool00`00Oomoo`0@Ool20005@@l30009E_d200000gZ`00113`02@@l200000d4?00113`06
@@l00`00@@m13`04@@l00`00N/mjc`03N/l20003N/l00`00@C11<002@C040004N/l00`00@C11<005
@C000`00@C11<003@C000`00E_eFo@030006@C000`00@C11<005@C000`00@C11<002@C0300000d4`
0011<006@C000`00@C11<006@C000`00@C0000020006Dad00`00DaeC7@07Dad00`00DaeC7@030004
@C000`00OZ/00009Dad20003OZ/01@00OZ/007j[00000Wj[0`0000=5D00000002EKm0`0000=5D@00
00000Woo00<007ooOol06Goo00<007ooOol06goo0004Ool00`00Oomoo`0BOol01000@@m13d4?0P00
0UKm00<005KmE_d02EKm0P0000=13`0000000d4?00<0044?@@l0144?00<0044?@@l0144?0P001G[?
00<007[?00000W[?00<0044`00000P000T4`0P0017[?00<0044`@C00144`00<0044`@C00144`0`00
00=1<000@C001T4`00<0044`@C001D4`00<0044`00000P00144`00<0044`@C001D4`00<0044`@C00
1D4`0`002E<M00<005<MDad01U<M10001d4`00<007j[00001U<M0`000U<M00P007j[OZ/007j[001n
Z`000gj[00H004E@AE0007j[0008E_d20002AE400`00OZX00002Ool00`00Oomoo`0HOol00`00Oomo
o`0KOol000Aoo`03001oogoo019oo`0400113`000005E_d00`00E_eFo@08E_d30005@@l00`00@@m1
3`04@@l00`00@@m13`02@@l20002Dad00`00N/mjc`02N/l00`00N/mjc`040003@C020002E_d01@00
N/mjcg[?00001T4`00<0044`@C000T4`0`000d4`00<0044`@C001D4`00<0044`@C00144`0`001d4`
00<0044`@C001D4`00<0044`@C000T4`0`000U<M00<005<MDad025<M00@005<MDaeC7@@00091<003
0011<44`00I1<004001nZgj[0002Dad30006Dad00`00OZ/00002OZ/20003OZ/2000014E@001nZ`00
1UKm0P0014EA00<007jZ00000goo00<007ooOol067oo00<007ooOol06Woo0004Ool00`00Oomoo`0B
Ool20008E_d20006E_d200000d4?00113`04@@l00`00@@m13`05@@l00`00@@l000020005Dad01000
N/mjc`000W[?100000A1<000000000EFo@04001jcg[?0006@C000`00@C0000020006@C000`00@C11
<005@C000`00@C11<002@C0200000d4`0011<007@C000`00@C11<005@C000`00@C0000020006Dad0
0`00DaeC7@07Dad40006@C000`00@C11<006@C001000OZ]nZgj[0P002E<M00<007j[00000gj[00@0
07j[OZ]nZ`800005AE0007j[OZ/00002E_d30007AE400`00OZX00002Ool00`00Oomoo`0HOol00`00
Oomoo`0JOol000Aoo`03001oogoo01=oo`03001FoEKm00QFo@03001FoEKm00<000=13`0300113d4?
00=13`0300113d4?00A13`<000UC7@03001jc`00008000=jc`8000UFo@03001jc`0000E1<0<00003
@C00044`00I1<0030011<44`00E1<0030011<000008000=1<0030011<44`00I1<0030011<44`00A1
<0<000YC7@03001C7E<M00AC7@800003Dad0044`00M1<0030011<44`00I1<004001nZgj[OZ/2000:
Dad20003OZ/20002OZ/01000OZ/000000gj[0P0000=nZ`00AE401dEA00@007jZOZX0009oo`03001o
ogoo01Qoo`03001oogoo01Uoo`0017oo00<007ooOol057oo00<005KmE_d01eKm0`001T4?00<0044?
@@l00d4?00<0044?@@l00T4?0P000U<M00<005<MDad01U<M10001G[?0P002UKm0P0000=1<0000000
0`000d4`00<0044`@C001D4`00<0044`@C00144`0`001T4`00<0044`@C001T4`00<0044`@C000T4`
0P000U<M00<005<MDad02E<M00<005<MDad00`000e<M00<0044`@C001T4`00<0044`@C001D4`0P00
0gj[00<007j[00002E<M0P000gj[00H007j[001nZ`00OZ/20003OZ/200000gj[0015D@07AE400`00
OZYnZP020002Ool00`00Oomoo`0HOol00`00Oomoo`0HOol000Aoo`03001oogoo01Eoo`8000EFo@80
0003E_d0044?00E13`0300113d4?00A13`0300113`00008000EC7@03001C7E<M009C7@<0009C7@80
00Ejc`03001jc`0000UFo@D000I1<0030011<44`00E1<0030011<44`0091<0800003@C00044`00I1
<0030011<44`00I1<0030011<000008000EC7@03001C7E<M00QC7@<000IC7@030011<44`00I1<003
0011<44`0091<0<0009C7@06001nZgj[001nZ`001U<M0`000U<M00P007j[OZ/007j[001nZ`000Wj[
00T007j[OZ]nZ`00OZ/007j[00001TEA0P000WjZ0P000goo00<007ooOol05goo00<007ooOol067oo
0003Ool00`00Oomoo`0HOol00`00E_eFo@020003E_d00`00@@m13`04@@l00`00@@m13`03@@l30009
Dad40003Dad20002Dad00`00N/mjc`02N/l01000N/mjc`001UKm100000=1<000@C001T4`00<0044`
@C001D4`00<0044`00000P000d4`00<0044`@C001D4`00<0044`@C001D4`0`002E<M00<005<MDad0
15<M0`000U<M00<005<MDad015<M00<0044`@C001T4`00<0044`00000P001U<M00<007j[00000Wj[
00<005<MDad00`001E<M00@007j[OZ/0009nZ`80009nZ`80009nZ`05001nZ`00OZ/00004AE420002
E_d01@00OZX007jZ00000Woo00<007ooOol067oo00<007ooOol05goo0003Ool00`00Oomoo`0IOol2
0005E_d00`00@@m13`04@@l01000@@m13d4?0P000U<M00<005<MDad01E<M10000U<M0`001E<M00@0
07[?N/l000Ajc`03001FoEKm00D000=1<0030011<44`00E1<0030011<44`00A1<0<000I1<0030011
<44`00E1<0030011<44`0091<0<0009C7@03001C7E<M00QC7@03001C7E<M00<000EC7@03001C7E<M
00AC7@030011<44`00E1<0<000UC7@04001nZgj[0002OZ/20009Dad00`00OZ/00003OZ/02000OZ]n
Z`00OZ/007j[0002OZ/2000014EA000000001EKm00@007jZ000000=oo`03001oogoo01Qoo`03001o
ogoo01Ioo`000goo00<007ooOol06Woo00<005KmE_d00UKm00<0044?@@l01D4?00@0044?000000EC
7@03001C7E<M009C7@8000=C7@<000UC7@03001jc`0000Ejc`@000I1<0030011<44`00E1<0030011
<44`0091<0800003@C00044`00I1<0030011<44`00E1<0030011<000008000IC7@03001C7E<M00MC
7@<000UC7@03001C7E<M00=C7@030011<44`0091<0<0009C7@03001C7E<M00QC7@03001nZ`00009n
Z`8000YC7@8000=nZ`800006OZ/007j[001nZ`000gj[0P0025Km00D007jZ001nZP0000=oo`03001o
ogoo01Moo`03001oogoo01Ioo`000goo00<007ooOol06goo00D005KmE_eFo@0000I13`<000QC7@@0
00=C7@800003@@l0000000YC7@80009jc`@00003@C00044`00I1<0030011<44`00E1<0030011<000
008000=1<0030011<44`00E1<0030011<44`00A1<0<000UC7@03001C7E<M00AC7@<00003@C000000
00YC7@03001C7E<M009C7@030011<000008000IC7@03001C7E<M00QC7@80009nZ`03001C7@0000UC
7@8000=nZ`800004OZ/007j[OZ/20003OZ/20009E_d200000gjZ001oo`02Ool00`00Oomoo`0HOol0
0`00Oomoo`0EOol000=oo`03001oogoo01aoo`04001FoEKm0002@@l40002Dad00`00DaeC7@04Dad3
000015<M001C7E<M0P000d4?00<007Z_00002E<M10001D4`00<0044`@C001D4`00<0044`@C00144`
0`001T4`00<0044`@C001D4`00<0044`@C000T4`0P000U<M00<005<MDad025<M00<005<MDad00`00
144`00<007j]00002E<M00<005<MDad010002E<M00<005<MDad025<M0P000Wj[00<005<M00002E<M
0P000gj[00D007j[001nZ`00009nZ`04001nZgj[OZ/20009E_d200000gjZ001oo`03Ool00`00Oomo
o`0HOol00`00Oomoo`0DOol000=oo`03001oogoo01eoo`03001Fo@00008000MC7@03001C7E<M00<0
00AC7@<000E13`03001j[gZ_008000EC7@800003@C00044`00I1<0030011<44`00E1<0030011<44`
00@00003@C00044`00I1<0030011<44`00E1<0030011<000008000EC7@03001C7E<M00MC7@<000M1
<004001n[Gj]0008Dad30003@C000`00DaeC7@08Dad00`00DaeC7@04Dad30002Dad00`00OZ/00002
Dad00`00DaeC7@04Dad20002Dad01000OZ]nZ`000Wj[0P000Wj[0P000Wj[00<007j[00001EKm0`00
0UKm0P001Goo00<007ooOol05goo00<007ooOol057oo0003Ool00`00Oomoo`0NOol30008Dad30005
Dad200000d4?00113`05@@l00`00NZmj[`02NZl00`00DaeC7@020003@C000`00@C11<005@C000`00
@C11<004@C040005@C000`00@C11<005@C000`00@C11<004@C030009Dad00`00DaeC7@04Dad20000
0d4`0011<007@C001@00OZen[Gj]00000e<M100000=1<000@C00144`00<005<MDad025<M00<005<M
Dad00`001U<M00<007j[00000U<M00<005<MDad00`001E<M00<007j[00000Wj[0P000Wj[00L007j[
001nZ`00OZ/00002E_d30005E_d00`00OZX00005Ool00`00Oomoo`0=Ool20008Ool00`00Oomoo`0C
Ool0009oo`03001oogoo029oo`03001C7E<M009C7@<0009C7@03001C7E<M00<000=13`0300113d4?
00A13`03001j[gZ_00=j[`8000E1<0030011<44`00E1<0030011<44`0091<0800003@C00044`00I1
<0030011<44`00E1<0030011<44`00@0009C7@03001C7E<M00QC7@03001C7E<M00<000=1<0030011
<44`00I1<003001n[Gj]009n[@<000E1<0030011<44`00=1<003001C7E<M00QC7@<000UC7@04001n
Z`00Dad40008Dad00`00OZ/00003OZ/02000OZ]nZ`00OZ/007j[0002OZ/20009E_d20005Ool00`00
Oomoo`0;Ool200000dEa00000008Ool00`00Oomoo`0BOol0009oo`03001oogoo02=oo`@000EC7@<0
00I13`0300113d4?00A13`03001j[gZ_00=j[`030011<44`00A1<0030011<44`00E1<0030011<000
008000=1<0030011<44`00A1<0030011<44`00E1<0@000MC7@03001C7E<M00MC7@<000I1<0030011
<44`00I1<003001n[Gj]009n[@030011<44`00E1<0030011<44`00A1<003001C7E<M00AC7@<0009C
7@03001C7E<M00QC7@<000=C7@03001C7E<M00MC7@8000=nZ`800004OZ/007j[OZ/20002OZ/20009
E_d20006Ool00`00Oomoo`07Ool30003AG420008Ool00`00Oomoo`0BOol0009oo`03001oogoo029o
o`@0009C7@@00003Dad0044?00E13`0300113d4?00E13`03001j[gZ_00=j[`030011<44`00A1<003
0011<44`00A1<0<000I1<0030011<44`00A1<0030011<44`0091<0<0009C7@03001C7E<M00MC7@03
001C7E<M00AC7@800003Dad0044`00I1<0030011<44`00I1<003001n[Gj]009n[@030011<44`00E1
<0030011<44`00E1<003001C7E<M00<000IC7@03001C7E<M00MC7@8000EC7@03001C7E<M00IC7@80
00=nZ`05001nZ`00OZ/00002OZ/01P00OZ]nZ`00E_d000QFo@8000Moo`03001oogoo00=oo`<000I5
L@03001nZ@0000Qoo`03001oogoo015oo`000Woo00<007ooOol07goo0`0017oo0P001E<M00<0044?
@@l0144?00<0044?@@l0144?0P001GZ_00<0044`@C00144`00<0044`@C000T4`0P0000=1<000@C00
1D4`00<0044`@C001D4`00<0044`00000P001U<M00<005<MDad01e<M00<005<MDad00`000e<M00<0
044`@C001D4`00<0044`@C001D4`0P0017j]00<0044`@C001D4`00<0044`@C00144`10002E<M00<0
05<MDad015<M0`001e<M00<005<MDad015<M0P000U<M00P007j[OZ/007j[001nZ`000Wj[0P0000An
Z`00E_d000IFo@8000Uoo`03001oogoo00<00003AG4004Ea00M5L@8000Uoo`03001oogoo011oo`00
0Woo00<007ooOol077oo0`0027oo00<005<MDad00e<M00<0044?@@l0144?00<0044?@@l010000U<M
00D007Z_NZmj[`0000M1<0030011<000008000=1<0030011<44`00A1<0030011<44`00A1<0<000UC
7@03001C7E<M00IC7@@000IC7@030011<44`00E1<0030011<44`0091<0<0009C7@05001n[Gj]OZd0
0007@C000`00@C11<0040003Dad00`00DaeC7@08Dad00`00DaeC7@0300000gj/001C7@08Dad00`00
DaeC7@030005Dad00`00OZ/00002OZ/20002OZ/01`00OZ/007j[001Fo@00009Fo@<000]oo`<000A5
L@030015LDEa00I5L@03001nZ@0000Qoo`03001oogoo011oo`000Woo00<007ooOol06Goo0`0037oo
00D005<MDaeC7@0000I13`@000MC7@800003NZl0044`00E1<0<000I1<0030011<44`00A1<0030011
<44`0091<080009C7@03001C7E<M00QC7@04001C7E<MDad40002@C020006Dad00`00@C11<005@C00
0`00@C0000020006Dad01000OZen[@001T4`100025<M00<005<MDad01e<M0`000Wj/00<007j/0000
25<M100025<M00<007j[00000gj[00T007j[OZ/007j[001nZ`00E_d00`0037oo0P000TEa00<004Ea
AG400TEa00<004EaAG401TEa00@007jY000000Qoo`03001oogoo00moo`000Woo00<007ooOol05Woo
0`0047oo00@005<MDad000A13`80009C7@03001C7E<M00QC7@800091<0@00003@C00044`00E1<003
0011<44`00E1<0030011<000008000EC7@03001C7E<M00MC7@@000I1<003001j[P0000EC7@030011
<44`00A1<0<000YC7@03001n[@0000A1<080009C7@03001C7E<M00MC7@03001C7E<M00AC7@<0009C
7@04001n[7j/0002OZ`01000DaeC7E<M10000TE@0P002E<M0P000gj[0P0000AnZ`00OZ]nZ`<000mo
o`030015LDEa0095L@050015LDEaAG400007AG4200000gjY00000009Ool00`00Oomoo`0>Ool00003
Ool007oo01Ioo`8001=oo`800003Dad0044?00<000EC7@03001C7E<M00MC7@@000E1<0030011<44`
00A1<0030011<44`00A1<0<000UC7@03001C7E<M00AC7@800003@C00044`00M1<003001j[P0000EC
7@030011<44`0091<080009C7@03001C7E<M00UC7@800004@C0000000005Dad00`00DaeC7@07Dad0
0`00DaeC7@030006Dad00`00OZ`00003OZ`30006AE000`00OZ/00008Dad20003OZ/01@00OZ/007j[
00000Wj[00<007ooOol01Goo0P001goo00<004EaAG400TEa00D004EaAG55L@0000A5L@<0009Fo@80
0003OZT007oo00Moo`03001oogoo00ioo`0000=oo`00Ool04goo0`005Goo1@002E<M00<005<MDad0
15<M0P0000=1<000@C001T4`00<0044`@C00144`00<0044`@C000T4`0P000U<M00<005<MDad025<M
00<005<MDad00`000d4`00<0044`@C001D4`00D007Z^NZij[P00009C7@<00004@C0000000005Dad0
0`00DaeC7@08Dad30008Dad00`00DaeC7@07Dad30009Dad00`00OZ`00003OZ`00`00AE15D006AE00
0`00OZ/00006Dad20002Dad02000OZ]nZ`00OZ/007j[0002OZ/20004Ool200000dEa00000006Ool0
0`00AG55L@03AG401@00AG55L@00AG400`001EKm00@007jY000000Uoo`03001oogoo00eoo`0000=o
o`00Ool047oo0`006Goo00@005Km000000YC7@03001C7E<M00<000=1<0030011<44`00A1<0030011
<44`00E1<0030011<000008000EC7@03001C7E<M00MC7@<000I1<0030011<44`00E1<003001j[WZ^
009j[P80009C7@8000UC7@03001C7E<M00AC7@<0009C7@03001C7E<M00MC7@03001C7E<M00AC7@80
009C7@03001C7E<M00QC7@8000=n[0030015D4E@00I5D004001nZgj[0002Dad30005Dad00`00OZ/0
0002OZ/20002OZ/2000017oo000000000dEa00<007j[00001Woo00<004EaAG400dEa10002EKm0P00
00=nZ@00Ool027oo00<007ooOol037oo00000goo001oo`0=Ool3000MOol01000E_d000002E<M0`00
1T4`00<0044`@C00144`00<0044`@C00144`0`002E<M00<005<MDad015<M0P0000=C7@00@C001T4`
00<0044`@C001D4`00<007Z^NZh00WZ^0P000e<M00<005<MDad025<M00<005<MDad00`001U<M00<0
05<MDad01e<M00<005<MDad00`001E<M00<005<MDad01e<M0P000gj/00<004E@AE001TE@00@007j[
OZ]nZ`8000QC7@03001nZ`0000=nZ`06001nZgj[001nZ`001TEa00<007j[00001Woo00<004EaAG40
0TEa0P000UKm00<005KmE_d01eKm0P0000=nZ@00Ool027oo00<007ooOol037oo00000goo001oo`0:
Ool3000QOol50005Dad200000e<M0011<005@C000`00@C11<005@C000`00@C11<0040002Dad00`00
DaeC7@08Dad00`00DaeC7@030003Dad00`00@C11<005@C000`00@C11<004@C020004NZh00`00NZh0
0003Dad00`00DaeC7@07Dad30009Dad00`00DaeC7@06Dad40009Dad00`00DaeC7@04Dad20002Dad0
1000OZan[00024E@00@007j[OZ]nZ`8000UC7@8000=nZ`800004OZ/007j[0007AG400`00OZ/00002
Ool4000014Ea000000000UKm00@005KmE_d000QFo@800003OZT007oo00Uoo`03001oogoo00]oo`00
00=oo`00Ool01goo0`009Woo0P0000AC7@00DaeC7@8000=C7@030011<44`00A1<0030011<44`00A1
<0@000MC7@03001C7E<M00MC7@<000IC7@030011<44`00E1<0030011<44`0091<080009C7@05001j
[WZ^NZh00002NZh01@00DaeC7E<M00001U<M0P000U<M00<005<MDad025<M00@005<MDaeC7@@000=C
7@03001C7E<M00QC7@03001C7E<M00<000EC7@03001n[00000M5D08000=nZ`03001nZ`0000QC7@80
00=nZ`800005OZ/007j[OZ/00006AG400`00OZ]nZ`020003AG420006E_d00`00E_d00006E_d20002
E_d2000;Ool00`00Oomoo`0:Ool00003001oogoo00Eoo`8002Yoo`D000EC7@030011<44`00A1<003
0011<44`0091<080009C7@03001C7E<M00MC7@03001C7E<M00AC7@80009C7@03001C7E<M00AC7@03
0011<44`00E1<0030011<000008000EC7@04001j[WZ^0003NZh00`00DaeC7@020002Dad30005Dad0
0`00DaeC7@07Dad40008Dad00`00DaeC7@07Dad30008Dad00`00OZ`00004AE030002Dad01P00OZ]n
Z`00OZ/000IC7@80009C7@05001nZgj[001nZ`020002OZ/20005AG401000OZ]nZ`001DEa00<005Km
E_d01EKm00<005Km00000UKm0`0015Km00<007jY00002Woo00<007ooOol02Woo00000`00Oomoo`02
Ool3000]Ool200000e<M001C7@04Dad00`00@C11<004@C000`00@C0000020005Dad00`00DaeC7@07
Dad00`00DaeC7@030005Dad00`00DaeC7@03Dad00`00@C11<004@C030009Dad00`00NZh00004NZh2
0002NZh20009Dad00`00DaeC7@04Dad20002Dad00`00DaeC7@07Dad00`00DaeC7@04Dad30002Dad0
0`00DaeC7@07Dad2000014E@000000001U<M00<007j[00000Wj[00<005<MDad00`001E<M00<007j[
00000Wj[00H007j[OZ/007j[0003AG420002OZ/00`00AG55L@03AG400`00E_eFo@05E_d50008E_d2
000;Ool00`00Oomoo`09Ool00003001oo`000080035oo`800003Dad005<M00=C7@030011<44`00=1
<0<000UC7@03001C7E<M00IC7@<000UC7@03001C7E<M009C7@030011<44`0091<080009C7@03001C
7E<M00QC7@8000Aj[P8000=j[P03001C7E<M00QC7@03001C7E<M00<00003OZd005<M009C7@03001C
7E<M00MC7@03001C7E<M00<000IC7@03001C7E<M00IC7@<000UC7@03001nZ`0000=nZ`8000QC7@03
001nZ`00009nZ`800005OZ/007j[0015L@020002E_d00`00OZ/00006AG401000E_eFoEKm1@0000=5
L@00000025Km0P0037oo00<007ooOol027oo0002000fOol00`00Dad00003Dad01000@C11<44`0P00
0U<M00<005<MDad025<M00@005<MDaeC7@@00003@C00000000YC7@03001C7E<M00800004@C000000
0005Dad00`00DaeC7@07Dad20004NZh00`00NZh00002NZh20009Dad30002OZd01000OZen[@000e<M
00<005<MDad01U<M0`002E<M00<005<MDad015<M0P000U<M00<005<MDad025<M0P000gj[0P002E<M
0P000Wj[00L007j[001nZ`00OZ/00004E_d00`00OZ/00006AG440005AG430008E_d2000<Ool00`00
Oomoo`08Ool00003Ool007oo03Ioo`03001C7@00009C7@040011<0000005Dad00`00DaeC7@07Dad4
0005@C001000N/l0000025<M0`0000=1<00000002E<M00<005<MDad015<M0P000U<M00D007Z^NZij
[P00009j[P04001j[P000006Dad30002Dad01000OZen[@000gj]00D005<MDaeC7@0000=C7@@0009C
7@03001C7E<M00QC7@03001C7E<M00<000EC7@03001C7E<M00MC7@8000=nZ`03001C7@0000QC7@80
009nZ`05001nZ`00OZ/00002OZ/00`00E_eFo@02E_d20004AG4200000dEa0015L@06AG4200000gjZ
001Fo@02E_d4000?Ool00`00Oomoo`07Ool0009oo`8003Ioo`H000QC7@8000EC7@800003@C00044`
00I1<005001jcg[?N/l00003Dad400000d4`0011<002@C000`00DaeC7@08Dad00`00DaeC7@030005
Dad01000NZij[P000gZ^0P0000A5<000DaeC7@<000IC7@03001n[@0000An[@<00004AE0000000007
Dad00`00DaeC7@07Dad30009Dad00`00DaeC7@04Dad20002Dad01P00OZ]nZ`00Dad000IC7@80009C
7@03001nZ`00009nZ`80009nZ`8000=Fo@800004AG4000000003AG400`00AG55L@06AG400`00OZYn
ZP040008Ool20009Ool00`00Oomoo`06Ool000Aoo`03001oogoo03Eoo`04001oogoo000:Dad00`00
DaeC7@020003@C000`00@C11<005@C000`00N/mjc`02N/l30005@C000`00@C11<002@C000`00DaeC
7@07Dad30009Dad00`00NZh00004NZh200000dD`00000009Dad00`00OZd00004OZd00`00AE15D002
AE000`00DaeC7@06Dad00`00DaeC7@04Dad30002AE000`00DaeC7@08Dad00`00DaeC7@030005Dad0
0`00OZ/00002Dad00`00DaeC7@030005Dad00`00OZ/00002OZ/00`00OZ]nZ`020003E_d30006AG40
0`00AG55L@06AG4200001WjZ00000000OZX000=oo`@00003BG40000000Qoo`03001oogoo00Ioo`00
1Goo00<007ooOol0=Goo0P0000=oo`00000025<M0`001D4`00<0044`@C001D4`00<007[?N/l00W[?
00<0044`@C001D4`00<0044`@C000d4`00<005<MDad015<M0P000U<M00<005<MDad025<M0P0017Z^
00D004D`AC15<00000YC7@8000An[@030015D4E@00=5D003001C7E<M00IC7@03001C7E<M00<000I5
D003001C7E<M00MC7@<000QC7@04001nZ`00Dad40008Dad00`00OZ/00002OZ/200000gj[001nZ`03
00000dEa0015L@07AG400`00AG55L@05AG400`00OZX0000200000gjZ001nZP030005BG420008Ool2
0007Ool000Ioo`03001oogoo03Ioo`04001oogoo0003Dad400000e<M0011<005@C000`00@C11<005
@C000`00N/mjc`02N/l00`00@C11<005@C000`00@C11<004@C000`00DaeC7@030005Dad00`00DaeC
7@07Dad20004NZh00`00AC15<002AC000`00DaeC7@07Dad20004OZd00`00AE15D003AE000`00DaeC
7@06Dad30002AE000`00AE15D004AE000`00DaeC7@04Dad30002Dad00`00DaeC7@07Dad30002AE42
0009Dad20002OZ/01`00OZ/007j[001nZ`000095L@030015LDEa00I5L@030015LDEa00A5L@800004
OZX00000OZX200000gjZ0019L@06BG400`00OZT00003Ool400000goo001oo`06Ool000Moo`03001o
ogoo03Ioo`03001oogoo00<000EC7@030011<44`00A1<0030011<44`00A1<08000Ajc`030011<44`
00E1<0030011<44`00A1<0<000UC7@03001C7E<M00AC7@80009C7@05001j[WZ^NZh00005AC000`00
DaeC7@04Dad20002Dad01@00OZen[Gj]00001TE@00@005<MDaeC7@@000I5D0030015D4E@00A5D003
001C7E<M00<000IC7@03001C7E<M00IC7@8000=5D@8000QC7@<0009nZ`06001nZ`00OZ/007j[0P00
00=5L@00AG401dEa00<004EaAG4010000U<M00<007jZ00000`0000=nZP00BG401dUa00<007jY0000
0P001Goo00<007ooOol01Goo0008Ool2000gOol01000Oomoo`001U<M00<0044`@C00144`00<0044`
@C000T4`0P000U<M00D007[?N/mjc`0000M1<0030011<44`00@0009C7@03001C7E<M00QC7@03001C
7E<M00<000EC7@04001j[WZ^0006AC000`00DaeC7@030005Dad01000OZen[@001TE@100000=n[@00
AE001dE@00<004E@AE0014E@0`002E<M00<005<MDad015<M0P001DEA00<007j[00000e<M10000e<M
00<007j[00000Wj[0P0000InZ`00OZ/004Ea0006AG440007Dad01`00OZX007jZ001nZP0000Q9L@04
001nZ@000006Ool00`00Oomoo`05Ool000Yoo`03001oogoo03Eoo`04001oogoo0004Dad00`00@C11
<005@C000`00@C0000020005Dad01000N/mjc`001T4`10001e<M00<005<MDad01e<M0`002E<M00<0
07Z^00001TD`0`002E<M00<007j]000014E@0P000U<M00@007j]OZd000Q5D0030015D4E@00@0009C
7@03001C7E<M00QC7@03001C7E<M00<000M5D@03001nZgj[00<000QC7@03001nZ`00009nZ`07001n
Z`00OZ/004Ea000014Ea0P000U<M00<005<MDad01e<M0P0000EnZP00001nZP0000M9L@04001nZ@00
0007Ool00`00Oomoo`04Ool000]oo`03001oogoo03Eoo`04001oogoo0003Dad00`00@C11<004@C03
0009Dad00`00N/l00004@C020002Dad00`00DaeC7@07Dad00`00DaeC7@04Dad20002Dad00`00DaeC
7@08Dad20002AC040002Dad00`00DaeC7@08Dad2000014E@000000001E<M00<007j]00001dE@1000
1e<M00<005<MDad01e<M0`0000=5D@00AE401dEA00<007j[OZ/00P002E<M00<007j[00000Wj[0P00
00=nZ`00OZ/00P0000A5L@00000000AC7@03001C7E<M00MC7@D00003OZX004Ua00E9L@800004OZT0
07jY0006Ool00`00Oomoo`04Ool000aoo`03001oogoo03Eoo`04001oogoo0002Dad00`00@C11<004
0002Dad00`00DaeC7@08Dad20000144`000000001E<M00<005<MDad01e<M00<005<MDad0100000Ej
c`00DaeC7@0000UC7@@000MC7@03001C7E<M00IC7@@000QC7@03001n[@0000A5D0<0009C7@03001C
7E<M00IC7@03001C7E<M00AC7@<000A5D@030015DDEA00I5D@06001nZgj[001nZ`002E<M0P000Wj[
0P0000AnZ`00OZ]nZ`8000QC7@03001C7E<M00=C7@<0009C7@800003OZX000000099L@@0009Fo@04
001nZ@000006Ool00`00Oomoo`04Ool000eoo`03001oogoo03Eoo`03001oogoo00D000MC7@03001C
7E<M00MC7@<000UC7@03001C7E<M00IC7@<000=jc`04001jcg[?0002Dad00`00DaeC7@04Dad20002
Dad00`00DaeC7@07Dad01000DaeC7E<M10000dE@00<005<MDad01e<M0P0000A5D000000000IC7@03
001C7E<M00IC7@03001C7E<M00<000Q5D@030015DDEA00A5D@80009nZ`03001nZ`0000QC7@<0009n
Z`04001nZ`000002OZ/20008Dad00`00DaeC7@030005Dad01000OZX007jZ0`001UKm00D007jY001n
Z@0000Eoo`03001oogoo00Aoo`003Woo0P00=Woo00H007ooOol005<M0009Dad00`00DaeC7@04Dad2
0002Dad00`00DaeC7@08Dad01000DaeC7E<M10000U<M00@007[?N/l000Ajc`@0009C7@<000EC7@03
001C7E<M00IC7@@00095D0030015D4E@00=5D003001C7E<M00IC7@<000UC7@03001C7E<M00IC7@<0
0095D@030015DDEA00I5D@030015DDEA0095D@80009C7@03001nZ`00009nZ`04001C7E<MDad40003
Dad00`00OZ/00002OZ/00`00OZ]nZ`020008Dad30009Dad200000gjZ00000008E_d200000gjY001o
o`04Ool00`00Oomoo`04Ool0011oo`03001oogoo03Aoo`06001oogoo001C7@002E<M00<005<MDad0
0`001E<M00<005<MDad01e<M10001e<M00<007[?000017[?00@004E@AE15D08000QC7@03001C7E<M
00AC7@8000I5D0030015D4E@00=5D003001C7E<M00AC7@80009C7@03001C7E<M00QC7@04001C7E<M
Dad40005AE400`00AE55D@06AE400`00AE4000020005Dad00`00OZ/00002OZ/30007Dad00`00OZ/0
0002OZ/2000017j[001nZ`000e<M100000=9L@0000002E<M1@0025Km0P0000=nZ@00Ool017oo00<0
07ooOol017oo000AOol00`00Oomoo`0dOol01P00Oomoo`00Dad000QC7@<000UC7@03001C7E<M00AC
7@80009C7@03001C7E<M00MC7@8000Ajc`030015D4E@0095D003001C7E<M00MC7@03001C7E<M00@0
00M5D0030015D4E@00A5D003001C7E<M00<00003OZd005<M009C7@03001C7E<M00MC7@@00003OZd0
04EA00I5D@030015DDEA00A5D@@000QC7@03001nZ`00009nZ`8000UC7@80009nZ`06001nZ`00OZ/0
07j[0`001DUa00<007jZ000025<M0P0000AnZP00OZX000=Fo@@0009Fo@8000Eoo`03001oogoo00Ao
o`004Woo00<007ooOol0=7oo0P0000Aoo`00Dad000=C7@@0009C7@03001C7E<M00QC7@03001C7E<M
00<000EC7@03001C7E<M00IC7@8000Ajc`030015D4E@00=5D003001C7E<M00IC7@<000=5D0030015
D4E@00E5D0030015D4E@00A5D0<0009n[@04001n[Gj]0002Dad00`00DaeC7@04Dad30002Dad01000
OZen[@001dEA00<004EAAE4010000e<M00<005<MDad01e<M0P000Wj[00<005<M000025<M0P000Wj[
00L007j[001nZ`00OZ/00007BG401000OZYnZP000e<M10000U<M0`0000AnZP00000000IFo@03001n
Z@0000Aoo`03001oogoo00Aoo`004goo0P00=Woo00<007oo000010001e<M0P0025<M0`0025<M00<0
05<MDad015<M0P000U<M00D007[?N/mjc`0000I5D004001C7E<MDad40006AE000`00AE15D005AE00
0`00AE15D0040002Dad01000OZen[@000gj]10000U<M0`001U<M00<007j]00001TEA100025<M00<0
05<MDad01U<M0P000Wj[00<005<M00001U<M0P000U<M00<007j[00000Wj[0P0000=nZ`00BG401dUa
00<007jZOZX00`001U<M00@007jZ001nZP8000QFo@8000Eoo`03001oogoo00=oo`005Goo00<007oo
Ool0=7oo00D007oo001C7@0000YC7@04001C7E<MDad40002Dad00`00DaeC7@07Dad00`00DaeC7@03
0005Dad01000N/mjc`001TE@10000W[>00<004E@AE001DE@00<004E@AE0014E@10001e<M00<007j]
00000gj]0P000U<M0P002E<M00<007j]000014EA0P000U<M00<005<MDad025<M00@005<MDaeC7@@0
009C7@03001nZ`00009C7@03001C7E<M00<000EC7@03001nZ`00009nZ`03001nZ`0000Q9L@03001n
ZWjZ008000QC7@D000QFo@8000Eoo`03001oogoo00=oo`005Woo00<007ooOol0=7oo00<007oo0000
0P002E<M10001e<M0P001e<M0`002E<M00<007[?000014E@0P000U<M00D007[>N/ijcP0000M5D003
0015D4E@0095D080009C7@03001C7E<M00MC7@8000=n[@03001n[@00009C7@03001C7E<M00QC7@80
0004AE4000000005Dad00`00DaeC7@07Dad40007Dad01000OZ/005<M0`0025<M00<007j[00000Wj[
0P0000=nZ`00BG401TUa00<007jZOZX00P0025<M0P0000AnZP00E_d000EFo@8000Moo`03001oogoo
00=oo`005goo00<007ooOol0=7oo00<007ooOol00P001U<M0`0000=C7@00Dad02E<M00<005<MDad0
10000U<M00<005<MDad025<M0P0000A5D000000000EC7@04001jcW[>0007AE000`00AE0000020005
Dad00`00DaeC7@06Dad20003OZd00`00OZd00003Dad20008Dad30008Dad00`00DaeC7@04Dad30002
Dad00`00DaeC7@06Dad01000OZ/000000U<M00<005<MDad01e<M0P000Wj[0P0000=nZ`00BG401DUa
0P000WjZ00<007jZ00001E<M0P000U<M10000UKm0`002Goo00<007ooOol00goo000HOol00`00Oomo
o`0dOol00`00Oomoo`020002Dad30003Dad00`00Dad00009Dad30007Dad20008Dad30009Dad00`00
N/h00006AE030008Dad00`00DaeC7@04Dad20002Dad01000OZen[@000Wj]00<005<MDad00`000e<M
10000U<M00<005<MDad01e<M00<005<MDad00`001E<M00<005<MDad01e<M0P000e<M00<005<MDad0
1U<M0`000Wj[00@007j[00000099L@@0009C7@05001nZP00OZX00002Dad30004Dad00`00OZX00003
000<Ool00`00Oomoo`03Ool001Uoo`8003Eoo`03001oogoo00<000MC7@03001C7@0000IC7@80009C
7@03001C7E<M00MC7@04001C7E<MDad40002AE000`00DaeC7@08Dad20002AE040002Dad00`00DaeC
7@07Dad00`00DaeC7@030005Dad00`00OZd00003OZd20003AE430007Dad00`00DaeC7@06Dad30009
Dad00`00DaeC7@05Dad30004Dad01000DaeC7E<M10000e<M00<007j[00000Wj[0`001U<M00<007jZ
00000WjZ0P0025<M0`003Woo00<007ooOol00goo000KOol00`00Oomoo`0cOol01000Oomoo`0025<M
10000U<M0`001E<M00<005<MDad01U<M10000TE@00<004E@AE000TE@00<005<MDad01e<M10001e<M
00<005<MDad01U<M0`0025<M00<007j]00000gj]00<004EAAE400dEA00<005<MDad01e<M00@005<M
DaeC7@@00095D@03001C7E<M00MC7@04001C7E<MDad40007Dad40007Dad00`00OZ/00002OZ/20008
Dad20002OZX20008Dad3000>Ool00`00Oomoo`03Ool001aoo`03001oogoo03=oo`04001oogoo0005
Dad2000015<M0015D4E@0P0025<M00<005<MDad015<M0P001TE@00<004E@AE000dE@00<005<MDad0
15<M0P000U<M00<005<MDad01e<M00@005<MDaeC7@@0009C7@03001C7E<M00MC7@8000=n[@030015
DDEA00A5D@03001C7E<M00IC7@D000I5D@03001C7E<M00IC7@@00004OZ`007j/0005Dad200000dEa
00000009Dad20002OZ/20008Dad20002OZX20006Dad20003Ool00`00Oomoo`0<Ool00`00Oomoo`02
Ool001eoo`03001oogoo03=oo`04001oogoo0002Dad20003Dad01@00AE15D4E@00002E<M00<005<M
Dad010001dE@00<004E@AE0014E@00<005<MDad00`0000=jc`0000000U<M00<005<MDad01U<M1000
1e<M00<005<MDad01U<M0P000gj]00<004EAAE4014EA00<005<MDad015<M0P0014EA00<004EAAE40
1DEA00@005<MDaeC7@@0009C7@06001n[7j/001n[0000U<M0`000dEa00<007j[000025<M0P000Wj[
00<007j[00001E<M0P000U<M00D007jZ001C7@00009C7@<000Ioo`03001oogoo00]oo`03001oogoo
009oo`007Woo00<007ooOol0<goo00<007ooOol00P001E<M00<004E@AE000TE@0P001e<M0`000g[?
00<004E@AE001DE@00<004E@AE0014E@0`000W[?00L007[?N/mjc`00Dad00006Dad20002Dad00`00
DaeC7@07Dad01000DaeC7E<M10000U<M00D007j]OZen[@0000I5D@03001C7E<M00<000M5D@030015
DDEA00A5D@@000MC7@03001n[000009n[08000I5L@03001nZ`0000IC7@80009C7@05001nZ`00OZ/0
0002Dad30005Dad00`00OZX00003000:Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool001moo`8003Ao
o`800003Ool005<M00AC7@030015D4E@00A5D003001C7E<M00@0009C7@05001jcg[?N/l00007AE00
0`00AE15D0040002Dad01000N/mjc`0017[?0`000U<M0`001E<M00<005<MDad01U<M10001e<M0P00
00=n[@00AE401DEA0`0000=n[@00AE401dEA00<004EAAE400TEA0P000U<M00<005<MDad01U<M00<0
07j/00000Wj/00<004EaAG401DEa00@007j[OZ/0009C7@<000EC7@04001nZ`00OZ/20008Dad00`00
OZX0000=Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool0025oo`03001oogoo03=oo`04001oo`000003
Dad00`00AE15D004AE030007Dad200000g[?0015D005AE040007Dad00`00N/l00004N/l200000e<M
00000008Dad00`00DaeC7@04Dad20002Dad00`00DaeC7@08Dad20002AE440002Dad01000OZen[@00
1dEA00<004EA00000P001E<M00<005<MDad01U<M0P000Wj/00<004EaAG401TEa00<007j[OZ/00P00
25<M00@007j[001nZ`8000UC7@8000ioo`03001oogoo00Uoo`03001oogoo009oo`008Woo00<007oo
Ool0<goo00@007ooOol0009C7@030015D4E@0095D080009C7@03001C7E<M00MC7@800095D0@0009C
7@03001C7E<M00MC7@8000Ajc`05001jc`00Dad00009Dad00`00DaeC7@030005Dad00`00DaeC7@07
Dad40007Dad00`00OZd00006AE430008Dad00`00DaeC7@06Dad20002OZ`00`00AG55L@06AG400`00
OZ]nZ`020009Dad2000017j[001C7@0025<M0P003goo00<007ooOol027oo00<007ooOol00Woo000S
Ool00`00Oomoo`0cOol00`00Oomoo`03000014E@000000001E<M00<005<MDad01U<M10001e<M00<0
05<MDad01U<M0P0017[?00H007[?N/l005<M0008Dad30009Dad00`00DaeC7@04Dad20002AE400`00
DaeC7@07Dad20002AE440002Dad00`00DaeC7@07Dad01000DaeC7E<M10000U<M00@007j/OZ`000M5
L@03001nZgj[008000QC7@<00005OZ/005<MDad00003Dad4000AOol00`00Oomoo`08Ool00`00Oomo
o`02Ool002Aoo`03001oogoo03=oo`03001oogoo00<000QC7@03001C7E<M00AC7@80009C7@03001C
7E<M00MC7@04001C7E<MDad40002Dad01@00N/mjcg[?00000g[?0`000e<M10000U<M00<005<MDad0
25<M00<005<MDad00`001DEA00<005<MDad01U<M10001e<M00<005<MDad01U<M10001e<M00<007j/
00001TEa0P000Wj[00<007j[00000e<M10000e<M00@007j[001C7@@001Ioo`03001oogoo00Qoo`03
001oogoo005oo`009Goo0P00=7oo00<007ooOol00P002E<M00<005<MDad00`001E<M00<005<MDad0
1U<M10001e<M0P0000=jc`00N/l00W[?00<004EAAE400`001e<M0P0025<M0`0000=5D@00AE401DEA
00<005<MDad015<M0`0000=n[@00Dad025<M00@005<MDaeC7@@0009C7@03001C7E<M00MC7@800095
L@@0009C7@05001nZgj[001nZ`030007Dad01000OZ/000006goo00<007ooOol01goo00<007ooOol0
0Goo000WOol00`00Oomoo`0bOol00`00Oomoo`030007Dad30009Dad00`00DaeC7@03Dad20002AE40
0`00DaeC7@08Dad20003N/l01@00AE55DDEA00002U<M00@005<MDaeC7@@000E5D@030015DDEA00A5
D@03001C7E<M00@00005OZd007j]OZd00008Dad40007Dad00`00DaeC7@06Dad40007Dad01000OZ/0
07j[0P002E<M0P007Goo00<007ooOol01Woo00<007ooOol00Goo000XOol00`00Oomoo`0bOol00`00
Oomoo`030002Dad40002Dad00`00DaeC7@08Dad00`00DaeC7@030004AE400`00DaeC7@07Dad20003
N/l00`00AE55D@02AE420008Dad400000dEA0015D@06AE400`00AE55D@04AE43000017j]001n[Gj]
0P000Wj]00<005<MDad015<M0P000U<M00<005<MDad01e<M00@005<MDaeC7@@0009C7@03001C7E<M
00MC7@800004OZ/005<M0008Dad2000MOol00`00Oomoo`06Ool00`00Oomoo`01Ool002Uoo`03001o
ogoo039oo`05001oogoo001C7@020007Dad20008Dad30002AE400`00AE55D@03AE400`00DaeC7@04
Dad20002Dad01000N/mjc`001TEA00@005<MDaeC7@@000E5D@030015DDEA00E5D@030015DDEA00@0
009C7@04001n[Gj]0002OZd3000014Ea001C7E<M0`0015<M00<005<MDad01e<M10001U<M00<005<M
Dad01U<M0`0000EnZ`00DaeC7@0000=C7@@0021oo`03001oogoo00Eoo`03001oogoo005oo`00:Woo
0P00<goo00H007ooOol005<M0009Dad01000DaeC7E<M10001DEA00<004EAAE4014EA00<005<MDad0
0`001E<M00<007[?00001TEA100000=jcP00AE401TEA00<004EAAE4014EA10001e<M00<007j]0000
0Wj]00<004EaAG400TEa0P0025<M00<005<MDad00e<M0`000U<M00<005<MDad01U<M00@005<MDaeC
7@@000=C7@04001nZ`00Dad4000UOol00`00Oomoo`04Ool00`00Oomoo`01Ool002aoo`03001oogoo
035oo`06001oo`00001C7@0025<M10000TEA00<004EAAE4014EA00<004EAAE4014EA0`0025<M00<0
07[?000014EA0P000U<M00@007[>N/h000M5D@030015DDEA00@0009C7@03001C7E<M00MC7@80009n
[@030015LDEa00=5L@03001C7E<M00IC7@03001C7E<M00<000EC7@03001C7E<M00IC7@@000MC7@04
001nZ`00000YOol00`00Oomoo`04Ool00`00Oomoo`01Ool002eoo`03001oogoo035oo`800004AG40
05<M0003Dad40005AE400`00AE55D@05AE400`00AE55D@040002Dad00`00DaeC7@07Dad2000014EA
000000001E<M00<007[>00001TEA10001e<M00<005<MDad01U<M0P000Wj]00<004EaAG400dEa00<0
05<MDad01U<M0`002E<M00<005<MDad00e<M0P000U<M00<005<MDad01e<M0P00:goo00<007ooOol0
0goo00<007ooOol00Goo000^Ool00`00Oomoo`0aOol00`00AG4000050002Dad00`00AE55D@04AE40
0`00AE55D@04AE440007Dad00`00DaeC7@06Dad30008Dad00`00N/h00004AE420002Dad00`00DaeC
7@07Dad01000DaeC7E<M10000U<M00<007j]00001TEa00@005<MDaeC7@@0009C7@03001C7E<M00MC
7@03001C7E<M00<000EC7@03001C7E<M00IC7@8002aoo`03001oogoo00=oo`40005oo`5oo`00;goo
00<007ooOol0<7oo0P000UKm00<005<MDad00e<M00<004EAAE4014EA00<004EAAE4010000U<M00<0
05<MDad01e<M00@005<MDaeC7@@00095D@03001C7E<M00MC7@800004AE4000000005Dad00`00DaeC
7@06Dad40006Dad00`00OZd00006AG440007Dad00`00DaeC7@06Dad30008Dad00`00DaeC7@04Dad2
000_Ool00`00Oomoo`02Ool10001Ool1Ool0031oo`80035oo`05001FoEKmE_d00004Dad00`00AE55
D@03AE440007Dad20007Dad40002AE400`00AE55D@02AE400`00DaeC7@06Dad30008Dad00`00DaeC
7@04Dad20002Dad00`00DaeC7@06Dad20002AG440002Dad00`00DaeC7@07Dad01000DaeC7E<M1000
0U<M00<005<MDad01e<M00<005<MDad00`00<Goo00<007ooOol00Woo0@000Goo0Goo000bOol00`00
Oomoo`0_Ool01@00E_eFoEKm00000e<M00@004EAAE55D@80009C7@03001C7E<M00QC7@03001C7E<M
00@000E5D@030015DDEA00A5D@04001C7E<MDad400000dEa00000009Dad00`00DaeC7@0300000gZ^
001C7@02Dad00`00DaeC7@05Dad40007Dad00`00DaeC7@06Dad40003Dad01@00DaeC7E<M000025<M
0`00=Goo00D007ooOomoo`00009oo`00<goo00<007ooOol0;goo00<005KmE_d01@0000=5D@000000
1E<M00<005<MDad01e<M0`000W[?00<004EAAE4014EA00<004EAAE4014EA100000Ajc`00N/mjc`80
0003N/l005<M00MC7@<0009j[P04001j[WZ^0002Dad00`00DaeC7@03Dad20002Dad00`00DaeC7@07
Dad01000DaeC7E<M10001e<M100000=oo`00Dad00U<M1000>Goo00@007ooOol0009oo`00=7oo00<0
07ooOol0;goo0P000UKm00@005<M000000QC7@03001C7E<M00AC7@80009C7@04001jcg[?0006AE40
0`00AE55D@040002Dad01000N/mjc`000g[?10000e<M10000U<M00@007Z^NZh000=j[P800004Dad0
05<MDad20005Dad00`00DaeC7@06Dad4000017j]001C7@000e<M10001Woo0`00?Goo00@007ooOol0
009oo`00=Goo00<007ooOol0;goo00@005KmE_eFo@<000UC7@03001C7E<M00<000EC7@03001jc`00
00E5D@@000MC7@03001jc`0000=jc`040015LDEaAG430007Dad00`00NZh00003NZh20002Dad20008
Dad01000DaeC7E<M10000U<M00D007j]OZd005<M00@004]oo`03001oo`00009oo`00=Woo0P00<7oo
0P000eKm0P0025<M0`0025<M00<007[?00000dEA0P000U<M00<005<MDad01e<M0P000g[?00<004Ea
AG400TEa00<005<MDad01e<M0P000gZ^0P000e<M00<005<MDad01U<M10001e<M00@007j]0000051o
o`03001oo`00005oo`00>7oo00<007ooOol0;goo00<005KmE_d00`000e<M10000U<M00<005<MDad0
1e<M0P0000=5D@0000001E<M0P001e<M0P000g[?00<004EaAG400dEa00<005<MDad01U<M0P000gZ^
00<007Z^00000U<M00<005<MDad015<M0P000U<M00<005<MDad01e<M0P00DWoo0P000Goo000iOol0
0`00Oomoo`0_Ool300000dEa000000020007Dad00`00DaeC7@06Dad30009Dad00`00DaeC7@040002
Dad01000N/mjc`001TEa00@005<MDaeC7@@0009C7@04001j[WZ^0002NZh40002Dad30005Dad00`00
DaeC7@06Dad2001BOol20001Ool003Yoo`03001oogoo031oo`800003Dad0000000UC7@04001C7E<M
Dad40002Dad00`00DaeC7@07Dad30007Dad00`00N/l00006AG440007Dad00`00NZh00002NZh20002
Dad20008Dad00`00DaeC7@04Dad2001DOol20001Ool003]oo`80035oo`03001C7E<M00<000MC7@@0
00MC7@03001C7E<M00AC7@80009C7@03001C7E<M00IC7@800095L@@0009C7@03001C7E<M00MC7@80
009j[P03001C7@00009C7@03001C7E<M00MC7@03001C7E<M00<0059oo`@000=oo`00?Goo00<007oo
Ool0;goo00<005<MDad00`000U<M1`002E<M00<005<MDad00`001E<M00<005<MDad01E<M10001e<M
00<005<MDad01U<M0P000WZ^00@005<MDad0009C7@03001C7E<M00IC7@<0055oo`@000Moo`00?Woo
00<007ooOol0;goo00D005<MDad005<M008000IC7@<000MC7@<000UC7@03001C7E<M00@0009C7@03
001C7E<M00MC7@04001C7E<MDad40002Dad01@00NZij[P00Dad01@000e<M1000D7oo10002goo000o
Ool00`00Oomoo`0_Ool200000e<M001C7@07Dad40002Dad40002Dad00`00DaeC7@07Dad30007Dad0
0`00DaeC7@06Dad40007Dad01000NZh000001Goo0`00DGoo0`003goo0010Ool00`00Oomoo`0_Ool0
1000DaeC7@000e<M100000AC7@00AG55L@8000MC7@03001C7E<M00AC7@80009C7@03001C7E<M00IC
7@04001C7E<MDad40002Dad00`00DaeC7@07Dad2001FOol4000BOol0045oo`80031oo`800004Dad0
00000005Dad01@00AG55LDEa000025<M00<005<MDad00`001E<M00<005<MDad01E<M10001e<M00<0
05<MDad01U<M0P00DWoo10005Woo0013Ool00`00Oomoo`0]Ool50006Dad00`00AG55L@02AG400`00
DaeC7@05Dad30009Dad00`00DaeC7@0500000e<M001C7@08Dad01000DaeC7E<M1000D7oo10006Woo
0014Ool00`00Oomoo`0/Ool01@00Ool00000Dad00P0015<M00<004EaAG400dEa00<005<MDad01000
0U<M00<005<MDad01e<M0`001E<M00<005<M000025<M1000DGoo0`007Woo0015Ool00`00Oomoo`0[
Ool00`00Oomoo`050002Dad20005AG430007Dad00`00DaeC7@04Dad20008Dad40003Dad4001AOol4
000QOol004Ioo`03001oogoo02Yoo`04001oogooOol300001U<M000005<M0015L@@0009C7@03001C
7E<M00IC7@03001C7E<M00@00003Dad005<M009C7@@000Aoo`<0055oo`@002Eoo`00Agoo0P00:Woo
00<007ooOol00Woo1@0000=C7@0000001e<M00<005<MDad01E<M0`000g[?00<005<M00000`00FGoo
0`00:Goo0019Ool00`00Oomoo`0WOol00`00Oomoo`03Ool200001E<M000005<M000025<M00<005<M
Dad010000U<M0P000W[?0P00FGoo1000;7oo001:Ool00`00Oomoo`0VOol00`00Oomoo`04Ool20000
1E<M000005<M00001e<M0`0025<M0`00EWoo1000<7oo001;Ool00`00Oomoo`0UOol00`00Oomoo`05
Ool200000e<M000000020002Dad40002Dad00`00DaeC7@07Dad2001BOol4000dOol004aoo`8002Eo
o`03001oogoo00Moo`@00003Dad0000000MC7@03001C7E<M00AC7@80055oo`<003Qoo`00CWoo00<0
07ooOol08Woo00<007ooOol02Woo100025<M00<005<MDad00`00Cgoo1000>goo001?Ool00`00Oomo
o`0QOol00`00Oomoo`0=Ool20007Dad3001>Ool4000oOol0051oo`03001oogoo021oo`03001oogoo
00moo`03001C7E<M00@004eoo`@004=oo`00DGoo00<007ooOol07goo00<007ooOol047oo0P00CWoo
0`00Agoo001BOol2000OOol00`00Oomoo`1LOol4001:Ool005Aoo`03001oogoo01aoo`03001oogoo
05Qoo`@004ioo`00EGoo00<007ooOol06goo00<007ooOol0E7oo1000DWoo001FOol00`00Oomoo`0J
Ool00`00Oomoo`1AOol3001FOol005Moo`03001oogoo01Uoo`03001oogoo04eoo`@005Uoo`00F7oo
0P006Goo00<007ooOol0BGoo1000GGoo001JOol00`00Oomoo`0EOol00`00Oomoo`16Ool4001QOol0
05]oo`03001oogoo01Aoo`03001oogoo04=oo`<006Eoo`00G7oo00<007ooOol04goo00<007ooOol0
?goo1000J7oo001MOol00`00Oomoo`0BOol00`00Oomoo`0kOol4001/Ool005ioo`80019oo`03001o
ogoo03Moo`@0071oo`00H7oo00<007ooOol03goo00<007ooOol0=7oo0`00M7oo001QOol00`00Oomo
o`0>Ool00`00Oomoo`0`Ool4001gOol0069oo`03001oogoo00eoo`03001oogoo02aoo`@007]oo`00
Hgoo0P003Goo00<007ooOol0:Goo0`00Ogoo001UOol00`00Oomoo`0:Ool00`00Oomoo`0UOol40022
Ool006Ioo`03001oogoo00Uoo`03001oogoo025oo`@008Ioo`00Igoo00<007ooOol027oo00<007oo
Ool07Goo1000RWoo001XOol00`00Oomoo`07Ool00`00Oomoo`0JOol3002>Ool006Uoo`8000Moo`03
001oogoo01Ioo`@0095oo`00Jgoo00<007ooOol017oo00<007ooOol04Woo1000UGoo001/Ool00`00
Oomoo`03Ool00`00Oomoo`0>Ool4002IOol006eoo`03001oogoo009oo`03001oogoo00]oo`<009eo
o`00KWoo00D007ooOomoo`0000Uoo`@00:1oo`00Kgoo0P0000=oo`00Ool017oo1000Y7oo001aOol2
00000goo00000002002XOol0079oo`800:aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {214.313, 0}} -> {-0.000691804, 0.0945384, \
0.00332572, 0.00332572}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Neural networks (Neat stuff, but not suitable for this early in the \
day)\
\>", "Section"],

Cell["\<\
Neural networks are a particular functional structure just like \
linear expressions and polynomials. They can similarly be used as structures \
to approximate functions. \
\>", "Text"],

Cell[CellGroupData[{

Cell["Function approximation by fitting", "Subsection"],

Cell["\<\
Perhaps the easiest problem to understand is that of function \
approximation (or curve fitting). With a neural network you simply get a very \
flexible structure to fit your data. And the fitting problem is nonlinear. \
\
\>", "Text"],

Cell["\<\
Load the package (for this you will need the new neural networks \
applications package).\
\>", "Text"],

Cell[BoxData[
    \(<< NeuralNetworks`\)], "Input"],

Cell[TextData[{
  "Load some data (which is set to symbols ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "). "
}], "Text"],

Cell[BoxData[
    \(\(Get[\ "\<onedimfunc.dat\>"\ ];\)\)], "Input"],

Cell["Plot the data ... ", "Text"],

Cell[BoxData[
    \(<< \ LinearAlgebra`MatrixManipulation`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(dplot\  = \ 
        ListPlot[\ AppendRows[x, y], \ 
          PlotStyle\  \[Rule] \ PointSize[0.02]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.100251 0.306042 0.298023 [
[.22431 .29354 -3 -9 ]
[.22431 .29354 3 0 ]
[.42481 .29354 -3 -9 ]
[.42481 .29354 3 0 ]
[.62531 .29354 -3 -9 ]
[.62531 .29354 3 0 ]
[.82581 .29354 -3 -9 ]
[.82581 .29354 3 0 ]
[.01131 .00802 -12 -4.5 ]
[.01131 .00802 0 4.5 ]
[.01131 .15703 -24 -4.5 ]
[.01131 .15703 0 4.5 ]
[.01131 .45505 -18 -4.5 ]
[.01131 .45505 0 4.5 ]
[.01131 .60407 -6 -4.5 ]
[.01131 .60407 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22431 .30604 m
.22431 .31229 L
s
[(2)] .22431 .29354 0 1 Mshowa
.42481 .30604 m
.42481 .31229 L
s
[(4)] .42481 .29354 0 1 Mshowa
.62531 .30604 m
.62531 .31229 L
s
[(6)] .62531 .29354 0 1 Mshowa
.82581 .30604 m
.82581 .31229 L
s
[(8)] .82581 .29354 0 1 Mshowa
.125 Mabswid
.07393 .30604 m
.07393 .30979 L
s
.12406 .30604 m
.12406 .30979 L
s
.17419 .30604 m
.17419 .30979 L
s
.27444 .30604 m
.27444 .30979 L
s
.32456 .30604 m
.32456 .30979 L
s
.37469 .30604 m
.37469 .30979 L
s
.47494 .30604 m
.47494 .30979 L
s
.52506 .30604 m
.52506 .30979 L
s
.57519 .30604 m
.57519 .30979 L
s
.67544 .30604 m
.67544 .30979 L
s
.72556 .30604 m
.72556 .30979 L
s
.77569 .30604 m
.77569 .30979 L
s
.87594 .30604 m
.87594 .30979 L
s
.92607 .30604 m
.92607 .30979 L
s
.97619 .30604 m
.97619 .30979 L
s
.25 Mabswid
0 .30604 m
1 .30604 L
s
.02381 .00802 m
.03006 .00802 L
s
[(-1)] .01131 .00802 1 0 Mshowa
.02381 .15703 m
.03006 .15703 L
s
[(-0.5)] .01131 .15703 1 0 Mshowa
.02381 .45505 m
.03006 .45505 L
s
[(0.5)] .01131 .45505 1 0 Mshowa
.02381 .60407 m
.03006 .60407 L
s
[(1)] .01131 .60407 1 0 Mshowa
.125 Mabswid
.02381 .03782 m
.02756 .03782 L
s
.02381 .06762 m
.02756 .06762 L
s
.02381 .09743 m
.02756 .09743 L
s
.02381 .12723 m
.02756 .12723 L
s
.02381 .18683 m
.02756 .18683 L
s
.02381 .21663 m
.02756 .21663 L
s
.02381 .24644 m
.02756 .24644 L
s
.02381 .27624 m
.02756 .27624 L
s
.02381 .33584 m
.02756 .33584 L
s
.02381 .36565 m
.02756 .36565 L
s
.02381 .39545 m
.02756 .39545 L
s
.02381 .42525 m
.02756 .42525 L
s
.02381 .48486 m
.02756 .48486 L
s
.02381 .51466 m
.02756 .51466 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57426 m
.02756 .57426 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.02381 .30604 Mdot
.07393 .44892 Mdot
.12406 .55682 Mdot
.17419 .60332 Mdot
.22431 .57703 Mdot
.27444 .4844 Mdot
.32456 .3481 Mdot
.37469 .2015 Mdot
.42481 .0805 Mdot
.47494 .01472 Mdot
.52506 .02026 Mdot
.57519 .09577 Mdot
.62531 .22277 Mdot
.67544 .37015 Mdot
.72556 .50184 Mdot
.77569 .58559 Mdot
.82581 .60089 Mdot
.87594 .54401 Mdot
.92607 .42886 Mdot
.97619 .28365 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000COol5003oOol9Ool001Eo
o`03001oogoo00=oo`03001oogoo0?moo`=oo`005Goo00<007ooOol00goo0P00MGoo0`00Rgoo000=
Ool40004Ool00`00Oomoo`03Ool00`00Oomoo`1cOol50009Ool3001nOol001Eoo`03001oogoo00=o
o`03001oogoo07=oo`D000Qoo`D007eoo`0057oo0P001Goo00<007ooOol0Lgoo1@0027oo1@00OGoo
000KOol00`00Oomoo`1dOol30009Ool5001mOol001]oo`03001oogoo085oo`<007ioo`006goo00<0
07ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`800?moo`Aoo`006goo00<007ooOol0
ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0
ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0
ogoo0goo000KOol2003oOol4Ool001]oo`03001oogoo06Ioo`<009Uoo`006goo00<007ooOol0IGoo
1@00V7oo000KOol00`00Oomoo`1UOol5002HOol001]oo`03001oogoo06Eoo`D009Qoo`006goo00<0
07ooOol0IWoo0`009Goo0`00LGoo000KOol00`00Oomoo`2=Ool5001`Ool001]oo`03001oogoo08eo
o`D0071oo`006goo0P00SWoo1@00L7oo000KOol00`00Oomoo`2>Ool3001aOol001]oo`03001oogoo
0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo
0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol2003oOol4Ool001]oo`03001oogoo0?moo`=o
o`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=o
o`006goo00<007ooOol0ogoo0goo0008Ool20004Ool20004Ool20005Ool00`00Oomoo`3oOol3Ool0
00Moo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0ogoo0goo0007Ool01000Oomoo`00
2goo00<007ooOol00Woo0P00ogoo17oo00000goo000000020002Ool01000Oomoo`002Goo0P001Goo
00<007ooOol0ogoo0goo0007Ool01000Oomoo`002Goo00<007ooOol017oo00<007ooOol0ogoo0goo
0008Ool2000:Ool30004Ool00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<0
07ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo0P00
ogoo17oo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo05Uoo`<00:Ioo`006goo00<007oo
Ool0F7oo1@00YGoo000KOol00`00Oomoo`1HOol5002UOol001]oo`03001oogoo05Qoo`D00:Eoo`00
6goo00<007ooOol0FGoo0`00YWoo000KOol00`00Oomoo`3oOol3Ool001]oo`8009eoo`<006=oo`00
6goo00<007ooOol0Vgoo1@00HWoo000KOol00`00Oomoo`2KOol5001ROol001]oo`03001oogoo09]o
o`D0069oo`006goo00<007ooOol0W7oo0`00Hgoo000KOol00`00Oomoo`3oOol3Ool001]oo`03001o
ogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol2003oOol4Ool001]oo`03001oogoo0?mo
o`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?mo
o`=oo`006goo00<007ooOol0<7oo1000<goo0`00<Goo0`00<goo0P00;goo000KOol00`00Oomoo`0`
Ool00`00Oomoo`0eOol00`00Oomoo`0`Ool01000Oomoo`00<Goo00@007ooOol002ioo`006goo00<0
07ooOol0<Goo00<007ooOol0<Goo1@00<Goo00@007ooOol0035oo`04001oogoo000^Ool001]oo`80
03=oo`03001oogoo031oo`04001oogoo000bOol3000cOol2000VOol30006Ool001]oo`03001oogoo
031oo`04001oogoo000bOol00`00Ool0000cOol00`00Oomoo`0aOol01000Oomoo`0097oo1@001Goo
000KOol00`00Oomoo`0aOol2000dOol2000cOol3000bOol2000UOol50005Ool001]oo`03001oogoo
0?Qoo`D000Eoo`006goo00<007ooOol0nGoo0`001Woo000KOol00`00Oomoo`3oOol3Ool001Yoo`<0
0?moo`Aoo`006Goo1@00ogoo0goo000DOooo000=000001Uoo`D000Yoo`03001oogoo00Yoo`03001o
ogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00]oo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00]oo`03001oogoo00Yoo`03001oogoo00Eoo`006Woo0`00<goo00<007ooOol0<Woo00<007oo
Ool0<goo00<007ooOol0<Woo00<007ooOol0;Goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001o
ogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001o
ogoo0?moo`=oo`006goo0P00ogoo17oo000KOol00`00Oomoo`1<Ool3002cOol001]oo`03001oogoo
04]oo`D00;9oo`006goo00<007ooOol0Bgoo1@00/Woo000KOol00`00Oomoo`1;Ool5002bOol001]o
o`03001oogoo04aoo`<00;=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`2YOol3001F
Ool001]oo`800:Uoo`D005Eoo`006goo00<007ooOol0Z7oo1@00EGoo000KOol00`00Oomoo`2XOol5
001EOol001]oo`03001oogoo0:Uoo`<005Ioo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomo
o`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol2003oOol4
Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3
Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3
Ool001]oo`03001oogoo0>aoo`<001=oo`006goo0P00k7oo1@004Woo000KOol00`00Oomoo`3[Ool5
000BOol001]oo`03001oogoo0>]oo`D0019oo`006goo00<007ooOol0k7oo0`004goo000KOol00`00
Oomoo`09Ool3003fOol001]oo`03001oogoo00Qoo`D00?Eoo`0027oo0P0017oo0P0017oo0P001Goo
00<007ooOol027oo1@00mGoo0007Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo00Qo
o`D00?Eoo`001goo00@007ooOol000]oo`03001oogoo009oo`8000Yoo`<00?Ioo`001goo00@007oo
Ool000Uoo`8000Eoo`03001oogoo0?moo`=oo`001goo00@007ooOol000Uoo`03001oogoo00Aoo`03
001oogoo0?moo`=oo`0027oo0P002Woo0`0017oo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3o
Ool3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0?Woo0`00`Goo000KOol00`00Oomo
o`0mOol50030Ool001]oo`8003ioo`D00<1oo`006goo00<007ooOol0?Goo1@00`7oo000KOol00`00
Oomoo`0nOol3001eOol30019Ool001]oo`03001oogoo0;Eoo`D004Qoo`006goo00<007ooOol0]Goo
1@00B7oo000KOol00`00Oomoo`2eOol50018Ool001]oo`03001oogoo0;Ioo`<004Uoo`006goo00<0
07ooOol0ogoo0goo000KOol2003oOol4Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0
ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0
gWoo0`008Goo000KOol00`00Oomoo`3MOol5000POol001]oo`800=ioo`D0021oo`006goo00<007oo
Ool0gGoo1@0087oo000KOol00`00Oomoo`0FOol30035Ool3000QOol001]oo`03001oogoo01Eoo`D0
0>Qoo`006goo00<007ooOol05Goo1@00j7oo000KOol00`00Oomoo`0EOol5003XOol001]oo`03001o
ogoo01Ioo`<00>Uoo`006goo00<007ooOol0<Goo0`00cWoo000KOol2000aOol5003=Ool001]oo`03
001oogoo031oo`D00<eoo`006goo00<007ooOol0<7oo1@00Sgoo0`00>goo000KOol00`00Oomoo`0a
Ool3002?Ool5000jOol001]oo`03001oogoo0<=oo`D003Yoo`006goo00<007ooOol0`goo1@00>Woo
000COol50003Ool00`00Oomoo`0TOol3002MOol3000:Ool3000^Ool001Eoo`03001oogoo00=oo`03
001oogoo02=oo`D00:Qoo`D002eoo`005Goo00<007ooOol00goo0P0097oo1@00Z7oo1@00;Goo000E
Ool00`00Oomoo`03Ool00`00Oomoo`0SOol5002XOol5000]Ool001Eoo`03001oogoo00=oo`03001o
ogoo02Aoo`<00:Yoo`<002ioo`0057oo0P001Goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3o
Ool3Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.02471, -1.11595, \
0.037499, 0.0126142}}]
}, Open  ]],

Cell["Initilize, i.e. get initial values for parameter fit. ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f0 = InitializeFeedForwardNet[x, y, {3}]\)], "Input"],

Cell[BoxData[
    TagBox[
      TagBox[\(FeedForwardNet[{{w1, w2}}, {Neuron\  \[Rule] \ Sigmoid, \ 
            FixedParameters\  \[Rule] \ None, \ 
            AccumulatedIterations\  \[Rule] \ 0, \ 
            CreationDate\  \[Rule] \ {2002, \ 7, \ 13, \ 15, \ 29, \ 5}, \ 
            OutputNonlinearity\  \[Rule] \ None, \ 
            NumberOfInputs\  \[Rule] \ 1}]\),
        Null,
        Editable->False],
      DisplayForm]], "Output"]
}, Open  ]],

Cell["\<\
This is the resulting (vector) function. This shows the structure \
of the feedforward neural network function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f0[{\ a\ }\ ]\)], "Input"],

Cell[BoxData[
    \({\(-6.285970945766158`\) + 
        5.530196415957265`\/\(1 + \[ExponentialE]\^\(\(\(9.045658478584478`\)\
\(\[InvisibleSpace]\)\) - 1.7831848847187164`\ a\)\) + 
        1.3099452145381882`\/\(1 + \
\[ExponentialE]\^\(\(\(2.005235014829063`\)\(\[InvisibleSpace]\)\) - \
1.433118686967168`\ a\)\) + 
        6.478893582423208`\/\(1 + \[ExponentialE]\^\(\(-5.826228520854685`\) \
+ 1.4274621515972905`\ a\)\)}\)], "Output"]
}, Open  ]],

Cell["The initial fit isn't particularly good ... ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[\ f0[\ {a}\ ], \ {a, \ 0, \ 3  \[Pi]}\ ];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.101051 0.368143 0.286501 [
[.22591 .35564 -3 -9 ]
[.22591 .35564 3 0 ]
[.42801 .35564 -3 -9 ]
[.42801 .35564 3 0 ]
[.63011 .35564 -3 -9 ]
[.63011 .35564 3 0 ]
[.83222 .35564 -3 -9 ]
[.83222 .35564 3 0 ]
[.01131 .08164 -12 -4.5 ]
[.01131 .08164 0 4.5 ]
[.01131 .22489 -24 -4.5 ]
[.01131 .22489 0 4.5 ]
[.01131 .51139 -18 -4.5 ]
[.01131 .51139 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22591 .36814 m
.22591 .37439 L
s
[(2)] .22591 .35564 0 1 Mshowa
.42801 .36814 m
.42801 .37439 L
s
[(4)] .42801 .35564 0 1 Mshowa
.63011 .36814 m
.63011 .37439 L
s
[(6)] .63011 .35564 0 1 Mshowa
.83222 .36814 m
.83222 .37439 L
s
[(8)] .83222 .35564 0 1 Mshowa
.125 Mabswid
.07433 .36814 m
.07433 .37189 L
s
.12486 .36814 m
.12486 .37189 L
s
.17539 .36814 m
.17539 .37189 L
s
.27644 .36814 m
.27644 .37189 L
s
.32696 .36814 m
.32696 .37189 L
s
.37749 .36814 m
.37749 .37189 L
s
.47854 .36814 m
.47854 .37189 L
s
.52906 .36814 m
.52906 .37189 L
s
.57959 .36814 m
.57959 .37189 L
s
.68064 .36814 m
.68064 .37189 L
s
.73116 .36814 m
.73116 .37189 L
s
.78169 .36814 m
.78169 .37189 L
s
.88274 .36814 m
.88274 .37189 L
s
.93327 .36814 m
.93327 .37189 L
s
.98379 .36814 m
.98379 .37189 L
s
.25 Mabswid
0 .36814 m
1 .36814 L
s
.02381 .08164 m
.03006 .08164 L
s
[(-1)] .01131 .08164 1 0 Mshowa
.02381 .22489 m
.03006 .22489 L
s
[(-0.5)] .01131 .22489 1 0 Mshowa
.02381 .51139 m
.03006 .51139 L
s
[(0.5)] .01131 .51139 1 0 Mshowa
.125 Mabswid
.02381 .11029 m
.02756 .11029 L
s
.02381 .13894 m
.02756 .13894 L
s
.02381 .16759 m
.02756 .16759 L
s
.02381 .19624 m
.02756 .19624 L
s
.02381 .25354 m
.02756 .25354 L
s
.02381 .28219 m
.02756 .28219 L
s
.02381 .31084 m
.02756 .31084 L
s
.02381 .33949 m
.02756 .33949 L
s
.02381 .39679 m
.02756 .39679 L
s
.02381 .42544 m
.02756 .42544 L
s
.02381 .45409 m
.02756 .45409 L
s
.02381 .48274 m
.02756 .48274 L
s
.02381 .05299 m
.02756 .05299 L
s
.02381 .02434 m
.02756 .02434 L
s
.02381 .54004 m
.02756 .54004 L
s
.02381 .56869 m
.02756 .56869 L
s
.02381 .59734 m
.02756 .59734 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .46268 m
.06244 .48527 L
.10458 .51883 L
.14415 .55533 L
.16408 .57291 L
.18221 .58672 L
.19159 .5926 L
.20178 .59773 L
.20738 .5999 L
.21254 .60147 L
.21509 .60207 L
.21748 .60253 L
.21997 .6029 L
.22129 .60305 L
.22203 .60312 L
.22272 .60318 L
.22336 .60322 L
.22405 .60326 L
.22525 .6033 L
.22594 .60332 L
.22666 .60332 L
.22796 .6033 L
.22916 .60325 L
.23028 .60317 L
.2315 .60306 L
.23282 .60291 L
.23578 .60243 L
.23859 .6018 L
.24385 .60014 L
.24885 .59797 L
.25347 .59543 L
.26394 .58769 L
.27357 .57804 L
.28261 .56664 L
.30321 .53184 L
.32339 .48551 L
.34189 .43263 L
.38152 .29255 L
.41963 .14815 L
.44088 .08058 L
.45093 .05536 L
.46019 .03698 L
.46478 .0298 L
.46983 .02346 L
.4749 .01878 L
.47768 .01697 L
.47892 .01633 L
.48027 .01575 L
.48154 .01532 L
.48272 .01502 L
Mistroke
.48385 .01483 L
.48505 .01472 L
.48623 .01472 L
.48734 .0148 L
.48834 .01494 L
.48941 .01517 L
.4906 .01552 L
.4919 .01602 L
.49453 .01738 L
.49696 .01905 L
.49923 .02097 L
.50426 .02643 L
.50971 .03419 L
.51963 .05281 L
.53819 .10079 L
.57903 .23622 L
.59932 .30201 L
.61835 .35593 L
.63677 .39922 L
.65615 .43521 L
.67637 .46347 L
.69489 .48244 L
.71467 .49703 L
.73305 .5066 L
.7436 .51076 L
.75355 .51397 L
.77215 .51849 L
.7819 .52026 L
.7922 .52177 L
.81067 .52376 L
.82013 .5245 L
.83028 .52514 L
.8398 .52561 L
.84861 .52596 L
.85876 .52628 L
.86982 .52655 L
.87957 .52672 L
.88993 .52686 L
.89929 .52696 L
.9042 .527 L
.90938 .52703 L
.91393 .52706 L
.91891 .52708 L
.92765 .52711 L
.93293 .52712 L
.93791 .52713 L
.94239 .52714 L
.94491 .52714 L
.94724 .52714 L
.94974 .52714 L
Mistroke
.95208 .52714 L
.95342 .52715 L
.95465 .52715 L
.95532 .52715 L
.95606 .52715 L
.95676 .52715 L
.95741 .52715 L
.95808 .52715 L
.95882 .52715 L
.95951 .52715 L
.96014 .52715 L
.96135 .52715 L
.96262 .52715 L
.96399 .52714 L
.96527 .52714 L
.96818 .52714 L
.97237 .52714 L
.97619 .52714 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000KOol00`00Oomoo`3oOol3
Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`1fOol5
0027Ool001]oo`03001oogoo07Eoo`03001oogoo00=oo`03001oogoo08Aoo`006goo0P00M7oo0P00
1goo00<007ooOol0Pgoo000KOol00`00Oomoo`1bOol00`00Oomoo`08Ool00`00Oomoo`22Ool001]o
o`03001oogoo079oo`03001oogoo00Qoo`03001oogoo089oo`006goo00<007ooOol0LGoo00<007oo
Ool02Woo00<007ooOol0PGoo000KOol00`00Oomoo`1aOol00`00Oomoo`0;Ool00`00Oomoo`20Ool0
01]oo`03001oogoo071oo`03001oogoo00aoo`03001oogoo081oo`006goo00<007ooOol0L7oo00<0
07ooOol03Goo00<007ooOol0Ogoo000KOol00`00Oomoo`1_Ool00`00Oomoo`0>Ool00`00Oomoo`1o
Ool001]oo`80071oo`03001oogoo00moo`03001oogoo07ioo`006goo00<007ooOol0KWoo00<007oo
Ool047oo00<007ooOol0OWoo000KOol00`00Oomoo`1^Ool00`00Oomoo`0AOol00`00Oomoo`1mOol0
01]oo`03001oogoo06eoo`03001oogoo019oo`03001oogoo07eoo`006goo00<007ooOol0KGoo00<0
07ooOol04goo00<007ooOol0O7oo000KOol00`00Oomoo`1]Ool00`00Oomoo`0COol00`00Oomoo`1l
Ool001=oo`D000=oo`03001oogoo06aoo`03001oogoo01Aoo`03001oogoo07aoo`005Goo00<007oo
Ool00goo00<007ooOol0K7oo00<007ooOol05Goo00<007ooOol0Ngoo000EOol00`00Oomoo`03Ool2
001]Ool00`00Oomoo`0EOol00`00Oomoo`1kOol000eoo`@000Aoo`03001oogoo00=oo`03001oogoo
06]oo`03001oogoo01Ioo`03001oogoo07]oo`005Goo00<007ooOol00goo00<007ooOol0Jgoo00<0
07ooOol05goo00<007ooOol0NWoo000DOol20005Ool00`00Oomoo`1[Ool00`00Oomoo`0GOol00`00
Oomoo`1jOol001]oo`03001oogoo06Yoo`03001oogoo01Uoo`03001oogoo07Uoo`006goo00<007oo
Ool0JWoo00<007ooOol06Goo00<007ooOol0NGoo000KOol00`00Oomoo`1ZOol00`00Oomoo`0IOol0
0`00Oomoo`1iOol001]oo`8006Yoo`03001oogoo01]oo`03001oogoo07Qoo`006goo00<007ooOol0
JGoo00<007ooOol06goo00<007ooOol0N7oo000KOol00`00Oomoo`1YOol00`00Oomoo`0KOol00`00
Oomoo`1hOol001]oo`03001oogoo06Qoo`03001oogoo01eoo`03001oogoo07Moo`006goo00<007oo
Ool0J7oo00<007ooOol07Goo00<007ooOol0Mgoo000KOol00`00Oomoo`1XOol00`00Oomoo`0MOol0
0`00Oomoo`1gOol001]oo`03001oogoo06Moo`03001oogoo01ioo`03001oogoo07Moo`006goo00<0
07ooOol0Igoo00<007ooOol07goo00<007ooOol0MWoo000KOol2001XOol00`00Oomoo`0OOol00`00
Oomoo`1fOol001]oo`03001oogoo06Ioo`03001oogoo021oo`03001oogoo07Ioo`006goo00<007oo
Ool0IWoo00<007ooOol08Goo00<007ooOol0MGoo000KOol00`00Oomoo`1VOol00`00Oomoo`0QOol0
0`00Oomoo`1eOol001]oo`03001oogoo06Eoo`03001oogoo029oo`03001oogoo07Eoo`006goo00<0
07ooOol0IGoo00<007ooOol08goo00<007ooOol0M7oo000KOol00`00Oomoo`1UOol00`00Oomoo`0S
Ool00`00Oomoo`1dOol001]oo`8006Ioo`03001oogoo02=oo`03001oogoo07Aoo`006goo00<007oo
Ool0I7oo00<007ooOol097oo00<007ooOol0M7oo000KOol00`00Oomoo`1TOol00`00Oomoo`0UOol0
0`00Oomoo`1cOol001]oo`03001oogoo06Aoo`03001oogoo02Eoo`03001oogoo07=oo`006goo00<0
07ooOol0I7oo00<007ooOol09Goo00<007ooOol0Lgoo000KOol00`00Oomoo`1SOol00`00Oomoo`0W
Ool00`00Oomoo`1bOol001]oo`03001oogoo06=oo`03001oogoo02Moo`03001oogoo079oo`006goo
00<007ooOol0Hgoo00<007ooOol09goo00<007ooOol0LWoo000KOol2001TOol00`00Oomoo`0XOol0
0`00Oomoo`1aOol001]oo`03001oogoo069oo`03001oogoo02Uoo`03001oogoo075oo`006goo00<0
07ooOol0HWoo00<007ooOol0:Goo00<007ooOol0LGoo000KOol00`00Oomoo`1ROol00`00Oomoo`0Z
Ool00`00Oomoo`1`Ool001]oo`03001oogoo069oo`03001oogoo02Yoo`03001oogoo071oo`006goo
00<007ooOol0HGoo00<007ooOol0:goo00<007ooOol0L7oo0008Ool20004Ool20004Ool20005Ool0
0`00Oomoo`1QOol00`00Oomoo`0[Ool00`00Oomoo`1`Ool000Moo`04001oogoo0008Ool01000Oomo
o`0017oo00<007ooOol0HGoo00<007ooOol0;7oo00<007ooOol0Kgoo0007Ool01000Oomoo`002goo
00<007ooOol00Woo0P00HWoo00<007ooOol0;7oo00<007ooOol0Kgoo00000goo000000020002Ool0
1000Oomoo`002Goo0P001Goo00<007ooOol0H7oo00<007ooOol0;Goo00<007ooOol0Kgoo0007Ool0
1000Oomoo`002Goo00<007ooOol017oo00<007ooOol0H7oo00<007ooOol0;Woo00<007ooOol0KWoo
0008Ool2000:Ool30004Ool00`00Oomoo`1POol00`00Oomoo`0^Ool00`00Oomoo`1^Ool001]oo`03
001oogoo061oo`03001oogoo02ioo`03001oogoo06ioo`006goo00<007ooOol0Ggoo00<007ooOol0
<7oo00<007ooOol0KGoo000KOol00`00Oomoo`1OOol00`00Oomoo`0`Ool00`00Oomoo`1]Ool001]o
o`80061oo`03001oogoo031oo`03001oogoo06eoo`006goo00<007ooOol0Ggoo00<007ooOol0<7oo
00<007ooOol0KGoo000KOol00`00Oomoo`1NOol00`00Oomoo`0bOol00`00Oomoo`1/Ool001]oo`03
001oogoo05ioo`03001oogoo039oo`03001oogoo06aoo`006goo00<007ooOol0GWoo00<007ooOol0
<Woo00<007ooOol0K7oo000KOol00`00Oomoo`1NOol00`00Oomoo`0cOol00`00Oomoo`1[Ool001]o
o`03001oogoo05eoo`03001oogoo03Aoo`03001oogoo06]oo`006goo00<007ooOol0GGoo00<007oo
Ool0=7oo00<007ooOol0Jgoo000KOol2001NOol00`00Oomoo`0eOol00`00Oomoo`1ZOol001]oo`03
001oogoo05eoo`03001oogoo03Eoo`03001oogoo06Yoo`006goo00<007ooOol0G7oo00<007ooOol0
=Woo00<007ooOol0JWoo000KOol00`00Oomoo`1LOol00`00Oomoo`0fOol00`00Oomoo`1ZOol001]o
o`03001oogoo05aoo`03001oogoo03Moo`03001oogoo06Uoo`006goo00<007ooOol0Fgoo00<007oo
Ool0>7oo00<007ooOol0JGoo000KOol00`00Oomoo`1KOol00`00Oomoo`0hOol00`00Oomoo`1YOol0
01]oo`03001oogoo05]oo`03001oogoo03Uoo`03001oogoo06Qoo`006goo0P00G7oo00<007ooOol0
>Goo00<007ooOol0J7oo000KOol00`00Oomoo`1JOol00`00Oomoo`0jOol00`00Oomoo`1XOol001]o
o`03001oogoo05Yoo`03001oogoo03]oo`03001oogoo06Moo`006goo00<007ooOol0<Goo10009Goo
00<007ooOol02goo0`00;Goo00@007ooOomoo`<003Aoo`8002eoo`006goo00<007ooOol0<Goo00<0
07ooOol09Goo00<007ooOol03Goo00<007ooOol0;7oo00D007ooOomoo`00009oo`03001oogoo031o
o`04001oogoo000/Ool001]oo`03001oogoo039oo`03001oogoo02Aoo`03001oogoo00Yoo`D002io
o`04001oogoo0002Ool00`00Oomoo`0`Ool01000Oomoo`00;7oo000KOol00`00Oomoo`0cOol00`00
Oomoo`0SOol00`00Oomoo`0:Ool01000Oomoo`00;goo00<007ooOol00`00=7oo0P00;Goo000KOol2
000bOol01000Oomoo`008goo00<007ooOol037oo00<007oo0000;goo00D007ooOomoo`0003Aoo`04
001oogoo000/Ool001]oo`03001oogoo039oo`8002Aoo`03001oogoo00eoo`80031oo`03001oogoo
00<003=oo`8002eoo`006goo00<007ooOol0F7oo00<007ooOol0?goo00<007ooOol0IGoo000KOol0
0`00Oomoo`1HOol00`00Oomoo`0oOol00`00Oomoo`1UOol001]oo`03001oogoo05Moo`03001oogoo
045oo`03001oogoo06Aoo`006goo00<007ooOol0Egoo00<007ooOol0@Goo00<007ooOol0I7oo000K
Ool00`00Oomoo`1GOol00`00Oomoo`11Ool00`00Oomoo`1TOol001]oo`03001oogoo05Ioo`03001o
ogoo04=oo`03001oogoo06=oo`0057ooo`003@00000KOol00`00Oomoo`0:Ool00`00Oomoo`0;Ool0
0`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool0
0`00Oomoo`09Ool2000=Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomo
o`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool001]oo`03001oogoo05Eoo`03
001oogoo04Eoo`03001oogoo069oo`006goo00<007ooOol0EGoo00<007ooOol0AWoo00<007ooOol0
HGoo000KOol00`00Oomoo`1EOol00`00Oomoo`16Ool00`00Oomoo`1QOol001]oo`03001oogoo05Eo
o`03001oogoo04Moo`03001oogoo061oo`006goo00<007ooOol0E7oo00<007ooOol0B7oo00<007oo
Ool0H7oo000KOol2001EOol00`00Oomoo`19Ool00`00Oomoo`1OOol001]oo`03001oogoo05Aoo`03
001oogoo04Uoo`03001oogoo05moo`006goo00<007ooOol0Dgoo00<007ooOol0BWoo00<007ooOol0
Ggoo000KOol00`00Oomoo`1COol00`00Oomoo`1;Ool00`00Oomoo`1NOol001]oo`03001oogoo05=o
o`03001oogoo04]oo`03001oogoo05ioo`006goo00<007ooOol0DWoo00<007ooOol0CGoo00<007oo
Ool0GGoo000KOol00`00Oomoo`1BOol00`00Oomoo`1=Ool00`00Oomoo`1MOol001]oo`03001oogoo
059oo`03001oogoo04ioo`03001oogoo05aoo`006goo0P00Dgoo00<007ooOol0CWoo00<007ooOol0
G7oo000KOol00`00Oomoo`1AOol00`00Oomoo`1@Ool00`00Oomoo`1KOol001]oo`03001oogoo055o
o`03001oogoo051oo`03001oogoo05]oo`006goo00<007ooOol0DGoo00<007ooOol0DGoo00<007oo
Ool0FWoo000KOol00`00Oomoo`1@Ool00`00Oomoo`1COol00`00Oomoo`1IOol001]oo`03001oogoo
051oo`03001oogoo05=oo`03001oogoo05Uoo`006goo00<007ooOol0D7oo00<007ooOol0E7oo00<0
07ooOol0F7oo000KOol00`00Oomoo`1@Ool00`00Oomoo`1EOol00`00Oomoo`1GOol001]oo`80051o
o`03001oogoo05Moo`03001oogoo05Ioo`006goo00<007ooOol0Cgoo00<007ooOol0Egoo00<007oo
Ool0EWoo000KOol00`00Oomoo`1?Ool00`00Oomoo`1HOol00`00Oomoo`1EOol001]oo`<004ioo`03
001oogoo05Yoo`03001oogoo05Aoo`006goo00<007ooOol00P00C7oo00<007ooOol0Fgoo00<007oo
Ool0Dgoo000KOol00`00Oomoo`02Ool00`00Oomoo`19Ool00`00Oomoo`1LOol00`00Oomoo`1BOol0
01]oo`03001oogoo00=oo`8004Uoo`03001oogoo05eoo`03001oogoo055oo`006goo0P001Woo0P00
AWoo00<007ooOol0Ggoo00<007ooOol0D7oo000KOol00`00Oomoo`07Ool00`00Oomoo`13Ool00`00
Oomoo`1POol2001@Ool001]oo`03001oogoo00Qoo`03001oogoo045oo`03001oogoo06=oo`03001o
ogoo04eoo`006goo00<007ooOol02Goo0P00@Goo00<007ooOol0I7oo0P00CGoo000KOol00`00Oomo
o`0;Ool00`00Oomoo`0mOol00`00Oomoo`1WOol00`00Oomoo`1:Ool001]oo`03001oogoo00aoo`03
001oogoo03aoo`03001oogoo06Qoo`03001oogoo04Uoo`0027oo0P0017oo0P0017oo0P001Goo00<0
07ooOol03Goo00<007ooOol0>Woo00<007ooOol0JWoo0P00BGoo0007Ool01000Oomoo`0027oo00@0
07ooOol000Aoo`03001oogoo00ioo`03001oogoo03Uoo`03001oogoo06aoo`8004Moo`001goo00@0
07ooOol000]oo`03001oogoo009oo`80011oo`8003Qoo`03001oogoo06moo`<004Aoo`001goo00@0
07ooOol000Uoo`8000Eoo`03001oogoo015oo`03001oogoo03Eoo`03001oogoo079oo`@0041oo`00
1goo00@007ooOol000Uoo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo03=oo`03001oogoo
07Moo`H003Yoo`0027oo0P002Woo0`0017oo00<007ooOol04goo00<007ooOol0<Woo00<007ooOol0
OGoo2P00<7oo000KOol00`00Oomoo`0DOol00`00Oomoo`0`Ool00`00Oomoo`28OolY0007Ool001]o
o`03001oogoo01Eoo`03001oogoo02moo`03001oogoo0;Qoo`006goo00<007ooOol05Woo00<007oo
Ool0;Goo00<007ooOol0^Goo000KOol2000HOol2000]Ool00`00Oomoo`2iOol001]oo`03001oogoo
01Uoo`03001oogoo02Uoo`03001oogoo0;Yoo`006goo00<007ooOol06Woo00<007ooOol0:7oo00<0
07ooOol0^Woo000KOol00`00Oomoo`0KOol00`00Oomoo`0VOol00`00Oomoo`2kOol001]oo`03001o
ogoo01aoo`03001oogoo02Eoo`03001oogoo0;]oo`006goo00<007ooOol07Goo00<007ooOol08goo
00<007ooOol0_7oo000KOol00`00Oomoo`0NOol00`00Oomoo`0ROol00`00Oomoo`2lOol001]oo`03
001oogoo01moo`80025oo`03001oogoo0;eoo`006goo0P008Woo00<007ooOol07Woo00<007ooOol0
_Goo000KOol00`00Oomoo`0ROol00`00Oomoo`0LOol00`00Oomoo`2nOol001]oo`03001oogoo02=o
o`03001oogoo01Yoo`03001oogoo0;moo`006goo00<007ooOol097oo0P006Goo00<007ooOol0`7oo
000KOol00`00Oomoo`0VOol00`00Oomoo`0EOol00`00Oomoo`31Ool001]oo`03001oogoo02Moo`03
001oogoo01=oo`03001oogoo0<9oo`006goo00<007ooOol0:7oo0P004Goo0P00aGoo000KOol00`00
Oomoo`0ZOol2000>Ool00`00Oomoo`35Ool001]oo`8002eoo`<000Qoo`<00<Qoo`006goo00<007oo
Ool0;goo2000bgoo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<0
07ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0166, -1.36722, \
0.0372022, 0.0131215}}]
}, Open  ]],

Cell["\<\
By training or fitting this parameter structure better we get \
better fit. You can see the root mean square error in the picture below. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({f, \ r}\  = \ NeuralFit[\ f0, \ x, \ y\ ]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 -0.000509979 2.2218 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -32.625 -22.1875 ]
[.5 -0.0125 32.625 -9 ]
[-0.0125 .11058 -24 -4.5 ]
[-0.0125 .11058 0 4.5 ]
[-0.0125 .22167 -18 -4.5 ]
[-0.0125 .22167 0 4.5 ]
[-0.0125 .33276 -24 -4.5 ]
[-0.0125 .33276 0 4.5 ]
[-0.0125 .44385 -18 -4.5 ]
[-0.0125 .44385 0 4.5 ]
[-0.0125 .55494 -24 -4.5 ]
[-0.0125 .55494 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -14.25 0 ]
[.5 .63053 14.25 13.1875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
gsave
.5 -0.0125 -93.625 -26.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Iterations) show
124.250 13.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11058 m
.00625 .11058 L
s
[(0.05)] -0.0125 .11058 1 0 Mshowa
0 .22167 m
.00625 .22167 L
s
[(0.1)] -0.0125 .22167 1 0 Mshowa
0 .33276 m
.00625 .33276 L
s
[(0.15)] -0.0125 .33276 1 0 Mshowa
0 .44385 m
.00625 .44385 L
s
[(0.2)] -0.0125 .44385 1 0 Mshowa
0 .55494 m
.00625 .55494 L
s
[(0.25)] -0.0125 .55494 1 0 Mshowa
.125 Mabswid
0 .02171 m
.00375 .02171 L
s
0 .04393 m
.00375 .04393 L
s
0 .06614 m
.00375 .06614 L
s
0 .08836 m
.00375 .08836 L
s
0 .1328 m
.00375 .1328 L
s
0 .15502 m
.00375 .15502 L
s
0 .17723 m
.00375 .17723 L
s
0 .19945 m
.00375 .19945 L
s
0 .24389 m
.00375 .24389 L
s
0 .26611 m
.00375 .26611 L
s
0 .28832 m
.00375 .28832 L
s
0 .31054 m
.00375 .31054 L
s
0 .35498 m
.00375 .35498 L
s
0 .3772 m
.00375 .3772 L
s
0 .39941 m
.00375 .39941 L
s
0 .42163 m
.00375 .42163 L
s
0 .46607 m
.00375 .46607 L
s
0 .48829 m
.00375 .48829 L
s
0 .5105 m
.00375 .5105 L
s
0 .53272 m
.00375 .53272 L
s
0 .57716 m
.00375 .57716 L
s
0 .59938 m
.00375 .59938 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -75.25 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(RMSE) show
87.500 13.313 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.02381 .60332 m
.05556 .57004 L
.0873 .50904 L
.11905 .48138 L
.15079 .46498 L
.18254 .45034 L
.21429 .37113 L
.24603 .24059 L
.27778 .11824 L
.30952 .06336 L
.34127 .02933 L
.37302 .01818 L
.40476 .01656 L
.43651 .01559 L
.46825 .01542 L
.5 .01519 L
.53175 .01516 L
.56349 .0151 L
.59524 .01509 L
.62698 .01507 L
.65873 .01505 L
.69048 .01502 L
.72222 .015 L
.75397 .01497 L
.78571 .01494 L
.81746 .01491 L
.84921 .01488 L
.88095 .01484 L
.9127 .0148 L
.94444 .01476 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo001oOol30003Ool20004Ool30002Ool40002Ool50002Ool20004Ool3
0003Ool20002Ool20002Ool2000017oo00000000JGoo0020Ool01@00Oomoogoo00000Woo00@007oo
Ool000Ioo`03001oogoo009oo`@0009oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo00=oo`03001oogoo06Ioo`00P7oo00D007ooOomoo`0000Eoo`@000=oo`03
001oogoo00Eoo`04001oogoo0007Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo
00<006Uoo`00P7oo00<007ooOol01@000goo0P000goo10000goo0`0000=oo`0000000`000goo0P00
17oo0P000Woo10000goo1000J7oo0020Ool01@00Oomoogoo00005goo00<007ooOol0PGoo001oOol3
000ROol00`00Oomoo`1iOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00<Woo0P008Goo
0P007Goo1@000Woo0P006Woo1@000Woo0P006Woo10000goo0P006Woo10000goo0P006goo0P0017oo
0P005goo000aOol01000Oomoo`007goo00@007ooOol001ioo`05001oogooOol00002Ool00`00Oomo
o`0IOol01@00Oomoogoo00000Woo00<007ooOol05goo00<007ooOol00goo00@007ooOol001Uoo`03
001oogoo00=oo`04001oogoo000IOol01000Oomoo`000Woo00@007ooOol001Ioo`00<Goo00@007oo
Ool0029oo`03001oogoo01aoo`05001oogooOol00002Ool00`00Oomoo`0IOol00`00Oomoo`04Ool0
0`00Oomoo`0HOol00`00Oomoo`02Ool01000Oomoo`006Woo00<007ooOol01Goo00<007ooOol06Goo
00D007ooOomoo`00009oo`03001oogoo01Aoo`00<Goo00@007ooOol0021oo`8001moo`05001oogoo
Ool00002Ool00`00Oomoo`0IOol00`00Oomoo`02Ool2000LOol01@00Oomoogoo00000Woo00<007oo
Ool06Goo00<007ooOol00Woo0P007Goo00@007ooOol0009oo`03001oogoo01Aoo`00<Goo00@007oo
Ool0021oo`03001oogoo01ioo`05001oogooOol00002Ool00`00Oomoo`0IOol00`00Oomoo`02Ool0
0`00Oomoo`0IOol01000Oomoo`000Woo00@007ooOol001Uoo`04001oogoo0003Ool00`00Oomoo`0I
Ool01000Oomoo`000Woo00@007ooOol001Ioo`00<Woo0P008Goo0`007Goo0P0017oo0P006goo0P00
17oo0`006Woo0P0017oo0P006goo0P0017oo0`006Woo0P0017oo0P005goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00;Woog@005Goo000^Ool00`00Oomoo`02Ool00`00Oomo
o`0POol00`00Oomoo`0POol00`00Oomoo`0POol00`00Oomoo`0POol00`00Oomoo`0POol00`00Oomo
o`0POol00`00Oomoo`02Ool00`00Oomoo`0COol002ioo`03001oogoo0=Uoo`03001oogoo01=oo`00
;Woo00<007ooOol0DgooPP0017oo00<007ooOol04goo000^Ool2001?Ool50026Ool00`00Oomoo`0C
Ool002ioo`03001oogoo04Yoo`@008]oo`03001oogoo01=oo`00;Woo00<007ooOol0B7oo0P00Sgoo
00<007ooOol04goo000^Ool00`00Oomoo`17Ool00`00Oomoo`2?Ool00`00Oomoo`0COol002ioo`03
001oogoo04Ioo`03001oogoo091oo`03001oogoo01=oo`00;Woo0P00AWoo00<007ooOol0TGoo00<0
07ooOol04goo000^Ool00`00Oomoo`14Ool00`00Oomoo`2BOol00`00Oomoo`0COol002ioo`03001o
ogoo04=oo`03001oogoo09=oo`03001oogoo01=oo`00;Woo00<007ooOol0@Woo00<007ooOol0U7oo
00<007ooOol04goo000^Ool00`00Oomoo`11Ool00`00Oomoo`2EOol00`00Oomoo`0COol002ioo`80
045oo`03001oogoo09Ioo`03001oogoo01=oo`00;Woo00<007ooOol0@7oo00<007ooOol0UWoo00<0
07ooOol04goo000^Ool00`00Oomoo`0oOol00`00Oomoo`2GOol00`00Oomoo`0COol002ioo`03001o
ogoo03moo`03001oogoo09Moo`03001oogoo01=oo`00;Woo00<007ooOol0?Woo00<007ooOol0V7oo
00<007ooOol04goo000^Ool2000oOol00`00Oomoo`2HOol00`00Oomoo`0COol002ioo`03001oogoo
03eoo`03001oogoo09Uoo`03001oogoo01=oo`00;Woo00<007ooOol0?Goo00<007ooOol0VGoo00<0
07ooOol04goo000EOol20004Ool20004Ool20004Ool20005Ool00`00Oomoo`0lOol00`00Oomoo`2J
Ool00`00Oomoo`0COol001Aoo`04001oogoo0008Ool01000Oomoo`000Woo00@007ooOol000Aoo`03
001oogoo03aoo`03001oogoo09Yoo`03001oogoo01=oo`0057oo00@007ooOol000Qoo`04001oogoo
0005Ool00`00Oomoo`02Ool2000lOol00`00Oomoo`2KOol00`00Oomoo`0COol001Aoo`04001oogoo
0008Ool01000Oomoo`000goo0P001Goo00<007ooOol0>goo00<007ooOol0Vgoo00<007ooOol04goo
000DOol01000Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo03Yoo`03001o
ogoo09aoo`03001oogoo01=oo`005Goo0P002Woo0P0017oo0`0017oo00<007ooOol0>Woo00<007oo
Ool0W7oo00<007ooOol04goo000^Ool00`00Oomoo`0iOol00`00Oomoo`2MOol00`00Oomoo`0COol0
02ioo`8003Yoo`03001oogoo09eoo`03001oogoo01=oo`00;Woo00<007ooOol0>Goo00<007ooOol0
WGoo00<007ooOol04goo000^Ool00`00Oomoo`0iOol00`00Oomoo`2MOol00`00Oomoo`0COol002io
o`03001oogoo03Qoo`03001oogoo09ioo`03001oogoo01=oo`00;Woo00<007ooOol0>7oo00<007oo
Ool0WWoo00<007ooOol04goo000^Ool2000iOol00`00Oomoo`2NOol00`00Oomoo`0COol002ioo`03
001oogoo03Qoo`03001oogoo09ioo`03001oogoo01=oo`00;Woo00<007ooOol0=goo00<007ooOol0
Wgoo00<007ooOol04goo000^Ool00`00Oomoo`0gOol00`00Oomoo`2OOol00`00Oomoo`0COol002io
o`03001oogoo03Moo`03001oogoo09moo`03001oogoo01=oo`00;Woo0P00=goo00<007ooOol0X7oo
00<007ooOol04goo000^Ool00`00Oomoo`0fOol00`00Oomoo`2POol00`00Oomoo`0COol002ioo`03
001oogoo03Ioo`03001oogoo0:1oo`03001oogoo01=oo`00;Woo00<007ooOol0=Woo00<007ooOol0
X7oo00<007ooOol04goo000^Ool2000fOol00`00Oomoo`2QOol00`00Oomoo`0COol002ioo`03001o
ogoo03Eoo`03001oogoo0:5oo`03001oogoo01=oo`00;Woo00<007ooOol0=Goo00<007ooOol0XGoo
00<007ooOol04goo000KOol20004Ool20003Ool50003Ool00`00Oomoo`0eOol00`00Oomoo`2QOol0
0`00Oomoo`0COol001Yoo`04001oogoo000:Ool00`00Oomoo`03Ool00`00Oomoo`0dOol00`00Oomo
o`2ROol00`00Oomoo`0COol001Yoo`04001oogoo000:Ool00`00Oomoo`03Ool2000eOol00`00Oomo
o`2ROol00`00Oomoo`0COol001Yoo`04001oogoo000:Ool00`00Oomoo`03Ool00`00Oomoo`0dOol0
0`00Oomoo`2ROol00`00Oomoo`0COol001Yoo`04001oogoo000:Ool00`00Oomoo`03Ool00`00Oomo
o`0dOol00`00Oomoo`2ROol00`00Oomoo`0COol001]oo`8000Yoo`8000Eoo`03001oogoo03=oo`03
001oogoo0:=oo`03001oogoo01=oo`00;Woo00<007ooOol0<goo00<007ooOol0Xgoo00<007ooOol0
4goo000^Ool2000dOol00`00Oomoo`2SOol00`00Oomoo`0COol002ioo`03001oogoo03=oo`03001o
ogoo0:=oo`03001oogoo01=oo`00;Woo00<007ooOol0<Woo00<007ooOol0Y7oo00<007ooOol04goo
000^Ool00`00Oomoo`0bOol00`00Oomoo`2TOol00`00Oomoo`0COol002ioo`03001oogoo039oo`03
001oogoo0:Aoo`03001oogoo01=oo`00;Woo0P00<goo00<007ooOol0Y7oo00<007ooOol04goo000^
Ool00`00Oomoo`0aOol00`00Oomoo`2UOol00`00Oomoo`0COol002ioo`03001oogoo035oo`03001o
ogoo0:Eoo`03001oogoo01=oo`00;Woo00<007ooOol0<Goo00<007ooOol0YGoo00<007ooOol04goo
000^Ool00`00Oomoo`0aOol00`00Oomoo`2UOol00`00Oomoo`0COol002ioo`80035oo`03001oogoo
0:Ioo`03001oogoo01=oo`00;Woo00<007ooOol0<7oo00<007ooOol0YWoo00<007ooOol04goo000^
Ool00`00Oomoo`0`Ool00`00Oomoo`2VOol00`00Oomoo`0COol002ioo`03001oogoo031oo`03001o
ogoo0:Ioo`03001oogoo01=oo`00;Woo00<007ooOol0;goo00<007ooOol0Ygoo00<007ooOol04goo
000^Ool2000`Ool00`00Oomoo`2WOol00`00Oomoo`0COol002ioo`03001oogoo02moo`03001oogoo
0:Moo`03001oogoo01=oo`00;Woo00<007ooOol0;goo00<007ooOol0Ygoo00<007ooOol04goo000E
Ool20004Ool20003Ool50002Ool20005Ool00`00Oomoo`0^Ool00`00Oomoo`2XOol00`00Oomoo`0C
Ool001Aoo`04001oogoo000:Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol0;Woo
00<007ooOol0Z7oo00<007ooOol04goo000DOol01000Oomoo`002Woo00<007ooOol017oo00<007oo
Ool00Woo0P00;goo00<007ooOol0Z7oo00<007ooOol04goo000DOol01000Oomoo`002Woo00<007oo
Ool00Woo0P001Goo00<007ooOol0;Woo00<007ooOol0Z7oo00<007ooOol04goo000DOol01000Oomo
o`002Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0;Goo00<007ooOol0ZGoo00<007oo
Ool04goo000EOol2000:Ool20004Ool30004Ool00`00Oomoo`0]Ool00`00Oomoo`2YOol00`00Oomo
o`0COol002ioo`03001oogoo02eoo`03001oogoo0:Uoo`03001oogoo01=oo`00;Woo0P00;Woo00<0
07ooOol0ZGoo00<007ooOol04goo000^Ool00`00Oomoo`0/Ool00`00Oomoo`2ZOol00`00Oomoo`0C
Ool002ioo`03001oogoo02aoo`03001oogoo0:Yoo`03001oogoo01=oo`00;Woo00<007ooOol0;7oo
00<007ooOol0ZWoo00<007ooOol04goo000^Ool00`00Oomoo`0/Ool00`00Oomoo`2ZOol00`00Oomo
o`0COol002ioo`8002aoo`03001oogoo0:]oo`03001oogoo01=oo`00;Woo00<007ooOol0:goo00<0
07ooOol0Zgoo00<007ooOol04goo000^Ool00`00Oomoo`0ZOol00`00Oomoo`2/Ool00`00Oomoo`0C
Ool002ioo`03001oogoo02Yoo`03001oogoo0:aoo`03001oogoo01=oo`00;Woo0P00:goo00<007oo
Ool0[7oo00<007ooOol04goo000^Ool00`00Oomoo`0YOol00`00Oomoo`2]Ool00`00Oomoo`0COol0
02ioo`03001oogoo02Uoo`03001oogoo0:eoo`03001oogoo01=oo`00;Woo00<007ooOol0:7oo00<0
07ooOol0[Woo00<007ooOol04goo000^Ool00`00Oomoo`0XOol00`00Oomoo`2^Ool00`00Oomoo`0C
Ool002ioo`8002Uoo`03001oogoo0:ioo`03001oogoo01=oo`00;Woo00<007ooOol09goo00<007oo
Ool0[goo00<007ooOol04goo000^Ool00`00Oomoo`0WOol00`00Oomoo`2_Ool00`00Oomoo`0COol0
01]oo`8000Aoo`8000=oo`@000Aoo`03001oogoo02Moo`03001oogoo0:moo`03001oogoo01=oo`00
6Woo00@007ooOol000Qoo`03001oogoo00Eoo`03001oogoo02Ioo`03001oogoo0;1oo`03001oogoo
01=oo`006Woo00@007ooOol000Uoo`03001oogoo00Aoo`8002Moo`03001oogoo0;1oo`03001oogoo
01=oo`006Woo00@007ooOol000Yoo`03001oogoo00=oo`03001oogoo02Eoo`03001oogoo0;5oo`03
001oogoo01=oo`006Woo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`0TOol2002cOol0
0`00Oomoo`0COol001]oo`8000Yoo`8000Eoo`03001oogoo029oo`800;Eoo`03001oogoo01=oo`00
;Woo00<007ooOol087oo0P00]goo00<007ooOol04goo000^Ool2000NOol3002iOol00`00Oomoo`0C
Ool002ioo`03001oogoo01]oo`800;aoo`03001oogoo01=oo`00;Woo00<007ooOol06Goo0P00_Woo
00<007ooOol04goo000^Ool00`00Oomoo`0GOol20030Ool00`00Oomoo`0COol002ioo`03001oogoo
01Ioo`03001oogoo0<1oo`03001oogoo01=oo`00;Woo0P005Woo00<007ooOol0`Goo00<007ooOol0
4goo000^Ool00`00Oomoo`0DOol00`00Oomoo`32Ool00`00Oomoo`0COol002ioo`03001oogoo01=o
o`03001oogoo0<=oo`03001oogoo01=oo`00;Woo00<007ooOol04Woo00<007ooOol0a7oo00<007oo
Ool04goo000^Ool00`00Oomoo`0AOol00`00Oomoo`35Ool00`00Oomoo`0COol002ioo`80015oo`03
001oogoo0<Ioo`03001oogoo01=oo`00;Woo00<007ooOol03goo00<007ooOol0agoo00<007ooOol0
4goo000^Ool00`00Oomoo`0?Ool00`00Oomoo`37Ool00`00Oomoo`0COol002ioo`03001oogoo00io
o`03001oogoo0<Qoo`03001oogoo01=oo`00;Woo00<007ooOol03Woo00<007ooOol0b7oo00<007oo
Ool04goo000^Ool2000>Ool00`00Oomoo`39Ool00`00Oomoo`0COol002ioo`03001oogoo00eoo`03
001oogoo0<Uoo`03001oogoo01=oo`00;Woo00<007ooOol037oo00<007ooOol0bWoo00<007ooOol0
4goo000EOol20004Ool20003Ool40003Ool20005Ool00`00Oomoo`0<Ool00`00Oomoo`3:Ool00`00
Oomoo`0COol001Aoo`04001oogoo0008Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007ooOol0
2goo00<007ooOol0bgoo00<007ooOol04goo000DOol01000Oomoo`002Goo00<007ooOol01Goo00<0
07ooOol00Woo0P0037oo00<007ooOol0bgoo00<007ooOol04goo000DOol01000Oomoo`002Woo00<0
07ooOol00Woo0P001Goo00<007ooOol02Woo00<007ooOol0c7oo00<007ooOol04goo000DOol01000
Oomoo`0027oo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo0<aoo`03
001oogoo01=oo`005Goo0P002Woo0P0017oo0`0017oo00<007ooOol02Goo00<007ooOol0cGoo00<0
07ooOol04goo000^Ool00`00Oomoo`08Ool00`00Oomoo`3>Ool00`00Oomoo`0COol002ioo`8000Qo
o`03001oogoo0<moo`03001oogoo01=oo`00;Woo00<007ooOol01Woo00<007ooOol0d7oo00<007oo
Ool04goo000^Ool00`00Oomoo`05Ool00`00Oomoo`3AOol00`00Oomoo`0COol002ioo`03001oogoo
00Aoo`03001oogoo0=9oo`03001oogoo01=oo`00;Woo0P0017oo00<007ooOol0dgoo00<007ooOol0
4goo000^Ool00`00Oomoo`02Ool00`00Oomoo`3DOol00`00Oomoo`0COol002ioo`03001oogoo0=Uo
o`03001oogoo01=oo`00;Woo00<007ooOol0fGoo00<007ooOol04goo000^Ool00`00Oomoo`3IOol0
0`00Oomoo`0COol002ioomd001Eoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00T7oo0`000Woo0`0000Eoo`00000007oo00<0009oo`D007Uoo`00TGoo00H007oo
Ool007oo0003Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo07Moo`00TGoo0`000Woo
00D007oo001oo`0000Eoo`04001oogoo001lOol0095oo`05001oogoo001oo`0200000goo00000003
Ool20003Ool2001kOol0095oo`05001oogoo001oo`0200000goo00000002Ool01000Oomoo`000Woo
00@007ooOol007Uoo`00T7oo10000Woo0P0000Eoo`00000007oo00@00003Ool0000000<007Uoo`00
ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-7.39254, -0.0507598, \
0.143086, 0.00204448}}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          
          TagBox[\(FeedForwardNet[{{w1, 
                  w2}}, {AccumulatedIterations\  \[Rule] \ 30, \ 
                CreationDate\  \[Rule] \ {2002, \ 7, \ 13, \ 15, \ 29, \ 
                    25}, \ Neuron\  \[Rule] \ Sigmoid, \ 
                FixedParameters\  \[Rule] \ None, \ 
                OutputNonlinearity\  \[Rule] \ None, \ 
                NumberOfInputs\  \[Rule] \ 1}]\),
            Null,
            Editable->False],
          DisplayForm], ",", 
        TagBox[
          
          TagBox[\(NeuralFitRecord[FeedForwardNet, \ 
              ReportFrequency\  \[Rule] \ 1, \ 
              CriterionValues\  \[Rule] \ {\(-values\)\(-\)}, \ 
              CriterionValidationValues\  \[Rule] \ {\(-values\)\(-\)}, \ 
              ParameterRecord\  \[Rule] \ {\(-parameters\)\(-\)}]\),
            Null,
            Editable->False],
          DisplayForm]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The resulting function appears to approximate the data better. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(fplot\  = \ Plot[\ f[{a}], \ {a, \ 0, \ 3  \[Pi]}\ ];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.101051 0.309219 0.293378 [
[.22591 .29672 -3 -9 ]
[.22591 .29672 3 0 ]
[.42801 .29672 -3 -9 ]
[.42801 .29672 3 0 ]
[.63011 .29672 -3 -9 ]
[.63011 .29672 3 0 ]
[.83222 .29672 -3 -9 ]
[.83222 .29672 3 0 ]
[.01131 .01584 -12 -4.5 ]
[.01131 .01584 0 4.5 ]
[.01131 .16253 -24 -4.5 ]
[.01131 .16253 0 4.5 ]
[.01131 .45591 -18 -4.5 ]
[.01131 .45591 0 4.5 ]
[.01131 .6026 -6 -4.5 ]
[.01131 .6026 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22591 .30922 m
.22591 .31547 L
s
[(2)] .22591 .29672 0 1 Mshowa
.42801 .30922 m
.42801 .31547 L
s
[(4)] .42801 .29672 0 1 Mshowa
.63011 .30922 m
.63011 .31547 L
s
[(6)] .63011 .29672 0 1 Mshowa
.83222 .30922 m
.83222 .31547 L
s
[(8)] .83222 .29672 0 1 Mshowa
.125 Mabswid
.07433 .30922 m
.07433 .31297 L
s
.12486 .30922 m
.12486 .31297 L
s
.17539 .30922 m
.17539 .31297 L
s
.27644 .30922 m
.27644 .31297 L
s
.32696 .30922 m
.32696 .31297 L
s
.37749 .30922 m
.37749 .31297 L
s
.47854 .30922 m
.47854 .31297 L
s
.52906 .30922 m
.52906 .31297 L
s
.57959 .30922 m
.57959 .31297 L
s
.68064 .30922 m
.68064 .31297 L
s
.73116 .30922 m
.73116 .31297 L
s
.78169 .30922 m
.78169 .31297 L
s
.88274 .30922 m
.88274 .31297 L
s
.93327 .30922 m
.93327 .31297 L
s
.98379 .30922 m
.98379 .31297 L
s
.25 Mabswid
0 .30922 m
1 .30922 L
s
.02381 .01584 m
.03006 .01584 L
s
[(-1)] .01131 .01584 1 0 Mshowa
.02381 .16253 m
.03006 .16253 L
s
[(-0.5)] .01131 .16253 1 0 Mshowa
.02381 .45591 m
.03006 .45591 L
s
[(0.5)] .01131 .45591 1 0 Mshowa
.02381 .6026 m
.03006 .6026 L
s
[(1)] .01131 .6026 1 0 Mshowa
.125 Mabswid
.02381 .04518 m
.02756 .04518 L
s
.02381 .07452 m
.02756 .07452 L
s
.02381 .10385 m
.02756 .10385 L
s
.02381 .13319 m
.02756 .13319 L
s
.02381 .19187 m
.02756 .19187 L
s
.02381 .22121 m
.02756 .22121 L
s
.02381 .25054 m
.02756 .25054 L
s
.02381 .27988 m
.02756 .27988 L
s
.02381 .33856 m
.02756 .33856 L
s
.02381 .36789 m
.02756 .36789 L
s
.02381 .39723 m
.02756 .39723 L
s
.02381 .42657 m
.02756 .42657 L
s
.02381 .48525 m
.02756 .48525 L
s
.02381 .51458 m
.02756 .51458 L
s
.02381 .54392 m
.02756 .54392 L
s
.02381 .57326 m
.02756 .57326 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30964 m
.06244 .41743 L
.08255 .46955 L
.10458 .51958 L
.12507 .55713 L
.13422 .57061 L
.14415 .58274 L
.14961 .58825 L
.15465 .59259 L
.15937 .596 L
.16457 .599 L
.16681 .60006 L
.16922 .60103 L
.17131 .60173 L
.17359 .60235 L
.17491 .60264 L
.17614 .60286 L
.17732 .60304 L
.17858 .60318 L
.17981 .60327 L
.18097 .60331 L
.18202 .60332 L
.18314 .60329 L
.18439 .60322 L
.18552 .60311 L
.18682 .60294 L
.18806 .60273 L
.19026 .60225 L
.19265 .60157 L
.19807 .59942 L
.20308 .59667 L
.2133 .58889 L
.22415 .57751 L
.24362 .54952 L
.2619 .51528 L
.30059 .423 L
.34173 .308 L
.38135 .19723 L
.41946 .10581 L
.43907 .06883 L
.46002 .03907 L
.47026 .0286 L
.47566 .02423 L
.48137 .02049 L
.48636 .01797 L
.4892 .01686 L
.49185 .01602 L
.49429 .01544 L
.49651 .01505 L
.49774 .0149 L
Mistroke
.49843 .01484 L
.49908 .01479 L
.50026 .01473 L
.50152 .01472 L
.50276 .01474 L
.50347 .01478 L
.50413 .01483 L
.50546 .01496 L
.50689 .01517 L
.50948 .01568 L
.51183 .01633 L
.51457 .01728 L
.51755 .01856 L
.52297 .02155 L
.53346 .02975 L
.54315 .04008 L
.56185 .06714 L
.58247 .10687 L
.62273 .20758 L
.66147 .31972 L
.70266 .43551 L
.72322 .48593 L
.74233 .52591 L
.7608 .55703 L
.77105 .57079 L
.78049 .58113 L
.79076 .58975 L
.79617 .59316 L
.80188 .59594 L
.80428 .59684 L
.80685 .59764 L
.80927 .59823 L
.81149 .59863 L
.81284 .59881 L
.81408 .59893 L
.81473 .59898 L
.81545 .59902 L
.8162 .59905 L
.81691 .59906 L
.8182 .59905 L
.81938 .599 L
.82068 .5989 L
.82133 .59884 L
.82204 .59875 L
.82457 .59834 L
.826 .59803 L
.82732 .5977 L
.8323 .59604 L
.83683 .59396 L
.84163 .59118 L
Mistroke
.8516 .58353 L
.86257 .57223 L
.882 .54518 L
.90288 .50671 L
.94412 .40587 L
.97619 .30885 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000KOol00`00Oomoo`3oOol3
Ool001=oo`D000=oo`03001oogoo0?moo`=oo`005Goo00<007ooOol00goo00<007ooOol0ogoo0goo
000EOol00`00Oomoo`03Ool2001jOol70022Ool000eoo`@000Aoo`03001oogoo00=oo`03001oogoo
07Moo`8000Moo`03001oogoo07moo`005Goo00<007ooOol00goo00<007ooOol0MGoo0P002Woo0P00
Ogoo000DOol20005Ool00`00Oomoo`1dOol00`00Oomoo`0<Ool00`00Oomoo`1lOol001]oo`03001o
ogoo07=oo`03001oogoo00ioo`03001oogoo07]oo`006goo00<007ooOol0LWoo00<007ooOol047oo
0P00Ngoo000KOol00`00Oomoo`1aOol00`00Oomoo`0COol00`00Oomoo`1hOol001]oo`03001oogoo
071oo`03001oogoo01Eoo`03001oogoo07Moo`006goo0P00L7oo00<007ooOol05Woo00<007ooOol0
Mgoo000KOol00`00Oomoo`1_Ool00`00Oomoo`0GOol00`00Oomoo`1fOol001]oo`03001oogoo06io
o`03001oogoo01Qoo`03001oogoo07Ioo`006goo00<007ooOol0KGoo00<007ooOol06Woo00<007oo
Ool0MGoo000KOol00`00Oomoo`1/Ool00`00Oomoo`0LOol00`00Oomoo`1dOol001]oo`03001oogoo
06aoo`03001oogoo01aoo`03001oogoo07Aoo`006goo00<007ooOol0Jgoo00<007ooOol07Woo00<0
07ooOol0Lgoo000KOol00`00Oomoo`1ZOol00`00Oomoo`0OOol00`00Oomoo`1cOol001]oo`8006]o
o`03001oogoo021oo`03001oogoo079oo`006goo00<007ooOol0JGoo00<007ooOol08Goo00<007oo
Ool0LWoo000KOol00`00Oomoo`1YOol00`00Oomoo`0ROol00`00Oomoo`1aOol001]oo`03001oogoo
06Qoo`03001oogoo02=oo`03001oogoo075oo`006goo00<007ooOol0J7oo00<007ooOol097oo00<0
07ooOol0L7oo000KOol00`00Oomoo`1WOol00`00Oomoo`0UOol00`00Oomoo`1`Ool001]oo`03001o
ogoo06Moo`03001oogoo02Ioo`03001oogoo06moo`006goo0P00Igoo00<007ooOol09goo00<007oo
Ool0Kgoo000KOol00`00Oomoo`1VOol00`00Oomoo`0XOol00`00Oomoo`1^Ool001]oo`03001oogoo
06Ioo`03001oogoo02Qoo`03001oogoo06ioo`006goo00<007ooOol0IGoo00<007ooOol0:Woo00<0
07ooOol0KGoo000KOol00`00Oomoo`1UOol00`00Oomoo`0ZOol00`00Oomoo`1]Ool001]oo`03001o
ogoo06Aoo`03001oogoo02aoo`03001oogoo06aoo`006goo00<007ooOol0I7oo00<007ooOol0;7oo
00<007ooOol0K7oo000KOol00`00Oomoo`1SOol00`00Oomoo`0]Ool00`00Oomoo`1/Ool001]oo`80
06Aoo`03001oogoo02ioo`03001oogoo06]oo`006goo00<007ooOol0Hgoo00<007ooOol0;Woo00<0
07ooOol0Jgoo000KOol00`00Oomoo`1ROol00`00Oomoo`0`Ool00`00Oomoo`1ZOol001]oo`03001o
ogoo069oo`03001oogoo031oo`03001oogoo06Yoo`006goo00<007ooOol0HGoo00<007ooOol0<Goo
00<007ooOol0JWoo000KOol00`00Oomoo`1QOol00`00Oomoo`0bOol00`00Oomoo`1YOol000Qoo`80
00Aoo`8000Aoo`8000Eoo`03001oogoo065oo`03001oogoo039oo`03001oogoo06Uoo`001goo00@0
07ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`1POol00`00Oomoo`0dOol00`00Oomoo`1XOol0
00Moo`04001oogoo000;Ool00`00Oomoo`02Ool2001QOol00`00Oomoo`0dOol00`00Oomoo`1XOol0
0003Ool000000080009oo`04001oogoo0009Ool20005Ool00`00Oomoo`1OOol00`00Oomoo`0fOol0
0`00Oomoo`1WOol000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`1OOol00`00Oomo
o`0fOol00`00Oomoo`1WOol000Qoo`8000Yoo`<000Aoo`03001oogoo05ioo`03001oogoo03Moo`03
001oogoo06Moo`006goo00<007ooOol0GWoo00<007ooOol0>7oo00<007ooOol0IWoo000KOol00`00
Oomoo`1NOol00`00Oomoo`0hOol00`00Oomoo`1VOol001]oo`03001oogoo05eoo`03001oogoo03Yo
o`03001oogoo06Eoo`006goo00<007ooOol0GGoo00<007ooOol0>Woo00<007ooOol0IGoo000KOol2
001MOol00`00Oomoo`0kOol00`00Oomoo`1UOol001]oo`03001oogoo05aoo`03001oogoo03aoo`03
001oogoo06Aoo`006goo00<007ooOol0G7oo00<007ooOol0?7oo00<007ooOol0I7oo000KOol00`00
Oomoo`1KOol00`00Oomoo`0nOol00`00Oomoo`1SOol001]oo`03001oogoo05]oo`03001oogoo03io
o`03001oogoo06=oo`006goo00<007ooOol0Fgoo00<007ooOol0?Woo00<007ooOol0Hgoo000KOol0
0`00Oomoo`1JOol00`00Oomoo`10Ool00`00Oomoo`1ROol001]oo`03001oogoo05Yoo`03001oogoo
041oo`03001oogoo069oo`006goo0P00FWoo00<007ooOol0@Goo00<007ooOol0HWoo000KOol00`00
Oomoo`1IOol00`00Oomoo`12Ool00`00Oomoo`1QOol001]oo`03001oogoo05Uoo`03001oogoo049o
o`03001oogoo065oo`006goo00<007ooOol0F7oo00<007ooOol0@goo00<007ooOol0HGoo000KOol0
0`00Oomoo`1HOol00`00Oomoo`14Ool00`00Oomoo`1POol001]oo`03001oogoo05Qoo`03001oogoo
04Aoo`03001oogoo061oo`006goo00<007ooOol0Egoo00<007ooOol0AGoo00<007ooOol0H7oo000K
Ool2001HOol00`00Oomoo`16Ool00`00Oomoo`1OOol001]oo`03001oogoo05Ioo`03001oogoo04Mo
o`03001oogoo05moo`006goo00<007ooOol0EWoo00<007ooOol0Agoo00<007ooOol0Ggoo000KOol0
0`00Oomoo`1FOol00`00Oomoo`18Ool00`00Oomoo`1NOol001]oo`03001oogoo05Eoo`03001oogoo
04Uoo`03001oogoo05ioo`006goo00<007ooOol0<Goo100087oo00<007ooOol047oo0`00<Goo0`00
0Woo00<007ooOol0;goo0P00;Goo000KOol00`00Oomoo`0aOol00`00Oomoo`0QOol00`00Oomoo`0A
Ool00`00Oomoo`0`Ool01000Oomoo`000Woo00<007ooOol0;Goo00@007ooOol002aoo`006goo00<0
07ooOol0<Woo00<007ooOol07goo00<007ooOol03goo1@00<Goo00@007ooOol0009oo`03001oogoo
02eoo`04001oogoo000/Ool001]oo`8003Aoo`03001oogoo01ioo`03001oogoo00moo`04001oogoo
000bOol30003Ool00`00Oomoo`0^Ool2000]Ool001]oo`03001oogoo035oo`04001oogoo000OOol0
0`00Oomoo`0@Ool00`00Ool0000cOol00`00Oomoo`03Ool00`00Oomoo`0/Ool01000Oomoo`00;7oo
000KOol00`00Oomoo`0bOol2000OOol00`00Oomoo`0BOol2000cOol30003Ool00`00Oomoo`0]Ool2
000]Ool001]oo`03001oogoo05=oo`03001oogoo04eoo`03001oogoo05aoo`006goo00<007ooOol0
DWoo00<007ooOol0Cgoo00<007ooOol0Fgoo000KOol00`00Oomoo`1BOol00`00Oomoo`1?Ool00`00
Oomoo`1KOol001]oo`03001oogoo059oo`03001oogoo04moo`03001oogoo05]oo`006goo00<007oo
Ool0DGoo00<007ooOol0DGoo00<007ooOol0FWoo000DOooo000=000001]oo`03001oogoo00Yoo`03
001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`05
001oogooOol00009Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;
Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Ool00005
Ool001]oo`8003Aoo`03001oogoo01Yoo`03001oogoo01Eoo`03001oogoo03=oo`03001oogoo00Eo
o`03001oogoo02]oo`03001oogoo029oo`03001oogoo00Ioo`006goo0P00DGoo00<007ooOol0Dgoo
00<007ooOol0D7oo00<007ooOol01Woo000KOol2001AOol00`00Oomoo`1COol00`00Oomoo`1@Ool0
0`00Oomoo`06Ool001]oo`03001oo`0004moo`03001oogoo05Eoo`03001oogoo04ioo`03001oogoo
00Moo`006goo00<007oo0000Cgoo00<007ooOol0EGoo00<007ooOol0CWoo00<007ooOol01goo000K
Ool00`00Ool0001>Ool00`00Oomoo`1FOol00`00Oomoo`1>Ool00`00Oomoo`07Ool001]oo`800003
Ool007oo04aoo`03001oogoo05Moo`03001oogoo04eoo`03001oogoo00Moo`006goo00@007ooOol0
04eoo`03001oogoo05Moo`03001oogoo04aoo`03001oogoo00Qoo`006goo00@007ooOol004aoo`03
001oogoo05Qoo`03001oogoo04aoo`03001oogoo00Qoo`006goo00D007ooOomoo`0004]oo`03001o
ogoo05Uoo`03001oogoo04]oo`03001oogoo00Qoo`006goo00D007ooOomoo`0004]oo`03001oogoo
05Uoo`03001oogoo04Yoo`03001oogoo00Uoo`006goo00D007ooOomoo`0004Yoo`03001oogoo05]o
o`03001oogoo04Uoo`03001oogoo00Uoo`006goo00<007ooOol00Woo00<007ooOol0Agoo00<007oo
Ool0Fgoo00<007ooOol0BGoo00<007ooOol02Goo000KOol00`00Oomoo`02Ool00`00Oomoo`16Ool0
0`00Oomoo`1LOol00`00Oomoo`18Ool00`00Oomoo`0:Ool001]oo`8000Aoo`03001oogoo04Eoo`03
001oogoo05eoo`03001oogoo04Moo`03001oogoo00Yoo`006goo00<007ooOol00goo00<007ooOol0
AGoo00<007ooOol0GGoo00<007ooOol0Agoo00<007ooOol02Woo000KOol00`00Oomoo`03Ool00`00
Oomoo`14Ool00`00Oomoo`1NOol00`00Oomoo`16Ool00`00Oomoo`0;Ool001]oo`03001oogoo00Ao
o`03001oogoo04=oo`03001oogoo05moo`03001oogoo04Eoo`03001oogoo00]oo`006goo00<007oo
Ool017oo00<007ooOol0@goo00<007ooOol0Ggoo00<007ooOol0AGoo00<007ooOol02goo000KOol0
0`00Oomoo`04Ool00`00Oomoo`12Ool00`00Oomoo`1POol00`00Oomoo`15Ool00`00Oomoo`0;Ool0
01]oo`03001oogoo00Eoo`03001oogoo045oo`03001oogoo065oo`03001oogoo04=oo`03001oogoo
00aoo`006goo0P001Woo00<007ooOol0@Goo00<007ooOol0HGoo00<007ooOol0@goo00<007ooOol0
37oo000KOol00`00Oomoo`05Ool00`00Oomoo`10Ool00`00Oomoo`1ROol00`00Oomoo`13Ool00`00
Oomoo`0<Ool001]oo`03001oogoo00Ioo`03001oogoo03moo`03001oogoo06=oo`03001oogoo045o
o`03001oogoo00eoo`006goo00<007ooOol01Woo00<007ooOol0?Woo00<007ooOol0I7oo00<007oo
Ool0@Goo00<007ooOol03Goo000KOol00`00Oomoo`06Ool00`00Oomoo`0nOol00`00Oomoo`1UOol0
0`00Oomoo`10Ool00`00Oomoo`0=Ool001]oo`03001oogoo00Moo`03001oogoo03eoo`03001oogoo
06Eoo`03001oogoo03moo`03001oogoo00ioo`006goo00<007ooOol01goo00<007ooOol0?7oo00<0
07ooOol0IWoo00<007ooOol0?goo00<007ooOol03Woo000KOol00`00Oomoo`07Ool00`00Oomoo`0l
Ool00`00Oomoo`1WOol00`00Oomoo`0mOol00`00Oomoo`0?Ool001]oo`8000Uoo`03001oogoo03]o
o`03001oogoo06Moo`03001oogoo03eoo`03001oogoo00moo`006goo00<007ooOol027oo00<007oo
Ool0>Woo00<007ooOol0J7oo00<007ooOol0?Goo00<007ooOol03goo000KOol00`00Oomoo`08Ool0
0`00Oomoo`0jOol00`00Oomoo`1YOol00`00Oomoo`0kOol00`00Oomoo`0@Ool001]oo`03001oogoo
00Uoo`03001oogoo03Qoo`03001oogoo06Yoo`03001oogoo03]oo`03001oogoo011oo`006goo00<0
07ooOol02Goo00<007ooOol0>7oo00<007ooOol0JWoo00<007ooOol0>Woo00<007ooOol04Goo000K
Ool00`00Oomoo`09Ool00`00Oomoo`0hOol00`00Oomoo`1[Ool00`00Oomoo`0iOol00`00Oomoo`0A
Ool000Qoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo00Yoo`03001oogoo03Ioo`03001oogoo06ao
o`03001oogoo03Uoo`03001oogoo015oo`001goo00@007ooOol000Qoo`04001oogoo0004Ool00`00
Oomoo`0:Ool00`00Oomoo`0fOol00`00Oomoo`1]Ool00`00Oomoo`0gOol00`00Oomoo`0BOol000Mo
o`04001oogoo000;Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`0dOol00`00Oomoo`1^Ool00`00
Oomoo`0gOol00`00Oomoo`0BOol000Moo`04001oogoo0009Ool20005Ool00`00Oomoo`0;Ool00`00
Oomoo`0dOol00`00Oomoo`1_Ool00`00Oomoo`0eOol00`00Oomoo`0COol000Moo`04001oogoo0009
Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`0dOol00`00Oomoo`1_Ool00`00Oomoo`0e
Ool00`00Oomoo`0COol000Qoo`8000Yoo`<000Aoo`03001oogoo00aoo`03001oogoo039oo`03001o
ogoo075oo`03001oogoo03=oo`03001oogoo01Aoo`006goo00<007ooOol037oo00<007ooOol0<Woo
00<007ooOol0LGoo00<007ooOol0<goo00<007ooOol057oo000KOol00`00Oomoo`0<Ool00`00Oomo
o`0aOol00`00Oomoo`1cOol00`00Oomoo`0bOol00`00Oomoo`0DOol001]oo`03001oogoo00eoo`03
001oogoo031oo`03001oogoo07=oo`03001oogoo035oo`03001oogoo01Eoo`006goo00<007ooOol0
3Goo00<007ooOol0<7oo00<007ooOol0M7oo00<007ooOol0<7oo00<007ooOol05Goo000KOol2000?
Ool00`00Oomoo`0^Ool00`00Oomoo`1eOol00`00Oomoo`0_Ool00`00Oomoo`0FOol001]oo`03001o
ogoo00ioo`03001oogoo02ioo`03001oogoo07Eoo`03001oogoo02moo`03001oogoo01Ioo`006goo
00<007ooOol03goo00<007ooOol0;7oo00<007ooOol0Mgoo00<007ooOol0;Woo00<007ooOol05Woo
000KOol00`00Oomoo`0?Ool00`00Oomoo`0/Ool00`00Oomoo`1gOol00`00Oomoo`0]Ool00`00Oomo
o`0GOol001]oo`03001oogoo011oo`03001oogoo02]oo`03001oogoo07Qoo`03001oogoo02aoo`03
001oogoo01Moo`006goo00<007ooOol047oo00<007ooOol0:Woo00<007ooOol0NGoo00<007ooOol0
:goo00<007ooOol067oo000KOol00`00Oomoo`0AOol00`00Oomoo`0YOol00`00Oomoo`1jOol00`00
Oomoo`0ZOol00`00Oomoo`0HOol001]oo`03001oogoo015oo`03001oogoo02Qoo`03001oogoo07]o
o`03001oogoo02Uoo`03001oogoo01Uoo`006goo0P004goo00<007ooOol09goo00<007ooOol0O7oo
00<007ooOol0:7oo00<007ooOol06Goo000KOol00`00Oomoo`0BOol00`00Oomoo`0VOol00`00Oomo
o`1mOol00`00Oomoo`0WOol00`00Oomoo`0JOol001]oo`03001oogoo01=oo`03001oogoo02Eoo`03
001oogoo07ioo`03001oogoo02Ioo`03001oogoo01Yoo`006goo00<007ooOol04goo00<007ooOol0
97oo00<007ooOol0Ogoo00<007ooOol09Goo00<007ooOol06goo000KOol00`00Oomoo`0DOol00`00
Oomoo`0SOol00`00Oomoo`20Ool00`00Oomoo`0SOol00`00Oomoo`0LOol001]oo`03001oogoo01Ao
o`03001oogoo029oo`03001oogoo085oo`03001oogoo02=oo`03001oogoo01aoo`006goo00<007oo
Ool05Goo00<007ooOol08Goo00<007ooOol0PWoo00<007ooOol08Goo00<007ooOol07Goo000KOol2
000GOol00`00Oomoo`0OOol00`00Oomoo`23Ool00`00Oomoo`0QOol00`00Oomoo`0MOol001]oo`03
001oogoo01Ioo`03001oogoo01moo`03001oogoo08Aoo`03001oogoo01moo`03001oogoo01ioo`00
6goo00<007ooOol05goo00<007ooOol07Goo00<007ooOol0QWoo00<007ooOol07Goo00<007ooOol0
7goo000KOol00`00Oomoo`0GOol00`00Oomoo`0LOol00`00Oomoo`27Ool00`00Oomoo`0MOol00`00
Oomoo`0OOol001]oo`03001oogoo01Qoo`03001oogoo01]oo`03001oogoo08Qoo`03001oogoo01]o
o`03001oogoo021oo`006goo00<007ooOol067oo00<007ooOol06Woo00<007ooOol0RWoo00<007oo
Ool06Goo00<007ooOol08Goo000KOol00`00Oomoo`0IOol00`00Oomoo`0HOol00`00Oomoo`2;Ool0
0`00Oomoo`0HOol00`00Oomoo`0ROol001]oo`03001oogoo01Uoo`03001oogoo01Moo`03001oogoo
08eoo`03001oogoo01Moo`03001oogoo029oo`006goo0P006goo00<007ooOol05Woo00<007ooOol0
SWoo00<007ooOol05Goo00<007ooOol08goo000KOol00`00Oomoo`0KOol00`00Oomoo`0DOol00`00
Oomoo`2@Ool00`00Oomoo`0COol00`00Oomoo`0TOol001]oo`03001oogoo01aoo`03001oogoo019o
o`03001oogoo099oo`03001oogoo015oo`03001oogoo02Eoo`006goo00<007ooOol07Goo00<007oo
Ool047oo00<007ooOol0U7oo00<007ooOol03goo00<007ooOol09Woo000KOol00`00Oomoo`0NOol0
0`00Oomoo`0>Ool00`00Oomoo`2FOol00`00Oomoo`0<Ool2000YOol001]oo`03001oogoo01moo`80
00eoo`03001oogoo09Qoo`03001oogoo00Yoo`03001oogoo02Uoo`004goo1@000goo00<007ooOol0
8Goo00<007ooOol02Goo00<007ooOol0VWoo0`001goo0P00;7oo000EOol00`00Oomoo`03Ool00`00
Oomoo`0ROol20007Ool2002OOol8000^Ool001Eoo`03001oogoo00=oo`8002Eoo`L00=Moo`005Goo
00<007ooOol00goo00<007ooOol0ogoo0goo000EOol00`00Oomoo`03Ool00`00Oomoo`3oOol3Ool0
01Aoo`8000Eoo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.0166, -1.13363, \
0.0372022, 0.0128139}}]
}, Open  ]],

Cell["In fact quite well in this case. ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[\ {dplot, \ fplot}\ ];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.100251 0.309219 0.293378 [
[.22431 .29672 -3 -9 ]
[.22431 .29672 3 0 ]
[.42481 .29672 -3 -9 ]
[.42481 .29672 3 0 ]
[.62531 .29672 -3 -9 ]
[.62531 .29672 3 0 ]
[.82581 .29672 -3 -9 ]
[.82581 .29672 3 0 ]
[.01131 .01584 -12 -4.5 ]
[.01131 .01584 0 4.5 ]
[.01131 .16253 -24 -4.5 ]
[.01131 .16253 0 4.5 ]
[.01131 .45591 -18 -4.5 ]
[.01131 .45591 0 4.5 ]
[.01131 .6026 -6 -4.5 ]
[.01131 .6026 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22431 .30922 m
.22431 .31547 L
s
[(2)] .22431 .29672 0 1 Mshowa
.42481 .30922 m
.42481 .31547 L
s
[(4)] .42481 .29672 0 1 Mshowa
.62531 .30922 m
.62531 .31547 L
s
[(6)] .62531 .29672 0 1 Mshowa
.82581 .30922 m
.82581 .31547 L
s
[(8)] .82581 .29672 0 1 Mshowa
.125 Mabswid
.07393 .30922 m
.07393 .31297 L
s
.12406 .30922 m
.12406 .31297 L
s
.17419 .30922 m
.17419 .31297 L
s
.27444 .30922 m
.27444 .31297 L
s
.32456 .30922 m
.32456 .31297 L
s
.37469 .30922 m
.37469 .31297 L
s
.47494 .30922 m
.47494 .31297 L
s
.52506 .30922 m
.52506 .31297 L
s
.57519 .30922 m
.57519 .31297 L
s
.67544 .30922 m
.67544 .31297 L
s
.72556 .30922 m
.72556 .31297 L
s
.77569 .30922 m
.77569 .31297 L
s
.87594 .30922 m
.87594 .31297 L
s
.92607 .30922 m
.92607 .31297 L
s
.97619 .30922 m
.97619 .31297 L
s
.25 Mabswid
0 .30922 m
1 .30922 L
s
.02381 .01584 m
.03006 .01584 L
s
[(-1)] .01131 .01584 1 0 Mshowa
.02381 .16253 m
.03006 .16253 L
s
[(-0.5)] .01131 .16253 1 0 Mshowa
.02381 .45591 m
.03006 .45591 L
s
[(0.5)] .01131 .45591 1 0 Mshowa
.02381 .6026 m
.03006 .6026 L
s
[(1)] .01131 .6026 1 0 Mshowa
.125 Mabswid
.02381 .04518 m
.02756 .04518 L
s
.02381 .07452 m
.02756 .07452 L
s
.02381 .10385 m
.02756 .10385 L
s
.02381 .13319 m
.02756 .13319 L
s
.02381 .19187 m
.02756 .19187 L
s
.02381 .22121 m
.02756 .22121 L
s
.02381 .25054 m
.02756 .25054 L
s
.02381 .27988 m
.02756 .27988 L
s
.02381 .33856 m
.02756 .33856 L
s
.02381 .36789 m
.02756 .36789 L
s
.02381 .39723 m
.02756 .39723 L
s
.02381 .42657 m
.02756 .42657 L
s
.02381 .48525 m
.02756 .48525 L
s
.02381 .51458 m
.02756 .51458 L
s
.02381 .54392 m
.02756 .54392 L
s
.02381 .57326 m
.02756 .57326 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.02381 .30922 Mdot
.07393 .44987 Mdot
.12406 .55609 Mdot
.17419 .60186 Mdot
.22431 .57599 Mdot
.27444 .4848 Mdot
.32456 .35062 Mdot
.37469 .20631 Mdot
.42481 .08719 Mdot
.47494 .02243 Mdot
.52506 .02789 Mdot
.57519 .10223 Mdot
.62531 .22724 Mdot
.67544 .37233 Mdot
.72556 .50196 Mdot
.77569 .58441 Mdot
.82581 .59947 Mdot
.87594 .54348 Mdot
.92607 .43013 Mdot
.97619 .28717 Mdot
.5 Mabswid
.02381 .30964 m
.06214 .41743 L
.08209 .46955 L
.10394 .51958 L
.12426 .55713 L
.13334 .57061 L
.1432 .58274 L
.14861 .58825 L
.15361 .59259 L
.1583 .596 L
.16345 .599 L
.16568 .60006 L
.16807 .60103 L
.17014 .60173 L
.1724 .60235 L
.17372 .60264 L
.17494 .60286 L
.17611 .60304 L
.17735 .60318 L
.17858 .60327 L
.17973 .60331 L
.18076 .60332 L
.18188 .60329 L
.18311 .60322 L
.18424 .60311 L
.18553 .60294 L
.18676 .60273 L
.18894 .60225 L
.19131 .60157 L
.19669 .59942 L
.20166 .59667 L
.2118 .58889 L
.22256 .57751 L
.24188 .54952 L
.26001 .51528 L
.29839 .423 L
.33921 .308 L
.37852 .19723 L
.41633 .10581 L
.43578 .06883 L
.45657 .03907 L
.46673 .0286 L
.47208 .02423 L
.47774 .02049 L
.4827 .01797 L
.48551 .01686 L
.48814 .01602 L
.49056 .01544 L
.49277 .01505 L
.49399 .0149 L
Mistroke
.49468 .01484 L
.49532 .01479 L
.49649 .01473 L
.49773 .01472 L
.49897 .01474 L
.49967 .01478 L
.50033 .01483 L
.50165 .01496 L
.50307 .01517 L
.50563 .01568 L
.50796 .01633 L
.51069 .01728 L
.51364 .01856 L
.51902 .02155 L
.52942 .02975 L
.53904 .04008 L
.55759 .06714 L
.57805 .10687 L
.61798 .20758 L
.65642 .31972 L
.69728 .43551 L
.71769 .48593 L
.73664 .52591 L
.75496 .55703 L
.76513 .57079 L
.7745 .58113 L
.78469 .58975 L
.79005 .59316 L
.79572 .59594 L
.7981 .59684 L
.80065 .59764 L
.80306 .59823 L
.80525 .59863 L
.80659 .59881 L
.80783 .59893 L
.80847 .59898 L
.80918 .59902 L
.80993 .59905 L
.81063 .59906 L
.81191 .59905 L
.81308 .599 L
.81437 .5989 L
.81501 .59884 L
.81572 .59875 L
.81823 .59834 L
.81965 .59803 L
.82096 .5977 L
.8259 .59604 L
.83039 .59396 L
.83516 .59118 L
Mistroke
.84504 .58353 L
.85593 .57223 L
.8752 .54518 L
.89592 .50671 L
.93684 .40587 L
.96865 .30885 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000KOol00`00Oomoo`3oOol3
Ool001=oo`D000=oo`03001oogoo0?moo`=oo`005Goo00<007ooOol00goo00<007ooOol0ogoo0goo
000EOol00`00Oomoo`03Ool2001eOol300000goo000000050023Ool000eoo`@000Aoo`03001oogoo
00=oo`03001oogoo07=oo`D000Moo`03001oo`00008007ioo`005Goo00<007ooOol00goo00<007oo
Ool0Lgoo1@0027oo1@00OGoo000DOol20005Ool00`00Oomoo`1cOol50008Ool5001mOol001]oo`03
001oogoo079oo`03001oo`00008000Uoo`D007eoo`006goo00<007ooOol0LGoo00<007ooOol03Goo
1@00O7oo000KOol00`00Oomoo`1`Ool00`00Oomoo`0COol00`00Oomoo`1iOol001]oo`03001oogoo
06moo`03001oogoo01Eoo`03001oogoo07Qoo`006goo0P00Kgoo00<007ooOol05Woo00<007ooOol0
N7oo000KOol00`00Oomoo`1^Ool00`00Oomoo`0GOol00`00Oomoo`1gOol001]oo`03001oogoo06eo
o`03001oogoo01Qoo`03001oogoo07Moo`006goo00<007ooOol0K7oo00<007ooOol06Woo00<007oo
Ool0MWoo000KOol00`00Oomoo`1[Ool00`00Oomoo`0LOol00`00Oomoo`1eOol001]oo`03001oogoo
06]oo`03001oogoo01aoo`03001oogoo07Eoo`006goo00<007ooOol0JWoo00<007ooOol07Woo00<0
07ooOol0M7oo000KOol00`00Oomoo`1YOol00`00Oomoo`0OOol00`00Oomoo`1dOol001]oo`8006Yo
o`03001oogoo021oo`03001oogoo07=oo`006goo00<007ooOol0IWoo0`008goo00<007ooOol0Lgoo
000KOol00`00Oomoo`1UOol5000SOol00`00Oomoo`1bOol001]oo`03001oogoo06Eoo`D002=oo`03
001oogoo079oo`006goo00<007ooOol0IGoo1@0097oo00<007ooOol0LGoo000KOol00`00Oomoo`1V
Ool3000UOol3001aOol001]oo`03001oogoo06Ioo`03001oogoo02Aoo`D0071oo`006goo0P00IWoo
00<007ooOol09Goo1@00L7oo000KOol00`00Oomoo`1UOol00`00Oomoo`0UOol5001`Ool001]oo`03
001oogoo06Eoo`03001oogoo02Ioo`<0075oo`006goo00<007ooOol0I7oo00<007ooOol0:Woo00<0
07ooOol0KWoo000KOol00`00Oomoo`1TOol00`00Oomoo`0ZOol00`00Oomoo`1^Ool001]oo`03001o
ogoo06=oo`03001oogoo02aoo`03001oogoo06eoo`006goo00<007ooOol0Hgoo00<007ooOol0;7oo
00<007ooOol0KGoo000KOol00`00Oomoo`1ROol00`00Oomoo`0]Ool00`00Oomoo`1]Ool001]oo`80
06=oo`03001oogoo02ioo`03001oogoo06aoo`006goo00<007ooOol0HWoo00<007ooOol0;Woo00<0
07ooOol0K7oo000KOol00`00Oomoo`1QOol00`00Oomoo`0`Ool00`00Oomoo`1[Ool001]oo`03001o
ogoo065oo`03001oogoo031oo`03001oogoo06]oo`006goo00<007ooOol0H7oo00<007ooOol0<Goo
00<007ooOol0Jgoo000KOol00`00Oomoo`1POol00`00Oomoo`0bOol00`00Oomoo`1ZOol000Qoo`80
00Aoo`8000Aoo`8000Eoo`03001oogoo061oo`03001oogoo039oo`03001oogoo06Yoo`001goo00@0
07ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`1OOol00`00Oomoo`0dOol00`00Oomoo`1YOol0
00Moo`04001oogoo000;Ool00`00Oomoo`02Ool2001POol00`00Oomoo`0dOol00`00Oomoo`1YOol0
0003Ool000000080009oo`04001oogoo0009Ool20005Ool00`00Oomoo`1NOol00`00Oomoo`0fOol0
0`00Oomoo`1XOol000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`1NOol00`00Oomo
o`0fOol00`00Oomoo`1XOol000Qoo`8000Yoo`<000Aoo`03001oogoo05eoo`03001oogoo03Moo`03
001oogoo06Qoo`006goo00<007ooOol0GGoo00<007ooOol0>7oo00<007ooOol0Igoo000KOol00`00
Oomoo`1MOol00`00Oomoo`0hOol00`00Oomoo`1WOol001]oo`03001oogoo05aoo`03001oogoo03Yo
o`03001oogoo06Ioo`006goo00<007ooOol0G7oo00<007ooOol0>Woo00<007ooOol0IWoo000KOol2
001LOol00`00Oomoo`0kOol00`00Oomoo`1VOol001]oo`03001oogoo05]oo`03001oogoo03aoo`03
001oogoo06Eoo`006goo00<007ooOol0FGoo0`00?Woo00<007ooOol0IGoo000KOol00`00Oomoo`1H
Ool5000nOol00`00Oomoo`1TOol001]oo`03001oogoo05Qoo`D003ioo`03001oogoo06Aoo`006goo
00<007ooOol0F7oo1@00?Woo00<007ooOol0I7oo000KOol00`00Oomoo`1IOol30010Ool00`00Oomo
o`1SOol001]oo`03001oogoo05Uoo`03001oogoo041oo`<006=oo`006goo0P00FWoo00<007ooOol0
?goo1@00HWoo000KOol00`00Oomoo`1HOol00`00Oomoo`10Ool5001ROol001]oo`03001oogoo05Qo
o`03001oogoo041oo`D0069oo`006goo00<007ooOol0F7oo00<007ooOol0@Goo0`00Hgoo000KOol0
0`00Oomoo`1GOol00`00Oomoo`14Ool00`00Oomoo`1QOol001]oo`03001oogoo05Moo`03001oogoo
04Aoo`03001oogoo065oo`006goo00<007ooOol0Egoo00<007ooOol0A7oo00<007ooOol0HGoo000K
Ool2001GOol00`00Oomoo`16Ool00`00Oomoo`1POol001]oo`03001oogoo05Ioo`03001oogoo04Io
o`03001oogoo061oo`006goo00<007ooOol0EWoo00<007ooOol0AWoo00<007ooOol0H7oo000KOol0
0`00Oomoo`1EOol00`00Oomoo`18Ool00`00Oomoo`1OOol001]oo`03001oogoo05Eoo`03001oogoo
04Qoo`03001oogoo05moo`006goo00<007ooOol0<7oo10008Goo00<007ooOol03goo0`00<Goo0`00
0Woo00<007ooOol0;Woo0P00;goo000KOol00`00Oomoo`0`Ool00`00Oomoo`0QOol00`00Oomoo`0A
Ool00`00Oomoo`0`Ool01000Oomoo`000Woo00<007ooOol0;7oo00@007ooOol002ioo`006goo00<0
07ooOol0<Goo00<007ooOol087oo00<007ooOol03Woo1@00<Goo00@007ooOol0009oo`03001oogoo
02aoo`04001oogoo000^Ool001]oo`8003=oo`03001oogoo01moo`03001oogoo00ioo`04001oogoo
000bOol30003Ool00`00Oomoo`0]Ool2000VOol30006Ool001]oo`03001oogoo031oo`04001oogoo
000OOol00`00Oomoo`0@Ool00`00Ool0000cOol00`00Oomoo`03Ool00`00Oomoo`0[Ool01000Oomo
o`0097oo1@001Goo000KOol00`00Oomoo`0aOol2000POol00`00Oomoo`0AOol2000cOol30003Ool0
0`00Oomoo`0/Ool2000UOol50005Ool001]oo`03001oogoo05=oo`03001oogoo04aoo`03001oogoo
05=oo`D000Eoo`006goo00<007ooOol0DWoo00<007ooOol0CWoo00<007ooOol0Dgoo0`001Woo000K
Ool00`00Oomoo`1BOol00`00Oomoo`1>Ool00`00Oomoo`1LOol001Yoo`<005=oo`03001oogoo04io
o`03001oogoo05aoo`006Goo1@00DGoo00<007ooOol0D7oo00<007ooOol0Fgoo000DOooo000=0000
01Uoo`D000Yoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00]oo`05001oogooOol00008Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0:
Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`08
Ool00`00Ool00007Ool001Yoo`<003=oo`03001oogoo01]oo`03001oogoo01Aoo`03001oogoo03=o
o`03001oogoo00Eoo`03001oogoo02Yoo`03001oogoo029oo`03001oogoo00Qoo`006goo0P00DGoo
00<007ooOol0DWoo00<007ooOol0Cgoo00<007ooOol027oo000KOol2001AOol00`00Oomoo`1BOol0
0`00Oomoo`1?Ool00`00Oomoo`08Ool001]oo`03001oo`0004moo`03001oogoo05Aoo`03001oogoo
04eoo`03001oogoo00Uoo`006goo00<007oo0000Cgoo00<007ooOol0E7oo00<007ooOol0CGoo00<0
07ooOol02Goo000KOol00`00Ool0001>Ool00`00Oomoo`1EOol00`00Oomoo`1=Ool00`00Oomoo`09
Ool001]oo`800003Ool007oo04aoo`03001oogoo05Ioo`03001oogoo04aoo`03001oogoo00Uoo`00
6goo00@007ooOol004]oo`<005Qoo`03001oogoo04]oo`03001oogoo00Yoo`006goo00@007ooOol0
04Yoo`D005Moo`03001oogoo04]oo`03001oogoo00Yoo`006goo00D007ooOomoo`0004Uoo`D005Qo
o`03001oogoo04Yoo`03001oogoo00Yoo`006goo00D007ooOomoo`0004Uoo`D005Qoo`03001oogoo
04Uoo`03001oogoo00]oo`006goo00D007ooOomoo`0004Yoo`<005Yoo`03001oogoo04Qoo`03001o
ogoo00]oo`006goo00<007ooOol00Woo00<007ooOol0Agoo00<007ooOol0FWoo00<007ooOol0B7oo
00<007ooOol02goo000KOol00`00Oomoo`02Ool00`00Oomoo`16Ool00`00Oomoo`1KOol30017Ool0
0`00Oomoo`0<Ool001]oo`8000Aoo`03001oogoo04Eoo`03001oogoo05Yoo`D004Ioo`03001oogoo
00aoo`006goo00<007ooOol00goo00<007ooOol0AGoo00<007ooOol0FWoo1@00AWoo00<007ooOol0
37oo000KOol00`00Oomoo`03Ool00`00Oomoo`14Ool00`00Oomoo`1KOol50015Ool00`00Oomoo`0=
Ool001]oo`03001oogoo00Aoo`03001oogoo04=oo`03001oogoo05aoo`<004Ioo`03001oogoo00eo
o`006goo00<007ooOol017oo00<007ooOol0@goo00<007ooOol0GWoo00<007ooOol0A7oo00<007oo
Ool03Goo000KOol00`00Oomoo`04Ool00`00Oomoo`12Ool00`00Oomoo`1OOol00`00Oomoo`14Ool0
0`00Oomoo`0=Ool001]oo`03001oogoo00Eoo`03001oogoo045oo`03001oogoo061oo`03001oogoo
049oo`03001oogoo00ioo`006goo0P001Woo00<007ooOol0@Goo00<007ooOol0H7oo00<007ooOol0
@Woo00<007ooOol03Woo000KOol00`00Oomoo`05Ool00`00Oomoo`10Ool00`00Oomoo`1QOol00`00
Oomoo`12Ool00`00Oomoo`0>Ool001]oo`03001oogoo00Ioo`03001oogoo03moo`03001oogoo069o
o`03001oogoo041oo`03001oogoo00moo`006goo00<007ooOol01Woo00<007ooOol0?Woo00<007oo
Ool0Hgoo00<007ooOol0@7oo00<007ooOol03goo000KOol00`00Oomoo`06Ool00`00Oomoo`0nOol0
0`00Oomoo`1TOol00`00Oomoo`0oOol00`00Oomoo`0?Ool001]oo`03001oogoo00Moo`03001oogoo
03eoo`03001oogoo06Aoo`03001oogoo03ioo`03001oogoo011oo`006goo00<007ooOol01goo00<0
07ooOol0?7oo00<007ooOol0IGoo00<007ooOol0?Woo00<007ooOol047oo000KOol00`00Oomoo`07
Ool00`00Oomoo`0lOol00`00Oomoo`1VOol00`00Oomoo`0jOol3000COol001]oo`8000Uoo`03001o
ogoo03]oo`03001oogoo06Ioo`03001oogoo03Uoo`D0019oo`006goo00<007ooOol027oo00<007oo
Ool0>Woo00<007ooOol0Igoo00<007ooOol0>Goo1@004Woo000KOol00`00Oomoo`08Ool00`00Oomo
o`0jOol00`00Oomoo`1XOol00`00Oomoo`0hOol5000BOol001]oo`03001oogoo00Uoo`03001oogoo
03Qoo`03001oogoo06Uoo`03001oogoo03Uoo`<001=oo`006goo00<007ooOol02Goo00<007ooOol0
>7oo00<007ooOol0JGoo00<007ooOol0>Goo00<007ooOol04goo000KOol00`00Oomoo`09Ool3000h
Ool00`00Oomoo`1ZOol00`00Oomoo`0hOol00`00Oomoo`0COol000Qoo`8000Aoo`8000Aoo`8000Eo
o`03001oogoo00Qoo`D003Ioo`03001oogoo06]oo`03001oogoo03Qoo`03001oogoo01=oo`001goo
00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`08Ool5000fOol00`00Oomoo`1/Ool00`00
Oomoo`0fOol00`00Oomoo`0DOol000Moo`04001oogoo000;Ool00`00Oomoo`02Ool20009Ool5000e
Ool00`00Oomoo`1]Ool00`00Oomoo`0fOol00`00Oomoo`0DOol000Moo`04001oogoo0009Ool20005
Ool00`00Oomoo`09Ool3000fOol00`00Oomoo`1]Ool00`00Oomoo`0eOol00`00Oomoo`0EOol000Mo
o`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`0dOol00`00Oomoo`1^
Ool00`00Oomoo`0dOol00`00Oomoo`0EOol000Qoo`8000Yoo`<000Aoo`03001oogoo00aoo`03001o
ogoo039oo`03001oogoo06moo`03001oogoo03=oo`03001oogoo01Ioo`006goo00<007ooOol037oo
00<007ooOol0<Woo00<007ooOol0Kgoo00<007ooOol0<goo00<007ooOol05Woo000KOol00`00Oomo
o`0<Ool00`00Oomoo`0aOol00`00Oomoo`1aOol00`00Oomoo`0bOol00`00Oomoo`0FOol001]oo`03
001oogoo00eoo`03001oogoo02ioo`<007=oo`03001oogoo035oo`03001oogoo01Moo`006goo00<0
07ooOol03Goo00<007ooOol0;Goo1@00Lgoo00<007ooOol0<7oo00<007ooOol05goo000KOol2000?
Ool00`00Oomoo`0/Ool5001cOol00`00Oomoo`0_Ool00`00Oomoo`0HOol001]oo`03001oogoo00io
o`03001oogoo02aoo`D007=oo`03001oogoo02moo`03001oogoo01Qoo`006goo00<007ooOol03goo
00<007ooOol0;7oo0`00MGoo0`00;Woo00<007ooOol067oo000KOol00`00Oomoo`0?Ool00`00Oomo
o`0/Ool00`00Oomoo`1dOol5000/Ool00`00Oomoo`0IOol001]oo`03001oogoo011oo`03001oogoo
02]oo`03001oogoo07Aoo`D002aoo`03001oogoo01Uoo`006goo00<007ooOol047oo00<007ooOol0
:Woo00<007ooOol0MGoo1@00:goo00<007ooOol06Woo000KOol00`00Oomoo`0AOol00`00Oomoo`0Y
Ool00`00Oomoo`1fOol3000/Ool00`00Oomoo`0JOol001]oo`03001oogoo015oo`03001oogoo02Qo
o`03001oogoo07Uoo`03001oogoo02Uoo`03001oogoo01]oo`006goo0P004goo00<007ooOol09goo
00<007ooOol0NWoo00<007ooOol0:7oo00<007ooOol06goo000KOol00`00Oomoo`0BOol00`00Oomo
o`0VOol00`00Oomoo`1kOol00`00Oomoo`0WOol00`00Oomoo`0LOol001]oo`03001oogoo01=oo`03
001oogoo02Eoo`03001oogoo07aoo`03001oogoo02Ioo`03001oogoo01aoo`006goo00<007ooOol0
4goo00<007ooOol097oo00<007ooOol0OGoo00<007ooOol09Goo00<007ooOol07Goo000KOol00`00
Oomoo`0DOol00`00Oomoo`0SOol00`00Oomoo`1nOol00`00Oomoo`0SOol00`00Oomoo`0NOol001]o
o`03001oogoo01Aoo`03001oogoo029oo`03001oogoo07moo`03001oogoo021oo`@0021oo`006goo
00<007ooOol05Goo00<007ooOol08Goo00<007ooOol0P7oo00<007ooOol07Woo1@0087oo000KOol2
000GOol00`00Oomoo`0OOol00`00Oomoo`21Ool00`00Oomoo`0NOol5000POol001]oo`03001oogoo
01Ioo`03001oogoo01moo`03001oogoo089oo`03001oogoo01eoo`D0021oo`006goo00<007ooOol0
5Woo0`007Woo00<007ooOol0Q7oo00<007ooOol07Goo0`008Goo000KOol00`00Oomoo`0EOol5000L
Ool00`00Oomoo`25Ool00`00Oomoo`0MOol00`00Oomoo`0QOol001]oo`03001oogoo01Eoo`D001ao
o`03001oogoo08Ioo`03001oogoo01]oo`03001oogoo029oo`006goo00<007ooOol05Goo1@006goo
00<007ooOol0R7oo00<007ooOol06Goo00<007ooOol08goo000KOol00`00Oomoo`0FOol4000JOol0
0`00Oomoo`29Ool00`00Oomoo`0HOol00`00Oomoo`0TOol001]oo`03001oogoo01Uoo`03001oogoo
01Eoo`<008eoo`03001oogoo01Moo`03001oogoo02Aoo`006goo0P006goo00<007ooOol04goo1@00
SGoo00<007ooOol05Goo00<007ooOol09Goo000KOol00`00Oomoo`0KOol00`00Oomoo`0BOol5002>
Ool4000BOol00`00Oomoo`0VOol001]oo`03001oogoo01aoo`03001oogoo015oo`D008ioo`D0011o
o`03001oogoo02Moo`006goo00<007ooOol07Goo00<007ooOol047oo1000Sgoo1@003goo00<007oo
Ool0:7oo000KOol00`00Oomoo`0NOol00`00Oomoo`0>Ool00`00Oomoo`2AOol5000>Ool00`00Oomo
o`0YOol001]oo`03001oogoo01moo`03001oogoo00]oo`8009Eoo`@000Uoo`<00003Ool007oo02]o
o`004goo1@000goo00<007ooOol087oo0P000Woo0`001Goo00<007ooOol0VGoo0`001Goo1@00;Goo
000EOol00`00Oomoo`03Ool00`00Oomoo`0ROol60003Ool00`00Oomoo`2MOol:000]Ool001Eoo`03
001oogoo00=oo`8002Aoo`P00:Eoo`D002eoo`005Goo00<007ooOol00goo00<007ooOol08goo1@00
ZGoo0`00;Woo000EOol00`00Oomoo`03Ool00`00Oomoo`0TOol3003KOol001Aoo`8000Eoo`03001o
ogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.02471, -1.13363, \
0.037499, 0.0128139}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Combinatorics and combinatorial optimization (also neat, but I'm \
skipping this too so the next people can speak)\
\>", "Section"],

Cell[CellGroupData[{

Cell["Combinatorica Graph Algorithms", "Subsubsection"],

Cell[TextData[{
  "Combinatorial structures are important in many computational settings. The \
program ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a package, Combinatorica, that produces and manipulates many such \
objects. We show some simple examples."
}], "Text"],

Cell[BoxData[
    \(<< DiscreteMath`Combinatorica`\)], "Input"],

Cell[BoxData[
    \(\(SetOptions[\ ShowGraph, \ VertexStyle \[Rule] Disk[ .05], 
        VertexColor \[Rule] Red\ ];\)\)], "Input"],

Cell["\<\
This is a special (i.e. named) graph called a K-partite graph. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowGraph[\ CompleteGraph[6, 6, 6]\ ];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.26471 2.15686 0.0495495 0.990991 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.10784 .04955 m
.5 .04955 L
s
.10784 .04955 m
.5 .22973 L
s
.10784 .04955 m
.5 .40991 L
s
.10784 .04955 m
.5 .59009 L
s
.10784 .04955 m
.5 .77027 L
s
.10784 .04955 m
.5 .95045 L
s
.10784 .04955 m
.89216 .04955 L
s
.10784 .04955 m
.89216 .22973 L
s
.10784 .04955 m
.89216 .40991 L
s
.10784 .04955 m
.89216 .59009 L
s
.10784 .04955 m
.89216 .77027 L
s
.10784 .04955 m
.89216 .95045 L
s
.10784 .22973 m
.5 .04955 L
s
.10784 .22973 m
.5 .22973 L
s
.10784 .22973 m
.5 .40991 L
s
.10784 .22973 m
.5 .59009 L
s
.10784 .22973 m
.5 .77027 L
s
.10784 .22973 m
.5 .95045 L
s
.10784 .22973 m
.89216 .04955 L
s
.10784 .22973 m
.89216 .22973 L
s
.10784 .22973 m
.89216 .40991 L
s
.10784 .22973 m
.89216 .59009 L
s
.10784 .22973 m
.89216 .77027 L
s
.10784 .22973 m
.89216 .95045 L
s
.10784 .40991 m
.5 .04955 L
s
.10784 .40991 m
.5 .22973 L
s
.10784 .40991 m
.5 .40991 L
s
.10784 .40991 m
.5 .59009 L
s
.10784 .40991 m
.5 .77027 L
s
.10784 .40991 m
.5 .95045 L
s
.10784 .40991 m
.89216 .04955 L
s
.10784 .40991 m
.89216 .22973 L
s
.10784 .40991 m
.89216 .40991 L
s
.10784 .40991 m
.89216 .59009 L
s
.10784 .40991 m
.89216 .77027 L
s
.10784 .40991 m
.89216 .95045 L
s
.10784 .59009 m
.5 .04955 L
s
.10784 .59009 m
.5 .22973 L
s
.10784 .59009 m
.5 .40991 L
s
.10784 .59009 m
.5 .59009 L
s
.10784 .59009 m
.5 .77027 L
s
.10784 .59009 m
.5 .95045 L
s
.10784 .59009 m
.89216 .04955 L
s
.10784 .59009 m
.89216 .22973 L
s
.10784 .59009 m
.89216 .40991 L
s
.10784 .59009 m
.89216 .59009 L
s
.10784 .59009 m
.89216 .77027 L
s
.10784 .59009 m
.89216 .95045 L
s
.10784 .77027 m
.5 .04955 L
s
.10784 .77027 m
.5 .22973 L
s
.10784 .77027 m
.5 .40991 L
s
.10784 .77027 m
.5 .59009 L
s
.10784 .77027 m
.5 .77027 L
s
.10784 .77027 m
.5 .95045 L
s
.10784 .77027 m
.89216 .04955 L
s
.10784 .77027 m
.89216 .22973 L
s
.10784 .77027 m
.89216 .40991 L
s
.10784 .77027 m
.89216 .59009 L
s
.10784 .77027 m
.89216 .77027 L
s
.10784 .77027 m
.89216 .95045 L
s
.10784 .95045 m
.5 .04955 L
s
.10784 .95045 m
.5 .22973 L
s
.10784 .95045 m
.5 .40991 L
s
.10784 .95045 m
.5 .59009 L
s
.10784 .95045 m
.5 .77027 L
s
.10784 .95045 m
.5 .95045 L
s
.10784 .95045 m
.89216 .04955 L
s
.10784 .95045 m
.89216 .22973 L
s
.10784 .95045 m
.89216 .40991 L
s
.10784 .95045 m
.89216 .59009 L
s
.10784 .95045 m
.89216 .77027 L
s
.10784 .95045 m
.89216 .95045 L
s
.5 .04955 m
.89216 .04955 L
s
.5 .04955 m
.89216 .22973 L
s
.5 .04955 m
.89216 .40991 L
s
.5 .04955 m
.89216 .59009 L
s
.5 .04955 m
.89216 .77027 L
s
.5 .04955 m
.89216 .95045 L
s
.5 .22973 m
.89216 .04955 L
s
.5 .22973 m
.89216 .22973 L
s
.5 .22973 m
.89216 .40991 L
s
.5 .22973 m
.89216 .59009 L
s
.5 .22973 m
.89216 .77027 L
s
.5 .22973 m
.89216 .95045 L
s
.5 .40991 m
.89216 .04955 L
s
.5 .40991 m
.89216 .22973 L
s
.5 .40991 m
.89216 .40991 L
s
.5 .40991 m
.89216 .59009 L
s
.5 .40991 m
.89216 .77027 L
s
.5 .40991 m
.89216 .95045 L
s
.5 .59009 m
.89216 .04955 L
s
.5 .59009 m
.89216 .22973 L
s
.5 .59009 m
.89216 .40991 L
s
.5 .59009 m
.89216 .59009 L
s
.5 .59009 m
.89216 .77027 L
s
.5 .59009 m
.89216 .95045 L
s
.5 .77027 m
.89216 .04955 L
s
.5 .77027 m
.89216 .22973 L
s
.5 .77027 m
.89216 .40991 L
s
.5 .77027 m
.89216 .59009 L
s
.5 .77027 m
.89216 .77027 L
s
.5 .77027 m
.89216 .95045 L
s
.5 .95045 m
.89216 .04955 L
s
.5 .95045 m
.89216 .22973 L
s
.5 .95045 m
.89216 .40991 L
s
.5 .95045 m
.89216 .59009 L
s
.5 .95045 m
.89216 .77027 L
s
.5 .95045 m
.89216 .95045 L
s
1 0 0 r
.05 w
.10784 .04955 Mdot
.10784 .22973 Mdot
.10784 .40991 Mdot
.10784 .59009 Mdot
.10784 .77027 Mdot
.10784 .95045 Mdot
.5 .04955 Mdot
.5 .22973 Mdot
.5 .40991 Mdot
.5 .59009 Mdot
.5 .77027 Mdot
.5 .95045 Mdot
.89216 .04955 Mdot
.89216 .22973 Mdot
.89216 .40991 Mdot
.89216 .59009 Mdot
.89216 .77027 Mdot
.89216 .95045 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol001aoo`Il06Yo
o`Il06]oo`Il01eoo`006goo27`0J7oo27`0JGoo27`077oo000JOol:O01VOol:O01WOol:O00KOol0
01Uoo`al06Aoo`al06Eoo`al01Yoo`0067oo3G`0Hgoo3G`0I7oo3G`06Woo000HOol>O01ROol>O01S
Ool>O00IOol001Qoo`il069oo`il06=oo`il01Uoo`0067oo3W`0HP003W`0H`003W`06Goo000HOol>
O01ROol>O01SOol>O00IOol001Qoo`el00D005ioo`el061oo`@000el01Yoo`006Goo37`000<007oo
Ool00Woo1000FWoo00<007`0O0002W`00P00FWoo100017oo00<007`0O0002W`06Woo000JOol:O000
1000Ool000001Woo1000E7oo0P000Woo2W`00goo0P00E7oo10001Woo0P0000=oo`00O0002G`06goo
000KOol8O004000017oo000000001goo1@00C7oo0`000goo0P0027`00`000goo0`00C7oo1@001goo
0`0000=oo`0000000P0027`077oo000LOol6O002000017oo001oo`000goo0P002Woo1000AWoo0P00
1Goo00@007ooOol000Il0080009oo`03001oogoo00=oo`8004Ioo`@000Yoo`8000=oo`04001oo`00
Ool20006O00MOol0025oo`@00004Ool007oo0004Ool2000<Ool5000oOol20006Ool00`00Oomoo`03
0005Ool30002Ool00`00Oomoo`04Ool2000oOol5000<Ool20004Ool01000Ool007oo10008Woo000R
Ool01`00Ool00000Ool007oo008000Aoo`8000moo`@003Uoo`8000Moo`06001oogoo001oo`001goo
00<007oo00000Woo00<007ooOol01Goo0P00>Goo10003goo0P0017oo0P0000=oo`00Ool00P0000=o
o`00Ool08Woo000ROol200001Goo000007oo00000Woo00<007ooOol00goo0`0047oo1@00<Goo0`00
27oo00D007ooOol007oo008000Moo`800005Ool007ooOol00008Ool3000aOol5000@Ool30005Ool0
1@00Oomoo`00Ool00P0000=oo`0000008goo000ROol200001Woo001oo`00Ool0009oo`8000Eoo`<0
01=oo`@002]oo`8000Yoo`06001oogooOol007oo0P001goo0P0000=oo`00Ool00Woo00<007ooOol0
27oo0P00:goo10004goo0`001Goo0P000Woo00H007oo001oo`00Ool2000SOol002=oo`800006Ool0
07oo001oo`000goo00<007ooOol01Goo0P005Goo10009Goo0P002goo00H007ooOomoo`00Ool20009
Ool200000goo001oo`02Ool00`00Oomoo`09Ool2000UOol4000EOol20007Ool02P00Oomoogoo001o
o`00Ool007oo0P0097oo000SOol02@00Ool007oo001oo`00Ool00003Ool20007Ool2000GOol5000N
Ool2000<Ool02@00Oomoogoo001oo`00Ool00009Ool01@00Ool007oo00000goo00<007ooOol02Woo
0P007Woo1@005goo0P001goo0P000goo00T007oo001oo`00Ool007oo000097oo000TOol2000017oo
001oo`000Woo00<007ooOol00Woo00<007ooOol01Woo0P006Woo100067oo0P003Goo00<007ooOol0
0Woo00@007oo000000]oo`800003Ool007oo00=oo`03001oogoo00]oo`8001Qoo`@001Yoo`8000Qo
o`03001oogoo009oo`07001oogoo001oo`00Ool00P009Goo000TOol01`00Ool007oo001oo`00009o
o`03001oogoo009oo`8000Qoo`<001]oo`D0011oo`<000ioo`03001oogoo009oo`05001oo`00Ool0
000;Ool01@00Ool007oo000017oo00<007ooOol037oo0`0047oo1@006goo0`0027oo0P0017oo00X0
07ooOol007oo001oo`00Ool002Eoo`009Goo0P000Woo00<007oo00000Woo0P0017oo00<007ooOol0
1goo0`007Woo10002Woo0P003goo0P0017oo00<007ooOol00P003Goo0P000Woo00<007ooOol00Woo
0P003goo0P002Woo10007Woo0`002Goo00<007ooOol00Woo0P000Woo00<007oo00000Woo0P009Woo
000UOol00`00Ool00002Ool00`00Ool00002Ool20004Ool2000:Ool2000POol50003Ool2000@Ool0
0`00Oomoo`03Ool01P00Oomoo`00Ool000eoo`03001oo`00009oo`03001oogoo00=oo`03001oogoo
00ioo`8000=oo`D0021oo`8000Yoo`8000Aoo`80009oo`03001oo`00009oo`03001oo`0002Ioo`00
9Goo00<007oo00000Woo00@007ooOol000=oo`03001oogoo00=oo`03001oogoo00Uoo`8002=oo`@0
011oo`03001oogoo00Aoo`06001oogoo001oo`003Goo00<007oo00000Woo00<007ooOol017oo00<0
07ooOol03Woo10008goo0P002goo00<007ooOol00goo00D007ooOomoo`00009oo`06001oogoo001o
o`009Woo000VOol00`00Ool00002Ool01000Oomoo`000goo00<007ooOol00goo00<007ooOol02Woo
0P0087oo0P000goo10002goo00<007ooOol017oo00H007ooOol007oo000?Ool00`00Ool00002Ool0
0`00Oomoo`04Ool00`00Oomoo`09Ool40003Ool2000POol2000<Ool00`00Oomoo`03Ool01@00Oomo
ogoo00000Woo00H007ooOol007oo000WOol002Ioo`03001oo`0000=oo`04001oogoo0003Ool00`00
Oomoo`03Ool2000<Ool3000JOol30009Ool50005Ool00`00Oomoo`04Ool01`00Oomoogoo001oo`00
00moo`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo00=oo`D000Uoo`<001Yoo`<000aoo`80
00Eoo`05001oogooOol00002Ool01`00Oomoogoo001oo`0002Moo`009goo00<007oo00000goo00@0
07ooOol000=oo`03001oogoo00Aoo`03001oogoo00]oo`<001Ioo`80015oo`D000Ioo`07001oogoo
Ool007oo00004Goo00<007oo00000goo00<007ooOol017oo1@004Goo0P005Woo0`003Goo00<007oo
Ool017oo00D007ooOomoo`00009oo`07001oogooOol007oo0000:7oo000WOol00`00Ool00003Ool0
1000Oomoo`0017oo00<007ooOol017oo0P003Goo0`004Woo0P005Woo1P000Woo00L007ooOomoo`00
Ool0000AOol00`00Ool00003Ool00`00Oomoo`06000FOol2000BOol3000=Ool20006Ool00`00Oomo
o`02Ool01000Oomoo`000goo00<007oo0000:7oo000XOol00`00Ool00003Ool01000Oomoo`0017oo
00<007ooOol01Goo00<007ooOol03Goo0P003Woo0P005goo00<007ooOol017oo100000Aoo`00Ool0
01=oo`04001oo`00Ool40006Ool00`00Oomoo`0EOol2000>Ool2000?Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool01000Oomoo`000goo00<007oo0000:Goo000XOol01000Oomoo`000goo00@007ooOol0
00Aoo`03001oogoo00Eoo`8000moo`<000Qoo`<001Qoo`03001oogoo00Eoo`04001oogooOol5000A
Ool50003Ool00`00Oomoo`05Ool00`00Oomoo`0FOol30008Ool3000?Ool20007Ool00`00Oomoo`02
Ool01000Oomoo`000goo00@007ooOol002Uoo`00:Goo00<007oo00000goo00D007ooOomoo`0000Ao
o`03001oogoo00Ioo`03001oogoo00ioo`<000Aoo`8001Yoo`03001oogoo00Ioo`07001oogooOol0
07oo00000Woo10002Goo10000Woo00<007oo00000goo00<007ooOol01Woo00<007ooOol067oo0P00
17oo0`0047oo00<007ooOol01Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oo`0002Yo
o`00:Goo00@007ooOol000=oo`05001oogooOol00004Ool00`00Oomoo`06Ool2000@Ool5000KOol0
0`00Oomoo`06Ool01@00Oomoogoo00000Woo00<007ooOol017oo100000=oo`0000000P001Woo00@0
07ooOol000=oo`03001oogoo00Ioo`03001oogoo01Uoo`D0011oo`8000Qoo`03001oogoo009oo`05
001oogooOol00003Ool01000Oomoo`00:Woo000YOol01000Oomoo`0017oo00D007ooOomoo`0000Ao
o`8000Qoo`03001oogoo00ioo`@001Uoo`8000Qoo`03001oogoo009oo`04001oogoo0006Ool90006
Ool01000Oomoo`0017oo00<007ooOol01Woo0P006Goo100047oo00<007ooOol01Woo0P0017oo00D0
07ooOomoo`0000Aoo`04001oogoo000ZOol002Yoo`04001oogoo0004Ool01@00Oomoogoo000017oo
0P0027oo0P0037oo0P0017oo0P005Woo00<007ooOol01goo00<007ooOol00Woo00@007ooOol000=o
o`@000Uoo`@000=oo`04001oogoo0004Ool00`00Oomoo`07Ool00`00Oomoo`0DOol20004Ool2000<
Ool20008Ool20004Ool01@00Oomoogoo000017oo00@007ooOol002]oo`00:Woo00@007ooOol000Ao
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Ioo`<000Qoo`<0019o
o`03001oogoo00Qoo`03001oogoo009oo`03001oo`0000@0015oo`D00003Ool007oo00=oo`03001o
ogoo00Qoo`03001oogoo011oo`<000Qoo`<000Qoo`03001oogoo00Moo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo009oo`04001oogoo000[Ool002]oo`04001oogoo0004Ool01@00Oomoogoo
00001Woo00<007ooOol01goo0P0017oo0P003Goo0`003goo00<007ooOol027oo00@007ooOomoo`D0
01Uoo`D000=oo`03001oogoo00Qoo`03001oogoo00eoo`<000eoo`8000Aoo`8000Uoo`03001oogoo
00Aoo`05001oogooOol00004Ool01000Oomoo`00;7oo000[Ool01000Oomoo`001Goo00D007ooOomo
o`0000Ioo`03001oogoo00Qoo`04001oo`00000AOol3000<Ool00`00Oomoo`08Ool500001Goo001o
ogoo00006Goo00D007ooOol007oo00D000Yoo`03001oogoo00Yoo`<0015oo`800003Ool007oo00Uo
o`03001oogoo00Aoo`05001oogooOol00005Ool01000Oomoo`00;7oo000/Ool01000Oomoo`001Goo
00D007ooOomoo`0000Ioo`03001oogoo00Moo`8001Eoo`<000Uoo`03001oogoo00Eoo`@000Eoo`04
001oogoo000KOol01000Oomoo`001Goo10001goo00<007ooOol01goo0`005Goo0P002Goo00<007oo
Ool017oo00D007ooOomoo`0000Eoo`04001oogoo000]Ool002aoo`04001oogoo0005Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool30002Ool2000FOol30005Ool01000Oomoogoo1@00
0goo00<007ooOol00goo00@007ooOol001]oo`04001oogoo0005Ool01000Oomoogoo1@000goo00<0
07ooOol00goo0`005Woo0P000Woo0`001Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0
0goo00@007ooOol002eoo`00;7oo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00Ao
o`03001oogoo008000Moo`03001oogoo01Eoo`<0009oo`D000Moo`03001oogoo00=oo`05001oogoo
Ool0000KOol01@00Oomoogoo00001Goo00<007ooOol01Goo1@000Woo0`005goo00<007ooOol01Goo
0P000Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0002eoo`00
;Goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo00Aoo`8000Yoo`8001Moo`@000Yo
o`03001oogoo00=oo`05001oogooOol0000MOol01@00Oomoogoo00001Goo00<007ooOol027oo1000
5goo0P002Woo0P001Woo00<007ooOol00Woo00<007ooOol00goo00D007ooOomoo`0002ioo`00;Goo
00D007ooOomoo`0000Ioo`03001oogoo009oo`04001oogooOol200000goo001oo`0;Ool00`00Oomo
o`0?Ool500000goo000000020008Ool00`00Oomoo`04Ool01@00Oomoogoo00007Goo00D007ooOomo
o`0000Ioo`03001oogoo00Ioo`@00003Ool0000000<0015oo`03001oogoo00Yoo`04001oo`000003
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo0000;Woo000^Ool01@00Oomoogoo0000
1Goo00<007ooOol00goo0`0017oo0P002goo0P002goo100017oo0P000goo0`001Woo00<007ooOol0
0goo00D007ooOomoo`0001moo`05001oogooOol00005Ool00`00Oomoo`04Ool30003Ool20004Ool4
000;Ool2000;Ool20004Ool30005Ool00`00Oomoo`03Ool01@00Oomoogoo0000;goo000^Ool01@00
Oomoogoo00001Woo00<007ooOol00`001goo0P0037oo00<007ooOol00goo1@001goo00<007ooOol0
1Woo0`000Woo00<007ooOol017oo00D007ooOomoo`0001moo`05001oogooOol00006Ool00`00Oomo
o`030008Ool00`00Oomoo`05Ool50005Ool00`00Oomoo`0:Ool20007Ool30002Ool00`00Oomoo`04
Ool01@00Oomoogoo0000;goo000_Ool01@00Oomoogoo00001Woo0P000goo00<007ooOol01Goo0P00
37oo1@002goo00<007ooOol02Goo0`001Woo00D007ooOomoo`00025oo`05001oogooOol00006Ool3
000;Ool00`00Oomoo`09Ool5000<Ool20007Ool01000Oomoogoo0P001Woo00D007ooOomoo`00031o
o`00;goo00D007ooOomoo`0000Aoo`<000Eoo`03001oogoo00Ioo`03001oogoo00Eoo`D00003Ool0
07oo00]oo`03001oogoo00aoo`<000Aoo`05001oogooOol0000QOol01@00Oomoogoo000017oo0`00
3Woo00<007ooOol02Woo00<007oo000010001goo00<007ooOol01Woo00<007ooOol00goo0`0017oo
00D007ooOomoo`00031oo`00<7oo00H007ooOomoo`00Ool20003Ool00`00Oomoo`03Ool00`00Oomo
o`06Ool00`00Oomoo`040007Ool20009Ool00`00Oomoo`0<Ool00`00Oomoo`0300000goo001oo`02
Ool00`00Oomoo`0QOol01P00Oomoogoo001oo`<0009oo`03001oogoo00aoo`03001oogoo00Moo`80
00Moo`@0009oo`03001oogoo00Ioo`03001oogoo00=oo`04001oogooOol200000goo001oo`02Ool0
0`00Oomoo`0_Ool0031oo`04001oogooOol20006Ool00`00Oomoo`03Ool00`00Oomoo`04Ool4000=
Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool30003Ool00`00Oomoo`0QOol01000
Oomoogoo0`001Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol02goo10001Woo00<007oo
Ool00goo00<007ooOol017oo0P000goo00<007ooOol0;goo000`Ool400000goo001oo`06Ool00`00
Oomoo`03Ool60003Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`05
Ool00`00Ool00003000SOol400000goo001oo`06Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00
Oomoo`0<Ool01000Oomoogoo1P001Goo00<007ooOol01Goo00<007oo00000`00<Goo000_Ool30003
Ool00`00Oomoo`05Ool00`00Oomoo`050008Ool00`00Oomoo`0<Ool20002Ool00`00Oomoo`0=Ool0
0`00Oomoo`05Ool01000Oomoogoo0`008Goo0`000goo00<007ooOol01Goo00<007ooOol03Goo00<0
07ooOol00P003Woo00<007ooOol01Woo1@000Woo00<007ooOol01Goo00@007ooOomoo`<0031oo`00
;Goo0P000Woo00<007ooOol00Woo00<007ooOol00Woo1@001Goo00<007ooOol01Woo00<007ooOol0
3Goo0P003goo00<007ooOol01Goo00<007ooOol00Woo00<007oo00000P007Goo0`0000=oo`00Ool0
0goo00<007ooOol01Goo00<007ooOol03Goo0P003goo00<007ooOol01Woo00<007ooOol00goo1@00
17oo00<007ooOol00Woo00<007ooOol00P00;Woo000LOol6O009Ool20005Ool00`00Oomoo`02Ool4
0004Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`0<Ool3000=Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool30009Ool6O00:Ool30004Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`0;Ool3000>Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`02Ool4
0004Ool00`00Oomoo`03Ool20009Ool6O00MOol001]oo`Ql00Eoo`<000Moo`H000Qoo`03001oogoo
00=oo`03001oogoo00Moo`8000Yoo`8000=oo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo
009oo`03001oogoo00Aoo`@000Eoo`Ql00Ioo`@000Ioo`03001oogoo009oo`03001oogoo00Ioo`03
001oogoo00Uoo`04001oogooOol2000:Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`06Ool60007
Ool30005Ool8O00LOol001Yoo`Yl009oo`8000Ioo`@00003Ool007oo00=oo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Moo`8000Qoo`03001oogoo00Aoo`8000Uoo`03001oogoo00Eoo`03
001oogoo009oo`03001oogoo00Qoo`<0009oo`Yl00=oo`<000Yoo`03001oogoo009oo`03001oogoo
00Eoo`03001oogoo00Moo`8000Ioo`03001oogoo00Ioo`8000Uoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo009oo`03001oo`0000<000Ioo`80009oo`Yl01]oo`006Goo37`000<007ooOol0
0Woo10001Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01goo0P00
1Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0
2Woo0P0037`00`0037oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0
1goo00<007ooOol017oo0P002Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol00Woo00<0
07ooOol00goo100017oo00<007`0O0002W`06Woo000HOol=O0050009Ool00`00Oomoo`03Ool00`00
Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`07Ool20004Ool00`00Oomoo`09Ool20004Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool=O0000`00Oomoo`0<Ool00`00Oomoo`03Ool0
0`00Oomoo`06Ool00`00Oomoo`02Ool2000;Ool00`00Oomoo`02Ool20009Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`07Ool4000=O00JOol001Qoo`il00ioo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Qoo`04001oogoo000>Ool01@00
Oomoogoo000027oo00<007ooOol00Woo00<007ooOol037oo3W`03goo00<007ooOol00Woo00<007oo
Ool01Woo00D007ooOomoo`0000ioo`04001oogoo000:Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`02Ool00`00Oomoo`0<Ool>O00IOol001Qoo`il068000il06<000il01Uoo`0067oo3W`0
3goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol01goo0P004Goo0P00
27oo00<007ooOol00Woo00<007ooOol03Goo3W`047oo00<007ooOol00Woo00<007ooOol01Woo0P00
4Goo0P002Goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol03Goo3W`0
6Goo000HOol>O003000<Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomo
o`06Ool01000Oomoo`003goo00<007ooOol00P001Goo00<007ooOol00goo00<007ooOol03Goo3W`0
47oo00<007ooOol00goo00<007ooOol00goo0P000Woo00<007ooOol03Goo00@007ooOol000Qoo`03
001oogoo00Aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Yoo`<000il01Uoo`0067oo
3G`000@007ooOomoo`D000Qoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo00ioo`el0080011oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Moo`03001oogoo009oo`03001oogoo00Ioo`D000=oo`el01Yoo`006Goo37`000=oo`0000001Woo
100017oo00<007ooOol00goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00Woo00<007oo
Ool017oo00<007ooOol02Woo00<007ooOol017oo00@007ooOol000Eoo`03001oogoo00aoo`<000al
0004Ool00000000>Ool00`00Oomoo`03Ool01000Oomoo`001Woo00<007ooOol02Woo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0
0Woo10001Woo0P0000=oog`0O0002W`06Woo000JOol:O0020002Ool20008Ool400000goo001oo`04
Ool00`00Oomoo`07Ool00`00Oomoo`05Ool01000Oomoo`0027oo00<007ooOol027oo00<007ooOol0
1Woo0P001Goo00<007ooOol02goo0`000goo2W`000@007ooOomoo`<000eoo`03001oogoo00=oo`80
00Qoo`03001oogoo00Qoo`03001oogoo00Ioo`04001oogoo0007Ool00`00Oomoo`07Ool00`00Oomo
o`03Ool00`00Ool000030008Ool20002Ool2000:O00KOol001]oo`Ql0003Ool000000080009oo`<0
00Uoo`D0009oo`03001oogoo00Qoo`03001oogoo00Eoo`8000Yoo`8000Moo`03001oogoo00Qoo`80
00Aoo`03001oogoo00Qoo`@000=oo`800003Ooml07`000Il0004001oo`000003Ool4000:Ool00`00
Oomoo`02Ool2000:Ool00`00Oomoo`05Ool2000:Ool20007Ool00`00Oomoo`08Ool00`00Oomoo`05
0009Ool30002Ool400000gooO01l0006O00LOol001aoo`Il0080009oo`03001oo`0000Aoo`8000Qo
o`04001oogooOol40009Ool00`00Oomoo`04Ool00`00Ool0000;Ool20006Ool00`00Oomoo`07Ool0
0`00Oomoo`020002Ool00`00Oomoo`06Ool30005Ool00`00Oomoo`020006O0000goo00000002Ool0
0`00Oomoo`03Ool30008Ool00`00Oomoo`020002Ool00`00Oomoo`07Ool00`00Oomoo`04Ool2000;
Ool00`00Ool00006Ool00`00Oomoo`07Ool40003Ool00`00Oomoo`06Ool20004Ool00`00Ool00002
Ool20006O00MOol0029oo`03001oo`00009oo`04001oo`000004Ool20007Ool00`00Oomoo`03Ool5
0006Ool00`00Oomoo`02Ool01@00Oomoogoo00002goo0P0017oo00<007ooOol027oo00<007ooOol0
0Woo0P001goo0`001Woo00H007ooOol007oo0007Ool00`00Ool00002Ool00`00Oomoo`04Ool30007
Ool20004Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000;Ool01@00Oomoogoo000017oo00<007oo
Ool017oo1@001Goo00<007ooOol01Goo0P0017oo0P0000Moo`00Oomoo`00Ool0000SOol002=oo`03
001oo`00009oo`04001oogoo0005Ool20005Ool00`00Oomoo`04Ool01000Oomoogoo1@000Woo00@0
07ooOol000Eoo`03001oogoo00Uoo`80009oo`03001oogoo00Qoo`03001oogoo00Aoo`8000Aoo`<0
00Moo`06001oogoo001oo`002Goo00<007oo00000Woo00<007ooOol01Goo0`0017oo0P001Woo00<0
07ooOol027oo00<007ooOol00P002goo00<007ooOol00goo00@007ooOol0009oo`D000=oo`03001o
ogoo00Aoo`03001oogoo00=oo`8000Eoo`04001oogoo0002Ool00`00Ool0000TOol002=oo`03001o
o`0000=oo`03001oogoo008000Eoo`8000Aoo`03001oogoo00=oo`03001oogoo00Ioo`D000Ioo`03
001oogoo00]oo`03001oo`0000Yoo`03001oogoo00=oo`05001oogoo001oo`030008Ool01`00Oomo
ogoo001oo`0000Uoo`03001oo`0000=oo`03001oogoo00Ioo`<00005Ool007ooOol00005Ool00`00
Oomoo`08Ool00`00Ool0000=Ool00`00Oomoo`04Ool50008Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool20005Ool20002Ool01`00Oomoogoo001oo`0002Aoo`0097oo00<007oo00000goo00D007ooOomo
o`0000Ioo`80009oo`03001oogoo00Aoo`03001oogoo00Qoo`D000Aoo`03001oogoo00]oo`03001o
ogoo00Qoo`03001oogoo00Aoo`03001oogoo00<000Uoo`07001oogooOol007oo00002goo00<007oo
00000goo00<007ooOol01goo0`000Woo00<007ooOol017oo00<007ooOol027oo00<007ooOol02goo
00<007ooOol00Woo1@002Woo00<007ooOol017oo00<007ooOol00P001Woo00D007ooOomoo`0000=o
o`03001oo`0002Eoo`009Goo00<007oo00000goo00@007ooOomoo`8000Ioo`@000Eoo`03001oogoo
00Moo`03001oo`0000=oo`H000]oo`03001oo`0000Uoo`03001oogoo00=oo`@000=oo`03001oogoo
00Eoo`07001oogooOol007oo00003Goo00<007oo00000goo00<007ooOol01Goo00@007ooOomoo`@0
00Eoo`03001oogoo00Moo`03001oo`0000]oo`H000=oo`03001oo`0000Uoo`03001oogoo00=oo`@0
00Ioo`8000=oo`07001oogooOol007oo00009Woo000UOol00`00Ool00004Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool20005Ool00`00Oomoo`05Ool01@00Oomoogoo00001goo10001goo00D007ooOomo
o`0000Moo`03001oogoo00=oo`<000Ioo`8000Aoo`03001oogoo009oo`03001oo`0000eoo`03001o
o`0000Aoo`03001oogoo009oo`8000Ioo`<000Eoo`03001oogoo00Eoo`05001oogooOol00007Ool4
0007Ool01@00Oomoogoo00001goo00<007ooOol00goo0P0027oo00<007ooOol00Woo00<007ooOol0
0Woo00<007oo00009Woo000VOol00`00Ool00004Ool00`00Oomoo`02Ool20006Ool01000Ool00000
0goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01goo00<007oo000010000Woo00<007oo
Ool00Woo00<007ooOol017oo00@007ooOomoo`@000Uoo`04001oogoo0004Ool00`00Ool0000?Ool0
0`00Ool00004Ool01000Oomoo`002Goo10000goo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool01@0000=oo`00Ool027oo00<007ooOol00Woo00<007ooOol017oo00@007ooOomoo`800003Ool0
07oo00Eoo`8000Aoo`03001oogoo009oo`03001oo`0002Moo`009Woo00@007ooOol000Aoo`03001o
ogoo00=oo`03001oogoo00Aoo`03001oogoo0080009oo`03001oogoo009oo`03001oogoo00Aoo`03
001oogoo00Moo`03001oogoo00=oo`@000Aoo`03001oogoo009oo`03001oogoo00<00003Ool007oo
00Yoo`8000Aoo`04001oogoo000?Ool01000Oomoo`0017oo0P002goo00<007oo00000P000Woo00<0
07ooOol00Woo00<007ooOol00Woo10001Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol00P000Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00@007oo
Ool002Moo`009goo00@007ooOol000Aoo`8000Aoo`03001oogoo00=oo`03001oogoo009oo`800003
Ool007oo008000Qoo`03001oogoo00Moo`03001oogoo009oo`04001oogooOol400001Woo000007oo
001oo`<000=oo`03001oogoo00Uoo`<0009oo`04001oogoo000AOol01000Oomoo`000Woo0`002goo
00@007ooOomoo`<00003Ool007oo00800003Ool00000008000=oo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo00Ioo`800003Ool007oo008000Aoo`03001oogoo00=oo`03001oogoo009oo`80
00Aoo`04001oogoo000XOol002Moo`04001oogoo0005Ool20004Ool20004Ool00`00Oomoo`03Ool3
000;Ool00`00Oomoo`07Ool01000Oomoo`0027oo1P001Goo00<007ooOol027oo0P000goo00<007oo
00000Woo00<007ooOol03goo00H007ooOol007oo0003Ool2000:Ool00`00Oomoo`03Ool60008Ool0
1000Oomoo`002Goo00<007ooOol02Goo0`001Goo00<007ooOol00Woo0P0017oo0P001Goo00@007oo
Ool002Qoo`00:7oo00@007ooOol000Ioo`03001oogoo00=oo`05001oogooOol00006Ool40009Ool0
0`00Oomoo`07Ool01000Oomoo`002Goo20000Woo00<007ooOol01goo00<007ooOol017oo0P0000=o
o`00Ool04Woo00@007oo000000Ioo`03001oogoo00Moo`03001oogoo00P000Uoo`04001oogoo0009
Ool00`00Oomoo`07Ool40006Ool01@00Oomoogoo00001Goo00<007ooOol017oo00@007ooOol002Uo
o`00:7oo00D007ooOomoo`0000Ioo`03001oogoo00=oo`80009oo`03001oogoo009oo`03001oo`00
009oo`8000Qoo`03001oogoo00Moo`8000Qoo`<00004Ool000000003Ool40007Ool00`00Oomoo`04
Ool00`00Oomoo`02000COol20002Ool00`00Oomoo`04Ool00`00Oomoo`05Ool40003Ool3000017oo
0000000027oo0P002Goo00<007ooOol01Woo0P000Woo00<007oo000017oo00<007ooOol00P001Goo
00<007ooOol017oo00D007ooOomoo`0002Uoo`00:Goo00@007ooOol000Moo`03001oogoo00Aoo`03
001oo`0000=oo`05001oogooOol00003Ool20007Ool00`00Oomoo`06Ool20006Ool30002Ool00`00
Oomoo`020003Ool00`00Oomoo`0500000goo001oo`06Ool00`00Oomoo`03000AOol30002Ool00`00
Oomoo`05Ool00`00Ool000040002Ool01000Oomoogoo0P000Woo00<007ooOol00`001Woo0P0027oo
00<007ooOol01Goo0P000goo00D007ooOomoo`0000=oo`03001oo`0000Ioo`03001oogoo00Eoo`04
001oogoo000ZOol002Uoo`05001oogooOol00007Ool00`00Oomoo`04Ool300000goo001oo`03Ool0
0`00Oomoo`03Ool20005Ool00`00Oomoo`06Ool00`00Ool00003Ool30004Ool00`00Oomoo`02Ool0
0`00Ool00008Ool40004Ool01@00Oomoogoo00000Woo00<007ooOol03Goo00@007ooOol000=oo`03
001oogoo009oo`@000Qoo`03001oo`0000Aoo`03001oogoo009oo`<000=oo`03001oo`0000Qoo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oo`00008000Ioo`03001oogoo00Eoo`05001o
ogooOol0000ZOol002Yoo`05001oogooOol00007Ool00`00Oomoo`05Ool20006Ool00`00Oomoo`04
Ool20004Ool00`00Oomoo`04Ool01000Oomoogoo0`001Woo00<007ooOol017oo0P001goo00<007oo
Ool00Woo10000goo00<007ooOol00Woo0P002goo0P0017oo00@007ooOomoo`@000Aoo`03001oogoo
00Eoo`8000Ioo`03001oogoo00Aoo`<000=oo`03001oogoo00Aoo`03001oogoo009oo`8000Ioo`03
001oogoo00Aoo`8000Moo`03001oogoo00Eoo`05001oogooOol0000[Ool002]oo`05001oogooOol0
0007Ool00`00Oomoo`04Ool30005Ool00`00Oomoo`06Ool30002Ool00`00Oomoo`02Ool00`00Oomo
o`040007Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Ool000040005Ool0
0`00Oomoo`07Ool00`00Oomoo`03Ool500000goo001oo`06Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool40002Ool00`00Oomoo`02Ool00`00Oomoo`030008Ool00`00Oomoo`03Ool3
0006Ool00`00Oomoo`05Ool01@00Oomoogoo0000;7oo000[Ool01@00Oomoogoo000027oo00<007oo
Ool00Woo00D007oo001oo`0000Eoo`03001oogoo00Qoo`800006Ool007ooOol007oo0`000goo00<0
07ooOol00goo00<007ooOol01Goo00<007oo000017oo00<007ooOol01Woo00D007ooOomoo`00009o
o`@0009oo`8000Eoo`80009oo`@0009oo`05001oogooOol00008Ool00`00Oomoo`02Ool00`00Ool0
0007Ool00`00Oomoo`03Ool01000Oomoogoo0`0000Ioo`00Oomoo`00Ool2000:Ool00`00Oomoo`03
Ool01@00Ool007oo000017oo00<007ooOol01Woo00D007ooOomoo`0002aoo`00;7oo00D007ooOomo
o`0000Qoo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol02Woo0P000Woo0`001Woo00<0
07ooOol00Woo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo00Ioo`05001oogooOol00007
Ool50003Ool50007Ool01@00Oomoogoo000027oo00@007ooOol0009oo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo00Aoo`<0009oo`8000aoo`03001oogoo009oo`04001oogoo0002Ool01000
Oomoo`0027oo00D007ooOomoo`0002eoo`00;7oo00<007ooOol00Woo00<007ooOol01Woo0P0017oo
00<007ooOol00P000goo00<007ooOol02goo0`0027oo00D007ooOomoo`0000Moo`03001oogoo009o
o`8000Qoo`03001oogoo009oo`03001oogoo00Uoo`D000]oo`03001oogoo009oo`03001oogoo00Io
o`8000Aoo`03001oogoo00Eoo`05001oogooOol00008Ool3000=Ool01000Oomoogoo0P000Woo00<0
07ooOol00Woo0P0027oo00<007ooOol00Woo00<007ooOol0:goo000]Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool01000Ool000000goo00<007ooOol00Woo00D007ooOomoo`0000Yoo`H000Qoo`03001o
o`0000Qoo`03001oogoo009oo`<000Ioo`03001oogoo009oo`03001oogoo00Ioo`@00005Ool00000
001oo`040008Ool00`00Oomoo`02Ool00`00Oomoo`04Ool30004Ool00`00Oomoo`06Ool00`00Ool0
0008Ool6000:Ool01@00Oomoogoo000017oo00@007ooOomoo`800003Ool007oo00Eoo`03001oogoo
009oo`03001oogoo02aoo`00;Goo00<007ooOol00Woo00<007ooOol00goo00@007ooOomoo`8000=o
o`03001oogoo009oo`800003Ool007oo00Moo`800006Ool007ooOol007oo0P001goo0P001goo00<0
07ooOol00Woo00<007ooOol00P001Goo00<007ooOol00Woo00<007ooOol00Woo100017oo00D007oo
Oomoo`0000Aoo`@000Aoo`03001oogoo009oo`03001oogoo00=oo`80009oo`03001oogoo009oo`03
001oogoo00Eoo`8000Moo`800006Ool007ooOol007oo0P0027oo00@007oo000000Aoo`04001oogoo
Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0/Ool002ioo`03001oogoo009o
o`05001oogooOol00005Ool20002Ool00`00Oomoo`04Ool00`00Ool00004Ool30003Ool01000Oomo
o`000goo0`0017oo0P001goo00<007ooOol00P0017oo0P000goo00<007ooOol00Woo1P001Woo0P00
1Goo0P001Woo1P0017oo00@007ooOomoo`8000Aoo`80009oo`03001oogoo00Eoo`8000Aoo`<000=o
o`04001oogoo0003Ool30004Ool00`00Ool00006Ool00`00Oomoo`020005Ool01@00Oomoogoo0000
17oo00<007ooOol0;Goo000^Ool00`00Oomoo`03Ool00`00Ool00008Ool00`00Ool00007Ool20002
Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20002Ool00`00Ool00006Ool00`00Ool00007
Ool2000017oo001oogoo10002Woo00<007ooOol01goo00<007ooOol027oo10000Woo00@007oo0000
00Moo`03001oo`0000Ioo`03001oo`00009oo`8000Eoo`03001oogoo009oo`03001oogoo009oo`<0
009oo`8000Moo`03001oo`0000Qoo`03001oo`0000Eoo`03001oogoo02eoo`00;goo00<007ooOol0
0Woo0P002Woo00<007oo000027oo0`001Goo00<007ooOol017oo00<007ooOol017oo0P000goo00<0
07ooOol00Woo00<007oo00002Goo1@000Woo00<007ooOol01goo0P002goo0P002Goo00<007ooOol0
1@002Goo00<007oo000017oo00@007ooOomoo`8000Ioo`03001oogoo00Aoo`03001oogoo00=oo`<0
00Qoo`03001oo`0000Yoo`8000Aoo`03001oogoo02ioo`00;goo00<007ooOol00Woo0P002goo0P00
1Woo1@0017oo00<007ooOol01Woo00<007ooOol017oo0`000Woo00@007ooOomoo`8000Ioo`L000Ao
o`03001oogoo00Ioo`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo009oo`L000Ioo`8000=o
o`03001oogoo00<000Ioo`03001oogoo00Ioo`03001oogoo009oo`D000Ioo`8000]oo`8000Aoo`03
001oogoo02ioo`00<7oo00@007ooOol0009oo`03001oogoo00Uoo`8000=oo`8000=oo`03001oo`00
00=oo`03001oogoo00Ioo`03001oogoo00=oo`04001oogooOol200000goo001oo`020003Ool40004
Ool01000Oomoo`000Woo00<007ooOol01Goo0P004Goo0P001goo00@007ooOol0009oo`03001oogoo
009oo`@000=oo`800003Ool007oo008000=oo`03001oogoo00=oo`03001oogoo00Ioo`07001oogoo
Ool007oo00000goo0P000goo0P002goo00@007ooOol0009oo`03001oogoo02moo`00<Goo0P0017oo
00<007ooOol02Goo00@007oo000000Eoo`06001oogoo001oo`002Woo00<007ooOol00Woo00<007oo
Ool00goo0P0000=oo`0000000`001goo00<007ooOol00Woo0P001goo00<007ooOol04goo00<007oo
Ool01Goo0P0017oo00<007ooOol01Goo1@0000=oo`0000001Goo00<007ooOol00Woo00<007ooOol0
27oo00<007oo00000Woo00<007ooOol00goo0P0000=oo`00Ool02Woo00<007ooOol00Woo0P00<Woo
000aOol00`00Oomoo`03Ool00`00Oomoo`08Ool30008Ool00`00Oomoo`02000;Ool01000Oomoo`00
1Goo1P002Woo00<007ooOol00goo00<007ooOol00goo0P005goo0P001Goo00<007ooOol00goo00<0
07ooOol027oo1P001Goo00@007ooOol000]oo`80009oo`03001oogoo00Ioo`<000Yoo`03001oogoo
00=oo`03001oogoo031oo`00<7oo00<007oo00001Goo00<007ooOol01Goo0`0000=oo`0000001goo
00H007ooOol007oo000:Ool01@00Oomoo`00Ool010000Woo0`0000=oo`0000001goo00<007ooOol0
0goo00<007oo00000goo00<007ooOol06Goo00L007ooOomoo`00Ool00005Ool00`00Oomoo`05Ool2
000017oo000000000Woo100000Eoo`00Oomoo`0000Yoo`03001oo`00009oo`03001oogoo00Eoo`80
0004Ool000000007Ool00`00Oomoo`03Ool00`00Ool0000aOol002ioo`80009oo`03001oogoo00Ao
o`03001oogoo009oo`<000Aoo`8000Moo`8000=oo`8000Uoo`@000Eoo`80009oo`03001oogoo0080
00Aoo`03001oogoo00Aoo`03001oogoo00<001eoo`<0009oo`03001oogoo00Aoo`03001oogoo009o
o`80009oo`03001oogoo008000Eoo`@000Uoo`8000=oo`8000Moo`8000Aoo`<000Aoo`03001oogoo
00Aoo`03001oogoo008002moo`00;Goo00<007ooOol00goo00<007ooOol017oo00@007oo000000Mo
o`04001oo`000005Ool20005Ool01000Oomoogoo1`001Woo00<007oo00000goo00@007ooOomoo`80
0003Ool007oo00Eoo`04001oogooOol3000MOol30003Ool00`00Oomoo`04Ool01000Ool000000goo
00L007ooOomoo`00Ool00006Ool70003Ool00`00Oomoo`03Ool20005Ool200000goo001oo`06Ool2
00000goo001oo`05Ool00`00Oomoo`03Ool00`00Oomoo`0/Ool002aoo`03001oogoo00Aoo`03001o
ogoo00Aoo`8000Uoo`03001oogoo008000=oo`03001oo`0000Eoo`@000Eoo`03001oo`0000Aoo`04
001oogoo0004Ool00`00Oomoo`02Ool20006Ool01000Oomoo`000Woo0P006goo0P000Woo00@007oo
Ool000Ioo`8000Aoo`03001oogoo009oo`04001oogoo0004Ool00`00Ool00005Ool40005Ool00`00
Ool00003Ool20002Ool00`00Oomoo`07Ool20006Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool002]o
o`03001oogoo00Ioo`03001oogoo00<00003Ool007oo00Uoo`03001oogoo0080009oo`03001oogoo
00D000=oo`03001oogoo009oo`04001oogoo0002Ool20002Ool00`00Oomoo`04Ool01P00Oomoogoo
001oo`<0009oo`04001oo`000004Ool2000IOol20004Ool2000017oo001oogoo0`0000=oo`00Ool0
0Woo00<007ooOol017oo00<007ooOol00P000Woo00@007ooOol000Aoo`04001oogooOol50002Ool0
0`00Oomoo`020002Ool00`00Oomoo`08Ool00`00Ool000020002Ool00`00Oomoo`06Ool00`00Oomo
o`0ZOol002Yoo`03001oogoo00Moo`@000Aoo`03001oogoo00Moo`03001oogoo009oo`H000Qoo`80
009oo`04001oogooOol20004Ool00`00Oomoo`05Ool00`00Ool00005Ool40007Ool2000GOol20007
Ool40005Ool00`00Ool00007Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`020008Ool60004Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool40009Ool00`00Oomoo`0YOol002Uoo`03001oogoo00Moo`<0
00Ioo`03001oogoo00Qoo`H000Aoo`03001oogoo00Moo`8000Aoo`8000=oo`03001oogoo00Ioo`03
001oo`0000Ioo`<000Qoo`8001Eoo`8000Qoo`<000Ioo`03001oo`0000Qoo`04001oogooOol20004
Ool20009Ool00`00Oomoo`02Ool6000:Ool00`00Oomoo`04Ool30009Ool00`00Oomoo`0XOol002Qo
o`03001oogoo00Ioo`80009oo`03001oogoo00Eoo`03001oogoo00=oo`D0009oo`04001oogoo0003
Ool00`00Oomoo`08Ool20002Ool01000Oomoo`000Woo00<007ooOol01goo00<007ooOol017oo0P00
0Woo0P0027oo00<007ooOol04Goo00<007ooOol01Woo0P000Woo0P001Woo00<007ooOol01goo00@0
07ooOol0009oo`03001oogoo008000Yoo`05001oogooOol00002Ool00`00Oomoo`050005Ool00`00
Oomoo`05Ool00`00Oomoo`020008Ool00`00Oomoo`0WOol002Moo`03001oogoo00Eoo`8000Eoo`03
001oogoo00Eoo`D000Eoo`03001oo`0000=oo`05001oogooOol00008Ool00`00Oomoo`020003Ool0
0`00Ool00009Ool00`00Ool00003Ool30005Ool20007Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool2
0005Ool30003Ool00`00Ool00009Ool00`00Ool00003Ool20002Ool00`00Oomoo`06Ool01@00Oomo
ogoo00000goo00<007oo00001Goo1@001goo00<007ooOol00goo0P001goo00<007ooOol09Woo000V
Ool00`00Oomoo`04Ool20008Ool01000Oomoogoo1@0027oo0P001Goo00@007ooOol000Qoo`03001o
ogoo008000Aoo`8000Qoo`09001oogooOol007oo001oo`0000Qoo`8000Ioo`03001oogoo00eoo`03
001oogoo00Aoo`8000Qoo`05001oo`00Ool00003Ool00`00Oomoo`06Ool20004Ool20002Ool00`00
Oomoo`06Ool01000Oomoo`001Goo0P0027oo1@000goo00<007ooOol01Woo0P001Woo00<007ooOol0
9Goo000LOol6O003Ool00`00Oomoo`02Ool30009Ool50004Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool01000Oomoo`001Woo00@007ooOol0009oo`8000=oo`03001oogoo00Ioo`04001oogooOol20002
Ool00`00Oomoo`08Ool30004Ool01000Oomoogoo1W`017oo00<007ooOol00Woo0`002Woo00<007oo
Ool00P000goo00<007ooOol01Woo00@007ooOomoo`80009oo`04001oogoo0006Ool01000Oomoo`00
1goo00<007ooOol01Woo00<007ooOol00Woo1@002Goo0`0017oo00@007ooOomoo`Il01eoo`006goo
27`00P000goo0`001goo10000Woo00<007ooOol01Goo00<007ooOol01Goo0P001goo00<007oo0000
1Woo00<007oo00001Goo00@007oo000000Moo`05001oogooOol00002Ool2000>Ool20003Ool20008
O0000goo00000003Ool2000>Ool20002Ool01@00Oomoogoo00001goo0P0000=oo`00Ool017oo00<0
07oo00001Woo00<007oo00001goo0P001goo00<007ooOol01Goo00<007ooOol010001goo0`000goo
0P0027`077oo000JOol:O002Ool20006Ool40006Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00
Ool00008Ool00`00Ool00004Ool00`00Ool00007Ool200000goo001oo`04Ool00`00Oomoo`020004
Ool00`00Oomoo`0>Ool20002Ool:O0000`00Oomoo`02000@Ool00`00Oomoo`02Ool20002Ool00`00
Oomoo`03Ool01000Ool000001goo00<007oo000017oo00<007oo000027oo00<007oo00001Goo00<0
07ooOol01Woo00<007ooOol017oo10001Woo0P000Woo2W`06goo000IOol<O0001000Oomoogoo1@00
2goo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Qoo`<0009oo`03001oo`0000Qo
o`05001oo`00Ool00004Ool00`00Ool00005Ool00`00Ool0000AOol00`00O01l000:O002000AOol0
0`00Ool00005Ool00`00Ool00004Ool01@00Ool007oo000027oo00<007oo00000Woo0`0027oo00D0
07ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo00Uoo`D000=oo`03001l07`000Yl01Yoo`00
67oo3G`0100047oo00<007ooOol01Woo00@007ooOol000Aoo`03001oogoo00Moo`80009oo`8000Uo
o`03001oogoo00<0009oo`03001oo`0000Ioo`03001oo`00015oo`el01=oo`03001oo`0000Ioo`03
001oo`00009oo`<0009oo`03001oogoo00Moo`80009oo`8000Uoo`03001oogoo009oo`04001oogoo
0008Ool00`00Oomoo`0>Ool3000=O00JOol001Qoo`il01Aoo`03001oogoo00Ioo`03001oo`0000Eo
o`03001oogoo00Moo`@000Uoo`03001oogoo00=oo`03001oo`00008000Ioo`05001oogooOol0000@
Ool>O00AOol01@00Oomoogoo00001Woo0`0000=oo`00Ool017oo00<007ooOol01goo10002Goo00<0
07ooOol00goo00<007oo000027oo00<007ooOol04Woo3W`06Goo000HOol>O01R000>O01S000>O00I
Ool001Qoo`il01Eoo`03001oogoo00Eoo`8000Moo`03001oogoo00Ioo`@000Qoo`03001oogoo00Ao
o`@000Ioo`03001oogoo00Aoo`03001oogoo00aoo`il00moo`03001oogoo00Aoo`03001oogoo00Ao
o`@000Ioo`03001oogoo00Ioo`@000Qoo`03001oogoo00Eoo`8000Moo`03001oogoo01=oo`il01Uo
o`0067oo3W`00`004Woo00<007ooOol017oo00@007ooOol000Ioo`03001oogoo00Eoo`06001oo`00
001oo`001goo00<007ooOol00goo0P000Woo0P001Goo00<007ooOol01Goo00<007ooOol02goo3W`0
3Woo00<007ooOol01Goo00<007ooOol00goo0P000Woo0P001Goo00<007ooOol01Goo00H007oo0000
07oo0007Ool00`00Oomoo`04Ool01000Oomoo`001Woo00<007ooOol047oo0`003W`06Goo000HOol=
O0001000Oomoogoo1@003Woo00<007ooOol00goo00D007ooOomoo`0000Eoo`03001oogoo00Aoo`03
001oo`00009oo`03001oo`0000Ioo`04001oogooOol30003Ool01000Ool000000Woo00<007ooOol0
1goo00<007ooOol02Woo3G`00P0037oo00<007ooOol01goo00<007ooOol00P0000=oo`00Ool00Woo
0`000goo00<007ooOol017oo00<007oo00000Woo00<007oo00001Woo00<007ooOol00goo00D007oo
Oomoo`0000Eoo`03001oogoo00aoo`D000=oo`el01Yoo`006Goo37`000=oo`0000001Woo10002goo
00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`0017oo00L007ooOomoo`00Ool00005Ool00`00Oomoo`02000;Ool00`00Oomoo`07Ool200000goo
O01l000:O002Ool20009Ool00`00Oomoo`09Ool20002Ool00`00Oomoo`03Ool00`00Ool00003Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00=o
o`05001oogooOol0000;Ool40006Ool200000gooO01l000:O00JOol001Yoo`Yl0004Ool00000Ool2
0008Ool40007Ool01000Oomoo`001Woo00<007ooOol00goo00D007ooOomoo`00009oo`03001oogoo
009oo`04001oogoo0003Ool01000Ool000000Woo00<007ooOol017oo00<007ooOol00P002goo00<0
07ooOol017oo0P0017oo2W`000<007ooOol00Woo0P001Woo00<007ooOol02Goo0P000Woo00<007oo
Ool017oo00<007ooOol00P0000=oo`00Ool00Woo00@007ooOol000Aoo`04001oogoo0003Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool01000Oomoo`001goo100027oo0P0000Aoo`00001oo`Yl01]oo`00
6goo27`000Eoo`00001oo`00009oo`<000Uoo`D000=oo`03001oo`0000Moo`03001oogoo00=oo`03
001oo`00009oo`03001oogoo00Aoo`08001oogoo001oo`00Ool000=oo`03001oogoo00Eoo`03001o
o`00009oo`03001oogoo00Qoo`04001oogooOol30004Ool200000gooO01l0006O0001000Ool00000
17oo0`000goo00<007ooOol027oo00H007ooOol007oo0007Ool02@00Oomoogoo001oo`00Ool00002
Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000Eoo`03001oogoo00Eoo`03001oo`0000=oo`D000Uo
o`<0009oo`05001oo`00001oo`08O00LOol001aoo`Il0007Ool007ooOol007oo000017oo0P0037oo
1@002Goo00<007ooOol00Woo0P000goo00<007ooOol017oo00@007ooOomoo`<000=oo`03001oogoo
00Moo`8000=oo`8000Uoo`<000Ioo`800003Ool007oo00Il009oo`04001oo`000006Ool30009Ool2
0003Ool20009Ool01000Oomoogoo0`000goo00<007ooOol017oo00@007ooOomoo`8000Aoo`03001o
ogoo00Moo`D000aoo`8000Aoo`03001oo`00009oo`03001oog`000El01eoo`0097oo00D007ooOol0
07oo008000Aoo`8000eoo`D000Ioo`03001oogoo009oo`80009oo`03001oogoo00Ioo`03001oogoo
00<000=oo`03001oogoo00Moo`8000Eoo`03001oogoo00Eoo`<000Ioo`800003Ool007oo00Yoo`04
001oo`000006Ool30007Ool00`00Oomoo`03Ool20009Ool01000Oomoogoo0`000Woo00<007ooOol0
1Woo00<007ooOol00P0017oo00<007ooOol017oo1@003Goo0P0017oo0P0000Eoo`00Oomoo`0002Eo
o`009Goo00@007ooOol0009oo`03001oogoo00=oo`8000Yoo`03001oo`0000=oo`D0009oo`06001o
ogoo001oo`000Woo00<007ooOol01Woo100000Eoo`00001oo`0000Yoo`03001oo`0000Eoo`8000=o
o`8000=oo`03001oogoo009oo`800003Ool007oo00aoo`04001oo`000004Ool01000Oomoogoo0P00
0goo0P001Goo00<007oo00002Woo00D007oo000007oo00@000Qoo`06001oogoo001oo`000Woo00<0
07ooOol01@000goo00<007oo00002Woo0P001Goo00@007ooOol0009oo`03001oogoo02Aoo`009Goo
00D007ooOomoo`00009oo`8000Eoo`8000Qoo`04001oogoo0007Ool50002Ool00`00Ool00009Ool2
000017oo001oogoo0P002Woo00@007ooOol000Moo`<000Ioo`03001oogoo0080009oo`03001oogoo
00]oo`03001oogoo0080009oo`03001oogoo00Aoo`<000Moo`04001oogoo000:Ool20002Ool01000
Ool000002Goo00<007oo00000Woo1@001goo00@007ooOol000Qoo`8000Eoo`80009oo`05001oogoo
Ool0000VOol002Ioo`05001oogooOol00003Ool00`00Oomoo`04Ool20005Ool01@00Oomoogoo0000
2Woo1`0027oo00@007oo000000=oo`<000Uoo`05001oogooOol00005Ool30008Ool30002Ool00`00
Oomoo`0=Ool00`00Oomoo`030008Ool30005Ool01@00Oomoogoo00002Goo0`000goo0P0000=oo`00
Ool01goo1`002Woo00D007ooOomoo`0000Eoo`8000Ioo`05001oogooOol00003Ool00`00Oomoo`0U
Ool002Moo`05001oogooOol00003Ool20006Ool300000goo001oo`04Ool00`00Oomoo`05Ool20000
0goo001oo`02Ool50003Ool20003Ool01P00Oomoogoo001oo`8000Moo`03001oogoo00=oo`03001o
o`00008000=oo`8000Ioo`80009oo`03001oogoo00moo`03001oogoo008000Ioo`8000=oo`<00003
Ool007oo00Aoo`03001oogoo00Eoo`800003Ool007oo009oo`04001oogooOol20003Ool50003Ool0
1000Ool000001goo00<007ooOol00goo00<007oo00000P001Woo0P000goo00D007ooOomoo`0002Qo
o`009goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Woo0P001Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00P000goo10000goo0P000Woo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol00goo0P0027oo00<007ooOol00Woo00H007ooOol007oo000AOol00`00Ool00002
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`020003Ool40003Ool20002Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool2
0008Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0VOol002Qoo`03001oogoo009oo`03
001oogoo009oo`8000Ioo`04001oo`000004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool200000goo
001oo`02Ool20002Ool70006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool200000goo001oo`08Ool2
00000goo001oo`02Ool2000COol20003Ool01000Ool000002Goo00@007oo000000Aoo`03001oogoo
009oo`03001oogoo00Aoo`L0009oo`8000=oo`04001oo`000006Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool200000goo001oo`05Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0WOol002Uoo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`8000=oo`04001oogoo0008
Ool01P00Oomoo`00Ool000Ioo`03001oogoo00@000Eoo`04001oogoo0003Ool20004Ool00`00Oomo
o`08Ool00`00Oomoo`02Ool2000COol20004Ool00`00Oomoo`08Ool00`00Oomoo`02Ool20003Ool0
1000Oomoo`001Goo10000Woo00<007ooOol017oo00<007oo00000Woo00<007ooOol01Woo00@007oo
Ool000=oo`8000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo02Qo
o`00:Woo00<007ooOol00Woo00<007ooOol00goo0P0000=oo`00Ool01Woo0P0000Aoo`00Ool000Qo
o`80009oo`8000Moo`03001oogoo0080009oo`@0009oo`04001oo`00Ool20007Ool00`00Oomoo`06
Ool01P00Ool00000Ool0009oo`03001oogoo00moo`05001oogoo001oo`0200000goo001oo`07Ool0
0`00Oomoo`05Ool2000017oo001oo`000Woo10000Woo0P000Woo00<007ooOol01Goo0P000Woo0P00
27oo00@007oo001oo`8000Moo`04001oo`000005Ool00`00Oomoo`02Ool00`00Oomoo`0YOol002Yo
o`03001oogoo00=oo`8000Eoo`8000Uoo`<000Qoo`03001oogoo00800003Ool007oo00Eoo`04001o
ogoo0002Ool00`00Oomoo`03Ool60009Ool00`00Oomoo`04Ool20004Ool20003Ool00`00Oomoo`0=
Ool01000Oomoogoo0P0017oo0P001Woo00<007ooOol01goo1P001Goo00@007ooOol0009oo`03001o
ogoo00Aoo`04001oo`000002Ool00`00Oomoo`06Ool30009Ool20005Ool20005Ool00`00Oomoo`0Y
Ool002]oo`03001oogoo00Aoo`03001oogoo009oo`8000Yoo`@000Ioo`03001oo`0000800003Ool0
07oo00Eoo`03001oo`0000=oo`03001oogoo00Aoo`P000Moo`03001oogoo009oo`8000Eoo`<000=o
o`03001oogoo00]oo`04001oogooOol30005Ool20004Ool00`00Oomoo`05Ool80006Ool01`00Oomo
ogoo001oo`0000Ioo`03001oo`0000800003Ool007oo00Eoo`@000Yoo`8000Aoo`03001oogoo00Ao
o`03001oogoo02Yoo`00;7oo00<007ooOol017oo00@007ooOol0009oo`8000Moo`05001oogoo001o
o`020003Ool00`00Ool00002Ool00`00Ool00006Ool00`00Ool00004Ool01000Oomoogoo0P0000Ao
o`00Oomoo`80009oo`@000Aoo`03001oogoo008000Eoo`05001oogooOol00003Ool00`00Oomoo`09
Ool01@00Oomoogoo00000goo00<007ooOol00goo0P000Woo00<007ooOol00Woo10000Woo0P000Woo
00@007oo000000=oo`03001oogoo009oo`03001oo`0000Ioo`03001oo`00009oo`03001oo`0000=o
o`800005Ool007ooOol00007Ool20002Ool01000Oomoo`001Woo00<007ooOol0:goo000]Ool00`00
Oomoo`04Ool20005Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo0P0000=oo`00000017oo00<0
07oo000017oo00<007oo00001Goo00@007oo000000=oo`04001oogooOol20005Ool80005Ool00`00
Oomoo`03Ool20002Ool00`00Oomoo`07Ool00`00Oomoo`020005Ool00`00Oomoo`03Ool80005Ool2
0003Ool01000Oomoogoo0P0000=oo`00Ool017oo00<007oo000017oo00<007oo000017oo0P0000=o
o`0000000goo00D007ooOomoo`0000Eoo`03001oogoo00=oo`8000Ioo`03001oogoo02aoo`00;Goo
00<007ooOol01Goo00<007ooOol017oo0P000Woo00<007ooOol00goo00<007ooOol00Woo0P001Woo
0P0017oo0P001Woo0P0017oo00<007ooOol00goo0P002Goo100017oo00<007ooOol01Goo00@007oo
Ool000Moo`04001oogoo0007Ool00`00Oomoo`02Ool40009Ool20005Ool00`00Oomoo`02Ool20006
Ool20004Ool20006Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`020006Ool00`00Oomoo`05Ool0
0`00Oomoo`0/Ool002ioo`03001oogoo00=oo`03001oo`0000Moo`8000Ioo`04001oogooOol20000
0goo00000005Ool20002Ool20005Ool200000goo001oo`03Ool00`00Oomoo`04Ool20007Ool30002
Ool40009Ool00`00Ool00007Ool00`00Ool00009Ool40002Ool30007Ool20006Ool00`00Oomoo`02
Ool01000Ool000001Goo0P000Woo0P001Goo0P0000=oo`0000000goo00<007ooOol017oo0P001goo
00<007oo00001Goo00<007ooOol0;Goo000_Ool01@00Oomoogoo00000goo00<007ooOol00goo1000
1Woo100017oo0`000Woo0P000Woo0P000Woo0`0017oo00@007ooOol000Qoo`8000Eoo`05001oogoo
Ool00003Ool00`00Ool000040005Ool30005Ool30005Ool500000goo001oo`02Ool01@00Oomoogoo
00001Goo0P0027oo00@007ooOol000Aoo`<0009oo`80009oo`80009oo`<000Aoo`@000Ioo`@000Eo
o`05001oogooOol00003Ool00`00Oomoo`0^Ool002moo`04001oogoo0005Ool01@00Oomoogoo0000
17oo00<007ooOol00goo00@007ooOol000Moo`800003Ool0000000800003Ool0000000Moo`04001o
ogoo000:Ool01@00Oomoogoo00001Goo00@007ooOol000Ioo`@000=oo`8000=oo`8000=oo`@000Io
o`04001oogoo0005Ool01@00Oomoogoo00002Woo00@007ooOol000Moo`800003Ool0000000800003
Ool0000000Moo`04001oogoo0005Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00@007ooOol0
031oo`00<7oo00<007oo00001Woo00<007oo00001Woo0P0000Aoo`00001oo`8000Yoo`H000Yoo`80
00aoo`03001oo`0000Ioo`03001oo`0000]oo`H00003Ool0000000@000]oo`03001oo`0000Ioo`03
001oo`0000aoo`8000Yoo`H000Yoo`800004Ool00000Ool20006Ool00`00Ool00006Ool00`00Ool0
000aOol0035oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Yoo`80
00aoo`03001oogoo00aoo`03001oogoo00Ioo`03001oogoo00ioo`D0011oo`03001oogoo00Ioo`03
001oogoo00aoo`03001oogoo00Yoo`8000aoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo
00Ioo`03001oogoo031oo`00<7oo00<007oo00001Woo00<007oo00001Woo0P0000Aoo`00001oo`80
00Yoo`H000Yoo`8000aoo`03001oo`0000Ioo`03001oo`0000]oo`H00003Ool0000000@000]oo`03
001oo`0000Ioo`03001oo`0000aoo`8000Yoo`H000Yoo`800004Ool00000Ool20006Ool00`00Ool0
0006Ool00`00Ool0000aOol002moo`04001oogoo0005Ool01@00Oomoogoo000017oo00<007ooOol0
0goo00@007ooOol000Moo`800003Ool0000000800003Ool0000000Moo`04001oogoo000:Ool01@00
Oomoogoo00001Goo00@007ooOol000Ioo`@000=oo`8000=oo`8000=oo`@000Ioo`04001oogoo0005
Ool01@00Oomoogoo00002Woo00@007ooOol000Moo`800003Ool0000000800003Ool0000000Moo`04
001oogoo0005Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00@007ooOol0031oo`00;goo00D0
07ooOomoo`0000=oo`03001oogoo00=oo`@000Ioo`@000Aoo`<0009oo`80009oo`80009oo`<000Ao
o`04001oogoo0008Ool20005Ool01@00Oomoogoo00000goo00<007oo000010001Goo0`001Goo0`00
1Goo1@0000=oo`00Ool00Woo00D007ooOomoo`0000Eoo`8000Qoo`04001oogoo0004Ool30002Ool2
0002Ool20002Ool30004Ool40006Ool40005Ool01@00Oomoogoo00000goo00<007ooOol0;Woo000^
Ool00`00Oomoo`03Ool00`00Ool00007Ool20006Ool01000Oomoogoo0P0000=oo`0000001Goo0P00
0Woo0P001Goo0P0000=oo`00Ool00goo00<007ooOol017oo0P001goo0`000Woo10002Goo00<007oo
00001goo00<007oo00002Goo10000Woo0`001goo0P001Woo00<007ooOol00Woo00@007oo000000Eo
o`80009oo`8000Eoo`800003Ool0000000=oo`03001oogoo00Aoo`8000Moo`03001oo`0000Eoo`03
001oogoo02eoo`00;Goo00<007ooOol01Goo00<007ooOol017oo0P000Woo00<007ooOol00goo00<0
07ooOol00Woo0P001Woo0P0017oo0P001Woo0P0017oo00<007ooOol00goo0P002Goo100017oo00<0
07ooOol01Goo00@007ooOol000Moo`04001oogoo0007Ool00`00Oomoo`02Ool40009Ool20005Ool0
0`00Oomoo`02Ool20006Ool20004Ool20006Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`020006
Ool00`00Oomoo`05Ool00`00Oomoo`0/Ool002eoo`03001oogoo00Aoo`8000Eoo`03001oogoo00=o
o`05001oogooOol00003Ool200000goo00000004Ool00`00Ool00004Ool00`00Ool00005Ool01000
Ool000000goo00@007ooOomoo`8000Eoo`P000Eoo`03001oogoo00=oo`80009oo`03001oogoo00Mo
o`03001oogoo008000Eoo`03001oogoo00=oo`P000Eoo`8000=oo`04001oogooOol200000goo001o
o`04Ool00`00Ool00004Ool00`00Ool00004Ool200000goo00000003Ool01@00Oomoogoo00001Goo
00<007ooOol00goo0P001Woo00<007ooOol0;7oo000/Ool00`00Oomoo`04Ool01000Oomoo`000Woo
0P001goo00D007ooOol007oo008000=oo`03001oo`00009oo`03001oo`0000Ioo`03001oo`0000Ao
o`04001oogooOol2000017oo001oogoo0P000Woo100017oo00<007ooOol00P001Goo00D007ooOomo
o`0000=oo`03001oogoo00Uoo`05001oogooOol00003Ool00`00Oomoo`03Ool20002Ool00`00Oomo
o`02Ool40002Ool20002Ool01000Ool000000goo00<007ooOol00Woo00<007oo00001Woo00<007oo
00000Woo00<007oo00000goo0P0000Eoo`00Oomoo`0000Moo`80009oo`04001oogoo0006Ool00`00
Oomoo`0[Ool002]oo`03001oogoo00Aoo`03001oogoo009oo`8000Yoo`@000Ioo`03001oo`000080
0003Ool007oo00Eoo`03001oo`0000=oo`03001oogoo00Aoo`P000Moo`03001oogoo009oo`8000Eo
o`<000=oo`03001oogoo00]oo`04001oogooOol30005Ool20004Ool00`00Oomoo`05Ool80006Ool0
1`00Oomoogoo001oo`0000Ioo`03001oo`0000800003Ool007oo00Eoo`@000Yoo`8000Aoo`03001o
ogoo00Aoo`03001oogoo02Yoo`00:Woo00<007ooOol00goo0P001Goo0P002Goo0`0027oo00<007oo
Ool00P0000=oo`00Ool01Goo00@007ooOol0009oo`03001oogoo00=oo`H000Uoo`03001oogoo00Ao
o`8000Aoo`8000=oo`03001oogoo00eoo`04001oogooOol20004Ool20006Ool00`00Oomoo`07Ool6
0005Ool01000Oomoo`000Woo00<007ooOol017oo00@007oo0000009oo`03001oogoo00Ioo`<000Uo
o`8000Eoo`8000Eoo`03001oogoo02Uoo`00:Woo00<007ooOol00Woo00<007ooOol00goo0P0000=o
o`00Ool01Woo0P0000Aoo`00Ool000Qoo`80009oo`8000Moo`03001oogoo0080009oo`@0009oo`04
001oo`00Ool20007Ool00`00Oomoo`06Ool01P00Ool00000Ool0009oo`03001oogoo00moo`05001o
ogoo001oo`0200000goo001oo`07Ool00`00Oomoo`05Ool2000017oo001oo`000Woo10000Woo0P00
0Woo00<007ooOol01Goo0P000Woo0P0027oo00@007oo001oo`8000Moo`04001oo`000005Ool00`00
Oomoo`02Ool00`00Oomoo`0YOol002Uoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo009oo`8000=oo`04001oogoo0008Ool01P00Oomoo`00Ool000Ioo`03001oogoo00@0
00Eoo`04001oogoo0003Ool20004Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000COol20004Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool20003Ool01000Oomoo`001Goo10000Woo00<007ooOol017oo
00<007oo00000Woo00<007ooOol01Woo00@007ooOol000=oo`8000Aoo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo02Qoo`00:7oo00<007ooOol00Woo00<007ooOol00Woo
0P001Woo00@007oo000000Aoo`03001oogoo009oo`03001oogoo00Aoo`800003Ool007oo009oo`80
009oo`L000Ioo`03001oogoo009oo`03001oogoo009oo`800003Ool007oo00Qoo`800003Ool007oo
009oo`8001=oo`8000=oo`04001oo`000009Ool01000Ool0000017oo00<007ooOol00Woo00<007oo
Ool017oo1`000Woo0P000goo00@007oo000000Ioo`03001oogoo009oo`03001oogoo009oo`800003
Ool007oo00Eoo`8000Aoo`03001oogoo009oo`03001oogoo02Moo`009goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol01Woo0P001Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0
0P000goo10000goo0P000Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00goo0P0027oo
00<007ooOol00Woo00H007ooOol007oo000AOol00`00Ool00002Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`020003Ool40003Ool20002
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool20008Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`0VOol002Moo`05001oogooOol00003Ool20006Ool300000goo001oo`04
Ool00`00Oomoo`05Ool200000goo001oo`02Ool50003Ool20003Ool01P00Oomoogoo001oo`8000Mo
o`03001oogoo00=oo`03001oo`00008000=oo`8000Ioo`80009oo`03001oogoo00moo`03001oogoo
008000Ioo`8000=oo`<00003Ool007oo00Aoo`03001oogoo00Eoo`800003Ool007oo009oo`04001o
ogooOol20003Ool50003Ool01000Ool000001goo00<007ooOol00goo00<007oo00000P001Woo0P00
0goo00D007ooOomoo`0002Qoo`009Woo00D007ooOomoo`0000=oo`03001oogoo00Aoo`8000Eoo`05
001oogooOol0000:Ool70008Ool01000Ool000000goo0`002Goo00D007ooOomoo`0000Eoo`<000Qo
o`<0009oo`03001oogoo00eoo`03001oogoo00<000Qoo`<000Eoo`05001oogooOol00009Ool30003
Ool200000goo001oo`07Ool7000:Ool01@00Oomoogoo00001Goo0P001Woo00D007ooOomoo`0000=o
o`03001oogoo02Eoo`009Goo00D007ooOomoo`00009oo`8000Eoo`8000Qoo`04001oogoo0007Ool5
0002Ool00`00Ool00009Ool2000017oo001oogoo0P002Woo00@007ooOol000Moo`<000Ioo`03001o
ogoo0080009oo`03001oogoo00]oo`03001oogoo0080009oo`03001oogoo00Aoo`<000Moo`04001o
ogoo000:Ool20002Ool01000Ool000002Goo00<007oo00000Woo1@001goo00@007ooOol000Qoo`80
00Eoo`80009oo`05001oogooOol0000VOol002Eoo`04001oogoo0002Ool00`00Oomoo`03Ool2000:
Ool00`00Ool00003Ool50002Ool01P00Oomoo`00Ool0009oo`03001oogoo00Ioo`@00005Ool00000
Ool0000:Ool00`00Ool00005Ool20003Ool20003Ool00`00Oomoo`02Ool200000goo001oo`0<Ool0
1000Ool0000017oo00@007ooOomoo`8000=oo`8000Eoo`03001oo`0000Yoo`05001oo`00001oo`04
0008Ool01P00Oomoo`00Ool0009oo`03001oogoo00D000=oo`03001oo`0000Yoo`8000Eoo`04001o
ogoo0002Ool00`00Oomoo`0TOol002Aoo`05001oogoo001oo`020004Ool2000=Ool50006Ool00`00
Oomoo`02Ool20002Ool00`00Oomoo`06Ool00`00Oomoo`030003Ool00`00Oomoo`07Ool20005Ool0
0`00Oomoo`05Ool30006Ool200000goo001oo`0:Ool01000Ool000001Woo0`001goo00<007ooOol0
0goo0P002Goo00@007ooOomoo`<0009oo`03001oogoo00Ioo`03001oogoo008000Aoo`03001oogoo
00Aoo`D000eoo`8000Aoo`800005Ool007ooOol0000UOol001aoo`Il0007Ool007ooOol007oo0000
17oo0P0037oo1@002Goo00<007ooOol00Woo0P000goo00<007ooOol017oo00@007ooOomoo`<000=o
o`03001oogoo00Moo`8000=oo`8000Uoo`<000Ioo`800003Ool007oo00Il009oo`04001oo`000006
Ool30009Ool20003Ool20009Ool01000Oomoogoo0`000goo00<007ooOol017oo00@007ooOomoo`80
00Aoo`03001oogoo00Moo`D000aoo`8000Aoo`03001oo`00009oo`03001oog`000El01eoo`006goo
27`000Eoo`00001oo`00009oo`<000Uoo`D000=oo`03001oo`0000Moo`03001oogoo00=oo`03001o
o`00009oo`03001oogoo00Aoo`08001oogoo001oo`00Ool000=oo`03001oogoo00Eoo`03001oo`00
009oo`03001oogoo00Qoo`04001oogooOol30004Ool200000gooO01l0006O0001000Ool0000017oo
0`000goo00<007ooOol027oo00H007ooOol007oo0007Ool02@00Oomoogoo001oo`00Ool00002Ool0
0`00Oomoo`04Ool01P00Oomoo`00Ool000Eoo`03001oogoo00Eoo`03001oo`0000=oo`D000Uoo`<0
009oo`05001oo`00001oo`08O00LOol001Yoo`Yl0004Ool00000Ool20008Ool40007Ool01000Oomo
o`001Woo00<007ooOol00goo00D007ooOomoo`00009oo`03001oogoo009oo`04001oogoo0003Ool0
1000Ool000000Woo00<007ooOol017oo00<007ooOol00P002goo00<007ooOol017oo0P0017oo2W`0
00<007ooOol00Woo0P001Woo00<007ooOol02Goo0P000Woo00<007ooOol017oo00<007ooOol00P00
00=oo`00Ool00Woo00@007ooOol000Aoo`04001oogoo0003Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool01000Oomoo`001goo100027oo0P0000Aoo`00001oo`Yl01]oo`006Goo37`000=oo`0000001Woo
10002goo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo009oo`04001oogoo0002Ool0
1000Oomoo`0017oo00L007ooOomoo`00Ool00005Ool00`00Oomoo`02000;Ool00`00Oomoo`07Ool2
00000gooO01l000:O002Ool20009Ool00`00Oomoo`09Ool20002Ool00`00Oomoo`03Ool00`00Ool0
0003Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00=oo`03001o
ogoo00=oo`05001oogooOol0000;Ool40006Ool200000gooO01l000:O00JOol001Qoo`el0004001o
ogooOol5000>Ool00`00Oomoo`03Ool01@00Oomoogoo00001Goo00<007ooOol017oo00<007oo0000
0Woo00<007oo00001Woo00@007ooOomoo`<000=oo`04001oo`000002Ool00`00Oomoo`07Ool00`00
Oomoo`0:Ool=O002000<Ool00`00Oomoo`07Ool00`00Oomoo`0200000goo001oo`02Ool30003Ool0
0`00Oomoo`04Ool00`00Ool00002Ool00`00Ool00006Ool00`00Oomoo`03Ool01@00Oomoogoo0000
1Goo00<007ooOol037oo1@000goo3G`06Woo000HOol>O003000BOol00`00Oomoo`04Ool01000Oomo
o`001Woo00<007ooOol01Goo00H007oo000007oo0007Ool00`00Oomoo`03Ool20002Ool20005Ool0
0`00Oomoo`05Ool00`00Oomoo`0;Ool>O00>Ool00`00Oomoo`05Ool00`00Oomoo`03Ool20002Ool2
0005Ool00`00Oomoo`05Ool01P00Ool00000Ool000Moo`03001oogoo00Aoo`04001oogoo0006Ool0
0`00Oomoo`0@Ool3000>O00IOol001Qoo`il01Eoo`03001oogoo00Eoo`8000Moo`03001oogoo00Io
o`@000Qoo`03001oogoo00Aoo`@000Ioo`03001oogoo00Aoo`03001oogoo00aoo`il00moo`03001o
ogoo00Aoo`03001oogoo00Aoo`@000Ioo`03001oogoo00Ioo`@000Qoo`03001oogoo00Eoo`8000Mo
o`03001oogoo01=oo`il01Uoo`0067oo3W`0HP003W`0H`003W`06Goo000HOol>O00DOol00`00Oomo
o`06Ool00`00Ool00005Ool00`00Oomoo`07Ool40009Ool00`00Oomoo`03Ool00`00Ool000020006
Ool01@00Oomoogoo000047oo3W`04Goo00D007ooOomoo`0000Ioo`<00003Ool007oo00Aoo`03001o
ogoo00Moo`@000Uoo`03001oogoo00=oo`03001oo`0000Qoo`03001oogoo019oo`il01Uoo`0067oo
3G`0100047oo00<007ooOol01Woo00@007ooOol000Aoo`03001oogoo00Moo`80009oo`8000Uoo`03
001oogoo00<0009oo`03001oo`0000Ioo`03001oo`00015oo`el01=oo`03001oo`0000Ioo`03001o
o`00009oo`<0009oo`03001oogoo00Moo`80009oo`8000Uoo`03001oogoo009oo`04001oogoo0008
Ool00`00Oomoo`0>Ool3000=O00JOol001Uoo`al0004001oogooOol5000;Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01@00Oomoogoo000027oo0`000Woo00<007oo000027oo00D007oo001oo`0000Ao
o`03001oo`0000Eoo`03001oo`00015oo`03001l07`000Yl0080015oo`03001oo`0000Eoo`03001o
o`0000Aoo`05001oo`00Ool00008Ool00`00Ool00002Ool30008Ool01@00Oomoogoo000017oo00<0
07ooOol01Goo00<007ooOol02Goo1@000goo00<007`0O0002W`06Woo000JOol:O002Ool20006Ool4
0006Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Ool00008Ool00`00Ool00004Ool00`00Ool0
0007Ool200000goo001oo`04Ool00`00Oomoo`020004Ool00`00Oomoo`0>Ool20002Ool:O0000`00
Oomoo`02000@Ool00`00Oomoo`02Ool20002Ool00`00Oomoo`03Ool01000Ool000001goo00<007oo
000017oo00<007oo000027oo00<007oo00001Goo00<007ooOol01Woo00<007ooOol017oo10001Woo
0P000Woo2W`06goo000KOol8O0020003Ool30007Ool40002Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool20007Ool00`00Ool00006Ool00`00Ool00005Ool01000Ool000001goo00D007ooOomoo`00009o
o`8000ioo`8000=oo`8000Ql0003Ool0000000=oo`8000ioo`80009oo`05001oogooOol00007Ool2
00000goo001oo`04Ool00`00Ool00006Ool00`00Ool00007Ool20007Ool00`00Oomoo`05Ool00`00
Oomoo`040007Ool30003Ool20008O00LOol001aoo`Il00=oo`03001oogoo009oo`<000Uoo`D000Ao
o`03001oogoo00Ioo`03001oogoo00Eoo`04001oogoo0006Ool01000Oomoo`000Woo0P000goo00<0
07ooOol01Woo00@007ooOomoo`80009oo`03001oogoo00Qoo`<000Aoo`04001oogooOol6O004Ool0
0`00Oomoo`02Ool3000:Ool00`00Oomoo`020003Ool00`00Oomoo`06Ool01000Oomoogoo0P000Woo
00@007ooOol000Ioo`04001oogoo0007Ool00`00Oomoo`06Ool00`00Oomoo`02Ool50009Ool30004
Ool01000Oomoogoo1W`07Goo000VOol00`00Oomoo`04Ool20008Ool01000Oomoogoo1@0027oo0P00
1Goo00@007ooOol000Qoo`03001oogoo008000Aoo`8000Qoo`09001oogooOol007oo001oo`0000Qo
o`8000Ioo`03001oogoo00eoo`03001oogoo00Aoo`8000Qoo`05001oo`00Ool00003Ool00`00Oomo
o`06Ool20004Ool20002Ool00`00Oomoo`06Ool01000Oomoo`001Goo0P0027oo1@000goo00<007oo
Ool01Woo0P001Woo00<007ooOol09Goo000WOol00`00Oomoo`05Ool20005Ool00`00Oomoo`05Ool5
0005Ool00`00Ool00003Ool01@00Oomoogoo000027oo00<007ooOol00P000goo00<007oo00002Goo
00<007oo00000goo0`001Goo0P001goo00<007ooOol03goo00<007ooOol01Goo0P001Goo0`000goo
00<007oo00002Goo00<007oo00000goo0P000Woo00<007ooOol01Woo00D007ooOomoo`0000=oo`03
001oo`0000Eoo`D000Moo`03001oogoo00=oo`8000Moo`03001oogoo02Ioo`00:7oo00<007ooOol0
1Woo0P000Woo00<007ooOol01Goo00<007ooOol00goo1@000Woo00@007ooOol000=oo`03001oogoo
00Qoo`80009oo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`04Ool20002Ool20008Ool0
0`00Oomoo`0AOol00`00Oomoo`06Ool20002Ool20006Ool00`00Oomoo`07Ool01000Oomoo`000Woo
00<007ooOol00P002Woo00D007ooOomoo`00009oo`03001oogoo00D000Eoo`03001oogoo00Eoo`03
001oogoo008000Qoo`03001oogoo02Moo`00:Goo00<007ooOol01goo0`001Woo00<007ooOol027oo
1P0017oo00<007ooOol01goo0P0017oo0P000goo00<007ooOol01Woo00<007oo00001Woo0`0027oo
0P005Goo0P0027oo0`001Woo00<007oo000027oo00@007ooOomoo`8000Aoo`8000Uoo`03001oogoo
009oo`H000Yoo`03001oogoo00Aoo`<000Uoo`03001oogoo02Qoo`00:Woo00<007ooOol01goo1000
17oo00<007ooOol01goo00<007ooOol00Woo1P0027oo0P000Woo00@007ooOomoo`8000Aoo`03001o
ogoo00Eoo`03001oo`0000Eoo`@000Moo`8001Moo`8000Moo`@000Eoo`03001oo`0000Moo`03001o
ogoo009oo`8000=oo`03001oogoo008000Qoo`H000Aoo`03001oogoo00Moo`03001oogoo009oo`@0
00Uoo`03001oogoo02Uoo`00:goo00<007ooOol01Woo00<007ooOol00`0000=oo`00Ool02Goo00<0
07ooOol00P000Woo00<007ooOol01@000goo00<007ooOol00Woo00@007ooOol0009oo`80009oo`03
001oogoo00Aoo`06001oogooOol007oo0`000Woo00@007oo000000Aoo`8001Uoo`8000Aoo`800004
Ool007ooOol300000goo001oo`02Ool00`00Oomoo`04Ool00`00Oomoo`020002Ool01000Oomoo`00
17oo00@007ooOomoo`D0009oo`03001oogoo0080009oo`03001oogoo00Qoo`03001oo`000080009o
o`03001oogoo00Ioo`03001oogoo02Yoo`00;7oo00<007ooOol017oo00<007ooOol017oo0P002Goo
00<007ooOol00P000goo00<007oo00001Goo10001Goo00<007oo000017oo00@007ooOol000Aoo`03
001oogoo009oo`8000Ioo`04001oogoo0002Ool2000KOol20002Ool01000Oomoo`001Woo0P0017oo
00<007ooOol00Woo00@007ooOol000Aoo`03001oo`0000Eoo`@000Eoo`03001oo`0000=oo`80009o
o`03001oogoo00Moo`8000Ioo`03001oogoo00Aoo`03001oogoo02]oo`00;Goo00<007ooOol00goo
00<007ooOol017oo00@007oo000000Moo`04001oo`000005Ool20005Ool01000Oomoogoo1`001Woo
00<007oo00000goo00@007ooOomoo`800003Ool007oo00Eoo`04001oogooOol3000MOol30003Ool0
0`00Oomoo`04Ool01000Ool000000goo00L007ooOomoo`00Ool00006Ool70003Ool00`00Oomoo`03
Ool20005Ool200000goo001oo`06Ool200000goo001oo`05Ool00`00Oomoo`03Ool00`00Oomoo`0/
Ool002ioo`80009oo`03001oogoo00Aoo`03001oogoo009oo`<000Aoo`8000Moo`8000=oo`8000Uo
o`@000Eoo`80009oo`03001oogoo008000Aoo`03001oogoo00Aoo`03001oogoo00<001eoo`<0009o
o`03001oogoo00Aoo`03001oogoo009oo`80009oo`03001oogoo008000Eoo`@000Uoo`8000=oo`80
00Moo`8000Aoo`<000Aoo`03001oogoo00Aoo`03001oogoo008002moo`00<7oo00<007oo00001Goo
00<007ooOol01Goo0`0000=oo`0000001goo00H007ooOol007oo000:Ool01@00Oomoo`00Ool01000
0Woo0`0000=oo`0000001goo00<007ooOol00goo00<007oo00000goo00<007ooOol06Goo00L007oo
Oomoo`00Ool00005Ool00`00Oomoo`05Ool2000017oo000000000Woo100000Eoo`00Oomoo`0000Yo
o`03001oo`00009oo`03001oogoo00Eoo`800004Ool000000007Ool00`00Oomoo`03Ool00`00Ool0
000aOol0035oo`03001oogoo00=oo`03001oogoo00Qoo`<000Qoo`03001oogoo008000]oo`04001o
ogoo0005Ool6000:Ool00`00Oomoo`03Ool00`00Oomoo`03Ool2000GOol20005Ool00`00Oomoo`03
Ool00`00Oomoo`08Ool60005Ool01000Oomoo`002goo0P000Woo00<007ooOol01Woo0`002Woo00<0
07ooOol00goo00<007ooOol0<7oo000aOol20004Ool00`00Oomoo`09Ool01000Ool000001Goo00H0
07ooOol007oo000:Ool00`00Oomoo`02Ool00`00Oomoo`03Ool200000goo000000030007Ool00`00
Oomoo`02Ool20007Ool00`00Oomoo`0COol00`00Oomoo`05Ool20004Ool00`00Oomoo`05Ool50000
0goo00000005Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Ool00002Ool00`00Oomoo`03Ool2
00000goo001oo`0:Ool00`00Oomoo`02Ool2000bOol0031oo`04001oogoo0002Ool00`00Oomoo`09
Ool20003Ool20003Ool00`00Ool00003Ool00`00Oomoo`06Ool00`00Oomoo`03Ool01000Oomoogoo
0P0000=oo`00Ool00P000goo100017oo00@007ooOol0009oo`03001oogoo00Eoo`80015oo`8000Mo
o`04001oogoo0002Ool00`00Oomoo`02Ool40003Ool200000goo001oo`020003Ool00`00Oomoo`03
Ool00`00Oomoo`06Ool01`00Oomoogoo001oo`0000=oo`8000=oo`8000]oo`04001oogoo0002Ool0
0`00Oomoo`0_Ool002moo`03001oogoo009oo`8000]oo`8000Ioo`D000Aoo`03001oogoo00Ioo`03
001oogoo00Aoo`<0009oo`04001oogooOol20006Ool70004Ool00`00Oomoo`06Ool00`00Oomoo`0=
Ool00`00Oomoo`06Ool00`00Oomoo`02Ool70006Ool20003Ool00`00Oomoo`030006Ool00`00Oomo
o`06Ool00`00Oomoo`02Ool50006Ool2000;Ool20004Ool00`00Oomoo`0^Ool002moo`03001oogoo
009oo`8000Yoo`03001oo`0000Qoo`<000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`8000=oo`03
001oogoo009oo`03001oo`0000Uoo`D0009oo`03001oogoo00Moo`8000]oo`8000Uoo`03001oogoo
00D000Uoo`03001oo`0000Aoo`04001oogooOol20006Ool00`00Oomoo`04Ool00`00Oomoo`03Ool3
0008Ool00`00Ool0000:Ool20004Ool00`00Oomoo`0^Ool002ioo`03001oogoo00=oo`03001oo`00
00Qoo`03001oo`0000Moo`80009oo`<000Aoo`03001oogoo009oo`03001oogoo00=oo`80009oo`03
001oo`0000Ioo`03001oo`0000Moo`800004Ool007ooOol4000:Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool40002Ool01000Ool000001goo00<007oo00001Woo00<007oo00000Woo0P001Goo00<007oo
Ool00Woo00<007ooOol00Woo0`000Woo0P001goo00<007oo000027oo00<007oo00001Goo00<007oo
Ool0;Goo000^Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo0P000Woo00<007ooOol017oo00<0
07oo000017oo0`000goo00@007ooOol000=oo`<000Aoo`8000Moo`03001oogoo008000Aoo`8000=o
o`03001oogoo009oo`H000Ioo`8000Eoo`8000Ioo`H000Aoo`04001oogooOol20004Ool20002Ool0
0`00Oomoo`05Ool20004Ool30003Ool01000Oomoo`000goo0`0017oo00<007oo00001Woo00<007oo
Ool00P001Goo00D007ooOomoo`0000Aoo`03001oogoo02eoo`00;Goo00<007ooOol00Woo00<007oo
Ool00goo00@007ooOomoo`8000=oo`03001oogoo009oo`800003Ool007oo00Moo`800006Ool007oo
Ool007oo0P001goo0P001goo00<007ooOol00Woo00<007ooOol00P001Goo00<007ooOol00Woo00<0
07ooOol00Woo100017oo00D007ooOomoo`0000Aoo`@000Aoo`03001oogoo009oo`03001oogoo00=o
o`80009oo`03001oogoo009oo`03001oogoo00Eoo`8000Moo`800006Ool007ooOol007oo0P0027oo
00@007oo000000Aoo`04001oogooOol20003Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`0/Ool002eoo`03001oogoo009oo`03001oogoo00Aoo`04001oo`000003Ool00`00Oomoo`02Ool0
1@00Oomoogoo00002Woo1P0027oo00<007oo000027oo00<007ooOol00Woo0`001Woo00<007ooOol0
0Woo00<007ooOol01Woo100000Eoo`00Ool007oo00@000Qoo`03001oogoo009oo`03001oogoo00Ao
o`<000Aoo`03001oogoo00Ioo`03001oo`0000Qoo`H000Yoo`05001oogooOol00004Ool01000Oomo
ogoo0P0000=oo`00Ool01Goo00<007ooOol00Woo00<007ooOol0;7oo000/Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool20004Ool00`00Oomoo`020003Ool00`00Oomoo`0;Ool30008Ool01@00Oomoogoo
00001goo00<007ooOol00Woo0P0027oo00<007ooOol00Woo00<007ooOol02Goo1@002goo00<007oo
Ool00Woo00<007ooOol01Woo0P0017oo00<007ooOol01Goo00D007ooOomoo`0000Qoo`<000eoo`04
001oogooOol20002Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`02Ool00`00Oomoo`0[Ool002ao
o`05001oogooOol00008Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo00Yoo`80009o
o`<000Ioo`03001oogoo009oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`06Ool01@00
Oomoogoo00001goo1@000goo1@001goo00D007ooOomoo`0000Qoo`04001oogoo0002Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool30002Ool2000<Ool00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol000Qoo`05001oogooOol0000]Ool002]oo`05001oogooOol00008Ool00`00
Oomoo`02Ool01@00Ool007oo00001Goo00<007ooOol027oo0P0000Ioo`00Oomoo`00Ool30003Ool0
0`00Oomoo`03Ool00`00Oomoo`05Ool00`00Ool00004Ool00`00Oomoo`06Ool01@00Oomoogoo0000
0Woo10000Woo0P001Goo0P000Woo10000Woo00D007ooOomoo`0000Qoo`03001oogoo009oo`03001o
o`0000Moo`03001oogoo00=oo`04001oogooOol300001Woo001oogoo001oo`8000Yoo`03001oogoo
00=oo`05001oo`00Ool00004Ool00`00Oomoo`06Ool01@00Oomoogoo0000;7oo000[Ool01@00Oomo
ogoo00001goo00<007ooOol017oo0`001Goo00<007ooOol01Woo0`000Woo00<007ooOol00Woo00<0
07ooOol010001goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007oo00001000
1Goo00<007ooOol01goo00<007ooOol00goo1@0000=oo`00Ool01Woo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol01Goo10000Woo00<007ooOol00Woo00<007ooOol00`0027oo00<007ooOol0
0goo0`001Woo00<007ooOol01Goo00D007ooOomoo`0002aoo`00:Woo00D007ooOomoo`0000Moo`03
001oogoo00Eoo`8000Ioo`03001oogoo00Aoo`8000Aoo`03001oogoo00Aoo`04001oogooOol30006
Ool00`00Oomoo`04Ool20007Ool00`00Oomoo`02Ool40003Ool00`00Oomoo`02Ool2000;Ool20004
Ool01000Oomoogoo100017oo00<007ooOol01Goo0P001Woo00<007ooOol017oo0`000goo00<007oo
Ool017oo00<007ooOol00Woo0P001Woo00<007ooOol017oo0P001goo00<007ooOol01Goo00D007oo
Oomoo`0002]oo`00:Goo00D007ooOomoo`0000Moo`03001oogoo00Aoo`<00003Ool007oo00=oo`03
001oogoo00=oo`8000Eoo`03001oogoo00Ioo`03001oo`0000=oo`<000Aoo`03001oogoo009oo`03
001oo`0000Qoo`@000Aoo`05001oogooOol00002Ool00`00Oomoo`0=Ool01000Oomoo`000goo00<0
07ooOol00Woo100027oo00<007oo000017oo00<007ooOol00Woo0`000goo00<007oo000027oo00<0
07ooOol00goo0P001Goo00<007ooOol00Woo00<007oo00000P001Woo00<007ooOol01Goo00D007oo
Oomoo`0002Yoo`00:Goo00@007ooOol000Moo`03001oogoo00Aoo`03001oo`0000=oo`05001oogoo
Ool00003Ool20007Ool00`00Oomoo`06Ool20006Ool30002Ool00`00Oomoo`020003Ool00`00Oomo
o`0500000goo001oo`06Ool00`00Oomoo`03000AOol30002Ool00`00Oomoo`05Ool00`00Ool00004
0002Ool01000Oomoogoo0P000Woo00<007ooOol00`001Woo0P0027oo00<007ooOol01Goo0P000goo
00D007ooOomoo`0000=oo`03001oo`0000Ioo`03001oogoo00Eoo`04001oogoo000ZOol002Qoo`05
001oogooOol00006Ool00`00Oomoo`03Ool20002Ool00`00Oomoo`02Ool00`00Ool00002Ool20008
Ool00`00Oomoo`07Ool20008Ool3000017oo000000000goo10001goo00<007ooOol017oo00<007oo
Ool00P004goo0P000Woo00<007ooOol017oo00<007ooOol01Goo10000goo0`0000Aoo`00000000Qo
o`8000Uoo`03001oogoo00Ioo`80009oo`03001oo`0000Aoo`03001oogoo008000Eoo`03001oogoo
00Aoo`05001oogooOol0000YOol002Qoo`04001oogoo0006Ool00`00Oomoo`03Ool01@00Oomoogoo
00001Woo10002Goo00<007ooOol01goo00@007ooOol000Uoo`P0009oo`03001oogoo00Moo`03001o
ogoo00Aoo`800003Ool007oo019oo`04001oo`000006Ool00`00Oomoo`07Ool00`00Oomoo`080009
Ool01000Oomoo`002Goo00<007ooOol01goo10001Woo00D007ooOomoo`0000Eoo`03001oogoo00Ao
o`04001oogoo000YOol002Moo`04001oogoo0005Ool20004Ool20004Ool00`00Oomoo`03Ool3000;
Ool00`00Oomoo`07Ool01000Oomoo`0027oo1P001Goo00<007ooOol027oo0P000goo00<007oo0000
0Woo00<007ooOol03goo00H007ooOol007oo0003Ool2000:Ool00`00Oomoo`03Ool60008Ool01000
Oomoo`002Goo00<007ooOol02Goo0`001Goo00<007ooOol00Woo0P0017oo0P001Goo00@007ooOol0
02Qoo`009goo00@007ooOol000Aoo`8000Aoo`03001oogoo00=oo`03001oogoo009oo`800003Ool0
07oo008000Qoo`03001oogoo00Moo`03001oogoo009oo`04001oogooOol400001Woo000007oo001o
o`<000=oo`03001oogoo00Uoo`<0009oo`04001oogoo000AOol01000Oomoo`000Woo0`002goo00@0
07ooOomoo`<00003Ool007oo00800003Ool00000008000=oo`03001oogoo009oo`03001oogoo00Mo
o`03001oogoo00Ioo`800003Ool007oo008000Aoo`03001oogoo00=oo`03001oogoo009oo`8000Ao
o`04001oogoo000XOol002Ioo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00
Oomoo`020002Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`03Ool4
0004Ool00`00Oomoo`02Ool00`00Oomoo`0300000goo001oo`0:Ool20004Ool01000Oomoo`003goo
00@007ooOol000Aoo`8000]oo`03001oo`000080009oo`03001oogoo009oo`03001oogoo009oo`@0
00Eoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo0080009oo`03001o
ogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`04001oogoo000WOol002Ioo`03001oo`0000Ao
o`03001oogoo009oo`8000Ioo`04001oo`000003Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`07Ool00`00Ool000040002Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000Oomoogoo1000
2Goo00@007ooOol000Aoo`03001oo`0000moo`03001oo`0000Aoo`04001oogoo0009Ool40003Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0500000goo001oo`08Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool01000Oomoogoo0P0000=oo`00Ool01Goo0P0017oo00<007ooOol00Woo00<007oo
00009goo000UOol00`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`06Ool20005Ool00`00Oomo
o`05Ool01@00Oomoogoo00001goo10001goo00D007ooOomoo`0000Moo`03001oogoo00=oo`<000Io
o`8000Aoo`03001oogoo009oo`03001oo`0000eoo`03001oo`0000Aoo`03001oogoo009oo`8000Io
o`<000Eoo`03001oogoo00Eoo`05001oogooOol00007Ool40007Ool01@00Oomoogoo00001goo00<0
07ooOol00goo0P0027oo00<007ooOol00Woo00<007ooOol00Woo00<007oo00009Woo000UOol00`00
Ool00003Ool01000Oomoogoo0P001Woo10001Goo00<007ooOol01goo00<007oo00000goo1P002goo
00<007oo00002Goo00<007ooOol00goo10000goo00<007ooOol01Goo00L007ooOomoo`00Ool0000=
Ool00`00Ool00003Ool00`00Oomoo`05Ool01000Oomoogoo10001Goo00<007ooOol01goo00<007oo
00002goo1P000goo00<007oo00002Goo00<007ooOol00goo10001Woo0P000goo00L007ooOomoo`00
Ool0000VOol002Aoo`03001oo`0000=oo`05001oogooOol00006Ool20002Ool00`00Oomoo`04Ool0
0`00Oomoo`08Ool50004Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomo
o`030009Ool01`00Oomoogoo001oo`0000]oo`03001oo`0000=oo`03001oogoo00Moo`<0009oo`03
001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo009oo`D000Yoo`03001oogoo
00Aoo`03001oogoo008000Ioo`05001oogooOol00003Ool00`00Ool0000UOol002=oo`03001oo`00
00=oo`03001oogoo008000Eoo`8000Aoo`03001oogoo00=oo`03001oogoo00Ioo`D000Ioo`03001o
ogoo00]oo`03001oo`0000Yoo`03001oogoo00=oo`05001oogoo001oo`030008Ool01`00Oomoogoo
001oo`0000Uoo`03001oo`0000=oo`03001oogoo00Ioo`<00005Ool007ooOol00005Ool00`00Oomo
o`08Ool00`00Ool0000=Ool00`00Oomoo`04Ool50008Ool00`00Oomoo`03Ool00`00Oomoo`02Ool2
0005Ool20002Ool01`00Oomoogoo001oo`0002Aoo`008goo00<007oo00000Woo00@007ooOol000Eo
o`8000Eoo`03001oogoo00Aoo`04001oogooOol50002Ool01000Oomoo`001Goo00<007ooOol02Goo
0P000Woo00<007ooOol027oo00<007ooOol017oo0P0017oo0`001goo00H007ooOol007oo0009Ool0
0`00Ool00002Ool00`00Oomoo`05Ool30004Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02000;
Ool00`00Oomoo`03Ool01000Oomoo`000Woo1@000goo00<007ooOol017oo00<007ooOol00goo0P00
1Goo00@007ooOol0009oo`03001oo`0002Aoo`008Woo00<007oo00000Woo00@007oo000000Aoo`80
00Moo`03001oogoo00=oo`D000Ioo`03001oogoo009oo`05001oogooOol0000;Ool20004Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool20007Ool30006Ool01P00Oomoo`00Ool000Moo`03001oo`00009o
o`03001oogoo00Aoo`<000Moo`8000Aoo`03001oogoo00Qoo`03001oogoo009oo`8000]oo`05001o
ogooOol00004Ool00`00Oomoo`04Ool50005Ool00`00Oomoo`05Ool20004Ool200001goo001oogoo
001oo`0002=oo`0077oo1W`00P000Woo00<007oo000017oo0P0027oo00@007ooOomoo`@000Uoo`03
001oogoo00Aoo`03001oo`0000]oo`8000Ioo`03001oogoo00Moo`03001oogoo0080009oo`03001o
ogoo00Ioo`<000Eoo`03001oogoo008000Il0003Ool00000009oo`03001oogoo00=oo`<000Qoo`03
001oogoo0080009oo`03001oogoo00Moo`03001oogoo00Aoo`8000]oo`03001oo`0000Ioo`03001o
ogoo00Moo`@000=oo`03001oogoo00Ioo`8000Aoo`03001oo`00009oo`8000Il01eoo`006goo27`0
00=oo`0000000P000Woo0`002Goo1@000Woo00<007ooOol027oo00<007ooOol01Goo0P002Woo0P00
1goo00<007ooOol027oo0P0017oo00<007ooOol027oo10000goo0P0000=oog`0O0001W`000@007oo
000000=oo`@000Yoo`03001oogoo009oo`8000Yoo`03001oogoo00Eoo`8000Yoo`8000Moo`03001o
ogoo00Qoo`03001oogoo00D000Uoo`<0009oo`@00003Ooml07`000Il01aoo`006Woo2W`00P000Woo
0P0027oo100000=oo`00Ool017oo00<007ooOol01goo00<007ooOol01Goo00@007ooOol000Qoo`03
001oogoo00Qoo`03001oogoo00Ioo`8000Eoo`03001oogoo00]oo`<000=oo`Yl0004001oogooOol3
000=Ool00`00Oomoo`03Ool20008Ool00`00Oomoo`08Ool00`00Oomoo`06Ool01000Oomoo`001goo
00<007ooOol01goo00<007ooOol00goo00<007oo00000`0027oo0P000Woo0P002W`06goo000IOol<
O0000goo00000006Ool40004Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool01000Oomoo`001Goo00<0
07ooOol037oo0`0037`000Aoo`00000000ioo`03001oogoo00=oo`04001oogoo0006Ool00`00Oomo
o`0:Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool40006Ool200000gooO01l000:O00JOol001Qoo`el0004001oogooOol5
0008Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`0>Ool=O002000@Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0<
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool50003Ool=O00JOol001Qoo`il00<000aoo`03001oogoo00=oo`03001oogoo
00Moo`03001oogoo00Aoo`03001oogoo00Ioo`04001oogoo000?Ool00`00Oomoo`020005Ool00`00
Oomoo`03Ool00`00Oomoo`0=Ool>O00@Ool00`00Oomoo`03Ool00`00Oomoo`03Ool20002Ool00`00
Oomoo`0=Ool01000Oomoo`0027oo00<007ooOol017oo00<007ooOol01goo00<007ooOol00goo00<0
07ooOol02Woo0`003W`06Goo000HOol>O00?Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomo
o`05Ool00`00Oomoo`07Ool2000AOol20008Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool>O00@Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool2000AOol20009Ool00`00Oomoo`05Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`0=Ool>O00IOol001Qoo`il068000il06<000il01Uoo`0067oo3W`0
3Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol027oo00@007ooOol0
00ioo`05001oogooOol00008Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool>O00?Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool01@00Oomoogoo00003Woo00@007ooOol000Yoo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001oogoo009oo`03001oogoo00aoo`il01Uoo`0067oo3G`01@002Goo00<007ooOol0
0goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol01goo0P0017oo00<007ooOol02Goo0P00
17oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol02goo3G`000<007ooOol037oo00<007oo
Ool00goo00<007ooOol01Woo00<007ooOol00Woo0P002goo00<007ooOol00Woo0P002Goo00<007oo
Ool017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo10003G`06Woo000IOol<O000
0`00Oomoo`02Ool40005Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomo
o`07Ool20006Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool2000<O003000<Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`05Ool0
0`00Oomoo`07Ool00`00Oomoo`04Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool40004Ool00`00O01l000:O00JOol001Yoo`Yl009oo`8000Ioo`@00003
Ool007oo00=oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Moo`8000Qoo`03001oogoo
00Aoo`8000Uoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Qoo`<0009oo`Yl00=oo`<0
00Yoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Moo`8000Ioo`03001oogoo00Ioo`80
00Uoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oo`0000<000Ioo`80009o
o`Yl01]oo`006goo27`01Goo0`001goo1P0027oo00<007ooOol00goo00<007ooOol01goo0P002Woo
0P000goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol017oo10001Goo
27`01Woo10001Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol02Goo00@007ooOomoo`80
00Yoo`8000Uoo`03001oogoo00=oo`03001oogoo00Ioo`H000Moo`<000Eoo`Ql01aoo`0077oo1W`0
2Goo0P001Goo00<007ooOol00Woo100017oo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
37oo0`003Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo0`002Goo1W`02Woo0`00
17oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol02goo0`003Woo00<007ooOol01goo00<0
07ooOol00goo00<007ooOol00Woo100017oo00<007ooOol00goo0P002Goo1W`07Goo000]Ool20002
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool50005Ool00`00Oomoo`06Ool00`00Oomoo`0=Ool2000?
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Ool00002000MOol300000goo001oo`03Ool00`00
Oomoo`05Ool00`00Oomoo`0=Ool2000?Ool00`00Oomoo`06Ool00`00Oomoo`03Ool50004Ool00`00
Oomoo`02Ool00`00Oomoo`02000^Ool002moo`<000=oo`03001oogoo00Eoo`03001oogoo00D000Qo
o`03001oogoo00aoo`80009oo`03001oogoo00eoo`03001oogoo00Eoo`04001oogooOol3000QOol3
0003Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`02000>Ool00`00Oomoo`06Ool50002
Ool00`00Oomoo`05Ool01000Oomoogoo0`00<7oo000`Ool400000goo001oo`06Ool00`00Oomoo`03
Ool60003Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00
Ool00003000SOol400000goo001oo`06Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0<
Ool01000Oomoogoo1P001Goo00<007ooOol01Goo00<007oo00000`00<Goo000`Ool01000Oomoogoo
0P001Woo00<007ooOol00goo00<007ooOol017oo10003Goo00<007ooOol01Goo00<007ooOol037oo
00<007ooOol00goo0`000goo00<007ooOol08Goo00@007ooOomoo`<000Eoo`03001oogoo00aoo`03
001oogoo00Eoo`03001oogoo00]oo`@000Ioo`03001oogoo00=oo`03001oogoo00Aoo`8000=oo`03
001oogoo02moo`00<7oo00H007ooOomoo`00Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`06Ool0
0`00Oomoo`040007Ool20009Ool00`00Oomoo`0<Ool00`00Oomoo`0300000goo001oo`02Ool00`00
Oomoo`0QOol01P00Oomoogoo001oo`<0009oo`03001oogoo00aoo`03001oogoo00Moo`8000Moo`@0
009oo`03001oogoo00Ioo`03001oogoo00=oo`04001oogooOol200000goo001oo`02Ool00`00Oomo
o`0_Ool002moo`05001oogooOol00004Ool30005Ool00`00Oomoo`06Ool00`00Oomoo`05Ool50000
0goo001oo`0;Ool00`00Oomoo`0<Ool30004Ool01@00Oomoogoo00008Goo00D007ooOomoo`0000Ao
o`<000ioo`03001oogoo00Yoo`03001oo`0000@000Moo`03001oogoo00Ioo`03001oogoo00=oo`<0
00Aoo`05001oogooOol0000`Ool002moo`05001oogooOol00006Ool20003Ool00`00Oomoo`05Ool2
000<Ool5000;Ool00`00Oomoo`09Ool30006Ool01@00Oomoogoo00008Goo00D007ooOomoo`0000Io
o`<000]oo`03001oogoo00Uoo`D000aoo`8000Moo`04001oogooOol20006Ool01@00Oomoogoo0000
<7oo000^Ool01@00Oomoogoo00001Woo00<007ooOol00`001goo0P0037oo00<007ooOol00goo1@00
1goo00<007ooOol01Woo0`000Woo00<007ooOol017oo00D007ooOomoo`0001moo`05001oogooOol0
0006Ool00`00Oomoo`030008Ool00`00Oomoo`05Ool50005Ool00`00Oomoo`0:Ool20007Ool30002
Ool00`00Oomoo`04Ool01@00Oomoogoo0000;goo000^Ool01@00Oomoogoo00001Goo00<007ooOol0
0goo0`0017oo0P002goo0P002goo100017oo0P000goo0`001Woo00<007ooOol00goo00D007ooOomo
o`0001moo`05001oogooOol00005Ool00`00Oomoo`04Ool30003Ool20004Ool4000;Ool2000;Ool2
0004Ool30005Ool00`00Oomoo`03Ool01@00Oomoogoo0000;goo000]Ool01@00Oomoogoo00001Woo
00<007ooOol00Woo00@007ooOomoo`800003Ool007oo00]oo`03001oogoo00moo`D00003Ool00000
008000Qoo`03001oogoo00Aoo`05001oogooOol0000MOol01@00Oomoogoo00001Woo00<007ooOol0
1Woo100000=oo`0000000`004Goo00<007ooOol02Woo00@007oo000000=oo`03001oogoo009oo`03
001oogoo00Aoo`05001oogooOol0000^Ool002eoo`05001oogooOol00005Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool2000:Ool2000GOol4000:Ool00`00Oomoo`03Ool01@00Oomoogoo00007Goo00D0
07ooOomoo`0000Eoo`03001oogoo00Qoo`@001Moo`8000Yoo`8000Ioo`03001oogoo009oo`03001o
ogoo00=oo`05001oogooOol0000^Ool002aoo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Oomoo`020007Ool00`00Oomoo`0EOol30002Ool50007Ool00`00Oomoo`03Ool0
1@00Oomoogoo00006goo00D007ooOomoo`0000Eoo`03001oogoo00Eoo`D0009oo`<001Moo`03001o
ogoo00Eoo`80009oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol0
000]Ool002aoo`04001oogoo0005Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool3
0002Ool2000FOol30005Ool01000Oomoogoo1@000goo00<007ooOol00goo00@007ooOol001]oo`04
001oogoo0005Ool01000Oomoogoo1@000goo00<007ooOol00goo0`005Woo0P000Woo0`001Goo00<0
07ooOol017oo00<007ooOol00Woo00<007ooOol00goo00@007ooOol002eoo`00;7oo00@007ooOol0
00Eoo`05001oogooOol00006Ool00`00Oomoo`07Ool2000EOol30009Ool00`00Oomoo`05Ool40005
Ool01000Oomoo`006goo00@007ooOol000Eoo`@000Moo`03001oogoo00Moo`<001Eoo`8000Uoo`03
001oogoo00Aoo`05001oogooOol00005Ool01000Oomoo`00;Goo000[Ool01000Oomoo`001Goo00D0
07ooOomoo`0000Ioo`03001oogoo00Qoo`04001oo`00000AOol3000<Ool00`00Oomoo`08Ool50000
1Goo001oogoo00006Goo00D007ooOol007oo00D000Yoo`03001oogoo00Yoo`<0015oo`800003Ool0
07oo00Uoo`03001oogoo00Aoo`05001oogooOol00005Ool01000Oomoo`00;7oo000[Ool01000Oomo
o`0017oo00D007ooOomoo`0000Ioo`03001oogoo00Moo`8000Aoo`8000eoo`<000moo`03001oogoo
00Qoo`04001oogooOol5000IOol50003Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool3000=Ool20004
Ool20009Ool00`00Oomoo`04Ool01@00Oomoogoo000017oo00@007ooOol002aoo`00:Woo00@007oo
Ool000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Ioo`<000Qo
o`<0019oo`03001oogoo00Qoo`03001oogoo009oo`03001oo`0000@0015oo`D00003Ool007oo00=o
o`03001oogoo00Qoo`03001oogoo011oo`<000Qoo`<000Qoo`03001oogoo00Moo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo009oo`04001oogoo000[Ool002Yoo`04001oogoo0004Ool01@00
Oomoogoo000017oo0P0027oo0P0037oo0P0017oo0P005Woo00<007ooOol01goo00<007ooOol00Woo
00@007ooOol000=oo`@000Uoo`@000=oo`04001oogoo0004Ool00`00Oomoo`07Ool00`00Oomoo`0D
Ool20004Ool2000<Ool20008Ool20004Ool01@00Oomoogoo000017oo00@007ooOol002]oo`00:Goo
00@007ooOol000Aoo`05001oogooOol00004Ool20008Ool00`00Oomoo`0>Ool4000IOol20008Ool0
0`00Oomoo`02Ool01000Oomoo`001Woo100000=oo`0000000P001Woo00@007ooOol000Aoo`03001o
ogoo00Ioo`8001Uoo`@0011oo`03001oogoo00Ioo`8000Aoo`05001oogooOol00004Ool01000Oomo
o`00:Woo000YOol01000Oomoo`000goo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`80011oo`D0
01]oo`03001oogoo00Ioo`05001oogooOol00002Ool00`00Oomoo`04Ool90006Ool01000Oomoo`00
0goo00<007ooOol01Woo00<007ooOol06Goo1@0047oo0P0027oo00<007ooOol00Woo00D007ooOomo
o`0000=oo`04001oogoo000ZOol002Uoo`03001oo`0000=oo`05001oogooOol00004Ool00`00Oomo
o`06Ool00`00Oomoo`0>Ool30004Ool2000JOol00`00Oomoo`06Ool01`00Oomoogoo001oo`00009o
o`@000Uoo`@0009oo`03001oo`0000=oo`03001oogoo00Ioo`03001oogoo01Qoo`8000Aoo`<0011o
o`03001oogoo00Ioo`03001oogoo009oo`05001oogooOol00003Ool00`00Ool0000ZOol002Qoo`04
001oogoo0003Ool01000Oomoo`0017oo00<007ooOol01Goo0P003goo0`0027oo0`0067oo00<007oo
Ool01Goo00@007ooOomoo`D0015oo`D000=oo`03001oogoo00Eoo`03001oogoo01Ioo`<000Qoo`<0
00moo`8000Moo`03001oogoo009oo`04001oogoo0003Ool01000Oomoo`00:Goo000XOol00`00Ool0
0003Ool01000Oomoo`0017oo00<007ooOol01Goo00<007ooOol03Goo0P003Woo0P005goo00<007oo
Ool017oo100000Aoo`00Ool001=oo`04001oo`00Ool40006Ool00`00Oomoo`0EOol2000>Ool2000?
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007oo0000:Goo000WOol00`00
Ool00003Ool01000Oomoo`0017oo00<007ooOol017oo0P003Goo0`004Woo0P005Woo1P000Woo00L0
07ooOomoo`00Ool0000AOol00`00Ool00003Ool00`00Oomoo`06000FOol2000BOol3000=Ool20006
Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007oo0000:7oo000WOol00`00Ool00003Ool01000
Oomoo`000goo00<007ooOol017oo00<007ooOol02goo0`005Woo0P004Goo1@001Woo00L007ooOomo
o`00Ool0000AOol00`00Ool00003Ool00`00Oomoo`04Ool5000AOol2000FOol3000=Ool00`00Oomo
o`04Ool01@00Oomoogoo00000Woo00L007ooOomoo`00Ool0000XOol002Ioo`03001oo`0000=oo`04
001oogoo0003Ool00`00Oomoo`03Ool2000<Ool3000JOol30009Ool50005Ool00`00Oomoo`04Ool0
1`00Oomoogoo001oo`0000moo`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo00=oo`D000Uo
o`<001Yoo`<000aoo`8000Eoo`05001oogooOol00002Ool01`00Oomoogoo001oo`0002Moo`009Woo
00<007oo00000Woo00@007ooOol000=oo`03001oogoo00=oo`03001oogoo00Yoo`80021oo`8000=o
o`@000]oo`03001oogoo00Aoo`06001oogoo001oo`003goo00<007oo00000Woo00<007ooOol017oo
00<007ooOol02Goo10000goo0P0087oo0P0037oo00<007ooOol00goo00D007ooOomoo`00009oo`06
001oogoo001oo`009goo000UOol00`00Ool00002Ool01000Oomoo`000goo00<007ooOol00goo00<0
07ooOol02Goo0P008goo100047oo00<007ooOol017oo00H007ooOol007oo000=Ool00`00Ool00002
Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool4000SOol2000;Ool00`00Oomoo`03Ool01@00Oomoogoo
00000Woo00H007ooOol007oo000VOol002Eoo`03001oo`00009oo`03001oo`00009oo`8000Aoo`80
00Yoo`80021oo`D000=oo`80011oo`03001oogoo00=oo`06001oogoo001oo`003Goo00<007oo0000
0Woo00<007ooOol00goo00<007ooOol03Woo0P000goo1@0087oo0P002Woo0P0017oo0P000Woo00<0
07oo00000Woo00<007oo00009Woo000UOol20002Ool00`00Ool00002Ool20004Ool00`00Oomoo`07
Ool3000NOol4000:Ool2000?Ool20004Ool00`00Oomoo`02000=Ool20002Ool00`00Oomoo`02Ool2
000?Ool2000:Ool4000NOol30009Ool00`00Oomoo`02Ool20002Ool00`00Ool00002Ool2000VOol0
02Aoo`07001oo`00Ool007oo00000Woo00<007ooOol00Woo0P0027oo0`006goo1@0047oo0`003Woo
00<007ooOol00Woo00D007oo001oo`0000]oo`05001oo`00Ool00004Ool00`00Oomoo`0<Ool3000@
Ool5000KOol30008Ool20004Ool02P00Oomoo`00Ool007oo001oo`009Goo000TOol2000017oo001o
o`000Woo00<007ooOol00Woo00<007ooOol01Woo0P006Woo100067oo0P003Goo00<007ooOol00Woo
00@007oo000000]oo`800003Ool007oo00=oo`03001oogoo00]oo`8001Qoo`@001Yoo`8000Qoo`03
001oogoo009oo`07001oogoo001oo`00Ool00P009Goo000SOol02@00Ool007oo001oo`00Ool00003
Ool20007Ool2000GOol5000NOol2000<Ool02@00Oomoogoo001oo`00Ool00009Ool01@00Ool007oo
00000goo00<007ooOol02Woo0P007Woo1@005goo0P001goo0P000goo00T007oo001oo`00Ool007oo
000097oo000SOol200001Woo001oo`00Ool000=oo`03001oogoo00Eoo`8001Eoo`@002Eoo`8000]o
o`06001oogooOol007oo0P002Goo0P0000=oo`00Ool00Woo00<007ooOol02Goo0P009Goo10005Goo
0P001goo00X007ooOomoo`00Ool007oo001oo`8002Aoo`008Woo0P0000Ioo`00Ool007oo0002Ool2
0005Ool3000COol4000[Ool2000:Ool01P00Oomoogoo001oo`8000Moo`800003Ool007oo009oo`03
001oogoo00Qoo`8002]oo`@001=oo`<000Eoo`80009oo`06001oo`00Ool007oo0P008goo000ROol2
00001Goo000007oo00000Woo00<007ooOol00goo0`0047oo1@00<Goo0`0027oo00D007ooOol007oo
008000Moo`800005Ool007ooOol00008Ool3000aOol5000@Ool30005Ool01@00Oomoo`00Ool00P00
00=oo`0000008goo000ROol01`00Ool00000Ool007oo008000Aoo`8000moo`@003Uoo`8000Moo`06
001oogoo001oo`001goo00<007oo00000Woo00<007ooOol01Goo0P00>Goo10003goo0P0017oo0P00
00=oo`00Ool00P0000=oo`00Ool08Woo000QOol4000017oo001oo`0017oo0P0037oo1@00?goo0P00
1Woo00<007ooOol00`001Goo0`000Woo00<007ooOol017oo0P00?goo1@0037oo0P0017oo00@007oo
001oo`@0029oo`0077oo1W`00P0000Aoo`00Ool000=oo`8000Yoo`@004Ioo`8000Eoo`04001oogoo
0006O0020002Ool00`00Oomoo`03Ool20016Ool4000:Ool20003Ool01000Ool007oo0P001W`07Goo
000KOol8O004000017oo000000001goo1@00C7oo0`000goo0P0027`00`000goo0`00C7oo1@001goo
0`0000=oo`0000000P0027`077oo000JOol:O0001000Ool000001Woo1000E7oo0P000Woo2W`00goo
0P00E7oo10001Woo0P0000=oo`00O0002G`06goo000IOol<O0000`00Oomoo`02Ool4001JOol00`00
O01l000:O002001JOol40004Ool00`00O01l000:O00JOol001Qoo`el00D005ioo`el061oo`@000el
01Yoo`0067oo3W`0HWoo3W`0Hgoo3W`06Goo000HOol>O01R000>O01S000>O00IOol001Qoo`il069o
o`il06=oo`il01Uoo`0067oo3W`0HWoo3W`0Hgoo3W`06Goo000HOol=O01SOol=O01TOol=O00JOol0
01Uoo`al06Aoo`al06Eoo`al01Yoo`006Woo2W`0IWoo2W`0Igoo2W`06goo000KOol8O01XOol8O01Y
Ool8O00LOol001aoo`Il06Yoo`Il06]oo`Il01eoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {0.586364, -0.050005, 0.00161548, \
0.00351603}}]
}, Open  ]],

Cell["\<\
This is one of the spanning trees that allows you to visit every \
node from every other node ... but only through one path ... i.e. a spanning \
path ... or tree.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowGraph[MinimumSpanningTree[CompleteGraph[6, 6, 6]]];\)\)], "Input",\

  CellTags->"S5.18.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.26471 2.15686 0.0495495 0.990991 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.10784 .04955 m
.5 .04955 L
s
.10784 .04955 m
.5 .22973 L
s
.10784 .04955 m
.5 .40991 L
s
.10784 .04955 m
.5 .59009 L
s
.10784 .04955 m
.5 .77027 L
s
.10784 .04955 m
.5 .95045 L
s
.10784 .04955 m
.89216 .04955 L
s
.10784 .04955 m
.89216 .22973 L
s
.10784 .04955 m
.89216 .40991 L
s
.10784 .04955 m
.89216 .59009 L
s
.10784 .04955 m
.89216 .77027 L
s
.10784 .04955 m
.89216 .95045 L
s
.10784 .22973 m
.5 .04955 L
s
.10784 .40991 m
.5 .04955 L
s
.10784 .59009 m
.5 .04955 L
s
.10784 .77027 m
.5 .04955 L
s
.10784 .95045 m
.5 .04955 L
s
1 0 0 r
.05 w
.10784 .04955 Mdot
.10784 .22973 Mdot
.10784 .40991 Mdot
.10784 .59009 Mdot
.10784 .77027 Mdot
.10784 .95045 Mdot
.5 .04955 Mdot
.5 .22973 Mdot
.5 .40991 Mdot
.5 .59009 Mdot
.5 .77027 Mdot
.5 .95045 Mdot
.89216 .04955 Mdot
.89216 .22973 Mdot
.89216 .40991 Mdot
.89216 .59009 Mdot
.89216 .77027 Mdot
.89216 .95045 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol001aoo`Il06Yo
o`Il06]oo`Il01eoo`006goo27`0J7oo27`0JGoo27`077oo000JOol:O01VOol:O01WOol:O00KOol0
01Uoo`al06Aoo`al06Eoo`al01Yoo`0067oo3G`0Hgoo3G`0I7oo3G`06Woo000HOol>O01ROol>O01S
Ool>O00IOol001Qoo`il069oo`il06=oo`il01Uoo`0067oo3W`0HP003W`0H`003W`06Goo000HOol>
O01ROol>O01SOol>O00IOol001Qoo`el00D005ioo`el06Aoo`el01Yoo`006Goo37`000<007ooOol0
0Woo1000FWoo00<007`0O0002W`0IGoo37`06Woo000JOol:O0001000Ool000001Woo1000E7oo0P00
0Woo2W`0Igoo2W`06goo000KOol8O004000017oo000000001goo1@00C7oo0`000goo0P0027`0JGoo
27`077oo000LOol6O002000017oo001oo`000goo0P002Woo1000AWoo0P001Goo00@007ooOol000Il
06]oo`Il01eoo`008Goo100000Aoo`00Ool000Aoo`8000aoo`D003moo`8000Ioo`03001oogoo00<0
09=oo`008Woo00L007oo000007oo001oo`020004Ool2000?Ool4000iOol20007Ool01P00Oomoo`00
Ool009Aoo`008Woo0P0000Eoo`00001oo`00009oo`03001oogoo00=oo`<0011oo`D0035oo`<000Qo
o`05001oogoo001oo`02002DOol0029oo`800006Ool007oo001oo`000Woo0P001Goo0`004goo1000
:goo0P002Woo00H007ooOomoo`00Ool2002DOol002=oo`800006Ool007oo001oo`000goo00<007oo
Ool01Goo0P005Goo10009Goo0P002goo00H007ooOomoo`00Ool2002EOol002=oo`09001oo`00Ool0
07oo001oo`0000=oo`8000Moo`8001Moo`D001ioo`8000aoo`09001oogooOol007oo001oo`0009Eo
o`0097oo0P0000Aoo`00Ool0009oo`03001oogoo009oo`03001oogoo00Ioo`8001Yoo`@001Qoo`80
00eoo`03001oogoo009oo`04001oo`00002FOol002Aoo`07001oo`00Ool007oo00000Woo00<007oo
Ool00Woo0P0027oo0`006goo1@0047oo0`003Woo00<007ooOol00Woo00D007oo001oo`0009Ioo`00
9Goo0P000Woo00<007oo00000Woo0P0017oo00<007ooOol01goo0`007Woo10002Woo0P003goo0P00
17oo00<007ooOol00P00Ugoo000UOol00`00Ool00002Ool00`00Ool00002Ool20004Ool2000:Ool2
000POol50003Ool2000@Ool00`00Oomoo`03Ool01P00Oomoo`00Ool009Moo`009Goo00<007oo0000
0Woo00@007ooOol000=oo`03001oogoo00=oo`03001oogoo00Uoo`8002=oo`@0011oo`03001oogoo
00Aoo`06001oogoo001oo`00Ugoo000VOol00`00Ool00002Ool01000Oomoo`000goo00<007ooOol0
0goo00<007ooOol02Woo0P0087oo0P000goo10002goo00<007ooOol017oo00H007ooOol007oo002H
Ool002Ioo`03001oo`0000=oo`04001oogoo0003Ool00`00Oomoo`03Ool2000<Ool3000JOol30009
Ool50005Ool00`00Oomoo`04Ool01`00Oomoogoo001oo`0009Qoo`009goo00<007oo00000goo00@0
07ooOol000=oo`03001oogoo00Aoo`03001oogoo00]oo`<001Ioo`80015oo`D000Ioo`07001oogoo
Ool007oo0000VGoo000WOol00`00Ool00003Ool01000Oomoo`0017oo00<007ooOol017oo0P003Goo
0`004Woo0P005Woo1P000Woo00L007ooOomoo`00Ool0002IOol002Qoo`03001oo`0000=oo`04001o
ogoo0004Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool2000>Ool2000GOol00`00Oomoo`04Ool40000
17oo001oo`00VWoo000XOol01000Oomoo`000goo00@007ooOol000Aoo`03001oogoo00Eoo`8000mo
o`<000Qoo`<001Qoo`03001oogoo00Eoo`04001oogooOol5002IOol002Uoo`03001oo`0000=oo`05
001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`0>Ool30004Ool2000JOol00`00Oomoo`06
Ool01`00Oomoogoo001oo`00009oo`@009Eoo`00:Goo00@007ooOol000=oo`05001oogooOol00004
Ool00`00Oomoo`06Ool2000@Ool5000KOol00`00Oomoo`06Ool01@00Oomoogoo00000Woo00<007oo
Ool017oo1000TGoo000YOol01000Oomoo`0017oo00D007ooOomoo`0000Aoo`8000Qoo`03001oogoo
00ioo`@001Uoo`8000Qoo`03001oogoo009oo`04001oogoo000:Ool5002<Ool002Yoo`04001oogoo
0004Ool01@00Oomoogoo000017oo0P0027oo0P0037oo0P0017oo0P005Woo00<007ooOol01goo00<0
07ooOol00Woo00@007ooOol0011oo`@008Qoo`00:Woo00@007ooOol000Aoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo00Ioo`<000Qoo`<0019oo`03001oogoo00Qoo`03
001oogoo009oo`04001oogoo000DOol50023Ool002]oo`04001oogoo0004Ool01@00Oomoogoo0000
1Woo00<007ooOol01goo0P0017oo0P003Goo0`003goo00<007ooOol027oo00<007ooOol00Woo00@0
07ooOol001Yoo`@007moo`00:goo00@007ooOol000Eoo`05001oogooOol00006Ool00`00Oomoo`08
Ool01000Ool000004Goo0`0037oo00<007ooOol027oo00<007ooOol00goo00@007ooOol001ioo`D0
07Yoo`00;7oo00@007ooOol000Eoo`05001oogooOol00006Ool00`00Oomoo`07Ool2000EOol30009
Ool00`00Oomoo`08Ool00`00Oomoo`03Ool01000Oomoo`0097oo1000MWoo000/Ool01000Oomoo`00
1Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00goo0`000Woo0P005Woo0`001Goo00<0
07ooOol02Goo00<007ooOol00goo00@007ooOol002Qoo`D0075oo`00;7oo00D007ooOomoo`0000Eo
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo008000Moo`03001oogoo01Eoo`<0009oo`03
001oogoo00Uoo`03001oogoo00=oo`05001oogooOol0000]Ool4001]Ool002eoo`05001oogooOol0
0005Ool00`00Oomoo`02Ool00`00Oomoo`04Ool2000:Ool2000GOol3000;Ool00`00Oomoo`03Ool0
1@00Oomoogoo0000<Woo1000JGoo000]Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00@007oo
Oomoo`800003Ool007oo00]oo`03001oogoo01Eoo`@000Qoo`03001oogoo00Aoo`05001oogooOol0
000fOol5001TOol002ioo`05001oogooOol00005Ool00`00Oomoo`03Ool30004Ool2000;Ool2000C
Ool20003Ool30006Ool00`00Oomoo`03Ool01@00Oomoogoo0000?7oo1000H7oo000^Ool01@00Oomo
ogoo00001Woo00<007ooOol00`001goo0P0037oo00<007ooOol03goo00<007ooOol01Woo0`000Woo
00<007ooOol017oo00D007ooOomoo`00041oo`D005]oo`00;goo00D007ooOomoo`0000Ioo`8000=o
o`03001oogoo00Eoo`8000aoo`8000ioo`03001oogoo00Uoo`<000Ioo`05001oogooOol00016Ool4
001GOol002moo`05001oogooOol00004Ool30005Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00
Oomoo`0:Ool00`00Oomoo`0<Ool30004Ool01@00Oomoogoo0000BWoo1@00DWoo000`Ool01P00Oomo
ogoo001oo`8000=oo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00]oo`8000Uoo`03001o
ogoo00aoo`03001oogoo00<00003Ool007oo009oo`03001oogoo04ioo`@004ioo`00<7oo00@007oo
Oomoo`8000Ioo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00aoo`03001oogoo00Eoo`03
001oogoo00aoo`03001oogoo00=oo`<000=oo`03001oogoo059oo`@004Yoo`00<7oo100000=oo`00
Ool01Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol037oo00<007ooOol00goo00<007oo
Ool037oo00<007ooOol01Goo00<007oo00000`00F7oo1@00AGoo000_Ool30003Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool20002Ool00`00Oomoo`0=Ool00`00
Oomoo`05Ool01000Oomoogoo0`00G7oo1000@Goo000]Ool20002Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0=Ool2000?Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool00`00Ool00002001NOol5000lOol001aoo`Il00Uoo`8000Eoo`03001oogoo009o
o`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00aoo`<000eoo`03001o
ogoo00Eoo`03001oogoo009oo`03001oogoo009oo`<000Uoo`Il059oo`@001Eoo`Il01eoo`006goo
27`01Goo0`001goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01goo
0P002Woo0P000goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol017oo
10001Goo27`0EGoo1@003goo27`077oo000JOol:O002Ool2000;Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`07Ool20008Ool00`00Oomoo`04Ool20009Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`08Ool30002Ool:O01IOol4000:Ool:O00KOol001Uoo`al
0003001oogoo00]oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Mo
o`8000Ioo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo009oo`03001o
ogoo00Yoo`8000al05aoo`@000Eoo`al01Yoo`0067oo3G`03Woo00<007ooOol00goo00<007ooOol0
1Woo00<007ooOol017oo00<007ooOol01goo0P0017oo00<007ooOol02Goo0P0017oo00<007ooOol0
1Woo00<007ooOol00goo00<007ooOol02goo3G`0H7oo10003G`06Woo000HOol>O00>Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`08Ool01000Oomoo`003Woo00D007oo
Oomoo`0000Qoo`03001oogoo009oo`03001oogoo00aoo`il06=oo`il01Uoo`0067oo3W`03Woo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol027oo0P0047oo0`0027oo00<0
07ooOol00goo00<007ooOol037oo3W`0Hgoo3W`06Goo000HOol>O00?Ool00`00Oomoo`02Ool00`00
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`07Ool2000AOol20008Ool00`00Oomoo`02Ool00`00
Oomoo`0=Ool>O01SOol>O00IOol001Qoo`il00moo`03001oogoo00=oo`03001oogoo00Moo`03001o
ogoo00Aoo`03001oogoo00Ioo`04001oogoo000?Ool00`00Oomoo`020005Ool00`00Oomoo`03Ool0
0`00Oomoo`0=Ool>O01SOol>O00IOol001Qoo`el015oo`03001oogoo009oo`03001oogoo00Moo`03
001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00ioo`el0003001oogoo065oo`el01Yoo`006Goo
37`04Goo00<007ooOol00goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00Woo00<007oo
Ool017oo00<007ooOol02Woo00<007ooOol017oo00@007ooOol000Eoo`03001oogoo00moo`al0003
Ool00000069oo`al01Yoo`006Woo2W`04goo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
1Goo00@007ooOol000Qoo`03001oogoo00Qoo`03001oogoo00Ioo`8000Eoo`03001oogoo015oo`Yl
00Aoo`80065oo`Yl01]oo`006goo27`057oo00<007ooOol00goo00<007ooOol027oo00<007ooOol0
1Goo0P002Woo0P001goo00<007ooOol027oo0P0017oo00<007ooOol04Woo27`01goo0`00Ggoo27`0
77oo000LOol6O00EOol00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Ool0000;
Ool20006Ool00`00Oomoo`07Ool00`00Oomoo`020002Ool00`00Oomoo`0COol6O00;Ool2001NOol6
O00MOol003Qoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo009oo`05001oogooOol0000;
Ool20004Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000YOol2001oOol003Qoo`03001oogoo00Ao
o`03001oogoo00Qoo`04001oogoo0005Ool00`00Oomoo`09Ool20002Ool00`00Oomoo`08Ool00`00
Oomoo`04Ool2000ZOol2001mOol003Uoo`03001oogoo00=oo`03001oogoo00Qoo`03001oo`0000Io
o`03001oogoo00]oo`03001oo`0000Yoo`03001oogoo00=oo`04001oogoo000[Ool2001kOol003Uo
o`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Qo
o`03001oogoo00Aoo`04001oogooOol2000[Ool3001hOol003Yoo`03001oogoo00=oo`03001oogoo
00Moo`03001oo`0000Qoo`03001oogoo00Uoo`03001oo`0000Uoo`03001oogoo00=oo`03001oogoo
00Aoo`03001oogoo02]oo`8007Ioo`00>Woo00<007ooOol017oo00<007ooOol01Goo00D007ooOomo
o`0000Qoo`03001oogoo00Moo`05001oogooOol00007Ool00`00Oomoo`04Ool00`00Oomoo`05Ool2
000]Ool2001dOol003Yoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo
00Moo`03001oogoo02aoo`80079oo`00>goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol01goo00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol02Goo00<007ooOol0;Goo0P00L7oo000kOol00`00Oomoo`05Ool01000Ool00000
27oo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01Woo0P0000=oo`00Ool01Woo00<007oo
Ool02Woo0P00;goo0`00KGoo000lOol00`00Oomoo`04Ool2000;Ool00`00Oomoo`07Ool01000Oomo
o`002Woo0`001Woo00<007ooOol03Goo00<007ooOol0;goo0P00Jgoo000lOol00`00Oomoo`04Ool2
000;Ool00`00Oomoo`07Ool01000Oomoo`002goo0P001Woo00<007ooOol03Woo0P00<Goo0P00JGoo
000mOol00`00Oomoo`02Ool00`00Ool0000<Ool00`00Oomoo`07Ool2000<Ool30004Ool00`00Oomo
o`0AOol00`00Oomoo`0`Ool2001WOol003eoo`05001oogooOol00003Ool00`00Oomoo`0:Ool00`00
Oomoo`06Ool2000;Ool00`00Oomoo`020003Ool00`00Oomoo`0BOol2000bOol2001UOol003ioo`03
001oo`0000Aoo`03001oogoo00Yoo`03001oogoo00Ioo`03001oo`0000Yoo`03001oogoo009oo`03
001oo`0001Moo`03001oogoo035oo`<0069oo`00?Woo0P001Woo00<007ooOol02Woo00<007ooOol0
17oo00D007ooOomoo`0000Qoo`03001oogoo00Aoo`8001Qoo`8003Aoo`80061oo`00?Woo00<007oo
Ool01Goo00<007ooOol02goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol067oo00<007ooOol0<goo0P00GWoo000mOol00`00Ool00007Ool00`00Oomo
o`0;Ool01000Oomoo`001goo00<007ooOol00goo00<007ooOol01Goo00<007oo00006Woo0P00=Goo
0P00G7oo000lOol01000Oomoo`001goo00<007ooOol02goo00@007ooOol000Qoo`03001oogoo009o
o`03001oogoo00Eoo`04001oogoo000KOol00`00Oomoo`0dOol2001JOol003Yoo`8000Aoo`03001o
ogoo00Eoo`03001oogoo00]oo`8000Uoo`05001oogooOol00007Ool00`00Oomoo`02Ool2000JOol0
0`00Oomoo`0eOol3001GOol003Uoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Yoo`80
00Yoo`03001oo`0000Qoo`03001oogoo00=oo`8001Yoo`8003Qoo`8005Eoo`00>7oo00<007ooOol0
1Woo00<007ooOol01Goo00<007ooOol02Goo00@007ooOol000Yoo`8000Moo`03001oogoo00Eoo`80
01]oo`03001oogoo03Moo`8005=oo`00=goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol0
27oo00@007ooOol000Yoo`8000Moo`03001oogoo00Ioo`8001]oo`8003Uoo`80055oo`00=Woo00<0
07ooOol027oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01goo00<0
07oo00001Woo00<007ooOol01goo0P0077oo00<007ooOol0>7oo0P00Cgoo000eOol00`00Oomoo`0:
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01@00Oomoogoo
000017oo00<007ooOol02Goo0P0077oo0P00>Woo0`00C7oo000dOol00`00Oomoo`0;Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomo
ogoo00003Goo00<007ooOol06goo00<007ooOol0>Woo0P00BWoo000cOol00`00Oomoo`0=Ool00`00
Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00
Ool0000?Ool00`00Oomoo`0KOol2000lOol20018Ool0039oo`03001oogoo00ioo`03001oogoo00Io
o`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`00011o
o`03001oogoo01aoo`03001oogoo03]oo`8004Ioo`00<Goo00<007ooOol047oo00<007ooOol01Woo
00@007ooOol000aoo`04001oogoo0008Ool00`00Oomoo`0@Ool00`00Oomoo`0LOol2000mOol20014
Ool0031oo`03001oogoo015oo`03001oogoo00Ioo`04001oogoo000<Ool01000Oomoo`0027oo0P00
4Woo00<007ooOol07Goo00<007ooOol0?7oo0P00@Woo000^Ool2000EOol00`00Oomoo`06Ool2000>
Ool20008Ool01000Oomoo`004Woo0P007Woo0P00?Woo0`00?goo000]Ool00`00Oomoo`0EOol00`00
Oomoo`06Ool2000>Ool20008Ool01@00Oomoogoo00004Woo0P007goo00<007ooOol0?Woo0P00?Goo
000/Ool00`00Oomoo`0FOol00`00Oomoo`05Ool00`00Ool0000>Ool00`00Ool00007Ool00`00Oomo
o`02Ool00`00Oomoo`0@Ool2000OOol00`00Oomoo`0oOol2000kOol002]oo`03001oogoo01Qoo`03
001oogoo00Aoo`04001oogoo000<Ool01000Oomoo`001Woo00<007ooOol017oo00<007ooOol047oo
0P007goo0P00@Goo0P00>Goo000ZOol00`00Oomoo`0IOol00`00Oomoo`03Ool01@00Oomoogoo0000
37oo00D007ooOomoo`0000Eoo`03001oogoo00Eoo`03001oogoo011oo`80021oo`03001oogoo041o
o`8003Moo`00:Goo00<007ooOol06goo00D007ooOomoo`0000Eoo`03001oogoo00Qoo`03001oogoo
00=oo`05001oogooOol00008Ool00`00Oomoo`0AOol2000POol20012Ool3000dOol002Qoo`03001o
ogoo01aoo`04001oogoo0006Ool00`00Oomoo`08Ool00`00Oomoo`04Ool01000Oomoo`002Goo00<0
07ooOol04Woo00<007ooOol07goo00<007ooOol0@Woo0P00<Woo000WOol00`00Oomoo`0NOol00`00
Ool00007Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Ool0000;Ool00`00Oomoo`0BOol00`00
Oomoo`0OOol20014Ool2000`Ool002Ioo`03001oogoo01moo`8000Qoo`03001oogoo00Ioo`03001o
ogoo00Ioo`8000aoo`03001oogoo019oo`03001oogoo021oo`03001oogoo04=oo`8002ioo`0077oo
1W`00goo00<007ooOol087oo00<007ooOol027oo00<007ooOol017oo00<007ooOol027oo00<007oo
Ool02goo00<007ooOol04Woo00@007ooOomoo`Il01Uoo`8004Eoo`8000Uoo`Il01eoo`006goo27`0
0P008goo0P002Goo00<007ooOol017oo00<007ooOol01goo0P003Woo00<007ooOol04Woo0P0027`0
6Woo00<007ooOol0A7oo0`001Goo27`077oo000JOol:O00SOol00`00Ool0000:Ool00`00Oomoo`02
Ool00`00Oomoo`08Ool00`00Ool0000>Ool00`00Oomoo`0BOol:O00JOol20017Ool20002Ool:O00K
Ool001Uoo`al025oo`05001oogooOol0000:Ool01000Oomoo`002Woo00D007ooOomoo`0000ioo`03
001oogoo011oo`al01]oo`03001oogoo04Ioo`03001l07`000Yl01Yoo`0067oo3G`087oo00<007oo
Ool00Woo00<007ooOol027oo00@007ooOol000Yoo`03001oogoo009oo`03001oogoo00]oo`03001o
ogoo00moo`el01aoo`03001oogoo04Eoo`el01Yoo`0067oo3W`07goo00<007ooOol00goo00<007oo
Ool027oo0P002Woo00<007ooOol00goo00<007ooOol037oo00<007ooOol03Woo3W`077oo0P00AGoo
3W`06Goo000HOol>O00NOol00`00Oomoo`04Ool00`00Oomoo`08Ool2000:Ool00`00Oomoo`04Ool0
0`00Oomoo`0<Ool00`00Oomoo`0=Ool>O00NOol00`00Oomoo`12Ool>O00IOol001Qoo`il01eoo`03
001oogoo00Ioo`03001oogoo00Moo`8000Uoo`03001oogoo00Ioo`03001oogoo00aoo`03001oogoo
00aoo`il01moo`80049oo`il01Uoo`0067oo3W`077oo00<007ooOol01goo00<007ooOol01goo0P00
2Goo00<007ooOol01goo00<007ooOol037oo00<007ooOol02goo3W`08Goo00<007ooOol0?goo3W`0
6Goo000HOol=O00MOol00`00Oomoo`07Ool00`00Oomoo`06Ool01000Oomoo`0027oo00<007ooOol0
1goo00<007ooOol03Goo00<007ooOol02Woo3G`08goo0P00?goo3G`06Woo000IOol<O00LOol00`00
Oomoo`09Ool00`00Oomoo`05Ool01000Oomoo`001goo00<007ooOol02Goo00<007ooOol03Goo00<0
07ooOol02Woo37`09Goo00<007ooOol0?Goo37`06Woo000JOol:O00LOol00`00Oomoo`0:Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00
Oomoo`0:Ool:O0000`00Oomoo`0TOol2000nOol:O00KOol001]oo`Ql01eoo`03001oogoo00]oo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00eoo`03
001oogoo00]oo`Ql009oo`03001oogoo02Eoo`03001oogoo03aoo`Ql01aoo`0077oo1W`07Goo00<0
07ooOol037oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol037oo00<0
07ooOol03Goo00<007ooOol02goo1W`017oo00<007ooOol09Goo0P00?Goo1W`07Goo000nOol00`00
Oomoo`0>Ool01000Oomoo`0027oo00@007ooOol0011oo`03001oogoo00eoo`03001oogoo01Eoo`03
001oogoo02Ioo`03001oogoo05eoo`00?Goo00<007ooOol03goo00@007ooOol000Qoo`04001oogoo
000AOol00`00Oomoo`0=Ool00`00Oomoo`0EOol00`00Oomoo`0VOol2001MOol003eoo`03001oogoo
00moo`03001oo`0000Yoo`03001oo`00015oo`03001oogoo00ioo`03001oogoo01Eoo`03001oogoo
02Moo`03001oogoo05Yoo`00?7oo00<007ooOol04Goo0P002Woo0P004goo00<007ooOol03Woo00<0
07ooOol05Goo0P00:7oo00<007ooOol0FGoo000kOol00`00Oomoo`0BOol00`00Oomoo`0:Ool00`00
Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`0FOol00`00Oomoo`0VOol2001IOol003Yoo`03001o
ogoo01=oo`8000Yoo`8001Eoo`03001oogoo00ioo`03001oogoo01Ioo`03001oogoo02Moo`03001o
ogoo05Ioo`00>Woo00<007ooOol04Woo00<007oo00002Woo00<007oo000057oo00<007ooOol03Woo
00<007ooOol05goo00<007ooOol09goo0P00EWoo000iOol00`00Oomoo`0COol01000Oomoo`0027oo
00@007ooOol001Eoo`03001oogoo00ioo`03001oogoo01Moo`03001oogoo02Qoo`03001oogoo05=o
o`00>7oo00<007ooOol04goo00D007ooOomoo`0000Qoo`05001oogooOol0000EOol00`00Oomoo`0>
Ool00`00Oomoo`0GOol00`00Oomoo`0XOol2001COol003Qoo`03001oogoo019oo`03001oogoo00=o
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo019oo`03001oogoo00moo`03001oogoo01Mo
o`03001oogoo02Uoo`03001oogoo051oo`00=goo00<007ooOol04goo00<007ooOol00goo00<007oo
Ool017oo00<007ooOol00goo00<007ooOol04goo00<007ooOol03goo00<007ooOol05goo00<007oo
Ool0:Goo0P00D7oo000fOol00`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`0COol00`00Oomoo`0?Ool00`00Oomoo`0GOol00`00Oomoo`0ZOol00`00Oomo
o`1=Ool003Eoo`03001oogoo01Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Eoo`03
001oogoo01Aoo`03001oogoo00moo`03001oogoo01Moo`03001oogoo02Yoo`8004eoo`00=Goo00<0
07ooOol04goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol04goo00<0
07ooOol047oo00<007ooOol05goo00<007ooOol0:goo00<007ooOol0BWoo000dOol00`00Oomoo`0D
Ool00`00Oomoo`07Ool01000Oomoo`002Goo00<007ooOol057oo00<007ooOol03goo00<007ooOol0
67oo0P00;7oo00<007ooOol0BGoo000cOol00`00Oomoo`0DOol00`00Oomoo`08Ool01000Oomoo`00
2Woo00<007ooOol057oo00<007ooOol03goo00<007ooOol06Goo00<007ooOol0:Woo0P00BGoo000b
Ool00`00Oomoo`0EOol00`00Oomoo`09Ool2000;Ool00`00Oomoo`0EOol00`00Oomoo`0?Ool00`00
Oomoo`0IOol00`00Oomoo`0[Ool00`00Oomoo`16Ool0039oo`03001oogoo01Aoo`03001oogoo00Yo
o`8000aoo`03001oogoo01Aoo`03001oogoo011oo`03001oogoo01Uoo`03001oogoo02]oo`8004Io
o`00<Goo00<007ooOol05Goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol05Goo00<007oo
Ool047oo00<007ooOol06Goo00<007ooOol0;7oo00<007ooOol0@goo000`Ool00`00Oomoo`0EOol0
0`00Oomoo`0;Ool2000=Ool00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`0IOol00`00Oomo
o`0/Ool20013Ool002moo`03001oogoo01Eoo`03001oogoo00aoo`8000ioo`03001oogoo01Eoo`03
001oogoo011oo`03001oogoo01Uoo`03001oogoo02eoo`03001oogoo041oo`00;goo00<007ooOol0
5Goo00<007ooOol02goo00@007ooOol000eoo`03001oogoo01Eoo`03001oogoo015oo`03001oogoo
01Uoo`03001oogoo02eoo`80041oo`00;Woo00<007ooOol05Goo00<007ooOol037oo00@007ooOol0
00ioo`03001oogoo01Eoo`03001oogoo015oo`03001oogoo01Uoo`03001oogoo02ioo`03001oogoo
03eoo`00;Goo00<007ooOol05Woo00<007ooOol02goo00<007ooOol00Woo00<007ooOol02goo00<0
07ooOol05Woo00<007ooOol047oo00<007ooOol06Woo00<007ooOol0;Woo0P00?Goo000]Ool00`00
Oomoo`0EOol00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0EOol00`00
Oomoo`0AOol00`00Oomoo`0JOol00`00Oomoo`0_Ool00`00Oomoo`0jOol002aoo`03001oogoo01Io
o`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo01Ioo`03001oogoo015o
o`03001oogoo01Yoo`80031oo`8003Yoo`00:goo00<007ooOol05Woo00<007ooOol037oo00<007oo
Ool017oo00<007ooOol037oo00<007ooOol05Woo00<007ooOol04Goo00<007ooOol06goo00<007oo
Ool0;goo00<007ooOol0=goo000ZOol00`00Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`04Ool0
0`00Oomoo`0<Ool00`00Oomoo`0GOol00`00Oomoo`0AOol00`00Oomoo`0KOol00`00Oomoo`0_Ool0
0`00Oomoo`0fOol002Yoo`03001oogoo01Ioo`03001oogoo00aoo`03001oogoo00Ioo`03001oogoo
00aoo`03001oogoo01Ioo`03001oogoo019oo`03001oogoo01]oo`03001oogoo02moo`8003Ioo`00
:Goo00<007ooOol05goo00<007ooOol037oo00<007ooOol01Woo00<007ooOol037oo00<007ooOol0
5goo00<007ooOol04Woo00<007ooOol06goo00<007ooOol0<7oo00<007ooOol0<goo000XOol00`00
Oomoo`0GOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`0GOol00`00
Oomoo`0BOol00`00Oomoo`0KOol00`00Oomoo`0`Ool2000cOol002Moo`03001oogoo01Moo`03001o
ogoo00eoo`03001oogoo00Qoo`03001oogoo00eoo`03001oogoo01Moo`03001oogoo015oo`03001o
ogoo01aoo`03001oogoo035oo`03001oogoo031oo`009goo00<007ooOol05goo00<007ooOol037oo
00<007ooOol02Woo00<007ooOol037oo00<007ooOol05goo00<007ooOol04Woo00<007ooOol077oo
00<007ooOol0<Goo0P00<7oo000VOol00`00Oomoo`0GOol00`00Oomoo`0=Ool00`00Oomoo`0:Ool0
0`00Oomoo`0=Ool00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`0LOol00`00Oomoo`0bOol0
0`00Oomoo`0]Ool002Eoo`03001oogoo01Qoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo
00aoo`03001oogoo01Qoo`03001oogoo019oo`03001oogoo01aoo`03001oogoo039oo`8002eoo`00
9Goo00<007ooOol05goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol03Goo00<007ooOol0
5goo00<007ooOol04goo00<007ooOol077oo00<007ooOol0<goo00<007ooOol0:Woo000TOol00`00
Oomoo`0HOol00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0HOol00`00
Oomoo`0COol00`00Oomoo`0LOol2000dOol2000ZOol001aoo`Il0003Ool007oo01Uoo`03001oogoo
00eoo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo01Qoo`03001oog`000El00ioo`03001o
ogoo01eoo`03001oogoo03=oo`03001oogoo00Aoo`Il01eoo`006goo27`06goo00<007ooOol03Goo
00<007ooOol03Woo00<007ooOol03Goo00<007ooOol06Goo27`03Woo00<007ooOol07Goo00<007oo
Ool0<goo00<007ooOol00Woo27`077oo000JOol:O00IOol00`00Oomoo`0=Ool00`00Oomoo`0@Ool0
0`00Oomoo`0=Ool00`00Oomoo`0GOol:O00=Ool00`00Oomoo`0NOol00`00Oomoo`0cOol200000goo
O01l0008O00KOol001Uoo`al01Qoo`03001oogoo00eoo`03001oogoo011oo`03001oogoo00eoo`03
001oogoo01Ioo`al00eoo`03001oogoo01ioo`03001oogoo03Aoo`al01Yoo`0067oo3G`05goo00<0
07ooOol03Goo00<007ooOol04Woo00<007ooOol03Goo00<007ooOol057oo3G`03Woo00<007ooOol0
7Woo00<007ooOol0<Woo3G`06Woo000HOol>O00EOol00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00
Oomoo`0>Ool00`00Oomoo`0COol>O00>Ool00`00Oomoo`0NOol00`00Oomoo`0aOol>O00IOol001Qo
o`il01Eoo`03001oogoo00ioo`03001oogoo019oo`03001oogoo00ioo`03001oogoo01=oo`il00mo
o`03001oogoo01ioo`03001oogoo031oo`il01Uoo`0067oo3W`057oo00<007ooOol03Woo00<007oo
Ool057oo00<007ooOol03Woo00<007ooOol04Woo3W`047oo00<007ooOol07Woo00<007ooOol0;goo
3W`06Goo000HOol>O00DOol00`00Oomoo`0>Ool00`00Oomoo`0DOol00`00Oomoo`0>Ool00`00Oomo
o`0BOol>O00AOol00`00Oomoo`0NOol00`00Oomoo`0^Ool>O00IOol001Qoo`el01Aoo`03001oogoo
00ioo`03001oogoo01Ioo`03001oogoo00ioo`03001oogoo015oo`el01=oo`03001oogoo01ioo`03
001oogoo02eoo`el01Yoo`006Goo37`057oo00<007ooOol03Woo00<007ooOol05Woo00<007ooOol0
3Woo00<007ooOol04Woo37`04goo00<007ooOol07goo0P00;Woo37`06Woo000JOol:O00DOol00`00
Oomoo`0>Ool00`00Oomoo`0HOol00`00Oomoo`0>Ool00`00Oomoo`0BOol:O00EOol00`00Oomoo`0P
Ool00`00Oomoo`0/Ool:O00KOol001]oo`Ql01Eoo`03001oogoo00ioo`03001oogoo01Qoo`03001o
ogoo00ioo`03001oogoo01=oo`Ql01Moo`03001oogoo021oo`03001oogoo02aoo`Ql01aoo`0077oo
1W`05Goo00<007ooOol03Woo00<007ooOol06Woo00<007ooOol03Woo00<007ooOol04goo1W`06Goo
00<007ooOol087oo00<007ooOol0;7oo1W`07Goo000gOol00`00Oomoo`0>Ool00`00Oomoo`0JOol0
0`00Oomoo`0>Ool00`00Oomoo`0cOol00`00Oomoo`0POol00`00Oomoo`1>Ool003Ioo`03001oogoo
00moo`03001oogoo01Yoo`03001oogoo00moo`03001oogoo03=oo`03001oogoo021oo`03001oogoo
04eoo`00=Goo00<007ooOol03goo00<007ooOol077oo00<007ooOol03goo00<007ooOol0<goo00<0
07ooOol087oo00<007ooOol0C7oo000eOol00`00Oomoo`0?Ool00`00Oomoo`0LOol00`00Oomoo`0?
Ool00`00Oomoo`0dOol00`00Oomoo`0POol00`00Oomoo`1;Ool003Aoo`03001oogoo00moo`03001o
ogoo01ioo`03001oogoo00moo`03001oogoo03=oo`03001oogoo025oo`03001oogoo04Yoo`00=7oo
00<007ooOol03goo00<007ooOol07Woo00<007ooOol03goo00<007ooOol0=7oo00<007ooOol08Goo
00<007ooOol0BGoo000cOol00`00Oomoo`0?Ool00`00Oomoo`0POol00`00Oomoo`0?Ool00`00Oomo
o`0dOol00`00Oomoo`0QOol00`00Oomoo`18Ool003=oo`03001oogoo00moo`03001oogoo021oo`03
001oogoo00moo`03001oogoo03Eoo`03001oogoo025oo`8004Qoo`00<Woo00<007ooOol047oo00<0
07ooOol087oo00<007ooOol047oo00<007ooOol0=Goo00<007ooOol08Woo00<007ooOol0AGoo000b
Ool00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`0?Ool00`00Oomoo`0fOol00`00Oomoo`0R
Ool00`00Oomoo`14Ool0035oo`03001oogoo011oo`03001oogoo029oo`03001oogoo011oo`03001o
ogoo03Ioo`03001oogoo029oo`03001oogoo04=oo`00<Goo00<007ooOol03goo00<007ooOol097oo
00<007ooOol03goo00<007ooOol0=goo00<007ooOol08Woo00<007ooOol0@Woo000`Ool00`00Oomo
o`0@Ool00`00Oomoo`0TOol00`00Oomoo`0@Ool00`00Oomoo`0fOol00`00Oomoo`0SOol00`00Oomo
o`11Ool002moo`03001oogoo011oo`03001oogoo02Ioo`03001oogoo011oo`03001oogoo03Ioo`03
001oogoo02=oo`03001oogoo041oo`00;goo00<007ooOol047oo00<007ooOol09Woo00<007ooOol0
47oo00<007ooOol0=goo00<007ooOol08goo00<007ooOol0?goo000^Ool00`00Oomoo`0@Ool00`00
Oomoo`0XOol00`00Oomoo`0@Ool00`00Oomoo`0gOol00`00Oomoo`0SOol00`00Oomoo`0nOol002io
o`03001oogoo011oo`03001oogoo02Qoo`03001oogoo011oo`03001oogoo03Qoo`03001oogoo02=o
o`03001oogoo03eoo`00;Goo00<007ooOol04Goo00<007ooOol0:7oo00<007ooOol04Goo00<007oo
Ool0>7oo00<007ooOol08goo00<007ooOol0?7oo000]Ool00`00Oomoo`0@Ool00`00Oomoo`0ZOol0
0`00Oomoo`0@Ool00`00Oomoo`0iOol00`00Oomoo`0SOol2000lOol002aoo`03001oogoo015oo`03
001oogoo02Yoo`03001oogoo015oo`03001oogoo03Uoo`03001oogoo02Aoo`03001oogoo03Uoo`00
;7oo00<007ooOol047oo00<007ooOol0;7oo00<007ooOol047oo00<007ooOol0>Goo00<007ooOol0
9Goo00<007ooOol0>7oo000[Ool00`00Oomoo`0AOol00`00Oomoo`0/Ool00`00Oomoo`0AOol00`00
Oomoo`0iOol00`00Oomoo`0UOol00`00Oomoo`0gOol002]oo`03001oogoo011oo`03001oogoo02io
o`03001oogoo011oo`03001oogoo03Yoo`03001oogoo02Eoo`03001oogoo03Ioo`00:Woo00<007oo
Ool04Goo00<007ooOol0;Woo00<007ooOol04Goo00<007ooOol0>Woo00<007ooOol09Goo00<007oo
Ool0=Goo000YOol00`00Oomoo`0BOol00`00Oomoo`0^Ool00`00Oomoo`0BOol00`00Oomoo`0jOol0
0`00Oomoo`0UOol00`00Oomoo`0dOol002Uoo`03001oogoo015oo`03001oogoo031oo`03001oogoo
015oo`03001oogoo03]oo`03001oogoo02Eoo`03001oogoo03=oo`00:7oo00<007ooOol04Woo00<0
07ooOol0<7oo00<007ooOol04Woo00<007ooOol0>goo00<007ooOol09Goo00<007ooOol0<Woo000X
Ool00`00Oomoo`0AOol00`00Oomoo`0bOol00`00Oomoo`0AOol00`00Oomoo`0lOol00`00Oomoo`0U
Ool00`00Oomoo`0aOol002Moo`03001oogoo019oo`03001oogoo039oo`03001oogoo019oo`03001o
ogoo03]oo`03001oogoo02Ioo`03001oogoo031oo`009goo00<007ooOol04Goo00<007ooOol0=7oo
00<007ooOol04Goo00<007ooOol0?7oo00<007ooOol09Woo0P00<7oo000VOol00`00Oomoo`0BOol0
0`00Oomoo`0dOol00`00Oomoo`0BOol00`00Oomoo`0lOol00`00Oomoo`0WOol00`00Oomoo`0]Ool0
02Ioo`03001oogoo015oo`03001oogoo03Ioo`03001oogoo015oo`03001oogoo03eoo`03001oogoo
02Moo`03001oogoo02aoo`009Goo00<007ooOol04Woo00<007ooOol0=Woo00<007ooOol04Woo00<0
07ooOol0?Goo00<007ooOol09goo00<007ooOol0:goo000UOol00`00Oomoo`0BOol00`00Oomoo`0f
Ool00`00Oomoo`0BOol00`00Oomoo`0nOol00`00Oomoo`0WOol00`00Oomoo`0ZOol002Aoo`03001o
ogoo019oo`03001oogoo03Qoo`03001oogoo019oo`03001oogoo03ioo`03001oogoo02Moo`03001o
ogoo02Uoo`008goo00<007ooOol04goo00<007ooOol0>7oo00<007ooOol04goo00<007ooOol0?Woo
00<007ooOol09goo00<007ooOol0:7oo000SOol00`00Oomoo`0BOol00`00Oomoo`0jOol00`00Oomo
o`0BOol00`00Oomoo`0nOol00`00Oomoo`0XOol00`00Oomoo`0WOol0029oo`03001oogoo01=oo`03
001oogoo03Yoo`03001oogoo01=oo`03001oogoo03ioo`03001oogoo02Qoo`03001oogoo02Ioo`00
77oo1W`000<007ooOol04Woo00<007ooOol0?7oo00<007ooOol04Woo00<007`0O00017`0>goo00<0
07ooOol0:7oo00<007ooOol00Woo1W`07Goo000KOol8O00DOol00`00Oomoo`0lOol00`00Oomoo`0B
Ool8O00kOol00`00Oomoo`0XOol00`00Oomoo`08O00LOol001Yoo`Yl01=oo`03001oogoo03aoo`03
001oogoo015oo`Yl03]oo`03001oogoo02Qoo`03001l07`000Ql01]oo`006Goo37`04Goo00<007oo
Ool0?Woo00<007ooOol03goo37`0>goo00<007ooOol09goo37`06Woo000HOol=O00AOol00`00Oomo
o`0nOol00`00Oomoo`0>Ool=O00lOol00`00Oomoo`0UOol=O00JOol001Qoo`il00moo`03001oogoo
041oo`03001oogoo00eoo`il03aoo`03001oogoo02Aoo`il01Uoo`0067oo3W`03goo00<007ooOol0
@7oo00<007ooOol03Goo3W`0?7oo00<007ooOol097oo3W`06Goo000HOol>O00>Ool00`00Oomoo`12
Ool00`00Oomoo`0<Ool>O00mOol00`00Oomoo`0SOol>O00IOol001Qoo`il00ioo`03001oogoo049o
o`03001oogoo00aoo`il03ioo`03001oogoo029oo`il01Uoo`0067oo3G`03Woo00<007ooOol0A7oo
00<007ooOol02goo3G`0@7oo00<007ooOol08Goo3G`06Woo000IOol<O00>Ool00`00Oomoo`14Ool0
0`00Oomoo`0<Ool<O011Ool00`00Oomoo`0QOol<O00JOol001Yoo`Yl00moo`03001oogoo04Aoo`03
001oogoo00eoo`Yl04=oo`03001oogoo025oo`Yl01]oo`006goo27`03goo00<007ooOol0AWoo00<0
07ooOol03Goo27`0AGoo00<007ooOol08Goo27`077oo000LOol6O00@Ool00`00Oomoo`16Ool00`00
Oomoo`0>Ool6O017Ool00`00Oomoo`0QOol6O00MOol0035oo`03001oogoo04Qoo`03001oogoo05Yo
o`03001oogoo04Aoo`00<Goo00<007ooOol0B7oo00<007ooOol0Fgoo00<007ooOol0@goo000`Ool0
0`00Oomoo`1:Ool00`00Oomoo`1KOol00`00Oomoo`12Ool0031oo`03001oogoo04Yoo`03001oogoo
05aoo`03001oogoo045oo`00<7oo00<007ooOol0BWoo00<007ooOol0GGoo00<007ooOol0@7oo000_
Ool00`00Oomoo`1<Ool00`00Oomoo`1MOol00`00Oomoo`0oOol002moo`03001oogoo04aoo`03001o
ogoo05ioo`03001oogoo03ioo`00;Woo00<007ooOol0CWoo00<007ooOol0GWoo00<007ooOol0?Goo
000^Ool00`00Oomoo`1>Ool00`00Oomoo`1NOol00`00Oomoo`0mOol002eoo`03001oogoo051oo`03
001oogoo05ioo`03001oogoo03aoo`00;Goo00<007ooOol0D7oo00<007ooOol0Ggoo00<007ooOol0
>goo000/Ool00`00Oomoo`1BOol00`00Oomoo`1OOol00`00Oomoo`0jOol002aoo`03001oogoo059o
o`03001oogoo061oo`03001oogoo03Uoo`00;7oo00<007ooOol0DWoo00<007ooOol0HGoo00<007oo
Ool0>7oo000[Ool00`00Oomoo`1DOol00`00Oomoo`1QOol00`00Oomoo`0gOol002]oo`03001oogoo
05Aoo`03001oogoo069oo`03001oogoo03Ioo`00:Woo00<007ooOol0EWoo00<007ooOol0HGoo00<0
07ooOol0=Woo000ZOol00`00Oomoo`1FOol00`00Oomoo`1ROol00`00Oomoo`0eOol002Uoo`03001o
ogoo05Qoo`03001oogoo069oo`03001oogoo03Aoo`00:Goo00<007ooOol0F7oo00<007ooOol0Hgoo
00<007ooOol0<goo000YOol00`00Oomoo`1HOol00`00Oomoo`1TOol00`00Oomoo`0bOol002Qoo`03
001oogoo05Yoo`03001oogoo06Aoo`03001oogoo035oo`00:7oo00<007ooOol0FWoo00<007ooOol0
IGoo00<007ooOol0<7oo000WOol00`00Oomoo`1LOol00`00Oomoo`1UOol00`00Oomoo`0_Ool002Mo
o`03001oogoo05aoo`03001oogoo06Eoo`03001oogoo02moo`009Woo00<007ooOol0GWoo00<007oo
Ool0IGoo00<007ooOol0;Woo000VOol00`00Oomoo`1NOol00`00Oomoo`1VOol00`00Oomoo`0]Ool0
02Eoo`03001oogoo061oo`03001oogoo06Ioo`03001oogoo02aoo`009Goo00<007ooOol0H7oo00<0
07ooOol0Igoo00<007ooOol0:goo000UOol00`00Oomoo`1POol00`00Oomoo`1XOol00`00Oomoo`0Z
Ool002Aoo`03001oogoo069oo`03001oogoo06Qoo`03001oogoo02Uoo`0097oo00<007ooOol0HWoo
00<007ooOol0JGoo00<007ooOol0:7oo000SOol00`00Oomoo`1TOol00`00Oomoo`1XOol00`00Oomo
o`0XOol002=oo`03001oogoo06Aoo`03001oogoo06Uoo`03001oogoo02Moo`008Woo00<007ooOol0
IWoo00<007ooOol0JGoo00<007ooOol09Woo000ROol00`00Oomoo`1VOol00`00Oomoo`1ZOol00`00
Oomoo`0UOol0029oo`03001oogoo06Ioo`03001oogoo06]oo`03001oogoo02Aoo`008Goo00<007oo
Ool0J7oo00<007ooOol0Jgoo00<007ooOol08goo000LOol6O01ZOol6O01YOol00`00Ooml0005O00M
Ool001]oo`Ql06Qoo`Ql06Uoo`Ql01aoo`006Woo2W`0IWoo2W`0Igoo2W`06goo000IOol<O01TOol<
O01UOol<O00JOol001Qoo`el06=oo`el06Aoo`el01Yoo`0067oo3W`0HWoo3W`0Hgoo3W`06Goo000H
Ool>O01ROol>O01SOol>O00IOol001Qoo`il069oo`il06=oo`il01Uoo`0067oo3W`0HWoo3W`0Hgoo
3W`06Goo000HOol=O01SOol=O01TOol=O00JOol001Uoo`al06Aoo`al06Eoo`al01Yoo`006Woo2W`0
IWoo2W`0Igoo2W`06goo000KOol8O01XOol8O01YOol8O00LOol001aoo`Il06Yoo`Il06]oo`Il01eo
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {0.586364, -0.050005, 0.00161548, \
0.00351603}}]
}, Open  ]],

Cell[TextData[{
  "This spanning tree was not unique ... in fact there are about ",
  Cell[BoxData[
      \(TraditionalForm\`10\^17\)]],
  "of them. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumberOfSpanningTrees[CompleteGraph[6, 6, 6]]\)], "Input"],

Cell[BoxData[
    \(277326388342554624\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[\ %\ ]\)], "Input"],

Cell[BoxData[
    \(2.7732638834255462`*^17\)], "Output"]
}, Open  ]],

Cell["\<\
This computes the maximum amount of goods that can from through \
this graph where \[Dash] in this case \[Dash] each edge (or road) has \
capacity one. This is an example of a common discrete optimization problem. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NetworkFlow[CompleteGraph[6, 6, 6], 1, 18]\)], "Input"],

Cell[BoxData[
    \(12\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Summary", "Section",
  PageBreakAbove->True],

Cell["\<\
Modern technical computation needs impose many requirements on \
software. Programs need good graphical capabilities. Functionality for basic \
mathematics (e.g. calculus and linear algebra), signal processing (e.g. \
various mathematical transforms), image processing (e.g. list convolution \
a.k.a. DFT), and more are a necessity. Programs must have good heuristics in \
regards to knowing what algorithms to deploy for various types of \
computations.\
\>", "Text"],

Cell[TextData[{
  "In general there is the need to \"do alot of neat stuff\" and also to link \
to other dedicated programs when the limitations of your general program are \
reached. As I work on one such general purpose technical program, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", I have attempted to illustrate a few of these ideas in that language. \
But the same needs exist for other programs and are generally pushing much of \
the computational software \"industry\" (both commercial and academic) in the \
directions I have indicated."
}], "Text"]
}, Closed]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
ScreenStyleEnvironment->"Presentation",
Evaluator->"Local",
WindowSize->{1016, 668},
WindowMargins->{{50, Automatic}, {-80, Automatic}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "usr1", "danl"}, \
"IWU_Talk.nb.ps", CharacterEncoding -> "ISO8859-1"],
"Magnification"->1},
Magnification->2,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 11},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[0],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->38],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {10, 20}},
    FontSize->40,
    FontTracking->"Plain",
    Background->GrayLevel[1]]
  }, Open  ]],
  
  Cell[RawData["\<\
Cell[StyleData[\"Subtitle\"],
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {0, 0}},
  PageBreakBelow->False,
  InputAutoReplacements->{\"TeX\"->StyleBox[ 
          RowBox[ {\"T\", 
            AdjustmentBox[ 
            \"E\", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
              BoxBaselineShift -> 0.5], \"X\"}]], 
      \"LaTeX\"->StyleBox[ 
          RowBox[ {\"L\", 
            StyleBox[ 
              AdjustmentBox[ 
              \"A\", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> 
              Smaller], \"T\", 
            AdjustmentBox[ 
            \"E\", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
              BoxBaselineShift -> 0.5], \"X\"}]], 
      \"mma\"->\"Mathematica\", \"Mma\"->\"Mathematica\", 
      \"MMA\"->\"Mathematica\", Inherited},
  LineSpacing->{1, 3},
  ParagraphIndent->-96,
  CounterIncrements->\"Subtitle\",
  CounterAssignments->{{\"Section\", 0}, {\"Equation\", 0}, {
      \"Figure\", 0}, {\"Subsubtitle\", 0}},
  FontFamily->\"Helvetica\",
  FontSize->18,
  FontColor->GrayLevel[1],
  Background->RGBColor[0.2, 0.700008, 0.700008]]\
\>"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[RawData["\<\
Cell[StyleData[\"Subtitle\", \"Presentation\"],
  CellMargins->{{0, 0}, {0, 0}},
  LineSpacing->{1, 6},
  ParagraphIndent->-157,
  FontSize->30]\
\>"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[RawData["\<\
Cell[StyleData[\"Subtitle\", \"Condensed\"],
  CellMargins->{{0, 0}, {0, 0}},
  ParagraphIndent->-78,
  FontSize->14]\
\>"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[RawData["\<\
Cell[StyleData[\"Subtitle\", \"Printout\"],
  CellMargins->{{0, 0}, {0, 0}},
  ParagraphIndent->-85,
  FontSize->16,
  Background->GrayLevel[0.6]]\
\>"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 7},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 7},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    LineSpacing->{1, 9},
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{22, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6},
    FontSize->16]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", Inherited},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    FontSize->7]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{62, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {4, 4}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{44, 0}, {6, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    Background->GrayLevel[0.8]]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{62, Inherited}, {12, 5}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{40, Inherited}, {4, 1}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{44, 0}, {6, 2}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {2, 2}},
    LineSpacing->{1, 1},
    FontSize->16],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 2}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->16],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->12],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{20, 0}, {4, 4}},
    ParagraphSpacing->{0, 4},
    FontSize->16]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    ShowCellBracket->False,
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{20, 0}, {72, 4}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    Hyphenation->True,
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    Hyphenation->True,
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    LineSpacing->{1, 7},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    Hyphenation->True,
    LineSpacing->{1, 7},
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{17, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellDingbat->None,
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{62, 10}, {5, 5}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{74, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{52, 10}, {2, 2}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{54, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    Hyphenation->False,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CellularAutomaton"->{
    Cell[15771924, 581184, 413, 8, 310, "Input",
      CellTags->"CellularAutomaton"],
    Cell[15993829, 584271, 225, 6, 298, "Input",
      CellTags->"CellularAutomaton"]},
  "S5.18.1"->{
    Cell[17154085, 635286, 117, 3, 160, "Input",
      CellTags->"S5.18.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CellularAutomaton", 17226689, 637138},
  {"S5.18.1", 17226879, 637143}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 87, 1, 222, "Title",
  PageBreakAbove->False],
Cell[1795, 53, 195, 5, 424, "Author"],
Cell[1993, 60, 54, 0, 141, "Copyright"],
Cell[2050, 62, 18, 0, 50, "Author"],

Cell[CellGroupData[{
Cell[2093, 66, 27, 0, 162, "Section"],
Cell[2123, 68, 746, 11, 582, "Text"],
Cell[2872, 81, 414, 7, 332, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3323, 93, 55, 1, 102, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[3403, 98, 32, 0, 135, "Subsection"],
Cell[3438, 100, 457, 11, 282, "Text"],
Cell[3898, 113, 341, 6, 282, "Text"],
Cell[4242, 121, 74, 0, 82, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4353, 126, 80, 1, 75, "Subsection",
  PageBreakAbove->True],
Cell[4436, 129, 286, 5, 282, "Text"],
Cell[4725, 136, 867, 19, 1064, "Text"],
Cell[5595, 157, 301, 7, 232, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5945, 170, 126, 5, 170, "Section"],
Cell[6074, 177, 481, 8, 382, "Text"],

Cell[CellGroupData[{
Cell[6580, 189, 41, 0, 135, "Subsection"],
Cell[6624, 191, 280, 5, 232, "Text"],
Cell[6907, 198, 43, 1, 114, "Input"],
Cell[6953, 201, 106, 3, 132, "Text"],

Cell[CellGroupData[{
Cell[7084, 208, 86, 1, 162, "Input"],
Cell[7173, 211, 49, 1, 108, "Output"]
}, Open  ]],
Cell[7237, 215, 53, 0, 82, "Text"],

Cell[CellGroupData[{
Cell[7315, 219, 101, 2, 210, "Input"],
Cell[7419, 223, 852, 14, 1164, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8332, 244, 78, 0, 170, "Section"],
Cell[8413, 246, 394, 7, 332, "Text"],

Cell[CellGroupData[{
Cell[8832, 257, 41, 0, 135, "Subsection"],
Cell[8876, 259, 251, 6, 182, "Text"],
Cell[9130, 267, 47, 1, 114, "Input"],
Cell[9180, 270, 55, 1, 114, "Input"],

Cell[CellGroupData[{
Cell[9260, 275, 322, 6, 306, "Input"],
Cell[9585, 283, 77077, 2968, 816, 37643, 2478, "GraphicsData", "PostScript", \
"Graphics"],
Cell[86665, 3253, 420, 8, 204, "Output"]
}, Open  ]],
Cell[87100, 3264, 55, 1, 114, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[87204, 3271, 38, 0, 102, "Section"],
Cell[87245, 3273, 257, 5, 218, "Text"],
Cell[87505, 3280, 60, 1, 112, "Input"],

Cell[CellGroupData[{
Cell[87590, 3285, 115, 4, 216, "Input"],
Cell[87708, 3291, 68979, 1456, 372, 11120, 737, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[156724, 4752, 142, 3, 202, "Input"],
Cell[156869, 4757, 92, 1, 105, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[156998, 4763, 58, 0, 130, "Subsection"],
Cell[157059, 4765, 541, 9, 452, "Text"],

Cell[CellGroupData[{
Cell[157625, 4778, 638, 12, 1088, "Input"],
Cell[158266, 4792, 141, 2, 150, "Output"]
}, Open  ]],
Cell[158422, 4797, 106, 3, 125, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[158577, 4806, 53, 0, 102, "Section"],
Cell[158633, 4808, 291, 5, 232, "Text"],

Cell[CellGroupData[{
Cell[158949, 4817, 55, 0, 135, "Subsection"],
Cell[159007, 4819, 176, 4, 176, "Text"],
Cell[159186, 4825, 464, 9, 762, "Input"],

Cell[CellGroupData[{
Cell[159675, 4838, 115, 2, 160, "Input"],
Cell[159793, 4842, 425206, 20696, 356, 374748, 20069, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[585048, 25544, 40, 0, 75, "Subsection"],
Cell[585091, 25546, 399, 7, 320, "Text"],
Cell[585493, 25555, 505, 11, 325, "Input"],
Cell[586001, 25568, 527, 12, 368, "Text"],
Cell[586531, 25582, 950, 17, 581, "Input"],
Cell[587484, 25601, 255, 6, 229, "Input"],
Cell[587742, 25609, 1557, 28, 997, "Input"],
Cell[589302, 25639, 270, 5, 437, "Input"],
Cell[589575, 25646, 97, 5, 80, "Text"],

Cell[CellGroupData[{
Cell[589697, 25655, 112, 2, 205, "Input"],
Cell[589812, 25659, 68, 1, 105, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[589929, 25666, 56, 0, 75, "Subsection"],
Cell[589988, 25668, 456, 7, 368, "Text"],
Cell[590447, 25677, 1005, 21, 581, "Input"],
Cell[591455, 25700, 892, 17, 517, "Input"],
Cell[592350, 25719, 52, 0, 80, "Text"],

Cell[CellGroupData[{
Cell[592427, 25723, 323, 7, 530, "Input"],
Cell[592753, 25732, 69, 1, 105, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[592859, 25738, 37, 1, 113, "Input"],
Cell[592899, 25741, 351, 6, 597, "Output"]
}, Open  ]],
Cell[593265, 25750, 111, 3, 128, "Text"],

Cell[CellGroupData[{
Cell[593401, 25757, 79, 1, 160, "Input"],
Cell[593483, 25760, 217, 3, 240, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[593749, 25769, 56, 0, 75, "Subsection"],
Cell[593808, 25771, 219, 4, 182, "Text"],
Cell[594030, 25777, 228, 4, 182, "Text"],

Cell[CellGroupData[{
Cell[594283, 25785, 36, 0, 117, "Subsubsection"],
Cell[594322, 25787, 3251, 67, 1300, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[597610, 25859, 52, 0, 69, "Subsubsection"],
Cell[597665, 25861, 121, 3, 132, "Text"],
Cell[597789, 25866, 1328, 27, 670, "Input"],
Cell[599120, 25895, 212, 4, 182, "Text"],

Cell[CellGroupData[{
Cell[599357, 25903, 75, 1, 162, "Input"],
Cell[599435, 25906, 4052, 82, 908, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[603536, 25994, 35, 0, 69, "Subsubsection"],
Cell[603574, 25996, 481, 8, 382, "Text"],
Cell[604058, 26006, 121, 2, 162, "Input"],
Cell[604182, 26010, 80, 1, 162, "Input"],
Cell[604265, 26013, 250, 5, 402, "Input"],
Cell[604518, 26020, 236, 5, 354, "Input"],
Cell[604757, 26027, 386, 8, 498, "Input"],
Cell[605146, 26037, 245, 5, 354, "Input"],
Cell[605394, 26044, 403, 7, 450, "Input"],
Cell[605800, 26053, 262, 5, 306, "Input"],
Cell[606065, 26060, 287, 5, 402, "Input"],
Cell[606355, 26067, 335, 7, 402, "Input"],
Cell[606693, 26076, 275, 5, 354, "Input"],
Cell[606971, 26083, 325, 6, 402, "Input"],
Cell[607299, 26091, 539, 9, 594, "Input"],
Cell[607841, 26102, 280, 5, 354, "Input"],
Cell[608124, 26109, 521, 9, 594, "Input"],
Cell[608648, 26120, 70, 0, 69, "SmallText"],

Cell[CellGroupData[{
Cell[608743, 26124, 81, 1, 162, "Input"],
Cell[608827, 26127, 1321, 26, 1500, "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[610221, 26161, 36, 0, 102, "Section"],
Cell[610260, 26163, 487, 8, 382, "Text"],

Cell[CellGroupData[{
Cell[610772, 26175, 279, 6, 190, "Input"],
Cell[611054, 26183, 581633, 24529, 735, 444468, 22831, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1192724, 50717, 1050, 19, 504, "Input"],
Cell[1193777, 50738, 1269967, 34995, 1179, 1129405, 33255, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2463781, 85738, 96, 2, 148, "Input"],
Cell[2463880, 85742, 6970695, 321805, 1076, 6817443, 319909, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9434612, 407552, 96, 2, 119, "Input"],
Cell[9434711, 407556, 1371099, 35291, 1076, 1223589, 33465, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[10805825, 442850, 439, 14, 187, "Text"],
Cell[10806267, 442866, 4768407, 132700, 592, 4642783, 131145, "GraphicsData", \
"PostScript", "Graphics"],

Cell[CellGroupData[{
Cell[15574699, 575570, 53, 0, 135, "Subsection"],
Cell[15574755, 575572, 116, 3, 130, "Input"],
Cell[15574874, 575577, 297, 7, 190, "Input"],
Cell[15575174, 575586, 195, 5, 130, "Input"],
Cell[15575372, 575593, 715, 14, 310, "Input"],
Cell[15576090, 575609, 745, 16, 340, "Input"],
Cell[15576838, 575627, 131, 3, 100, "Input"],
Cell[15576972, 575632, 136, 3, 100, "Input"],
Cell[15577111, 575637, 228, 6, 160, "Input"],
Cell[15577342, 575645, 2028, 38, 560, "Input"],
Cell[15579373, 575685, 3458, 62, 768, "Input"],
Cell[15582834, 575749, 578, 11, 286, "Input"],
Cell[15583415, 575762, 387, 7, 198, "Input"],
Cell[15583805, 575771, 201, 4, 124, "Input"],
Cell[15584009, 575777, 297, 5, 166, "Input"],
Cell[15584309, 575784, 267, 5, 159, "Input"],
Cell[15584579, 575791, 326, 8, 293, "Input"],
Cell[15584908, 575801, 230, 4, 165, "Input"],
Cell[15585141, 575807, 200, 4, 140, "Input"],
Cell[15585344, 575813, 152, 3, 138, "Input"],
Cell[15585499, 575818, 182, 4, 165, "Input"],
Cell[15585684, 575824, 705, 16, 224, "Input"],
Cell[15586392, 575842, 612, 14, 184, "Input"],
Cell[15587007, 575858, 153, 3, 133, "Input"],
Cell[15587163, 575863, 3801, 75, 1522, "Input"],
Cell[15590967, 575940, 320, 8, 229, "Input"],
Cell[15591290, 575950, 697, 12, 301, "Input"],
Cell[15591990, 575964, 2138, 44, 916, "Input"],
Cell[15594131, 576010, 984, 17, 496, "Input"],
Cell[15595118, 576029, 300, 6, 197, "Input"],
Cell[15595421, 576037, 159, 3, 165, "Input"],
Cell[15595583, 576042, 196, 4, 197, "Input"],
Cell[15595782, 576048, 195, 4, 165, "Input"],
Cell[15595980, 576054, 1825, 34, 869, "Input"],
Cell[15597808, 576090, 227, 6, 165, "Input"],
Cell[15598038, 576098, 134, 3, 133, "Input"],
Cell[15598175, 576103, 2566, 43, 1413, "Input"],
Cell[15600744, 576148, 262, 5, 197, "Input"],
Cell[15601009, 576155, 847, 17, 357, "Input"],
Cell[15601859, 576174, 1061, 21, 430, "Input"],
Cell[15602923, 576197, 1527, 30, 490, "Input"],
Cell[15604453, 576229, 1249, 25, 520, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15605751, 576260, 57, 0, 102, "Section"],
Cell[15605811, 576262, 598, 11, 452, "Text"],

Cell[CellGroupData[{
Cell[15606434, 576277, 42, 0, 130, "Subsection"],
Cell[15606479, 576279, 100, 3, 125, "Text"],
Cell[15606582, 576284, 1028, 21, 434, "Input"],

Cell[CellGroupData[{
Cell[15607635, 576309, 79, 1, 157, "Input"],
Cell[15607717, 576312, 980, 15, 513, "Output"]
}, Open  ]],
Cell[15608712, 576330, 185, 4, 172, "Text"],

Cell[CellGroupData[{
Cell[15608922, 576338, 124, 3, 157, "Input"],
Cell[15609049, 576343, 149, 2, 150, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15609247, 576351, 60, 0, 122, "Subsection"],
Cell[15609310, 576353, 487, 10, 358, "Text"],
Cell[15609800, 576365, 287, 6, 182, "Input"],
Cell[15610090, 576373, 132, 3, 126, "Input"],
Cell[15610225, 576378, 407, 9, 610, "Input"],

Cell[CellGroupData[{
Cell[15610657, 576391, 88, 1, 202, "Input"],
Cell[15610748, 576394, 2089, 35, 1057, "Output"]
}, Open  ]],
Cell[15612852, 576432, 90, 3, 78, "Text"],
Cell[15612945, 576437, 863, 15, 444, "Input"],
Cell[15613811, 576454, 1172, 21, 550, "Input"],

Cell[CellGroupData[{
Cell[15615008, 576479, 167, 4, 248, "Input"],
Cell[15615178, 576485, 155749, 4669, 1120, 52815, 3394, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[15770942, 581157, 451, 7, 358, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15771442, 581170, 50, 0, 102, "Section"],
Cell[15771495, 581172, 362, 6, 218, "Text"],

Cell[CellGroupData[{
Cell[15771882, 581182, 39, 0, 109, "Subsubsection"],
Cell[15771924, 581184, 413, 8, 310, "Input",
  CellTags->"CellularAutomaton"],
Cell[15772340, 581194, 356, 7, 230, "Input"],
Cell[15772699, 581203, 106, 2, 97, "Input"],
Cell[15772808, 581207, 119, 3, 97, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15772964, 581215, 45, 0, 62, "Subsubsection"],

Cell[CellGroupData[{
Cell[15773034, 581219, 89, 1, 157, "Input"],
Cell[15773126, 581222, 593, 11, 302, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15773756, 581238, 51, 1, 112, "Input"],
Cell[15773810, 581241, 4718, 107, 330, 916, 56, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[15778543, 581351, 147, 3, 125, "Text"],

Cell[CellGroupData[{
Cell[15778715, 581358, 143, 3, 202, "Input"],
Cell[15778861, 581363, 214251, 2884, 592, 82776, 1256, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[15993127, 584250, 450, 7, 358, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[15993614, 584262, 68, 0, 62, "Subsubsection"],
Cell[15993685, 584264, 119, 3, 128, "Text"],

Cell[CellGroupData[{
Cell[15993829, 584271, 225, 6, 298, "Input",
  CellTags->"CellularAutomaton"],
Cell[15994057, 584279, 47014, 959, 122, 30127, 746, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16041108, 585243, 105, 2, 205, "Input"],
Cell[16041216, 585247, 339, 5, 418, "Output"]
}, Open  ]],
Cell[16041570, 585255, 74, 0, 80, "Text"],

Cell[CellGroupData[{
Cell[16041669, 585259, 76, 1, 113, "Input"],
Cell[16041748, 585262, 71158, 2116, 512, 29801, 1601, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[16112921, 587381, 54, 0, 80, "Text"],

Cell[CellGroupData[{
Cell[16113000, 587385, 160, 3, 252, "Input"],
Cell[16113163, 587390, 876523, 44162, 448, 827554, 43553, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[16989747, 631559, 101, 3, 170, "Section"],
Cell[16989851, 631564, 195, 4, 182, "Text"],

Cell[CellGroupData[{
Cell[16990071, 631572, 55, 0, 135, "Subsection"],
Cell[16990129, 631574, 245, 5, 232, "Text"],
Cell[16990377, 631581, 113, 3, 132, "Text"],
Cell[16990493, 631586, 51, 1, 114, "Input"],
Cell[16990547, 631589, 188, 8, 82, "Text"],
Cell[16990738, 631599, 67, 1, 114, "Input"],
Cell[16990808, 631602, 34, 0, 82, "Text"],
Cell[16990845, 631604, 71, 1, 114, "Input"],

Cell[CellGroupData[{
Cell[16990941, 631609, 139, 3, 162, "Input"],
Cell[16991083, 631614, 9361, 293, 372, 3063, 211, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[17000459, 631910, 70, 0, 82, "Text"],

Cell[CellGroupData[{
Cell[17000554, 631914, 73, 1, 160, "Input"],
Cell[17000630, 631917, 445, 10, 418, "Output"]
}, Open  ]],
Cell[17001090, 631930, 135, 3, 128, "Text"],

Cell[CellGroupData[{
Cell[17001250, 631937, 46, 1, 113, "Input"],
Cell[17001299, 631940, 442, 8, 288, "Output"]
}, Open  ]],
Cell[17001756, 631951, 60, 0, 80, "Text"],

Cell[CellGroupData[{
Cell[17001841, 631955, 83, 1, 113, "Input"],
Cell[17001927, 631958, 14661, 439, 372, 4507, 309, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[17016603, 632400, 163, 4, 176, "Text"],

Cell[CellGroupData[{
Cell[17016791, 632408, 75, 1, 113, "Input"],
Cell[17016869, 632411, 16836, 467, 372, 5950, 328, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17033708, 632880, 979, 24, 688, "Output"]
}, Open  ]],
Cell[17034702, 632907, 89, 3, 80, "Text"],

Cell[CellGroupData[{
Cell[17034816, 632914, 90, 1, 114, "Input"],
Cell[17034909, 632917, 16822, 458, 372, 4384, 300, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[17051746, 633378, 49, 0, 82, "Text"],

Cell[CellGroupData[{
Cell[17051820, 633382, 64, 1, 114, "Input"],
Cell[17051887, 633385, 16704, 473, 372, 4772, 321, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17068652, 633865, 141, 3, 238, "Section"],

Cell[CellGroupData[{
Cell[17068818, 633872, 55, 0, 117, "Subsubsection"],
Cell[17068876, 633874, 286, 7, 232, "Text"],
Cell[17069165, 633883, 63, 1, 114, "Input"],
Cell[17069231, 633886, 131, 2, 210, "Input"],
Cell[17069365, 633890, 89, 3, 82, "Text"],

Cell[CellGroupData[{
Cell[17069479, 633897, 75, 1, 114, "Input"],
Cell[17069557, 633900, 84301, 1375, 592, 4321, 383, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[17153873, 635278, 187, 4, 182, "Text"],

Cell[CellGroupData[{
Cell[17154085, 635286, 117, 3, 160, "Input",
  CellTags->"S5.18.1"],
Cell[17154205, 635291, 31596, 487, 592, 1471, 110, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[17185816, 635781, 162, 5, 128, "Text"],

Cell[CellGroupData[{
Cell[17186003, 635790, 78, 1, 160, "Input"],
Cell[17186084, 635793, 52, 1, 105, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17186173, 635799, 41, 1, 114, "Input"],
Cell[17186217, 635802, 57, 1, 108, "Output"]
}, Open  ]],
Cell[17186289, 635806, 240, 5, 232, "Text"],

Cell[CellGroupData[{
Cell[17186554, 635815, 75, 1, 162, "Input"],
Cell[17186632, 635818, 36, 1, 108, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17186729, 635826, 50, 1, 102, "Section",
  PageBreakAbove->True],
Cell[17186782, 635829, 478, 8, 382, "Text"],
Cell[17187263, 635839, 574, 10, 432, "Text"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

